(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  17010249,     327949]*)
(*NotebookOutlinePosition[  17010947,     327973]*)
(*  CellTagsIndexPosition[  17010903,     327969]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Two soda cans classification examples", "Title"],

Cell[TextData[{
  "This notebook  assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global variables", "Section"],

Cell[CellGroupData[{

Cell["File information", "Subsection"],

Cell[BoxData[
    \(\(dir = \
"\</Users/nechyba/www/eel6825/course_materials/t5.em_examples2/soda_cans_data\
\>";\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(segmentedFile1 = "\<coke_eng_sml.ppm\>";\)\), "\[IndentingNewLine]", 
    \(\(segmentedFile2 = "\<light_eng_sml.ppm\>";\)\), "\[IndentingNewLine]", \

    \(\(segmentedFile1T\  = \ "\<coke_chn_sml.ppm\>";\)\), "\
\[IndentingNewLine]", 
    \(\(segmentedFile2T\  = \ "\<light_chn_sml.ppm\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(SetDirectory[dir];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Replacement color", "Subsection"],

Cell[BoxData[
    \(\(replacementColor = {0, 255, 0};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting options", "Subsection"],

Cell[BoxData[{
    \(\(pointStyle1\  = \ {Orange, \ 
          PointSize[ .01]};\)\), "\[IndentingNewLine]", 
    \(\(pointStyle2\  = \ {Purple, \ PointSize[ .01]};\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(classColor1\  = \ RGBColor[ .5, 1, 1];\)\), "\[IndentingNewLine]", 
    \(classColor2\  = \ RGBColor[1, 1,  .5]; 
    classColors\  = \ {classColor1, \ classColor2};\)}], "Input"],

Cell[BoxData[
    \(\(pr = {{0, 255}, {0, 255}};\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Segment loaded image", "Subsection"],

Cell[BoxData[
    \(\(SegmentObject[img_, thresh_:  245, \ 
          color_:  
            replacementColor] := \[IndentingNewLine]Module[{img2}, \
\[IndentingNewLine]img2\  = \ 
            Map[If[#[\([1]\)]\  > \ thresh\  && \ #[\([2]\)]\  > \ 
                      thresh\  && \ #[\([3]\)]\  > \ thresh, \ 
                  replacementColor, #] &\ , 
              img[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[img, 
            img2, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Segment file image", "Subsection"],

Cell[BoxData[
    \(\(ConvertImage[outFile_, inFile_, \ type_, \ thresh_:  245, 
          color_:  
            replacementColor] := \[IndentingNewLine]Module[{img}, \
\[IndentingNewLine]img = Import[inFile, type]; \[IndentingNewLine]img2 = 
            SegmentObject[img, thresh, color]; \[IndentingNewLine]Export[
            outFile, img2, "\<PPM\>"];\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extract RGB data from segmented images", "Subsection"],

Cell[BoxData[
    \(\(ExtractRGB[img_, 
          color_:  
            replacementColor] := \[IndentingNewLine]Module[{rgb}, \
\[IndentingNewLine]rgb = 
            Partition[Flatten[img[\([1, 1]\)]], 
              3]; \[IndentingNewLine]DeleteCases[rgb, 
            color]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get representative sample of data", "Subsection"],

Cell[BoxData[
    \(\(RepresentativeSample[dat_, \ 
          n_] := \[IndentingNewLine]Module[{d2, 
            m}, \[IndentingNewLine]m\  = \ 
            Ceiling[Length[dat]/n]; \[IndentingNewLine]d2\  = \ 
            First\  /@ \ Partition[dat, \ m]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data plotting routines", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Plot representative sample data (columns a and b from dat ) from a \
larger data set in 2d\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PlotRepresentativeSample2D[dat_, \ n_, {a_, b_}, \ 
          opt___] := \[IndentingNewLine]Module[{d2, m, 
            rgblabel}, \[IndentingNewLine]rgblabel\  = \ {"\<Red\>", \ \
"\<Green\>", \ "\<Blue\>"}; \[IndentingNewLine]m\  = \ 
            Ceiling[Length[dat]/n]; \[IndentingNewLine]d2\  = \ 
            First\  /@ \ Partition[dat, \ m]; \[IndentingNewLine]Show[
            Graphics[
              Join[opt, \(Point[{#[\([a]\)], #[\([b]\)]}] &\) /@ \ d2]], \ 
            Frame \[Rule] True, AspectRatio \[Rule] Automatic, \ 
            FrameLabel \[Rule] {rgblabel[\([a]\)], \ rgblabel[\([b]\)]}, \ 
            DisplayFunction \[Rule] Identity, \ 
            PlotRange \[Rule] {{0, 255}, {0, 255}}]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot representative sample data  from a larger data set in 3d\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(PlotRepresentativeSample3D[dat_, \ n_, \ 
          opt___] := \[IndentingNewLine]Module[{d2, 
            m}, \[IndentingNewLine]m\  = \ 
            Ceiling[Length[dat]/n]; \[IndentingNewLine]d2\  = \ 
            First\  /@ \ Partition[dat, \ m]; \[IndentingNewLine]Show[
            Graphics3D[Join[opt, Point /@ \ d2]], \ 
            DisplayFunction \[Rule] Identity, 
            PlotRange -> {{0, 255}, {0, 255}, {0, 255}}]];\)\)], "Input"],

Cell[BoxData[
    \(data2pixel[{r_, g_, b_, x_, y_}] := {RGBColor[r/255. , g/255. , 
          b/255. ], \ Rectangle[{x, \(-y\) - 1}, {x + 1, \(-y\)}]}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(EMAllPlot[{\[Mu]_, \[CapitalSigma]_, priors_}, \ 
          gin_] := \[IndentingNewLine]Module[{pr, g2, g4, 
            g5}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nS, \ 
              FrameTicks \[Rule] None]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nS, \ 
              FrameTicks \[Rule] None]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nS, \ 
              Axes \[Rule] None]; \[IndentingNewLine]Show[
            GraphicsArray[{{g2, gin}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (2d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage2DAugmented[im_, pdf1_, pdf2_, \ 
          which_: {Red, \ Green}, \ 
          scale_:  1] := \[IndentingNewLine]Module[{class, colors, pos1, 
            pos2, lpdf, gr, 
            bl}, \[IndentingNewLine]gr = \((List @@ \((pointStyle1\  // \ 
                      First)\))\)*255; \[IndentingNewLine]bl = \((List @@ \
\((pointStyle2 // First)\))\)*255; \[IndentingNewLine]colors = {Red, Green, 
              Blue}; \[IndentingNewLine]pos1 = \(Position[colors, 
                  which[\([1]\)]] // Flatten\)\  // 
              First; \[IndentingNewLine]pos2 = \(Position[colors, 
                  which[\([2]\)]] // Flatten\)\  // 
              First; \[IndentingNewLine]lpdf\  = \ \((Log[pdf1]\  // 
                  PowerExpand)\)\  - \ \((Log[pdf2]\  // \ 
                  PowerExpand)\); \[IndentingNewLine]class\  = \ 
            Map[If[# \[Equal] replacementColor, replacementColor, 
                  If[\((lpdf\  /. \ {x \[Rule] #[\([pos1]\)]/scale\  // \ N, 
                            y \[Rule] #[\([pos2]\)]/scale\  // \ N})\)\  > \ 
                      0, \ gr, \ bl]] &, \ 
              im[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[im, 
            class, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (3d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage3DAugmented[im_, lpdf1_, lpdf2_, \ 
          scale_:  1] := \[IndentingNewLine]Module[{class, colors, lpdf, gr, 
            bl}, \[IndentingNewLine]gr = \((List @@ \((pointStyle1\  // \ 
                      First)\))\)*255; \[IndentingNewLine]bl = \((List @@ \
\((pointStyle2 // First)\))\)*255; \[IndentingNewLine]colors = {Red, Green, 
              Blue}; \[IndentingNewLine]lpdf\  = \ \((lpdf1\  - \ 
                lpdf2)\); \[IndentingNewLine]class\  = \ 
            Map[If[# \[Equal] replacementColor, replacementColor, 
                  If[\((lpdf\  /. \ {x \[Rule] #[\([1]\)]/scale\  // \ N, 
                            y \[Rule] #[\([2]\)]/scale\  // \ N, \ 
                            z \[Rule] #[\([3]\)]/scale\  // \ N})\)\  > \ 
                      0, \ gr, \ bl]] &, \ 
              im[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[im, 
            class, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Count pixels in classified images", "Subsection"],

Cell[BoxData[
    \(\(CountPixels[classim_, 
          color1_: \((List\  @@ \ \((pointStyle1\  // \ First)\))\)*255, \ 
          color2_: \((List\  @@ \ \((pointStyle2\  // \ First)\))\)*255, 
          backgroundColor_:  
            replacementColor] := \[IndentingNewLine]Module[{cnts, n1, n2, 
            n3}, \[IndentingNewLine]cnts = 
            Frequencies[
              Partition[Flatten[classim[\([1, 1]\)]], 
                3]]; \[IndentingNewLine]n1 = 
            cnts[\([\(Position[cnts, color1]\  // \ Flatten\)\  // \ First, 
                1]\)]; \[IndentingNewLine]n2 = 
            cnts[\([\(Position[cnts, color2]\  // \ Flatten\)\  // \ First, 
                1]\)]; \[IndentingNewLine]n3 = 
            cnts[\([\(Position[cnts, backgroundColor]\  // \ Flatten\)\  // \ 
                  First, 1]\)]; \[IndentingNewLine]{100*n1/\((n1 + n2)\), \ 
              100*n2/\((n1 + n2)\)}\  // \ 
            N\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normalized log-likelihood for each object (2d)", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood2D[data1_, \ data2_, \ 
          which_] := \[IndentingNewLine]Module[{d1, 
            d2, \[Mu]1, \ \[CapitalSigma]1, \ 
            gauss1, \ \[Mu]2, \ \[CapitalSigma]2, \ gauss2, \ a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]\[Mu]1 = Mean[d1]; \[CapitalSigma]1 = 
            CovarianceMatrix[d1]; 
          gauss1 = {{\[Mu]1}, {\[CapitalSigma]1}, {1. }}; \[IndentingNewLine]\
\[Mu]2 = Mean[d2]; \[CapitalSigma]2 = CovarianceMatrix[d2]; 
          gauss2 = {{\[Mu]2}, {\[CapitalSigma]2}, {1. }}; \
\[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, gauss1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, gauss2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, gauss1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, gauss2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Normalized log-likelihood for each object (2d) (mixture \
model)\
\>", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood2DEM[data1_, \ data2_, \ model1_, \ model2_, 
          which_] := \[IndentingNewLine]Module[{d1, d2, \ a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, model1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, model2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, model1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, model2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normalized log-likelihood for each object (3d)", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood3D[data1_, \ 
          data2_] := \[IndentingNewLine]Module[{d1, 
            d2, \[Mu]1, \ \[CapitalSigma]1, \ 
            gauss1, \ \[Mu]2, \ \[CapitalSigma]2, \ gauss2, \ a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]\[Mu]1 = Mean[d1]; \[CapitalSigma]1 = 
            CovarianceMatrix[d1]; 
          gauss1 = {{\[Mu]1}, {\[CapitalSigma]1}, {1. }}; \[IndentingNewLine]\
\[Mu]2 = Mean[d2]; \[CapitalSigma]2 = CovarianceMatrix[d2]; 
          gauss2 = {{\[Mu]2}, {\[CapitalSigma]2}, {1. }}; \
\[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, gauss1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, gauss2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, gauss1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, gauss2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Normalized log-likelihood for each object (3d) (mixture \
model)\
\>", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood3DEM[data1_, \ data2_, model1_, 
          model2_] := \[IndentingNewLine]Module[{d1, d2, a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, model1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, model2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, model1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, model2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3d EM initialization function", "Subsection"],

Cell[CellGroupData[{

Cell["Scalar covariance initialization 3d", "Subsubsection"],

Cell[BoxData[
    \(\(EMInitializationScalar3D[x_, \ k_] := 
        Module[{n, \ rl, \ \[Mu], \ \[Sigma], \ priors, \ sm, \ del2}, \n\t
          n\  = \ Length[x]; \n\t
          rl\  = \ Table[{Random[Integer, {1, n}]}, \ {k}]; \n\t\[Mu]\  = \ 
            Partition[Flatten[\(Take[x, \ #] &\)\  /@ \ rl], \ 3]; \n\t
          sm\  = \ 
            Table[\(dist[#, \ \[Mu][\([i]\)]] &\)\  /@ \ \[Mu], \ {i, \ 1, \ 
                k}]; \n\t
          del2\  = \ 
            Table[{i, i}\ \ , \ {i, \ 1, 
                k}]; \n\t\[Sigma]\  = \ \(\((#*#)\) &\)\  /@ \ \((Min\  /@ \ 
                  Delete[sm, \ del2])\); \n\t
          priors\  = \ Table[1/k, \ {k}]\  // \ N; \n\t{\[Mu], \ \[Sigma], \ 
            priors}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Full covariance initialization 3d", "Subsubsection"],

Cell[BoxData[
    \(\(EMInitializationFull3D[x_, 
          k_] := \[IndentingNewLine]Module[{\[Mu], \[Sigma], priors, 
            dim}, \[IndentingNewLine]{\[Mu], \[Sigma], priors}\  = \ 
            EMInitializationScalar3D[x, \ k]; \[IndentingNewLine]dim\  = \ 
            Length[First[\[Mu]]]; \[IndentingNewLine]{\[Mu], \(\((#\ \
IdentityMatrix[dim])\) &\)\  /@ \ \[Sigma], 
            priors}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Load and visualize data", "Section"],

Cell[CellGroupData[{

Cell["Load segmented images", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(obj1 = Import[segmentedFile1, "\<PPM\>"];\)\), "\n", 
    \(\(obj2 = Import[segmentedFile2, "\<PPM\>"];\)\), "\n", 
    \(\(obj1T = 
        Import[segmentedFile1T, "\<PPM\>"];\)\), "\[IndentingNewLine]", 
    \(\(obj2T = 
        Import[segmentedFile2T, "\<PPM\>"];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{obj1, obj2, obj1T, obj2T}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45448 
%%ImageSize: 400 181.791 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0108209 0.238095 [
[ 0 0 0 0 ]
[ 1 .45448 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45448 L
0 .45448 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0108209 0.245293 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0108209 0.488926 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C834
59C9355AC9365CC9365CC9355ECD3B61D14389B25CBB9C81BD9F86BC9C80B29274B59678
51C337AD9173BCA285BCA48CBAA590B19B88B29D8A857668796F639486738A7A62887760
9B886D5AD1457FAF5953CA3E56C93D55C63A55C5382AE11B00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008CB65EB89A7CBA9D81
BEA588C7B095BDA38BC2A78FDCC7B5D8C9B9CCBEAEC9BAA9CEBEACBAA793AC9580C3AE9B
D2C3B5C0B5A8CBC1B6D6CEC8B6B3B2868484B0AAA842464C1D2E39626C6FA7A8A48F9190
9B9F9DC9CCC8B0B6B1BDC1BBC7C4BACAC1B5C4B7A9C1B0A2BCA797B59E8EB39A8784B163
59CD4256C93D51C33600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE318
59C6315BC734B69169B8946CBA9A72B89E7BD2BB9DCCB69CB6A28AD4C4AED2C4B0BAA996
BCAB97D7CBBCDDD1C5CBBDB1CFC2B7CFC7BCC5BDB1AEA393BDAE9ECCBFB2C3B6AAC6BBB1
D5D0CBC2C2BEB3B1ACBCB9B5A1A2A26E6E719E9A98B1B3B399A8AF90A4AEBBC9CEA9BAC4
3450655B7B915B7B8C627E8BBCCED2C8CFCFC9CCCACCCBC9CECBC8CEC9C7CEC9C6CEC9C4
CFCAC2CEC5BCC5B8AEBCAFA3B3A393AC978555CA4300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002CE31959C7325BCA3489B14FB8986BBD9C72
C09D76C19E7AC5A484CBAB8FC4A78DC0A88FD4C3ACCFBEA9B9A790B8A68FC2B5A2CAC0AE
BFB5A5D3CABED8D2C9C8BEB3BAAE9EC6BDAFCEC9BCC7C0B4CAC2B8D6D1CAD6D1CABBB3AC
C2BDB6B3B2ADB0AEA8ABA89FCAC8C1D3D3D1C0C1C1BCC0C1AAB9C2334D66536D838FA1B2
203A5412345182A2B6748E9CB0C6D0C1D0D5C7D0D3CBD1D4CAD0D2CDCFD3CCCFD1CCCED1
CCD0D1CACECFCCCECECCCDCCCACAC8CEC9C8C7BFBBC4B9B3BAABA0AF9A8859CE4550C236
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002DE3195BCA35B8946FBB9874BC9B76C09E7AC3A480C4A682C4A682
C7A885C5A987C6AB8DD1B7A0CFB7A0C9B198C7B099C8B29DC8B09DBEA894CEBEACD3CABC
BEB6A9A69D92AEA69DC6BDB5CAC1B7CBC3B9D8D5CDD6D6CEC1BEB5C0BCB3C8C2BBC2BAB3
BCB5ADD6D4CED6D6D0C7C7BFC0C1B9CBCFCD8690938891949BA3A94B5C6F455C6F9FB1BA
A9BCC785A0B29CBAC8B6D3DF648495ABC6D2C0CFD3C8D2D4C9D1D4CCD1D5CAD0D4CDD3D7
C6CED1C9CED1CBD0D3C9D0D3C9D0D3C7CCCFC9CBCEC9CBCEC7CAC9C7C7C3CAC6BFCBC1B8
C3AFA4A88E7E94755E47B52922D81100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC935
5ECC3ABA9670BC9974BC9D76BEA07BC0A07FC4A284C7A78AC7A98DC8AB8FC9AD90C9B090
CBB293CCB393CCB296CDB39ACEB69ECEB8A0CEB9A2D5C1AEE0CCBBC8B4A1C4AF9CBCAC9D
A79F90BEB7A9CDC5BCC7C2BDCDC8C3C6BCB5CBC4BCCDCCC4C3C1B9BFBCB4D7D5CEDADAD4
C6C6C1CBCCC7CDCFCABEBEB8B3B2A9B7B5AE979B9C9DA1A3B8BCB9CAD2D7B7C8D498AFBD
B8D1E14E6F8C254E6F799FB9284C667090A7BFD2DAC7D2D5C6CFD3C8D1D3C7D1D2CBD4D7
C7D1D2C9D0D2CCD1D4C8D0D3C7D1D3C8D0D3C8CED3BFC8CEBDC8CBC4CDCFC5CCCCC6C9C8
C7C5C4C7BEBCBDB1ACB1A1969D857489674F42B02100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BCA3486AE4FB79A72BDA37E
BEA281BD9F81BEA283C0A686C2A889C7AB8ECCAE92CCAF95CAAF98CEB49ECEB7A0CBB69E
CBB79FCEBAA0D0BAA2D3BAA3D5BFA9DAC8B3CFBEA8D2C0ABCEBCA7CBB4A0D0B7A4B9A99A
CEC7BBD9D4CACDC7BDCAC5BFAAA69FC7BFB5C7C0B6D8D7CEDBDAD5CECDC8CECDC7D9D7D3
CCCAC4C0BCB5C5C1BAC2BEB8C4C0B8C3BFB9D5D8D4CFD6D6B7BFC0C8D0D7687F9623476D
6D8EAE3F5F82143A6261839DA8C2D38EA8B8BDD3DDC6D5D9C6D2D6C7D1D3C8D2D4C6D0D2
C6D0D1C6CED0C8D0D4C8CFD5C4CDD2C2CCCEC6CED4C4CDD5C0CBD0C5CDD2C4CCCEC6CECE
C4CACBC5C7C9C0C2C4C1C1C0C4BFBAB9AAA29D877686694D3DAD1D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002CE41BB09268B3986EB99E77B79C77B79F7BBAA381
C0A887C1A888C4AB8BC6AD8FCAB398C8B196CEB89FCFBBA5CCBAA5D3C0ACD2C1ACD0BFAA
C9B8A5D0BFACD3C2AFD7C3B0D7C4B0D8C6B0D7C5ACD7C3AAD6C2AADDC7B3D7C1AEC3B2A3
B2A99FCDC7BEC7C0B6ABA69CBCB9B0DAD6CECAC7BFD3D2CBDADAD3CECBC4C2BBB2CCC5BE
D3CEC8C7C2BBD2CFC8DBD8D3D6D4D0CCCAC6CACBC8B7BFC2768489A9B3B88F9EAE46607F
7D94ADBDCEE0A5BBCE9BB6C9BAD3E295B2C36E8FA1BED6DFC8D6D9CCD6D8CCD4D9C9D1D4
C8D0D3C8CFD4CBD2D8C9D0D6C7CED4C5CCD2C4CDD3C4CDD6C4CED6C4CDD2C0CACDC3CCD0
C2CBCEC5CBCFC1C8CAC3C7CABEC1C4C1C3C3C1BEBBB7ACA4988471628D381ED50D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CE3185AC8335ACA36B0946CB59B76BAA17DBCA583BAA281BBA381BCA582BDA886
BEAA8AC2AD8FC8B295CDB89ECCB8A1CAB9A3CABAA6B7AA9AADA295A69A8BCABDABD4C3B0
D4C1ADD6C4B0DBC9B5DBC9B5DAC8B4DBC9B2DCC8B0DCC6AEDAC6AFDDCBB7D7C6B1D5C4AF
BCAF9EB9AFA4C1B8B1B8B2A9D7D4CCD8D7D1C4C1BAB9B5ABC7C3B9CFCBC2C7C2BAD2CCC6
DAD6D2D8D7D3C4C1BCD3CDC8D2CDC8C5C0BABBB6B0BFC0BEA4ACADB2B8BBCBD2D6C5D3E1
A2B6C7AABDCAA3BACC2B4E6E3A607F6185A01C435D9DBCCDC4D8DBCED9DACCD6D7CAD5D7
CAD3D8CAD3DACDD5DBC9D2D5C9D3D5CCD3D8C8CFD6C8CFD7C7CED6C6CDD5C2CBD0C0C9CF
C1CBCFC4CED0C4CDD0C0C8CCC1C7CCC2C6CABCC2C5C0C1C3C5C0BCAB9B90856D583BAB1E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058C833
85AE4FB7996FBB9C75B89C78B99F7DB9A380B7A380B8A384B7A383BDA987C1AD8AC1AD8C
C3AF91C8B298CDB79FCDB8A3CEBBA9D0BFAFC2B6A6B9AFA3D4C9C1A89E94C1B4A4DAC9B6
DECAB8DDC8B5DFCAB6DCC8B6DDCBB7DFCEB9E0CFB8E0CCB5E0CCB4DAC9B2D9C9B1D8C8B0
D2C5B0DED3C5E2D7CED0C6BCCBC2B6CAC4BAA6A49D9B9B95A6A8A0D8DAD2D8D7D1C4BEB8
CFCAC5CFCAC6BCB5AFC6BCB4CFC8C0D7D4CDC9C5BFCDCDC8D5D7D4C8CBCCADB1B4A4B1BD
2745603D5D788CA6BB2A4869183C5FA1C0D68AA7BA96B4C4C3DAE1CBD9DACCD7D9CAD4D6
C5CFD1C2CDD0C5D0D2C9D4D6C9D4D6CBD4D9C9D2D7C9D2D9C7CFD6C7D0D5C1CACFBFC8CD
BCC7CBC2CDD2C3CED4C1CAD1BFC8CDBFC7CCBDC5CBBDC1C9BDBFC5BDBCBFAEA9A68A796C
5E883600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE51A83AE4FB0956E
B89C78BC9F7DBFA282BDA283B9A083B6A084B5A082B7A284C0AB8CC1AD8CC9B393CAB697
C9B79CCDBBA1D3C0A7D1BDA6CFBCA9D0C1B1D6CEC1D9D5CFDCD7D3B3AAA0CCBDABD7C4AE
DDC8B3DECAB7DECCB8D9C7B5D9CAB8DCCEBDE0D0BDDFCDB7DECCB3DCCBB3DECEBADBCFBB
D4C8B3D4C5B4D4C5B6CFC1B2CBBFB0D6CDC3C2BFBBCBCBC88C9089CACDC5D2D1CAC0B8B1
C3BAB1D5D0C6D6D4CAC9C7BDCECDC4D8D9D2D4D6CFBBBBB4C2C4BF868B8E949A99ACB1B4
5D6F80536C80B0C4CFB3C7D58BA8BDA2C0D1B4D0E253768DA0C1D0C4D7DECAD4D6CAD3D6
C9D3D5C8D4D4C7D3D4C8D2D4C6D0D2C8D1D7C7CED6C6CFD7C5CED5C3CCD3C2C9CFC1C8D0
BCC5CCBDC6CDC2CBD2C2CBD0C3CCD3C3CAD3BEC7D0BBC2CBBBC1C8BEC4C9B8BEC3A7A6AB
7B736D55863700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002CE41958C934B0956CB09970B6A079
BAA17FBBA182BBA082BDA385BDA489B9A48CBAA58CBEA88BC8B192CAB294CCB498CDB89F
CEBBA3D1BFA7D4C0A8D3BCA5D1BDA6CDC1AFDEDBD0DCDDDADFDCDBD6CBC3D5C4B2D8C3AC
DBC6B0D9C7B1D7C9B4D7CDBFDDD6CDDFD9D0DCD2C5DECFBBDDCBB3DFCAB4DBC9B5D9C9B5
D8C8B4D8C6B1D8C8B6E1D4C5D3C8BAD3C7BCD4C9C4B1ABA6ABA79FC3BDB3D7D4CCD6D2CC
C7C1BAD8D6CDDADBD3D3D3CBC2BDB6CBC4BEC7C2BBB4AFA5BAB7B0B8BAB9B6B8B7BCBBB9
D2D8DCBDCED89CAEB6B1C4D046647E264C6C7CA0B9224764537A91C0D8E2CBD7DACCD4D7
CBD5D6CAD6D7C8D5D5CCD5D8CCD4D8CAD1D9C9D0DAC4CCD3C2CBD1BEC7CEBEC7CDBDC6CB
BBC4C8C1CACEC0C9CEC5CED3C7D0D5C5CED5C2CCD3BBC4CBB8C3C8BCC6CABFC7CFABB1BC
3F4652404042467D341AD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C73484AE51B3986FB1976FB59B74B59F78BAA482
B89E81BAA083BBA286BDA389C3AB92C3AD96C1AB92C5B095CAB599C9B499CAB49ACEB9A1
D2BFA8D2BEA9D1BCA7D1BBA6D4BEA9D4C5B1DDD8CAE0DED7DED8D1D5C7BAD7C5B2D8C3AC
D9C4AEC9BBA7B3AB9DBCBAB4CCCECCDADCDAE0DDD6DACFC0DCCCB7E0CBB5DDCAB5DBC9B4
DACAB3D7C7AED6C6B2DCD0C1D3C7BACEC0B2CFC1B6D6CCC2D3CBC3C7BFB8DCD9D1DBDAD4
CAC9C0C2BFB4CBC8BEC7C3BAC3BAB3C5BCB5DAD5D1D6D4CFC2C0BCD4D5D1D1D6D2A7ABA6
B3BABB5F74842C495F8CA3B6445F7B1033577D9FB69EBBCC7492A5B8D0DCC8D7D9CDD7D9
CCD6D8CBD6D8CBD6D8CDD5DACBD2D8CCD3DBC9D2D9C8CFD6C7CED3C1CACEBCC5C9B9C0C6
B6C0C2B7C2C6B9C4C6BFC9CDC4CFD3C6CFD7BFC9D2BFC8D0BBC6CCBAC4CDBFC8D1BDC6D0
7C8894717F8A62676B66594A1DD61000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0056C835AE936EB19672B39873B39974B49C77B69E7BB9A282B9A285
B79E87BAA28BBEA891C3AD97C3AC96C7B09CCAB59DCCB89ECCB79EC8B399CBB69CCDBBA1
CDBBA2CEBBA3D0BEA6D0BEA6D4C0A8D5C2ACD2C4B2D4C7B9D7C6B6D3BEA8D8C2AAD9C3AD
CCBBA9AEA391CDC6B9DAD8D3BFC1C2CED0D1DEDCD6D9D0C4DCCCBBDFCBB8DFCAB7DCC9B4
DAC8B2D8C6B0D5C3AFD2C1B0D2C2B1D0C1B1CEC2B4E0D7CFDFD8D2C6BEB6CAC1B6CECABF
C3BFB4BEB6ABD5CEC4DFDBD3D7D5CFC4C0BCD9D5D4DAD9D5BBB7B4B9B4B0B1B3AF767B7A
A8AAAC919BA853697E98ABBABFD1DE92AAC0849FB5B5CDDD86A3B56C8C9FC1D9E1C9D6D9
CBD5D7CBD5D7CAD3D8CDD6DBCDD6DBD0D7DCCCD5DACDD4DCCCD3DAC7CED4C2C9CFBEC7CC
BCC6C8BAC4C6B8C1C4AFB6BCB6BFC2BDC6CDBBC6CCBDC6CDC0CBD0BFC9D1BFCAD3BCC7D0
A6B4C08798A88B9CA69CA2A390827100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002AE31980AD4FAE9471B19776B39977B29B75B19C77B19B79B79E80BBA287B9A28A
B9A38DBEA893C5B09CC8B59FC6B39DCAB69FC9B49BC8B398C8B399C8B199CCB49CCAB59C
CCB89FCBB79ECBBAA0CDBDA2D2BEA6D2BCA7D4C1ABD3C0AAD7C1A7D3BDA0D8C1A5D8C4AD
B4A694BBB2A2D2CABEDDD8D1CCCCC8C4C3BDD9D2C8DCCDBDDECCB8DDC8B3DECAB4DEC9B4
D9C6AED9C6AED8C3AED1C0ACDDCDBDDDD0C1C9BCADCFC3B7CCC2B7C5B9ABBFB2A3D3CEC1
DBD8CFD3CCC5D1CBC5DBD8D3D7D8D3C1BCB7C1B8B3CAC4BFC1B9B5B6ADAAD4D1CFC5C7C5
B6B7B3CED0D0C9D4DBA0B2BBA9BCC57A93A8183B5C4F718D5778921A3E5DA6C5D9C7D7DD
C9D4D6CCD5DACCD3DBCCD5DCCDD6DACDD4DACCD5DCCCD3DCCDD6DDC7D0D5C6D0D2C4CDD2
BEC8CDC0C7CDBDC4C7B6BDC0B2BABDB3BCC1B4BEC1B8C3C5B5C0C3BFC9D1B7C5CEBCC9D3
B3C2D03A4B62334A603A515E6E76775B904400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C733
53C733A89067AD956FB09775B39978B59C7BB29C7BB19D7EB39F81BEA78BBDA68CC0A991
C3AE98C9B39CC9B39CC9B29CC8B19AC6B097C4AE93C7AF93C6B195C6B196C9B198CCB39B
CBB59DCCB99FCCBB9ECEBD9FD3BEA5D2BDA5D2BEA5D4C0A6D7C1A5D8C0A2D5BC9EDAC1A8
C2AE9AAB9D8CD2C7B9CAC2B6ACA598CBC1B2DBCCBADDCCB7DECBB4DECBB3DBC7B0DBC8B0
D8C7ADD6C3AAD4C1A9D1C2ABD3C2B0D4C2B2D0BCACCAB9A9D0C4B5DAD0C5C5BCB1CFCBBF
D9D9D1D7D5CFBDB7B0C2BDB6C7C6BEC9C3BFBEB4ADD5D0CBD8D6D3C3C1BEC9C8C5D4D5D2
B6B7B2A8A9A48F9BA130495E506D808099AB23406033536FB4CEE2728EA58FAEC1C2D7E1
C7D4DAC9D4DACBD4DBCDD6DDCFD8DFCED6DECDD6DDCBD3DCC9D2DAC2CDD2CAD4D8C8D0D5
C2CBD0C0C7CDC2CACEC2CACEBDC5CABBC2CBB6BEC4B6BFC4B6BFC6B9C3CCBDC7D1B0B9C6
B8C1D0738193667B8E4D647653657085858261914400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007BAA4BA79169
A7916AAC956FAF9773B09876B39A7AB49C7DB49E81B39E83BBA68DC0AA91C5AE95C6AF98
C4AF99C4B098C4AF96C6AF97C6AD95C5AB92C5AC92C5AE94C5B197C6B299CAB49ACCB49A
CCB59BCCB89DCEBA9FCFBBA1D0BBA2D3BDA5D1BBA3D3BDA5D4BEA2D6BEA1DABEA1DCBEA5
D9BFA8BCA995AC9C8DAFA090C8B8A5D9C8B2DCCAB4DDCBB5DBC9B3DAC8B2D8C5B0DAC6AF
D9C5ACD6C2A8D5C2AACFBDA6D0BDA7D2BFABD4C1AFC9B8A7D0C6B8DAD5CACCC6BBBBB3A5
C4BFB2C8C4B9C1BDB2BDB9AFD2D0CADCDAD6CEC9C5C4C0BBD1D1CCBFBCB8ABA5A0B9B5B2
8B8C899B9D98BABDC16372855D7485B7C8D2B0C2CF8FA8B9A0B8C8AAC2D6577992ABCADC
C1D4DBC8D2D8CCD3D9CCD5DACFD8DFCED8DECBD6DCCCD6DFCCD6DDC9D2D9C8D1D7C7CED7
C3CAD2C1C8D0C4CBD3C8D1D9C3CDD5C3C9D4BBC4CCBBC6CCBCC8CEBDC7D0C1CAD3B0B9C2
AEB6BF9FAAB592A3B198ACBB889BA59CA6AAA9A1993EB02500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A48B64A78F69A7916C
AB9370AE9574B09778B49B7CB49D7DB5A082B8A287BBA38BBFA38EC6AD97C8B29AC4AF98
C1AD95BFAE94BEAB8FC1AB90C4AB90C4AB8FC2AC92C2AD95C5B19AC9B59DCEB89ECDB59A
CEB69ACDB89ECCB9A0CDBAA2CDB9A2CFBAA2D3BEA6D3BFA6D5C0A7D6BFA5D8BFA4D7BCA1
DAC0A4D8C3A8D8C3ACD9C4AED8C3ACDCC7B1DCC7B2DFCAB4DDC9B1DAC7AFDAC7B0D9C3AC
D9C3AAD8C3A9D5C0A9D3BEA6D3BEA7D3BEABE0CFBCCDBCACC8B8A9C8BCAFC3B8ABC2B4A7
C4B9ADDDD8CFD9D5CEC4BEB8CAC4C0D5D1CDC9C2BEB4A9A1B8B0A7C2B9B6B6ADABC8C2BE
CECECBC1C2C0BDBCBDCED3DAB4C1CB95A1A9A0B1BD334F692B4E6E7F9EBC16395E648AA5
BFD7E1C9D4DACBD5D8CCD3D9CFD8DFCDD6DFCCD6DFCDD6DFCDD6DDCDD4DCCDD6DDC7CDD8
C7CED7C1CAD1C8D1D8C9D1DBC8D2DBC6CFD9C3CCD5C5CFD6C0CDD3B8C5CDBEC8D1B2BEC4
B0BAC0A0A6B1414D5E44596D5268756C7C8091979395847500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0028E11979A64CA68F6CA7916FA99171
AB9273AE9678B19B7EB29C7FBBA287C2A88CCAA98FC89C87C79782CDA48AC4A88EBEAA90
BBAA91BBAA8FBBA78AC1A98DC3AA8CC3AA8DC5AF95C5B199C7B29CC8B39DC8B399C9B196
CAB59ACCB9A1C5B6A0BEB39FBCB39FC3B8A4CBBEA8D1BFA8D2BEA6D6C0A5D7BEA5D9BFA5
D9C0A4D9C3A7D7C3A9D8C4ABDBC6AEDBC7AFDBC7AFDCC9B1DBC9B1DBC9B1D8C5ADD9C4AC
D9C2A9D9C1A9D6BDA6D4BCA6D3BAA4D0B9A4D0BAA7CDB9A6C9B5A4C9BAAADCD3C8D6CCC2
C1B5AAD4CCC0D2CDC3C4BDB2B7AFA4C2BAB0CEC6BFC1B8B0C2BCB4DAD6D2D4D2D0B9B7B3
CECFC9C4C5C0A1A09CACADAF566573364D5F96ACBA3C557214355997B5D086A2BB608096
BDD6E1C6D3D9CCD4D7CDD4DACFD6DCCED7DECBD6DCCBD4DDCED7E0CED7E0CBD4DDC4CDD6
C6CFD4C4CDD2C5CED4C6CFD8BFC9D1B7C3CCB4BEC8C5CFD6C5D0D6BEC9CFBDC8CEB6C1C7
B4BCC2B1B4BE565D6E5565794C606F6577817F8B8E9088843DB02800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A18866A18A689F8A68A18C6CA59173AA967B
B09D83B5A48AB3A28ABCA690C3A38EC69984D79482B65B4B9D3423BB644CCC987AC2A586
BBA688BCA68BBEA58CC1A78DC4AA8DC4AB8EC4AB91C4AD95C6B099C6B099C5B096C7B297
C2B29BA49B89817D707170656C6D656C6F678C8E81BCB4A2D1C1A8D6BFA7D8C0A8DAC2A9
D8BFA4D9C3A4D7C3A6D8C4A9D8C5ABDBC6ADDBC5AEDCC8B1DBC8B0DAC8B0D9C6AED9C4AC
D9C2AAD9C0A8D7BDA6D3BBA3D2BBA3D1BBA4CFB9A3D5C1ADCFBCACC8B8A8D5CABCD0C7BB
BDAFA1C1B2A2C8BDAECEC6B9C2BCB0C7C2B9DAD7D2D6D5D0B8B5B0CBC6C1CAC6C1ABA8A0
AFADA4ABABA88C8E8CB6B6B899A2AD586C7C9BAAB6BDCCD796AFBE8DA7BAA9C1D068879C
89AABBC3D5DECDD5D9CDD4DACFD6DCCED6DDCAD5DBC9D4DACBD6DDCBD5DFC9D4DDC5D0D6
C7D2D6C7D0D7C4CDD4C6CFD6C2CBD2B5BDC6A9B1B9B4BBC3C2CDD6BFCAD3C4CED8B8C1C9
B8C0C8BBC1C8909BA481939F8297A28DA0A9A1AFB6ACADB095837A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CC22F9885619A88679D8B6BA39173A59377AC9B82AE9E85
B2A38AB3A48DB6A68FBDA491C99A89A14E3DA52E1FB32418B42012A12912C98365C5A182
BDA386C2A78FC2A78EC4A98EC3A98BC4AA8CC4A98EC5AB91CDB49BC7AF95C5AE95BEAE97
8F87757272628A87789A94869A93887D7D7560645E74756BBEB5A1D3BEA6D7BFA7D7BFA8
D6BFA6DAC2A7D8C1A5D8C4A7D8C5A8DBC7ADDBC7AFDBC5AFDCC7AFDDC9B1D8C4ACD9C5AD
D8C3AAD6C0A7D9C1A7D5BDA3D5BFA7D3BEA6D0BBA4D3BFABD0BDABC8B6A2C4B59FC4B7A4
C7B8A8C1B3A3D6CFC3DBD8CFD8D6D0BFBCB5CBC9BFCBC8C0B3ACA5B0A79ECCC4BDC8C4BF
B3B1ABD4D4D3CACBCDB0B0AFC4C7C8C2CAD097A0A7A0AAB26B82932245646A8BA9345573
315473B8D3E2C9D7DBCCD3D8D1D8DECED6DFCDD7DDC9D4DACAD5DBCCD6DFC9D3DCC8D4DA
C9D4DAC3CCD5C6CFD8C6CFD8C7D0D8BFC5CFAEB5BDAEB7BEC0CCD4C0CED5C2CED6BFC8D1
C0CBD4BCC8D18494A1374C5B415966667E8685979EA4ACB3B0A9A840B42B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CC2309989649C8E6BA19274A19278A6967EAC9E85AB9D86B1A28A
B0A188B4A48BB6A28ABF9C87B6715EA83A27B12715B52110B22410B64B30D09475C4A285
C0A589C3A88CC2A78BC1A78AC3A98AC4A98BC6AB8DC6AB8DC8AD91C5AA91C1AC96968A7A
6D6D5F919283A39F8CA69F8AA9A18F9F9A8D7679725B615A92907FCEC0A5D4BFA4D5BFA4
D8C1A6DAC1A7DAC1A3D8C0A2DAC4A8DBC7AED8C7ADDCC8AFDCC8AFDBC8B0D8C6ADD6C5AB
D6C3AAD5C0A8D5BFA7D5BEA6D2BCA4CFBAA2CFB7A2CFB8A3CAB5A1CAB6A2C4B49DD2C5B3
E1D4C9C1B5AAC1B9ADCAC5BBC6C4BDB8B4AAB7B3A7D2CFC5D3CDC8B7B1ABD5D2C9D5D4CF
BCBAB6BCBAB6C2C1BEA8A7A1A0A19A939A9E3546566C7F8E849AAE17375A41607FA0BAD0
526F83A7C1CCC4D5DAC9D5D9CED5DBCED6DECCD5DDCBD4DBCBD4DACDD6DDC8D2DBCAD3DC
C9D2DBC4CDD7C4CED6C3CDD6C5CFD7C6CDD6BAC2C7ABB3B8C2CDD2C0CDD5C1CBD3C1CBD5
C2CFD8BECCD797A7B72F43583E56694A64726F858E96A3AA98989A62954D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0024DF179787649C8E6C9D8F72A1927BA49680A69A85A79B85AC9E87B1A18A
B2A189B6A48BB39B81BE91769C432DAE3720C54D33DA6B509D381DCB8164CB9F82C1A488
BFA589C0A789C1A88AC1A887C2A987C3A888C7AA89C7AA8AC5A88AC2A78BB3A48F676557
77796C9E9C89A6A08BA59E8CAAA291A8A0927F80775D675F737868CABEA6D3BCA0D6BCA2
D6BCA4DAC0A7DBC2A4DBC3A4DAC4A8D9C5ACDBC6AEDCC7AFDCC7B1D9C6AFD9C6AED7C3AA
D8C4AAD5C1A7D5C1A8D5C0A9D3BCA5D1B8A2D0B7A1CEB7A2CBB7A3D6C3B1C4B29FC5B4A3
CCBDAEC2B2A3BDAD9EB6AB9ECBC6BCD1CCC7BCBAB2D3D2CCD7D7D2C1BCB8B6AFA7C1BBB4
B2ACA4A59E95C0BCB58F8F8B9EA09CC7CCCE64717F647280C0CAD2ACB3BF8F959DBABBBC
B1B4B6909A9FC7D2D5CAD3D6CDD6D8CED6DBCBD5DAC8D4DBC8D3DBCAD3DCCAD3DCC9D2DB
C7D0D9C7CDD8C7CDD7C3CBD4C4CBD1C0C5C2C6CBC2C4CBC8C0CACEBECCD3BDCAD3C2CFD8
C2CFD8BECAD7AEBCCB7B8B9A7689976277827E939C9DACB4B6BBC0978C861BD40F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
22DD146699408C7D5B9586659B8D709B8E75A2967EA3977FA79C85A89B83A99980AE9D83
AC9A7FAF9D80B49D80BD9277A7583E982E14AB4A2BD58B69AF7554C79A7BC0A084BFA48A
BFA388BFA286BFA385BFA385C2A587C2A484C3A485C3A585C5A888C0A68B9588755C5D52
7A7F70989983A09C84A29E8A9E998B939084797C775A645E727769C6BBA3D1BCA1D6C0A5
D6BDA5D7BEA7DAC2A7DAC2A4D8C1A5D9C2A8DBC5ADDAC5ADDAC6AED9C5ADD8C4ABD6C3AA
D8C5ABD5C1A8D6C2AAD4BFAAD2BDA8D1BCA4CFBAA2CDB8A2C7B5A0CBB7A3C9B39EC5B09B
C2B09ECCBCAAC3B4A4BBAFA2D0CABFD6D5CFC4C2BCB6B1AAC1BBB3B7ADA7B1A49DC3B8B1
D2CCC6BFBAB5D1CDC8CFCBC9C2BCB9BAADAAC4AFB1B39697B38C8BC39392BB8782BA827C
B98481A67A7CBE9B9FC8AEB1CCC0C2CECDD1CFD3D8C9D1D7CAD4D9C7D0D6C7D0D7C9D2D9
CBD4DBC5CED7C7CED8C7CED7C9CDCDB1AE95ADA87DCBCAAEBFC6C0C2C9D1C2CBD5C1CDD9
B9C7D2C2CEDCBCC8D56A76864D5E6D63758076878F859299A1AAADBEBBBA43B83300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0021DC15
8473548777588B7C608D80659589709D917AA29680A39880A99E85A99C81A99A7EAB9A7C
AB9A7CAE9D7FB39F7FB99B7DC59779BA7F60B37C5AC59D7BBE9D7EBEA083BBA084BCA286
BFA386BE9F80C1A382BFA081BEA080C1A483BE9F7EC0A280C2A482BFA4868A7E6A595D52
6A7367838774898977898A7C82857B767C75646E6C57625D818272CBBFA7D0BFA3D2BEA3
D4BFA5D5BEA6D9C1A7D9C1A4DAC2A6DBC5AADBC6ADDAC7ADDAC7ABD8C3A8DAC5ADD8C4AC
D8C2ABD7C2ABD7C2ABD6C0ADD3BEA9CEBBA2D0BDA4CDB9A1C8B49DCAB59FC7B39BC7B29C
C3B29EDACEBDCCC0AFB9AC9DBCB1A2BFB7ACB7B0A5B0A69BC7C1B6D7D1CDC9C2BFC8C0BD
D7CFCDD1C5C2B8A19DC19B95B6817BAB635FA347479F33329F2423A42021A41C1CA31919
A2191C9E1C219B232A9F363DAB585EB78084C4A7AACFC5C8CFD1D3CAD2D6C5D0D5C9D2DB
CBD5DEC7D0D7C5CFD5C3CCD2C7CCCABAB89AA69D5DB3AB6ECBCBB2C6CACCC4CDD6BCC9D5
B2C1CCBBC9D4B7C3D06A76892A3C4E495F6D62748079888F7F898B9C9D9E88726700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00817154
837359887A60847B618B826A9990779F957CA2987FA39980A69C82A59A80A7997CAE9C7D
B19E7EB29F80B39F7FB59E7FB89E80BA9C7FBCA081BAA081B89E80B89F82B89F80B99D7D
BB9D7DBEA07EBEA07CBEA17EBEA17FBEA07CBE9E78C0A078C0A278BDA17B8E7C6455544B
5A635E676E686D736D6A726D67706B5D6A6654625F5B645AA7A38FCDBEA3D0BFA1D2C1A3
D2BFA3D4BFA4D7C2A7D8C2A5DCC4A9DCC5ABDAC6ADD7C5ABDCC9B0DAC5ACDBC6ADDAC7AE
D8C3ACD6C0A9D5BFA8D3BDA8D4BEA9D0BCA5CCBAA2CCB9A2CBB79FC9B59DC6B59CC4B29A
C2AE99C1B09DBFAF9BBDAC99BCAB98BDB4A4D6D0C6C7C0B9C4C0B7D4D5CED0CCC6B5A49D
C3A19CBC8480AD5B56A53733A1221DA31512A80E0FAC0C0EB20B0CB70C10B50B0DB70A10
B30A0EB30A10AE0910AD0C14A70F159D181D9A3337AA666BC8A4AAD4CBCECBD0D4CAD3DB
CAD5DCC9D4DAC5D0D5C5CED5C6CFD0CACCBCB6AE7CADA25CC7C190C9CBBCC1C9CDBAC5CF
B7C5CEB5C2CBBFCBD88C98A86573816577825C70787B8C9399A8ABA5ABAF96898300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001FDA145D913E7B6C53
7C6F5780765F847C668A846D958E779A927CA09882A19A80A49B82A89E85A99B82AC9B81
AD9C80AE9D81B09E80B29F81B4A080BAA384BAA183B89F80B59D7DB69E7CB49C77B49C77
B59C78BDA17FBA9C7ABB9C79BE9F7BBF9E79C09F76BE9D72BE9E6FBE9D70A58C6D5C5548
525855535E5D56636055615E515C59505B57545C52898776C4B7A0D0BCA2D2BFA1D2C0A3
D3BFA4D5BFA7D3BFA6D7C2A8D9C3A8D8C2A7DAC4ABD9C5ACDAC7AEDAC6AED6C4AED7C5AF
D8C4AED9C3ADD5BFA8D3BFA8D2BEA9CEBCA5CEBBA3CCB8A2CCB7A0CAB59EC7B59CC1B197
C1AE96BDAA95CAB8A6D2C1B0C2B1A1C3B7A8D6CFC5D3C8C1B2A49AC0ABA2C6A098B6726B
AB4740A42421AA1715AF0F10AF0A0CB2090AB4090AB4070BB6080AB7080AB70709BA080C
B7070AB3040AB3060AB5070AB2070AAD080DA90E149A111A972E37B2757AD1BBBFCECFD5
C8D1DAC7D1D9C4CFD5C6D1D7C4CFD2C4CDCBC2C3B0B1A87AA69A62BCBA95C0C6BCBEC7CC
B8C1C9B6C3CBB7C5CFA7B4C26978885C6E786D7F847F8C92929DA2A3A8ADACA6A21BD40F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00786951726953736C57
8C85748F8877857E6C8B8471958D7A9C9480A39984A49983A79C86A69A83A79A80AA9980
AB9A81B1A087AF9E82B2A184B3A184BCA88BBAA185B79E80B49B7BB39A77B19A73B29C75
B49D77B79C79BA9C78BA9A73BA9972BF9D76BF9D74BD9A6FBC9B69C0A06DBCA07589775C
5955464E564A555E536064597471647E76678E806CBDA990CBB599CFB99ED3BDA3D3BDA4
D3BDA5D4BCA4D3BDA5D5BFA6DAC3A9D8C4A8D8C4AADAC5ADDCC6AEDAC7AFD7C5ADD9C7AF
D6C3ABD6C1A9D6C2AAD4C1A9D0BEA6CDBDA3CDBCA2CBB9A0C9B49CC8B39CC8B49CC3AF97
C7B099C2AB97CCB9A8D4C4B4C8B7A8BCA899BCA899C1A497C69889BC7468AC433CA61E1B
AE1210B30D0BB50B0BB6090BB40608B5060BB30608B30607B40808B50808B50707B60608
B40406B60609B00406B30608B40608B00609AF060BAB070DA30B1295191DA25357C9ACB0
CDCDD3C6D0D9C5D0D9C5D0D6C3CED2C3CDD0C5CBC9C7C6B4A9A173A29D66C2C3A5C2C9C6
BEC6CCB5C0C9B7C3CDB3C1D03F5067293C505E727F82949C849096848B8E9894903DB229
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001CD81270684F6D6C5885877A
BDBDB6A7A59D868172918D7897917D9B9480A29A85A49B87A79D88A49880A89A80AA9B7F
AB9B80AFA084AF9F84B1A187B19F83B9A387B39B7DB59C7DB29978B59B76B49B73B49C74
B39C73B79E76BA9E73B99B6FBA9A6FBE9E75BB9870BD986CBD9968BF9D6CBF9E6EBA9C70
9E86637F70528D8165A08F74A99278B69D81C5A98AC8AC8ACCB293D0B99CD2BDA2D4BEA6
D3BDA4D4BFA4D3BEA3D5BFA7D8C2AADAC5ABD7C1A8DCC4ADD9C4AED9C7B2D4C4AFD4C5AF
D6C4AED4C2AAD5C3AAD2BFA6D2BEA6D0BCA4CEBAA1CCB89FCAB69EC8B49BC9B59CC7B39A
C5B098C9B29CC6AE9BC3AC99C2AB98C2A492C89C8AC68073B24B41A9231CB01410B30D0C
B90D0BB80B0BB6080AB5060BB6070CB5060BB40709B70A0BB30907B50B08B50907B50709
B6080AB4050AB00506AE0405B10707B10707AE0606AF060AAC060BA7090E951116954248
C5A6ACCDCBD2C8D0D6C4CFD5C1CCCFBFC8C4C4CBBFCBCCB3C4BF86A19949B7B278C7CAB7
C3CACCB7BFC6BAC4CDBBC6D35161733445575D7180697F8990A2A99FA9AE92918D3EB42D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF001BD711508939726F5C939788B5BFB7
C1C7C6B0B3AF86867A91907C94927D9B9782A09A87A29C88A19A84A49B81A89C82A99B80
A99B7EAC9E81AD9E83B2A186B19D7FB1997AB19779B09677B19774B49B74B19771B39A74
B39971B59870B49669BA9A69B79766BC9A6BC09A6EBE986BBD9968BE9C69BD9D6BBE9E6E
BE9D6FBE9F72BDA076BFA47CC3A67FC8A682C8A781C9AC83C9AF87CCB593D3BEA0D2BEA2
D1BDA2D3BEA5D4BEA7D5BEA6D7BFA8DAC2AAD8C1A8D7C4ACC9BCA8B1A8979F9789A29A8D
AEA89AC3BBA9CDC2ABD1C2A8CFBEA5D0BEA5CFBBA1CDB9A0CAB69DC9B69EC8B59DC7B39B
C6B19AC8B09CC7AC98C5A793CDA795CE9383BA5D51AA2924B31715BA0E0FBB0B0DBA090B
BB0A0AB8090AB9090BB50508B40608B50709B50909B60A0AB60909B70A09B80A0AB80A0B
B7090BB5060BB20509B20509AE0305AF0506B00607AD0305AC0408A9060CA3080D950F15
933E42C7A8ABCBCBCEC4CDD1C5CDCBAEAF9AAEA977B8AD62AFA339A79920A59C39C8C795
C5CBBDBEC7C9BCC5CDB7C0CA7A89926675816B7C857B8C948E9FA59CA9AEA8ABAB6A9C52
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004E863367604A6B685796998FB9C3BFBFCBCB
C2CCCDB8BCBB8A8B838D8D7B9795819D99869F9A87A19C89A09A83A39C82A49C82A89E83
A49679A99A7BAA997DAB9B7EAF9B7CB0997AAE9776A9916CAD946DB39872B59B76B09571
B3956FB7976DB9986AB69563B99863B99662BB9565BD9767BF9A68BE9C6AC1A070BF9F70
C09E6FC49F71C3A175C2A378C3A37AC6A57CC7A67EC9AB83C7AB84C8AE8CCFB698D2BCA0
D1BFA2CEBEA2D2BFA6D6BDA7D7BFA9DAC4ADD5C2AFB8AE9C8A8776908D7DA7A0939D958B
7C786F7C7C72B8B4A4CEC2ABCDBEA5CEBEA5CDBCA3CEBAA2CBB79ECAB59DC9B39DC7B29D
C7B19CCAAE9BCFA797D49E92CD7E73B03D35AF1B16BB1211BD0C0EBF0B0EBC0809BD090C
BA070ABB070CBB080BB70509B40608B30608B20707B40708B40408B6050AB7070AB7070A
B30507B10308B1070CB0040AB10509B20509AE0407AE0508AB0507AA0509A70409A4090C
931114984749D3BABACACECFC6CFCCC1C2AFB1A770AA9A3DA9991AA9980AA49511ABA33E
BDBE82C3CAAFBEC7BFB6C2C48A9AA63F55674D6877748E9891A4AA8893998C8E908A786D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00518633665F4B68655790918BBAC2C28FA0A4A9BBC1
C2CED2C4C8CB8B8D868D8E7F9696849C9A889D9A899E9C88A09B85A29C85A59C86AA9D86
A7977BAA9979AC9979B29E7FAF9B7CAD9978B19B79AE9975AE9874B19877B49B7AB29775
B49570BA9970B59467B89364B7925EB9945FBD9661BE9866C39F6EC5A172C3A073C19E71
C19F71C19F71C2A177C3A47DC6A780C7A780C8A881CCAD87CAAC87CCAF8DCDB394CEB69A
D0BDA0D0BFA2D4BFA6D6BDA7D9C0AAD6C0ACC3B3A57E796D999789B8B1A0C0B4A3C3B4A7
AFA49B74736D76776EC5BEACCFC0A9CFBFA6CFBFA5CDBBA1CDB89FCEB59FCCB39DCBB29C
CCAF9AD4A696D2837ABD5149B12923B71512BD0D0DC20B0FC0090DBE0A0DBD0B0BBA070A
BA070ABD080DBA070BB60609B40608B20608AF0507B3070BB1060AB20609B2070BB2080A
AE0909AB080AAC0A0EAB090EA9060AAE080DAE0708AD0508AB0608A80307A80307A80607
A1070B880D12A66668D1C6C7C5CFCEC3CDC7C3C5AFBAB481A89938A19009A69602A79A0C
A79F25B2AE55B7B985C3C9B4A9B3B13547513C56644F6975798F98A0AFB6A0A5A8897A72
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF001BD711665D476764548A8C85B4BABCB2BFC45A7178637D82
C1CFD3C8CCD09092908C8E829494859695869A98889D99869C9683A19A85A59B87A99B86
A6967DA89879AB9A7BAE9B7BA79472AB9975AA9775AE9C77AF9B77B19B79AF9676B09573
B49671B39369B69566B59260B99460B9935DBD9660BC9965BE9D69C3A172C5A377C5A277
C5A175C19E74C1A177C5A67EC5A880C7AA83C9AA86CCAE8AC9AB87CFB18FCBB091CDB596
CCB89AD2BEA2D3BEA6D5BFA7D8C1AAD6BFAF9C8F8475736BA4A299BCB7A8BEB5A5C2B8A9
B1AAA083847F5F6660AEAD9FCCBFABD1C0A7D0BDA4CFBBA3CEBAA3CDB7A1CFB6A1D1B29F
D8A595CF766CB7342CBD1F18C11510C30F0DC20D0BC1090BBF090BBC090BBA0909BA0A0A
B80809BA070AB70609B40607B30709B1070BAD080AAA090DA70C0DA00E0F9D13159D1C1F
9A242798282D95293092242B921B2097141B9D0E12A20C0FA5080BA70609A70405A90506
A604099B080F831C21BF9697C8CACAC1CECFC4CBCBC6C7B6ACA363A19018A99704AD9C04
AF9F08AC9F14A59A2CC0B96EB9B8886A70586C7A7568787C7180848F9DA09DA4A6A29793
1BD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004C873464645285887FA9AEAFBDC5CD909FA75C7076798C91
C6D1D7CBD2D68F95928B8F848F92849596889B97889F98869D96839F9683A29482A49582
A3947BA5977AA7987AA59476A79474B09B7BAE9978AC9771AE9970B09A72AD9671B49B78
B39671AF9167B59466B59361B7945FB7945EBB9460BF9965BE9B68C1A070C2A175C2A176
C19E74C09E74C4A379C5A57CC3A37AC5A57CC8A782CFAF8FCEB190CBAF8ECDB293D4BB9E
CEB99ED1BBA3D2BEA6D4C0A7D5C0A9D4C0AF897E7575736F93948FA9A89EAEAB9EAAA69A
9B9C94767E795B6760A2A496CDC1ADD0BEA7D0BEA7D1BFA8D2BEA9CEB6A2D5B2A1DDA094
C9635BB62621C21814C7130EC7110CC70F0CC50D0BC30B0BC00B0ABC0907BA0B09BA0A0A
B90909BC090CB60708B40A0AAF0F0DA40F0D9A16149B292B983E44924E58885665734E64
664E675C4A655A4B655F4F666E5568835B6B8D4F5A8C30398E141A9E0A10A5080BA9060B
A6040AA1040A920E128D3F42CFBDBDC5CBCFC2CBD2C2C9C5BEB990A69732A7930DA8970A
AE9E08AE9E04AA9A06B09F19A99C2977712B5F68536A7B7D889A9E8C979A848688968A84
3AAB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF001AD81262604C7D8378A1AAA9AEB8BCBCC6CEA3B0B7B1BEC4B9C4CA
C9D1D9CBD3D79EA4A28B8E859393849591839B93879D94859E95849E9582A0927FA39481
A39680A3947AA4957AA5957AA79478AF997AAE9676AB936EAD976DAD996FAA956EB39A77
B69B78B2936DB39366B2915FB3935DB5935DBA9561BD9765BF9C6BBE9D6EC09E72C3A076
C4A076C5A47BC5A67EC3A47DC4A47AC6A57BC9A881CBAC8ACBB190CBB190CBB293D1B89C
D3BAA2CFB8A0D6C0A8D2BEA5D6C1AAD8C2B08E83796F6F6E7D807F8A8F888C9189838B83
757E7B5F6F6A5C6960B0AF9FCFC2AED1BFACD1BEACD3C0ADD5BDAADAB4A3DF9C92C1504B
BA1F1DC61513C9120FC60D0AC60D0ACA110EC9100DC50C0EC20B0DBD0A0CB9090BB9090B
B80A0BB80D0DAE0D0DA31516A030329E4C5386566260496237335522295219234F1B2652
212E55303D633B496B3A4B6C32456838496C323C5B5A4D658856668D2F3A96121AA1090E
A5060AA305099E0A0D821316B88A8CC6C5C7C2CCD2C3CDCCC1C3A8A3974898891F645806
9E9312AC9E08AFA003AE9E04A696098D831E3D3F1E394A4D657B8494A2A8A5A8AA9A8F8D
3AAC2400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00655F47676C5E99A5A0ACB9BCB2BEC4BBC8CFBDCBD2C1CFD7C4D1D7
C8D1D7CCD2D5A7ADAB8A8C838E8E809995869A94869C95879D95859F95839E927FA0937E
A39781A3957DA3947BA5957BA7957AAC9478AA9172AB9570A8956BA9966BAC966EB09872
AC916DB0916CB19165B09360B1945FB3955FB89562BD9966BB9967C0A071C5A67AC7A67E
C7A57FC3A37DC3A681C6AA84C4A780C6A680C9AA85CBAE8CC9B18FCDB595CBB495D1B99D
D2B9A0CFB79ED3BDA4D4BFA7D6C0AAD7C1AFB4A4996A676362696867716F69737063706A
5E6D675B685F7F8678C4BEACD1C3AED4C3AFD6C3AFD7C1AEDFBBABDF9B8FBD4843BD1E1E
C91314CC1011CB0F0FCA0E0ECA0E0DCB0F0ECC100FC60C0DC30C0BBD0A0BBA0A0AB50C0A
AE0F0EA61D1EA53F42985B69674E6835355A16264E182C552F42665A6A89697289848595
9898A3969BA8A4AEBC94A6BA3451718CAFD16B8EA89EB3C98787998B6C7C954856921921
9F0A10A10409A0060A910D108D4346C6B8BCBFCACFC2CECFC5C9B3A59A5592832855490B
71680B988F0FACA20DAD9E06A797069D8F177B75346970636F7B807E898E98A1A3A7A6A4
47BE3800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0033AD225E60518D9790A9B6B7B3C1C8B7C5CDBAC9D1BECED6BDCED5BBCCD2
C5D3D8C9D2D5B3B8B88488818B8C809391849894889A94889F968AA095879E917FA2937E
A2937CA2927BA4967DA09177A39076AA9176AA8F72AD9573A8926CAA946BAE976FAC936D
AC9168AD9062B19160B2935FB39562B39462B69665BA9966BF9E6DC4A477C8AA82C8AA85
C5A583C6A785C3A684C4A886C7AB88C8AA88CBAD8DCBB092C9B091CAB495CAB699CEB99E
D2BCA2D0B8A0D2BCA4D5C1A9D5C2ABD6C2ADD5C1B0A6988C6C69616C6F69767B727D8276
7F827689887ABEB7A6D0C3B0D2C2AFD4C1B0D5BEAEDAB5A9E29C93C14A44C01E1CCE1517
D11114CD0F11CF1113CC0E0FCC0E10CE1012CC0C0FC80C0EC30C0CBD0E0CB2120FA81F1D
A9444898606F584A66232D56142855273C624D607776808C8C9196AEB1B4B5B9BCA9ABAD
CCCFD56471817A8D9E90A4BC0B284F2F547C7BA2BAA5C3D0C7D6DFC6C6D0B99EA79D565D
901A209E0A10A1060A99080D7F1B2093717BBFC5CFC3CCD2C3C6ADA49C4F8B7B1B6C5B13
7F731B4D4801959219A39B0DA19403A3940C978E2B8E92668A968C97A2A3869091888987
689B4E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00488234787E75A9B3B4B0BCC4B1BFC8B9C7D0BDCDD6BFD1DBAEC2C9B3C6CD
C3D4D9C6D1D6B8C1C28388848B8D82919185939185969286A0988DA09689A09586A19382
A2927FA4947DA3937BA29278A49277AB9378AB9174AF9576AC9472AB936EAD956DAB926A
AB9165AD9061B1915FB1915EB49562B49565B79767BC9C6ABD9D6DC1A175C6A67DC3A47E
C5A683C5A687C6A98AC6AA8BC7AD8CCBB090CBB094CAB196CCB498CAB498CDB89DCCB69C
D0BAA0CEB79DD2BEA4D3C2A9D5C2ABD7C2ADD9C4AED9C7B3C0B3A2B3AA9AB5AF9FB9B3A3
BFB6A5CEC2B0D3C4B3D6C6B6D7C6B6D5C1B2DDBAADE09B92BB453FC72422CF1716D01313
CF1111CF1111CF1110CD100ECB0F0ECD0F10CE0E13C90E0FBD100FAD1A19AB42449D6471
57486622305D162F5C32476A69738A8E919AB0B2B1C5C5C2ABACAACED1D2B3BBC28C959D
C6CED6556477384C61A9B9CB62758C4D678090ABBCB7CCD6C5D5DDCAD2DBD3D1D6C1A6AA
954A4F91151C9C070B9B070A820B117A444EAAABB6C2CBCEBDBD9DA49A3F958313826C0C
90801A4D46016261087471089B940FA19407A2961778721A696F3E8C9782ACB8B1A3A6A0
82756200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006F6D5EA3ACAAB2BEC3B5C1C9B6C4CBB8C6CEBBCBD5A7BBC480979FB3C8CF
BDD0D6C1CFD4C0C9CC868C898B8D848E90849392869491869D978C9A9285A197899F9383
9E917F9F927CA2967DA3967BA5967CA49278A99477AA9272AD9572AC946FAB926BAB9269
AB9065AC8E61AF8F5FB49463B29260B59462B69664B99968BE9D6EC0A074C0A279C2A680
C3A886C4A78BC5AA8EC5AA8DCAB092CBB394CBB295CAB197CCB49BCEB8A0CBB79DCCB79C
D4BFA3D0BBA0D0BCA2D4C0A7D6C1ABD7C4AED7C4AEDDC9B3D7C6B1D8C8B5D9C8B7D7C7B7
D7C6B6D8C7B6D7C8B6D7C8B8D6C2B4D9BAADE3A297BF4B44C2221DCD1614CF1311D01311
CF1211CE1111CC0F0ECC0F0DCC0F0DC90C0DC71212B81717B4383AAB6573675573253662
143261334D756D7C90A0A5A7CBC9C5B9B4B1C4C1BED1D0CFC6C2C5B8B1B3C9C3C7A29C9F
ACA4A2B3AEAFA5A8ACA1A7ACBAC7D25972886B89A1A4C0D2BAD0DCC7D4DDC9D1D8D1CED3
B89399882D34940E13990509900A0E7E3039897D87C2CCCDB6B895A5993CAA9715A58E07
A48F13645703554F0B4849086E6E0C968F0E9F93089B8F0C9C972887863B989B76A9AB9E
9D908400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF003AB62A92978EBAC7CBB2C2CAB5C4CDB3C3CCB4C5D09EB2BD7D949D81989EA0B5BC
82959CC2D0D8C5CED3868B8C8A8C859191869594879D998D9D988C9B93879B93859B9281
A09583A29584A09480A39881A59881A3937BA69377AC9576AF9577B09575AB906BAE936C
AB8E66AE8E63B09062B39464B59463B59363BA9568BD9B6DBD9C6FC0A076C5A882C2A988
C4AA8CC4AA8EC7AD92C6AC91CAB196CAB498C9B599CBB69BCBB89DCBB99ECCB89DCDB89D
D2BEA3D0BCA3D2BDA4D4BFA7D6C1ABD6C2ADD5C2ABDAC6ADD8C6AFD8C6B3D9C9B8D6C8B8
D7CAB8D5C6B4D4C5B2D4C2B2DABDB0E4AA9FC3564EBF221CCD1812D0140FCF100CCF110E
CF1210CE100FCC0F0FCD1010C80E0DC21515B72629B557647F5A743138651430612B4971
677B92AFB6BCB3B2AEB0ACA1D7D1C8D3C8C4B3A09EC9AAAABF9595B27D7DAD7473AC7270
B17B74C0938EC8ADAC8A8083B8BFCA2239590F2F58799AB4ABC3D1C7D5DDC9D3D9CDD3D8
CFC1C7A36B7185171F99090F970B0E81212969505CBFCAD0C1C5B5AEA467A9972AA8930C
A8930A928006867A135049046563116965069B910CA09305A6980BA7991C998F37908A5F
9588731CD40D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0069A454B6BDBDBBCAD4AFC2CCB7C8D3B4C6D19CB1BC76909A79939B8BA2A88CA1A6
A7B7BDC7D2DAC8D0D88F9396888B8690908798978B9F9B8F9B968A9891849D95869E9584
A29886A59A88A39885A29782A0937EA1927AA59479AA9576AB9273AE9471AD906AAE9069
B09268AE8F62B09062B29263B49364B69467B8966ABB996FBD9C73C6A681C8AA89C1A78A
C5AA90C4AA90C5AC90C8B093C7AF94CAB39BC8B298CAB499CDBA9CC9B89AC9B698CDB89B
D3BEA2D2BDA3D4BEA7D4BEA7D6C1ABD6C1ABD8C4ACDAC6AEDAC7B0D7C7B1D5C7B4D4C6B3
D5C6B2D6C5B1D3C2AED6BFADE5B5A9CE6C63BD2720CF1A15D51511D4170ED3150ED1110F
CE110FCE1210C8100EC31311BA1A19B74146AC7084554D791B3367213E6B5C6F8A92979F
A2A09BC3BDB4C4B8ADAC998EBA9B92BD8B87B16663A84344A52D319F1E219B17179B1417
9D1A1A9920219D3B3DAB686ABC9DA07A7988364762748CA1B6CBD4C8D5DCC8D1D8CAD2DA
D3D2D7BF9FA4852E38930C1499080D83171F603F4DA9B7C2BBC7C8C6C6B3ADA667A39327
A6930BA18E04A7971283760A5C55064A46019891139B90059D9104A69A0AA39618B0A351
A3936B3AAA1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A09E8DBFCBD0B4C4D1B2C3D2B1C2D1A2B4C2768E9B738F9A7C99A36A868D92A9AD
BECED4C7D2DBCAD2DA969CA0888B878F908696958999978A9F9A8E9C95889D9486A09787
9F9584A19886A39986A0947FA0937C9F9078A39379A89479AB9376AA9070A98E69AE9269
AD8F64AF9063B09063B39265B59368B8956BB49369BF9F76BD9F78C0A27DC2A585BFA387
C3A98EC1A98DC5AD90C4AE90C9B498C7B297CAB499C9B298CAB59ACAB69BCBB79DCDB9A0
D3BEA5D4BEA6D5BDA7D7BEA8D6BFA9D6C0ABD6C0ABD7C2ACDBC6B0D8C6B0D7C5AFD8C5AE
D6C4ADD8C6B0D8C2AEE2BBACDB8A83BB312DCB1C15D41911D41710D21510D31410CF110F
CA100FC61311B81917B12E2FB85C678262802C3B6E1B3C733E5B828791A0A6A19FAD9E94
B19D8FB59A8DBF948AB6716AAB4A46A22826A51515B31214B20B0FB0090EAC0708AB060A
AB0709AA080CA50B0F9813159B3E3BCA9E9FA5A3B15A7288B1CBDBC1D1DAC7D1D8C8D1DA
CBD1D9CFC2C995565F89121C97080F851017693C47919CA9B4C6CFBAC3C4BABCA7AAA25F
A3941FAC9B0BAE9F06A798099185106E6404988E10817707837B079E9508A49809A2941D
B6A55849BB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4A298BAC6CDB0BFCDB0C1D1A6B9C9798F9E6E89954A69724361686A8489A6BAC1
BFCFD6C5D0D8C8D1D89EA5A9878A86918F869593879795899A978B9992869C92869D9183
A19484A19584A29683A29480A1917C9F8F77A29179A59278A99274A99070AB906CAD8E66
AD8D61B08F64B19067B09168B6956CB5946AB3946ABB9E76BA9D77BEA07BC0A180C3A487
C6A98EC6AC91C5AB90C3AB8FC3AE93C8B398CAB39ACCB49CCDB79FCBB59DCBB69ECDB9A1
D1BCA5D3BEA6D2BCA5D2BCA4D8BFAAD8C1ACD5C0ABD7C3ABD8C4ABD6C3ABD7C5AED6C5AE
D8C7B0DAC8B2E0C3B0E8AA9DB8423BC6201CD11811D41811D4160FD51511D31310CC130F
C2140FB3211FB95860A5738859527A1B396F264B7C7086A2A4A7AAB3A99EB7A395BC9E8F
C39386BE746BAB413DA71F1EAD1112B30C0EB7090BB9080BB70609B4060AAF0405B00607
B10708AF0506B2070BAC080B9E0D109A353B956F811725465B7C97BDD4E2C5D1DAC7D0D9
C8D0D9D1CCD5AB7F88841E28950B13870B13753B48717786B4C9D3B7C5CCBDC4C3C2C0A5
A59D4DA79917AD9D04AA9B04A596089B8E06A0920B7D700C5F59008C880DA1970BA29509
A2911B50C11500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0093938BB7C4CDB0BDCDAABCCC849BA8718C984C6B742142466F8B8EA3B9BEB9CBD3
BACCD5B7C9D0C6D3D7A8B1B3868B8790918994948A95958B9592899A948A9890859A9183
9F95859C9382A39786A19482A29582A0917BA29278A79377AA9374A88F6FA88D69AB8F65
AD9063AF8F65B2926CAE906AB3966EB0956AB4986DBDA07ABC9E7CBA9C7BC1A283C6A78A
C7A98EC6AA92C8AD95C4AB93C4AE96C9B49BCDB79FCCB7A0CBB79FC9B59CCEBBA2CDBCA1
CEBDA2D0BDA4D1BDA4D4C1A7D6C3ABD4C1ABD4C1A8D7C3AAD5C1A9D9C6AEDAC9B2DACAB3
D8C8B2DBC6B3E9BEADCB6C61BF2821CF1914D21511D41711D5170FD5160FD1150EC41811
B62D29BB6D756B5B7D243769173B703D5D8590A0AEB2B0AEBAAE9FBAA893C3A290C98D80
B04F47A82220B11414B50B0DB6080ABA080BBC080BBA060BB70509B40608AE0304B00305
B00607B10406B00607B10507AE080B980A13AA57625C5067415A73B1C8D5C4D1D8C8D1DA
C8D2DBCFD1D9BEA5AC802D36900E16890A117C3A475F6372B0C6D2B5C4CDC1CDD1C5CBC6
BBB98AA5982DAC9D0DA89803A59602A09102A3920880730D5F5804615F078784119E960A
9F8F0A4CBE0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
73A0458B8C84B5C2CAB2C3D195AAB8728B985C798321404857767B4D696FA7BEC690A7B0
7B949B9EB4B9C6D5D9AFB9BB858D8A8F938C92938A96948B98948C9A968C9994889A9485
9C95839E9684A39586A39383A39381A0917BA6967CA9957AA89274AA9373A78F6AA88F68
AA8F65AD8E65AF8F68AF916AB1976FB3966FB99B76BA9D7ABB9E7DBB9E7FBFA284C4A789
C7AB8FC9AE93C6AC92C4AC93C5AF97C8B39ACBB79FCBB69FCEB7A1CDB69ECEB8A0D1BDA4
CFBEA4D0BFA6D1BFA7D2C0A8D3C0AAD6C2ACD6C2AAD8C4ACD9C6AFD9C7B0DCCAB3DBCAB6
D8C7B4DFC0B1E1998FB8362ECD201AD51A13D41610D6170FD5170ED0160DC61C14BC3C38
B474814C4C70183A6C244877617997A4A9ADBAB1A7C1B0A3C2AA9ACAA190C57C6FAC3A34
AF1917B70E0EBD0D0DB8080AB7060BBA070BBB070BB90409B70508B50609B00307B10408
B3060AB20509B10408B20509AE0508A6090D972B32A2839572869F9BB6C6C3D4DCC5D2DA
C4D2D9CAD3DAC3B6BC86414A8D111A8C0A118038454F5161B0C8D5B4C4CCC0CFD5C4CECF
BEC1A4AFA956A99B20A8970BA89805A29200A4940593850C5B53034848054B4D01908C13
9F910B92740A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AA8F688B8E87B3C3CAAABFCD7890A064808D28465154727B4B69705A767E87A0A8516A70
92AAAFBDCFD4C5D1D5B9C2C4838A898C908A94958C98978D97958999968A9C978A9B9385
9B94849D95869F93849D907EA2937DA4947CA3937AA5947AA49174A69271A48F6AA9926B
A88E65AE9065B2916AAE9069B2956EB79975BB9E7CB69C7BB79C7DBBA083BDA285C3A88A
C3AB8CC2AA8EC7AF95C5AD95C1A990C5AF96C9B39CCAB49DCBB49BD0B69DCEB69ECDB6A0
D0BCA8D0BEA8CFBDA7D3C1ABD6C3AFD6C2ADD6C3ADD4C2ACD8C7B0D7C6AED8C7B1D9C7B4
DCC3B3EBB6ABC35852C3251FD31D15D61A13D51811D2150DD0180FC41E15C24848AD778A
3B4570183E724A698E8E9EAEB1B0B0BFB0A4C5B1A1CAAEA1D09E93BF655DAB2924B11411
B70C0BBC0B0BBC0A0AB9080AB60709B60609B6050ABC070CB9070BB6070BAF0509B0060A
AE0609B3070BB10407B20507AE0406AA070A93181F7949680F1F4D2D4E73B6D0E0C2D3DB
C4D3DACAD3DCC6BDC592566089121D8B0912843A483F3F52AEC8D6B8CAD3BECCD4C3D0D6
C5CBC1BABA92C3BB6CAD9C29A7950AA79603A29301998B048F8514564E02514E07646204
979011947E1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AD926C919290A9B8C68FA5B66A8798304F5D45646E4C6B75506F76567177A4B8BFA3B5BD
9CB3BB889FA6C5D3D8C0C9CC878E8E8C8F8D90918C93928B98958D98948A9A95899A9486
9993839E96869C927F9F927CA0917AA4967CA2947AA4957BA69578A69372A6916EAA916D
AE916BAE9167B1946BAD9069B39772B69A77BCA281B79D7EBAA081BEA388C5AA90C0A789
C4AB8EC3AA90C6B095C7B095C3AB90C6AE92C6AE95C7B199C9B49BCEB69CCEB69DD0B9A3
D0BAA4D2BEA6D0BEA6D2C1A8D4C3ABD7C5AFD6C4AFD7C6B2D6C5AFD6C6AFD7C6B0D8C3B0
E2BDAEDE8D84B93028CF2017D61A13D51612D11411CF1711C41F17C14D4CA97B92344273
193F735D7998A8AEB4BBB3AAC1B1A3C4AE9DCBAD9ED6A095C05E57AD1E1BB6100FBB0B0D
BA0A0CBB080BBC090CBA090CB50608B5080AB40709B4090CAF0A0EA90D119E0E109E0E11
A40B0FAC070CAF0509B00609AF0508AB060A96141C804C681525531B3F65A3C2D4C0D2DB
C4D2DAC9D2DCCDC4CF97606C8715208C0A11863A4736374CA9C5D5B8CAD5BCCAD5C1CFD9
BECCD0C8D0C9C8C6A3B0A652A99A1BA39305A292019E90039D9208978D0F776C0C5F5700
8C840F98851400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A588608F8E8CA1B0BD8097A74C6A783655604D6B744E6C7457747986A0A791A6AEA2B6BF
778F976A8288C2D1D9C5CDD48B91938E939090928D95958F9B97929C9590978F87979285
9A97879B96849D95829E927FA0927CA3947DA1947BA2957BA59579A59272A79070AD9172
AF9472B19772AF936DAF936DB49774B79C79B59C7AB8A081B9A485B8A487BDA98CC0A98D
C5AD92C5AD95C5AD94C5AC92C7AD94C6AD94C9B198C6AF98C7B39ACAB69CCEB89FCFB9A1
CEBAA2D2BDA8D1BEA7D0BFA6D5C4AAD3C1A9D3C1ACD5C3B0D6C5B0D5C5ACD6C4ACDFC3AF
EAB5A5C0554AC4261BD51E14D51812D31614D11713C31B15BF49499E72893245761C457A
6B87A5AEB3B7BFB5A9C5B4A2C5B09EC9AB9AD1988DBD574FB4201CBF1212BD0B0BBC090C
BB080CBC080BBA070BB8090CB40A0AAE0B0CA40E0FA11E20A0363D9D4C568F505C92515C
9E3B429C0F14AD070CAE0309AE0407A9080B9820266F475F47618585ADCC8DADC1BED4DE
C4D3DAC8D1DBC7C3CC98637086141F8E0C14883A49332F47A8C2D5BACBD8BAC8D3BDCBD4
BECFD6C3D0D5BCC0AFABA267B1A43CA39415A59509A192039D91029D8E049F900E796D07
847A0A8F7E1042B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A07F5593918D97A6B1849CAA31505C4B6C74496A6D4D6B6E88A5AA546E7591A8B1899FA8
ACC4CB81969DC0D1D7C6D0D58C9596878E8B8F928D95958F99958E9D968F9990899A9286
9C95869C96859C95839B92809D927EA2967EA2957CA3957BA19176A69376A89276AC9377
AF9577B19979B29878B29876B29976B69F7AB7A17DBDA686BDA588BAA68BB7A289C5B095
C5AE93BFA98EC4AE93C5AC92C9AF94C9B094CBB39ACBB49DCDB79FCCB69DCBB39BCDB6A0
D0BBA7CEBCA7D1BFA8D2C0A7D1C0A7D2C0AAD3C0ADD4C1AFD6C4AFD6C4ABD9C4ACE1C0AD
E09789B73127CF1F15DB1D12D4170DD21712C61B16BC4140A7778D304373214D7F728EAA
B2B4B7C0B4A8C4B3A2C4B19ECAAF9CD39D90B8544EB31E1BC31413C40E10BE0A0CBB080C
BA0A0DBA080BB80B0CAE0D0DA214149D2E329E525E8359705245662F315A1D2752242347
81526696242CA9090FAE030AAF080A9D090AA040474A3653415F89416A9422476BB1CFE1
C2D4DBC7D3DBC8C4CE98637084121D8C0B14893B4B302C45A7C1D5B8CDD8B1C0C9BECCD4
C3D2D9C0CDD5BBC2C1B9B89EA7A269B0A652A094259E910D9C8D039E8C02A69608A19309
9B8D0D86720641B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
977141A299908F99A47C909E4C66714C6B7048686B7D9C9F506E728DA7AEADC6CE69868F
74909997B0B6C2D3DAC3D0D6959FA1878F8B90938D96978F98968E98948A969084999183
9791819A95859A94849990809D9582A19784A398839C9178A1957AA3947AA8957CAD987D
B0977AB29979B2997AB29A7AB79F7FB69D7DBCA584BBA685BBA688BBA88BBDA88EC4AE95
C5AD93C3AC92C5B095C4AE92CAB296CAB297C8B299C9B39BCBB59DC9B39BCAB39CCDB59F
CFB9A3CFBAA5D0BBA5CFBBA3D2BDA7D2BFA9D3C1ABD3C1AAD8C5ADD6C2A9DAC4ADE8BDAC
C7675CC52921D61C17DA1B14D51911C91B13BA3532B47B8B3847751A477B7795B2B7BBBB
C2B6A8C6B5A6C6B2A4CBAFA1D6A899BB5D54AE201CC31514C91211C30C0DC00C0FBA070A
B80909B60D0BAB1714A8393B9E5C696B536E313761152B5D193260435980606E8C7B7186
A36874981D24AA080CB0050BA9070A98181A985A6A2023453F5C816280A11737589BB8D0
BED2DDC8D4DCC8C1CD985E6D85101C8C0A13893E502A27439FBBD0B1C6D2B8CAD1B7C8CF
C0D2D8BAC9D2C1CDD4C2CBCABFC4B9BDBEA4A8A56E9B9234988B129E8F07A19203A39301
A7990F8B790621D90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
9A713CB5AA9C848E9597A9B5556D774E6A6F6F8B8F5C787C77939B9CB8C35F7C857D9AA0
809CA2607C81A3BABFC0D0D49DA8A9868E8B8D908A95958E92928A908F86969287958E80
9993839A94849D97879B94829E9784A29988A49B89A09681A69982A4957CAB987FAD987E
B19A7AAE9773AD9774AE9979B6A081BBA384BBA283BCA687B8A586B9A78ABDAB90C3AF95
C0AA8FC8AF95C7AF96C3AE91C7B295C6B195C4B096C7B39AC9B49CC9B29CCBB59ECCB69F
CDB8A1CDB9A5CDBBA5CFBDA5D0BFA6D2C0A9CFC0A9D0C0A9D7C5ADD6C3ACDBC1AEE9AFA0
B84039CC221ED31813D71B14D21F16BD2C25C276824C50771B477B6083A5B6BDC3C6BCB2
C7B5A7C8B5A5CDB1A2DAABA0C5766DAB2520BD1513C5100FC70F0FC20B0EBD090CBC0A0D
B50909B3201CB6555679576D2D3660122D5F203D6A5369888691A1C2C3CDCDC1C7B28486
A13D3EA20F11AD080AAB080B9A1013A24D594F3D5D122C556C8CAAB4CCDC9FB8CBA1BED2
BDD5DFC9D4DDC4BAC795596486121A890A12863E50292A459FBFD1B0C8D2BAC9D2BDCCD5
BFD0D8BFCDD6C2CFD7BFCBD3B8C3C9B7BFC2B7BEB2A7A9818A8838928A1D9E9213A3940A
A3950E7F6E0245B90C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4EBB24B5A7957E868BA0B2BB526B7264818669848970899091ADB54D6D76617F87A1BDC3
758F968AA3A88EA2A6C4D1D6A9B3B6848E8B8E938C97969192908B9290899692888E897D
9592839390819995869B95859C96859F9886A19885A29783A59882A89880AB977FAD957C
B29B7BB09978B19B7BB29D81B49E82BAA285B9A084BAA487B8A585BCA889BEA98DC4AF94
C5AD93C6AC92C3AA8FC2AD90C4AF94C5B095C5B096C7B199C8B29BCAB59ECAB69DCBB99F
C8B79ECCBAA2CEBCA4CBBAA1CFBEA5D1C0AAD0C1ADD2C2ADD4C3ABD1C0A8DDC0ABDB8F82
BA2E25D21F19D51812D51C15C2231BCA656A7663841A3F734E739AADB8C1C7BEB5CEBDAF
C9B6A7C8B4A3D4AEA1D18A82AA3531B91716C3100FC71012C60E0EC10A0CBE0B0EBA090C
B60A0BB82B2AAF5C653C2A4A2839615668858E96A3C6C5C7B3A6A3BC9F9EB983819E3C3B
A01214AB080CAA090B9B1213A04B54634B670D21513D649084AAC795B4C67EA1B53A617B
B4D6E5C7D3DEC1B6BF905259861116860B1083414F282E45A2C2D2B1C6D1B9C6D0C1CEDA
BCCCD6BFCDD6BECCD5BACAD2B1BFC8B3BDC7B4BEC4B1BBB7869178999F6FA2A1569C9328
988D0F85790864960E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB91FAD9B847D8487A5B6BF5B727A7B979D5B757C99B4BD4C6A725C7B8188A4AA8EA8B0
98B1BC879EA79CAFB6C4D0D6B2BBBF808B88868D868B8C888D8D8990908996948A8C8A7D
9390829893849892829893829C98859E99869F9885A49B86A89A84AA9982AF9A82B09980
B19C7FB29E7FB4A185B39F85B6A286BAA186BCA48AB8A489B8A487B7A486BFAB8FC6AF97
C4AC93C3AB91C2AC90C3AE92C4AE91C7AF95C5AE96C6B199C6B29AC7B49BC9B99DC9BA9D
CABA9FCBB9A1CFBDA5CEBCA4CEBBA4D0BDA8D1BFABD4C2ACD8C5ADD6C1AAE4BCAAC96B5F
C32721D31B14D71B14CD1E16C24342A67A92273F70385D8AA9B3C4C8BBB5CEBAACD0BBAC
CCB9A7C8B2A0D69F92A7463FB01F1DC21312C8100EC60E0EC31011BC0F11B41012B50D11
B70C0FAE0E10A82B2EA5626A9A8689A29C96AA9F94B59F95BC938CB66D699E2E2DA31211
A80907A60B0A9815179D4B565D48631325560B2A5C7595B82C4B6A1F3E5D6B8DA71E425D
A1C0D4C6D2DFBBAEB9884650891319840B118545562A324AA4C3D5B2C6D1AEBCC5BECBD6
B8C8D2B9CAD4BBCCD4B8C6CFAFBCC4B5BFC9B3BEC8B1BEC67C8F93778A8394A487A1A767
9B962F978E158D7C1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B718AB9374818784A8B8BF7C919B60788290ABB6607C854F6C7288A2A6A1BBC3718E99
5976807D959CBCCCD3C3CDD3B6BEC27B8381828783868883888A828D8A83929185939486
9493849895859894849B9587A19A8B9F9887A09986A49B88A89C87AA9A83AC9A81AF9B81
B19D82B3A086B29E84B39E83B7A086B8A088B8A28ABBA68AB8A084BAA588BDA78CC0AA92
BFA991C0AC91C1AC91C1AD92C0AB91C4AD96C4AE97C4AF98C6B39BC8B69DC8B79DC9B89E
CDBAA2CDB8A2CFBBA5D0BEA5CFBEA5D1BEA6D5C1AAD3C0A8D7C5AED6C0ABE8B8A6BA4C42
C9241DD71D14D31E14C02924CC7D8A4C4F772849799399B4D6B7B8DDADA3DBAC9FD9B3A6
CEB4A3D0AE9FC87970A42723BE1A1AC91112C50E0EBE100FB01D1CB23B3EAF494FA53239
A4181AAF1010AE1111A32925C88578B89785B79584BA8075A84A44A01E1BA9100EAA0B08
A20D0B97222493505C4C3E611027561837673C54748593A291A0AE667B8F9BB2C19FB9C9
AAC4D4C5D2E0B8A8B4833C468B1119850C157F45572C3752A9C7D9BBCBD8BAC7D0BDC9D5
BCCAD5BAC8D5BBCCD6BCCAD5B3C0C9B3BFCBB2BFCAAFBDCB5C707F293C41637364778361
8C934E9592289B8D1A40B20500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A68A62858B82A6B7BE8498A27E95A274909B48666F779197A6BDC55B757E7F99A0
9BB2B9BACED6BCCED5C3CED3BCC5C77B81808184808687808A8A808C8A7E8D8C7F959486
9291839693849B97889E97899E97899F9A88A29C89A59D8AA79C8BA99B89AC9A88B29D88
B09C84B29E85B39E84B49E82BCA38AB69F87B9A289BCA58AB7A286B9A489BDA98DBEAA90
C1AC94C1AC93BFAB90C0AC90C3AB93C7AD98C9AF9AC6B199C5B29AC7B59DC8B69ECAB8A1
CBB9A2CDBBA4CEBBA4D0BCA4D3BFA7D3BFA7D6C1ABD6C3ADD7C5B0D8C0ACECB2A3B43B2F
CF231AD41B11CB2118C54D50916C863945728980A2C0818CB84F4FB83C3AB6433ED38379
D9AC9FDCACA0B5524EB1201FC41615CA1110C31412B62B2AB2636D654C6946436270576C
AC646AA12426AF1011A9100FAF3830D37C71B65C54A22B27A51413AD0E0DAA0D0B99110E
97343885566B3030570D295A23456D92ACC4C1CFDBA5B0B6BEC9D1AEC2D07893A6A1C2D7
7093A6C1D4E3AE9CA780323A8C0E15820C157847572A3B54A6C4D6B7C8D4BCC9D4BECAD5
BECCD7C0CEDBBFCFD9BACBD5B3C1CAAFBEC9AABBC5ADBECC94A6B662737D88948F8F998C
8F977696944A9B8D2448BB0D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4885B93978D9BADB2879BA593ACB845656E6E8C9396B2BA58737E536F7692ACB2
A2BCC3A2BDC77C939BBCCBD0C3C9CD8084867E817D80817A86867E8D8C828C897D969186
9994889995889895869E988AA0998B9F9A89A39D8CA59F8EABA092AE9F93B4A193B39F8C
B5A088B6A089B59E86BAA28ABCA38DB9A18AB8A288B9A489B8A288BBA58CBDA88DC3AE93
C4B098C4B098BFAA92C2AC94C4AC95C7AD98C9B09BC7B29CC5B39CC7B59EC8B49EC9B49F
CEB9A4CCB9A2CEBCA5D1BFA9D1BFA9D0BEA9D2C0ACD5C3AFD4C3AFD7BDAAE7A899B13127
CF1F18D21C14BD231FD17882684E69A285A4B2596BB6282EC51E1FCA1C1AC11E1AAD322E
E19F99E0A8A4A9403EB51D1CC61412C81312BB1D1CC06069514062183165324D74707484
B18F90BF6664A21614B00C0AAE0E0DB11C1CAB1313AE0E10AC0B0CA3100F9A2426924852
59415D17235010325D557B9AACC6D6ADBCC3C4D0D896A7B193A6B1667E940B2B4C4B708E
41667DBBCFE1A8909D7F2833900E15800E1574495B31465EAFCEDDB5C8D5BBCBD8C0CCD9
C0CCD8C1CEDBC0CED9C0CED9BDC9D5B1C1CBACBEC8AABFCCA1BACA8FA8BB8DA3AFA1B3B6
B1BEB5A6A881978D404CC11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A584539E9D9193A0A7ACBFCB66808C5A798190AEB663828B4F6E7669848B7E989F
66838A59767D99AFB6B9C8CEC0C9CC838A8C797C7980817B83837E8B8B838F8D83928E82
9B97889D988C9A96899F9B8CA39C8CA69E8FB0A699B0A597B1A497B3A399B5A496B9A796
B6A590B7A38EB7A18AB69F87B9A38CBAA48CB49F87B8A58BB6A38AB8A58CBCA88FBBA88F
C3B199C3B098C1AB93C5AD95C2AB94C3AC96C6AD98C7B09BC6B19CC7B19EC9B49FCAB6A0
CCB6A0CDB9A1CDBAA3D1BEAAD1BEABD2C0ADD0BEAAD5C3AFD5C2AEDABEABE4A495B43329
CD1D15D31F18C03435BA73829D738AB55E70B9252DCD191DD01718CE1614C71A15AD2E2C
AF757BB890989F4244B2211FBF1313C30F11B3191ABB6270443354535B7CA19CA8BBA09D
C9978ED37871A71F1AB30B0CB7090BB80A0DB40D0CA90F0DA02221A04C537A526A31315A
0F245717335E4C6880A7BCC5C0CED19EA7AB9FAAB0495D6A5F748296A9B8486479628096
A3BECDBFCAD6A285907C1F29930E1582121B6A41533E536CB2D0E0BACBD7BBCCD8BECCD9
BFCCD8BFCAD6BECAD6BECAD7C0CFDCB2C2CFAEC2CCACC0CD738DA22F4F6A305067587480
8094979AA29499966F96845400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A47E47A7A1918C999E97ADB75C77818BA7B172909B496A7167888D47666A688488
6C858A97AFB68EA4ACB0C0C6BEC9CD899395757C797D7F7983827D8A89838A8A80929084
9C988C9F9A8F9F9B90A59F93ACA697ACA596B2A79AB3A89BB1A698B5A89AB5A597B2A291
AE9E8CB19F8BB39F8AB29E87B8A48BB7A388B8A489BCA88EBAA68CB7A489BBA88DBBA78F
C0AB95C1AC94BFA891C2AA93C3AD95C2AE96C7B099C9B19BC5AF98C7B29BC9B49ECBB6A2
D0BBA8D0BBA6D1BDA8D0BFA8CEBEA8D1C1ADD0BFADD6C5B1D5C2ADD9BFA9E6A999B0362A
CD2118D11F18CA4443B66874CF8391B12F36CC1D1FD31616D21615CD1613BC1C17B65158
69516B69637EA7656FA42629B91819C41113BC1215BB353EB55C69BB757DC07572B75A53
AD3C34AC201CB10F0EB80B0DB9090CB40C0BAC1F199B3936774751453E5E18295B132B5E
3A4D7079808F97989593938DB8BBB9B5B9B8A9B0B0C0CDD2ABBCC3ABBBC4B5CDDB89A6BA
9FBCCDBBC6D49D7C867C1A21910C118618205F3A4E4A5F79B5D0E1B7CAD2BBC9D2BBCBD8
BDCDD8C0CDD7C0CDD9C0CFDABFCFDCB7C9D7AEC2CDAFC1CE758B9C45617645637668818E
85969B828B888A8C80887E6C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00789B31A59B8684929694A8B2778F9A8DA9B649677360828847696C5D7D7E7D989B
A0B7BD8FA8B14760698CA0A5BECACE97A0A3757C787B7C7782827A84847C89887F8E8C81
969287A09992A39C94AAA199AAA298ADA59BAFA599B3A79BB2A69AB4A89AB5A698B1A190
B2A08EB39F8DB39E8AB59F89B8A28AB9A48BB7A38BBAA58DB7A289B9A48ABDA88FBCA690
BCA690BDA891C0A892C2A993C2AB94C5AF97C4AE96C6B099C6B09AC8B39CC7B59DC9B8A1
CCBBA4CDBBA4CDBBA5D0BEA9CEBDAAD0BFACCFBEAAD5C4AED3C1A9D7C2AAE7B6A4B1453A
C9251FD41F1BC72C2AF68084E1686BC22423D31C18D31815CE1714C11C16B43C3C9D6F84
2A3C655B708DC6A5AAAB5753A72824BA1817BE1212BC1215B4171BB21C1EAD1918B01816
B01411B41410B40F0DB80D0EB60A0BAB100DB54E4E5430421C2043192852414D737A748B
9B858BAB8B85B59288AF928BCEBFBCD6CFCFB7B8B8C2CBCFA5B6C17B919F8FAABD193A5A
3053737C8B9E96707B7C141B8F0A10841B2658384F526984B2D0E0B8CBD5BCCAD3BACBD8
BCCED9BDCED6BCCDD5BCCDD7BFD2DCB5C8D6ADC0CEB1C3D1A1B6C46B869799B5C294ACB6
A4B6BBAEB9BCA5ACAB8F8B862A9F1900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004CB81CA99A807E898AA1B5BE92A9B457737E5D7B845271765D7C8169888C425F66
839EA72D4951718B928A9CA0BAC5C9A2A9AD7176767B7B7780807A81817888877D8E8B80
938F859D9991A29D97A6A098ACA59DABA299AEA498B1A598AEA495ACA392AEA491B0A491
B1A28EB09F8BB39E8BB29D87B4A088B9A58CB7A38AB7A389BAA58ABDA58CBFA78FC2AC94
BDA992BFAA94C1A993C3AA93C2AB94C2AC95C5B099C5B098C5AF97C8B39BC9B69EC9B8A0
C8B8A0CABAA0CABAA1CDBDA4CCBCA4D0BFA9D4C1ABD2BFA7D0C0A7D2C2ACE1C0ADD18476
B93028CF231CCF211CCE2928D02A2BCF1D1AD21D17CC1F18BF261FBC4E4FAB7D92364673
1F4777889FB3C3B7B1D6AEA1C27C70AA3930AE1F1AB71A17BA1918B51614B11816A71715
A5201FA92D2BC03D3AAB1211B40D0DA51110A95057381C3643355386637AB07582A45056
9C3839982D2D9A2D2D9C363B9E4E54B37E82B6999AA19A9B65727C344C5B8CA2B44A637E
33516EABB4C68D5E667F1117900A10841E2951374D5F7892B6D2E1BACCD5BDCBD5B6C7D4
BBCED8B9CCD4B7C9D4BACCD8BDCFDBB7C9D7B3C6D2B8C9D6AFC3D32D495F47677B5D7889
7A919B90A1A89EABAEA9ACAC57443600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004AB417B29D81808788AABCC57E95A057737B5B788059767D71909637575C88A2A9
778E97445E6444595CA6B3B6BAC4C5A8B1B37175767A7C797F807A83837B89877D8D8B7F
928F839D998EA19D94A5A199ADA8A2A8A198ACA397B2A798AEA292A99F8EAEA492B3A795
B3A590B1A28EAE9D8AB09C85B5A188BAA48CB7A189B8A38BBCA78FBDA58EC3A993C4AC96
BEA892C0AA95C2AA94C3AC94C2AA93C2AB97C5AF9AC5AD97C8AF99CAB39CCAB49DC8B59D
C9B79FC9B8A0CCBCA2CEBEA4CEBEA4D0C0A7D4C1A9D3C0A7D1C0A7D2C3AED9C4B2E8BCAC
D27C6FBA382CC62820CA251FC6221DC2231CBC2E25BD4E4ABC7880887693304B7A1D4A7C
6888A6B2BABDC2B9ABC9B6A6CEB1A1D2A090C17B6FB25954AD4F4FAB4F54A5565CA2646E
9165767B5668BD78809D1D1FAF0C0FA30C0BD06367AC5C68A44653A02731A3161DA91015
A80A0EA8090EA8090FA60A129E0C14911319923437A67272C6BABDACB8C19CADB7B8CDDB
A1B6CA989AA9875057871317910A0E85212C4A344969829AB7D1DFBECEDABECCD6B4C6D3
B4CAD6B7CBD7B7CAD7B7CAD8BACCDAB9C9D6BBCAD7B9C8D6B0C2D45068824F6C854F6B80
6B839182949D7F8C92878C8E5C4E4300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB517B69E81888C8EA7B9C4627985657F88556F777F9CA23C5A5E79969B7F989E
768D94667D82A7B7BBB4BFC2BAC3C7B0B8BD767B7E7C7D7B80807B82807A87837B8D8980
938D859D968EA19C93A4A097ADA9A0A9A59BA6A294ABA494AEA394ACA092B1A497B3A494
B8A797B2A08FB09D89B49F88B5A189BBA68EB7A189BCA78EBAA78EBAA590BEA790C0A892
BDA68FC1A892C0A791C2AA93C3AD95C0AB94C2AE96C3AF97C4AF99C6B29DCAB7A1CDB9A4
CBB6A1CBB9A2CCBAA2CDBDA4CCBDA5CFBFA8D4C3ABD7C3ABD4C2ADD4C3B2D6C4B5DBC5B4
E6C2AFE4A696D2796CC66159C2635EC37779B58893817891415981224C7C3C668F8098B0
B8BCC1C2BAB3C4B8ABC6B9A9C7B8AAC7B2A4C4ACA1917B7C685A6A524F6A3D45632D3A5D
25375D383E5CA470809B1C22B10C0FB00B0DB61E21AA181EAC1118AE090FB2080FB2060C
B0060BAF050BAF030BAC020AA8040AA6070C9D0B0F8E1C22AA7176C8BEC87C8E9C8DA6B7
40586E5A5B6D7D404989101692090F85212F432F476D89A1B8D2DEBDCFD8BACBD5BACDD8
B9CDD8B7C9D7B8CAD6B9CDD8BCCEDABDCCD8BBCCD8B8CAD8B6C9DAA1B7CEA0BBCF9FB7C7
A0B5C0A8BBC3A3B1B8979DA25E524B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0028DB0BB094748D8E8FA4B5C07A919D58737D7D98A14B656D6A8588769093738E91
97B0B48BA3A99DB1B6B4C2C8BBC6CCB5BDC47A7F847879787E7E7986847D89867E8F8C82
948F849C978E9F9B929F9B94A6A39BA6A499A9A599ACA598AEA498AFA395B3A696B5A594
B7A694B4A290B5A28DB39F87B5A189BAA68FB6A18AB9A48CBDA991B9A58DBDA58EC0A891
C0A790C2AB93BDA78FBFA991BFA991C1AC94C2AE97C6B29DC4B29CC4B39BC8B89FC8B89E
CBB9A2CAB7A1CDBBA5CFBDA8D1BFABCFBEA8D3C2ABD6C4AED6C4B1D4C1B1D7C5B6D5C6B6
D7C8B7DCC5B6E1C3B8B59B9A80768258607C354F753257804C71957D96AEAEB8BFC0BCB8
C5BCB2C8BCB0C4B8AAC4B8AAC2B6A6C3B5A5BFB2A2BDB2A8AEA9A692939B838994828793
8E8D99A78F97A55758A11414B50B0CB40809B3070AB3070CB20709B2060AB30409B4040A
B4060AB4070AAE0406B10409AC0407AD0509AB070AA10A0F891A20A47381292F435B7486
607486635C6F803B468B0E1691070F892534402D45708EA4B8D2DEBBCED6BBCCD6B1C3CF
B8CBD6BCCFDCBCCED9BCCED8BCCED8BACCD8B6C9D4B7CAD9B1C8DD5B79944F728B6D8A9E
738A97869AA292A4AAA4AFB377706C27981000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A4835D93918FA1AFBB738A9769858F628087668187728B8E68838669858A
5E7C805C7A7D8CA6AAB1C4C9B6C5CCBAC4CB7E8589787B7A7C7D7885857E87877E8F8E82
959185A19B90A49C93A59E95A6A19AA6A298A8A499A9A396AEA698ACA191B3A796B5A595
B7A595B5A191B6A08EB39C86B79F89B9A38CB5A088B9A38CBBA58EBAA48DBDA68FC0A791
BCA58FBEA992C0AB92BFA991C2AC94C2AD96C3AF98C6B29DC7B39EC7B59EC9B8A1C8B7A0
C9B8A2CCBAA6CEBDAACEBDABD0BEABD1BFAAD3C1ACD2C0ACD5C3B0D7C5B4D9C8B7D5C6B8
D5C8BBD7C9BCD8C8BED0C4BEBAB4B6A7A9B4A7AEBBB1B8C2C0C0C3C5C0BDC9BFB6CABFB2
C9BCAFC8BAADC7BAACC5B8AAC6B8AAC7B9ACC0B5A6C1B6A6BEB6A6B8ADA1B4AB9EB4A99C
BCA499C188829D2D2AAD100FB50909B50709B40708B30608B4070BB30409B20308B6050B
B30507B40709B20809AF0506B00406AE0609AC0406A8050997090E933C44A5919E90A1B0
B8C8D1A797A27E313A8F0D1493080E8624353F2E497896AEB5CFDCBBCED6BCCDD7BCCCD9
B8CAD6BACCD8BDCFDBBDCFDBBDCFDCBBCDDBB8CAD6B8CBD8B5CBDF3A587543657F607F91
5B727E788B937B8A917E878D6F696924961000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A17C4F9A958E9AA7B28399A774919C62808985A1A75D797E617E85537076
56757767848686A2A6627C81A8BCC1BBC8CB858D8E7B7D7C7E7F7A81817A88877E8F8D82
9693879D988FA39C94A39C94A6A098A8A49BA7A499A8A498ACA59AACA497B3A797B4A395
B7A496B9A392B59E88B89F89B89F89BCA58FB6A089BBA28CBFA690B8A18AB8A28ABCA68F
BDA790BEAA92C2AD95BFAA92BFAC94BFAD96C3B099C5B09DC5B09CC7B39EC8B6A0C9B7A2
CDBBA7CDBBA9CCBBA9CFBDAAD0BEA9CFBDA7D0BEA9D3C2AED4C3B0D8C7B6D8C7B8D5C6B9
D3C5B8D5C7B9D4C7BAD4C8BBD0C5B9CDC4B9CCC3BACCC2B8CEC2B6CDBFB3CABEB1C8BCAF
C6B9ABC5B9ABC3BAACBDB5A7BEB7A8C1B8ACC0B7ABBCB4A5BAB1A1BAAE9EB6AB9ABBA496
C39187A74642A61614B30B0CB70A0CB5080AB2080AB10708B40709B6080AB50709B7060C
B40608B30608AF0507B00409B10507AD0305AE0509AB030AA2050C84121D946B7E8E9CB5
8796A7A8959D7E2B30940E1395080F8725353F2F487A9AB1B6CEDDBDCDD9BACCD6BBCDD9
BACCD6BDCDDABCCCD9BACCDAB6C9D7BACBD9BBCBDAB9CAD8B8CADB758CA18BA7BAA1BDC9
9CB2BC9EB0B8A5B4BA9EA8AE7B777A38671D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009C7440A69E91909CA5A6BAC766818D96B2BC6F8B945D7A814E6B71537477
62828488A5A85B777B55707597ABAFBCC9CE8F959A797C7B7E7E7A83827C8989828F8F86
9A978EA09B93A29D95A29C96A9A39FAAA5A0A6A297A9A298AFA89DACA499B2A699B2A393
B7A696B4A390B29F8BB39F8AB3A08BB4A28BB7A38CB9A38DBBA58EBBA58DBCA78EBCA68F
BCA690BFA994C2AC96BFAB93BEAB94BEAB95C2AE98C6B09BC7B19CC8B29DCBB6A1CCB7A3
CDB8A7CEB9ABCEBBABD1BFACCEBCA8CFBDA8D2C1ACD4C3B0D3C1AFD5C4B2D5C5B5D6C9B9
D5C8B8D5C8B8D3C8B8CFC7B5CFC6B8D0C5B9CFC3B7CDC2B6C9BFB3CAC2B4C9C0B2C8BEB2
C8BEB2C4BBADC2BBACB6B3A3BAB7A8BCB6AABCB4AAB8B0A4B5AE9EB6AB9DBBA699C4948D
AC4F4EA41A1CB00C0DB70A0CB50909B20809B20809B20809B40709B50709B30709B20409
B30A0CAD0A0CA9090BAB090DAF0A0EAE060BAC0408AA0207A5040A8C0A148B4E681B224B
2C43629B8A947A2228940A1195070E8723314333497899ADB5CFDEBCCDD9B4C6D0BBCDD7
BCCED8BDCDDABACBD6BDCFDBBBCDD9BACAD7B4C6D4B4C7D6B9CCDB7F94A9668196728F9F
7F99A383969D95A6A99DAAAD95999D48392E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A27740BAAEA188939C99AFBC87A2AD8BA6B177919B4D67704E6B70557578
4566686C888C94AFB3778F939EB0B4BECACD98A0A4767A7C7B7D7981827D8686818E8F87
9C9C949F9D969F9C959F9B96A39F9AA9A39DACA59CA9A297AEA79BAEA599AFA595B2A595
B6A696B3A090B2A08CB4A38FB5A38FB4A08BB8A38CB7A28AB6A28AB8A58DBCA990BAA68D
BAA68EBBA790C0AA96BDA994BDAB96BEAC96C1AD98C3AE99C7B29DC8B4A0CBB8A5CDBAA9
CCB9A8CDBBABD0BFAFD0BFACCDBDA6CFC0A9D1C1ACD4C3AFD4C3AFD3C3B1D4C5B6D5C8BB
D4C8BAD3C7B8D0C7B6CFC8B7D1C8BBD0C4BBCCC2B8C9C2B4C8C2B1C9C2B2C5BDAFC6BCB1
C5BBB2C2B9AFC2BBAFBFBAAEBDB8ACBAB4A8B8B2A4B5ADA0B7AD9FBBA89EC49690A94D4D
A61B1EB20E12B60A0EB6090BB70A0BB20809B20809B5080AB5090DB30A0DA90A0CA00B0E
9A1416962224983033992B3395151D9F090FA90509A90307A303078E060E8E4C62242D53
56738F9C8B977A2029960A1196050C861E2C4E384E7391A8B6D0E0BDCED9AABCC4B2C4CE
BCD0D9B4C6D4B8CBD9B8CAD5BACBD5BBCDD7BCCED9B5C8D8B2C4DA8298B32845604D6980
637C8A74868F7F8F957A878B7C83854A3F3700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004EBB24BDB09F7E8C92A6BBC99BB2C087A1AD617C864F6A73516C732A464B
223C405A747A627F856D888CB3C4C8BCC6CBA2A8AD76797B7B7C797E7D798887828E8E88
96988E999B909B9C919F9D94A49E97ABA49DADA59CAFA69DACA399ACA298AFA498B0A397
B4A396B4A092B39E8DB4A18CB6A18DB8A18EB7A28DB7A38CB4A28BB6A48EBAA68FBBA68E
BDA890BAA790BCA894BCA994BDAD96BEAD99BEAC98C1AF9AC6B59DC7B7A0C8B7A4CBB9A9
CAB7A8CCBBAACEBFACD0C1AECDBDA9CDBEAACFC1AED3C4B2D2C2B0D2C5B4D2C7B8D1C8B8
D2C9B8D1C8B8D1C8B9D0C8B8CDC5B8CCC2B9CCC3B9CAC3B6C7C3B1C5C0AFC6BEB2C8BEB7
C5BBB5C4BBB4C3BBB2C1B9AFBCB5ABB9B2A7B6B1A3BCB2A4BAA79CC79A95A74D4EA31B1D
B41112B70A0DB9090FB7090DB30709B10808B00807B10B0BA90C0C9E121498292E9A4B56
855769634E684F47655548617E4F5E932C35A10C12A80409A203078E0A12905265293457
9FBCD69E8B987A1E2595081197040C841724593B526F8BA2B4CFDFBFCFDAB9C7D2B7C9D4
BBCEDAB3C5D3B1C3D1B6C6D3B8CAD6B9CBD7BACEDAB9CADAB6C7DC92A7C26A829D8DA4BA
94A9B6A3B5BEA3B4BAA0ADB18A8F9352474227980E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004FB81EB8A690818B8FA8BCCA8EA6B47B97A45976814D69722441461C3639
7C9395849CA0658286547276758C8FBCC9CDABB2B5767A7A797B777C7D7883837E93928C
95968E989A9097988EA1A095A5A197AAA39BAAA29AAFA59DB0A69CAEA197AEA197B0A39A
B8A89CB2A092B5A190B6A18DB7A28DB5A08DB5A08CB7A28BB8A48BB9A48DBAA48DBCA68F
BEA991BCA68EBDA993BEAC95BCAC93BEAD96C2AF9AC1B09CC3B8A3C9C0AFCBC2B3C8BBAE
CCBCAECDBDABCDBEA9CDBEA8CCBDA6CEC1AACEC1ADD0C3B1D0C3B2CFC4B3CFC6B5D2C9B8
D0C6B6D3C8BBD1C7BBCFC6B8CEC4B9CCC3B9CDC4BBC9C1B8C7C1B4C7C1B4C7C0B6C7BFB8
C8BEB8C3B8B2C0B7B0BDB4ADBBB4ABB9B3A8B9B1A5BAACA2C59F99AE595BA21C1EB31013
B80C0EBA0B0EB80A0CB6080AB4090AAD0809A60E0C9D19189D393E915364634A682F335B
172D5B122C5E1B3661495F7C686677A3636C941219A3040B9C0306880D1184516415254A
304D6C867383781C2295080F99050D820E1B643F55647D95B2CFDEBACDD7BDCCD8BCCAD7
B6C7D4B9CCD9B8CBD9B7C9D8B5C7D5B7C9D7A5B7C5B6C8D7B9CADC889CB46D879E758FA1
7D95A181969F8CA0A698A8AE9BA4AA5A5352279A1300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0051B81AB29A7E878C8FADBECD8FA7B56F8D995878832F4D5518323672888D
6B828790A9B06580857B9699657B7EB8C8CBB1BABE777D7E7B7C797E7E7982827D878780
9192899B9D939B9C91A1A197A3A197A7A49AACA49CB1A7A0B3A89FB3A79DB1A59BB0A399
B6A79BB3A394B1A08FB5A38EB2A089B1A089B3A088B7A28BB8A28AB9A38BBAA48DBAA590
BBA78FBCA990BEAA92BEAB93BEAC94BFAE97BFAF9CB3A999C0BEB2D5D8D1DADCD9D0CFC9
C7BEB1CCBBAACFBEAACDBEA8CBBFA6CBC0AACDC0AECEC1B1CDC1B1CCC2B1CDC5B3CEC5B4
D1C6B6D0C4B6CFC4B6CDC3B6CCC3B7CCC4BAC6BEB6C9C0B9C8BFB6C8BFB6C9C0B8C7BEB7
C5BCB5BEB7B0BCB7AEBFB9AFBBB5ABB8AFA6BBAFA5C6A8A0B26866A12024B31115B90D0F
BB0C0EB8090EB70A0EB40A0DAC0E0F9A15169B3C3F956272554A6B20305F0F295A1B3963
445F7E7184988E9AA49FA6A9A99D9E9F6061901115A4060B9B06098E272A66465A172C4E
849CB38C7682761A2394081098040C7F08116F40525B6C83B2CFDDB9CED6BBCDD4BCCAD3
B9CAD2B9CCD6BACCD8B9CBD9B9CBD9B5C5D5A0B2C0B0C3D1B5C8D960799241637E34576C
557481748A9573868E76858D747F88575457269B1600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0050B615AD9170898C8DA9BBC87E98A56F8D994C6A75102C325C757A677F86
3E5A615A777D76909693ABB0768B90BAC7CDB9C1C77A8283797D7A7E7E7983827D86887E
9092859B9C90A1A096A4A099A9A49EABA59FAFA7A1B0A59FB0A49EB1A59CACA298AEA197
B1A397B0A394B5A494B3A090B09E8AB2A089B29E88B7A38BB49F87BAA38ABCA48DBBA68E
B8A68DBDAB92BBA791BFAB96BEAC97BDAD9BA69F8F9E9E91B3B8B2ACB4B5CED4D7D5D8D5
C4BDB2C7B9A8CCBCA9CDBDA8CABEA7CBBFAACCC0AECDC1B0CCC0B0CCC2B1CBC2B1CFC5B5
D0C4B7CFC5B7CEC6B6CCC5B5C9C1B5CAC1B9C8BEB8C8BEB7C8BFB8C7BEB7C9BFB8C6BDB6
C0B9B1BDB8AFBDB9AEB8B6AABCB9ACBDB4A9C2ADA4C28581A02B2CB31419B90D10B90B0D
B80A0CB80B0FB00C0EA512139E2F339B5E6C5A4E6D1F336110306325456F586E86848F98
9499999EA19AA19F96A69C95B89390983F419C1013A6060A95080A9A494F3A2F4C183556
98ACBC9D828B78192194071098040D8707117B3C4A535A6EB2D0DEBCD0DBBACBD4BACAD4
BBCBD5B9CBD6B9CDD7B9CBD7B8CAD6B4C6D4B3C5D3B0C4CFB2C6D588A0B54D6E836E8EA1
8CAAB596AFB98FA2AAA8B5BF75818E41444C4E3A2B00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AF8F68888785A1B1BE8198A669869423414B4A656C60777F3F575E
112A2F657F8544606758747A9DB2B9B5C4CBBBC6CB7E8789787F7D7F827C8A8D868A8D84
8E91869C9D929D9B94A4A09AA9A39DAAA39CAEA6A0AEA49FB0A59EB1A69DADA399ABA196
AEA196B0A193B2A191B29F8FB4A18DB5A08AB4A088B4A087B8A38ABAA48CBAA48DBAA68E
BBA78EBEAA91BEAA91BEAB94BDAC99B3A697938F82B8BAB0D8DDD8BFC6C7BFC4C4D0D0C9
C1B9ABC9BBAACBBCA9CDBEAACBBCA7CCBFA9CBC0ABCCC1AECEC3B2CDC1B0CEC4B2CEC4B4
D0C4B7CDC3B7CCC4B7CDC6B8C9C3B6CBC2B8C8BFB7CEC6BFCAC3BAC7C0B6C6BEB6C3BBB4
BEB9AFC0B9B1B9B2AABAB5ABBAB5AABBADA5C9A09AA44343AE191BBC1113BA0C0EBA0C0E
B60B0FAF10119E1B1DA14B547C5B752D35621030641F416D59738D8B98A0969B969D9D93
9C9A8CA4A295A8A296B19A93AE6E6C911A1EA4090DA2080A8C161984556810204822466B
7E94A299808473181D91080F99020B8F070F7D2D394D485DABC8DAB7CDDABACCD6B7C9D5
B9CAD6BACBD9BACBDAB8C8D7BAC8D5B9C7D6B5C6D3B3C5D3B2C5D3A1B5C7728C9E7D99A7
87A2AC8EA6AD90A3AA98A7B17E8F9D222E3950443800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A9865C9E9B9795A4B08EA6B546636F3E5C645C777F3B545C0F282D
627B7E8BA4A87D979C63818638565CA5BAC0BBC8CD8590937C84838386828C8E898E9089
8F92889FA0969B9A94A4A09BA6A19AABA39BAEA59FACA19CADA29BB0A69DAEA399AD9F95
AEA094B0A091B19F8FB4A191B4A08DB6A18BB4A088B4A088B7A38AB9A58CB8A48CBAA68E
BCAA92BBAA91BBAA90BCAB93BCAB97A89B8B9A9486B5B3A7C9C8C1B5B7B2B0B0A8C7BFB2
C5B9A6C9BBA5CABCA8CDBEACCDBDACCCBDAACBBFACCDC1B0CEC1B2CFC2B3CCC1B1CDC4B5
CDC3B8CDC3B8CEC4B9CEC6BBCAC4B8C9C3B7C9C3B7CCC5BBC8C2B9C5C0B5C6BFB4C5BDB3
C0BCB2C0BBB5BCB7B1C0B9B2C1B8B1C1A8A3BD7977A42222B81313BD0E10BB0C11B70F11
AA120FA52E2AAC666B5946601C2B5B1634664661858192A098A19E9C9E94A09F939E9C8F
A09F8EA5A193A89C91B085809233349F1014A4070B980C0F9845513F31540C2C5C325C82
4964778B7981731D21910A0F9B040D95050E7D1A275A4558A3BECEB7CFDBBCCDD9B8C8D5
B8C8D5BBC8D7BDCADBBCC9D8BCCAD7B8C8D7B5C7D3B2C6D1B3C8D6879FB0456479577688
66838E7B94997B8F947C8A926374811C2B36504A4000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AD8554AEA79E8F9EA77E94A23853607B97A23F5C650D272E597277
718B916C8890819AA0728A90768D929BAEB3BBC9CF8D9B9F7D86878C8F8C8F908D939490
999B939D9E969F9F97A3A29AA3A098A7A39AA9A39CABA29CADA49CAFA69CB0A298B1A096
B3A295B09E8FB09E8EB19E8FB39F8DB49F8BB19D86B19D85B4A087B9A68EB4A28BB7A590
BAA893BAA890BBA88FBCA991C0AE99B8A8978B8273A4A095A6A398979588BCB7A7CBBEAC
CCBBA7CBBBA7CABBA9CDBDADCDBCADCAB9A8CCBCABCDC0AFCEC1B1CBBEB1CDC1B4CDC3B7
CCC2B8CCC2B8CDC2B8CEC3BACCC3B8CBC2B8CBC2B9C9C1B8CAC3B9C5C0B5C6BFB4C8BFB6
C2BDB3BEBBB2B9B7B0BCB8B1C1B9B1D0ACA9A44749B11B1DBE1112BC0C10B60D0FA91310
B13F36CF837E98677070536C6256737D7E9391959B9A9D97A3A598A0A193A09E919D9E90
A4A293ABA297B5958E9E4F4E941416A5090D9E0A0D952A33754F6B112050254871A9CAE0
ABC0CB9C8E946F1F23920B1199030995020B810B167041538F9EAFB6CDDABBCCD9BCCAD7
B7C7D4B8C8D5B9C9D8B7C7D6BACAD9B8C8D7B3C5D3B2C5D3B5CAD87C94A86E8BA2557288
6D8A9788A2AAA0B4BA9EAEB58697A11E2D3858554D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AB7E4BB5AAA08B97A0899CAB758D9C67838F143138466064698389
4C69712B4950607E8394AFB4698186A7B9BDBBC8CE9AA5AA7F888A8B8F8F919290939390
91928D9C9C979E9E96A4A49AA6A59DA6A19BAAA49FADA49EAEA39CADA299AFA097B09F94
B29F92B09F90B09E8EB19E8EB39F8DB59F8CB39D87B4A088B2A089B4A58EB6A68FB7A790
B8A892B8A793BAA993BFAC97C5B19DC1AE9BB7A798A19688A9A291BCB5A2C8BBAACAB9A8
CEBEABCDBEADCDBDAECCBCADCDBEAEC9BCAACBBDABCCC0AFCAC0ADCBC0B0CAC1B3CAC2B6
CCC4BACCC3B9CEC3BBCDC3BCCEC3BBCBC1B8CAC0B8CABFBAC6BEB7C5BEB5C5BDB3C6BDB4
C0BAB1BCB9AFBBBAAFBEBAB1C2B4AECD9F9F9B2D32B5151ABF1013B90E11AD1412B53B34
DD8079BA60609B353C96283494353EA97070AD988FA29E92A19F92A5A298A2A095A3A193
A9A093B3968EA86562931B1DA30C0EA30A0A991F219156692626530E2A5C5F7E9995ADB6
A7B9BF9E959B73292F8C0B1298030898020A8B060F7529377B7585BBCEDCBACBD9BACAD7
B6C6D5B5C7D5B8CAD8B6C8D6B4C6D2B7C7D4B6C8D4B3C6D4B2C6D68AA0B2849FB0748E9D
768E98778E96869BA090A3A88C9EA61F303A5A5B56269A0F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0053BE28A69A8B828F96AEC1D0879FAF3E5B67314C54667F854A636A
0F29304A65685D797C456266819A9F94A8ADBCC8CDA8B1B67F878A8C91918D8F8D949590
9796929B98959F9D98A4A29DA5A19AA69F97A9A199ACA39CAEA49DACA299AEA299B1A496
B0A091B3A193B09D8FB19F8DB3A08CB29D89B39E88B39F87B19F88B4A48DB7A78EBBA991
BCA894BBA794BDAC98BFAE9AC1B09DC4B29CC6B3A1C2B1A1C7B7A5C7B9A6CABBA8C9B7A5
CCBBA8CBBCA9CCBEAECABEAECABEAFC7BAABCABEADCAC1ADCBC3B0C9C0AFCAC0B3CAC2B6
CBC3B8C9C1B8CAC0B9CDC3BDCCC1BACABFB6CAC0B8CAC2BAC4BDB5C7C0B8C1BAB2C3BCB4
C5BFB8BEBBB0BCB9AEC0B9B2C2B4AEC592929C272BB81519BC1011B41310AE2B24DF7871
AA3D3B9E191BA81114AC0D11A31216902A2AB18B849D9C939EA097A7A59CA39E95A79D93
B1938DA96162982023A30C10A7080AA11010BE595C6E425928284E43507095A2AD959EA3
8B989F716A747C3841890B129702079A020A92030B780D1B7C5261B4BCC9BBCCD6BBCCD6
B7C8D5B6C8D4B8CAD8B7CAD8B7CAD5B6C7D2B8CAD6B2C5D3B2C7D68CA4B64561755D7787
69828A687C835E7274697B7D687A811A2C395B605F279D1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0052BD23AA9B86808D92A7BDCA617D8B2C4B54627C82486166122B2F
455E627C949992ABAF9AB3B76D878D556D72BECCD3B7C0C781878D87898C8B8A8B939190
9998959B9A969C9B97A3A09AA8A39DA9A39CABA39BAEA59CACA199AFA29AAD9F98AFA196
A99B8EB3A496AF9F8FB09F8CB2A18DB5A38FB4A18BB29E86B6A28AB7A48CB8A68FBAA691
BAA491BFAA97BAA895C2B2A0C1B19FC5B4A1C4B2A0C3B1A0C4B3A2CAB9A9C8B8A6CBB9A7
CBB9A7CEBDABCDBDADCEC0B3CABDB1C7BBACC5BCABC5BEAACAC3B0C8C1B0CBC4B5C7C1B3
CCC6B8C7C1B4C8C2B7CBC4BAC9C1B8CAC4BBC9C4BAC9C4BDC6C1BBC4BFB9C2BEB7C0BCB5
BEBAB2BEBAB0BEB8AFBEB7AFC2B3ADC9989899282CB81519BB0F10AD140FD96058BC4A48
A21718AE0D11B10A0DB20B0DA90E119021257F5D67606D7693A09CA1A099AC9F97B6928E
A559589B2023A70C10A9050AA70408A20A0FA82A2F9D3A47924A5A9B6A75BFA4A8B8B1B3
B9BFC4958E9681444C890E159802089A02079502098C0914782834B7A4B0C2CBD5BFCDD8
BACBD5B7C6D3BBCBD8B8CAD8B3C7D4B6C8D4B7C9D5B3C5D3B0C5D3A4BCCE2C496066879B
6F8E99738C9579909580959A82969E1C303D5B64653A6C1E00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB81A9F8B6E7A8183ABBFCA3E59637591995C757C183035364F53
6E8A9058757C809CA38DA6AC6E868C687D82C1CED5C2CAD4858991898A8D8D8B8C908F8D
9697939797929B9994A09B96A6A19DA9A29FA9A19CADA39BACA299AFA49BAEA097B1A399
A99B8EAC9F90AF9E8FAF9D8BB19F8BB19F89B5A189B59E86B79F88B6A289BAA68DBDA791
BFA996BEA897BDA999BBA99BBCAB9CC1B0A0C6B4A4C3B0A1C8B5A6C6B3A3CAB7A5C9B8A4
CBBAA8CCBDAACDC1B0CBBFB0C9BCB0C7BCADC5BEACC2BBAAC8C0AFC7BFB0C6BFB0C5C1B2
C9C3B5C9C0B5C9C0B7C8C0B7C4BFB5CAC3BAC9C3BAC3BFB6C6C1B8C3BFB6C1BDB5C1BFB7
BFBCB3C1BDB4BDB8B0BCB5ADC1B3ADD0A8A79A373AB1171BBA1011AC110EE6605CAC2424
AE1013B40B0FB40E10AC0E109D131796435150436422395A8D9BA3A79B96B08681A14A48
9B1A1AA90D10AA0709AB0509A90307A90509A4060BA0080D9A0B129010188C2C30AF797C
A69798A89FA2834E52830F1797030B97010798020996050F800D17935A64CEC4CFC0CAD5
B9C8D5B8C7D4B2C3CDBACCD8B3C7D2B3C7D2B5C9D4B6C8D6B2C7D5ACC4D5637F937695AB
7493A7688397597687637F8F6A859515313E52626252453000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB616A78F6C888D8BA8B8C270878F7F99A3304B552D454C728991
526F792B4D5564848A607B807E9599A3B6BAC2CFD5C7D0D88A8F958B8D908D8C8D8C8A8A
92918E9696929A9995A29C99A49B9BA99F9FAAA19EAFA79FADA59CACA398AB9F96AB9F93
A99C8FAC9D8FAE9C8DB09D8CB09E8AB09E89B4A088BBA28CB99F89B8A38CB6A48DBAA793
BAA895BAA997BDAA99BDAA9ABEAD9CBDAC9AC4B2A1C5B2A3C5B2A2CCB9A8C9B8A6CBBCA9
C9B9A9C9BCABCBC0B0C8BFAFCCC0B2CABFB0C5BCADC4BAADC6BCAFC6BEAFC7C0B2C3C0B3
C7C3B8C9C1B7CAC1B8CAC2B8C7BFB6C8C0B7C9C3BAC6C2B9C4C1B8C5C1B8C0BEB4BEBDB3
BEBCB3BDBEB3BDBBB1BEB7AFC0B5B0CAB0ADAD6464A42025B51115B71112B9181AB41116
B50D11B30C0FAA0E109817189A434E785B7C19285A2C4069A297A3AF74759631329E1315
A90C0DAC0709AC0809A80307A90307AA030AA70105A60105A60308A6060B9C0B0D871A1E
AB7877A29090A174757D121996050E9A02099C030B98020C8C040D76151FAD818BCAC7D0
BBC9D5B6C8D2B3C5CFBBCDD9B7C9D5B7C9D5B7CBD7B5C9D8B2C9DE7C98B33957791D385E
0A224A051B4302173D0416380C223F09243854686A554D3C00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0050B814AA926A9B9F9BA0AFB99CB0BC516C7726424B68838B58737F
264751406267617F8249636695ADB098AEB3C3D3DAC9D2DB8D939A898D908E8E8F929291
9897959797949A99959D9996A49E9BA7A19EA7A19EABA6A1ABA49CAA9F96A99C94AA9D92
AC9D90AA9A8BAF9E8EB19F8DB19F8BB09F8AB3A18BB6A089B69E88BAA28BB9A48FB8A694
B7A996B9AB98BBAB9ABEAB9BBDAA99BFAC9AC0AE9DC6B3A4C8B5A6C8B6A5C9B8A6C8B7A6
C7B7A8C9BAADC9BBAEC9BDAFC9BFB0CCC2B4C6BCB0C5BCB1C2BAAFC4BCB2C9C2B7C3BFB4
C7C5B8C6C3B7C7C1B6C8C1B9C8C0B6C9C2B7C8C2B9C6C1B8C4BFB6C5C1B8BEBCB3C1C1B8
C1C1BAC1C1BAC2C0B9BDB8B2BEB8B1BEB2ADC6A09EA24C4FA12022B01819B11415B21418
AB1217A0151996262C9E5B696B5A7A1F2F5E2F3B6A8268859E505B9A1F23A81214AB070A
AF0808AF0808AA0607A80307A70208A70206A80309A60107A90408AE060DA9060C920A0F
93454A998087A6858B7A1D2691070F98020999020998020B92020B870813751E2AB5939E
C2C6CFB5C6CFB0C4CFB1C5D2B7C9D7B2C6D5AFC8D8A7C1DC6380A81A396B011B5000144D
001146000F3F010E3B000D37000F34021833475C6554544813CC0600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98D619B9B9696A5AF869DAB24414C728E97607C83325058
3E60652B4D4F7F9B9C98AEB3627A81516970B4C6CDC8D2DA91999F8A90938E9191909290
9798959B9C989D9C999D9C97A09F99A5A09BA39C99ABA5A0A8A199A9A097A89E94A99E93
A8998EAB9B8EAD9C8DB09F8CB2A08CAE9D89AF9D89B09D86B6A189B9A38CB6A18BB6A490
B9A994BBAA96BBA998BBA897BEAC98C0AE9AC1AF9EC1AF9FC5B4A4C7B6A5C8B7A6C6B7A6
C6B8A9C7B9ADCABCB0CABEAFC9BFAFCBC3B3C9C2B2C4BCAFC4BDB2C5BDB4C3BCB3C3BEB4
C3BFB4C5C1B6C5C0B5C7C0B6C4BEB2C6BFB5C7BFB6C7BFB9C5BEB7C5C1B8BFBEB5BFBFB9
BEBEB9BFBEBAC0BDB9BEB9B5BEB9B3BAB3ADBEAFAAC7A4A2B174709F48469A353897343A
98454D995E6E7C64813A406D1C2F6151537B936580932E3B9F1319AE0E11AE0909AB0507
AD0709AD0709A90506A80305A60105A70105A70206A60207A70208A90108A8040997060C
8D323E50384A998B997830398B0A1396010998030995010992010A8F020B830814762330
B0949EBEC7CEB5C7D0B8CAD7B7CADBB1C8DE7E9CBD24447502205B011A5900155100104A
010E44010E40010D3A000B36010E340112321B2F40535A5222980D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98552A5A19991A0AA7F94A14C66717390993A595F3B5D60
3154556C8C916D8B93718B919BB0B78B9EA6B0BFC7C8D3D89CA6A8878E918C92928F9392
9596949898949A9B959C9D989E9E989F9B97A39D99A8A19BAAA198A79F94A59C91A69A8E
A99A8CAB9A8CB09D8FB19D8CAE9A89AC9A87AE9C87AF9C85B49F87B39F86B4A08AB5A38E
BBA893BDA893C0AB98BBA793BDAB96BDAA98C0AC9CC1AF9FC1B0A0C6B6A5C5B6A3C3B7A4
C4B9A8C3B8AAC5B9ACC8BDAFC7BEB0CAC1B3C9C1B4C2BBB0C1BAB0C3BCB2C3BCB2C2BBB1
C4BDB2C7BFB5C4BCB4C6BDB5C7BEB5C8C1B9C7C1BAC4BFB8C2BFB7C3C1B7C1C1B9BFBFB9
BFC0BAC0C0BBBDBBB6C0BDB6BEBBB2BCB8AFBCB5AEBBAFAABEAEA8B09C9C7C6B756A6377
4F56732A3D66183367293A6D75648A924D62951E28AB1418AF0B0DB1070AAE070BAB0508
AB060AAC070BA90408A90409A9040AA80309A80409A80307A80307A80306A5030698070C
9237443D2A426E718485525C830F1797040B96010593000793000A94010C8D020D7F0A16
6E2F36B5B1B5B4C8D1B0C7D9A6BFDC58759F0B2A60011C5C00175A01145901135501114E
010F46010D41010D3E010C38010C33000E3005172E515A59219A1000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A87E42B2A99A89959C98ABB67F96A44F6B7736565C305155
6E8B9044606727434A5F7B828EA6AC7B8F96B6C7CEC5D1D8A7B1B6868E918E9395919595
9395939798949899949A9C979E9F9AA19E9BA49E9BA69D97A89E95A99F96A3988DA5978B
B1A093AA978AAD998BAF9A89B19C8AAD9B88AB9A83B09D85B29E85B5A189B6A48DB6A58F
B8A791B8A68FB9A792BAA693BEAC98BCAB97BCAA98BEAC9BBFAE9DC2B2A2C3B4A4BEB2A0
C0B8A5C3BBA8C2B9A8C2BBABC6BFAFC6BFB0C7BFB3C4BCB2C1BAAFC0BBAFC0BCB0C1BDB0
C6C0B2C8C0B6C7BFB7C7BFB7C6C0B6C0BEB3C4C2B8C4C2B8C1C1B7C0C0B7C1C0BABEBEB7
BDBEB6BFBFB7BBBAB3BFBCB5BCBBB1C0B9B2BAB3AEBCB5B1B4B2ABAFAFAC999EA3707F8E
5A6E855669877476949470889035469E1620AB0D12B20B10B2080CB1070EAF070DAC060A
AB060CAB060CA60409A60309A5050AA5060BA30508A50308A50207A80307A1030690060B
9648572E2647515E789B7B8677141C93070E98040995010894020993000A90020C850510
6E1F2A918898ABC4DA9AB7D73B5A8A04215D01195B01165B01185D02175B01135400104B
010E43000D40010D3D000C38000B31000D2E02132C38434A46362100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BD24BCAD9C7E878EB5C8D56983913858633B5C61607D82
486166172E327B9497718A8E687F86B3C5CCB2C1C8C1CED5B2BDC3848D908990928D9291
9496959796949A99959C99969E9D9A9F9C99A49F9AA69F98A59D93A39B90A59A8FA5988D
A7978DA7958AA89587A89683AD9B87AE9D89AA9A84AD9C84AF9C84B5A289B5A48BB4A48B
B7A78EB7A78EBAA992B9A894BCAA96BBAA96BDAA96BEAB96BCAC97BEAF9CC0B3A1BCB2A0
BCB3A0C3B8A4C3B7A5C1B8A8C1BBABC3BDADC5BEB0C9C1B6C2BBAFC1BBAEC0BCAFC0BCB0
C2BCB1C6BDB4C7BEB8C7BFBAC6C1B9C1BFB6C0C1B6C1C1B7C0C0B6C1C2B7BEBFB6BFC0B8
BEBFB7BEBFB7BBBCB4BABAB2BBB8B1BCB7B2B8B4B0BBB7B3B2B3ABAFB0AAADAFABAAADAD
A8A7ABB29EA7A86B76932531A8141CB30D13B5090FB50811B4060FB1060EB1090EAC070B
AA060CA7080D9D0A0E93090E900F15901317950C119D050BA30307A50306A00508890C15
8D546D161F484D6382A696A176252B900D1597030A96000A94010B93010B90010A86050E
7A2A3D322A4E6688B62B5085011E5E01185C00145802165B02185C01185A011551001248
01124004153C0C1F4307173C01103201122F04152F22313D4C423400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0056BF26B7A38F6F787CB1C5D04B677338596258777C516D72
152E32758D917B939AAAC1CBAFC4D0BBCFDBA9BAC4C4D0DABBC4CE838A91868E908C9392
9598979696959896949D99979F9D999C9B97A29F99A19B93A29A91A2988EA1958BA4948B
A49288A69289AA968AAB9687AD9A88AB9A85AE9D87B29E88B39F87B09F88AF9F89B3A28C
B6A48EB4A38CB6A68EB7A791B9A894BBA994BDAB95B9A78FBBAA93BEAE99BAAF9AB9B09C
BBB19DC0B4A0C2B6A3C0B7A6C0BAA9C2BDADC7C1B4C8C0B5C5BEB3BEBAAEC0BCB0C1BEB2
C3BEB3C6C0B6C4BFB6C4BFBAC4C0BCC4C3BCC3C2BAC2BFB7C2BFB6C2C1B7BEBFB4BFC1B7
BDC0B7BEC0B9BCBDB7B8B9B3B7B6B1B9B6B1B9B6B1B6B5B0B6B6ADADAEA6AFAEA8B0A8A3
BB9F9FA760659A212AAA1117B40D11B5090DB3080EB4070DB4070DB2070DAF0A0EA60A0D
9B0D12951B239539428E4D5D805466845663A04A52920B11A5060AA6040A98080C92333F
492E500D25547193B49DA3B2824D5483101795040C97010C94010B92010A8D000781050C
7B2F45201644041D5C011C6200176100145A001357011458011758011C570E2B5C1D375D
3951695066764F6275162842061C332139490920300F202E4D463E24960900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0053BA1DAA9175717474ACBFC8516C7745626B627F84173034
688185738D945C778299B2BF7A94A1748E988A9DA6C3D1DAC0C9D3888E958B9092919594
9195949496959795919C99949E9C979D9D98A19F9A9F9A92A39B90A49990A3968DA4948C
A5938BA99790A9978CAC988AAE9B8AAD9A88B09C89B49F8BB49F8BB29E89AF9C86B19F89
B3A18BB3A28BB5A58DB6A690B9A793B9A893B8A791B8A790B8A792BBAC97B8AA95AC9E8A
B5A592BDAF9CBAAD9BBEB5A5B9B3A3BEBAA9C3BEB1C7C0B5C5BEB5BDB9AEBCBAAEBFBDB0
BFBBAFC1BEB2C3C0B6C2BEB7C4C1BCC3C2BCC0C0B8C0BEB6C1BEB6BFBFB8C0C1BABDBFB8
BCC1BABBBDB8BCBEB8B7B8B2B8B9B1B9B6AFB8B8B0B8B8B0B4B4ACB1B0A6B5AEA7C0A3A1
A961649C2028AE1018B40B12B50B0EB4090FB3080EB3070DB0090BAA0A0F9D121595272E
934B5B7C57744B456C232D5D1926544D405F934A57920C14A10209A1040997171B9D5869
201C412A4A775D8CAE6D8CA389727E77181F91070E97020A9301099202098D02087E040E
7631491C144502165700155E01165B01175800165306235B1634653457815A80A07A9AAF
8BA4B093A8B35C7285061932213B4C4B64684053590E1D2A48494821960D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DC0C9F815D8C8B87A7B7BF5D75825E7A841A363B5D787B
6C878C5470794B65719EB5C1405A63859BA2C2D2D9C4D1D9C7D1D78B9298868B8D888C8D
848888878B898E8E899A98919B99929D9B979F9C979E98919E968CA1968D9F9188A4958E
A4938BA4948AA6968AA99789AA9788AE9988B09B88B19E88AF9D88AF9D88B09E87AD9C83
B2A089AF9D88B2A08CB3A18CB1A08CB3A28EB5A48EB4A58CB0A18AB1A28CB1A38EB3A38F
AE9D89AEA08BB0A492ABA190B2AB99BBB5A5BEB9ACBEB7ACC3BBB2BEB7AEBEBBAFBEBDB1
C0BDB1C0BEB2C0C0B5C4C2BAC3C2BBC2C3BEC5C5BFC2C2BBC0BFBABFC0BAC1C4BDBDC0B8
BCBFB7BEC0BABCBFB8BABDB6BABBB6BAB7B2B9B8B2B5B4AFB5B6AFB5B1ABC2ABA7AC6869
A02529AF1116B40C11B6090FB5080CB6090DB4080CAF0B109C0D0F982A309757656C5675
2E3567122964102C65253A6957517581495F8B19259E0710A4030AA1040AA41A21A34857
6C48616A6F8895AFC37792A49C97A1773139880C1395030B9401089100098A010B79071A
4E163B12114B02145901135B001559011A57092759375B8186A8C497B8D32A4C6781A1B7
7491A07794A62D4762011530506A75586F6D54646422303844484A21981100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009E7D53A5A39DA1B0BA839BA836535C48656A718D92
4D6A7146646C95B0B993AAB494ABB4A3B6BFC6D5DDC7D2DBCCD5DC8D969B7C8487787D7E
75797780827E8C8B8795928C98948D9E9A95A39C97A19790A1978E9F958CA0948A9D8F86
A19289A6958DA7968BA99889AB9988AA9885AB9A83AC9B84AB9983AC9B84AE9E85AE9D85
B19E86B5A08AB4A18BB19F87B2A088B19F88AD9D84AF9F85AF9E84AB9A81AB9A83AB9B84
AD9E87AB9E87ABA08AB1A794AFA794B0A897B4AD9EB6AEA2C2BAAFC4BFB3BDBBAFBDBBAF
C1BEB3BFBEB4BFC0B9BDBEB9C0C2BDC3C4C0C5C6C2C1C2BDBEBFBABDBFBBBEC2BBBCBFB6
BDBFB7C0BFBABDBFBBBABCB8BABCB9B5B4B2B9B8B4B4B5B0B5B5B0BEB0ACB8818299282D
AF1318B70B10B80B0EB40A0CB3070CB2090EA80D119E1F259E4F5C7156732C39690C2866
11326D36507C6F769393768B883B4B8C13209F0814A4040CA9060BA40108A1040B940914
87202BA06B75A19BA3B0BFC9A3A9B38B646E7A141D92070F95020A90000A860511600B29
240A3E0A155901145C01145A021D592748777A9BB9A1BCD1AFC7D98299AD5770846E8797
5D788833516B021E3D0F2B424660644F635C52635F3B494D3E4346219A1500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A38055A7A49E9CAAB5879FAC314D587591994B6870
3B595F88A6AB4A68716E8A95748E9995A9B3C4D3DEC0CBD5C8D0DA939BA27C8487767A7C
737674848480928F8C9C9593A098959F9793A49D969F978F9E968E9F978D9F94889E9085
A29086A49287A9978BA89687A99887A89884A99983A89780AE9B83AC9B82AA9A80AE9D84
AE9C84AF9D85B09E86AF9C83B19D84AB9A80A9987EAA987CAB977CA9977DAA9981AB9C85
AA9B83AC9E86AB9D88ACA18DAAA28DAAA290ACA596B5AFA1BBB4A7C1B9AFBDB9AFBFBBB3
C3BEB8BEBCB7A2A5A39197969FA4A4BCC0C0BFC1C0BEC1BFB0B5B29FA6A4A8AEAAB8BDB8
BCBFBABCBDBABABCBABCBDBEBBBCBDB8B8B6B4B6B1B3B4B1B5AFACC39F9F993D42A8181E
B50D13B80A10B80B0FB60A0EAD0A0EA010159B323B92607842436D122E680F346C3A5782
747C989B85949A5E698E272F970F17A0050DA40309A7030AA40308A70409A8040AA4040B
970911821E25B08C9599A6BA5A75908B8497732C35880C1392020A8D020B73081B3B0A35
0F1051041661001A5E0928614A6C949DBCD7ABC5D7ABBFCEB2C5D48297A799B2C094ACBD
4F6782071F450D284745637359727255666052605A414F5139424525A11D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A68254A6A09996A3AD748896758F9C5F7C853A575E
7D9AA04C6A72607E8675909A758D97A5B6BFC6D3DDC3CDD8C9D0DBA0A4AE7C8186727679
7B7E7E8B8C8A9392919793919D96939C958E9E998F9A958B9B968D9C948C9D9188A29087
A18E83A49186A69487A39283A69584A89784A99884A99884AA9782AB9981AA9B81AB9C82
AA9980A8957CAC987EAD997EAF9C81AF9F84AC9C81A9987DAB997FAB9980AA9B81AC9E85
A7997FAA9980AB9C85AB9F8AA9A18DA8A18EABA491AEA898B2AD9EB3ACA1BDB7ADBEBAB1
C1BEB8A9AAA5949994B2B8B5888E8DA9AEAEC2C4C5A2A5A4959A97A2A7A3A1A8A3848E8B
A3ADA9B6BDB9BABDBABEBFBDB7B7B5B7B8B4B5B6B1B2B1AEBEABABAF6C709B1D24B21016
B60B11B80B11B5090FB00C119B14199A445173577525366C0E327126477A6B79979C8B9C
9D687190333995161CA10B11A4040BA40309A40309A30208A40309A50409A50207A50309
9F030B830A138F5A676E768F1A39586C788C8B626B7A141A8B040B8605105A09261F0C45
07175F021B6213366F678EB4A6C6DCB0C7D8B1C5D4B3C5D4ABC0D23D5B7391B5D34C6B8F
14305B011B452A486173939D6B828360726E5260584856553440412CAB2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A47C4BA19A8F929EA5AABCC9849CA93C59646C8991
55727B5C7A84738F99788F97ABBDC6C4D0DAC6D1DCC5CFDAC7CFD9AAB2BA696E75727579
8385878F908F92918F96918F9D95939B96919A959093918A96938A9C948C9F91899F8F86
A18F85A18E82A18F81A69385A99686A89683A99782A79581AB9985A8967FA9977FAB9A7F
AB987CA79277B09B80B19C81AD9B80A9987CA9997AA89877AD9C80AA9A80A99A80A99B81
A8997FAB9A80AC9E85ADA28BABA08DA89D8BACA28EABA28EAEA897A9A394B5AFA3B9B6AB
C2BFB7AAAAA5888C87AEB5AF8A908DAFB2B0BABBBB8C8D8BBDBEB9BEC0BABCC0BAADB3B0
808988B5BDB9B9BAB5B9B8B3B9B8B3B6B5B1B6B5B0B9AEABC7A0A298373CAE181DB60B11
B60C10B50D10B00D129C181CA055625F5174162F6810336E475D878E849D98697491383F
8F151D9B0B11A3070EA8050DA7040AA50109A4030BA30208A10109A20108A60308A70409
A00309860610874C603C425B86A1B596A9B69B8D95762E34840D137E0919470E33121353
03165F011C5B4B749FA3C8E1AFC9D7B7CBD9B2C6D5B4C5D6AEC2D54F6D8A466C94163565
001C480D2C4C41606E5C757A53686852645E5362574D5B562D3A3A544E4500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0051BE29A397898A959EA8BDCB607B865B788257747E
58767F6C8992728D96A7BBC5BED0D8C1D0DBC3CFDAC5CFD9B2BDC6909BA26F767C737579
88878992909092908D938E8D9B959499949297928F8B8884908D859A92889C8F869F8E86
9E8B829F8C7FA29183A49383A89685A99782A5937DA4937DA4927CA7947DA7937BA8947A
AB987BA89579AF9C82AF9B82AA987EA49278AA967BA69273AA9779AA997EA7977EAA9C85
A4977FA69A81A9A089ACA28FAEA191AA9D8DA89B8AADA392ADA696AAA395A8A496AEAB9F
BEBDB3BCBBB39C9F97939B92A4ABA3BFC2BDB5B5B3959795C0C1BDBEBFBABCBEB8B4BAB7
7F8985B2BAB5B7BAB5B9B8B4B9B6B3B3B3AFB4B4AEBFB0AEB98285971F26B51117B90C12
B50C11AF0F13A01D23A35A6A554E72163168203C71717296997184943E4A91181FA00E15
A4070DA7040CA7020AA50309A30207A40309A6050BA40309A30208A60209A8050AA70309
A00509850A1488556D1A28499CC0DA6488A177889C8E6B757317226E0D26310B3A0B1454
0915531F2F633D6085A4C9DFAFC8D6B4C8D6B6C9D8B6C8DAAAC0D77694B60A2B59001E50
1C41645476877A949A6E82855D6E6F53635E5262584858562C3A3E56544E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004EB91FA59781869096A9BECA5E798473919A486771
65838B5C777F98AEB6BDCED8BDCED9C1D0DCC5D2DEABB6C3838D967B858980868A838687
88898890918D8E8E8A95919096918F98918F98928D827C758F88809D938A9D8F879D8B85
9E8A82A08D80A18E80A59384A69483A7937FA7927DA4907AA49078A8917AA9927BA8937B
A8957DAB9881A7947BAB987EA69579A39176A69277A79275A89375A9957AAA9A81AB9D85
A79C85A69B87AA9F8DACA190ACA291AEA393A69C8BA99F90A9A3999B9A8F9091869A9D94
B9BBB2BCBCB2BEBFB4C1C2B8BFC1B8C5C4BDBEBEB98B8C8BB3B6B6BCBFBDBEC2BD9FA5A2
909693BABEB9BABBB7B8B7B5B5B4B2B2B2AFB3B3AFC0B0AEAC6D70A11E22B71114B90C10
B40E11A1161AAA596659486C2334674A5182896A8B954758951C28A30F18AC0A11AE0A0C
AB0508AD080DAA060CAA070CA6050AA60409A60409A6030AA7040BA8040BA7030AA8060D
9E090C881E276E4F6E1026507CA1C11D4164385473AEA9B97137465E1637270C42121253
2813454D34583A4763A8C8DCAEC9D6B2C9D7B5CCDCADC6DE6E8DB0143464011F511F466D
5D859C88A7B28FA6AB7D8F926D7D7D5D6D6950625B394D4C253A3B61685F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004FB91CA29074899497B0C5D187A0AD54737E5E7D86
65818893A9AFACBDC6B4C3D0B9C9D7B9C9D898A6B677818C7780867B8386808689868A8D
88888A8F8F8F908F8D918F8C9992909A908E9E94918F867F8C847A938A819D908A9A8B85
9B8A819E8C7FA39081A49283A1917FA2907BA6937CA7937AAA957DAA937BAD947DAB9680
AB9681A7927BA28D73A49075A49276A8987CAC9B81A39073A79275A59174A6957CA99980
A69982AB9F8BB0A493ACA192ABA293AAA392A49E8D9C988A7C7D747D8179787E77626C66
848D88BAC0B8BCBEB5C1C1BAC5C3BBC5C2B9C1C1BBB0B2AF8E9293919899929D99949D98
B2B5B2BAB9B6BBBAB6BBBAB6B7B8B3B4B3B1B3B3AEBFB1ADAE6C71A21D23B81114B90E0F
AD1112B4474C87596B5C4E6F8769888F465D94212FA3121AAD0D13AD070EAF080DAD0709
AB0508AA0409AB050BA8030AA6060AA1060A9F0C0CA10C0FA4070DA60309A70309A20309
91080D9343543A345C1A3B667698AF7490A2849FAFC2CEDC927A8B4E2247200F47190F4C
46123C60233F3C344F9CB9D1A9C8DAAEC8E093B2D53F618F07285F011F550A27514F7089
59798668828B63767C5E6F71606F6D5464604D605C1F3439294147606E67209B1300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0027D90BA68D7093999DB4C8D86F8A9961828C5E7B81
96ADB3B6C6D1B3C1CFAFBECCABBBC98796A46B7681737A82787C807A80837F848787898D
858689888A898D8E8B92908C948F8C98908E97918B979289918D829892869B9287998B84
9A89819E8C82A39084A59284A59081A48E7CA58F79A7927AA6937BA9957DA8937BA9947C
A6947CA39278A39173AA9679AC9B7FA5957BA8987EA59376A69174A89276A59278AA9982
A89982A89C84A59A84A59B87A99F8CA69D88A39C89807F727B7D768D91898F958E737E7C
566663A3AFA8B7BBB3BFC0BBC5C5C0BEBEB6C3C4BDC0C1BCC0C2C0B8BAB8B9BCB8BEC1BC
BBBBB8BAB9B7B8B8B6B9B9B7B8B8B6B6B6B5B8B9B4BEB3B1B780829C2127B61217B80D0F
AA1111D5686AB66C75A14E5E9523319F111CA70A11B20B0FB1070BAF050BAB0509AC070B
AA050AA9040BA8070EA2080D970C0E8C1816A5423CBE504E980D12A3030BA8040B9F060B
8A1721825473102254537EAA9FC5DA9ABACA7DA0B2AECCDDB2B6C6614E6D1F164B170E49
43123C5213304535547F9BBF8CAFD44F709E10306703235C092C5D2A4B70728EA469828D
849BA1778B90697C7D6476755B716D4E6464344A52061A2D172C3D606F7025A21C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A58666939597B2C4D46B849667839088A2A9
B0C2CAB8C7D4B3C3D3A1AFBF7A808F706C786E677075737A7D7D837E8084818689858889
8888898987888E8D8A92908C928F8A938F88948F88959188969087978E84998F859A8A81
9B897F9B897FA08D82A18D80A18B7CA48979A58C79A6917BAA967EA8947BA7967BA69579
A493769F8D6FA49070A38E6EA39071A18F73A28F74A69074A79070A89270AB9676A89679
A5967CA4987DA59B7FA99D84A89C84A89D86A69F8B6B6A5F6D746E7E88827A8480627170
4D605C9BA8A0B9BDB5BFBFB8C3C2BCBFBEB9C0C0BBC0C1BBC0C0BBC2C1BDC0C0BBC1C2BD
BBBBB8B9B9B5BABBB6B8BAB5B6B9B4B7B9B6B7B8B3B8B4B0CAA5A4963339B0181DB80F11
B41012B31D21A81B22A8141CAC0E15AC070EAF090CB3090CB4090EB0070CAC070AAB060B
A6050AA0050C960B138D1A2292434A8B585DA7717396353B980B12A6050CA3070C900E14
99506238305F0627605E8FBE5585A97DA9C5234E689BBFD5BFD1E09393A92F2D5511144B
1D12472512412122541630690C2C68001D5A022157254770779AB891B1C99AB5C789A1AD
A5BCC48DA2A9889BA17A929567838B304C5C061F3701122F01142D3C4C5629AA2700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A2825D939493B0C0CE8096A578919CAAC1C8
B1C6CEB4C5D4A5B4C67072826D55635F303963383D8370747C7B7F7E83867F8585838786
8789898C8C8A8F8F8C92918C8F8F88939188918E86918D85968F86978D84988C839A8B82
9B897F9D897E9C897E9E8C7FA28B7CA18878A78D7DA7917FA28D78A7907AA59077A58F73
A69071A49070A28F6EA38E6AA8936EA18E6BA3906FA79373A79170AA9370A89371A69475
A6977BA79A7FA5987FA99C82A79D83A49C83A49E8A75756A525C57586A665566644D5C5B
616F69A9B1A7B9BDB2C0C1B6C4C3B9C5C2BBC5C4BEC5C6C0C0C0BBC5C4C0BFBFBCC0C0BE
BFBEBCBEBDBABABBB6B9BAB5B5B7B2B5B6B1B4B7B0B3B2ADC3AFACB670729F1C20B71213
B90E10B80C11B50D11B40C11B2080CB3090DB2080BB2070DB3090EB1080DAC080CA4090C
960B0F8D1E248D445075516845364F6A4D60873D4990141DA0090FA1070C921013974755
5A49710C25602147796991B2274C6B5B7F9A638396A9C5D4BFD2DEBCC4D1736D8828214D
18134914114D0B124F041A5505265B21426E6685A6A1BFD769879F82A4BD46677E7A96A7
6C87946A818F677F8F3C576D14314F031A3F011238010E330111331A2C3E4C4D4400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A38256A5A49FA9B8C397A9B596ABB5AEC4CD
B0C6D2A5B6C4717584674C5A67232D6A0D13671619865E607F797C7D82847D8485818788
888B8B8D8D8C908F8D91908C918F8A928E87918D87938F87968E86938980998B83998881
9A877F9C89809B887D9D8A7D9E8A7A9E8A78A38D7AA58F7CA7917DA68F79A28B73A38A6F
A68D72A58F71A18E6DA08F6EA39170A28D6DA28E70A39070A4906FA89272A99675A8977B
A69780A99D86A59A84A39A82A29A83A29A84A49D88989684666C625B666066716B68716A
8A9085A1A497B3B4AAC0C0BAC2C1BAC4C0BCC6C3BFC4C3BFC1BFBDC4C0BFBFBEBCBDBCB8
BDBCB8BDBCB8BCBCB7BABBB6B7B9B4B7B8B2B3B4ADB4B4AFBEB0ADC08386A02529B51315
B90E0FB7090EB70C0FB50B0CB3090BB5080EB3080EB2070DB10A0DAA0A0D9D0E12911F24
8F475372566E36365A2F33596C57727D3647860F199A070E9E0A0D901116934652625173
0F26600E346A688BA8859EAC9CB5C2ABC5D588A3B1BED4DFC0D1DBC7D2DCAFACBC694D68
4A1A3F42113D341542262B557797B5A3C2D6AFC8D8ADC6D649657A67859B486577708796
5E7481657A8E213959041A4501144301104102113B010E360110350A1A35494C4F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009B7848AEABA59CACB9BCCEDDB1C2D1B0C3D2
A8BCC978818E614D575C1D266B0C1474080E6F0E12824B4E84787A7E81847E8285848689
8687888B8B8B8A8A898E8E8B918F8B918D88918C868B877F928A83988D89978984988680
9B857EA0877E9E887E9F897DA38C7D9F8877A18A78A68F7CAB937EA38C759D876E9F896D
A38B6FA79075A89479A28F73A39173A38F73A190729E8F6EA1916FA4936FA39372A79A7F
A19580A89E8AA59C88A39885A69D88A19A83A19C86A19E8A9697879395889193869A9B8E
A3A194A3A295AFB0A7BCBDB7C1BFBBC2BFBCC5C5C1C0C0BFBFBEBEC1BFBFBEBDBABCBCB6
B9BAB5BCBDB8B8B8B5B9B9B7B7B9B4B4B7B0B4B7B0B5B6B1BCAEACA46367A11E24B50F13
B6090BB7090DB40709B6090CB70A0FB3070DB40B13AC0B0FA31113951F25954955755773
383D631D2C5948477078526E7C2737890F1A95071094090E8C1B21904F6051476B102B61
0D356B587A9DB9D2E3ACBFCDA3B9CB6384A0698EABB3CEDFBFD2DDC1CFDAC6CCD8A493A1
6B34466C142A640E26512D4A7D8EA4AECAD9B1C7D5AEC4D19CB5C58EA7BC92ABC198B0C1
7C94A2829BB1041A44021347000E42010F41010D39010D35011034031430444A5200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009C7640A9A39992A2ADC0D3E2AFC1D2ABBBCB
848D9A6A626D59323857121570202587363A6310167E454988787B7D7E807C80817F8283
848788888B8C8D8F8D8E8E8A92908C918C87938C868F89828C857D978D89968885988582
9E85819D847EA0877FA0887DA38B7C9E88779F8B77A28D79A5907AA390779D8C6FA79479
A69277A28D73A18D71A18C70A18C6FA08E70A798799D8F70A19171A29271A39375A3967E
A69C89A5A08C9F9A86A19985A59C87A09A849F9A86A19C8A9D9A899E9B8C9F9D90A19F92
A2A093A2A195AEAFA6B6B7B1C1C1BBC2C1BDC2C3BFC1C2C0C2C1BFC0BFBDBCBBB9C2C1BD
BDBDB8B8BAB6B6B8B5BDBFBCB7B9B4B2B7B1B2B7B1B1B4B0BBB1AEAE73769B1C22B30F13
B70B0DB6080AB6080AB70A0FB2090FAD0B10A00F13921B209446537F5E7A39406E143068
2C41716C5B7F7E3C54841725930E1892070F8C0D1284252E81546B3638630B2760194073
8CAECF94A9BC9BB0C27E96AD8AA0B8324F701A3F60ACCBDFBCD0DDBECEDCC3D1DBC4C4CF
997C896D25336F0F2161263C5C5F74ACC8DAB0C8D7ABC1D29FBBD2335175203D6A48678A
7494A95E7991081E47011244001044010F40010F39010E32031633051A333B465010CD0C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053C12BACA5958E9EA5BED0DFB3C2D39198A8
6C5E695D3C416D4446562B2C734E5186585F59181F6F383C8673747C7C7F7A7E7E7C8080
828889878B8B8B8D8B93928F91908C928F8C928E8A928A84948B85968C87968985998883
97847E9D88809F8981A38D83A08B7CA08E7BA08E7AA18C77A9937DA08C749B896EA28E71
A18C6F9F8A6DA18B6DA18B6B9F8B6BA08E6FA49576A19273A49476A29275A39379A4977F
A59E889E9A83A09B84A19A84A29A86A09A88A19B88A09B889D9A879E9D8A9F9C8DA29E91
A29F93A6A69BACADA4B2B3ACBFBFBAC0BFBDC1C0BDC0C0BBC3C2BEC1BFBEBAB8B5BCBBB7
C0BFBDBDBDBBB6B8B4B4B6B3B1B6B1AFB5B1AEB3AFB4B8B4B7AFADB68284991F26B10F14
B70C0FB80B0EB50B0EAE0A10A00B13931A22994752835F7A3E4270132E6E0D33732D4D7F
7C759272283C8C101D960912930A1186131B843B48654C6A1D2B5D072863193F6F6283A1
92A8B896A4AE8696A46C80918FA1B0899DAF91ADC0B4D0DFBED2E0C2D3E0BFD0D9C4CEDB
BFBDC8906D79671E2C601C314A4055A0BCD0ACC7D792A9BF617C9B0D2958011B56031F4F
44647E536F830E2346011241010F4302113E0115360F283D324E592D47532D3D4624A220
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004FBD24B0A5919099A1BFCEDEA6B0C1786D7A
6332395813146E3A396B52536A5C61775A62581D26672C31846C6E7677797A80807B8081
8083858789888C8E8A8E8F8A90908D92918F95918E938B88968C88968C87988E86998D84
95877E97857E9D8A83A28E859E8B7E9D8A7A9E8A75A18974A78D78A188709E876BA08B6D
9E8B6BA08D6EA08C6D9D89689D8A699F8D6CA09272A29478A99A80A7977DA29279A69983
A29A849F9883A19984A099839F9984A09A879F99889F9A889D9A889C9C8A9E9C8CA19F92
9C9C90A1A298ABACA4BBBDB4B8BAB3C0C0BBC2C1BDC2C1BCC3C2BDC1C1BCBEBEBBBCBDBB
BABDBCBABDBDBABEBEB4B8B8B5B9B9AEB2B2AFB5B3B3B6B4B6AFAEC2969B92232BB11318
B60C10B30C11AD1317991A2096414D89627946486E1730680C326E234A7E5E7EA08B99AA
9D8089771B24910F18890E158327317D4E643C375E10275E0A2E6630547C6E8C9E869B9F
91A0A2A5B0B7919FA7B8CCD7B8CFDC94ADBD85A6B99BBDD1BAD3E2BFD3E1BDCFDCBDCDDB
C4CEDAB9B1BD845E6C5920324A344A839AAFA9C3D394ABBD7991AC122C5B01185601154B
4765856F8BA018315001154000133E0C2343284452425C5D4B635E4B606229393E2AAA28
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004DB71DB7A38F91969EBFC8DA837F8F6A434B
61131664080A6424266A4F51675D62755D6460273063262C83676A747477747A7D797C7E
8484868989888C8C8A8E8F8A8F908D91918F928F8C96928E948E89948E879890879C9188
9D8D859D8A839F8B83A28E85A28E81A38E7C9D8872A18A73A187719A81689E86699E8768
A08A6A9E8A689F8B699E8C69A08D6AA59170A391719F8F72A6977DA7987FA2937EA39783
AAA08DA29988A59D8B9B95829D9784A099879E99869D99869C9A889B9B899C9D8D9C9D8F
9D9E909D9F93AAACA1B8BAB2BCBEB7BCBDB8BDBDB9C0BFBCC1C0BCBDBEBCBBBEBDB9BDBD
B7BEBCB5BCBCB6BCBCB5BBBBB4BBBBB1B8B7AFB6B2AFB3B0B1AEACC5A1A4912D33AD171D
AD1115A01D219B3E47936475554E6B3442683049752C4C765A7A968399AB91A0A79A9DA0
A58D906C262B7E232C8244555442641D2A5C07245C1338674E6F8C7B939D8E9FA08E9B9B
9CA7A9C7D4DCB0C2CC92ADBE5B819A7DA1BB355D777DA4BBB7D3E2BCD2DFBFD3E1BFD1DF
BDCDDAC2CCD9B1ADB8725A684737495E6F82A6C2D1ACC3D48098B3203D68001A53031852
1D355D718FA61F3C510B263F25415745606B4E66694C615C52635D4E61602334373A7A35
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0025D90BB9A2867C8082A4A9B468535D591C22
6D171A71181A5E161A663C4168545B775F67642E36601F26866467726E727175797A7C7E
8080818989898C8B8A8D8D8B91908F928F8E94908E928F8B928E89968E89958C859D9188
9D8C859C8A839E8C83A08E839E8C7F9F8D7B9B8872A08B73A28B739D856A9D85689E8567
A28A6B9F8969A08D6D9E8B6B9F8B6A9F8A6BA39071A09171A4967AA89C86A69A879F9380
A29987A9A192AFA7999C95859C9481A098849F98859C99849B9A879C9C8CA0A1949C9C91
9C9D909FA193A6A89CBDBEB5BFBFB9BFBEBBC1C0BFBEBEBCC1C1BFBBBEBCB9BEBDBABFC0
B8BFBFB3BCBCB6C0BEB1BAB7B2BDB9B2BCB8B0BAB5ADB4B2B3B2B2C8ABAE913D429A2226
9F393F9A6575615772373C5E605B7C7A627C917E919295A094A0A697A1A498A1A1979B9B
9A9594866D6E856F7B2E30550C255A0E2F63315377667F907F91938594919FACAAA7B2B3
8E999E97A3ADA0ADB88699A8345067688399748D9E9EB7C8BCD3E0BDCFDCBED0DCBED0DC
BED0DCBDCEDABFCDD8A5AAB5676A7A43576BA2BFD18DA8BA25425D29476F011C4E01174E
072148506F7F435F654660674F696D5168695069664D645D4E625C495C5D213238494A47
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B0926D74716D7572785B3C41551B1C
7B3C3C742D315A0C116126296A4A4F74555D682F375A1B1F8260637270716F7576757779
7D7D7F8887898B89888E8A88928D8B948E8D908A878E8885918785918482998B869F8F8A
9E8C859F8C85A28E879E8A809F8B7FA390809F8D789E8C769E89729D84699D8365A1886A
A0876AA48E719D8B6D9F8F6E9B88689E8B6FAA9A7F9F9175A092799E927DA79F8A9E9681
A29A86A39C8CB2ACA1A29C8E9A92819D96839F99859E9B869A9986A1A395A7A89FA19F98
A1A096A1A196ACADA2C0C1BAC1BFBBC1C0BDC0BFBFBDBEBDBDBFBEBCBFBEBDC1BFBFC3C2
BDC1C0BAC0BEB8C1BDB8C1BDB6BFBBB7C0BEB3BCBBB2BAB9B6B7B7C2B3B5936769A06A6E
7F66773C3F615A5A7C906C868A3B4C84212B995659A6989B959EA197A1A1999F9F979E9D
949897969594838A9320355528486D5D76917B8C94818B898A938D89928C8B9190939799
959296948F96968F95A0949CA297A0B2A7B1988E98B8B1BDC4C5D1C2CCD8C2D0DAC0D0DC
BDCFDCBACEDCBACEDBBACAD5A0AFBB51697B84A5B76985937992A0637C932E476B04204C
234563617F88637B7A596E6E5C7070546968516A664A645D4C635D43585C1D3039565B5B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A67D537B6D656C5F655634395F3334
794F50652E3152090B702F2F6B3A4077414A661E24601E217F62627172746F777A737679
7A797D8480838E8A8A8C8A878C8A858B85818E84829086848F818091817F92807D9C8984
9F8A859D898298857C9C877E9C867EA49185A29181A3907D99836D9C83679A80619C8264
9E86699F8A6D9B8A6B9D8F6D9C8D6BA09174A79A809C8F76A2967DA19780A19B859E9884
A39C8BA8A294B2ACA1A59F929C9584A099879B97829D9B869A99869D9C90A8A79DA8A49A
A9A69BACACA1B1B6ADBAC1BBBBC0BDBEC2C1BEBFBFBDBFBCBFC1BEC2C5C2BEC2C1B9BDBE
B9BCBDB9BEBEB5BEBDB5BEBDB3BCBBB7BDBDB5BABBB6BABBB3B5B6B6B4B4B6ADACB9A9AF
7C6A7F8F6B89984D65931F2EA012199F11189D424C69586A6B7F8C92A1A2979D9C9BA09D
949A969297958A949378868C7C8A93838C92888C8B8A88858E8A85928481957B7D9B747A
94606796555E9045508F39458C323C8A2F3C862F3C8B3E4C965D6BA2828FB6ACB8C3C8D4
BFCFD8BBCFD9BBCFDAB7CAD5B6C9D299B1BE82A0AF86A2B0AAC4CF8BA2AEA9BED1516D83
7F9BAD637B82677B7C586C6B596F6C566B684F67614A645E4C63602F434D1F34405D6766
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074912F7E67597262634E30336A4949
725352501D1F530E0E7A3839641F25671019670B11712E317E61636D6A6F6E747A71777A
7C7B80827D818882838886848785828983818A817F8B807F8C7C7C8E7A7A917E7C92807B
9A878099877E9C897F9E8A819E8A83A18D839D897B998471978069A0886EA0876A9A8265
9C896C9B896D9D8B6E9D8D6F9E8F719B8E73A2977FA399809F957DA9A08C9F9785A49E8D
ABA496ACA69AABA79CA9A5999A96849B98839996829B98859796849C9C8EA2A297A2A097
A8A99FA5AAA3959E978B96918994938E9B9BB0B9B9B7BEBBBEC2BCBCBFB9BCBEBBBABCBE
BBBDBEBABDBCB8BEBCB8BEBDB6BCBCB6BABAB4B7B7B7B9B8B5B6B6B6B5B6BAB2B3C09EA6
A85F6F962536A2131FAB0C14B00A12A50B149734424C3B584D69818CA2A6969F9C9CA39F
9AA09C9197938B94908B92918D8F8F8D87889885859776778E585B893B4183222C83141F
890F178F0B15950B16980A13980A119506109207128F0714870B1A8017267F303F976B79
B8ADB9C0CAD5B7CBD7B2CBD6B1C7D2B1C7D5A3BECF4F7085799BAE5C7C8A6C8794637986
5E737B5C6F725A6D6C596D6B586F685169634E67614E66673A505B091E3024404C5E6D6D
219E1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004AB2187F654B6E5F595239375E403E
70585563413E4C19177E42455E11176306096A151682474A6A4A50736B706B74766C7576
7D7E82868285857F818782808A8381877F7E877E7C8A7F7D8679758979768C7A778E7D77
95847C96837C99867F99867F9D8981A08D819C887897816C99836B9C866E9F886F9E8A6F
9E8F739B8F739A8D72A090769D8D759C8E78A0957FA69E8A9F9785B1A89AA9A193A7A294
ABA69AB1AAA1ACA69DA6A4989796869998859A9887A09F8E9B9A8DA0A094B0AEA4A9A79E
A9ABA38990899CA59DB3BAB2B5BCB89FAAA8818E8CB8C2BEBCC1BBB9BBB6B8BBB9B8BCBB
B8BBBAB7BBB9B6BABAB5B9BAB7BBBBB3B7B6B4BAB6B4B7B4B4B6B3B6B4B5BEA5AA8F3F4A
A01C29AD121AB00B10B1090EAF070DA709129123336145653A537490A8B295A2A098A09D
969B9993969393918E978A8C9B7E81935C6285353A801B21870E168F0B1592061096040C
9B060C9E060E9F040D9E02099E04089B010698010899030D94020D8F04108907157B0F1F
7B3345A68B9DBCC3D0B7CCD6B4C9D4B6C8D68197A82F4A5F446274637F8A627A83768A91
5F7376677B7B5B6F6E586A6A576D69516A674D6666384F5A0C1F3701102D0B213852656A
25A52100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004DB4158163416C5C525A423C553531
6A5250624F4C5A403D714344550B0F6210128242437946495E353A7C6C6F6E71726E7776
787A7C848284817C7D8981808C8280887F7C887E7B8178748074718575738774738C7975
92817A92817A99857F98847E9A867D9A877A9885759A88719B886F97836AA08C739C8A70
A293799D91779F9178A4957EA1927BA2957FA39782A69F8CA39E8BA9A494A4A193A5A396
A9A398B3ACA2AEAA9FAFAEA19D9F909E9F90A09F92AFAFA29D9F93A4A69BA9AA9FAAABA1
B0B2AB818983B1BAB3B6B9B4BFC1BFB5BCBB7A8483B1BAB8B8BDB9B8BBB9B9BDBCB8BEBB
BAC0BCB7BEB9B7BCB9BDC0BFBEC1BFB7BBBAAFB6B3B0B6B3B2B7B2B1AFB0BD9CA08C2932
AC131DB70D13B4090FAF080DAB060BA909138D1423754C6D2B426487A3B098A4A59CA1A1
9A98989E8E90A17A7F934F5789262F89101A8F0C1491070F94040C98010D98010A9A0109
9B02079D02089D03089E030B9F020A9E02089A020997020A94010A92010B91020C8E0410
830917721D2E9E7D8BC4C7D1B9C9D3BBCBD87E909BA6BAC6788D97A7BEC681989EA3B8C0
6A80867E93955C6E6E5A6B6A586C6A536B6B37515A081D36010F30000C31011230314454
387B3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0083592F735A4A664B43532E29
6D4A495D4443644E4E6A46474E12135F20218A5A5D612D305923277D6365717171747877
77797A7B7C7E7D7B7C817C7A857E7B88807D847B788078748077727E736D8575708C7A76
8F7E7897867F97857F95837B97847A99867B9886799B8A789E8A7697816B9C89719C8C73
9F90789F9079A1927CA29680A59883A1957FA59984A59E8AA6A08DABA596AEAA9CA5A196
AEA99FB2ACA4A9A69BAFADA1A9A69CA5A398B1ADA3B0AEA4A9ABA0A1A69CB0B5ACC2C7C0
C7CDCBB5BEBCBBC3C1AEB4B2B1B6B4ABB4B37F8988B4BCBAB7BCBBB7BBBABABFBDB5BCBA
B6BFBDB5BFBDB3BCBBB3BAB8B6BCB9B6BABBB4B9B9AFB5B3AFB5B1B5B3B6C7A9AD8C2C34
AB131BB60912B50812AF0710AB050FA80913870E1A7B506D1C31557D99A9979FA1A99C9E
A48084934B5489202B900F1A93071098051095020C95030B9401099A030B9A030A9A0107
9A01079D020B9D020A9D00099D02089B010597010692010893020991000993010B94020C
8C020C8108136F1D2AA98A95C0C5CFB5C8D5859EAB92ACB88DA6B17D99A286A0A670888F
627A7E5F73755D706F5B6B6A576A6B4A626B0E243C011034010C32010B3202123610253D
464D4C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7210754B34735047522824
7644434C1B1B6848486851525F3E3E4D292A7E5B5F5F2B31551A1F826264757171767878
79797D79797D7878787F7D7B827C7C857D7B7F76747E75727D756F7B716A837570847571
8D7B77927F79937F7899857C96827A96837C99867C9885779F8B7B9E8A749A88719A8A73
9F8E769F8E779F907DA09482A29684A79887AB9F8DA69E8DA6A090A8A395ABA79AAAA69B
AFA99FABA69BA9A79BACA9A0AFADA6A5A59DB1AFA8ACACA2ABB0A6B5BDB4CAD4CFC9D2D1
C9D3D4CEDADACDD8D9B8C3C49CA7A7838E8D9AA4A1AEB6B3B6BBB9B5B9B8B6BBBBB2B9BB
B3BDBEB2BCBDB2BCBBB1BBB8B5BDBAB6BABCB1B5B6ADB3B1AEB4B2B5B4B6C7AFB3913B43
A6121BB3090FB20910B00911A909109E0D168119257B5975182C4F7E8B9FA28B929F5D65
91272F9A131C9B08129C050C9B03099A020B97010A930008930108970108980107980108
99010A9F030D9D02089F040A9D02089E03099C040998030B93020991010891010A92020B
8D000988020B7B07126D2330BAA5B1A5B4C229475C4266784869764A676F6A8387687C82
5E76795A6F705B6E6E5A6A6A586A6E2D4354021435000C35010C33010C32001036061B3B
414D5400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00419E08713B237F574E5F3231
77393C4D0C0D68383A65494D6551536455576F5C615F313754171D805A5E776E70727174
7475777676787777767A7A78827E7E7D78787871707B73717D74717D736F80736F82726D
8874718F7875947D779C857E94807896847C9D8A809A877B988778A08E7DA08F7C9C8C76
9F8E7AA4927FA39383A39686A59989A99C8CAA9E8EA69C8DA8A192A8A194ADA79BACA79B
A9A39AA9A59CA8A59DA7A69EAAA8A2A5A49EAFB0A8ADB2A9A9B3AAC9D4CEB6C0BDAFB7B6
AAB4B3B8C4C3CDD9DABDC8CC8E9A9B9EA6A5ADB4B0B0B7B3B4B8B7B6B7B9B3B6B7B1B9B8
B1BBBBB5BEBFB5BCBEB4BBBCB4BDBCB3B9B9B2B8B8AEB4B4B1B7B6B4B3B5C5B1B59D4F58
A41722B20B13AD0A0FA70E149611178E2C358A576A453F5F494C6C8B677C8D3441981521
A50C15A80610A3030B9E01089D02089B020B9701089601079501079903089B0309970107
9A02099D020A9E0207A004099D00079D010898010698020796020892000891020B8E010A
8D020989010982020B72081380475099949D6E84904A6A7792B0B87B949A92AAAE809498
839A9C5D7675576C6A59696953656D10233D011037000B36000C33010D32000E33021738
3A47570CCB0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00449E0571321880544C683935
611B1A580C0A773939511E22643F4368565B6B5C6263363C5313177F545975686B6F6E70
7272727474747675737575737A78787D78797E79767874707B73707A706E7E706E82706D
86726E8B746F947D779681799581789A887E99877E9E8C829B897C9D8A7CA493839E8D7C
A0907FA59585A59386A59689A5978AA5988BA89C8EA89C8DA9A08FAAA495A9A497A7A398
AEAAA0A9A59CA7A79EABABA3AFADA6AEABA4AEAEA4ADB0A6B5BDB6C4CEC9A7AEABAEB2AD
A8AEA9A9B4B0C8D7D6CDD9DBB4BFC0ABB3B1B2B6B4B5BAB9B6BAB8B3B5B4B4B8B7B4BBB9
AFB8B6B1BAB9B3BBBCB1B9BBB0B6B5B4B8B7B3B7B6B0B4B3B2B7B3B5B5B5C2B0B4A65F67
9F1822AA0E149E121590252D995C6A68566E3F3E5C6E5B79874A61871B2B9A0C17A60711
AC090EA9040AA8040BA4020B9D020A9B010999020998020B960109950108970109960107
9A01099E020AA1020B9F020C9D020C99010A95020993030890030A8E01088C01098A0109
89020A8600078301077C030C6B121A846267B1BAC095ACB789A2AB9AB0BA738C907E969A
657E805E76755A6E6D586A6B465665031334010E37010D37010D33001030061833041B36
2C3D4E1D9C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D407794023754B436E3C39
580F0C5B0E0D7D3538560D115416196D4F5168575B6A3D43521114794D4F76686B717073
6F70727272717473717474727C7A78807B797D7A75797871766F6C7A6F6E7E6E6C836F6D
856C6988706A907A7395817A97847D97847C98867B9A887C9F8C7EA39183A18F81A29182
A29283A39484A09283A19485A09485A29688A59989AA9E8FAA9F93A69E92A9A399A5A198
A8A49BAEAAA2A7A79DACACA2AFAFA7A9A9A0AEAEA5AEB0AAB5BBB6C5CECBAAAFADB0B3AF
AFB5B0AFB9B5CAD7D7C8D5D7B1BABCB0B8B6B3B9B7B1B7B5B6BABAB5B8B9B5B9BAB2B9B8
B0B9B8B2BCBBB2BBBBB0B9B9B4BABAB7BBBAB2B5B4AEB3B2ADB4B2B4B7B8BCB1B3AB757B
8C1F259220259D535F7D647F363D643A42697C607D802E439214249F0A16A4040EA9060D
A9060BA9060BA7050BA3040C9F03099B02099801069B020A980108960107960107950108
98030A98020B99050E94060E8C060F870A11810C127A0A0F77080E7D070E81060E83030A
85030886020883000982030C73070F74353F8A808A72869259727E637A8260787B688283
637D7E5C75735B706E596C6F314357031239000C38000D350317361C37493D59642C4654
1D333F1C9F1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774021774C456A3837
5C1D1B60212279353A55070B5D1D1F6A484B6B4E54662F34561013794F4F6F636568686A
6A6B6D6B6A6B6C6969706C6D7976777E7C7B7E7D787A787379736F79706D7C6E6B806D6A
816A6888706C8F797496817C947D7996827999857AA28F82A29181A79686A59485A49384
9F9183A39587A497879E9280A29685A69A8AA59C8CA79E90A59C90A69D93AAA199A8A098
B2ACA4ADAAA1ACA99FAEADA1B1B1A7ABABA2AFB0A9AFB1ABAFB4B0C8CFCDBCC2C1B4B9B5
B7BBB8C4CCCCCCD7DCBBC6CBA7AFB0B2B7B6AFB4B3B4BAB8B2B8B7B6BBBDB4B8BBB5BABB
B3BCBBAEB8B5B0BAB7B0B9B8B1BAB7B3BABAAFB6B4ACB4B3ABB5B4ACB4B4B3B2B2AB8F91
8550529E788545496E1F3568545886835473842136950D1DA20814A6070FA5040BA5040A
A7060BA9050CA40309A3040C9F030A9C020A9D040A9B010A9901089402079203098E060B
85090D83121A86222C8836448346557B4E606B4A5C694D5F6E4E6077485873313F701521
7C091284040D85020B83010B7C050D6A15206146517C8B965B727C778B93738B8C768E8F
6C84865C74735A706D586C70263A5002113B000E380314342945554460634B6261445B5F
1C323A25A92B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723A15794E45663937
61322E693E3D6B343751080B69262A76434A6B313A590E135D1B1B735252665F625F6162
6365666868696665666C6A6D7473767877777E7B787D78757A746F79716B7A6E687E6D68
816D6889746F907C7598847D99857E96827A9B877CA18F80A19081A59284A59283A49484
9E8E80A190829E90809E9381A19887A19989A69C8FA59C91A6A094A79E94AAA199AFA79E
B1ACA3AFACA3B3B0A6B0B0A5AFAFA5ADAFA4B3B5ACB3B7AFA6ABA6B0B7B4C3CDCCCAD3D3
CED4D6CBD2D5BCC6C9B0B8BAADB3B2B7BBB9B6BAB8B5BABAB0B8BAABB5B7ADB7B9AFB7B7
AEB8B4ACB7B3AFB9B7ADB6B5ADB6B5ADB6B5ADB8B4AAB5B1AAB6B2ABB5B4ABB2B1B0ADAD
B3ACAF797E9323376167628E884B698C192A9F0C18A40711A5040BA9050CA9050CA7030A
A8040BA6030BA3020AA1030CA0030D9B020A98030998020A92060E870B1182182085323D
7C475572546C5A4E6F363A631F2B5A1122540F24521126541427511C2A50333855685469
6D2D3F770E1C84051084010C7E030A6D0B15552E3A9AA4AF9EB5BE798E9599B1B5698184
6E86885D73725C7270596F721E364B01123C011537203E4F405F614A64605065604C6363
1F363C40484700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00713910775043663C3A
5E3431745752643D3B541214681A1F73242A640E135D0B0D6A34346A56575E5C5E5A5C5E
6061636767676A67676B686A7371747573757976758079768178767B706E7B6F6C7B6C67
7F6D6783706A907C7596827B98847D99857C9D897EA08D7FA18F80A08E7FA1917FA1927F
9C8C7A9E8E7E9B8D7C9F95839E97869E9788A29A8BA59C8EA79E91A89E93AEA59DACA69E
AFACA3AFAFA6AFAFA6AEAFA6ACADA4ABADA4AEB1AAAFB4ABA8ADA6A7ADA8A6AEABABB3B4
B3BABDAEB4B7ACB5B5AFB6B4B2B8B4B8BDBAB5B9B8B2B8BB8F999C89979A7E8B8C9AA6A5
ACB8B4AEB8B5AFB9B6ACB5B4AEB7B6B0B9B8AFB7B6A9B2B1A6B2AEA8B3AFAFB6B4AEB0B2
ADACB1A49FAD8D72898F3E57961425A30914A9080EA9060DA8050AAA070CA8050AA60308
A30207A5050AA2020AA1030A9C030A93020B8D070F84101A832D397A4559644C6B3B3B65
1B2B5E0E245C0A225C12286020356530436A6272908D9CB598A7BE9CAAC191A3B8758497
766B7D763A48740B1681030E7F0109720510602A395D5D6D889EAA627980677F81647D7D
5D77755F787559706D5872731F3A4C011538102A434562694A65614F68614F65614D6165
1E353F44505600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00773F13794E42704445
582A2C765857684B4B5D212360060B68070B5F0C0C682E2C6C50515D56585B5D5C5B5D5C
5E5E5E6865666B66676C6768716C6F706C6F7772737D74748077747F72718173717E6D6A
816E6888736C90797395817995837997857B96847A9B897D9F8E80A08F809D8E7C9D8F7C
A39583A09181998C7C9C907F9A9180A19A88A29A8BA59B8FA9A094AAA198ADA59EAAA6A0
ABABA3B0AFA9B3B0ABAFAFA7AAACA4A4A79FADB1AAAEB2ABA8ADA7A5ABA7A6ACA9AFB5B5
AAAFB1ACB2B1AFB4B3A7ACAAACB2B0AEB4B3B9BEBFAFB6B8869092AAB6B7A3AFAE84908F
AEB9B7AEB8B7AFB9B9ABB5B6ACB5B6ADB4B6ADB2B5A9AFB1A6B0ADA8B2B1ACB5B2B0B1B3
B7ABB1B48993903642A01522AC0A14AF070FAA040BAB060DAA070CAA050BA80308A50207
A4030AA4050EA2050E9D060C91090F81121B813442734C68433D671A285D0A235F0C2865
1833683C4D7764688882738B8362768557698753638A56658C5D6B8F6A7890828E9BA3AD
B6C0C8A08B947229347C091581020C78040F6C2635392E406A80895D7579667C7B68807D
5D76725F7572597270557073223D4C0118333550614F676A54686451686347605E3F575F
17314026394604C50700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783B0C78483A794C4D
5224267553536A4C4C642D2E5806075D0A0B652D2D6A4F505E5457545457555758595A5C
5B5A5D6362646867666C686670696C716B6F766E6F7B74707F7771847A7683757282716E
86726D907874917B7594807898847C97837C9B877D9A8A7D9A8C7C9B8E7D9C8F7C9D917E
9F94829D9181998E7C9C917F9E9382A2998AA69A8FA4988FA7A095A7A198ABA69FABA8A1
ACABA1AFACA5B1AFA7AFAFA5A8AA9FA7A9A0B0B2A9AFB1A9A6ABA6A4ABA8ABB2B0ADB2B0
ABAFADA7ABA8AFB3B1AEB4B1ADB6B2B1B6B6B6B7B9B9BCBD8B949594A0A08290908F9D9D
A9B7B5ABB7B5ACB7B7ADB7B8ADB7B9AEB6B8ADB6B6B2B8B8ABB2B1A7ADAFA9ADACB9AEB0
B9899096323DA1141DAF0D14B20A10B0080FAA050DA9040BAD080FAD060EA9050CA6030B
A5050F9F070F93080F85121A863947734E6938355F12245E0725640F2F682F4B77606E8D
7F758B855B6C7F36457D1B2983101E860B1B880C17880C19810B1778141F622931888289
B5C6CDBBBDC7855967720F1F80040F7A040F6A1D2D2F2236758E989BB5B76D8383889E9C
5F75725F75735A716F59707337515E0119304863724C63665467665265654F646B1E3547
031A39071C38068B1200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008846107847357C514E
4F201F774A49663C3B6C38394F13125B282764494B5E54565351564E505354565858595B
5C5B5E626164656566696769706B6D756C6E776F6E78726E7D7870867C77877876857370
86726F91797690787495807996837D95827B97857B9486789A8C7C9E8E7EA19181A49685
A194839B8E7D988B799E917FA39685A39687A4988BA69B90AAA298A9A39AADA9A0ADACA3
ABA9A0B0AFA5B3B4AAAEAFA6A8A8A0AEAFA7ABABA5AAAAA4ACADA9ACB0ACADB2AEABB1AD
AAAFABAAADAAAFB4B2A8B0ADAEB5B3B1B6B4B6B9B8B2B6B6B1B8B89CA6A69BA7A7A5B1B1
A9B5B5A9B5B5AAB5B5A9B3B4A7B3B3A8B2B3A8B3B3AAB4B5ACB3B5AAADB0B4AAAEB4838A
99313AA5131CAF0B12B30B10B1080DAD060EAA040EA9030DAA050CAB040CA50209A2050A
99080D8C11178A343E8057703F3D6812235F0622600B2C63294A72667A93807B89885D6A
7E2B3686111C8E081294061196030F97020D98030C97040F8D08137D1D2A7654658C9CB1
A3C5D7B9CBDA967F916714287C04127B04106E1F2E2E2033506C787E9C9F677F80677F7C
6178765D73715C7071596D6F48616A021C2F405D694965675066694B616922384D031638
01143E04193D024C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00627209774732825A56
55201F7B37375D1516682F2F6742435843465A50555250554D4C52515155525456535655
5C5C5D6261646362676766696F6A6C726C6D746E6D78736F7E787382787688797A847373
857070937A788F7773917D7892807B95848093857C94877A998B7C9C8B7DA49284A09282
9F9382A196839D927E9F9581A09984A59E8BABA190A89E91ACA598A7A397ACAAA0AAA7A1
ADAAA4B1B0A8B0B1AAA8AAA4A4A69FA1A29CA7A5A0A8A5A1A5A4A1A8AAA7ACAEABABAFA9
AAAFA9AAAFAAAFB4B3ABB3B1AAB4B0B1B8B7B3B7B8AFB3B4B1B8B8AAB3B3A5AFB0A6AFB1
ABB5B4A8B4B2A9B4B2A7B1B1AAB5B5AAB4B4A9B3B4A9B2B4A7ABAFB3A7ADBB8B93972E3C
A91521B30D15B2080FB20910AD060DAB040DAD0711A7010CAB060DAA060DA4070D940C11
86222A86506553496F1729620726651031683A5980617991737B8A88717D823F49861723
9409149B050F9C040B9A010A9A010A9B010B9A020A93050D7E131F7545601D26530B3464
5787A9B6CEE296859666192B7C061377030E6F2434291E373B596959787C627C7A667B79
6578776175745D7170576D6C566F72102939314D5E4D6976334C5D10254101123700103A
01113C04173E06152A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A1077A4B33825A56
5A1F1E610D0C600A0C602627624A4C564D515752565250544F4C51524E53555356555557
57585A5D5D616060646766686D6968756F6F76706F7A75717F7773817675857677867274
85726F8E77738D7470917B7693827B92837D94877F95887E9C8E819E8E809E8D7EA09182
A29585A39786A49786A19683A19A86A39E8AABA593ACA596ACA598A7A398A9A79CADA9A2
AFAAA4AFACA4B2B3AAA6A79FA1A49B999B929D9E959B9B95999B97A3A5A2B0B1ADA8ABA5
ABADA9ADAFADB3B6B6AFB6B6ADB6B5ABB4B4B2B7BAB5B8BAB5BABBAFB6B9ACB3B7ABB4B6
A9B5B4A6B3B1ADB6B8ACB2B6AFB6BAACB4B7ABB3B6A9ACB0B0A5ABB78992993541A5131F
B10C14B10910B50A11B0070FAC040CA80209AD080FAA050CA8070CA10B0F8E13188E3F4D
6A4E6D26336808296A0B316D345782647F9570808C808188886771792A3787101B970712
9D030B9D02099C01079B01079A010998020996020B830B148346582A2B53072D6043759F
9FC8E1B9CBDD927C8D6616267B061276030E6E2B3D1F1C3A5272885D7B8288A0A1657A79
6275745F73735F7374596E6F546C6E324C5A0E274118335204173E000F3C010E3A010D39
010F3A02163E04162C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DAE12825336805A56
602729570A07651F1D6A41435E4D50585056534E534F4C4F4B484B545053514E50555457
545558585A5E5B5D616462666C6869706C6C7471707B76737F787581767682737383706E
8974718C7672917B778E7A75907F7791837993847B96867B9A897F9E8C7FA18F81A39484
A29585A79A8AA69988A69A89A59D8AA7A08DABA393ADA499ABA398A8A399A8A59CADA9A2
AEA9A4B0ACA7AFAEA79A9B949A9D959193899294898D90868C8F8892958FA8AAA4A7A9A3
AAAEAAA7ACA9B2B8B4ADB5B2AFB7B5B1B6B8B3B5B9B5B7BAB3B7B9B4B9BCAFB4B9AAB3B5
ADB9B9A8B2B3A9B2B4AAB2B5A9B1B4AAB3B5ABB3B4B0ACAFB99299983B44A61822AF0C14
B00A0FB30A0FB4090FB0060EB1080EAF070CAD090CA8070C9A0B118D232D8D576D4B4671
112B67072C6B234B7D5D7D9B7B919E7F8E9284848986666E75243084091492060E980209
9B01079A03059902049C03089A020A9500098C070E862E3E4C395C07265A3568949DC9E4
B6D0E0B6BCCB8664726A101C7D060E6D040D6B36491519397B99B069838B6E8385647978
6277765F74725E72705A6F6D566C6C38505D01163501123E010F3F020E3E010E39010D37
010F3702163A0D203600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050AF0F82522E795851
623939511C196D433F644E4D5D51545A5358504E5349474B49484B4F4D4F575556535253
56575A56575B5B5B5F5F5E626666676D6C6B7773727972727D747280747383757386736F
89756F8B7671917E79917D7994817A93817995847B96857C9A897C9E8C7E9F8F809F9181
A09383A49787A49787A49887A69C8AA79E8DAFA696AEA499ADA49CAAA29AA8A39BABA6A1
A9A49FAFAAA5AEABA4999A928C8D858C8E838E91848D8F828B8E838E9086A0A199A5A6A1
A3A7A5A3AAA8AAB3B0AEB8B4A5AFADAFB6B6B0B5B7AFB3B5B3B7B8B3B8B9AEB5B9ADB8BA
ABB5B6A8B0B2ACB2B5AFB4B8B1B5B8AEB2B5B0AEB0BD9CA29D4751A01720AD0C13B10A11
B00910B00910B0070CB1060DB50A0FB2090EA80B0F961017903847755274242F660B2D6E
0F387441688E7594A881969E87959885898C90777E772C37810B168F030C920109970208
9701059A03089B02079A000895020A91030D7C0C17824F6B1421511947778DBDDAAFCFE1
BDCDDBA49CAA743948790B1781050E6A0C1858354E0916384B687B617A80647A78617A76
6079745E777359716D5C6F6D596D6C354857011337010D3F010D41010D40010D3B010E37
0110320A233C31475208C90800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B3107C4820795A51
6952505E49456857536158565F57595954564E494C4440444342454B4A4C555254535155
52515659595E5B5D615C5E616262636C69697873737B72737E7576807575827473877672
8A78728C79748F7C788F7C77907D77917E7795827B9A887F9B8A7D9D8D7E9F8F80A29585
A29585A69989A79A8AA69A89A39A88A59E8CACA595ACA499AFA69DA9A298A9A39CA9A59E
AAA7A1A9A6A3A8A7A29A9A938A8C81878A7D8A8D7F8B8C808B8C838D8D8595968FA5A8A3
A4ABA7A7B0AEA1ACA8AEB8B6A4ADAEADB2B5AEB2B5AFB3B6B4B8BBABB1B3A8AFB2AAB3B5
A6B0B2A5AEB0ABB1B4B0B3B8AFB2B5B3B0B5BDA4A9A659629E1B26AD0D17AF0910B30A11
B10710B20910AE060DAF050CB50C11AA0C0F971C22934D615D4E77152A68062C6C244D82
6184A37995A281999D8093958490938D8388753D467A0C188D030F94030D95040B97020A
95010899030997040992040C8C050D8108138231444B3A65092A616595BBB0D7E8B9D0DE
B6BCCB8E6D7F6C15257F061279050D7225343525430D2346557284718889657978627773
6178726076735B716E5A6F6A566C69435864021334030F3E000E3F010D3F010E3C001037
071F3933505F50676A15971600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B80491E775A4F
665B5A61595665605C5F5B5B5854555B55584F494C47424644424549484A55525657565B
5051554F5457565A5D5A5F606364656967687471727872747B71747E7374847777887976
8879748778728D7C768F7E77917F789380799481799A887E9C8B7F9D8D809B8D7F9D8F80
A29383A39484A29585A69A8AA59D8BAAA393ADA79AA9A498AEA89EAAA59CA8A39CA9A59E
A9A69FA7A6A0A7A8A29FA29A8A8D82898C7F888C7E898D7F8B8E828D8F848E9389989F96
A0A6A1A5AEACA3ACABABB6B6A8B1B3ABAFB4ADB1B6AFB4B8B2B7BBB1B6B9AAAEB1AAAFB2
A3ABADA4ADAFA7AEB1A9AEB2B0B1B6BAAAB0AB707996212CAA0F18B10910B20910B30811
B40911B0070EAD070BAD080EA80E1598232E935B753F3F710C2C6E0C35733B638C7191A5
7F979F84989C7E9392809291878E908C6D736E182286061192040E93010B91030A8E020A
8C050D85080F7E0F167B1B247D2C36733646745879122158255282A1CDE7B4D1DFB8C6D4
9F8F9F7630427E0C1980030E6D0811713D5412173A4261805F818B869DA0697D7E627673
6378726178725B74705A706E586E6E4E646F041634010E3B01103F00103E001239102A43
33525D4664665B6F6E17991800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008852227B6152
655D5A605C59625F5E605F615A575A5853554E474945404245414547464B504E54514F56
5254584F5455555A5A5C5E5E6162626968697370717C74757E75757E7473827574897978
8B79768B79748E7C75917E788F7C7696827C98867E99897E99897C9A8C7F998C7E9C8F7E
9C8F7EA295839F917FA09383A19989A59F90A9A396A4A195A9A69CAAA69FA5A39BA8A59D
A8A59CA9A9A0A8A9A29C9D968E90858A8C80878A7C888C7D898D7E888E808B9184929990
9AA39DA5AEACA7B1B2A3ADAEA4ADAFACB2B6ADB1B6B1B5B9B3B6BAB1B6BAA6ABAFA7ACB0
A1A9ACA7B0B2AAB1B4AAACB1B5ADB3BF919B922C38A8131DB00C12AF090FAE060DB2070F
B40911B0060EAD080FA10E16972C398A5A7C2B336E072A7118437F577D9F7E9BA7849B9E
8A9C9D8A9999899897859393939092743F487C0F1A8D040E8F020A8F030B87060C790A12
7D27337C445768496355496C4043692E39671A3066072C656993BAB6D2E6BAC7D5A092A4
814759790F1E8606107B060E7126343D2C4C061A4354749065838B62797B667A7B647676
6679766177725C75715A706F5A6F71566A730A1B3601113901143C071F3E274357435F68
4864664964615A6E6C1DA12000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00637C197D6252
655C5A5F5B586663626161615B5959524D4C4C464645404044424349474A525054525055
514F545353575556575C5C5C626161696768726D6E7972727C73727F7473837676837373
8471708E7A768F7B7594807995827B93817A96857E96887E97897E998B7D9B907E9B907C
978C789A8E7C9A8D7C9A8F7E9B9582A39D8BA59F90A4A092A5A397A2A298A7A59DAAA7A0
AAA9A0ABABA3ABAAA5ABAAA5989892888B7F888C7E878C7C898C7E8A8D808C8F858A9087
959D97A1AAA8A8B1B0AAB3B2AAB2B2ACB1B4AFB4B7B2B8BBB1B7BBABB2B8A7AFB3A7B0B2
A6AFB2A7AFB3ABAFB4B2ACB1C1A3AA98424DA31823B00C13B40C10B20A11AD060EB30A11
B20A0FAD0A109E0E169634437C587E212F6E09307628538B6E92AF87A1AA8C9FA18F9F9E
92A19E8C9B9A849493838F8E998D8F6D2831860B1791020D8D020985050D781A23744459
493F6519245B0C21610621640E316B2C4F814566956080A8ACC4E1B5BACC998395804354
76101E84061280060D711620623F590F1A44103056577687678184627A785E7472607573
6579776176745B726F5C716F596D6D566B7111263803173219364A3F5F6A4C696C4F6969
4E67654A64625C7170393F3C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0041A915806253
6B5E5E615B59625F5C6565635F5C5D554F514E4548484242474444474647515053575557
5150525353555555575C5B5C615F606A6766716C6B726C6B766D6D7D7274827477837575
82716F8F7C7A8F7C768F7C7593807A94827E92817B93867C96887C968878988C7B958978
938876938777938676988E7C96907C9A94809E97869E998AA09D919F9E93A4A49BA9A7A0
A7A59EABAAA4ABA9A5AAA6A3A5A29E92938B8E9085878A7D8B8F838C8F848E92888F958D
98A09A9CA6A2A5B1AEA3AEADA9B3B1ACB4B3AEB4B4ADB6B5A6B0B1A4AEB1A3AEB0A4AEAF
A4ADB0A9B1B5B0AEB2C2A9AFAA68729B202BAC0F17B20A10B70C10B30A11B10A11B0080D
AD0C1099101599424F6D557C172F6E0A34793361917598B088A1A88C9EA091A1A192A0A1
8E9E9D8D9D9C8396947E8D899186856D252B880A1494030E8D040D7C121C77475D1F2050
06215D1C3F7A2546840226625B82ADB4D2EDBDCFE6B8BED6A498AE8F61767A293B7F0E1C
85050F82060F73141D73455D1E214A0A26555C809D64828C99B1B4687C7D5E73745A7370
6177756377775F73715C716F546D6A546C6C314C513250574664684C6B6B4F6D694F6A66
4E68654966654761633D4A4A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048AF1B856858
6E606068616067635F6968645F5D5B524A4C4B4044493E424C4346474143504B4D575554
514F4F504E515553565857595C5A5A6661606F6968716C6B756D6D7B7170807474867979
8F7E7F927F7F917D7A907E7791817990817A93817B928079907F7491827595877A938678
958878928573948573968976928773958B779A92809993849794889C9990A1A097A8A59E
A9A7A1A6A5A1A8A7A4A9A6A5ACA8A5A29F9B9A999496989193968E999D969AA098959B95
9BA29E9CA7A2A2B1ADA3B2B2AAB7B6B0B9B9ABB0B4A7B0B2A4AFB0A3AEAFA0ACACA3AEAE
A0A9ABA7AAAEB3A0A8B8828C932C37AE1820B50E15B3090EB3090EAE080CAE080FAA0A0F
9A121795425363517B133072093679426C9A83A2B790A2AB91A1A48D9DA08F9FA28E9E9E
94A4A48B9A9B82929182908F97908E743339870C1594040E87040A872E3A3F274A071B52
0E31668EAFD2AEC7E54F68888FA2BFACAFC4A08DA29161777E2D42831627880A1588060F
7F060D75182276485D2A2853041C4F28496E9FBFCE7D959C788E91697C805E72725C7471
6177756379775E74715A726E556E6A576D6B5269684F68664D68664D6866506D694D6A67
4A686A33515C0E2A3A35474F0ACA0900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049B31C856B59
6F6462625B5A696561686660645F5E52494A483E404D42444E41444E42445246495A5154
534F50504D4E5553555958595D5B596762616F6769736D6C78716F7B707182757787787B
8F7D7F8F7B7C927D7B93817B93827C917F7B927F79907D758B7A6E9080728C7E6E8E8172
8D80708C7F6C91856F928771928771918671968A78968E7F918A7E9894899D9991A8A59F
A9A7A2A5A5A0A6A7A3A8A8A5ACABA9ACABA7A5A6A1A3A7A2969C969A9E999B9C979C9E9A
A5A9A7A5ADAAA5B0ADA1AEADA5B1B1AAB4B3A9B2B4A1AAACA1ABACA3AEAE95A29F9EAAA9
9FA7AAAFA9AFB788929336439F1923B00F15B20C13AF0A11AA060CA9080EA3090E940F15
96425363507C1330720A397F4A74A286A2B695A2AC9BA2A8999EA2959C9F95A0A1909D9E
8D9C9E8999998595948491928A8C8D8254597A10198F060F88050C83243155304E30355D
6A7A97A5A9BEADA6B98D7A8D8963778340548021378710248E08178D040E8A050D7B0A13
762632724D6B252858051D551638605A7A8D748B927284886A7E8065787A657876627672
6076725D75735C757257716D546F6A546D6A546A675168654F68634F6A6653716F49676C
2A4756051E3901173531455615971700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB71D80644A
6F635F665D5D6B67646A68656A6565574E51514548513E41492F324D3438534347564D52
5853574E4C4F5452555755565C5A586863626E6768776E6E7A706F7D71728576798B7B7D
8B79798E7A7A8F7C79907D79937F7C917B778F78748B746D8E796F8D7A6D857666867969
8D806E91846E91856E998D779588749488749188748D87748F8C7B918D819693899A9891
A3A39AA7A89FAAABA4A8A9A3AAABA6AEAEABABADABA2A7A49BA29D9AA09CA0A4A0A1A6A2
999F9CA4ADAAA0A9A7A3ACADA8B2B2AAB4B3A7B1B0A5B0B0A4AEAFA6B0B19FAAAA9EA9AA
9DA1A4B6A0A69649549A1E2AA81018B10C12AC080FAB0A12A80A11A20A0F9410168A3947
614E75102A6B0935784A75A18BA1B69A9EA7A69FA5AC9BA3A98E96AA8E96AB969C9F9799
9597988A94948896968693938A91939A828770222C830A1589040D840916882B3F834258
864D5E8542537F2E407A1A2E7E0D208808199107169506119208108309107A1A237D4357
54446915215904215C1739675D7C93788F9775888B7F8F926E8082667A79617572637673
6176736278765B737159726E546F69526B65536C66526A654E68654A67693D5B66153148
02193D00113A01153A294055169B1D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B81B7C5435
79665E645C5A6A66636D69686A6465594D51574246522D324312164B2024584045554C52
57555A4E4D525353555554555E5B5C68636570686B786D707A6B6E8373758B7B7C907D7D
8C7A788876748572708D7978927C798F77738D736E8B70698D736C8A73678A7668918170
91846E978974978974988974978975978B79938B78918C799A95858F8C7D8B897C929286
9D9F92A4A69AA7A8A1A6A7A1A9AAA5ABACA9AAABABA7AAA8A1A6A2A0A5A19EA4A1A0A6A4
A3A9A8A0A6A6A0A6A7A1A9ABA9B1B3A9B4B4A5B2B0A3B1AE9FADAAA7B4B1A6B1B0A6B0B0
AAA8A9A67C828C232DA4131CAF0F14B10B10AD090CAD0C11A60A0F980F129039446B5579
132E6B0D37774C71998D9AACA18E989F707C954F5B8B2E3D8B21318C20328C2C3B934A54
9B70769F90948D949686959594A0A1A9A7AB876067721E277F0A13890511880612830715
820915890C178A07128B05118B030F8B050E87080E810D137B1F277D4252634B68252959
081C58041E5E173A6C7EA2BF7D98A5A2B5BC798C9091A4A875888D697D7D697D7B627474
63777564787661777459726E566F6A536E69506B6850696A456068264156071E3E01133D
000F3D02103D01123B1E364F2A323400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058B91880512C
7B645A645C5B6C68686D6769675E5F5B484B5633374F191B460C0D471A1D5A4047564952
5754595455584F51535354565D5C5C66616370676A766B6E7C6F718377768E807F917F7E
8F7C798F7C788874718F7A778F79768D75708B736B886E678B6F678970658B7769907F6F
8D7E6B8F806C9C8D779F8E77A0907B998F7C96907D94907E918E7F908D808F8D808C8D7F
96968A9F9E95A4A49DAAABA6AAAAA6ABAAA8A8A8A6A6A7A5AAACAAA7A9A8A4A9A7A5ABAA
A4ACAEA0A8ABA0A8ACA1ABAEA6B0B2ABB6B5A2AEACA9B6B39BAAA79EACA9A2ACACA5AAAC
BEACAF9951589E1A22AC0C14B20C11B10A0FB20C10AD090FA00E13912E387D628119336F
103779586D9A9A8BA09257648A2A378D1421920D18980C189C0D199A0E19960B1793101C
8317249959629D8E928A9598839496828D918483868B6F7374383C74191F7A0C157E0813
7F0611850814840912810912790D18771D267A36407C50635B4C6B282D5D0D1C550B1C57
203163556289535F7B9BA6B78A939CA4ADB37C8B8F6E81856A7F81667B7C667B7C627676
6479776377755D7371596F6D56706C546E6D4E6C6E375461102A4401153B01103C031141
000E3F010D3D00113B1328452C373E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059B71587542C
80665D6A63636B696A6F696A6E5C5F5D393C551F23571C1D4A1B1B4C2F30524144554A4F
58545758575A51505552515659565968636473696E786D707C72718479788C7F7D907D7D
907C7B8F7B788F7A798F7A798D76748D757189716B886D66866B62876F628B7667877463
8C7A668F7F689A89739B897391816B958B769D97849592829290839192848F908395968B
93948B9C9B96A6A5A0AAAAA6ACAEACACACABABAAAAABACACADB0B1A8ADAFA5ACACA1AAAA
A2AAACA2AAAC9EA8AAA2ACAEA5AFB1AAB4B3A8B4B1ADB9B69CA8A59DA8A89EA7A9B2AFB3
BB949A922E36AC141BB60E14B40A10B4090FB40B10A90B1198252F966A8922336D1C3D83
5D62989263848A293D9513219D0E189908119609108E0B14840F1884161F89101B940D19
910B187E1622986C748A90957B9395819698A5B3B48C9194837F837561696844526B384C
6E354A713449733C4F71465A694E6753496A2F345D152153111F54252F624D4872654B6E
744A64763F5377384B76394877455084616985777A767C7C7484836C7E7D657877647776
657A766478765D73725A6E71546C714A6772254157051C4000123E010D40010D40020E42
010E41000F3E00133910284032434600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00936139
856B6371696B6E696A7164666C4B4E571C2058171A5524234D2F2D4C3D3C504544554B4C
584F535D555A58535757545759575A686367736B6E756B6C7C7371857C7A897D7D8C7A7A
907A7A8F7A79927B7C90777A8C7274876E6C866E69846C65836B60897262846E5C867360
8E7C678E7E6696886D8D7D648B7A60978A7399907D9A968894948891938691948995978E
99999192928B959691999D9BA4A9A7ACAEACA8A9A8ABACADA6AAACA5ACAEA7AFB1AEB4B7
ABB0B3A1A6A99DA5A7A1AAACA3ADAEA3AEACA3AFABA9B5B1A2AEAAA2AEABA5ADAEB8AEB2
B0747E9B1C28B20F17B50A10B80F15B20A0FAF0C139A141F995772393B711F397B5A5189
853E6392182FA10D1CA20A14990A108B1119872933874A5A76566D6B556D8B5C6F811F2D
8D0A15840C158244525B61716787937A959ABED1D49EADB178888F6C7B863B4B601F2C52
1A295A1B275A1A2A591222560A1D540A1E5710225934396866507575405C742238780F23
7E081B8207168206168006157A0814720F196D2229815A5C8D85847D86876A7A7C657777
677A78617574596E70566C753F586B162E4F011341010F43010C41020E41010D3F010E3F
02103F00133C0A233E334F5C43525500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0096663B
88716771696B6E6566765B5E612E315C1B1C551C1E5733344E3B3B4B40404A3F41554A4E
5A4F5660555D5D535A5E585C605A5F6C636873696C766B6D7F75768A80818A7E808B7C7C
8F7D7B8F7C788E7A768E78778A71727F67667E6964806A6282695D886E5D8C735F8D7863
8877608C7D6595886E94856998896DA0937A97907B99968792928593958A8D90868B8D86
8F8F898B8B868B8C86878B869BA09DA6ACABA9ADADACADAFA9ADAEABB3B2ADB6B7ABB3B5
A5ACAFA5ACAFA2AAACA3AEAFA3AFAEA7B2B0A8B2B0B0BAB8ACB6B4A9B3B2A7ACADC1ABB1
9A4854A51723B40C14B80D13B40B10B00C11A01019953E554A3B692B3D75796C9A853453
9B1528A20917A108149410197F212E76445D564D7427376B0F2A6310295B5148687D3143
890C17890B1482394E303254587B9574909A83969D7C8C9476899167808AA3BDCC5D7799
032558305887668CAF6D8CAF6A7EA4595C7F705673703049761529800A1B8705138D040F
8F020D8E010A8B010A8B010B87020A82010A7C060F6E12197D4A4E7D72746D7778687879
62757564797C5A727D2F4860091F49011448020F48010B45010C42010D3F010E3C01103D
001339122F4936576149646846565618971400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A17646
827164726A6C6D5B5C653E3D6029285F28285833354B373A493D3F4C42434B4044574A51
5C4F5660545B5E545B635961655A626F626974676C796D7085797B8C80818B7E7E8B7B7C
907F7E8E7C798E7B778C767388706F806A687C665E7C66597D6658876F618A73638A7864
8675618B7D699488739A8D78998B749C8F7A99917E9996859291858E8F8391938894968A
8F90868A8A8289887F8989818C8D879EA29DA9ACA8A9ACABACB0B0959D9CA6AEB1ADB5B8
AAB2B5A7AFB2A3ADAFA3ADADA4AEADADB7B8AAB3B5AAB2B4A3ACAE9EA7A8AFAFB3BD9AA2
8E2A37AB111EB40912B80D14B30B11AC101792263679587B3743738777A28835509D1322
AA0D189E0C178D1B2987485F574C78182E6A092A6E1038752F54826173938C7085791E2C
8F0B168A0B1681395128285235567772919E768F93A6B9BE94A9B52D4A5CAACADAACC8DC
3E5F7E678BA8B4CEE0A8AFC08C768A79384E7814278508178C04108D020F8D010D8E020B
90010B8E010A8B00088A020987010885020A83020A7D060F690E1782565C767574687779
61767C5067771D375502174501124801104901114A031046010D41020E3F00103D02193E
1A3B5140626A4868674A646447595916961400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A67744
8671627E6D6E67464663322E653430643F3D523B3B473B3C44393B4A3D414F404654474D
5A4E525E54595C535A60565E62595E6C6267766C707B70747F7478867A7E8C7D808F7C7E
8E7B7C8E7B7C8D7A79887472826C6B7D65637D645E7F665A7D6558846E62867164877566
8878668E7E6E9084719185719386739D917FA19787948E80908F83999B8E98988D97968C
96938A8E8B838A89808B8B818788818E90899B9D97A4A6A1A9ADABA9B0AFACB5B5ADB8B7
ACB6B7ADB5B7ABB3B5ACB5B7A8B1B3A9B1B4ACB4B7A9B2B4A5AFB1A6B0B2AEADB1AE828B
8E1F2BAC101AB50B14B40A13B20D159B121C9E5B71474066877499893650A01526A90C15
9C101791304171486E2E38720E347B0C3979335D8C6989A68091A39A88947E3944860E1C
920912830D188048641B2252476A8D8FAEBD546F78B1C9D0C0D5DF718A9983A0AF9DB8C7
768E9F6877888B8291835564751E2E8009188A030F92020E91010A8F000A91010B90000A
8E01098A00088A01098901088501078301087F00057F010974040C6D242A82707366767C
465F73122C5002174901114A010E4A01104C01114C010F47010E4002103F01153B1D3E52
3F676A496B684663614D666550626217991700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA23
8E6E5D8464655A29286E3A3575514D604948503D3E493A3C493A3E493A414D3F4653464D
574C535C535B5D545C62575F635A6067606377707272696C83797D83777B897C808D7D80
8B7A7D8C787A8D78788974728167667F625F7E615C7F635C80685D846D61836F61867365
88756893827396867591826D9C8D7B9C8F7F9E9384938C7F91908497978D9594889A988C
9C9B909091889091898C8D858A8B848689828F938DA2A5A0ACB0ABADB4B2AAB3B1ADB7B6
A9B5B4ADB8B9ADB6B8ABB3B6A7AFB1A9AFB2A9AFB4A8B1B4A2ACAF96A0A7A6A4ABA4717B
911926AD0F18B00911B40E15AB1018A0333D865A6E876684913C56A21727AF101A9E111D
8D35486A537B1D367409377D22528A6389A9809BAB8A98A09B8B918A4853871320950713
9107117D192A65446D0B20595A7EA6B5D3E47E97A17D959E90A7B0748B99536E857A96AB
9EADBD7D6D7C793C4B7A121F8506128A020B93030C93020A91020891010A91010A90010A
8F020B8C010A88010886000983010982010683010782010A7B040C630D156B505C42546E
09244F00174D00134D01114D010E48010F4901124B00124701114202143F0F2A443F6569
4A6E6B4B6A654863604B6762556A671CA11D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B91F
9166507E53535C2727764A476D55535A4B494C3C3B44353547383C4B3D4450434A52464C
584D545B515960565E635A61675D626A6063786F717F757982797C837A7C857A7B8A7C7E
87787B8E7C7E8C78788A73727F6462785D597C615C7F645E846960866F64867062897466
8B786A907D6F9B8A7A9685729C8C7B9B8E7D9B908197908295938697988B96978B9C9A91
9C9B929799908F92898D918892968E8B8E88898F89969C98A5ACA9A7B0ADACB5B3ACB5B6
AAB4B6ABB5B7ACB5B8ADB5B8A9B0B3AAAFB3A9B1B4A6AFB1A3ACAF939AA0B1A9B0945761
941620AF0E15B40C12B30F15A21517BD656AB67D89953F4FA11826AD0E16A2141D9C4258
6854811531750B3B7F3664967396AF8BA0A88F979CA28E968A475387142397081696040E
880E1985435E28275E06276540688D7895A57A9199748B9799AEB9B2C6D7223D5C314A6B
7B738A6F31427B0E1C88040D8A02088F020A93020B93010B90000991010B8E010A8A010A
87020984030984040C84030D84020B84000986010983010A7A020C61081A472A480A1746
01154E01145201135201125001124A0013441129521D375F01123F01153A2D4E5D4A6C6A
51706A526D6A4C65624F6864576B6922A72500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057B81C
9763467B4B455D2F2D765856695A5B574A49493B384737354838384B3C3F4F4044504147
5749515A4F565C5359605A5E655E616A60637C717481757883777C84797C83777987797A
87797A8877788B76768970707F6463755A56765D587B625C816960856F62887063877061
8C7668907D709987789D8E7C9E91809D90809B90829A938795938793938A95958E9B9A94
9B9B9593958D8B91878F968B8F948B8D918A858B858F9792A2ABA7A5AEACA9B2B4A8B0B4
ADB5BBACB6B8AAB4B5ACB6B7ACB6B7A9B2B5AAB3B6A7B3B4A3B0B1A5AFB2BAB0B69D5B66
9D1824B20F17B20C11AD1014A22325E68E92AB4F57A11B26AD1116A31419A2475765507C
1130740B3C7E4F7BA5819FB391A0A99B979EA4848C883C4A88122095061397050F8B0A15
88384C4E3E690A2462143A6D61869E89A2AABACDD65A76876D8B9DBFD6E67F8FA5675F76
692F42750C1984030D8A020A8D010790010990010992010A9001098F030C89030E7F0610
740B1270131A711B2372162175081283041085010B7E01097206134A09261A0F3D05134D
001252011355001254001650061F492847614A667D1A325100153E051A3B3F616D4B6C6A
53706B516C6947626249646552696B3E494700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0D
995D386E3C3171504B776765645A5B5448474C3C394A38374736364E3E3F5245464E4243
574B4D5A4E535F545960565B665C626D61687D6F7780717982757E84777D85767A87797A
8B7B7B8B787A89747686706E8168647A5E597C615A7B625A806A5E846D60886F63907869
8772638B786A8F7E6F968878998D7CA094849D93869692849394879C9C9398989095968E
9798919599928B948A98A3999BA39A8B908A8C928C8E97939CA6A3A3ABACA9B1B3A9B2B5
AAB4B6ACB6B8A9B4B4AAB4B4AAB4B6A4AFB1A6B1B3A6B2B3A6B4B5A5B0B1B6ADB2A3616C
9D1822B10B12B50E13AD1216B9353AD15F679F1A24AE1119A711199D39496E547C142F73
0D3E7F4E7AA38DA8B989929B9B8D959B6975862837921020970712950711890E1887384D
594470102764133A6F8BAECD6A889777939EBFD7E0A7C0CE657F8F9AABBA958A9A703645
750D1A82020C8700088900088E020A9001098D00088C020989040B7F08107717237C3B4A
724F63594A64453F5D4D3F59734052710C1B7E030E77020F5A072224083707104F001357
001354011553011A4F18385D395C6E4D6E783F5C6E04193B0720470A254040646D4E6D6C
53706C4664663A5761142F401F3B4944545900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
92572D744A3C745F5D736B6B635C5D534745503E3A49353240282A4E3A3B524445504647
5247495B4F5261545A60535A675A616E5F667E707781747B85787F83787D84777A897A7B
8B7A7B8B787A8B78798874737C6561755B55775C537A61557F685B886E638970638D7666
8B78698D7C6D8F7E6F96877A96897D988E8299918496938493938598988D97988E9A9C92
9396908C938D9CA7A3C5D2D0C9D3D2B6BCBB8D93908C948F99A29EAAB3B1A7B0B0AAB4B5
A9B6B7A7B6B6A8B5B6ABB5B6ACB6B7A9B3B5AAB5B7A9B4B5A9B4B5A4B0B1B5B2B4A56D72
9D1E24B71217B80E15B00D13C9303AB41F28B3121BB0151D9D2A39875E821D33730E3B82
47719F8CA0B39C969D9D7981893E498B1A26960D199B071693091481121E87465B514370
0E2568082F704D769DB6D5E796B0BB6F89957E99A1829DA5788F998B8C987F505E781220
8A07128B000A8801088800068D01099102088B04097B060C79222A7B49595C4867292D59
102054061B5208205210224B51415B691B2D78061564051B31072F0E0F4C021359011359
0216530721512A4B6752727C5573784D6A741A365001183B27436308233B4465704F6D6E
4F6C6B39556208203C00143803193441545E08C80800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8E572676544474635F726868675D5E574846533A374A2728441D224F313857414855474D
564A4F594D545D51596556606958627060687A6D747E727882777D82777C827478897A7D
8C7A7E8A757A8B76788872727E6664755A56775B527A5E5480655B896E65907A6D8A796A
8D7D6D9384749285759B8E7E978B7D968D8196918395938396968796978B95978D91968F
7B837D7D87839CA9A89DACAEC6D1D6C6CED3888F908A918D99A39EA5B0ADA4AEADA6B0AF
A6B2B1A4B0B0A8B3B4ABB5B7ABB5B7A7B1B3AAB5B7A5B2B3A3B1B39AA8A9B3B5B6B28488
952127B51218BA0D15BB0E18BA101ABB1019B81118A91F269852693836681D3875546696
968FA7A177859547548F202E96111E9B0D15980A13890C178126367D54733336690D2A6F
0732723D66907394A88098A27B939B768C9678949BB6CFD57C89958A748271202D870815
8E030C91020C8F020A8C01088F020A8F0209850C10873D4754405B1D2858091F5906225B
11316037577A728CA5717D8E7C65716313206E0819450424170B4104115901135D011756
102C58405D755371785975775D797D385366021A3D122B4C3C58720218343A586C4B6975
3853660B224300113C020F3C0112332F435312961700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
915C277E5D49634C48715F5F6A5D5E594546522B2C440C1049121750292D563C42524048
574751594D565F535D65586168596073636A7B6D757D6F7882747C83757B827276867678
8D7A7C8B73768A7174897070806763765957735753795E577D625B866D65927B70928072
8F817197877999897A998B7B968A7B9A91829790839390829A988A999A8F999D95858D87
737E7A9FA9A8CAD7D8A6B4B9B7C3CBBCC6CC848A8F7E84828C9591A2ABAAA3ABADA5ADAF
ABB4B4A7B1B0A7B3B4A7B1B3A7B2B4A8B4B6A4B2B3A3B1B29EACAE95A2A6AFB5B7C1A2A5
8D2C31AD141CBB1019B70A16B50912BA0F18B31118B4373FB172857457797F597C934F69
922E41981C2B9F131FA00C199D0C18920F19821E2B824960584C73172C6606296D16407B
4C74997795A68298A082939BB6C7D093A8B7446173BCD1E2A8A7B67842507F0F1B8E050E
91020B92010B91010A90010A90020B8F030A800911783449281F470A2056193C694C6F8D
6D8D9E738B957A838C88747C6D2F396D091565091F2C052F0B105003135F01145A143162
4B6B815773785672715A76774D6A760C254500183C2F4C63445E710115380B2148183356
051B42011141010D3E010C3B010F361C2F46189E2200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D662E855E495B39367259596D5A5B583D3F4512134C090B5012144E2326543D3E524348
55484F574B525D515A62555E6759607263697B6C747F6E7782717983727A807074857678
887678857273897273886F6F8166647B5F5C735652795C587E645E876F688470658E7C6F
9383749787789787789B8C7C9486789E9286958E81959283959486949688989D927A827A
78837F8A9695C2CFD1A8B6BCB2BFC5A9B3B98A9194848A88949A97A4A9AAA5AAADA7ACAF
AFB4B7A6AEB0AAB4B6ABB5B7A7B2B4A4B1B2A2B0B0A6B4B4A7B3B4A7B1B3ABB4B6BBACAE
974B50A11720B50F1AB90F1AB60D15B70F16AE0C13AF242FAA3F5089263E8C1C319B1828
A51420A80F1AA50A159F0D188B101D7E2A3A8A637F454474102A69052E711640756085A4
7694A295ACB192A6AC80919DC5D4E0A5BACB29455B93A4B79586946E2230890C1690020B
91010A93010B92020B8F030C8D010A8A020A86050F791B2C63405B35415E6784987B98A3
93ADB2859297887C8379454E6E0E1B7406155606221B0638050F5201125D0117532F4E6E
5B78805E76775D767459757C2A465D00183D0A26434563724A6572061939001340001242
000E40020E42000C3D000D3B010F3710233C1DA52A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A16A2F885C465C34317356566F595B593536480B0B570F0F4E0D0E4A2020553E3F514246
55484D584A5161535D6556606A5A6275626A78656D7D69717F6C747F6F777E6E72827475
847575847374877273876E6D816664785C577659547A5E598066618670698A766D907D71
928273918172908272928575978A7B988E819A938696928598978A999A8D9A9C927D837C
727C798994939EA9AC8592998D9A9F828C8F888E91898E8EA0A6A5A3A9AAA2A8ACA7ACB0
ABB0B3A8B1B3ABB6B7A9B4B5A8B3B5A7B2B3A4AFB0A8B3B4A8B2B4A9B3B5A7B2B4B1AFB1
AD7D818F2129A9111CB10D1AB30C14B50D13B00A11A80D17A0111EA31221A7111DAA1018
A80F15A2101896131E8A25358D4F66705A7E2E3A6E0E2D6C0B32712A52825F84A17F9CAB
829BA1BACDD2B0C4CB6D7F8CA5B6C2B5C8D5758B9C7D87988C6D7C6F131F89080F8F030A
8C01098B040B83060C800B137B081080050D87040D7C081575303F9F939FA0B0B88DA2A7
ABB6BC8B7E867D4A557116227B071373041549092A11084003105501165A0421524A6A7F
5C77795D75755A74774866760C2647011A4024455B4C6B73506C740D213D011341011043
020F43000C41010E3E010E39011036091D38323F4500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A902587553D60332E765653715655522221520A0A590E0E4E1212532D2C584241554647
594A4E5A4A4F6151596756606E5963775C6577555E704E5677606878686F7E6F73827374
8374748372728772738B72718469677D5F5A7C5E577F625D836B6686706A8B776F907D72
8F7F719082728C806F928674948A7A928B7D9A95889693869594879694899E9C958A8B86
6B706C737A7A6972757981848F98988289878B908D969997A7ACACA8B0AFA6AEAEA5ABAD
A7AEB1A8B1B2A8B4B4A8B4B4A9B4B5A9B2B5AAB2B6A6ADB1A6AFB29AA5A7A5B3B4A9B2B3
B6A8AAAE6D74921521B11521B40B14B80D14B40E13AE0E15AC111AA50E17A0111895141C
8E242C8F3E4F8754706858812D3A6F0D2F6C0A33702A53845D82A17794A5AAC1C9A1B6BC
7A9197A0B3BCB1C4CE889AA680939C8C9FA6A6B8C08083907C4C5C7B0F1D8A040B8A0309
83070C7B1B2480415171475D704359702937760C15830611730B148C545DC7B8C09C939E
8E6F7D74303F760F1C82051280030D6D081B360932090D4A011357001B54294C6C5C7B83
6078765F75794D6876153151011C44102F4D446771516F6F557073243B4E02163D011142
000D41020F41010F3D011036031939031B3339474E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
55B71B814C2F6A3D367B5B5872524F531F1B510D09541615582C2D513736524040534546
584A4E5D4D5464535B6B586071525B6B3A4465242F7036407D5B6274626878696E77676B
79686A8571738973748C7373856A687F625E7E605C7E615E81686489716A8C766C8D7A6F
9180729181728A7A6A928574928A79918A7C99948897948894918696948C99989195958F
92958F878B87949A969396948A8C8880827D858883979C99A2A7A6AAB0AFA8AEADA1A8A8
A9B1B2AAB3B4AAB4B4A8B4B4A8B3B4A8B0B4A7AEB3A8AFB2A5AEB197A3A5A6B4B6A4B2B3
ACAFB1BA9298942733AE1622B80F17B51014A71B1F9E303A933A479247577F435888607D
6E5D824346771D336D0C326E123E75345C8A5E83A389A8B99BB4BB889BA2A0B1B5A4B6BC
859B9F85999F8EA1A6A5B8C178919E9DB8C4B5CFD96B707F723C4E820F1F8B030C86050B
7E1C257348602326510A22531229505049606E3542730A147F0611750F1DA45B6A7E3949
7318297E081885040F80040D7108126A263C261541051351001752193D62537886627D80
60787D516A7D173252011A4508284B3E6173516F7357716F57706F4E6671061D3C00113F
021044020F4200123C06203C314F611931423A4B500BCB0A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59BA1C814D2D784D477452526949454B221B4D1D1758322C553E3B4E3D3D4E3F4153464A
584B525F4F5866525B6D51597448506A212C670C166D1F277F5459705B61716168726166
7664677D696D81696E856B6F896E6D8468657E615E7A605C82696488706A8B736A8B766A
8F7D6F907E718977699385768F8577928A7E98918696928896938B96958D96978F9D9F98
979C939AA097979B959395908C8E8882847E8D908C969D9BA0A9A9A2A9ABA5ACADA1AAAA
A7B0B1A9B2B2A9B2B2A7B1B1A6B0B3A9B2B6A8B3B5A5B0B1A6B2B3A5B0B2A5B2B4A8B6B8
ADB1B4B58B9292202BAE131CB40C12AA1217B352628363874F55823E507D253F6E17366E
10346D1940773157884E759B7195AE84A1AE869EA59CB1B5A4B7BB92A1A690A2A58B9DA1
93A8AB849B9EA3B6BBC3D7E33A576D55788EADCAD69198A6703F4E7F101C8D060F85050F
8831413D25470E23563E5F907E9DC19DAAC096788575232D7E050E84030F8109167E0614
83061284050F78070F6B141C6835463F2F500A13460215501333604A70865F8089627C88
446078122D54011A4808244A3E5E7255747A59737458726F57706E596F73374E6004193B
00133D01163F102B4936576447666A2C454E374B5016991600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2DDD0D7E472187554D62333474504C52342B53372F55403952433F4B40404D404353454B
5A4C54624E5867444F703C4767232B6F17206E0911650F157D4B506D555B726065726265
7B696C7A666A7C656A775D61876D6F8469687F63617C615E80656289706B8A736D88746A
8F7D738F7E718D7D6E91837595897E968C82978F869892899A978F99978F98999092948B
959A92989D97979C978C918B898C8684877F979D96949D99919B9B8C9697959E9F818B8D
97A1A2A1AAACA7AFB0A8B2B2A9B3B4A7B1B3A6B2B3A2B1B19CA9AA9AA6A7A5B0B2798689
95949AB8828B991C25B10F17B60C13A91420A75A78272F69134284406EA05177A06184AB
7697B681A0B78BA6B48BA4AD89A0A58CA0A38B9FA08EA1A48DA0A393A5A88A9D9FA4B9BC
C2D9DF6A848E839DA6AFC7D3728C9F607C91768D98959DA5825E687716208C081188030F
781120783E5A513E608F88A795849F87677B8449577C1C2881060E87020B88020A85040B
7B070D6C1019662C3B5038501F214606154801164F00164F1F3F6A4B6D8A4E6C852D496B
072353011B4F07254F395A6F5B777C5D76775B737356706D587270546B6B5A72773E5764
1C37482A4A5744646B4B696B4D6969334C522E444821A62300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008345177E403164292677504C5C443E55423B56453F5243404F404050414357494B
5E4F53694C5457232C6A21286C171E731A1E690F1461171C6F4349664D55705D626E5E60
7665667B67697C666A7A626582696C806769806666836766886B6A896D6B876F6A88746C
8A786F8A7A6E8C7F708F837496897D968B81978E859A948B99958D98968E999990999B92
979B95949A95969B98878C888589828C91898A938B7F8982808A867B86827B85847E888A
919A9E97A1A39FA9ABA6B1B2A6B1B3A6B1B3A2AEAFA2B1B1A3B3B3A3B1B2A6B1B398A2A5
AAA1A8A766709F1A24B60F18BA0E15AB101CAC536E393C7130609782ABC88DA6B492A6B0
96A9B093A7AC90A3A791A1A693A4A78FA1A48CA0A18DA2A39BAFAEBFD1D595A9AF94ABB0
B1C9D177929C7C99A07F999E93ACB77792A966829AC1D4E29B8F976E2A34810D1689050F
820410780B1B74192D711C33731A3075112577091880071182030A850208830409790E13
7E374467476026274A0918470218480C28522C4B720A244F011B480A245406205001194D
011C500E2D5641637957767C5E7778667B7C5E73735A727158716F57706E5A7374536D6F
4A686753706F59757254706C4F696930494F26404437443900FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4C16702E1764261D7F58535F4D475648425748434F3F3D513E405440425C4749
5F4648653F435F272C66212361191B6825286D34376B424565494F624B556551596B585B
7563647663647762647960647C63667F6568866C6E8369698A6E6E846A67846C668B756D
8B796F8B7B708F8375948777978A7B968D8097908598938C99958D999790969590989B95
919791949D979198948389837C817B828780777F7876817A77827A7A847F7B8280828A8D
869193929EA096A2A39DAAABA5B1B3A7B2B3A4B0B1A4B3B3A4B3B4A2B1B3A2AEB1A8AEB3
A999A0954B54A61721BA0E16BC0E14B20E189A283E705480274B7B7FA6BE96AEB49BAEB1
9AABAD97A8A997A7AB96A3A990A1A69AADB0A6BABB8FA4A694A8AAB4C7CC86999F889CA2
879CA298B0B68CA9B27B9BA5B8D7E636577A092F5C7EA1BCA2B1BA8A6F766F232C7D0E19
82060F8404108003108004127E04117E04127E06107C060E7B040B7F02097B060C863844
49324F0F194803184B1029562948665677886A8793455D70162E4C041C45061E48132C52
2E4B68506F8058787C5F7C7C617B7A657D7F6277795F74765A7273597072587072526C6B
49666256716E536D69526F6B4C6968223D442441463C4D4400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0099591E642307652A1F7E5753624E4B56484353443F513D3D543A3E5E3D435E393E
5E3639693C406533365B28296D404069424767494E654E555C4A525F4C56634F58665258
705C5F7461637661647C62677D62667E636685696C866A6A8A6E6E896F6C87706A917C75
907E758F81779084779487789A8D7D9991839792879A968E96948C9A98929E9E99969A94
898E898F97917C867E727D746D776F6E766F727C7676817C77817D747F7B757F7D7E8889
828E9086959592A1A195A4A4A5B1B2A4AFB1A7B2B3A5B0B195A2A4A2B0B2A4B0B3A6ADB1
B29FA7904048A9161EB90C12B90A10B50B129E101F9750722C35636E92B293AEB79EAFB3
9EADAF98A9AA97A6A996A4A997A6AC9EAFB3A4B7BB899BA292A5A98FA2A597A9AB92A2A9
90A4AAC2D9E36182983159739CBED557779510345B3D657E9BB7BDB4B8BC91777F763B46
6B1D286A0E1C6C0B17680914680D176816206A26307C3A44812D3776050E77070F7E3C4C
25183B0E194725335877869E778591636D73676D70676E715E6D724F636F50687557717C
5471765673735A78755B79765C7A75627C7B6077786074765E77775B73755A7174546E6D
4C6A6753706C4E6965526E6A4F6C6D122D352E4B50485A5000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007483155E21046C3730774E4F624A475A4B455845415A3D3E54282C5B252C612C33
65343B6C4045613A3F5E3D41654A4F654D56665059655159615159594951624F56634E54
6853586E585D755F63785F627D64657E6567866A6B8A6C6E8668698A6F6C856F6A8F7C75
8B7A7291817B91847B93867995897C9991839A948795928798958D9898919999938B8D86
777C747C817A737B736D796F727D74737E7678817A777E7B79817E78837F727F7A768381
7D88888592928D9C9C93A2A298A5A6A6B0B4A5AEB0A6AFB1A2ACAEA3B1B2A5B3B4ACB4B7
B4A2A8924149A9161FB80D15B80A10B70A0FB00F189A283E76567E3B537C95B1C599AAB0
9EADAE9AAAAD99A9ACADBCC19CAAAF93A2A694A4A790A1A790A4A790A3A7C2D5DBAEC2CE
88A1ADB4CEDC7B98AE3A5A767190A3819CAA8BACC0527A8DA8CAD2C2D4D9C0C6CFA69EAB
6D5E6E564359583F595A415D5743604D41613938583D3550723F517109147A060D8A3543
74455B62405967415364384761313C5D2B335E2E3362363A6A4B4E6C6062656B6B5D7170
58737058736F57746F5C77745B7773637D7B647D7C62797A607B79607A7C546D72476465
4665624868634E6C6753716E476169041E2D39575E4A5E560DCE0A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0049A80C5B2206703D36683A3B684844604B455D444161363758191D5F181E682930
643138542D346A4D555B464E5B4953624D5965505B64525A5F4E575A4952614D545F4A50
624C52664F546F565B745A5D775E5F8169688A71708D7072876B6C856E6B826F698B7A72
8D7B74927F7B93847B928579998E7F9890829D978A9C988D9A978C918F8882837B797D74
767E74737971737C73727D74727C7478817A767D767C837D78817D78827E77837D7A8683
7782827D89898998988D9D9D9AAAABA4B0B4A2ACB0A4AEB19AA4A79BA6AAA2AFB1A9B1B4
C3AFB68C3B45A4141DB80F16B90B13B90C11B70D14A211209E506D3F3B657893B297ACB9
9BACAE9DACAF98A7AA99A7AD9CAAAE97A6A890A2A2BACCD0ACC1C6899FA6B5CCD399B1BD
6E8797879EAB97ADB99BB4C66C8AA09BBACE82A7BE235168ADD3DFBDD5DDC1D4DEC0D1DE
B2C5D46D8399334A69172F550B234D091F4D0F224D413A5B64283C78081581030B7F0B16
740F1E6C09196D09166D07136C071269050E65050B63040C5F0A1258171E6743456C6666
5D6C6A576F6D5B74726078765F79755D7774607A79627C7C5D7A785B7779344E56224146
40605F44625E49686449676C1B354700163018334347605D1DA01900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DAD0F6025076B342B67322E6E4642694A455F3332591A1A5D10135F13185F2327
60363A6043495B474F5A49525F4D58624E59645058604E555A49525747515C4953604B53
5F4A50614B506951556F5559785E608166678A6E6E8D70708A6E6F87717084726C8B7A72
8C7B73917F7895837A9A8B7F988E7E99928495918599978B969387817D747E7D757D8079
727871727870727A74737D78717C77737F7A79847E76807A77817D77827F75807E768282
7682837B88887C8B8B85969696A5A79AA8AB9CA7ABA2ACAF9FABAE9DAAAEAAB5B9ACB3B7
BCAAB191444EA2141EB30C13B80D12BD1015BA0C13AE0B15961B2E88587B3E4D7290ABC2
99AEB59BAAAF98A7AA99A9ADA6B7B99BADB093A7A9BBD0D49AB1B689A0A58AA2A795AAB1
9EB6C089A1AEB0C8D588A5C0183D693F6A91618FAB5E899DB8D9E3C0D7E0BFD4DFBAD0DC
BBD1DCBAD1DEB2CADE9DB0CB757E9A625C78664D666E3449710D1C82051086010987030C
83020F7E010D7B010A7600087301087201076F01057002086E020868030C5B090E623135
6E6365616F705B71705E75765D767357726E5873715D77765B78765A7678344E56153039
426364466362415E651D364B01153301103101132D384F5523A82400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0054B4156B300C592012652F286F433F6C3F3D5C1C1B6111116614165C171B6C3E44
60454B5E495058474E57484F5D4B54614C535F49505A454D59444F5946515A49535D4953
604C51634F52634D4F6C545774595D84686C8A6E708F737488706E836F6D8875728D7B73
8B7A6E91807694847B988A82998D8397908498948899978A828074807B71827D787F7E78
757973797E796E7674566462566664516260586A686A7A79758281758081747F80758182
7782837A85867B898978888889989A99A8AA9AA9AB9CA9AB9DAAAC9BA9AD9BA8AFA0A9AF
B6A9B0954F589E1720AE0910B50A0FB6080CB80910B40910A60F1A96334B644D725E7699
92ADBE98A8B19BAAB09AAAB0B2C5CB9CB3BA8EA5A98DA6A992A9AD95A9AE8CA4A7B3C9D0
A6C4D46388A383A5BF7193B2052D5B14426C6790A7B3D3DFBDD4DFC1D7DFC1D5E0C0D3E0
B8C9D6A6ACBE8E869B785C726B384B661D2D6A0D1B79081782030F87010B87010789020C
85020C80010A7C010A7601087401087301097001056E00066F00076C000867020859090E
63383C6B6A6B5B6F6E57707058737055726E54716D55726F577471577472455D640B2330
3F6068324F580E243B011034000D32010F3101112D1A303A327C3500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002DDC0C71380A4D190463342C7F53505B222063171660110E651F1F5B282A64444A
59464E58474F58464E57474F5C4B525F4B526048516046525E45505B45505B46515E4A54
5D4A4F624F52634E506C555870585C80666A8A71748C757487726F87736F8B79758E7C74
8C7A7092837990827992857D90877D958E839A948A8D887E7F7C727F7E747D7C757B7C75
798179626E6959686660736F687A766677765267674D6264677979748281748280758283
7681837985877784857685857F8F9092A3A596A6A98F9DA197A5AA95A4AA96A6AB98A4A9
ADA6AB9B5F67991822B10D15B90C13B90A10B90B12B80C12AF0A119C10209A506C48466A
7A98B1B2CAD59FAFB593A4AB8B9FA6889FA590A7A98CA2A5B8CED2BED4DDA2BEC89CB8C4
7EA1B60C3656567B987292A77095AE5B89A38BB3C1BED8E1BFD2DDC1D4E1BECBDBACADC0
9482977C4F666923386D12257209177D051381020D83020D83010B89040D85020987010A
83000881010A7C010A7501087401097300097100067001077001076E00076B0206650307
530F136E5C5C5B6C6B54706E56747156737154726D54726D55736F53706C4C666D041D31
1C364F041934000E31010A31020B31010C2F010F2C0B1D2A414D4300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007E410F521E07683A317A49465917146C1E1A5B14106A37346345465B484E
55464D54454C56454D58464F58464F5D4A545B44505D434F5F46515F49535B46515E4A53
5F4B51614C52664F536F56596B5256785F638770728F76758D74728A73708C7974907F79
93817A96857D92847A91847A91887E958D84968D86857D7674736C6A6F676E756D797F79
6F797550625F677A776E7F7A707E786D7D795C7070475E625369696B7E7A6E7D7A727F7D
707E7E717F807280817989887B8B8A83949581929489999D8C9BA098A9AC92A3A796A5A9
A6A8ACAC7F868F1A24B0121CB90C16B90912B70B10B6090DB1080DAD0D1793172A8E5A77
515B7999B5C49DB2B890A2A78BA0A3B1C5C7BBCFD29CB1B6ACC3CA9AB6C45E7F907F9EAA
7C99A67795A982A3BA7E9DAFA9CFE42C5B768EB8CBBCD5E1BDCEDAACAFC1968399855168
7826397A11217B05137D040F7C000981010A83020980010981000983010985020A850108
8401088402097E01087801077401087401087301067201067101067001076C0105690105
59060A5C393D556064526E6E547370526F6C52706B52706B4F706C4E6C6F3D5867041838
000E34010D34010C3300093101092F010B2E010E2C0314243C484300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0081420D5A240B663329793D3B651D1A6E2922652F2C6B4949634E5356464F
54444D55454E55424C59454F5C485258454F563F4B58404A59424C5E47545B46525C4950
604D525F4B51634D546F565B73595C795F63846A6E8C73748E7372896E6E8F78778F7C78
907F7893817A96867E8F83788E857B91897F877F777A776F656762656E6A5B6561777E7C
5661625063646677786D7A7A6F7C796A79765F7372475D604F6566677B796F7D7B768080
747E807481827483837383827E8E8D829392778A8A91A2A392A2A499A9AC8C9DA094A3A7
9BA5A7BB9EA48B2732A71521B60C18B70811B60B10B6090DB60A0FB40A13A80F1B972A3F
835F795E6E8391ACB697ACB18B9FA3B9CCD1BBD0D7A7BDC58BA2AA8DA8B088A5B0849EA8
87A1ACB3CEE35B7EA4406A9477A5C534617EB2D1E7B0BCCE988DA0865C707A2A3E841526
8A0A168A050E87020A8102087E01097E00087F02087D01067F010784020A840109840107
83010582010780030979030A7303097003096F03076E01066E01056E00066A0105670004
5C050B512532343A45506C6E53716D54706B536F6A516F6D4C6C7329465B071E3F000E39
010A36010A34010A3100082F000A2D000E2E00122A0012223846460ECE0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008649105F2A0E571E156B27236A241F6C36306E4D4B6D585C56474C53454A
55454E50404953414B57454E5A4A515D4B5259444B574149533C4758404D57414C5C4950
5F4C51614D5365505770595F765E61795F63886E728D75748A72708D7473907A788E7C77
90817C93847E94857E92867F8C837A8A8177807B6F78786F5F6660626D69646E6A7A817E
4B56574F62646173756775786573765D6F70586C6E44585B556A686D7F7B75837F778381
6F7C7D6E7C7E738283738383748485778888788B8A8194948A9B9D8C9C9F8B9C9F94A4A6
9AA6A9B9ACB29A515B981A26AE0F1BB40912B80C12B70A0FB50B0EB3090FB00A13A61220
9A3C506A536DA8BED4B7D2DF96AAB299AAB28FA4AB899DA78AA0A896ADB4BDD9E59BBAD1
7D9EB984A4C8062B64042F694973989AB4C9A6A4B88C667E7D344C7B12268909198F0411
8E020C8C02098800088200087F01097E00097D02097D000681000887010A870209830309
7E040976070E6F0B14660F195E161F5D19235D161E600B1468050B6A0107690104660005
5C040C542737161C2E4D696F506D6A516D694F6B6A3F5C6916314C02163E010F3F010B3B
010936020934010A2F020C2F00102B0B263726454E0E252E2C3D3B21A11A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0064790B642E0E54190B6120176F38317855536C585964555755474A504447
53434953404856414B54424B56464E56454C5A474E59454D553F4857404B57404A5A464D
5E4B51604C526650556B5659776365786164866E718A71728B73728E76748D7672917F79
8A7C778F837F908580908580908680837C727E7C6E7B7E706C736A68706A737973777C78
495655485D5E596C6F5B6D7256696E53686D485E6241575A6073716F7E7872817C6F7E7C
69787B707F836A797D7887887A88887B8A8A84959581939480919393A1A595A4A795A4A6
9FADAFADAEB2AF818A83222DA31621B30B15B80B12B80B11B50A0FB30A10B20911AE0B16
9D142492445C685E7A778DA28FA4AE92A5AA9AADB3BFD3DCB1CAD694AFBCA3C5D91C4369
244D756F91B048668B4F689178829D90798B8644597D182E880B1E8B021191030F93030E
8F020B8D010A8A020C8400088100098001087F010880010883010889020A830209770C12
72222B733F4F684861544260453C5A3F3956463952674151590D16670308690204680205
58070E512D4209142C4B66714F6D6B4D6A68425F66061F3A021541000C4000093D010839
010736010835010C3001142C18353F305454375A5728424224373125A71F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0041A2056228064F1304602C2173534C705F5D685C5B615455574A4B524144
593D44512C364A283159424A57454D55444D5B48515A454D553F4858414B543F485B484F
5E4B50624D526954576C58597461627763647F676A876F708A73738D7775907B77917F7B
8D7F7B8B7E7B8E817E8F837E897E777E766C7E7B6D7D7E7176796E72766E7679717B8079
5E6A68435657475C60455D61425C60415C5F3E585A516768697A7973807D727F7E697879
6B7B7E7283876F7F838391938390927987898897988898988191928E9C9F99AAAC94A6A7
A0B0B1A7AEB2B7A0A99C5A66901C27AD0D17B50A10B50A11B30A11B40A11B40A12AD070F
A70A15911122944F64928695BDC8CFA3B4B79CB0B5B8D2DE6C8EA17B9CAF80A0B252728A
68859F839BABABB7C9A499AE89586C8025378B10208F041391020E8D000A8E010991020B
8E010B90020D8A010B88010A8402098101097D0209810209830106820208720811804454
513E5E1E25540A1E53051E54031E4E061F49102241544357510E1A630208670102640206
55162036273E081B374966734F6D6B4E696749626A021635021040010D42020B3E010839
010936000B31071E3623454E365A573D5F573E5D56354F4C1A2E2735792B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004AAA0C5D1F0051190962392E735D557269636B615E6358575D4D4E584045
5329304409115522295C3D4353404857454F5A464F564048513B4458424C55414959464C
604C536752586B575D705C5F7460637C656881696C8970738972718C75758E7879907D7C
9384818E807B8F847E9086808379727D746A80786E7B796D76776C7B7D747C7E767D817A
757D794F5E5E3E515440595A415E5D496362536A686275726D7B7A6E7A7773837F6D7D7B
6676776B7C7D6F7F82818F918290908392928B9A998695948796968B9C9C889B9C8C9FA0
9BADAEA2AEB1ADA8AFC09DA793414DA1161FB20C14B30A11B30A12B60B13B30A10AF0910
AE0B13A30814941826A45E69D7C4CBC9D2D58DA0A598B0BB5C7B8B7E9CAB819AA4BCD0D9
C3D1DBA6A4B28B6D7E833B4E8415278F061596041096010D94010C90010A8E010991040E
8E000B90010C8D030C89040D7E060C75080F891E257D07107E030B75050F76344646385F
06195402205E1536682F4F7544607C55677D605E6F5227375A071166010765030458090F
5432420F14330C26434767744F6C6C526B6A5068700C203B010F3C020E40010C3E000938
000F341730473559603A605D3A5E563E5F563F5E55354F4C172D28444B3800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052B2135A1C00511A0B6A40345E443C71635E6E63606658585F494B532C31
571A2251060D4E0F135F383F533E4755444D58454E58424B533C4457414958444A59454A
624D536A565B6D5B607563687761657B636783696D876D71876D6F8B7273897173907D7C
91837E90847C8E857D8D857D877F757E776D7F7A707C796F7A7B70797B717D80787E827B
7D837E737C79616E6D60716D5E726D61746F6878736C79746F7B766E7C778F9E98B6C3C1
B3C0C18F9D9E7B888A7D898B8695959EAFAE97A8A69BABA997A8A793A4A593A5A89BAEB0
8EA1A39CACAFA3ACAFADA6ACB0868D8D242BA90F19B10A10B80E15B40A12B10810AF0810
AA050BAB0712A50B18961B29AA6571BBA8B0949DA28EA1A7B7CFD8B4D0DF98B2C2A6B2C1
AC9FAF925F737F2336890D1E94071597030F98020D9A030D98040E92010A8C01098D010C
8B01098B040C810A107312177D303496495184242E77040F77060F6D1D2B593F610C1B53
04235F2D507D4D708864808C6B798073646D5C2A355A081367030B6802075B0709613039
27223B03153B23425D496973506C6C536B6C546C7313274002113A010F3C00113C0A1C42
0118333A5A6542666340625B4161593D5D543E5B55334D4C162B2A49554800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0056B6145E22015F29195B2A1F5B36307B6563736161684F4F653B3E561A1F
550C125304074E0C10633B4155404954434E5A485257434B543E445941485E474E584349
604C516F5C5E7461637865687B646A7C636782686C84686D856A6D8A6F71886D6F897372
8C7B778F847C8F887F8C877E807B717C796D7B7A6F79796F76776D787B707F827782847D
82837E7D807D7A7F7D777F7C707A75758078727C75757D79707C78899895C8D7D6C9D6D7
CAD5DAC6D2D87C8B8F7887897D8E8E8A9C9C9CACAE83949587999986969B81929884969C
8EA1A5899C9F9BA9ABA5ADAFAFA5A9A3646A9A1D27AE0F16B60D13B20911B0070FB10A11
AF090FAE070FAC0710A40B17931B28A05E68C0B1B69CA8AEADC3D246657F60728E927E95
89445A88182F940C1D95031095010C99030F95010A95010A95020D93020D8A010888040D
7F081072131E7A3C49724D5B906872752E3972081478050E6A111B69405B15194A031C55
4A6A9488A4BD718694727781755D6465252F6307116B020A6C010666010572262A5D3947
1315320D23424363734C6C6F506B6A516A69546C731E3348011434061E3C2544573E5C6D
09203238576044676246665F43625B405E57415E5A284245142F2E4556480FCE0900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00642A03602B1A521D125F332D7F6362765858632F30641E2057090E
590E124F0A0D521E1F5C3C3F53404852404B5A46505A454E57434B58424859434A5B464E
6551576F5C5F7362637966687E696D785F6282666A83686B84686B886D6F82676A856E6F
8976748E837D90877F9188818177707D766D7B797078786F72736B76786D797A6F838279
82817B80827D787D7A7C8381767D7B7C868077827B76817C6E7E79A0B3B1C5D8D9C8D8DE
C9D7DFC9D7E085959D788B8E8295957E9090899A9B8396968B9C9E808F94849499798D91
889C9F8FA0A49AA8AC9AA6AAA4ABAEBBA4A9893B439E181FAA0A11B10A11B0090FAF070D
B0080EB0090EB10910AE0911A50D168F1824A25F68B09EA77D879561687E81637D812D44
8F11249806179A031098020C97020D99030E95020C94020C92020C8D030C81071071131F
753B50624A6A332E5251406075384E740D1B7A060F6A0A15734258231F4D0418540F315E
92B2CAACBDCE88819272495964162470081475050C7200067201066F0308670A125E1B29
4F2F424E4F5D536A6E4F6B6A526E6A506968536B6E334B551E3B473C5D6548696C4D6A6E
152A382E4D594568684A696444635C415E5A405D5B122D30163332435A4B21A31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006E340A622D17511C105E3029835C5B723D40611619610F105A0E11
5114174F2223533335574244523F46513D465B464E58434C58444D543F485C474F5D4951
6351576F5F6472626579676A7D6A6D755F637C6466806669896F71866C6E806668826C6A
8977748678728E827C9286818275718276717C777177766F74756D74756C7A7B717C7D74
81837C7E847D78817C78827F767F7D78837E75817B75837C6F7F7997ABA8C4D8DAC5D8DE
C4D6DFB8CAD375888F7185888295957486858FA1A1839696889B9D8191978193977A8E91
7A8E919BADB199AAAEA0AEB49FABAF9EA1A5AD8E938529319C0F18AE0C13B10B0FB0080D
B30B11AE070DAE070FB10A12AD0911A30C178F1926A86571B8939D96606E842235920C1C
9C05109E040D9E040D9C030D96000A97020C94020C92040D890810750D19722D415E4467
2D316714245F4D4978683153750D228106136F071173384D352C570516531431677E9DBD
7683937E6A7D692F456B0F217604117C020B7601067501077402077202086D010766030C
56081253282D656061546764536D6A516A685068684D68684665634867634967644D696B
1D36431D3B4944676948676245655C43615C3E5B5A082225223F3F40574A23A71C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0083481359240A4E1B0E6C3D378250516824276915157125255C2525
5831334F33354D373C513E4654414B56414B58424D56424B543F495A454F59444E5E4953
604F566B5B617361677B696E7A686D7A676B7763647C656784696D866A6D836867856E69
86726D8A7B748F837D9187827C726E7D74707A757274746F75776F787A72787B72737A71
757E7677817978827C76807C757E7A757D7A737E79727F797B8A867B8B8AA5B7BCB4C7D0
A9BCC47B8F9674888C708485839596788A8B889A9B819496809498778B9081959A84989D
788D918A9EA299ABAF98AAAE8E9DA29EAAAF9A9A9C9B6F738820289E0B13AB0A10B00A11
B30C14B00811AD0710AD070FAD0910A20910921219AF4A55A547538A17269209179C0511
9E040B9C010A9D040D9A020D9B040F95020E8C050F7D0D177E32426C4766302D5D0C1E5F
0D2267433F7A6B3459760D2582061477071279324646325C0A1756031A59485C8789869E
6F4659691A2D72081B79030F7D010B7E020A7A010877000A7300077301086F0106690005
66040856060A5D36375F62605067644E67644D66634D67644A68634A6964466560496767
27424D152F3C44666747676046665C43635C41605C133130314F4D43594D36782A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063750B592405562315713B367231307321236715136A2C2A633B3C
56373A48292E543A41513E4751414C56444F56414D58434E56414B5A454E5B46505B4650
5E49526B575E705F6579676D7C686F79656B7B65687E63678B686D8D63677C5250896962
88716B8776708F847D9088807A746C7D76707A767073746C74766C767A70737A726E786F
707B7378827C78817C77817C747C77777E7977817D75848079888675848478898B788A8E
7A8C907083866C7E817385897B8C8E7B8B8E7B8D8F7F9296748B8D758D8E6E84887B9094
73878C7A8E928EA2A49DB0B08FA2A395A5A9879495AEA6A8925C628A1A25A00D16A9040E
B50B14B30913AD070FAD080FA80B129C1418C54E54AB343E97101D9C08149C030EA0050E
9C020B9C020C99030B9A040F9606108409167821316A3B5840376511205D031F63152C6D
565386672E527A0D248805147B0813752A3D5239620E1454081A5C363E72705B7B65283D
6F0F1E7905137D020D7E000A7F01097E01097F020A7B010A7400077301076F01066B0105
6901046303055011126558575367644E67654E6865506A664C67624B6662476561466363
35505614303845676645645D47665E44625C45615C3B58513B595141574B4A4C3A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0041A208551E02622C1D61211A72222074201E6C25236F3C3B623A3A
512728481B205B383E543E4554434C54434D56424D54404A57424B5E4952604A535F4952
6049516753597260667B676E7F69707E676C796065805961854C537B3237752F2F8F615C
8C7570897C77887F788D867D7C766D7B776D7B786F78786F797A7173796E6C766D6E7670
767D797A827E767F7B76807C737E79747E7977827B81908B7C89897987877B8B8A829391
7E8E8E71838474878976888B7685897A888B88979A788B8E7E92937F9494768C8D7B8E90
7A8E90768A8D7E949596AAAA899E9E90A3A48DA0A18E9B9BA3989A995B638D1721AD131C
B40C15B50B13AD090FA90C13A0191EC74F53A72B369B0D1AA70A16A5030E9F010A9F040C
9A000A99020B97060D8F0A15811B2A81455F4C3B6417245F06256719387842568C746991
7235508010248F06168206127625385B40680D14540B165B3B366B683F6265152B770818
8106117E020B80030C7E010A7F000A7E010B7E01097C020B7501077202086E00066B0105
69010466020552070C482F364A5B5E4C68674C67644C69654F6B664D676345625D456260
4662633E5D5D44656247655F46625D48635E49635B4660563B554C42584E48504000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0049A90E591F0663271B560D0674241E6D25217F4945704141582223
5115164E14174E2328573F4454434C55424D53404B53414857464A5F4B51614A52624952
60464F6852586F5B617D676E7F686D7C676A7D656881575E712C32882D317E29298C5552
8A716D857875897F798E847F7E766F79756C7A7A7174746D78797272786F6D786D6A726C
767C787A807C77807B76807B75817C76837B7A857D848F8B7883847986877E8E8D839392
7A898A7788886D81827487886C7C7F848F948793988494978E9FA08E9F9F7C8E8F748689
798C8F788C8F6F868892A8AA96ABACBDD0D296AAAC899C9E97A1A2B3A4A688444B951823
AB0E16B40D14A80A0EA1191FCD575EA92D37A00F1CA70813AD0A12AB060FA4030C9F020B
9C040D95050E860E1883344A6E5076282F670724630B316F5A7FB299ADD67561827B314A
840D1F9006138807147E263967486E141B5A131D5F4B3A6F6025466F0D217C031382010C
86020B81000982030B81030B7D010C7800087A01097D010B7A02087501087101056E0006
69000265010355050C3F212E2F3D4A4866684866634867624968634B686346656144635E
49666249676147655F47645E47635D48625C476158435D5435504A39524A43524300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB0116227065516094F080269251E804C457A4F4C683434571214
570F12541A1D502A2C553E4255434C57434E55414C54414958464A5E4B4F5D474F624650
60414C674A536F525B785B627E65697864677A656885626882434A761B207C24238F5652
8A6D6A847370847875877C79847B7579746C74726A73736B73746E70766E6A746B69716A
6E746F757B76767D78757E7A7E888475817B75807B8B97947A88877686867586867C8C8C
7E8F8E7083826C81806A7E7F72848684929789979C8B9C9F97A6A99AABAC7385897D8F93
7285887F9395798E918CA1A49DB2B4ACBFC49DB0B499ABAE97A7A7B7BFC1A69197994D58
9B1A23AD1319A6181AD3575FAF323DA3121EA80712AC070FB00A11AC050FA5020D9D030C
920911831A2779415C443D6C0F2968052D6D325E9191B5D9AFBEDB8F74927A29448D1023
9205108A09147C22356B4970171F5B1E28675D4977631D3B760A1B83041082000A840108
8601078601098401088002087D040D75040B73010876030B75040A75040B730108710107
6C010366020453060D3F21341A293B45656A4767644A69644968644A666548656246655F
47665F4A686146645D47655E45645C46635B466058435E563B5A5526453E435748209F16
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057B615692B034F10024F10076B332C83544E7C4A485418175E1919
5D2020572C2E593E41523F4556434D503D47513D4856424B5D484E614B5260464F623A47
5E2B386E3A4668343E602F37805C617B60667C63698162678752577728297426218A5750
866B66857570817671847B76827A7477716976726B7A776E75756E70746E6C726D6F756F
707570737975747976757A79838A8978817E76817E788683758583758685768686788585
7C8A8A788A89647877667B7C728689879A9D8D9FA2859A9C94A7AA93A4A97F929775898D
6C8183B2C6CA92A6AB7D929695A9AD8D9FA69AACB1A1B2B6A7B9BCCDDEE2C5CDD2BFA8AF
954A5297242AC74B50B8353DA7131FAB0913AE0810B20A11B20A11AF0912A80A11930A10
91323C6A4260272F66062A6D1A48816F99C0B0D1EAA8B1C68A697F812B428F0F20960711
88070E7D2334725076191F5D1F27676B507C691C3677061583020B85020A810007850108
8401068501088403087F030975040A68060D5F0A12611A2367262E6A1C2568070F6F0208
6D01046303065211192F1D330D213644666E4667664968634A69654C68654C666349655F
47665E47666047676144635E46646044615D46635C415F573F5E5714332E354C4122A51C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006D2D07501003541A10713A33783936753130642220612B27
5E3735573D3E544043503D4453404A53404A523F49533E495C46505D464E624049622836
560B176416216B1F295C1A218B585F6E424A6C444B815E657B51556E383685504B87625D
856B6882726D81756F847B75867D77776F6A79726D7C787174756D6F736D6E736E727772
6E756E727973757B77737875777D7A7C8582737F7C73817E738280788886728080839091
7987887484846D7F7E677B7B728688889B9D809396889CA08DA0A592A4A97F9298778B91
758A8E6E82896F838A7F949999ACB0A3B4BBC9DBE0CBDCE2ABBDC4B2C5CCB5C8CCA4ACB0
B99FA7AD636DB03742AF1824B40F1AAE050EB30B11AF080DAE090EA8080F9B0E12AB3D41
A062732B2B57082F6D3A699D9BC3E1BED5E9AAA9BE885E787E2338910D1D9A0813910B13
7E2230704D711C24601A27696A5080701D3980081785010C84010983000983010984010A
83010A80020A79050A6C0A0F641B24693C4A584056453B5A36314F6A4D60580D196E050D
6C010659040754293513122B0C263D40646C43646245645F4867614B67644D66634A655F
496860486860476962456560476562486662405E584262563D5C512E4C452C483B25AA21
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0077350C511203581F156729226C1F1C7226236B312D643E3B
5B4341534141503D41523F464F3C44533F48523E47563E4A5B404D63414D63323E601823
6B161F630C14651419530F1378454864353A5B2E34816165806466876868846765846866
8A716F88767182756E857B75897F797C726E7A716B7E7871797A72727770737A736E7470
6B726E747C76757B76757A7671787476807B707C7874807D79848473807F6E7C7C728281
7688867183817789886B7C7D697B7D7D90918598997A8C908FA1A690A2A78093987C9096
7F949971878C8EA2A7B0C2C799ACB1889BA2BFD4DBC1D5DCA9BBC2A3B5BCB4C6CACDD9DF
C2AEBAA35263A41827AF0A16B30811B60B13B40A10B0090BA90C0CA01718C64F51A1323B
81344A48426B4975A2A7D2EDBBD3E3A8A1B58C5972821E39910B1C9E0A15910A14842738
6E4B701B25631025686056886A1F3F83091B8A030E88010A83000982000981010881030C
7C060F6D0A1267202A6A4456493F5C1E264D091C4B07194D1F26536244605709196E030E
6903075F181D40283707122C1B394C3D616442645F4766604B68634C67664A68654A6863
49686248696148696247676146655E44645B4363594161543C5C5123443C315146317A2C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0084421155190661271C55110A6B1E186A28237148425C4540
53433F5044424E3F414E3C43503E46533F485840495E3B475F323E69354260202A5A0912
6C161E5E0E145E1B1F643334704D4E6C4F50634949725C5D7C6969806D6D806C6B836D6B
8B7572897671837770877E77887E7A857C777B726B78736977776E71756D6E746E6F7572
767C78767D78767D77767B76747A76747D79717B77737E7B727D7B6E7C7A6E7E7C6A7C7A
687A78697C7B7184847080826C7B7F80909382939595A5AA7C8E9385989C84979B7A8E91
72898B789193B0C5CBC3D8DFB5C9D08A9EA67B90989DB1B8BDCFD59FB0B7AFBEC6CAC7D3
AC77889D2639B3101FB80A15B70912B40911B30C12AA0C0F9F1819CF595BA52C3196101C
82192D674E7254779CB4D1EA9F96AB844A6282183092081B980713910C1682293C6A4D74
18276706236B4247816933567C0C218B02108C020C89010A8602098101097A030A6C060D
691F286F465B493E61141F4F061C52041E53152C5A3E436B5C405F5B162B6906136F010A
650105641A214E2C38191C2D37515943636146655F46635E4B6964486663476763496762
4766604968624C6C6649686348676046655C4564584161543C5C5128484216342C435241
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008E4F145C24095A201159180D70312876463D6E50485B4742
5443405043425245464D3E434E3D45553C485F37425D212D59121D67242D68232A61181D
6B292F6029305D323765494B6B585B6756586655577767677A69697F6D6D7E6B6C826E6F
8773718A787284777089807A8B827E89827B7F7A6F74706576746C767871767C75777D77
787C7A767A77767B76777C77777D7A798381767F7D707A776A77746979766B7B7A70807E
728381768888788A8B6E7E817584887B8A8E88989C7C8E9483949B7B8D92809395ABBEC0
B0C4C87F969C718A927E969F89A0A695A8AF9CB0B5C1D2D7CBDDE1C7D5DCA9ADB7BD9AAA
983549AC1426BC0E1ABC0B15B80A13B30A13A70D13A82327C852589F222AA3111BA00A14
881120764A68333D618C80A07E3C57851429950919970714860B1687384C574068112566
052E732E4B846E567C72132E8A05168D010D8C020B8A020984010879030C6A0E186D3648
4D3D5B172150051B55041E561D35624F5B7D6B62795A2E415E0F1E6C051172010C6F0108
69000660040A510B11502F34565A5948625C45635C44615C4867614766614A6964496862
47665E4B68634B69644A68634967624A666149655E4463583D5C523957511F3C32435343
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF003E9F02652D08541D095B231569392D7651486A4C455C433F
564342554344503F41503E43543B445429355314205E0F185A0D1264232869303559252A
6C4449603F4760444B6950586551585D4A526A595F79696C7C686B7D686B816D70856D71
8A74748A76748A7A76887D7A8A807D857F798480767C796F78766F767871777A73767B75
787B7A757878767A77787D7B747A79717A7A707B7B6F7B796B79777180806F7D7D788783
6D7C796A7D7D697C7E6B7E806D80827F92958B9EA1869A9F7E9196788A8F83969AA2B5BA
A3B6BD7D92987F949A8CA1A7B1C4C9C0D2D6A1B4B8ACBDC2C4D4DBBBC3CCB7A3AF934556
A0192AB00B18BA0B14BD0E15B80E16A80E15AD2D31CA545CA2232EA6101CAA0812A50812
870914A25C707C516B7D2F498A122796091696091186111C7E3B534D42710F2A6C0C3A7B
608CBC818AA860253C840C209003128E010D8C020B86020978050B6B18246A42572E2A51
081A50031D55153061526284766D826C4253621B2B67081671040C7401097200076F0108
6E01066D02076202054B07085C444151625846635B44625C4767604867604B6962496862
4867604B68634E69654D676549676548656347645F45635C415F543D5A522947403E5143
20A01500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047A808632E0556250E54251567372E5A29236638325C3A35
5842405544444F3C3D51363D4A2028531720591016560C1061242765383C6C484D69484D
64474E644A53654A546A515A59424C503B465F4F5775666A7B696D7C686B80696D876D72
8C74778F7B798B7B7A8C807F8C83808A847F827E798B8881797A7273756E72766F737871
757B77747977727975757E79757D7B717A7A717E7D707D7C6C79797682836E7B7A72817C
6F817C637776667A7C65797C6E8284798D8E839899819699A8BDC09AAEB38A9DA285999E
7C8F959FB2B7879AA083959CC0D2D9C6D8DEACBFC4A2B3B99FACB3B1ACB6A36C79951D2D
AE101CBA1019BA0D15B70E13A60E11AE2D31CD575DA4212DA60F1BB20D16AC070FA50710
8F0812B955637F1B2D8F0F1F980915940C15841A25844B6739366B0C2B720D3A7B6B98C4
ACC7E28672876F182A8A061792030F90020C8D040C7E061071222F6445601A1E4B041752
0A2158394B7267647D6F4B5E6B2130700B1A74031176020C7602097501087202086E0006
6C00066C01056601045704064F242451565143605942635C4567604968604C6A62496762
4968624C69664D68654D66644764614A676348676145635B425F533E5A530D2A252F433C
22A31B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004FAF0E5D260150210E602F2361231E52100B6E38325B3833
55413E534443523F40502F354E1E254F141A56181D5D282A66404465484F685057675156
634B52695059674F5966515959454F4C39445F4E5777676C7B6A6D7D6A6D836C6F876F72
8C77798A797A8A7E7E908785908A8786837E84827E8A898482827B787A7273766F70746E
757B76727A766E7A76717E7A768280707D7B6976726A7673737E7C727C7C707C7C71827E
718582677C7A627677677A7E75878B83969885999A8095967C9295788D917F94997D9598
A0B7BBC5D9DEB7C9D08FA1AA8EA1AA9FB2B99DAEB39EADB2A3AAB0A0838E852837A51320
B40E15B80C13B20D12A11012B0363AC9555DA31C29A70C1AB10B15B40A12AC070EA40510
920811BC4B578C1220960A178C0C168328397A5174292E6907276F19448382ABD2B8D6EC
AEB8C97F5A6E7C152690061492020C91030D83071179253562416113184A06164F1B295A
5C577B6542596422326E0D1D7A06137E030E7C010B7700097702097401087101076D0005
6A00056901046301025802064C19202B293145616040635F4666624665614B6A65496864
4967644967634A686449656148656049686246656044635C425F56415B5616302E324A42
23A81F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0055B5125F28005A28155F271F560E0B560A07723B355F413C
54423F4F4040533E40512C335B2A325B293062373D59383E5F454E614B54634F56665357
6853596B555E6B545E69535B5B47514735405C4C5576676D7C6B6E7E696C836C6F877174
8D7A7B88797A8477798A817F827D7A888581817F7B88888493948E85877F72746C73746F
7276736C77755D6E6F4F64665B6F71687A7968767276817B6F79746B7473627070687B7A
667B7A647A7865797A6A7E8461787F7F969B7A90918296967B8F908BA0A2B3C7C98DA3A8
92AAAFAFC4CC9AABB48798A17F9298A3B6BCC9DADEBFCACF968D94874856901624AB0E19
B71116B30F16A0161B9C3E44C87D868A1C2BA40E1EAB0612B20912B10710AC0610A70912
920A0FBF4C57881320821221793146644E7A192A6A062B712B548C98BFE2B8D7E9C1D5E3
ABB2C1815A6C7F172794071591010B88040D7A1A26744D671818451A1F52443964633E5D
641F346F0C1E7A05137D010E7E000B7D010A7901087501087301057301077101066E0106
6D01066901036401025802064F1E271413223652593F6160456561486663456560466662
47666346656049686249666147645F47665F47656045645E4362593F5B52345249284135
337B2C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDC0B692F02612C1752140B580C08560A066B362E60413A
594340523F3D52393B4D23284A161E5B2F385E42475741485E4A52614E55604D52675558
6653586B555F6E55616B545E68525B523F4963555D73656B7D6C6F826D6F876F71877172
8A76788676778376768077747E7976888481817E7B8D8C8890908C878A8477797172746E
7076745D6A6D3C5357365056385257576D6F6A7A77717C766C76726D7A766D7D7C637777
667B7B6D8181677A815B74814562707892987B918F839696849799A3B6BCC4D7DF9AADB6
80959E7B8F989CABB3AFBDC599AAB0A4B7BCCADBE0C3C6CF946F7D821E2E9D0E1BAB0C16
AF0F169F131E9742547358749476907C1B2FA40D1BAC0611AE070EB20811AB060FA50710
920E13B14E5776293A8253723935680D286C083274507AAAACD0EBBBD7E8BDD5E0C2D5E0
ADB6C4866877791B2B8E08168E030E7D040C95485550314E503D61663B5B651B346F0A1E
7B051481030F84020C82010C7F020B7C01097601057100047102047102066E02066D0206
6E01066B01046701035703074F26300A0D1F2F4D5740636145645F48676244655F476962
4666604866614967614A686048665D4C676047645E46645D4565583F5E4E3D5D4D375443
44503B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00763B095E250F511007550E085D1F166F453A62463B
583E375238345639383E1518542A30573A4157444A57484B5544495F4E555B4A51604F53
69555B6B545F6B52606B505E6E5460705B6470606775666C7A6A6E7D6A6D826B6E80686B
857074806F718477768B817E867F7C8883818C89868B8A878E8F8A8B8D8781857E72746F
7277764C5B5E385056324F55355055546A6C68777777807E6D76736D7A7968797A677A7B
65787965797D6079832A4B5C4D6D7C7E969C98ABACBACCCF8EA0A584969C8A9CA580919B
7B8C958B9DA4C9D9E0C9D6DFC5D5DD96A7AFA9B7C0AB9FAB8C4658961523A50B15AF0F18
9D131C9B455B64517F1B306B6E6692792036A20E1CA80610AA050CAE0710AA0710A30A12
8C151EA062746152761D2C6507286E1D49857CA6CEB2D4ECBBD6E4BED5E1BDD3DEC1D4DF
BBC7D28C7D896F2836830A198F081483061096364283364B6D1B30730A1C7E051382020D
83010C83010B83010981010B7C010A7801077302056C01056703066208086C1818660A0D
6902066B010565020552060C4A2B39070F252F4F5B40646342625D47666146645F476760
45655E4B686349675F48685D49695E48655E4A666046645D446457405F513D5D4D375545
43533E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0082460E571B0452110754170D6F40366A4B415E473A
543B324F3831573D3A422929543D4050414754474E564A4E54464A5C4B525D4C53614F58
6A555F6D56617057637055626E555F715D6466565D5F515773666A79696D80696E7F656A
80676C837072867A7981777486807C8984838B88868E8E8A8E8F8A8D8D898788837F817B
7278745A6768334B4E314F52415C5D6074736C7A796F79786D77776C7979677778697A7C
6D7F826378813A5A6A284C5D6F8D98768D91899DA1A6BABF788C917F939886999EBACAD0
B5C4CC8E9FA7B0C2CBBDCED7B4C6CE8FA0A8A4ABB3A584918C2737A10D1AAA0E169F141E
8C33485D4877122B7313327A796C9880253A9D0C19A3050FA6050EA80811A4070F970811
8828385E466A112C64072F6D456FA19FC4E5B7D7EABBD5E3BCD4E0BCD3E0BCD1DEC0D3E1
C2D1DCA7A7B17F5662700F1D85041089040E83050F84061583041186020E86010B86000A
83010A83000883010980020D7B010B7301086B04085D060C591A2060363A82565A5D131A
6603086B010661030456151E35223704142D33556044656543615C46625D43615A4A6863
4B68634D68634A666048675F44655B46655F46645F42605B43625A426057405C513D574B
4254410ECE0900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF008E4E135416004F10035F251A65362E603E355F463C
58413855423D5444424D3F404E414451434A54454D55474F58494F5D4C505F4E5468545D
6D535D6B4D58745863715A636E5A616B5A605D505652464D73676C7C6D71826B70785E63
6E55597E696C8677777F757288817D8883808C8A868686818989868F8E8C91918E898B86
787C756D76715667645367666C7F7E6976746F7C796D7978727C7E68757764737765777B
667B814B687A10365062849799B4BA748A8D778D91768D9289A0A381959A8CA0A6C6D9E0
C6D9E1899BA682949F93A5AFB5C9D0BAC9CFACABB2A87480931A28AA0E199A10188D3748
675078192C6C23377C605890905C7C891C2EA10E1AA50914A30610A40812A007108F0A15
8539512A275A0F397374A2CBB2D4EBBCD4E4BFD7E1BFD4E0BCD3DFBBD2DDBFD3DFC0D2E0
C1D2E0B2B9C6977E8C7C293784061389010C87010989010B88010B860009870008870109
84010982000981010A7D020C74030B64070D5E1A235933423C30452F293C603E4C590A16
6802076B03075A060A582D3B14112D0B223B40616A47646645626049636047625E4D6764
4E68644B64604B66614A676248665E44625D43625C42615B44625C45605C425A533E574B
4357421FA11500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006C7A0F55170055190A5B1F13581C1466332C57322A
5C413C55433F4C413F493E3F4D3F4454434C56454E5746505B49525F4C5265505570525A
73475056262F79545C725B606F5D626E5E6465575D52454D6D61667C6D717E676C755B5F
6A515476616483747689807E87817E827E7A87848083847D8586818E8D8B999A988C8F8D
828682727773767E7A7D8683747E797B82807A8483737E7F707C7E67757760717364767B
5D76841B3F5C1943605F818E6F8A8C768D8F788F927C9295C2D6DAB6C8CF7B8F988FA6AE
8EA4AB8497A07789958C9EAAC6DAE2CAD8DEB6ADB69954619F1A28A9131E972B357E576E
333762605C8D7A4F79742341A33A4D981724A30D17A60B16A60C179C050F9A0812870F1C
7A42601621582B5889ADD7EEBAD5E0C2D6DFC0D4DCC2D5DDBED2DDBFD2DEBED2DDBED1DC
C3D4E09CA0AE7855677417288706148A020D86010986010A850109860107830006830107
82010880030B78050C69070F621A23663D4D4436501B2040202444533C56541224670510
6B02066105085B202A37263F0411321C3B5240656A47656445625F49656347635F4D6965
4965614966614A68624866614A686047655D46645D44625D46635E47615D445D553C584B
3C543F22A71A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A2095418005923125A1B105C140C65251E4E211A
61433D53413E4D403F4E40415242475A484F56444C5B4852634B56684B5369434B713F47
69262F6A262D815258765B616F5D626F5F656C5C6262535966575C7B696E735B60705459
674D507460627F7072817776837D7A817C7A807C787E7C767A7A758383807C7C7C6A6E70
686E6E6A716E777F7999A09EB1BAB9B2BCBB98A2A3727F81707F806D7E7D6D8180637880
3E5B76072C534A708B6A888F6E868593A7A77D91947D9295AFC3C8A1B1B9788A93798C93
B3C6CCC7D9DFA8BAC3798D97A5BBC3B6C6CCBBB0B98B404DA11925A20F1AB84C5AA3667D
8D58748A37518E192C92101EBF424E9A131F9F0914A007149C05119B0712940A147E1829
64456A0A255D527FA7B6DAEABDD5DCC0D4DCC0D4DCC1D5DCBFD2DBC0D2DDBED1DCBFD2DC
C1D3DBA3A7B379526176132487051386010B8401098401098401098500088201097E0209
7A040D6F0912691E296B3F51483B571A21470D1944302F5452344D550E216805116C0208
6004075A1C22452F430B103503193B3357684166674767634A68644A6965466560486862
47666149686249696348686148676048675F43625A47655E43615A44625B405F533A5A4A
3D5843337A2700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BAA10581F015C281650130859160D6A3128633C33
5D423C543F3C51404055434756454B5A474D5C464F624650663E49622D37672B347C3840
76242C7B2C33845057785C6374636A7263686D5F636B5E626E60666E5D62735D62694F53
6F55597762657D6E6E7B716F7E757379716F7F797578746E76766F7F807A8485827E8181
7C8482616C67A9B4B1C7D2D4C1CDD3B9C7CCC5D3D7A7B4B86C7B7E697A7A687C7F5A7585
103257133A605C7D906B83877C9191C5DADA9FB1B5778A90768A9097A9AFA9B9BF82939A
B3C5CDC6DAE3A8BDC68EA4AE839CA394A8AEBAB3BB9655619A1B27AA121EA41A279C2332
9519289E18249C151D931C23C7546097111F9E09169D0814990511980712870914833950
37305F072B6385B0D1B8D7E3BFD5DDBFD4DEBDD3DBBED4DBBED3DBC0D3DCBFD2DABED0DA
BDD0D8A7B0BD7D61706D142484051488030F84020B84010A86020A83010B7E040D710811
6918276C3E515142611D234E0818481C26534C3F62582840600D1D6B040F6D030A5E0509
5920274A35490C143502163C1E3E5545686F4768654967624B6A6448676345666045655F
47686249686347676248686247666048676141615A44615B46645C426157405F513F5C4D
3D5544434C3500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0054B415602704511D0A4E160A5D291E6941375E4239
5C453E55423C53424157444958464C5C454B623F47602F39672D3768252E76343B813D42
711F26792A32854F57795D65715E677162687063676D60657063686E5E627A666B7D676B
70595E776366807170796E6C786E6C746B69736C6873726A77796E8A8C82878983888C88
868D89939F9AC6D1D3B8C1CB7C889174818A819095C6D4D87F8B906F7C8060737E294564
0327533055758EA9B47A8E92788D91859B9E72868A71848A778B90BFD3D7C8D9DFA6B8C1
798E9A7A919B88A0A89AB1B990A7ADB5C7CEC0C5CCAE8D94852A349B1720A5171FA01822
90141E8B252F964B55BB7B859D435191101F96071293050F91040D940B147C11207D5274
14235C1A4377A7D0E8BAD4DFC1D5DDBED5DEBBD3DCBED6DFBED4DEBED3DDBDD3DABCD2DA
BDD0D9AEBBC875647466182A81091785010E83020D83010C7F030C7406106A16216C394C
523F611F2654061C4F041E502B39634E395755142868091672040E6D040C5C09105A2935
40334C0B133A01173F1939543F646C4A6A684A68634C68644A6964476761466862466661
4667614B69644B69644A686348676244645F41615B46645E45635C436158446156405C4F
3F584747533D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059B8156C30064911024E1C0E67403262453A5C443B
5D473F56443D5745455A474B5E464C643D445E222A5F151E732B3465222A74353C7F4247
6C292F6C2F3480575D765E666F5F677060696B5E626E62656D606574666A79696C7B686B
7D686B7E6A6C7B6B6C796C6C736967716865726D677A7971777A72848880848983878C88
89938FB4BFBEC8D2D8858E987A838A798386667476B9C7CC818D9564727D465C73082551
0B2F5A51738BA1B9C184969C74888D7B9193A6BBBDB3C5C97B8E9599AEB5ADC1CA8399A2
748A948499A2C4D9DFC5D9DFB5C9D29AB1BDACC3CFA4AAB1B39498915056934853955568
855B776C5F833F42668A728F7722388C0C1A8F071088030C8C060D8A0C187D2F46463C6C
0728655984AEB5D9EAC0D6E0C3D6DEC2D6E0BED5DEBED3DEBCD2DDBBD1DCBED3DCBDD3DB
BAD1D8BACAD57368775E1C2D7708167E020D7A040D7408116C1823713C50554160232955
091D54031E552E4F7A7C9BBA70778E4F21356208156F050D67080E5C17205C38492E2849
071643011B451B3D5A4165714767684B68654966614A66624A6963496A644A6A644A6965
4968654A676446656046666043655F45666141645E40625B42635B4361584260553D5C4F
3E5A4943523A0FCF0800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00733408491503572D1B654634644C3D5E473B
5E48415C45425B434461424764384065273161111B620D15752A306423296B31387C4A50
754C5279585D77606577676D6E5F6770606972646970646870646872676B786A6E806E72
7965687B6668826F707C6F6E726965746D6878736D7D7A767D7E7A8488838A8F8A878E8D
7B8788B3C0C4C4D0D7727E84737D7E6F7A76697875BBC9CC67777F566A7C1A375C082F61
1F466B54758361787D687A807183876C8185BDD3D7C3D7DD8B9EA583979F7F929AA5B9BF
9AAEB48A9EA5C3D6DEC6D8E2AAC1CC7494A83E657CAECBD8C0CBD0A9A6B270749238487F
1839780E39783A52867E597C7E172C8E0A15900A128A050C8C09117B142360365C132460
0F3B719AC3DFBAD7E3C1D6E0C2D6DEC2D5DFC0D4DDC0D4DEBCD3DABDD3DABFD3DCBDD3DC
BBD2DABFCEDA7F77855E25366B0B176C071161111E683448584362282C5B081D5604225A
2D4E7D5070937E9EB593AFBC777E8B552D3A570C1559121B653847493A56161E47041747
05224E204760456D764A6A6C4F6B6A526C684B69634B68634B69644B69644968624C6A66
4A696549676347676245686245686245676142645D3F615A42635B426359426256415F54
425E4E47564121A11400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF007B400E4D1F075D3B25624732614B385C4639
5F46406044435E3A3D67373D5E1F276D20276A151C641118753538703F42744A5176555D
735B62715E6371616676696E72636A72626873636874636870626574666A7A6B6F826C71
85686D8764687C5B5D806C69746B64756F6878746F7F7D7A8888848C8E898A8D8A6B7474
727F81A3B2B6C5D5D9839495707F7D6D7A7795A3A2A0B1B5586C793A53700321540D3366
3D658058757E6E8488AFC2C6BECFD5758991788D9683979F8799A07E8F9696A9AFC5DADF
C4D7DF8B9FA78DA1AA93A7B0A1B6BF93B0BF65899DB8D6E8C4DAE7ADC4DA3B5D8F053282
1247945E8ABD9995B682374D8D10219108139911188F0911850F1B854259302B5C072966
5886AEB3D7E9BED6E2C1D5DFC1D5DEC1D5DDC2D6DEBED5DDBCD3DABFD6DDBED3DDBBD0DB
BED3DEC1D0DD85859354303F551A255E2E3E493552222652071A53021F5A0C3063355A80
7EA2B8698998627E8A829CA487959B564A53563B4652415622274D051A49011B4B0E2D54
3B5F74456C724B716F4B6A684D6A674C69644B69634D69644F6B674C69654968624F6D69
4C6A664B6A65496A6345676145665F46655E45655D46655F43645D3F6158436259425D55
445F5346594923A51A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00824811582F0F5C3E275F4731604B385E4639
66473F693F3F572023652229671B2372232969191D5C171A6B3C3E68494D735A62715A63
6E5C6471616A74656A76656B7D6B726F5D64725E6576626874616877636982676D845C63
8249516E2F357946497F6462786D677F7A747F7D7981807C8586808C8E888D928D898F8D
8E98998B989BB7C7CCB9CCCFA0B1B2ABBBBCA4B3B7687983556D81142E5A011957153663
5C7C8C657F83667E82A5BABFA9BBC2687B82667A808FA3A8C4D6DAB4C4CB7C919AA3BDC5
A1B7BF8B9FA772878FA6BDC3C7DCE1C6D9E2ACC6D891B4D283A9CB94B7D8254C7F03317D
1B4D8D96ACCD9564798D1B2B9F111E970A14940A148A101C7A293D553E660C245D1E4979
A3CBE3BAD6E0C2D6DEC1D4DFC1D5DFC3D6DFC0D3DCC0D4DDBCD2DABED3DCBDD3DDBCD0DC
BCD0DBC2D3E08F99A665616C685F6A343755071A4C011D58072C5F264E72466F8851788A
6C909B98B8C256747F9EBCC4A1B9BF67757D7D8997142844021C480A29542B4D6B4C6F80
5272785070704D6C6A4F6D6C4F6D6C4A68674A68654F69674F69664D6A664C6B654F6C6A
4F6C694C6B664C6B6547676147676148676246645F46645F43625C426058426058445F57
405D52475F5023A91F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008B54145B320D5A3D255B46325E4A385F4337
643A33652829681D2164151A61141B662024652B2C6A3F41684C5065515769575F6E5D66
6E5E686E5F6874646A77656B78656D78646D746067785F677D5C65785157824E54773239
80292F822E307D41418468647A6E697E77747E7B7781817D8688828B8E88898F8A8D928F
8F96958F989B889298919BA397A2A9818D936A787E5E6F7B3C5271031B540018582C4D73
98B6C29BB2B75F777D5A73786B808584989B6D82859CB2B6C5D9E0B9CBD5748994748F96
A4BCC2BFD3D9A0B6BC9AB1B8BED4DBC0D3DF97B1CB224C7F0F457F8BB8DE8CB0D042638F
738DB2A892AB8A2D419E13209D0B14970A128A0C16751E2F75577915245E0B2F6884ABCC
BAD8E4C2D7DEC3D6DCC2D5DDC2D5DDC2D4DDC3D6DEC2D3DCC2D4DCC1D4DBBED2DBBED2DD
BCD1DCBFD0DDA1B2BD99A7AFBECED74257740E2B5B1A40742D5B82608CA180A7B820475C
7196A8ACCBD77D9DA875949F9FBBC37D959C637B85314D6036546B4C6C7F688892617F84
5673754E6C6B4B6A68516F704D6B6B4B68694A68684C68674A66634A68634F6E684F6D6C
5370715572704A686547666348676146635F46625E43605C46635F446159436056466156
405C50486053434B3800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF006B830F5F390D5C3E255E4432644939633D32
581C176E212069191A661C1F5C20226B3D406C4B50654F5462515665545C6959636C5D67
6A5C6671626B77666D7B666E7D666E7C636D7A586381535E73363F752A32802F347D2427
862727781F1E8747478264627B6E6B8177767F7B797F817C868A848F948E8A908A8F9590
8F95918C9292898E9073787B70767A6B7478626E74596B7F182F5C011D5D05265E416381
69858F6A808563787D5D747698AEB0C3D8DAB0C4C96D848C91A6AE92A5AD8C9EA6758B91
BBD2D8C5DAE1B3C8D195AEBB91AEBEA3BDCBB0CBDF3C608A2A5C8E9CC8E9BDD9ECA6B5C7
B9AEBF964F629C1B2CA50F1B9D0C13910F187A1E2D6744631C2A5F082B666088B1B8D8EA
C0D8DFC3D6DCC0D4DAC2D7DDC2D7DEC6D8DFC4D5DDC4D6DFC2D4DCC0D3DABFD2DBBED3DE
BCD1DCBCD1DBBCD1DABED1D8BCD0D8AAC0D07F9DBA133762012754527A999BC1D52F546B
42687B84A5B2809DA85D798468838B839CA1647F847A949CA1BDC5658188849FA385A0A2
5773734E6C6B4E6E6B4F6D6C52706F4E6B6A4C6A674A68654A68634C6C6751706D4C6B6A
4D6C6C4C6B6A49686549676449676446645F45635D44625D45625D49645E466158476157
445F54485F5449524200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049AF0D653E0E5E40246144326842365E261D
5E130C6815116015105E24226A4346684F556352595F52595E515761535C655862695C67
6C606A6D5F6877626B80616B87626D8658646C2E3C8134416C151E7A1F2472181B893333
7E2C2A6A1F1E672F2F7B5D5C7B6E6B79726F767470797C768689838D918B8E948D8F9790
8F98918F9791888F8A797F7A707774737D7D65737D394D6D031C56092B6D264E7C4E7183
5C767A6F838396A8A8677A7D889CA2BBD0D69BAFB67488908B9FA5C3D5DAC7D8DE98ABB4
8CA3ACA1B6BF94A9B47B96A731576C88AEBFC3DBE8B6D0E685ADD075A2CB87AAC9B0B2C5
A87383942133A81320A50D1796111B781B2C775474202E62052C6548729CB3D8EBBCD8E2
C0D7DEC2D8DDC1D8DCC3D8DFC2D8DEC2D6DDC2D5DDC1D3DDC1D3DCBFD3DCBBD3DABAD1DB
BBD2DBBDD1DABDD1D9BDD1DABAD0D7B7CDD7ABC5D55B779605274F244B6D739AB07699A9
4F727F50727D8AA8B07E9AA279959BAAC7CC98B3B9728B93A3BCC37B939A637B81647D81
5B7477536D6F51706D506F6D506F6E4E6B694D6B664C6B664A6A664C6D6A4B6C6A496B68
496C694C6C6A4C6C694A686647656347656244625D47666148676149645E466159476157
476157475D524C574800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B41269400D5B3E205F402D5E2E21540E05
64130A63160E682D26603B36634A4C63535A61555D5A4F565F535A62535C6758626F606A
70606A735C6779545F6C37436C2D387E333F832B387A1E29791F24731F2068201F8D524F
82514F774A497A56547B64627C716E77736F7A7A747E817A8789838D908B8C918C8B928B
909991909991919A93828883757C796D7777637280192F59021A5D001F5E2F54775E7C86
667C7DA5B6B7C8D9DC8899A06A7D85768A919EB3B7A4B8BD93A5ADC0D1DAC1D2DB91A5B0
7E95A08A9FA7BED2DBBED5E293B1C1A6C5D3BFD5E2B1C9DE4066910A3C7A436494B59FB9
943345A81425AD0F1C9D131F8326396443671E2D62072E69416D97AED2E8BEDAE3C0D9E0
BFD7DEC1D8E0C2D9DEC3D7DEC2D6DDC2D6DEC1D5DFC1D3DEC2D4DEBFD4DDBAD3DABAD3DD
BBD4DBBFD3DBBFD3DBBCD2DCB9D1DAB8D1DAA7C3CD7795A95F809A4269844A728696B7C5
789AA8436777A7C8D5A1BECB6B899594B1BB96B1BC627D87667F8663777E5E73795D747A
64797E5D7577567371506E6E4F6F6E52706E506E6A4B69664A6A664C6B694C6C6A476965
4A6A654D6C6A4B6A674665644B696647646147646045625E48676147655F47635A49645B
466257455E524A594A209F1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0055B914693E095F4020633F2B5C2317590C03
66170D6121186D453C634D485F4E5062565B61575F5D525B60535C64545E6A5761755C66
7B586480535E6025317E3D457A3339701D24923D44691B217C393E743F407F5756866967
826A6A735E5F715E5D7F706E7E74717C79757F817B898D85878A838E908C8A8E898E948E
979F979099918D9491858B897379776B75794B5C74021A4F00175C06265A52748B93ACB1
70828676888E93A5AD68798067797F798D92C4D9DDC4D9DF9FB2BC8699A483969E95AAB1
7D929991A8AFC5DAE1C4D7E1BACFDC99B4C880A1BEABCDEA51769E1E43759D9FC6965068
A41E2EAE1321A218269239516447721B2C6A052D6A45709CAED1E9C0DAE7C3D7E0C4D8E0
C2D7E0C2D7E0C1D7DDC4D8E0C2D8DFC0D5DFC0D5E0C2D6DFC2D5DEBED3DCBAD4DBB7D2DB
B9D5DBB9D3DBBAD3DDB8D2DCB4D1DBB5D0DAB0CCD759778A88A8C2224266214569A0C4DA
799DAF254A607091A692AEC064808F55728069868F6581875A767999B1B373898C6A8287
9EB5B962797E5A7675547170506F6D516E6C4F6E6A4A6866496865496865496966466661
4969634E6D6A4D6B6B4A686848686447656046635F48656043615C47666046655E47625C
456259445F554B5C4E25A61E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00704209613B1B582A17602215570D04
6621186F3B316C4A43644E4A5D4B4C5F51555D52595C515A62545E64525E6E5461693E4A
612330752A386F242F8042478B55575C1F238E515679484D8562667C6468817072817375
78696C79676A7968698477768076747C79757F807A878B838689828D8F8A9195908C928D
929B938F99918F9995888F8E747C7C6A768122385D021D5C001A5D12325E628292B9D0D5
74868C61747A6A7E83B4C7C9A9BBBF6B7F859EB5BCA4BBC5859BA5778C93A8BCC1C6D8DD
BDCED491A5ADA6BDC4ADC2CBA9C0CF4C6D8E1646728DB6D7B6D1E8A3A5C0A9738C982236
A91A289C2231A45D78615284162F740A35785582AFB4D7EDC1D9E6C4D8E3C6D8E2C7D9E3
C3D7DFC4D8E1C4D8DFC5D8E1C3D6E0C1D5DFC3D7E1C0D5DEC0D5DDBED4DDBED7DEBAD4DC
B7D2DAB7D4DBB6D3DDB5D1DCB6D4DDB7D1DBB6D0E036536E88A9CB173662022654507895
84A9B95577884E6D7E65818E7A95A0597680A1BDC3A4BFC4647F84A1BDC09DB7BA657E84
70878D637B7F5D7877587572516E6C53706C52716D4D6C68486764476764466863486863
4668624A69664967684A69684969654A69634A67614A666247645F47655F48676046625E
46625A486359495E4E367B2A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007C490B5D300C59230E602011601F15
743931632E266C403953312F634C4E6252556054595C4F57634F5B634856714C59612D39
813F4B64162280353F6F3A40815C6075515683616680666B7C6B707A6D727F747982767B
796A6E7B686B7A686A7D71707D74727A767182827D898A84888A858E908C9395928A8F8A
8F98908D98928895918590907A858A57677E061F53001E64103572254C6E5C7B86677E81
6D80856C7F827C9195C5D9DDBCD0D66B818768818886A0A6B3C8CE9EB0B7A2B4BBC4D5DD
B3C5CD9BB1BC8CA6B1AEC8D3C4DBE892ADC6507797ABC9E0C7C8D7B4859A8F2A40971F33
9A3E53956A91414983103179164281729CC6B9D9EEC3DBE4C3D9E1C5D8E2C6D9E0C4D7DF
C5D9E0C6D9E1C6D9E0C6D8E2C7D8E2C5D6E0C4D6DEC2D5DFBED4DCBED6DCBFD7DDBED7DD
BBD5DCB9D4DBBAD6DEB8D3DEB6D3DBB7D0D9B9D3E33E5E7B3D64865378982F5473456982
6586948BA9B55172808DACB8AECAD4849FA98CA8B2ABC3CE70899369858D6C878E667D84
6981866A8284617B7D5A777459767457737153706E506F6C4B6A66476764496B66486864
4969644B6A664A69684969684969654B6A654B68624C686447645F4A686048665E45625B
46655A476457455C4E49503D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008750105E2D08622E175A23127D4438
692D246122186F372E562E2B654C4E665457665358684F58603B48693B47703C475E2E38
82535C531F26774449724D51795F657F686D7D676E7B686F76686F7A6E747F747A85797F
87777C7F6D707564667D6E7080777576726F82817F8988878C8C8B8A8C8A8D908D929692
9198938F9B948C9A958491917B8A942E4267031B5D021E6B0F3671476E88628084708585
BACDCFB5C8CA6A8085869EA47B939867808360787CA9C0C5C6D8E0BCCDD597A8B09FB2B9
A4B7BFA8BEC95E7986ADC8D6C3DBE5C4D8E3A8BCC8ACB4C0B59AA8833E4F944051B77F98
696092203E880B3E8632629999C1E2BDDCECC3DBE3C7DAE0C3D7DEC5D8E2C5D9E1C5D8DF
C4D8DFC6DCE3C5DAE2C6D8E2C6D8E1C6D9E3C6D8E1C3D6DFC0D6DEC1D7DEBED4DCBED5DE
BCD5DDBAD4DDBAD3DEB8D3DFB7D4DCBAD4DDBDD4E27492A9466D885B859B84A9C13B5F7B
7B9DB2ADCBDB36586C6185989EBDCB86A3AE5D7A8569858F6A828B5D7880819CA38BA2A8
6D858AA1B9BF6E878B5D797A597675597475546F70516E6D4D6B6A4C6B694A6969496868
4A69674968644767644969684A69664B6A654A68634967634A686347635E4A675F46645A
446458426055465F5249534300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009254185C250764311C6935246A3023
632014601A0F6931266C4B43614E4D6750526A464C5F2C355F212C733038601F265D2930
79555B65494D6D5254755E6176646978676E7B687079687171636B796D737E74797F737A
87777E8473777C6C6F7C6D6F796E6E817A7A817E807E7E808687858C908B8B908C929894
939A97939D98939F9C8A97987486980E2656031A650018660C2C606A8A9C7F97998FA3A3
BDD2D5AFC3C96A808660797EA0B7BABFD4D591A3A88DA0A7B1C4CCA0B2B998AAB298ABB1
C5D8DFC8DBE3AFC4D09EB5C2ACC5D1AFC4CDAEBEC6B4B8C08C7981AF8B95C7B4C86A79A9
103C8D084299548EC7AED9F2C0DEE9C4DDE4C6DAE2C9DAE3C8DAE2C7D9E2C5D7E0C5D8E0
C3DAE0C1DBE3C4DCE4C6DBE3C5D9E0C4D8E1C1D7E1C2D9E2C0D6E0C3D5E0C3D7E1BED4DE
BBD4DEBDD5E1BCD3DFB9D2DEB8D3DEB9D1DBBDD3DF94ADC31B40615E89A7577E9F012552
3A60829ABCD17798AA5174845F808C77949E6A878F88A5ACA9C3C978929A8BA6AEAEC4CE
768F977992996E898D5F7B7E597776587574567172506C6E516D6F4D6A6C4966684C696A
4E6D6A4D6C68496A654969664968644B6B644868624B6A654F6A674D686249675D47655C
48675D44615A4760554A5A4A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003E9D04571B02622C186F3928622113
71251C62170F642C246B4C4668514F633F42652C33702B3362171F671F2766272D5C2F36
6C515768565A66555A6D5B6273636A75666C7B6B7177676E6E6166776D737E747A7C7178
81747A7D6C727C6B6E7E6F707C6F6F817877807B7C8382838788868E918C8D938D898F8C
8C9391939C99919A998B979E51658205215D021B6A001A631F3F6BABC8D7A1B5BA8A9CA1
8A9EA47C9096889CA15D7579B7CED2C3D7DCA9BBC18EA0A88EA2A8BBCDD3BDCED59EAFB9
BDCED7C1D3DBB1C7D692B0C5668CA498BACAABC0C8B5C3C9BCC5CCC8D4E57E9DC20F448B
0440A30747A27FB8E9B9DEECC2DCE2C3DAE0C7DBE4C9DAE3C7D9E0C8D9E1C6D9E0C5D8E0
C1D8DEC3DCE4C3DAE2C4DBE2C6DCE2C4D9E4C0D6E1C3DBE4BFD6DFC1D6E1C2D8E1BFD6DE
BDD5DEBFD4DFBED3DFBBD3DEBAD3DFBCD2DDBED3E0A5BCD60B2D591B46716F9ABC14385E
446A885A7E8F86A5B06F8E9973929BAFCCD599B7C085A2ACAEC8D28CA6AF69848D7A949D
69848A637F836581836580815B7777557272567373526C70526E71516C6D4D68674B6867
4C6A674C6A674667624766644968624A6A634B6B644D6C664F6D694A676246655E47655E
47645C47615B4962574A5D4C1EA01600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0047A70C5B210168311B5C200F6F271B
64170E6320176839316D4D49674244682F35641D246D252A66242A5B262D714B53684F56
65555C675A5F64545D6D5A6474626B77676E7A6A717B6B7177696F7F757C7D727A7D7179
83757B806F737C6A6E7B6B6D796C6C8076757F7A787F7E7B8889868F938E8E948E8E9591
969D9A979E9A959D9E92A0AF28406D04236B001E6D00206033557B84A0B07F959C75888E
768A90B4C6CBC7D8DE8CA1A871899292AAB08FA3A7889AA091A5AAC8DAE0C9D9E2A9B7C3
ACBBC5ACBDC5B7CEDC5B7D942B58739DC1D4B8CFD7BED4E0A2C3DD699BC75B97CB4283C5
04469F03489F629CCFBBE0F0C4DEE4C4DCE2C6DBE4CBDDE4C8DAE1C7D9E0C7D9E0C6D8E1
C6D9E0C8DCE4C9DDE5C6DBE2C6DAE1C5DAE3C4D9E3C4D9E2C2D9E0C2D9E3C1D8E0C3DAE1
C1D8DFC3D6DFC2D6E1BFD5E0BDD5DEBED4DDBED3DEB5CEE21E42661E4C75527F9A7CA1B6
7CA0B66B8FA1B1D1DF93B2C3698B9CA6C5D49CB9C667839276929D6E899265808769858A
749093617D7E839D9F708A8C647E825F7B7E577575526E70526F70506D6C4F6E694E6B66
4D6B684C6A674868634B6A664A69644D6A654E6C664D6B654D6C674A696547666146635E
46615A476159435E53485D4C20A31800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004BAC0D5F2604612713601C0F71251A
5F1B10703C32734C456D44446A3236661E256E21277433376B3D426F515A68565F655961
62585F6559616B5A646F5D6675636C7969707868707A6A727F6F76806F767F6B73836E74
70585B8C7276826B6E7E6B6C7B6D6C817776827B7985817E8585828B8E8C888D8B8D9290
929795999F9C959EA37688A30B28640221740F3384163E7A476A8A58748072888D8A9CA2
6B7E85A2B7BEBFD4DC8DA2AB7289938AA3A8C4D9DDBFD3D9889EA6A4B8BFADBEC697A7B1
9FB1BBB9CBD4C7DCE4BCD6E1A2C0CEB2D1DEB9D5E1B6D6EE467AB00B59A62A79BB91CDF5
467AB14984BE98CCF3BDE1EFC6E0E6C9DFE4CBDEE4CCDDE4CADAE1C8DAE2C6D9E0C4D8E1
C8DCE3C9DDE4C9DDE4C9DBE2CCDFE6C8DCE3C6DBE3C6DCE4C4DBE1C2D9E2C2D9E1C2D9E1
C0D7DEC2D7E1C0D6E2BFD7E1BDD6DFBED4DEBED4DFBAD3E47FA5C24778A05888A9A7CFEA
406A8D39668AA1C8E17293AB57788E6C8A9C77929F6A86937590999EB6BD77929786A5A9
ADC9CE748D907E999E728E936380845F7D7F5C7B7B5471714E6C6B4C6C694D6F6A4E6C69
4C69664A69654B6B674C6B664A6B654B6A654E6C664F6C674D6C6749696546656043615B
405F58436058436056465B4C25A71D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0055B512682D03541606671F15611D11
70382C71423A70403C6227276722246723255C21246B41446A4E5466555E635660685D67
695F686B5E676D5E6871606872616978676F7B6871826B7485656F845863693D46946F76
67464A8462657C5B5D715857847471847C7988827F87838081817E868886868A898D9291
909896939A9B8F99A44A5F8704206A001F780124770F366F597B93627C83AEC2C7C7D9DF
869AA369828D6E8A919BB3B994ABB0829CA2C2DBE3B7D0D87F99A092AAAFAFC4C7C0D4D8
A3B9C0B1C5CDC9DAE1CCDFE5C4E0EB8DBCD782BBDFACDFFC4F89C01764AE468CC1BCE5FD
D2F2FFA3D5EF80B8DABFE5F3CCE3E9CFE1E7CCDDE5D1E1E8CDDDE4CADCE4C4DAE0C2DAE0
C6DEE3C7DCE3CBDEE4CADDE4C9DCE4C8DCE4C6DDE4C5DBE4C6DCE2C6DBE3C4DAE1C3DAE1
C1D8E0C0D6E1C0D6E3BED5E1BDD6E1BED6E1BDD4E0BCD4E96A8EB60A397B1A4C888EBEE7
15436C1E4D756C95AF7191A56D8A9B7B95A3A7C0CB92ADB78FA8B1B6CAD298B3BA7A98A0
9EBBC27893996A858B668287617D815F7D7F5E7D7C58777553736E52726E4F706C50706D
506E6B4B69684B6A674C6C674E6C674A68644D6C674B6A654C69664B6A6548676242625C
3F60593F5F57416055455C4D474D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0A7336065A190756130A753B32
78483F612F266C30296F2D2863221F71403E6E4E4F6C585C64565D6659616A5E676D626C
6A5F6971656F70626C70616A7661697D606B835D69814F5A7A37447C293770212D7E494F
805C607A55587B575A8167697C6C6B807876817E7A8484818282818A8B8A878A89858C8C
8B9494939B9E8E9BAE1F376A022071011E790122702549797A98AA627981879DA5A1B7C0
647A87637D897B989FC2DCE0C4DAE279929D738F9A7E99A094ACB1A7BDC1C0D4D6C9DCE0
C9D9DFCAD9DFC9D8E0D0E3EEC0E1F44383B22B7AB291C9E8B9E0F9A8D1EBC9F1FDDAF9FF
D2F5FF7BB5D775B6DAC7ECFBD4E6EED4E4EBD1E2E9D2E3EAD0E1E8CFDFE7C6DAE1C4DAE0
C9E1E5CBDEE5CDE0E6CBDEE5C7DBE2C5DBE4C7DDE5C7DBE4C7DCE4C9DDE4C7DBE3C6DBE3
C2D9E1C2D7E3C2D6E3C2D5E2C0D6E2BFD7E3BDD4E1BED6EB6082B00535810A4188659AC5
6F9AB7638BA57C9FB2ADCAD8A3BBC988A0ADB4CED8A9C3CE7F98A59EB6C18BA5AE738F97
789299768E936E898D7F9BA0698387647F82637F815D7C7B57777454747153756F52736F
4D6D694D6C684C6B674F6D68506E694D6A664B6A644C6B664E6C684D6B674D6B66486762
46666045645C47655A435D4E48534000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783A085417015D2317744139
69332B62231B6D2F256A342C673B366B4D4D69585C65596163575F61555D665B636A5F69
6C616A6E606972616B765F677A525D7738467626348D354083212F811221730D168B484E
7F585C7352548C7073897476786A6A7F767376726E7574728486858C8F8F8A8E9082898A
8B96968D9BA07287A107246102217700207A00226E5478A3BBD7E87D959C5C767E607A82
A3BAC38DA5AF748D97B5CFD7A6C0C96E899490AAB2B7CED4C9DDE2C1D2D6D0DFE1D3DFE2
DDE9EDE9FAFFBBD2E1C6E0F0C7E4F595C0E1A4D4F1D9F7FFF1FEFFF4FFFFCADEE6ABC7D4
B6D8E7B3DDF2B2DBF1D7EFFADFECF4DCE8EFDAEAEFD7E8EED3E4EAD2E2E9CDDFE6CBDEE5
D0E2E9CFE0E8CCDFE6C9DDE5CADEE5CBDEE8C8DCE5C7DBE5C5DBE5C4D8E2C7DAE7C5DAE5
C1D7E1C5D9E4C5D7E3C3D6E2BFD5E0BFD7E3BED5E2BFD6E690B0CE3C679C4B7EB574A4C8
A9D0E88BB3CF81A8C1B5D2E29FB7C8809BAC96B2C08FA9B77A94A0829DA68DA8AE7A9298
9FB7BCA3BBC1748F95A1BCC47B969C6D868B6B8588708C8D6381815C7A7A597775567570
55757054726F52726E506F6B4F6E684D69654F6C674D6C674C6B684C69664E69664D6865
48656047645B47655844605247574600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C3D0E531903643122723C2E
5A190F611B1061291D7A554B71585465535561555A5F555C5F565C60555C61565F655961
6C5B63745B667D5B656F3F4A75313D701420780D199328338518247E0A147B1119914A50
724C4F7C61628A7575837473796E6C827A767D78747473707B7C7D86898A8D9192899191
8B96968E9FA7435F8104256B00237B072E87002670547AA584A2B2748C92647D8287A0A5
C4DAE1BBD0D98096A28099A290A9B0A9C1C7ACC1C8C3D8DDCCDDE1D4E1E2EFF6F6F2F7F9
E3EAEFCEDFEAADC5D3D6EDF5E4F3F9EFFCFFF4FFFFF5FFFFF0FCFDF4FEFFEFFAFEF1FFFF
EFFDFFF3FFFFECF9FCDFEBF3DFEAF1DEEBF2D7E5EAD4E5ECD4E7EBD4E6E9D2E3E8CFE1E8
D0E1E9D0E2EACADDE4CADEE6CADDE4CBDCE5CADDE6C7DBE6C3D9E4C4D7E4C5D8E5C1D7E4
C1D8E4C3D9E5C4D7E2C3D6E4BFD5E0C0D5E1BED4E0BBD2DEABC7DB9AC0E74F80B673A3CE
9CC6E82150785080A49CBDD498B3C692ABBD94AEBC9DB5C28BA4ADA3BEC6B2CBD188A0A8
A4BEC6A9C2CA7D959E7E969E778F946F888B748D8E7C9596748E90647E7F607B7C5F7B78
587674567474567676537271506F6B4D6B664E6C674A69644D6A674E6A66516B694D6864
4D686149655C486659456255465A491E9E1400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008246145621086331205B2114
5E1A0C6225155F3527735D53695A5862555860545A60555B5D53585C52595D515964545D
70565F724954672D387C374281313C7918218A2028962F3687252C76171D8D3E43835054
836769816E6F8474758174737F7573837A797F7B797B7A787B7C7C868A8A8A8F8E8C9493
8D96988B9BAC1D396B02237601248217419C012B715D85A97F9BA6ABBFC29AAEB47C919B
ADC3D09EB4C194AAB69BB2BBBBD0D6CCDEE4CDDDE2DEECEFE3ECEFF2F8FAF9FCFDFBFDFE
E6EBEEDBE4EAF2FCFEF8FEFFFBFFFFFAFFFFF3FFFFC9E8F1B7DCEAD2E9F1F2FBFDF8FCFD
FAFFFFF9FEFFE9F0F7DCE7F0DDE7F0D6E4EBD6E4EAD6E5EBD5E6EAD5E3E7D3E2E7D0E0E7
CFE0E8CDE0E8C9DEE5C9DDE5CCDFE7CADBE3CADCE5C6D9E5C3D7E4C4D9E5C3D8E4C2D8E5
C0D7E4C2D8E5C4D7E2C2D5E3C1D4E1C1D4E1C0D3E0BDD3DFB4CDE55278A806387E255A95
81B1D4527E9F648EAC85A5B8A9C1CF95ABBA9FB7C4BBD0DD9BB5BF9AB7C1ACC7D18AA2AC
87A1A9899FA9899EA78CA0A7869A9F8A9FA2849B9B81989A7A92966C8587678283637C7D
5C79775A787959777854747451716D4F6F685070694E6D68536F6A526D694F6B684E6B64
4E6A604B695E48665A476457475E4B22A41A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0060730D5D270B572412581C10
5F24156C3F2F69504371625B6A5E5F63555B60535A64565D62555B5A4D555C4E5669535B
5E3B4377434D661D2875232D82303772192077171E7521268E4B4E864E5190646884676B
7E6B707F747783787B84797A83797B837D7E7E7C7C808180808382858A88848D8A889190
909A9E798AA10B266202257E012489002685083579678DAE8AA0AAC6D4DABECED699ACB8
95ABB7AABFCABFD1DCB9CBD3C6D6DBD3DEE3E6EEF1F3F9FBF8FCFEDEE4E8DDE4E9FBFDFE
FBFCFDF6F9F9FAFFFFFAFFFFF5FFFFE7F5FCD7EDF6A5CDDCA8D4E3DEF6FBF8FFFFFBFEFF
E9F0F3D4E1E6DCE8F0DFEBF4DBE5EEDAE6EFD6E5EAD8E6EBD6E4EBD7E5EBD4E3EAD0E1E9
CDDFE8CADDE7C8DDE7C9DDE7C7DAE4C7DAE4C7D9E5C5D8E6C4D8E6C1D7E3C0D7E3C2D8E5
BFD6E2C2D6E2C3D6E2C1D3E1C1D4E2C0D2E0BED1DFBFD3E1ADC5DC4A6E9708356C295A89
6A96B0A4C8DB91B4C88DB0C0B4D2DFA8C4D585A1B0ABC4D096B2BD7797A27E9BA67D97A2
7F98A196ACB58DA1A99AACB4B3C5CB9BAEB292A6A9889DA07A9296728B8F6B8787617C7D
5E79795B78785C79795574724F6E6952706B51706851706B51706A516F6A506F6A4F6C66
4F6A604C675D4B675D49655A445C4B32772800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A309612806521B08582111
693C2C6D514364544B6D615C685D5D61565862555B66555C664F5762484F5438406B4C55
5F3B43804C546E222D721D257C30356A24296F2D338C565B8E626993656D97626C7D4D59
8666717E7277837B7D847A7B847979827B7A838181818381828686818987858F8F8D9697
909B9F8296AB0E2C65022782002891002C8E23549488ABC896A7B2A9B4BDA4B0BAAEBEC5
B2C3CAC9D9E0D0DDE6D2DEE4EBF5F7F0F6F9E9F0F4ECF2F6F7FDFFDDE3E8D8DFE4F9FCFE
FEFFFFFCFEFFEEF7FBDFEFF9B3CDDAC1D8E5DEEFF8E6FAFEEAFDFFF5FFFFF8FFFFF7FEFF
ECFBFEE4FBFFE0F6FFE1F0FADBE9F3D9E5EED7E6EED2E3EBD0E1EBCBDEE7CBDFE8C9DDE7
C9DCE9C5DAE6C7DCE7C7DDE8C1D8E1C0D7E2C3DAE6C0D7E4BFD6E3BFD7E2C0D8E2BED5E2
BCD4E0C2D6E1C2D5E0C2D3DFC0D2E0BED1E0BACFDDB9CFDDB3CCDD63849D8AB3D17BA6C8
628BA5A9D0E7517C9C5985A595BACF6D8FA27090A088A5AF7E9BA46F8E98A6C3CC9BB6C0
819CA6AFC8D298AFB8859AA49EB1BA879AA085999C8BA0A47D9297748D91698586658182
627D7E5E7A7C5D797A56737153706C58726E58726E55716D54726E52706B57736F526D69
536A65536B654F68614C685D455E4F414B3700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EAD106326014B1200522111
6A473869534867574F6D615C6C625F635758665357694B5263343D6228325E2A337B535B
603A4186545C5F1C23712A307E454A7D4F5686575F87535D8A4C577326328D303F761E2C
7F4750877276877D7F8A8081857A7A847D7B84837F888987858A89898F908F9798939C9D
94A0A293A5B6234376032C86012E9A0133973366A7AED0EAB7C5CFC3C9D0C9D0D8D1DBE2
D5DFE5DDE5EBD9E2E9E0E9EFF2F8FBF2F8FBD5DEE5D3DEE5EDF4F6F3F7F9F3F7F9F9FDFE
FDFFFFF8FBFDDAE3EAD9E8F3D2E6F0EEFDFFF6FFFFF6FFFFE5FDFFC0EBFCB4DEF4D7F3FE
BFD9E3B6D5E1C1DFECCFE3F0D1E2EDD1E1E9CEE0E8CCDFE8C6DDE6C6DDE8C4DBE6C5DBE7
C5D9E7C5D9E7C4DAE5C5DBE6C2DAE2BED7E2BDD8E2BDD7E1BED6E1BED5E2BED5DFBDD4E0
BBD2DFC0D3DFC2D4DFBFD0DCBDCFDCBED1DFBAD0DDB5CFDBB5D1DE7192A585ABCA194070
2049786F9CBE1241662C5B7D5881957596A57D9EA98FACB5ACC9D07E9CA6A6C2CDA8C3D0
73909D96B2BE839FA9849EA887A0A78A9FA6879DA1869A9F798E9472888D688285678284
617D7E5D797B5B78795976755976735971705B75725D777457757152706C55716E57716E
546B685369665369634E685E47635441513C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056B6166227004D1903582F1E
6A4F3F69564967594F6F645E6E62606E5B5D69474C622932661921650D1761172081515B
623C457D555C60343981565C8259617E4D577A364275232E8931398C2932861520831721
80383F8E7275887D808C82848980828781818B8C89888D8A8990908C9394969B9D999EA1
9AA0A49EABB94C699605328A0237A6023CA3275CA0AFCDE9C9D2DADCE0E5DBE1E9CFD9E1
D4DEE6E1E8EEE2E9F0DCE4EDDEE6EDE7EFF4E3EAEFD9E1E5F2F8F8FDFFFEF8FCFDDBE2E6
E0E6EBF9FDFFEDF1F4EEF2F7F7FEFFF4FFFFE6FAFFD1EEFF8ABEE33C8FCB549FCFC5EFFE
DBF6FFC4E9F8B7DBF3C9E1F1CBDEE9CCDEE7CCDFE8C7DCE4C2DCE3C4DCE6C1DAE3C2D8E3
C3D9E5C7DBE7C5DBE6BED6E0C0D8E1C0D8E3BCD5DFBDD6E1BDD6E0C1D6E3BFD4DFC0D4E0
BED2DEC0D3E1BED1DEBED2DEBCD0DDBACFDBBBD2DCB9D0DCB6D0DE7594AB3E668C022861
042A624170916590A46E95A8668A97ADCCD790B0BA7C9BA7ACCAD484A1AE75919F84A1AD
6B8895698591718F9875929B85A0A7869FA57F969C7B9197758A916D8489647E82627D80
6380805977775473755775765674725A74745A76765C767458757053706C57746F5A7471
516C67506963546C63516A5F4B6658465A4700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0C6C330554270C573822
66503D68564766594E6F625C6F5D5B76585955202464141B7B1C21700F145C10167A4C53
6F50586D50577B5D647D5E657B5058803E487D222D811A238B272F963039871920871F25
7932388F72788980848D888B8B888A87858788888B90949691989B959C9EA1A5A7A7A7AB
A9A9ADAFB2BC7D92B70938890345B00850B53672B3D0EDFFD7E1E9D7DDE4D2DBE4D2DBE5
DCE6EFD4DFE6E6EFF5D4DCE6D2DAE4E2EBF0FAFFFFFAFEFFF3F7FAF5FBFDF4FBFDD1DBE2
D9E2EAF7FCFFF8FDFFF4FCFFE5F2FDA5C4E65A8EC08FC1E99CD0F65EA0D38AC7EDBFE8FF
BEE1FC5889B384B5DBBEDCEDCADFE8C5D9E2C8DBE5C7DBE2C3DBE1C3DAE3C2DAE2C3D9E3
C3D9E3C4D9E3C0D7E1BFD8E1BDD6DFC0D6E3BFD5E0BDD4E0BED4DFC0D3E1BFD2E0BFD2DE
BED2DDBED3DFBAD0DCBCD2E0BAD1DEBAD1DBBAD2DAB8CFDAB6CFDC92B1C3456B8644698E
51789C48738CA5CADA9DBFD1638A9EA0C4D68DADBD5778886B8B9766828D607D87809DA6
7B96A0708D96A7C6CD7C99A290AEB78AA7B06E8990678085647E83637F83617E815B797B
5E7B7C5575745574745371725371725773765A76775D77765D77745E7974607E77647F7A
526D694B6661526C63516C634C695B475B4C1B9D13
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006F38075A3111583C22
644F3C66554767584E6F5D576E535077494A631D1F660B0F761719691314622324764E53
7B5A637F576177485382515B83475182323C7E1A25841C24862930852F377E292E7C3034
86525991767D91848B97929797979A919194949497989A9E9A9CA1A2A5A7ADADAFB1AFB2
B9B4B7C1BCC3AFBDD7214F92084FB41160C22F70B1B9DDF5CEDBE2D9E1E6D7E0E7D9E2EA
D7E1E9CDDBE0DFEDF3DFE8F0D7E0E8E0E9F0E5ECF3E8F0F7CFDAE3D5E2EBE2F0F6CCDBE2
DEEBF5D3E0EFBFD1E5C2D8EEC7DEF8759EC9326FA591C3EABBE0F3BDE4FC75A8D74682BD
81BBEC417DAE7AAED2C0DDECC9DDE3C7D9E1C7D9E1C8DAE2C6DAE1C5D9E2C5DAE3C4D8E2
C2D9E2C2D8E2BFD7E2C0D7E3BFD6E1BFD4E1BFD4E0C1D7E3BED5E0C0D5E2BED1DFBFD2DF
BED2DDBED5E1BCD3DFBDD2DFBBD1DEBAD1DEB6D1DAB6D0DAB8D0DCAFCAD66183939BBFD5
7FA6C6416C908EB4CF496E8C174162567E9660829258768669879296B3BC708E979DBBC4
A5C2CA708D97A0BDC67E99A364818A638289618085688488658184688587688587668385
5A767753727050706D516F6F5572735370705472725976745E7975637E796A878267817E
5A74714D6662516B664E69624D695C4D615120A319
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C470D5E3811573C20
634E3A66544769524B714F4B7A4A486422226C191A650B0C6B1A1C66272773424573454F
7C43506B222D84344073242F85343F8D364174161F7D242980393D955D6289575B996C72
9B70799268708A6C72A4969AA09EA29E9EA39E9FA39D9EA1A2A2A6ACABAFB5B5B6BCBABB
C9C7CAD1CED4CBD4E84A71A90647A5024EB24184C5B8DBF3D7E2EAE3EAEDE5ECF1E3EBF1
D5DFE7CBDAE3CBDCE4D4E3EAD0DFE5CAD7E0CAD8E4C0D0DDC5DAE6BCD3E0B3CAD5B7CFD8
C2D9E5BFD8EE6485A77596B9BCD8F2BAD7EFA0CAE990BDE3A6D1F2A2D0F31A599C0D5BB2
377FBF99CDEEABD0E5C4DBE6CADCE3C9DBE3C8DAE3C8DAE2C7DAE1C6D9E3C8DCE4C5D9E3
C3D9E4C5DAE5C4D9E5C3D9E5C1D8E4BFD5E3C0D7E4C0D7E5BED6E3BFD6E5BFD5E4BED3E2
BAD3E0BBD5E4BCD4E3BAD2E2BAD3E2B5D1E1B6D1E1B4D1E0B7D2E3B5D2E386ABC180ABCD
133E7604306E4977A24E7896355D775E85979EBEC88AA6B27B99A4A8C5D18DAEB97C9FA9
97B9C06F8C9769858E6D868D6581866B888B5C7A7D6480846683856784856B8888688486
5F7B7C5472704F6F6B4D6B6B516E6E506E6E4F6E6C516F6C5775705D797566837F677F7F
647E7C60767459726D526C64516C5F52675724A91E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00885311613D13553B1E
644F3A644C406D47415C221F742E2D6C1D1E6E1C1D601818743C3E73434867333A6A2934
6C192672101C87242E872C366B19228640477235397B42468F5E659668718F5F6A8E5B66
8D4C59702A33AB787CB39CA0ADA6ACA5A4A9A6A6AAA4A4A8AAABB0B7B8BDC2C4C6CBCDD0
C0C4C9C1C3CABEC5D37B97C10E489D044FB53172B9BEE0FADBE4EBDBE0E6D8E0E7D3DBE4
CFDAE4C6D6E1BED0D8BED0D7B7CBD3C7DAE6C6D9E7AEC4D399B2C08CA6B2ADC7D29EBAC7
B3D0DDBFDBED9AB9D492B2CDA4C0D6B0C7D79FC3E329649F256BA88AC6F24781B62B6DAC
74B2DEB6E5FDC1E0EFC6DCE6CADDE6CBDDE8C6DAE5C9DDE7C9DFE7C9DEE8C7DEE8C5DEEA
C0DDEAC0DBECBEDCECBBDDEEB7DCF0B2D8F0B3DAF5B2DAF8AFD9F7AED8F8AFDAFBA9D4F7
A6D4F8A5D4F9A1D0F6A4D1FAA1CEF69FCBF59BCAF398C6F196C4F197C5F45589BE4C85C5
0E4092023185427BB687BAE198C5E378A4BFA2CAE2A5C7DF6F93AB93B6CD6D94A75E8695
7397A270919A6E8D959AB6BD728E9493AFB4829DA2617C81648184607D80698687698588
637E815673734D6C6A506D6C4F6D6C4E6C6B506F6D52706E57757054716D55726F668180
6984838EA6A56C827F58716B536F6351685A25AB22
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00905D17624113533B1E
5D4A345A4132572A215B1812742621661B196D2E2E713E416C3C4261282F5A11186F1C25
791C2575101A81242D80353C71343C8F61688661668E646C89515E8139487D3140A35B68
8F3E4AAA555F96565BC2A4A6AFA7ABA8A9ADA8ACAEAFB5B8BAC1C5BCC2C7B6BBC0B4B5BD
AEAFB7D3D1D7CAC7D0B3BEDC24509A064AB01655A3A7CAEBC5D3DCCBD5DDC9D6E0CDDAE5
C0CED9B2C3CDC4D6DEC1D3DCA7BBC8AFC5D4A7BECE88A2B086A1AEB1C9D4C4DAE5A6C0CB
98B4C0AAC4D2A7C2D1A0BCCDAAC9DCBAD8EC9CC2E4205E9C2B75B39CCFECCEF2FFB7E7FE
88CCEC7FC0E3B6E2F8C8E1EEC9E1ECC8E1F0C4E2F4BFE3F5BFE8F9BAE5FBAFE1FBA5DEFC
9BDBFF8DD0FE83CDFC75C4F968BBF55EB1F452A5ED4E9DEB4190E23C89DD347FD52E79CE
2971C72A72C92369C21E62BC1D5EB71C5AB41856B01954AF1750AD164CAB0D45A40F48AB
0A3FA702339A0B419B1F55A2295EA71F51973362A33A64A32F5A953D689F436FA1507EAA
81ACD18DB6D56D94B09FC3DD7FA2B76E90A06E8B995F7B865C797F5A787A627F81678387
6781855A767753716E4F6C694B69654B6A674C6B68516F6B5875715775705E7C79668381
718E8D849D9E8096955F7775536E6752675D29AD26
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A808633F12563C21
5B422F573A2B54281B53130A6620175B1F197648466B3D41592128621A205D09106E171D
7622297521296B252C8D5D64835C658C616B8F5A668844527F27398A2033851B2BBB6872
9749538E3842853D43C19EA1AEA7ABAFB3B7B5BEC0BDC7CAB7BFC4BCC1C8BCBEC5BDBBC1
BDB6BCC0B5B8C6B6BAB8B4C83D5896063D9C11499AA2C8EDC0D5E2B3C5CEAABDC8B5C7D1
B2C3CDA8B9C4C5D7E2C4D7E29BB0BD8AA1B093ABB6B3CAD390A8B39BB3C0C2D8E3B6CBD4
AEC3CBADC3CCBDD8E4BDDDEF6D95AD97BBD0D0EAFBB3D5EBB6DDF1E3FEFFD0E9F4AAD3E2
7CBBD798D6EBC0EDFAC6EDFBC0F0FDA9E4FD8AD4F77BD2FB6ACBFA61C7FC44AFEE329FE8
2795E72090EC1A8BEE138AEF0B80ED0A7BEF0670E80D6CE60D60DA125AD21356CC1654C8
174EC01748BB1B47BA1B43B61A3DAD1B39A81B39A61733A0142E9A122993112890102890
122C95122E970E2A920E2C910F319209298B072684072782082C84062A8105297E052D7F
0B3483153E8811397F2C539529528C33598B4569914C708F56788E5678865B7C85618089
607E835E7B7D5675724F6E6A4D6D684D6B684D6C694E6C6851706B52716D607E7D688684
7B9896809999849B9E637B7B516B6651655D454B3A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047AD0C6841115B3C21
4A29164A26155227194D15095B21156D3A32623132591E24601C226F20265F090F67151C
6D2B306E3A4078515781646A846069763542791D2D8A2633972C3A9B22328E15239B3F48
BF7A82964D5685444AB7989BB4B0B4B6BDC4B9C3C8B7C0C6B2B8BDB4B6BCB3B2B8B3AFB4
B7AEB2B3A8A9AA9E9FA4A2B052689A08358A0C3D8B90B6DCAAC3D2A7BDC8A4BBC4BBD1D7
C5D8DFA0B3BEADC0CCA9BCC7899FA8859CA4B5CAD0C7DAE2B5CAD595ABB9B5C9D5BCD0D9
C2D6DDD4E6EBCADEE7C6E1F0ABCCDDD8F3F9F0FFFFEAFEFFDDFEFFC5F4FFA0DDF4BAFAFF
ADF4FFA5EFFF95E5FE70CEF854BFF14CC2FA32B5F523AEF411A1EF0C9EF50696F3048CF2
0787F50174EF016FED057DFA0375F5016AF00562E62152CE4441B05C399E64379463318B
692E856E2C82722B80742C7D7228777226726B236D671F68611A605E185A591555581658
53175B4E175E4C156048145F44165E3E155F3A165F371B652D19642415642319691E1A6E
1B1F77131D7710237B0B237C06227905227304226A0626670F30691D3D6D2E4F78436689
5478915F8090597C83517275517171516F6E4F6D6B4E6D684C6C67506E6C5271705B7B78
8EACAB9AB4B4859EA15B7577506A6750645C444A37
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB4106B3F0C552C12
4E23134019084F29175123126C34255C1D166522226C2428661C217023295A0F1467262C
80545A73555C735F677A676F8C67706A1F2B8216238F1E28A3363E8511198E1D24832F34
B07C8182585DA78186B6A3A7B0ADB3B0B1BAAAAEB4AAAEB2ABADB0AEADB2AFAEB3B0ADB3
ACA9AE9F9EA08E8F9089919B6179A1062E780A357B789BBF8AA1AEA2B4BDA6B9C0C1D5DC
C4D9E0A4B9C4A4B8C3AEC2CCC0D5DCB9CED4B7CAD3CADCE8BDD0DDBFD3DECCE2EDBDDEEF
B3DEF4C7F2FDCFF9FEC7F3FFC4F5FFC9FCFFB3EEFE89D6FB6BCAF449B7F032A8E837AFEC
26A1E21E9FE31CA3EC0D99E90B9CEF099FF1079FF108A3F6019BF4009AF6029AF90092F4
0391FA0283F30281F40586FA047FFA087AF8266EE96D51B7AF3980C62A5FC62250C92450
C71F47C81E47C81D44C3183EC31B3DBE1A39AE0E2DAE1330AA132FA5112DA3122E990D28
910A278C0828910C2F8E0C2E860A2C810D2F770D30701237660F37620C38650F3E600F40
5910465413504B15533C14562D11552411571E135B13135D0B145F07175F051C62042062
08266318386B2E517943678650758852737E51727552716E53726D577471537270537373
75959798B3B689A2A659727648636251645C3C7F31
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B915723F0D532007
5524134D231157311D61311E6523165A09065B0809782C2F632023703436622F34805259
764853663E4A7A5E6879646D8A686F6C2D3781212C80141CA03D427D24288B4144956466
A68F91A49699A59B9EA8A0A5ACA6ABAFA9AFAAA6AAADADAFABACAFA7A8ACA5A6ACA4A7AC
989CA192979A8C91958491986E87A50628690A31717091B19EB3BDCCDBE0B8C8CEB4C7CF
B3C7D2A7BCC7B1C5CFBBCFDAC3DCE6C8E1ECCBE5F2CCEAF9BFE6FCB8E7FFB5EEFF74C3F6
53B4F541A6E550B5EF3CA3E2339EE039ABEC259EE81399EB0C96EF0693EF0492ED0792E9
0F93E71897DD27A4E226A0DD29A9E528AFEB23B3F31FB5F81BB7FE15B4FF0EACFF11AAFF
0DA2FF0E9BFF0D96FF0B8AFB087AF20E78F43666DB873D94C92552D61B32D2172BCF162A
C30C20C50E23C40F20BF0B1CBC0D1CBC101EAD0713A50413A30816A106149C051390010F
8A010F8C01109608198F031287051281121B923C459F5B638A424F7115287E0A1F860519
87051B84061F8006237906266C0829630A2E580A324909363A0839350F46260D4B1D0F53
15155C0B1861041A610524640E32652649733F627E50728158787D597878547271567575
7494948DA9AC819A9F5E787C46615E55685E2AAD25
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00733A08571C06
5B2313592A196333235D1F1262120B6B13105E0A09712B2C5924266F4548724C50703B46
671E2C66202D8E606A6C4D558263698E6067803842711D2387414497666AA484889C8B8F
9A93979C989C9E999DA49DA1ACA3A8ACA6AAABA8ACA8A6ACA3A4A9A0A1A6999CA29AA0A6
949CA08F989A8894968393997E95AD0C2E660A336E7295B49EB4BEC5D4DCBFCDD7B4C5D2
B5CADABFD9EABEDBF2B8D9F6AED9FC95CDF97ABDF161ACEF3B90E0308CE3238AE41186EB
078BF3068EF60B94F80891F5028CF00695F70193F20195F10596EB119EE92CAEED54C5F3
7DDCFAA0EFFFA4F7FF97F7FF75E8FF5BDBFF3DC5FD2CB9FC1BACFB0F9EFB038AF30586F6
057FF30172EE056EED0460E20351D4064ECE324EC1772B7DB51740C11225BB0C1CB7091A
B3091AAD0516AF0818AD0817A205129F08149707139104148F031294051492061383010D
7C030E7A010D7B020D7C020E70050FB1696EDFB7BBBEA3ACCFB2BCB383906A1321820715
88040E86010D86010E84020E81020E7D02107802107603147105186C051E6508275B0C33
4D0C3B3B0C42280E4B1A15570F1B60081F6305225F1334663257785176885A7C83628082
728F8F88A4A76E888C5672734966605B6E6322A41C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723209591804
612514662F2153140A6A1C16630B076D1312590C0B703A386A424371484C643038702732
70111D680B158A4D54815C64856B748D737B6E484E8D6166937276948187988D95968E97
9991999B9399A1979CA2979DA79DA39F9AA09B9AA09A9A9F939498929599959B9F959CA1
8C9498909C9D819293819497849BAE1D40721947828DB6DEA2C0D8B2C9DEB8D0E8BAD7F5
AED5FD81B4EB5C98DC4385D82C77D7146CD8096AE00971EC0671EF0270EF0273F30278F6
0182FA0087F8028DF70190F50194F6059CF910ADFE1BB5FF33CAFF45D2FF54D5FF66D5FD
68C8F66CC3F550ACEB349EE71C92E9128CEF077DEA0879EA0772E20868DD085CD60D59D6
0F51CB1247C21942BB233EB42230A2282C9A3E25877E1F66A81134B0091CAE0819AB0617
A504139F0110A106149D0B16860A118523288F3A43893645741727780A1B7C0A16721018
78282F681C255B0C1664121C5D0E1A905261976E7C502F42776070D4BFCC7742506E0D1B
74040C77040D78030B79010B78000A7C020C7B03097901087A010A7C020B7C030D790210
77031772061F650A29570F35400E402E14501A17580B1A5D07225F0E30603C6080628595
7393988CABAE6480824F6A684B665F5E6D620ECE0A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0079350F581706
6C2D1F641F165D0C0869100D6209056C201D66302F6C4946674645562328631B24863039
700C15720C14772D359671798B78838B7C8787777F87757B8C7D848D838A9089908F8892
928B94988F96998F96978D94958E95949097908F959191968F8F958E92988D9599969DA3
929A9F93A0A287989B8D9FA693AAC13D61990C3E8B5F95DD568AC95A8BCD669BE0417DCB
2C6BC70F51BD0950C70651D00457DC0262E90064EC0067EF006BF20171F40378F7047FFA
078AFD0A92FF0D97FF0F9CFF0B9CFF0C99FE0694F80791F3098EEF0D8AEE0C85ED0D7FEB
0E7CE8157BEA1471E3156ADD1B64D9235DD42E55CC374FC23B42AD443AA04C359A553598
603793632D846A287B7627777A236E7B1F697E1759971545AA0D28B0091BAD0617AD0817
A80716A406149E07138F121ABE7072DEB6B9DCC2CBDDC3CFCDABB888505E5A1722BA898E
D7BDC0CAB2BAA48B91C8ABB1865D6A4F1D2E9A7684AD95A28E8390C2BCC78A6E7C561E29
793A3E6E2D315C1317610E1465091066040B6C040B700208710006750106770106790108
7A010B7B010C7A020D79031273051C670A2A530F35360D3E1F12490F1652051E571E4472
749EBA8FB5C465848856717049615A57605300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C391162210E
7531255E0C07660B096C141163181276403B6F4F4A6A53506C4F4F5F292C5F0D138D3238
73151C71171E6D2C348B6B74887B84847982847982837780857982887C858D838C8C858E
8E87908C858C8E858E8D848C8F868F8E878F918D9492919792939895999E959CA2979FA4
98A1A895A2AB92A6B781A0BD6B93C73060B001339A0539A50D44AF0541AF0850C20650CB
033FC20134BB0138C2013CC8004CD7076DF40473F8077BFC097EFD0B80FF097EFC0B83FE
067DFA0379F50274F10173EF0272EF046AEA076BE70865E11264DF175AD4245AD23257CD
4457C8514FBF634DB97049AE74409F803E998334898E3284952D769F2F729824679B2567
98216197236091225E8A205C8A24628425637B215F892059A3183FB81029B60818B90B18
B80C18B30916A60B189C2431F9B5C0E1B7C8996B858A6178CCB9C6CEBFC85B424CCEBDC6
C6BAC78A7286B29AAACCC5CE948893786471CDC0C9AC9FAFA79AABC3BECC9086948B7882
C5B4B8BAA9ADB59EA1B49398603239A36B75661F2963030E6A01066D01066F0003720106
7502087401097701097C010A7F010B7F031078051668051D5A0C2C44123F24134D0F2163
1138755885B07EA4B9617F8351666046493800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C6C0B6E3118
651E11610A05630C086A211A74393172443E6D4944735451634544703C3C621012711C1E
813D3E794748825F657E6C727D737A7F757E7D727A8377817E727B80737E857A84847D86
877F89887E87897F8890858D93878F938A919994999191969A9DA299A0A599A5AD99A9B6
98ACC2829DC2577EB51E529D0F4CAB0945B1012FA50126A00024A0002CAB0345C50650D4
0037C3002EBC053ECE064AD80459E7096EF90372F90473F80470F30167EC0462E9035ADF
0558DB0B58D90E51D0104AC61C4AC12C47BB3D48B7544AB56644AA743D9C863E9794398E
9F3485AB327FAD2D79B02F79AF377A9C3272953676923C7E8C3F828A478C7D4A926B4590
624A965246944B4D9C454EA23B4AA43649A83147A74D48A4883378BE1D43CE1727CD141E
CA121CC4101BBA111EB01C2EB33C52A039537E203C6A263EBEA6B2D5CED6776874CFC1CD
BBA5B6632A46662B45D1BBC89A939E968E9BCBC0CE634059552740BFAAB99B92A09B919F
B7ADB653435292828FBEB3BD584752CAB2BE7445555D08176701076700036800016B0206
6A070A6D10166E08107A030D7C010A7F030B7A010B7B030F7C07167609236311373F154B
1C1D621132754C75A47394A9556A6824A72000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003A9B026C2E0F
560D025C090260170D743B307A433C7339326028227F554E55342D784D495D221F6B3331
89676779686A786B71786D757B72797970787B70797B6E777D717B776B767A707A7A727A
7D767E857B848B808791848A9B8F959D959AA09DA29CA1A89BA5B394A6BE7C98BC567CAE
315C9E1747990B42A40540AD0441B6043EB8012CA600219D0024A4012CAE0749CC0D5FE6
0855E10349D80348D7024BD90657E5045BE9045AE50757DE084ECF0C45C31841BB1F35A8
2D319D4234995432906130887936898834808F30799D3079A62C73AA2F72B13D7CB24686
A546899C4C938D51998A65AE786BB16571B75175BB497DC24282C82E76C6257CD1218ADF
1B90E71993EC118EEA118BEF1288F20F80F2137BF1256CDF7451ADC32F61E4283AE1212A
D91A25D11823CF1D27C71D2CB01B2BA02C3AB1646ECEA7B0D5C5CFD6C1CE765565D3BAC9
C7A5B775243F732037D8B5C2A699A7A194A5CBBACA632E475D192FC5A1ADA993A276556B
CFB3C289748381727FC2B9C4544452C5B1C07B51625F091A6B01096900046B0205690308
67181ACA90926F232D720815760A1072070D72020B79020C81030E870513810516750C29
5A18482F206211286A466891556B7525A72300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049AA0C6C2D09
5710015C140572362571392D642018772B23651F18824E4672524979605A7B625D796361
7A6E71736D73736D74706970726B71786F77736770766872746771756A747970797B727A
817980897F8890858E9589919D939EA39FAE9EA8BE849ABD5477A82F589B134496073B9A
0438A00338A40334A4012FA40034AE0136B40638B6002CAD0430B50336BB0546CD0758E1
065AE60751DE0748D40946D00440C80D42C51C3DB82B31A1422E93522A84612577712470
7C22668722639126659329669C326F973A7891488A855199795AA36F66B0646FB7607CC2
577EC15884C06698CD6FACDD75C5EE64C8F157CDFA48CEFC44D2FF34C4FF25B8FF15ADFF
0DA9FF0CA4FD0B9DFF0892FE0787FD047BF70675F30F61DC5348ADA92862D31D34CE1120
CA101EC30E1AC2121DB41520AD3940E8A9ADE3C6CCDBC3D2C79DB493506C79354BE1BBCA
C199AB79223A802839E2B9C4A48D9DA08A9DD1BFCC6B42535D2939CBADB8A789995D283F
7E4F60A98E9BBDB2BCBEB5C1584553C8B3C17C5162650C1D71020A7000036D0105670408
5A151AC9A4A87038436A10209A4951A25A6168101A6E0610750610840A1589070F8A0512
850E24691B4831205F12296138536C22A72700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B1136A2A06
5C1B08672916793E2D67231763100791392F65160B6C322779595078696379706D777071
7772786D666F6C666D6C666B70696F72697174697174667070626B6F636D776D7580767E
837C848A858F8F8C999293A8868FB1687BAC375798164292083B99073EA60438A70336A7
0032A20132A2022D9E0530A60738B10437B4063BBB0333B90331B80430B90332B90C44C9
0945CA053DC2012BAE0123A1011F9520208A5E2B847A1E69891A5B8E1B578A1B54892660
80326F6F3A7D684E975A539F4F5AA74268B7387AC8348CD8339AE435ABED33B2F14ECBFB
72E3FF90F2FF9BF4FF98F1FF7EE5FF55C9F931B0F226ADF61EABFA109AF3078CF20180F0
0381F4037FF50074EF0067E90161E8005DE20058DB074BC9393AA18D1F5FBE122EC30E1F
BF0B17BC0915BB0D18A0131EE1979EE5C9D1C09FB197597487304F861D3B95374CF9BCCD
CB8CA07E1932963447F0B7C4A5758A8C5971DEBFCDBEA6B3B6A0ABD1BEC8987585976274
C599A75F4451A3939FB7A6B466505ECDBAC67F576665102175030D770106710104670307
58161BC6A4AB6A39485E10228F525CB98B9454162385414A914F57721824850E17940E16
960B1787112E5A275D192362183156327A3800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDB0C632200
5B210976402B6929186C190F75140D781B11813727814E3E76594E746661776E70777177
78717A756C766760676963686861676E666E72697074656F75646E73656F766C74807A84
818291848EA56D7FA4405A911B3E870C368F04319704329F0131A40130A50130A50233A8
0236AA0539AD0334A7012CA00535AC073AB30839B5072DAA0B239E101B8F19137F23157A
342F950A1A85011A8600167E0415761D106764256E782464783073693C84513E8C3D4698
2B50AA1E60BF1D80DC2096ED1A9AEF26B2FB1AB4FC23BDFE30C5FF30C0FE29B7FB24A9F3
2DA6EF2696E32699E6259BED128BEA0982EE047EF10279EE0279F00170EE006AEB0066E9
005FE10267EA005EE40056DD0053DA0157DC0357DB0347C6303EAB84256DBD1437C70F1F
CA101AC60B15C10F19A91D26F0ADB6E1CAD48D6879955469DA91A3D3788D96253CC35066
AF39509F142DA51E34CB5A70A2354F8F203BBB6379D492A7B88096CF95AB964B6283364A
D59FADCCABB6CFAEBC916679855D6ECBB6C0B39AA48B4D5B6F09167A030C7701066B0407
632528C3A9AF6C4D58521C2983545FB58F9B4D1F2CB7919CB398A19C6B776F1F28801922
9317228E142D6326561F256708204D343E3E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00672B02
6B391C76462F6C2A1A6C120A7A150D6D1408925443916D5C755F55665955776E6F726B6F
766F77736B765C555E665F686B616B6B626B71676F70646C776A74756D77787685717892
566A912C4A8310388207348D033194022F9A012C9A012B9C012CA00331A70333A80233A9
0237AE063EB40836AB032696112E9B182E9A2929902D157336095B46084D5F0E496D124B
601B5C1F0D5F041877001B81021D85142B913444A72E44A6224DB21860C81474DB198BED
1995F80D8FF814A3FF13A7FC0D9EFB12A3FE0B9EFB0792F6048BF20182EF027DF0027CF2
0275EF0271EE0273ED0175EE016EED0068EA006AEB006AEB006CEB006BEA006AE7016AEA
0066E70067E9016AEC0267E80162E30162E60160E40558DB2E52C5803685C31E44D41321
D8141CD5131BD2151DC01A26E17787F5C1D0E5C2CFE8BECBFBC1D1CE6D85AC1C34BA1327
BA1123B80C1EB50B1DB40E24B30D26B00E26A61026A61B349F1A35991731961028911024
8C1F32A0455A953B507C1B31964054B87D8CC798A5B06F7F6D09197C010C7C01066F060A
804749C2B2B7C0B1B984646D8B6D75A68691532A37C8ABB8685461997B8BA8828CD19CA6
7C223184193461275920276A051D4F18612800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A3F0A
6C3D1A6E40277439256917087A21117A31209266558E7569817269685F5878706F71686C
756C746F666F4B424B575059675E686E646E726872726C7573727F6870874B5C821E3871
072B76042D86032F91022E94002893002896012A99042E9E012FA00131A30433A60633A7
0934A80F30A11B289121136C3C17644E11586B1A5970134A6E0E3E660D3B5D0C3F54114B
522D75252B870626950129A2022DAB023CBC0B56D60B63E20E71EE0B7CF50C87FC0A89F8
067FF1037AF1067DF2057DF20072ED0070EC0073F00069EA0067E90066EB036EEF0069EA
016CED006CED0172F10174F00376F10277F0037EF40281F20387F40389F40A90F80489F5
0287F5068DFA0084F50180F5017FF6037FF70177F30470EF2267DD7749A3CA2957E61E2E
E91E24E31C20E01B20DB1C28D02A3DD5556DE07A91DB7792C6506DBC2744C6182CCB1421
C70F1AC10B18BF0B17BF0B19BF0C1BBD0D1AB70C19B70D1BB50B1BAF0A19A30412A00613
9D091897091A9407198F03148C081A861024871B30861A2C7F071583010A8102076E080C
AD797DAB929C8D6778764A59AD91979A818A5C3C49CFB9C5B4A5B0766271B09FAAB1929F
A66173811F3B6223542526670820510D921C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00647609
6D350E703D2086503678381F74331B996A55917565826F667B6F6976706B6861616D6568
6F676D71686F5850565A54596D69706E67746E697B666A8343537718306606246B012479
012887042C91002A91012A94012A95012A96012A98022B9A032D9B072D980E2A931E288D
31207D401567571458620D426C103B6B113E5E1448501550380A4E290D5B1A116A141D7F
13349E0C3BB30130B10538BF0942CB0341CB0855E00760E80563E80261E50265E70160E1
0159DA015ADC005ADD005BE0005DE2005FE30265E80169EC0067E9006DEC0073F00175ED
027BEE0484F10687F20A89EE0E8EEE1492EB1B9AEA21A5F020ADF417A8F01DB0F11DB1F8
12ADF90FAEFE09A9FE0BA7FF07A0FF0B9EFF0A94FF0B8AFF1D79F47866CDC83671EC243A
EF232AEA2127E31B24DF1923DA1927D41B32CA1B35C91B38C81633C50F28C50E1FC60F1C
C30C17BC0A15B90812BD0B15B90A12B80C14B30811B80C15B60B15B00A14A3030E9C020C
9B030E97010B98050E92010B90020E8D010F8B030F88020E86010C88030C81040A6E1217
CAA0A38866736121396A243ACFA7B3C4AFBB816D78BEAFBA82767FC4B9C5C5BAC6957784
AA647690243E731F473422590E1C460C8E1700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048A809
6F3004692B0D7F4A2C8051348A634A8C715E8674667C6E646D605A746A67504747665D5F
696366716A706A6469615F66696B7764698248527B192D6305216403217302237E022484
02268A02278E01268F02289302269303279105268F0B238B1621822A1C7444196660195B
73154D7A1142761341691A47542256311A5E212478162B8A081F88051E8E032397032FA6
0B46C00E4ECA0035B70639BE053ABF0136BD0441CA024BD20045C90047CA0149CD004ED0
0152D20056D5005BDC0061E30065E60571F1006FEC017AF20382F5078BF60890F21192EB
25A2EA3DACE858BAF16DC5F383D7F895E5FE9DEFFF8FEDFF77EAFF58DAFF56E2FF3DD0FF
20BCFF11B0FF08A8FE07A1FD0498FF038FFD0280F90278F9096BED4A5ACC9B2D77D21B3B
DE1927DA1422D40E1DD4111ED1121FCC1020C50C1CC70D20C60C20BC0719BE0A1BBE0C1C
BA0916B70814B30812B30914B10811AF0811B00711B10712AF0812AA07129C020C97010B
97020D95040D8B01078900088801088701078602078200068301098201097D050C772227
D2ABB0BBA2AB9E6D7F6F233A954E63C792A6916C7ED2BAC7B0A0ABB8A6B6C4B5C3D0B4C0
AA677897253D841A354E1D40251E3909C70A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052AF0E
7129026D250A874E338E664C8B6F5883715F7B6D618173696E5E5773635F4E3E3E625455
6B61646F666D79758064677A4C58781C2F63081E64031D6E021D7604217F042181021F80
02208302228A03258E04248D051F850E1B7B1E166B37125E5615566F15497B1540791542
6D1A4C591E58402065231F6D122680092D930633A5083AB2032FA8052CA6062EA8032FA8
0437B10944C00032B20029AB0126A60026A50132B30346C80146C70049CA0657D8045EDE
0262E10167E5016EEB0478F4017EF50288F8018EF70699F413A4F233BAF652CDF97AE3FE
9DF5FFB5FEFFC3FFFFC6FEFFBEF9FFABEFFF8BDFFA69CAF648BEF52AAFF216A2F00D9AF4
0390F5028BF90286FA007FF8027DFA0275F8016BF10468F20560E72558D0683B95A92156
C01534C3112BBE0C24BE1126BA1126B60F27B20F25B10D26B00E25AD0E24A90C23A70A22
A60A1EA60A1EA50A1DA3081CA20719A30819A50818A50515A30615A1061696010D95030D
9905108D01098300068101058000067F01077C00047B00067B01067B0107750209711019
98535FB48392C78EA07A2236790A2182162E7F2239C78196D19CB0966C80C5ABBBB597A5
B26F8095223984122757142811C80D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BB613
772B00742A0D763D258C695188705B81705F7F71657C6D6479686177655E685552615151
6F62676B63716465802E3C69081D5A01176300176D021A77011A7A011B7D031A7B001271
021572051D7D081C7D12187122105E4211535C0E426E0D3878133B711A42602355452465
27217114257F09288B0630990536A6053AB0063EB90A43BF0536B000249E011E9A001B96
00219D053CB90237B90026AA0024A60026A80031B5044ACD045ADC0363E4046CEC087BF7
027EF50486F9048FFA0799FB07A1FE0EADFF15B5FF24C5FF3BD4FF51DBFF66E1FF6AD8FA
6FD4F961C4F452B6EE3FA5E4329EE52095E61593EE0B8FF2068EF4078FF90385F7027CF5
0176F30274F3006BEC016BF0026CEF0164E9025DE1035CE10156D90B51D02843AE583083
7824638220597D1F577822587425596E1F576D20586A1C556D20586A1F56641B53641A52
671B5068194C691949701D496F194474184279163D7B11377C0F31811030840E2B870D26
860A1F7B061675031173020D76020D74020A7001066F01056F02066E01056E01066F020B
750819730F2378172A7E0D1D8704129106178F071B8E11288F1E37873147E7B4C5E3B0C1
99405591172F76102729881300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7D36036D2A0884543783664D826B587C695A7A6B5E7D6F657C6C637263596F615A6F6365
6D6674484D6C16245503185C02196803196E021671011774011A78021B79051A76010C63
070B5F151060240B50400B455C0C3B6B0C336C123B601A4A481F592E21681723770A2786
05299206309E0432A20535A60837AB032FA6012CA70233AE0330AA001E99001894011A98
0127A80842C40341C7012FBA012CB6053BC40442CC0452DA076DF10679F90483FA0792FD
099AFE0B9FFF0DA4FF0EA8FF05A2FE09A7FE089FF90BA0F7099BF20C9AF30B98F20B94F1
0D94F40A90F3088BF50585F60480F50581F7027BF60177F50278F50274F30170F00067E9
0063E60161E3015EE2015EE3015EE0025CDD0155D40355D2014FCD0249C9094BC21741AF
2539A02A35982B399B2235962136961F35951A31931B2F931B2E911E30941A2D90192C8F
1C2E8E1B27871C268222298223267B2727782D277430206E3320693A20674423674A2361
54285E522352501D46491033500D2C540A2155061657030F5B030A5C03096002076A0106
77020E78021075010E7D010A8A020A94051094030F9907159908198E0E21AA4157A9455A
9D223793132C6D193A264F2800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C49107A411989644379634878645075635278685A7A695F7A685D6C5A506E625E676470
353C5C08194D01155902196702176B02176D01136A01156D02197104186E0A1364180C53
2D0A464C0E3F5A0930620A2F5F103A4B12463318591D1E6F0E2580082C8F042C96022D9D
032FA20330A4022EA201299C001C8F00188A00198C022DA20331AB0022A0001D9F0329AF
002DB60648D00450DA003FCE013ACA084DDC034CDB0760EB0979FD047FFD0587FF0991FF
068DFC0184F70285F90080F60183F80287FB0184F80283FA017EF6017DF70182FC017EF9
0179F6027BF80178F70277F70072F10371F2016CEC0268EC0267EA0466E90162E5015CE0
015CDC0058D70155D50257D90156D40256D30050CC014CC7024CC80249C70147C20346BF
0645BC053FB8043DB5043DB4023BB0053FB2043DB3043CB30238AF0437AF0333AA0435AA
0435A90231A70431A5042FA2042F9E042F9C06319A062D95062B93072B9109298F0C298B
0D288210287C14257517216E1F2167271F5E2B194C2B0E362E082634061C3F0516550515
6D071973031573010F7B01098D080F93060F91030B96040E9E08129A06129A0A19990D1B
9F14228F19326027521E184311901900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
3D9E02764016866440756042705F4670624C6C5C4B746253705D4F6B5E55605E64252E4C
05164A02175C02176601166902156A03166A011366041466081360120B4F2C09434B0B39
5C0A2F620C2F58113A40124A24115913186B081E7C05278D042E9704339E0331A1022FA3
012EA4002BA200299E01249700168700198A0020920536AD033EBA053ABD002FB70132BE
0136C5054EDA0E6AF3045BE8074FE10448DB044ADC0961EE066FF6006FF40374F90070F4
026FF4006CF2026FF6046FF7016DF20170F4006EF00270F2036CF2016BEF016FF1006AEE
0066EB0067EE046FF1016BEC036AE90264E40160E10262E2015CDB015BDB0159D90255D6
0155D20155CE0152CF0253D10053CC0151CA0151C90350C80350C4014BC20148BE0247BD
0244B70140B4023FB20341B20341B0023FAD0441B10441B10340B0033DAD033CAA043CAA
053CAB0338A70337A60335A30233A102329F02329E01309C012E9A022F9B022E9A012C95
01299201299102289004289003278C06278709227C081B680814550B1048110B3C260F3D
3F123F4F0E355A082471071B8408158B04108D010B980510A70E14A2080EA0070D9F0B12
9209177D1C3E4429620C1A4F155A2600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B00D7B4612805E33735F3D6B5B406A5C43695A426C59446B5B4E5854571B253D041643
01165302175F021463031467011162031261040D57110C4D23063E4108325A0B2D5D0B2F
500E39340D44190E520E186B051C7B03238802278E022A94022A96002A97012B9B002CA0
012CA4022FA70230A8022EA700289D002A9E0134AC0343BF034BCC0850D40342CC043FCC
0542D1034DD80B67EE0C66EF0146D50039CB013BCC0245D4045AE60160E90262EB0263EA
0162EA0160E80162E9005EE60162E80365EA0162E70061E5005FE30160E20160DF015EDF
015CDE0362E20363E40160E0025FDE015CD8015BD7025DD8015DD6035DD6025AD20156CB
0155C70253C50252C50655C60756C50855C10551B90851B6084EAD094FAA0D4FA70B4BA0
0F4DA00D4998104894124A95164D951A4E96164A92164B9216499015468E13468C15498E
14458C13448A1041870F3F880E3E870A3884093885063384043285073689043387043085
042F86032D88022B8B012A8E022C9001298D03268A02238203217B031E73041A6C061969
0F18671A175F2B18514316465C1237710E2B7F071C940A19A50F16A60C109F060A9D0912
8E0C22671E4F2E2C7409215E1D223400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C5510825F2D6E59366D5D4169593F6D5B436E5B4B534B4A13192D03143A02174B
02165502165A000F5802115D040D560907471C043936052C4C0726540B2A490D33310D41
150B500A1666031B7302217F012589052C94032C97012996012696022999012A9B012BA0
002CA40233AD0138B3023CBA0541BC0440BB0649C6034DCD0455D70757DB0347CF033CC7
063CC9003BC60351D70653DB0038C50233C30132C30037C5034ED80258E00057DD015ADE
015BDF0058DC035CE00059DD015BDE015DDE025ADC025DDD015CDD015AD80159D40059D4
0058D30159D2005AD2025AD2045BD1055CCF065CCB075CC60C63C90D5FC10E5AB5125BAF
155BA9195BA51F5CA4225A9F265F9D2B629C30659B37699B3A6A963F709743749541708E
4873924C7491507791567E94597F955B7F96587C93587A905A7B9052738A5074894A6F82
51748C5B7F955A7D935E829A5579915378904A6F8A466A893C608231587A355D8032587F
2E547D274C7A22487C143B750C3675063074022A7302297502277802257A022479012279
021E79041F780821720D1E6A1D1C61321A564F18476F1434870E1F990C16A1090FA20B15
8D102A622B651B297507235F0C922000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00788E13896026745A356B573B6A59406F5E4C5E5350181A2B031234011343031851
031759021457020E52070D4E1509402E07324507254F09224209272C0B38150D4A0A1560
031971011E7D03258503288A03298E01289101289700279900289E022DA2012FA30132A8
0237AF0139B40442BE0245C3054ACA0247C7044BCB024DD00250D4054ED30039BF002DB4
032CB3002DB50544CA094ED40036BD0133BC053EC7003CC3044ED30457DB0257DC0258DA
0257D90155D60156D50155D40155D40258D70257D50157D40357D40358D0045ACD065AC9
085BC30959BA0E5AB8135AB1175DA91E5EA62562A12E68A1366FA24276A54D79A2517C9B
578199597F9565869B6786986885936C8894728E9878949C728F95719192719191789597
7D979C7A9399829C9E89A2A38AA5A590A8AB90A7A990A7AA92ABAD8EA5A893ABAA8EA5A5
94ABAD9EB5B59CB3B595ACAFA0B8B896B1AE92ADAB8DA6A88AA4A7809BA07C989D79939B
658289607E85607F8A5879884B6F823B6279335A76274E6F19406813396A093065022965
02266C0226710225740425770425780925771824712F2161531D4D781535950F21A91724
8D1736522B68142B770420580A8F1B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CDD099566217A582C6C53366C5942655A5121232F04103101113E011449011552
0416590410520C0A451D04333F0A2D500A254607232E082D150A3C070F52031565021A74
03238402258901248901258A01268D002892012A9A022DA10130A70134AB0238AF023BB2
0440BA0341BC0344C10145C5054ACA0445C60342C40146C80248CB0343C80235BA0026AA
0126A90128AC043ABE0A4ED10141C50343C6084FD0024ACB0550D1004ED00251D20051D0
0254D20153CF0254CF0253CD0556CD0456C80758C40855BB0953B0145BAF1C5DA92863A7
3069A03F73A14E7CA25580A06088A06386996586946886906D89916F899271898F738B8D
768C8E799192849A9D83989A869B9D879C9E8BA1A1889FA089A09F8AA29F92AAA694A9A8
97ACAC9AADAF99AFAFA0B7B5A5BAB8AFC2C1AEC1C0AEC0C0AFC4C2B3C8C6BBCCCBB6C6C5
B4C5C5BCCBCBB7C7C8B4C5C5AEC1C0ACBFBEA7BDBD99B1B195ACAE8BA4A77D969B819B9F
738F8F6D8A8A6A85876681855A787C5474774C6D6F45676C3F6067385A66325764284D61
1D445E173C600F335E03285D01276702287304297B092A7F1D2E7D3D296B671E4E8D193C
832049462D6F0E2C790B255A0D8F1A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0028DB0A7F571F6447266D5A4837333506122802123902144401144B00134F
05114E0E093D29082D4408214C08213A08291B06330A0B45021157011868001A75012183
02278B02288E02288E01248D012791022D990130A00233A50437AD053DB4023BB30139B3
023CB6003BB60140BD0140C00341BF023BB90031AE0238B5023AB9023BBB0335B70126A8
0124A70226AB0130B3094BCC0349C9034CCB024EC9014BC6024DC8034FC9024FC60451C3
0650BF0852B80B54B11055AC1A5AAA225EA22E69A03D72A04C799F5E85A562849E6D8A9C
728D98789297708A8C748D90779091748C8C768F8D79939081999879908F839A98899D9B
8FA3A18DA1A092A5A59BABAC96A5A59FAFAFA3B4B4B0BFBFB1C0C0BDCDCCB8C9C7BCCACA
BECECEC1D2D5C2D5D5C7D9DACADBDCCBDADBCADADECCDBE0C8DADDC3D5DAC4D5DAC3D3D9
B8C8CEB8C8CFBAC9D0B3C1C7A8B7BDA2B3B997ACB08DA5A8849DA27E979E7891996E8A90
6B898B658284607C7F5E7980577578516F704E6C6C48676744636142615F3C5C5A3A5C5A
3457563456592F52592A4D5C1C405911355B052D60022A6D052E7F1032882A2E7E502466
5E2D6C302F7B0C2D79122855108F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006A88185A3C13584B3D10151F02132F02153C021544011546071346
150B37330A2844071B430A20270429110A3E040D4F02145E011869011E7502227F012587
02278E01268E012890002891022D9803319F0131A30235A90336AC0135AB0136AC0137AD
0037AE0139B1013AB4013AB6023CB70137B10130A70030A60134AC0138B50436B60027A7
00219F0123A40029AC0440BE034AC5034DC4034DC0044EBA0950B50B4FAB1452A41F559D
2F619F3F6EA04E7AA15A83A261859F6686976B8B92708D92738B8F758A8D728688788C8E
758B8A7B918E8096938398977F949382979591A7A392A9A698ACAA98A9A9A6B6B5B0BABA
B9C4C5BAC7C8BDCCCBD1DCDBD9E0E1DCE3E6DDE5E7DFE5E9DBE2E8D5DFE5D4DEE4CCD4DB
C5CFD5BDC8CFB0BCC4A9B3BBA2ACB5A0A7B097A0A99399A48D929B868B937B808781878D
767E85767E86757A83757A826E747A6E767B6874766674756372766170755F6F735E7276
587172556D6C536A6C51676C51686C4C666848656549676542615D3D5E5A3C5D593B5B56
3958533656503856523755523353512D4F53264A551C405909305D0530720C35831C3789
2033861232850C307319244200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB4116C4D20352D2308132102153402153C02144006123C170C30
390B2549091A3403161A05270B0C4203105501146301196C02207502237C012482012688
02288C02278F022993012994022C98022F9D012FA2012EA40130A6012FA40031A50134A7
0439AD0338AE0135AB0136AD0137AF0239AE0238AD0338AB033BAF033BB50337B4022CA6
01249D02249D0028A0083FB00A49B00C4BA518539E2359973768994D799E5E819E69849A
79909F72899370888D6E84877186887086847089847288867C93908498978194938B9F9D
8A9E9C91A4A29DAFADA1B1B1B4C2C0BCC9C8CBD8D6D4DFE0DAE6E8E1EBEFE4EEF2E5EAF0
DFE4ECD4DBE5C6CED7BCBEC7B9B8BFA09BA296909691888F8780877D777D787276776F71
796F6F786E6B776E6A756C66776E68786E69796E6A7A706A7E71697E6F687E6F667F7168
7B6F65786D637A6D64786B60786B5E786A5D7268596F65556D65546D6558696156656355
5E6153595C4E5B5D53575B54555C56505C554B5C534C6057475D56435D573E5B543A5850
3D59513C59513B565038545039574F39585233544F3352502C4C54183B530A325D063475
0A3D8E0738871130650F911D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADD0B765526221D17061529011534021437030F33130727350A20
4509192F0315120321050B3E031358021767011A6F01207901237C02248003278703288A
002388062B93022894012691012892012996012A9A02299D01289A022C9D012FA00134A3
0135A60034A80135A90237AA0238AD033AAE023AAF0036AA0139AE023AB1043AAF0432A0
03298B0629811438842751913965984F779B61839B6A87956A858C778F93708688708487
74888B6F8687718786768B897A8F8D839894879D97889C969BAFA99FB0AEAAB9B8BDC9C9
CBD7D7D9E4E6DFEAEDE3EDF2DFE6ECDADDE4CCCDD6B9B8C3A7A7B295939F87858C837E82
7D777B7A74787972757A71717C716D7F6F6C806F6786736985736781706283715F836F5D
836C5A806B537B6A4F7D6C507D6D527D6D557668507B6D547D6D55806E577D6D557B6B54
7C6D567C6F57796A527B6C5376684C76654A76654A74634878674B7B694F7C6B52796C51
776B4F75684E7467507066506F67506D664F6B664D64644D5E634E565E4C505D4B485949
445847465A4D41574C3D544C39534B36534A3958503B5A5137554D2C4B47214249113852
0733610A3366172B490AC80B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007B55241F1A1307192C0116320411300E06212E07193F0917
2A04150F041F040B37031453041B68021E7402217C032582032583012383042687012284
03268B03279001269101258E01258E012691012693022695012697012898022C9B0333A1
0233A10132A20134A30135A60338AB023AAC023BAC033BA8053CA3063B98124291244C8B
3E5F8E547092607A91667E8B6981876E8588708688768A8A718684768B8A768C8B778E8C
7F9695809797899E9C98ACA99EAFACB4C4C1C9D8D4D7E2E0DCE6E7DBE6E9D4DEE2C4C8D0
B3B5BCA3A1AA8F8C94837F867D777B7A72757B70747C6F747E72737D716F7E7169817367
7D71627D74647E7462756C57796E5676695472654C73674B73674D72684C72684B74694E
6A5D42695D416960436A62446B6546676144635D406B654B6D674D6A634A6D68506F6B56
6A67536A675269655066624D6A674F6B674E66624966624A6761496C664D6A664C69654A
6762476A62486C644A666146696547686040665C39675D3B6860406661426160415F6145
5D61475A5D49535B484B59484557484153493B53493855483B5A4C314F4327483D214441
1E4248102F3B115B2000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF005F811A21180A0918230415290C0B222504163C0815260412
0D051E030B3100104602195E021E6E001F78012282012385012083022182011F7F022284
03268C03279100228B01238A01238901248A01248C01238E022491012793012B98022E9E
00309F0132A001349F0237A10339A0053B9A073B9017478E2C568D466B925C7C966E8796
748A916D81836D80816B7D7D748786758A88819696809595839594899B998E9FA097AAA9
ADC1C1C0D3D7D0E1E5D4E2E4D5DEE2C5CCD2ADB0B69A9BA087848A77757A737071726C6B
746B68786B67786A647D6F668073667B70607B705F7F71627E7261756C58706851746D57
6D6A526B6A536A684F6E6A506C694E68644C6A654A6A65496C684C6C674B6A6749686447
615D3E656043686445605D3E62604165614465624563614665624864604669674F666550
646651696A5565675267675665665466675266675163624E61634B5E604863664E61644E
62654F62634E5F604A5E61495F62475B593C5753325955315753305752315653305C5836
5D58375D583A5A583D575B43545C455057464C5A493F54433A5343344E402B493A27483B
244639254336139C1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047B21436230811191B070F1B1C0915380A152904110F061D
030C2D01113F011653031D69021F7501207D002183012285012083011F80011D7D021F81
01208602208B011E8A01208B01218900208701238802248B00238C022691012A96022D99
013299023596053A900C3F891B4886355E8D50739664829A6C869272878E75888B7B8D8E
7A8E8C758987758A8A7A8F8F7F9393879A9990A2A1A5B6B5B5C3C4C8D4D8C7D3D9BFCAD1
ADB8BE919BA17E848A74757B7471756E6969736C68716960766B5F766A5C776A57766952
7A6D5573674F6F654C70684D716C507570557A755B77705A746D576A664D67644A727056
6E6D546A6A4E69674B68644868654966654865644869654A6361446A65496B6649696547
646142666344666445646243626243605E41606042605F425E5D40615D43615F465F5E48
62614C6768536767556967576465526A6B5567674F63644E65685070745E696E59616552
6366525D604C5C5F4A5A5F485D6249605F485A5A3E59583B59583A595837575433575231
5753315651325250345153394D513852543F51563F4D58434555433E5241354E3D2D4A3A
26483525473430462F0CCD0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005A390D1F1A10130D12280810310914130516060E29
01113700154B051D64021D70011E7701217E01218101218402238503208200197B01187A
011A7F001A82001984011F8A03238D01218901228701238801268B022C8F032D8E043189
0B38821A467F305984537693678395708992788D92798C917D8F937B8D8E7E8F8F839694
8195928398948CA19F9BAFAFB4C6C8C4D3D6C7D2D5B5BEC29AA0A581858D6E70756A6769
6966626969606F6B60726A5E706456695C47665B3F675D3D6860406D64466B6044695E42
6B614471684D6F694E6B684C6868497171517976587670566A664C6F6E516E6E4F6E6D51
6E6A4F6863466763436661426966466867496766496561456764446B66496B6649696548
6965476663446665456463445F5F40646345646245615E415C593C645F465E5C435D5C41
5B5B4062604864624D69685461634D63664E62654C686B5361654D6265515E614F606453
696C5A5E62525D614E5A5F4B595E4A5B5F495D60495A5C445A5E425A5D3E575839565739
595A3D57593F5559414C543E464D374B513B494F37494F3848523D4554403D533D354E3A
2D4A382646322B46311DA31700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005F80153A250923100B2C0E121D0913090D1E031431
011540021D5B03206E011E74001E7702217C012180022284022183011C7F00197B00177A
031A7E021B80011D83012188002088012388012385032684042A80062E78123B75315682
56779363808F708A92788D90768A8A7A8F8F80939482939587999A8396948DA09C9CAEA9
B1C2BFBECECDBCCBCDAFBCC08F979E777C816A6D6D6666626A675F6B655A6E66576A604B
666046625F426663456A6447675F44685F41665E3D6A63406E69486C67496A6347655C41
665F436C664C6B694D6E6B506C6C4D6C6C4C6F70506C6A4E6C6C506B6D4E6A6C4C6D6C51
6C664D6B644768624167613E64603F666345605F40656143656343676244696447656145
666245676244656342626143656445656346666248615C42635F43615C445C5C405D5D3F
5C5C3D605F4163624665654B63654B61644960634A61644B62674E686A566B6D5B656756
646755636755646856676D5A5A614D5B604A5B5F48595D44555C41575D4153593C555B3F
565B40575C42535B434D59444451404A5645404D3B323C2938432D424F3641523840523B
3A513B324B362E483335422B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DC0B5C360935160526100F110F19051428001636
021B4E02216701217302227A03247E02227E032381011F81011D80021F84011C7F011B7C
001C7E021F82011F820020840021840226830226760A2D6E244675496987648290708890
7387898196937E93907C908F809591899D998FA09F95A4A4A6B6B6BCCBCAC0CDCDAEB8BA
909799787E80696B6B6867656A65616D685E6F6959706A53736A4F70664B6E664A696246
6C674B6F6D506F6D516D6A4F716C51746D526F6A4E6D684B6F6C516F6C536D6A516D6750
6A654D6E6A51706D536E6A506E6D4F6C6D4E6B6E516A6B526C6E526A6B4F636546666347
69634868614468614067603C65603D615D3D5E5B3C605C3F615F3F615C3C635E40645D40
656043656142666344636242626241615D40605F43605F436160445F5E425E5E3F5F5E40
60604160604063634461604563644961604962624C5F614A60624A656550656753636451
61655060654F5E634C5D644C596149586048585E465B5F495A5F49565D46565D44555B42
545A3F565A42535B42505E494856474353472C40322639292C3C2838462F425038434F37
4350383C4E38344B363447311B9D1100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0045AB0E4B220223110B0E162101152D001840
03205C02226C01207301227B022580022381011E7E011C7D021E82021E84021E82031D80
011D8000208101227F03257B0428721539733A5A815E7A90748B977F95977E93927D9190
8899968A9E998A9F9B8B9E9C98A9A8ADBCBBBBC8C9AEB9BF98A0A7787D82696A6C646362
67656174716A7772687972657A73647B75657A75647874617B7662797460797662777560
76756072735D75755F74725E73715C76715B75715B72705A74755E70705C747160757462
7475617576626F6F5B6E6F587071576E70556C6F566F705B6C6C5567674D636446656346
666144666143666140655F3C655E3A63603D605C3E625D405F5C3E605C3D605A3B615A3D
645E41635F42615F405E5E3C5B5D3860603C5F603E5D60415C5F406060445F5E40605F40
5E5D3F5F5F416060435F5F465E5F485F604B65675164675060634D62614C5D5F465C6046
6368505C634C5D654C5C644B59624959624A5A614A595E485B5F4B5A5C4A555844555944
54574251563F4E573F55655047584933453923392C273E2D32473340503D45533F4D5843
49533B454F373D4E3734452F1EA21500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074451429170B0D1824011837001B4C
03216201226D022273012279032580012482022180001E7E032184032186011C80011C7E
001E7C03247904286E183C6E456683708B997E93978293948B9C9C8CA19E8BA09D90A4A1
91A3A19DADABA6B7B8A9B8B9A3AFB1899192717276605F6262605F66635C6A675B716D5D
726F607C7B7081817794938AABA8A0A5A19C9E9C999C9B9693918B93928A8B8D83818479
8084778185767E80717D7D6E7B7B697A786478776273755F70745D6C6D5B6F6D606D6D60
6C715F6E73646C72616C72606E74607476627175626F73617075626B705C686B5465664F
63644C626349636448615F425F5E3D5D5B3E615F42605D405E5C3E5E5C3E5F5D3F605D40
625F415F5F415C5F405D6041585C3C5A5D395D603D585B3C585B3F5C5C415E5E415E5C3F
5E5B3F5D5C415D5D435D5E485B5E485A5E4A5C604C6165516165505D60485B5F44585D3F
595F445961495B644B626752646A555D624D5B604A585E475A5D48575945585B47545845
4E523D4D533E4D59455061503E50412C40322A3F313349373E533E4959474E5E4D4D5D4C
505D474D563E464F373C49303C442400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003BA40B321D0B111C2A031B41021E56
022165022471012375012379032681042887032887022586012486032586012081032178
06276C1F3D6F4D6988718B98819697869592909D9996A2A19AA8A791A1A19CAEACA1B3B0
AFBEBE99A4A87F878A696F6D5E605A5F5D53665E51675D4E746E5D868674999A8BAEAFA3
BEBEB8CFD0D0D0D1D6E1E1E8F4F0F9EBE4EFD6D0DCCDC9D7BEBCC6B8B6BEACACB09EA09F
989C9693958C9091879494889294858F8E808E8E7E8C8F7C8B8E7A898B7B868578828375
7F81727A7D6E7178676C75646A74636C71616971606A72626A75646671636A74656A7465
697363657160606B5A5B64506067515B624D5E654F60654E5F654B5D624A5B614A596049
586047576149556148545D47515B4350593D565C41585B43585C46575C46565C455B5F48
595C46575A46575C495A604E585F4D57604F5761515760515B63515C644F60664F60654E
5B624A5E66505D654F5B64505B634E5C624D5E624C5A60495D634D585E49535C454F5642
4B523C5058465B685946564B2D42352C4335344A3A3E5241495C494E5F4E5163544D6254
5668565E68544E533B434B3140462200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA1B3C2407131B26041B43031E59
012168052A7C01247A00237A002581032C8D022A8E00258601248401237E01216E15336B
4560806D82908090948D9C9C93A19F9BA6A49AA5A497A2A3A5B1B3A3ADB0A1ACAD798586
676F6D5F605C615E5469635168624B6E644D786D537F765D85816A7777647374657D7C73
86848189898A949298B2B0B9C5BECCC8C0CFB3ADBBA29EAA9A97A296949B908D90888784
88898187887F87887D8384778083717E8172797B6C777A6A7579687375677175676F7365
7377697175676D7465737C6C7782727782736C78696974666A796B6C7C71697B7066776C
64756A6172695B6E66566A5E55685955665957665855655659685957665852625456675A
5264575263565467595463574F5F505261515362515260515260524F5E514C5C4E4E5E50
4C5D4E4A574D4E5A5157645D57665C5B6A615A6B625B6A605F6D5F5D6858626959686C5D
6C71616F7665687461636E5D636D5B646A596369575D64505B634E565F4B4F59444E5642
4D55415B665748594E33463D2F473A3049393D5643465D4B4F625053645554655950645A
5C7064606F5E535B44474D3134761D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005D3E121E1E1E051B3B031F56
00226909368B002A86012682022A8A043195022C900126830325770D2D6B3450765D7485
74858B818F90919E9D96A3A28E9D9D91A0A199A8AA8F9D9E7F8A8A646B69595D57585B50
6463526C67516E664D6E64496F664A6B61456960426961436E684B706B4E736D54726A55
6A64526B66566B6557706A61726C6877716E746D68736D68716D646F6C616E6B5E6C6A5C
6B6B5B6C6C5B6A6A586E705B6A6E556B6E586B6D59696C596B6F5D6D72626A72646B7669
6D7A6C6F7C6E727E7274817473827673857B75877D6F81795F776E59726B577269566F69
536B664C646147625E45615B3F5C54415C55415A53405751445B54425951405752435A57
4058553E55523E57523E58533A554E3B554D3C554C3D544C3E544E3F544D44575042574D
40564A3F534C3E52503B515038514F405854425A53455A504A5B4D4F5C4E565F52595F52
5D62525D63545C65545E69596671616A74646870605A645358625055604C4D57444C5644
5661514E5D52364A40374C413E56463F5742405743506555596B5D5A695D56675957695F
5D70665F6E6158614C4A4F3424A41300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7F182C22110A1B32021E51
002168093B9403389901309103349602349605328A04297021406E4C637B6B7E847A8988
84918D828E8C8F9B98909C9A909D9D8390916E797959625C585B4E62604C6A664E726F55
6F6E526E6B4F6F6A50706A5170674D6D65496E65467268486B63406B633F685F3F6C6245
6D63456D634572674B766951716550796D597C6F5C7A6E5B79705A776F59757058716E58
726E58746F586E6A516C6B506A6B506C6E566B6E586A6E5B656D5C656E6166736864736A
5F736A61766D5D726D59716C56706D4E696549636043605D32544F2546421E423C1C3B37
1C3A3717363316373413322F11312E11312E14322D14302C13302C12302B142F2D15312F
132E2E102D2C0F2D2B10302F1033301D3E3B213E3B28423D31453E3A48413E4D433A493C
3A4D3E35493E28413B1D3A381C3A3925443F334F473F574A485B4A4F5C4D55605361695B
606958616959616B5A667160636F5E687262656F5F5B645456615054614E4B5A47576658
4A5A4F384C42394F4341574A485F4E5166544F62515B6B605E6C625B685E5B6B5F58695D
5C6C625E6A5E5B624C53533313D10900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0027DB0D5237121C222B031D48
01266B053A94033EA4023CA2063C9F03358C0B32722D4B6C5568756E797D778180808C87
838E8A808B8A828E8C76827E626B645B60555D5D4E68634E73694E796E51746C506D684D
69684C6D6C4F6D6A4F6C674E70694F716A4D736B4E746C4E716A4A6F68456F66436F6241
7365417769447B6C497E6C4C7E6F4F80715184735685745985775C86785E83795D80785C
837B61847B627F785F79775F7B7C6471745F6F735F7179686C786B6470685869624D605F
3C53522E4948213E3E1938380F302E102F2C17373124443E2F504A3D5B564D6B65607B75
5C7572506B67486460405C564560583B554E3C554D3A514C394F4A344C44334B42324942
2F483F2C453E2C463F27423C24413C223E391F3A35253E38293E35314137364539374738
3243332B3F3020392E17322C0C28241230292D493F3E54464B5D4C566354677265636E60
5965565A65565D6556595F4D5D644F5D63525C62515B6151545F4D4E5F4F4C615344574E
3C524841594C4860524E645753675A5B6D606170655F6C635C6A60606F655E6F6459695D
5D6C5F616C5B5E6348417F2300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0068891F3D31220D1E3D
052D6E09449E0343AC023EA40637910F34723148654F5D62646A697377747A808077807E
757E7C6E76745E675F565C4F5B5C486B664C71684A6D64436D634373684C70674F67634B
6E6B526C694D6865496E6A4F6F6B4E716B4C6D6748716A4C72674A7569497C6F4E7B6C4A
7A6B4677694278694578684775664472644073654377674A75664A83755A7A6E54796F55
7269517169546A6753686A56696C5A6A6E616972646875676979705264612A413F122D2C
0725230A2A251A3A33314F49536E6672897F8FA49CA5B8B2BBCBC7CDDBD8C3D2CEB5C2BE
A3AEAC8A95947A89836A796E6E7A6C646D5F646E615D655960665B62665A5D6457586050
5965525864555B675A5762585160554F5E524F5E534D5E504D5D4F515C4F4D584C505B4E
535D4E4B5948425443415243364A3C2B4337253E2F2D41324C5D4D6673645D695C5C685C
5965575A65565D63515D604B60634D5C604D5C614F595E4F5560544E5F56445852455A54
4A605750675C586E625F726764756A67756B66736A62716861726760716660726759695D
606E605E66525F603F2DA91400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0E6A4C2226272F
0625590B459A0546AA053D94103670364962545D5F575A53696A6472736D737572676B67
5D61595758495C5A43676346726A4A776B4B7265476B62426E67496F684B6A6348706A51
6E69506762496B66496F6B4D6C684A6D6949706946716543716442786B4B77694B756646
74654273653F72654073654271634070633F6F603D6D5E3D7061416D5F4174664C756A50
7269526D68556265535E655561675A626B625B6B64475A562C4441112A290C2A2524433D
4261596C897F99B3A6BACEC6D2E1DDECF4F2F6F9FDEBECF3DADAE3CBC7CDB0AAA99F968F
8F8378857769796E5C736A53766C51776B507A6C51796B4F77684D806B537C6A4F79694C
7C6F508072597D705B796E5C776D5B746B59726A55706951776E547D7055786C52796D54
73684F71694F6562485C5C43595F48535E4B485746394838384938536050606B5C5F685A
5C65535D655061654F61634E6164505D6152576052545F554D5D544A5D574E625C536662
5C6E6761736B6779716A7A7061716768766E66756D67777164756E63746C637369616F63
636E5E65664E655C3430A70C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B318503C28
17284615468C094091133A7332445B4E54545B5E5461635667695E686A605D5F545B5B4B
5D5A426862426C653F7066426F654375694B7267496961436A65486D694B686346726C4F
6F684C6661446E6A4C706C4D6D694A6D67467065416E613B6D613B6A63406761426F6546
7064416E623D6E613C74664271623E70623B71643D72653F7265406C5F3D7265476F6449
6B644B66644E666857646A5B626A5F4D5D582239360A26220A292522403B58756B86A099
9EB5B1ACBFBCB0BFBEA6B1B2A4A8AC9F9BA09A919691868A8F82828D7B778D7B6F8D7A66
8D785E887255816B4A7C68457C68427E6842806B437F6A41826C42876B448568408E7145
91764A90744D89724F897254856E52866F538672538B7452957E59937B58927D5E917D60
8875598272537E6F51756A4D6D674A67634A63654E5B63504E5B4A4954455E6455636656
61644F61654E6367516266545B62565C675E56655E526460536863586F685A6F6862746F
6C7B77707E7C70817B6F807764756D6C7C766D7C766B7B7668777168756F65736B636D63
6669586B63446D582546B71500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00855E2D
342F3226426F183968314256494D4A535449585C4C6063515E604F595B49595943625E42
6D64436C5F3A6B5E376E66416A62426C634473694A6D674966624469684A6E6C4F6B674B
6F6A4D6A6547676243746F4F6E694A6F67476E633F6E613A6C623B6A65406A65456D674A
6C66486E674971694A7065446D623E6D643E6A60387168407269437169486E6949696446
6A654A686750626554535B4F36443C0B221E0C2B242B4B424E6C647B948E8EA19D919E99
89908E7B7E7C70716C716E67716C6579736B837F748D897B9D96849C93818A82706D6450
6A644A7A745A7C765D736F55635E435E593E5B573A5E5A3867603976663F79653C7A6439
76613578643B7868437B6A4A7866477666476E63446C61436A6145665D4765604D656351
60604D5E5D4966634D6C69507570536A6346686449666852696F5E5A6051626556626350
6568526067525C66545F6B615C6C665E726F5D73716A7D7C697D7B6E847E687B7571817E
78878575848471827F70837C71857D71838072837F6E7D786E7B766A756F67706864685A
686148705B2D68902000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE10
583D1F404147323A3F46463D5251405959465D5E495B5F455A5D415C5C3E5C5A3A615C39
63593267592F675B3069613A68623D6C634074684872694B6C67486763476A674E706D54
6D684C6C66476E68466D68466F694A6E65457367447266417367416E6440736A47726949
73694B736A4C72694C6C64466862446A66456A643F6B623B7069446D6846686442666141
6D684B65654E444C3B2C392E50615A4159533452484F6B5F697C73757E78747871737368
7571647C75677F77657D746065634E797D6A989E8FB1B7ABB8BCAE9D9D8F8A8879777767
7174657A8075687068505D5545554A3B4E413548373B4B35434B2F615F40756C4A776946
73633E726441736849736C516C6A516567505C624E555D4B545F4F525C4F535E51556256
5663555C685A555C4C5A5D477B7961726D54706C536D6A5671715F686C5B656956626856
5F69575E6C5E68786D6B7D787185827389877087847D908E7F93917D928E778C877D8F8D
7C8C8A7B8B89768A85768C86758B857487867182816E7E7B6C7A74656E6764695C67644A
6F5C30678F2000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
5C7F1A473419473E2750492F5A553B5F5C445E5B415C5C3D5E603D5D5D3A4D4E2B534F2A
615529635424635627645A2C635A2D645A2E6B5D356E603A706440736A4A6F6A4F6B674E
676449635D3D665E3C6A63406C65426E65436F6543716745756946726643746844776944
7568437668457567477264456D62436B60416F63416D613C6C613C615833655C37766D4A
70694B6060473D473668746ABBC8C3606E6C57685F5362565F685B6C6B5B74705C74715C
73725D77756073725D71705C6D715B7077637D81728183768385788687798182746D7265
5B675E4758553C4F4F2C44441C39351938311A3A2C2F483648563F67684C766E507D6F4F
746948736C4F7C7A636F7462636D5F5A6A5D55675A56675C57675C5D6B615F6E615F6F62
59695B505C4B5A604B706D5775705A75705C74715E7471606F7061656A5B656F5D667366
72847A7A8E897D908D8092918092927F90917C8F8F869897869998859A98819794859796
8192918496938195927D9390778D87748785768585707C7B68736E60665A6360456C5D2F
66912200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59780D5337115544255A4F3062593C635C3E635D3F5A57395455385257384A4F2F504F29
6158296657256959276859286759286357246B5B2B6D5C2F6F5F3572643D716844706A4A
6F6A4C6965456965426C67436D67466F68476C67466A65436B62416F63406D603C6D5F36
6E5F3471623874643C7968427D6C467B694276633B76653B73663973663878693F7D6E4A
746A49636144444834898F82979C9660625C65685A6066567177667573607A7661767561
707361727968656E606672666B78696570626C7467687064646F6558655E43524D334641
1F3633142D2C08252402201E0929231C3B32415C51596B5D646C5776715672664973684B
6F6C527A7E6C7982756C7B7063776E647970657B70697A7069786E68756B627064506053
4A5A4B5F68546D705974725C75735E7776647475666F74676D766B79857B8B988E859591
8C9F9D99ABAB9AAAAA95A4A492A1A38897998696968B9A9A8494938093928B9F9D90A0A1
8A9B9B8999988294947E9290788985788984717F7B6E77736B6D63686247756132997734
29DE0C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6A40045A40155D4C2A6657376A5C3D6B5F41565436333A1F303E26414F374D563C515536
57542C5D54246456266B5B2C66572766572565552669592C6B5A2F6D5D326D603670663E
746B457069466E6A466E69486E694B706A4E746E53777154716B4C6A62416A5F3B6D5E38
69593167592E6C5E326E60346C5D336F5E346E5C306E5E2E6B5E2D6A5F2E6F623572633D
72664365603E5B573B6F69527C766167604B6C69517479656C7262777663797462787563
6E736541504828403C1E3C371C3A341B353018302A162F28112C270E2825223938384C4A
3D514F3E5353425B595169635D7368576A5D5D6B5D676F5F71725F746F557771567B7A63
7A816F7B877B7C8A8272857C687E755F776E50685F4D6258526158536159536056556253
5F6858747765787A65797C697A7F6E8085778A93879CA79E9FADA5A6B3AFABB7B5A5B1B3
A3AFB1ACB8B9ABB6B8A2AEB0A2B0B19BA9A99AAAAA9AA8A99EABAB99A7A795A4A494A3A6
909F9F8A9A9A8798988291917E8C8877847E6C756C6F70616B5F427F643077992600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB40F
613D04604B1C6758306B5B396D5E3F564F33343A22223420203724293F2D455543515B47
595D415654305D552C5F552961562A5F562863592E675B326A5C346C5E37695D35695F36
6E633C7067416D6641706B49736D4F726C51746E55706B517670567973567B75577C7357
786D4F7167466A623D6C653F6E633D70633E6E61396E61376C61356C65396D663F6C6441
726A4A6F69476F65416F5F3B71603A6C613C726F516E725C767A67807E6B7E7A657E7D6A
4C5548283E38203D3A1738341638331B3B3723423D36554C506D6592ABA8DAEBEBF1FAFB
F0F6FBC8D0D798A1A4848D84767C6E6C715E74766171715D6767556D715E7077656B7869
697A6C6D7D7473807A707F796F817B6E847D667D7760746D627069646F676A7466757C69
787E697A7F6D898F7E9EA699AEB7ACBFC8C2BFC9C4BFC9C4BEC8C5BBC5C5C2CDD0BAC4C7
B6BFC2B4BDC1B0BABCADB7BAADB8BAA7B4B5ACB9BBA9B5B7ABB6B7A6B4B49CAAAA97A5A6
8F9C9D8B9A9C8B999A818C8D7B838073786E6C6955766440916F362ADF0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0044AD07
6443096955246C5C316D5D395E563740432B2F3D2A273E2B223B2A233B2C2D4334415244
535F4D555D45595B3B5E5C3965633F6865426561406862436A644469624168613F67603D
6C63406B63416C66456E6A49706A4D746D53756E54746E53746E516F6A4C746D50736D51
746D52736B50736A4F787154777254777052726B4A726C48726C48746F4D747151757156
7B765C797357776A4971603B7460356E5F326F6946706E557B7A64807C667F7A647E7D69
636A585A68595564565A695C5767595A685C5F6B5E6B76687D877A929992A4A3A4B0A9AF
A59EA4948E92827E797E7968817C617972557B785B62644E4B55444B5848505F52607066
819288C7D2CFE3E9EBDEE5E7BCC4C899A4A67E8985777F767C827680867A888E7E999F8C
B6BCA9CBD2C4D7DFD7D6DDDAD6DDDCD4DBDCD0D7D9C8CFD0C4CDCCC4CBCEC1C8CBC2C9CD
BEC6C8C3CBCDC5CED0C0C9CBBBC5C7B0BABDB0B9BEACB5BBAEBABBA5B2B39CACAB95A3A5
909D9E899799869293787D78716F60726448856B3C779A2D2BDF0E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042AA04
705011705B29705F31675C374A4B313947343247352F46342B43312A42312B42342F4437
3A4D3E4D5C4957624B5B60485D614761644964654B64644B65654B67674B6A684C6A684B
6C684B6D684C6F6A4E716C50736D53746D55716B52726C51736D4F726B4A6D6544716647
74674A746749726649746C4F726C4F726D50716E4F737250757252737050757154726E54
756E57756C547A6D507A6B4979683E7261356D6037706645756C507A72587F765F807962
7F7A608A8468948B6C988A6B94866798896C9C8C70A291749B896C99846C967F6C917B6D
8E7D6E8A7D6C8B806B83765A7F704E7C6D4A8880636B6D5757614E5B67555F68556E705F
807F709E9890ADA5A39D98998D8A8B898784908E87A7A49AC4C5BBD5D8CFEAEFE4F5FAF0
F4F8F1EDF2EEE7EBECE3E7E9DDE1E4D6DBDFD1D6DACCD1D4CFD5D5CED2D4D7DADCDEE3E4
D8DFE0D8E0E2D5DEE0C7D1D4BFC9CCB7C0C5AEB8BCA9B3B7A9B4B6A3B0B29AA9A995A2A6
8A9798818B89787B717067507E683E9D793E2BE01000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0045AD06
775614755F2B6E6032565331444E383E52413B5341354C3B344B3A364D3C324839324738
3246343A4B384754425862505C6551606651616550626551626551666A5466674F6A6950
6D6A506D68506D68516D68516E695275715C736F5A74715A736F54736E506D6849726B4D
756C50786E51766E50746F50716D4F7975587775587A795C79785B7E7C607B785E7A7860
7C79617B735C7E745B82755A8679598074517F724F7C714F78704D766F5079715581765A
7C72518174508978508A754C87734987714A85704A826C44826C448269427D66417C6847
7D7152827A5E7D785B7D7354776A45766842756B496E694D6B6D5374775D8280639A8F72
A6987CA59782AFA496BFB8AED4CFC7ECEAE3F8F6F0FFFEFAFFFFFCFFFFFCFBFDF8F7F8F6
F7F9F8EFF0F2EDEFF1E6E8EBE5E9EDE6EBEFE1E7EAE0E6E9E1E7EBE6EBEFDFE4E8E4E9EC
D8E0E2D5DCDFCED5DBC0C9D0BEC8CDB5C0C3ACB8B9A9B4B6A3B0B1A1ADAF9AA3A5899190
7E827A756F5B7C694494743D54C01F00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CB40B
7D5B17725F2962593053573D4654433C53423C56443D554642574A4055473D52453A503F
384D3940523D41513D43503E4E5847575D4C5B5F4F5C61515D6353616555656855666852
6F70596C6B556B6C556E6F586C6E5771715B71705B74735E75745D75725A78755D73725B
78755D79745D74735971715675745C79766078765E78785F76765F7878637C7D687E7F6A
7E7F6B7979647B78627D78617D7961827E6588846A89856B88876B8A896F89876B898569
8C88698C8968908C6B938F6D9793719994749992739990719C94749E95769C96779A967A
9F9E849FA088A3A58DA1A2879F9E81A19F829F9E839B9B819C9D85A4A48DB5B39CCFCAB4
EAE3D0F8F3E5FEFBF3FFFFF8FFFEFAFEFDFBFEFEFDFEFFFFFEFEFEFEFEFCFEFEFCFCFCFC
FCFDFDFBFCFEF5F6F9F2F2F8E9ECF3E2E8F0D9E0E5D2DCE1D0DBE2D1DBE3D3DBE4D1D9E0
CCD4DACAD3D7C5CED3B8C2C8B7C2C6B2BDBFA8B6B6A4AFB0A1ADAD9AA09E898880796E5B
7E6A4498773E52BE1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA11
845F1B725E295D58324F57404A5A4B4056483C5647415B4D475F52465D50455C4F445D4B
4059434458444657444856444F5947525845565947545A47525C48535C4A58604E5B6352
696F5E7278647178646D77636B746070736071716073736071735F70725E6D715D6C705C
7374617878667E806C7F826D797C677777637475607778627374607274647B7F6F7E8270
7D826E7478637679647B7E687F816C8689758D917C8F927F8D907D868A78868A738C8F78
8F957D949B82939A83979D8897A18B9BA18DA0A391A3A593A4A793A8AB98ABAF9CB5BAA9
B9BEAFB9BEB2BAC0B3BCC2B4C2C7BAD1D4C9D9DED1E4E9DDF1F5EBF9FBF3FEFFF8FEFEFA
FEFEFAFEFEFDFEFEFCFDFDFCFEFEFDFDFDFDFEFEFEFDFEFDFDFEFEFEFEFFFDFEFEFCFDFE
F6F7FAEEEFF5E2E5EBDDE0E7D1D7DFD0D7E0D1DAE1CCD6DFCCD9E1C8D4DDCDD6E0C7D0D8
C6CFD3BFCACEBBC7CAB7C3C6B4BFC3ACB7B9A4B0B09EA7A38C8C817F735C856C45729831
2ADF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C621B775F2A5A542F49523B4D5F4F495E52425B4E3F594D465F534C65594E655A506858
516955526654516051546051555F4D59604B595F48565E47525C464F5947505B4B535F51
596557606C5D636E61697569707D706E786B6D73656D71646F75656E7767717B6A737D6B
71796872796A747B6C757B6B747867757866787C687B806D8388787E83767D84767C8472
7E87747D87737E86737F8775868E7C89907F8A92819196889196898F95878D9482939C89
97A39097A49195A38F9DA9989CA998A4AC9EA9AFA4B2B5ABC3C7BDD4D7CFDEE1D8E5E7E0
EAEDE6ECEFECF2F5F2F8FBF6FCFDFAFEFFFBFDFEFCFDFEFDFEFFFDFEFEFDFDFEFDFEFEFE
FDFDFCFDFDFEFEFEFDFEFEFEFEFEFFFEFEFEFCFDFFFBFDFEF5F8FAECF1F5E4EAEDE2E7EA
DBE0E6D6DBE2D1D7DED4D9E1D3DAE1D2DBE2D2DCE2CCD6DDC7D3DAC5D0D8C9D3DAC4CDD2
C0CCCEBAC5C8B7C5C6B4C0C2B2BCBDA1A3A188867A7B6F578A7146789D342BE01000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6E8D147A5E235F552D454C33495A484961514B6658466053475F544C625951675D586F63
5D73666275685F6E63616E63636F6165705E626B57606A555D6753576150556250546252
536052525F5354605755625956675C5B6B61606D6265706768756A6473676A786C6D7A6D
6F7C707581767582777886787784747C88787E8A7A7C887A7A867B839086849186889488
8392848493848998898B9A8A8C9B8A899786909C8C959E91939C8F99A2949EA798A4AD9F
A7B2A3B0BBAEBBC6B9CCD6CBD7DFD4E4E8E1F1F4EEF8FAF5FDFEFBFDFEFDFEFFFCFDFEFD
FEFEFDFEFEFEFEFFFEFEFDFDFEFEFDFDFDFDFDFDFCFDFDFDFDFEFEFDFDFEFDFEFEFEFEFE
FEFFFEFEFEFFFCFDFEF8F8FBF6F7FBEDEEF3E2E6EBD7DEE4D6DFE4D2DDE3D2DCE1D2DCE0
D1DADFD5DEE4D5DFE4D1DBE1D0D9DFD0DAE0CBD7DCCAD5D9C8D3D6C5D0D5C4CFD3C4CED0
C0CACDBEC6C7B2B8B79D9F998A8373857353957A497BA1332BE00F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DC0987621E6C5B2A4B4D2C4E5C47495E4F486251526B5D51685C52675D556B62536B61
576D6262766C68797168786E6C7B706E7A6C6C7867697564667260626F5E5E6E5C5D6D5C
616E5F5E6B5C5C685C5A695E5D6E635F6F655E6C635F6D6461726A5D6E655B6D6365786F
697C756A7B77697B766A7D7670847A73887D768980778A8281938D80918E84959080928C
83978F889C938FA49998AB9F9EB1A2AEBFB0B7C5B7C4CFC4D3DCD2E2E8E0EFF4ECF4F7F1
F8FDF6FCFFF9FCFFFBFDFEFCFEFFFDFEFEFDFEFDFDFEFEFDFEFEFCFEFDFDFDFDFCFDFEFD
FDFDFDFDFEFDFEFEFEFEFDFDFEFEFEFEFEFEFDFEFFFDFEFEFDFFFEFCFEFEFBFBFDF5F7F9
EEF1F5E9EDF0E0E4E8DDE0E7DDE2E9DADFE5D5DCE1CFD8DDD0DBDFD3DFE4D4E0E4D5DFE2
D2DCE0CED8DECAD6DCCBD7DCCAD5D9C4CFD2C7D3D6C0CDCFC3CFD2C4CFD1C0CACCC0C4C7
ADABA8988F858B786192785279A03C57C32400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007492187D601F5E55284950364D5D4D485E50506759536A5D586D63576D655A7169
5C72695F756B60746A67796E6E7E73748075738172717F6F707D6D707E6E6C7C6C6F7E6F
6C7A6C6C7B6C6C796D6E7B706E7E756C7D7472817973827A798981788B83748982788D88
859895869896849695879A988AA19D8BA39F97ADAA96AAA69DB1AF9FB1B2ACBEBFA7BBBA
AFC3C1BACDC9CADED8CDE1DAD3E5DCE1EEE7E7F2EBF2FAF4FBFFFCFDFFFDFEFEFDFEFEFE
FDFEFCFDFEFDFEFEFDFEFEFEFEFEFEFEFEFEFEFDFDFEFEFEFDFDFCFEFDFEFEFEFEFEFEFE
FEFEFEFEFEFEFDFEFEFEFFFFFDFEFFF9FBFCF3F8FAEEF3F5E9EFF0E4EAEDE0E4E8DDE2E6
DEE4E8DAE1E5DAE2E6D8DDE2D9DFE5DEE4EAD4DBE0D6DFE1D4DEE1CFDADECDD7DACED6DA
CDD6DACCD5D9C8D4D8C5D2D3C8D3D5C4CFD0C8D1D3C4CCCFC2C8C9B6B6B4999086917E6A
977A59A7835357C2292DE11100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006D8F15745B205954304E5843475A4C4C6355536A5D5B70655E736A5D726A
60746C60736C64776D65776C68796E68786E6F7E75707E7472807573807478867A77867A
73827874837978877D76867E77898171847D7F928B84938D7F8E898697928DA19F91A3A2
8B9E9D95A7A695A6A592A6A4A1B6B5A6B9BAA7B9BAAABBBBBAC9CAACBDBFB2C5C7B7CACC
C5D7D8C2D2D2D4E4E4D8E7E7DDEBEBE7F0F1EAF0F0F5F9F9FDFFFEFEFFFFFEFEFEFDFDFC
FDFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFDFDFDFEFEFEFDFEFEFDFEFFFDFDFEFEFEFF
FBFBFCF8F9FAF2F6F7EDF0F2E7EDEEE2E7E9DCE4E6DEE5E8DBE4E5DFE9EADCE5E7D7E0E2
E2EAECE2EAEEE1E9EDE3E8EDE4E8EDDCE1E8D2D9DFCDD6D9CED8DACDD7DACBD5D7CBD4D8
C6D0D2C6CFD2C9D3D5C8D2D4C9D1D2CACCCAB8B4ADA1968A94816C9A7E5CA7805156C027
2EE11200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006C8D167259225C583648553D4A5F4E53685B5A6E635F726961736A
66776F66766F6979736F80776C7E756C7F786E807972827A73827972807872827874857B
73867D74867F7A8B847B8D867F938D819590879B978699968DA09C8FA3A095A6A598A9AA
9AADAF9DB1B1A4B8B6A4B8B6B3C4C4B2C1C3B5C5C8B4C3C7C3D2D4C2D4D4C3D5D6C7D8D9
CDDCDED2E0E0D2DFDFDBE6E7E2EBECEBF0F2F3F7F6FCFDFEFFFEFFFFFEFEFEFFFEFDFEFD
FDFFFDFEFEFEFDFEFFFDFDFEFBFDFEF9FAFBF9FBFCF6F8F9F2F6F5EFF2F4ECEFF1EAEEF0
E7EBEDE9EEF0E6EBEBE9EFF0E3ECEBE1E9EAE0E8E9E3E8EBE4EDEDE2ECECDFEAEADFE9EA
DCE3E6D5DCE2D5DEE3D7DEE3D5D9DED5D9E0CCD4D9C9D2D7C9D3D6CCD4D8C9D2D4C9CFD3
CED4D7CED1D3C6C5C4AFABA39A8F7D9882659F80587DA13F5AC42A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CB61381632A655B3354583D515E4C596A5D61726866776E
68797066766E6B7B746C7E746C81766B807873857E76868077857F7887827B8C85798C83
7D908981928E80928E829691899D9A889C9A8CA09F91A5A38DA29F95A9A699ABA99FB1B2
9CAEB0A9BBBBB0C1C2AEBEBFB8C6C7B9C6C7C0CDD1C4D3D7C8D9DAD0DFDED3E0E0E4EEEE
EAF1F2EDF4F5F1F7F7F3F9F8F9FDFCFCFFFEFAFDFDFAFCFDF9FBFBF8FAFBF4F7F8F3F6F7
EEF1F1F0F3F3EEF2F3EBEEF0EAEFF1E7ECEDEBF0F0ECF2F2E8EFEFE6EDEFE8EEF0EDF2F3
EDF3F3EEF4F7EBF2F2EBF2F4E4EEEDE5EEEDE4EDECE0E5E8DBE3E5DAE4E6D7E3E3D6DFE1
D6DEE0D0D9DDCFD9DBD1D9DBD3D8DCCFD4DACDD3D8D3D9DDD2D8DBD2D5D8C6C6C6B1ACA5
A194879B86719D8061A8855983A73E2DE21400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DE0D698D1F78612E68623D5D644B5E6A59637367
6B7C71667970687A716F81766D81766E837974837D7A85807E8A847A89837A8C8780938E
8596928A9A968C9E9B8DA19E95A8A696A9A897A9A99AADAEA1B3B4ADBEBDABBDBBADC0BF
BBCCCCC2D1D2C3D1D3C1D0D2C2D1D1CBDADBD7E5E7DBE9EAE5F1F1F0F9F9F7FDFCFBFFFE
FCFEFDFCFDFDF6F9F9F3F6F6F4F7F7F4F5F7EDF1F2F0F4F6E9F0EFEEF4F5EDF2F3ECF0F2
EBEFF0EFF3F4F2F9F8EEF5F5E9F1F0EAF1F1EFF7F5EEF6F6ECF5F3E9F1F2E9F2F1ECF3F4
EBF0F2E7EFF1E3ECEDDFE8E9E0EAEBDEE8E8DAE4E3DAE2E2D5DDDED5DFE0D3DFDFD2DADC
D0D9DAD0D9DBD4DDDCD4D9D9DBDCDFD7D5DAC8C5C5B6ADA6A9998A9C87709C8362A7865B
80A23E59C32900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0027DC0B658E207A65336D6340696951
666F5D6573656C7B7072817573827873857B7988827A867F7C88827987807D8C887D8E8C
869693859692869996889C9B8FA2A18FA1A295A7A898A9ACA0B2B4A9BABBB5C4C4AFBEBE
C0D0CFC4D3D2C5D3D6C7D5D8CCDDDED0E0E1DBEAECDCE9EAE7F2F3F2F8FBF3F8F8F6FBFA
F4F9F9F2F7F7F2F7F8F4F9F9F3F7F8F6F8FAF6FAFBF6FAFBF0F7F6F1F7F7F1F7F7F1F6F7
F4F9F9EBF0F1F1F7F9EEF6F5E9F2F1E8F1F0E8F1F0E6EFEEE6F0EDE8F1F0E4EDECE5EDEF
E4EAEDE1EAEBD9E5E6DCE6E7DAE3E4DAE3E3D7E1DFD7E0DED8E1DFD6DDDCD6DEDCDCE1E0
D8D9D9CFD0CBC7C2B9B8AC9CAB9785A28771A18364AB875B5AC7305BC42800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADF0E47B618866931
7561366B63416D6D536B715D707A6B7380747484797988807B89827F8B867A888480908D
8395928295928499968398978EA3A28FA2A490A2A393A4A696A8A9A0B2B3A8B9B9B0BFC0
B6C6C5B7C6C6C1CED0C3D1D4C8D7D9CEDEDFD0E0E2D5E4E6DCE9EADFEAEBE0E9EAE2EDED
E7F2F2E6EFEFEDF4F4ECF2F2EDF1F2ECF0F1EDF2F4E9EEEFE9EFEDE7EFEEEAF2F1E8EDEF
EBF0F2E8EDF0E9F0F1E6ECECE5EDEBE6EFEEE3EDECE3ECEBE3ECEBE2EBEBE0E9E8E4EAED
DDE4E6D6E0E0D6E0E0DCE1E2E5E6E8E6E7E7E2E4E1DDDFDBD2CFC9BFB8AEB6AB9AAD9B87
A48C73A68A68AB8B5E57C6315CC72E5EC52900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28DE0D47B5188E6E347F6A3C746843726D4F71735A777D6A7981747E847D7F877F808C86
82908C80918F839794809593879B9A90A4A48D9E9F96A8A89CAEAE9FB2B2A6BABAA9BCBB
B2C2C1B7C7C7B9C8CABFCED0C6D5D6C9D9D9C8DADACFE0E1D5E4E4DAE7E7DCE7E6DDE8E8
E2EDEDE1ECECE5EFEEEAF1F1E6ECEDE8EDEEEAF1F0E7EFEEE7F0EEE4EEEDE5EEEDE6EBEE
E7EBEEE5EAEDE2E9E9E8EDEDE3E8E6E4E9EAE4EAEAE6EBEAE5E9E8EAEDEDEBEDEDEEEDEE
E5E5E4E3E3DFD6D2CBCFC2B9C3B0A5B7A092AD967EA88E6EA98B647DA44757C5305BC62D
2EE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BF204ABA1E6B962D8A713F836F467F6C4B7F70537F775E
807B6983847681877C848D8585908B8C96948A96948B999890A2A099ABAA9CB0AFA4B7B7
A8B9B8B3C2C2B2C2C4B7C7C9BFCED0C5D5D6C8D8DACBDDDED0DFDED7E1E1DEE7E6DEE8E7
E2ECECDFE8E8E1EAEAE4EDEDE3ECECE7ECEDE6EDECE8F0F0E9F0EFE9F1F0E7EDEDEAEBEE
EDECF0EEEDF2ECEDEEECEAE9EAE6E4E9E3E0E1D8D4D5C8C2CDBEB3C6B3A4BBA694B49B85
B09578AE906FB18E6759C6385CC7355EC6312FE31700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C32453C0224CBA22
47B7239A77478E724687714B85725483725783775F837D6683826E898A798C8E80989A90
9EA49AA0A69EA6ACA5ABB2ACB8BDBBBBC0BFC1C7C6C0C6C3CCD0CCD3D4CED5D6D1D2D4D1
D6D7D4D7D4D2D8D5D2DBD8D5D5D2CED4CFCBCFCAC4CCC6BFC7C0B5C0B7ACBFB3A7BEACA0
BDA898B69F8FB09A84AE957AAF9272B2926EB2906A87AB505AC7375ECA365EC83130E418
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059C32657C32851C0274CBE264ABE2845B92543B826
6F9C3C9B80529A7F529B81579C815B9E84619F84639E8361A18662A38863A68C66A88D69
A98B69AC8D69AE9069AD8E66AB8B62B08F6581A94C81AA4A54C63556C6335AC9365CC834
5FC9335EC83030E41700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0108209 0.732558 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0063C92C62C62962C62893AA3CC38F53
C39053C59055C48E55C58F57C48E55C58E56C18C53C28E5591AB3F61C52861C62961C72A
60C72961C82A60C62960C7295EC62800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC223
5AC1215BC1225AC12158BF20B58345B88146B7834AB47E46B58044B67F41B88141B68041
B27F40B47E43B37E43B57D42B67F42B47E42B17D42AF7C41B17E40B47E41B58043B38042
B38042B58243B68346B68346B68547B9894D5BC1245BC2245DC4265EC4265DC42700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDF1159C02356BD20829D31AD7E41AC7D40AC7D41AC7C43
AF7D42B37F46B38144B28146B28147B28048B5814DB3804DB17E48B68049B77F45B88148
B6824BB6814DB37E4AB6804AB7824BB8844EB37F4AB5834DB38048B58148B68248B38045
AF7C40B27F44B28045AF7D44AE7C43AF7D44AD7B41A9763AAA793AB07E40AE7C3EB07E40
B18143B28344B0834683A23658C0242CE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002EE11300FF0000FF0000FF0058BE2256BE22
54BC2156BD23829C32AF7C45AF7E43AD7D43AE8046AE8048AE8149B1824DB0834DB38251
B88452BE8757BE8958BE8A58BC8654C1885AC1855AC4885DC6865CCD885ECE875BCF875D
CE885ECA835BC88259C98259CA845BC8845CC8845DC9875FC7875DC5875BC08558BD8355
B98352B48353AF8051AD8052AE8252AD824FA97D48A67941A67940AC7D44AE7C44AA7840
A37338A37436A57538AA783DA9783CAD7B3F819C2F56BD2056BF2054BD1E809C2D56BD1D
2BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0058BF22AD7A3FAC7A40AB7941AA7941AB7D47
AA7E49AB7D4BAE7E4CB38050B4814FB98454BE8659C2875FC68761CB8861CF8960D58663
DD8965E08767E08566DF8363E17F5DE47B5CE5785BE4755BE57158E36A53E0654DE2644E
DD6149DF614ADF624AE1644DE36651E26651E26854E16B57E06C58E2725CDF755CDA775C
D47B60C27A5EBE8266BE896BBB8969BB8C67B78962B3865DAE8359AF8357AE8154AC8052
A77D4DA57C47A57942A4743CA27135A47335A16F33A27033A47335A87838A87738A97839
A978367F9A282BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0054BB1F7D9A2EA9773DAB7940AB7943AB7B48AF7E4FB48255B98458
BD835AC5855ECD8660D78766DB8665DD7D60E0765FE0705CD9624DD75741D44C38D44232
D53E2FD43829D23224CF2B1DD32B1AD42716D42716D52419D52117D71F17D51E14D72018
D82017DA2117D92014D81E14D81E14D92116D61F16D41E15D11E16CF1E17CC2015C52015
B420158D130A8118137C1D167F251A85302290402F974D3B9B5744A66651AF735BB37E61
B58464AE825EAD815BAC8055AB8051A57C49A27944A1753FA27239A27235A07130A37230
A57434A77736A8783654BC1929DD0B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DD107B9831A77743A87643A57443AC7747B27A4DBB7D53C17D58C87B5BD1795BD97459
D5664ED0543FCE4634CB392BCB3123CE281ED0241BD11E16D61F15D71B12DA1C13E01C15
E31C15E61B14EB1F15EB1E14EC2015ED2014E81C0FEB1C11EC1C12ED1B14EC1C13EE1C17
ED1D16ED1B13EE1C12EB190FEA180EF22015ED1B12EA1910E8180FE91A12E71A11E21912
CB120EA3030395040895080C950A0C8E07088B0A0A8409097C07087B0D0B77100C771912
78241A83382B924E3FA0634FAB725CB27F63AE8160AA7D59AA7F54A77D4CA27941A07339
9E6C30A16F30A16E2F9E6E2C9F712BA0712900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0029DD0F53BB1F52BB21799932A17544
A57647AD794DB1774FBB7653C47758C97052CB664BCC5943C44332C23427C6291DC92116
CE1E14D21911D71913DA1712E01914E11611E61911E6170EE91A12E91913E81810EC1B14
EB1A10EF1C11F22012F22014EC1B0FF42116F11F12F42015F31F13F41F14F62116F51F16
F21E14F21D12F62115F41F13F42013F41F13F41F13F11D12F21D12F11C11EF1C10E91C12
CC0E09AD0204A40205A30105A60408A001069D04089B03089703079002068F040A8C050A
8304087B060876070A710A0B6D0F0E721A167C2D258743369B604BA77357AA7C59A87A53
A7774CA675449F6F379A6A2F9A682C9665249E6D274FB61100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0028DC0E7B9930A97A47AA7B4DAE7B50B87955
C17656C56C51C65D48C14737BE3526BE2518C21D13C7150FCD1511D2130FDA140FDF130E
E2140FE41610E4130FE4140FE51610E71610EA1A10E9160EEA1A11EF1C15EE1C13EE1A11
F01C11F11D12F32113F42114F01E11F42116F52215F72317F72116F92217FB2419F62016
F62114F92317F72314F31D11F52111F82313F62114F62215F41F12F11C0FF11D11EB1D13
C90907B20203AE0306B00507AE0408A70105A60207A40207A002079E02079D0209990107
9601079302088F040B88030B81020A7B03097A070B71070A6A090869110D6F1F1880382A
914F3B9E634BA77451A374499E6E3F9A6A3597662A97662296661C4CB30B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DD117B9A34A87948AF7D52B67C5ABE775DBF634EBC4A38
B73024B61E15BB150FC4120FCD110FD3110DD7100DDA0F0DDC0F0EDE110DE1110DE2110E
E41410E61611E61611E51311E41511E5140FE91912EB1811EE1A12F11C14F42016F41F15
F41F14F31F14F62216F72317F42115F42116F22013F92519FB261BFD281BFE2A1CFC271B
FD291AFE2919FE2A18FB2616F92312FC2514F72012F62112F62012F62113F41F13EC1D14
C90806BD0809BB090ABC090BB8070AB00106AF0309AF050CA70106A70208A70108A20105
9F01059F04089701069101088A01088601078403088001067E01077D030C76030A730609
6C0707630A0764170E712D1D884B369C6448A06B44A16E3C9A69309565229260146B8307
47AB0300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029DC0D
50B81B53BA1F7F9931A97747B07B4FB97854BD6F50B459419C34249A1B15AF1B15BE1511
C7110DCE0E0DD30E0FD60E0FD90D0EDA0D0CDD0E0EDF100FDF100DE2120EE1120FDE0F0E
DC0D0DDD0E0DD90A09D9090BD70A0BD90A09DE0E0BE71610F01C13F41E14F72116F82117
F92217FB2519F92317F72117F92519FC281BFC2A1AFC281BFE2A1DFE2B1DFE2B19FE2D1B
FF2D1CFB2716FA2514FB2314FB2313FA2212F92214F92312F82211F82114F41E13EB1D14
C40502BE0908BF0908C30B0BBE070AB80509B40409B00308AE0308AD0309AA0206A70206
A60106A301059D02049500059001088B0008890107870105870006870109840107820207
7E01077901077604086E0506690808660F0A70221586422B9F6645A07245996B34936222
824E0E7B470542A90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DC0A7594219F7337
A67944AB7749B6784FBF7250BD5C42B43B2AB12518B0140EB3100CB90A0BC80F0FCD0D0B
D20C09D50B0BD70C0EDB0E10DD0D10DF0E0DDF0E0CE4110EE61410E3130FDA0D0CD30608
D20608D30609D30709D6080AD40708D80B0ADC0C0AE0100BEB1910F31E16FA2117FB2318
FB2517FB2415FA2515FA2619FB281AFD2B1BFD2E1BFC2C19FA2A19FF2F1EFD301BFE2C1A
FD2B1AFC2919FC2818FD2616FD2616FB2315FB2316F92112F92213F72014F31E12E51911
C20602BD0908C20B0AC30A09C1090CB70407B20408AD0207B2060BAE0307AD0308AA0209
A70106A80206A402079D01069801089301099002098B01078A00068B01078B02078B0208
86010787010889030988050A82040A78030776070A6B0805610D05702D1A915739A16C44
97653683531D6C3E047B4A074AAF0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DB0C9F7234A77D43AC8247
B4804AB46840B0462CAC2716B41A0EC0130DC30C09C50909CA0B0BCD0A0BD00D0CD10C08
D60F0AD60C0AD90D0DDE0D10DF0D0EE51211E5140FEA160FEA170FDD0D09D00402D20608
D30709D5090BD4080ADA090CD90A0ADC0D0ADE0E0BDD0D09E10F09EF1912FC241AFE271B
FD2A19F92816FC2C1AFB2E1EFA311FFB3521F93721F93522FB3522FD3321FE321FFF301E
FF2F1CFD2B1BFE2B1AFE2918FC2717FD2718FC2416FB2315FB2315F82212F52316D9130C
BB0404BC0A09C10C0BC30B0CBE090BB7070BAF0409AB0309B0070CAD0408A90207A80208
A8020AA80206A70308A20106A1030A9B01089501069101058C01058C02068E02078C0208
8801078802078B05098C04098A04088503087F02087C040A77050C70080A660A056E1F11
85442B99643C9163317D4E156F3E0260780525D70500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE0FA67B3CAB8145B0853CBC8F37
D0913CA23709AF1807BF100BC40B09C80A09CA0B0ACC0A0BD00C0DD30A0DD60D0CD60E09
D8110CDA110ED8100DDE1111E31411E81511EA1811EC170FEB180DE10E07D70A05D50806
D30706D40708D60A0ADA0C0CDB0C0ADD0D0ADB0D08DE0F09E3110AF21C13F92619F62C1E
EF3826EA3D2AE94331E84837E9503FE75544E85D4BEC6051EB4C3DF43628FD3121FD2F1B
FE301BFE2E1AFE2C1BFD2819FD2819FD2718FD2415FA2314F62513EF2A16E62C19CA160C
B60605BB0D0DC00E0DBF0C0DB80A0CAF080CA60307A20307A50408A70408AA0509A60207
A40107A60309A50207A102079C02079A0207980205910104880004850004890107870106
8201057C00037F01058202058604078202077F02087E02087F020A7F030A7B0409750609
6A09056A1A0A87482999643B8C5C2A74410C76400345A90400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0049AE049867197D9A2BAA7942AF7F3DBE8F33C39822CD9D18
DF9922AC3201B71001C10A07C10606C40707C90B09CC0909D20B0BD70C0CDB100EDC120E
DA120ECC0D0AEB2F2CD3100EDE120EE71410EA170FED190FEE1B0FF11C12E7160DD70803
DA0B08D80A06DA0C09DA0D0AD90D08DB0D07DE1109E01008EB190EF82418F4281DC41C12
EA7B6CFBAC9FFEB5A8FFC0B5FFCCC2FFD3C9FFD7CCFFD8CEFDADA3E24437F83522FF321E
FD2F18FD2C18FE2B19FE291AFE291BFE2719FC2615F72A1AD82312E45945F17F6DB53126
AC1711B5130EBF1311B80C0DAF090DA6060A9E0409980307980407A00609A40507A50205
A40206A20105A60308A00206940003930004970305940307870105820105840005850005
8101057700017700027900027A00027700037601057601057A01057C01057D01067F030A
7C050B720807660A026C210F8C533398643B834E1D6E370260740326D60300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB00A9B6A29AD7644B26F48A05127A96218D0991ACD9F08D2A306
E49D19AF3300BC1504C20B07C00607C40807CB0D09D00B08D40B0AD80E0CDA0E0DDB0F0E
D40F0EB70302C21210C00402DF1610E8180FEE1B10EF1C0FF01C0DF21D11EF1B0FE9170D
EE1C13ED1C12DC0E06DA0E08D80E06DE1108E7170CEF1D11F92518FD291CF22B20A6110F
B6766EFFEBE6FCEDE8FCEEEBFAF1EDFBF3EFFBF3EFFCF0EBFFDFDADF6258F23927FC311D
FE3019FE2D18FE2B17FE2918FE2918FD2818F82616E62D1E941206E0A193FFE0D3F6BCB2
C86A5EAF3328AE1D17AB1411A4100E9C0A0A9408088C0A098A0D0B870A0696100BA51311
A10707A20407A6060B9F02089801089201078F01058F0205870104840004860004890206
8601057F01037C01037D01047A00037701047300027200027501047A01067F0207800207
7E02087B03077703076D07065908026B2B189259398C562B7339087D420224D40300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00728E1A9E703AA56E499F4C35952614901600B85A13D79B10D0A303D3A405
DF9D17AD3500B71102C00907C00607C60A08CD0C07D10D09D50B09D90F0ED90E0CDC0F0F
D50F0EC6110FEC3C39D61814E51911EA180DEE1B0FED1A0BF01E0EF01D10EE1D10EC1E12
ED2316EE2618E22215D5190DDC2516E22719EC2C1CF32D1DF62C1DF92A1CF52E21C42721
833E3BFAE9E7F3EEECF5F1F0F1EFF0F5F3F3F3F0F0F7F2F1FFEDEBE98884EC3E31FC321F
FC2E19FF2C18FF2C18FE2A17FE2A17FC2A18F12E1CBE291A944437F4D9CEFBF0EAFEEEEA
FFE3DCF9C4BBDE8D85BB5750A1372D8E23188620157C20157422167E2F22B05A4DCC6158
96110E9B05099F040B9C020999010A9202098900058900058902058902048701038A0306
8901058701058502058301047F01047C01047901037601037600047B00067F0106810106
820308810107800209770307660103580400540C0371331A8E5631774011733901708109
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25D806996B299E7044854D30702011850E07A40F09A81103BD5313D89B0FD1A403D0A303
DB9D15AC3B01B71403BE0906C20807C90A08CD0B07D30C09D80E0CDC100DDB0F0BDF120E
DD130FDD1A16E52621E31A13E9180EEB170DEF1B10ED1B0EE81B0DE62113DC2718D32D1F
D33A2DDA4A3CDF5A4CE66C5CEC7867EE796AEB705EE86353E55444E34333E43C2CD33D33
711F1BDCC3C0F6F0EDF8F4F4F4F2F3F5F4F3F4F3F2F4F2F1FDEFEFF4B3B1E2443DF83222
FE301DFE2D19FD2B17FC2A17FB2E19EE2F1DCB301E9F3F30EAC3B8FBF1EBF4F2EFF6F3F3
F7F2F1FAF0EDFDEAE5FAD6D0E1B3A7D7A495CF9E8DCDA190D3AB9BDAB2A2E4AD9FAF5951
8209099203089802099600099400099002098C00078C01078B02078A0105870003870003
8A01078901078601048400048000047E01057F01067F0106800208810108810007840208
84020886020B82010A7500046800015E01005A02005405005A15087F44267B4116723700
6E7F0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310
9870338C633E5E2B185B130A700B07930709AF0D0BAF1102BB4A0FDB9D14CFA302D4A805
DB9F14AE3D02B61300C30B08C70907CE0C0AD00908D50C09D90E0BDD0F0CDD100CE0110E
DF130DE1160FE31810E8180FEC1A0FEB180DE7180DE21C11D42015BE291ECC584CEC9589
FBB8B0FFCBC2FFD6CDFFDFD7FFE2DAFFE3DBFFDFD6FFDDD4FFD4CAFFC1B8F5A499E2877D
8E5048B9A19CF6F0EAF7F5F2F5F3F3F3F1EFF3F1EFF3F2F0FAF0EFFED5D4DF5952F33628
FB311FFB301DF83320F03423E23727C03728BC6356F3CBC0FBEEE8F7F3F0F3F3F3F2F3F3
F3F3F3F3F2F2F5F3F2EDE7E3ECE0DAEBDBD3E9D8CDEBD7CCE9D2C6D2AFA4A2645D801A19
8B060A95040B9A020B9900099401079000069101089001078C00068901058901068C0107
8C01088A01078800078601078001057E00057F01077F0207800105810206830107850108
86020B8502098303097601046700006001015F02025C020155020050090174361B7F451A
7237016F7E0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718C16976E38
704B294317094007024D0305620102890307AB0A0AB11004B6410DDE9D16D2A602D8AB05
E1A414BA4708BD1703C90D08CE0C0ACF0B0AD10B08D60C0AD90E0ADC100CDB0D0DDC0E0F
DF130EDF130CDF1209E5160CE7170DE6170CDE1B12C22015AC342AE0938AFED3CCFEE6E1
FAEDE8F8EFEAF7F0EBF7F1EFF4F0EEF5F1F0F6F3EFF9F1F0F7EEEBFAECEAFDEBE7FFE8E2
F8E0D8EDDFD9F1ECE6F4F2EFF3F2F0F3EFEEF4F0EEF0EFEDF4EFECFEE6E4DF7E76DF4437
E73F30E03E31D34536CE5346D27064EBAFA6FFE4DCFCF1EBF6F2F0F3F3F2F1F2F1F3F4F4
F1F2F1F3F3F4EBEBECE4E1E0E6DFDCE6DAD9E8D9D5E6D1C9CAA89E91564E6F121085080C
95040A9A02099F040B9D03079903099501089802099301088D01078B02088E030A8D0108
8D01088B01078C01088900088401068001067D01067801047701037700027B01047F0107
8101098202088003077B02056C00006400006101015E01005B0202550201500600692911
81441B77370122D10100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718D178F6330593115
3B0F033805044005074802065D01057D0206A30909AD0E02B03608E49F1AD5A803D9AB04
E6AA14C3530ABE1601CC0C09CF0B0AD10A0AD00A08D70D0CD70A09DA0E0CD90C0DDC0F0F
DD120EDD110BDF130BE61710E3150DDE1812BC1A13932A20E7ADA3FADFD9F7ECE9F1EBEA
EFEDE9F2F0EEF4F0EDF4F0EEF5EFEEF6EFEEF5EFEDF6F0EEF5EFEEF6F1F1F5F1EFF4EFED
F6F0EDF8F2EFF3F0EDF3F2F0F4F4F2F2EFEEF2EFECF1EFEEF3F0EFFCF0EDF5C5BEE9978B
ED9B8EF3AEA4FDC9C1FFDDD5FFE7DFFDEEECF7F0EFF6F4F3F3F3F2F2F3F2F3F3F3F3F3F2
F1F1F0ECEDECE3E2E1E4DCDBE5DAD7E6D5D0DDC1BCC3968E88453D6F0F0B7D06078B0208
9702099A01069D02079A00049701069500079702089301098E00088C01088D01098B0108
8901088A01088C02098801078502087F0106760002710001720102730101750002790006
7C01077D01057E02048004077902047102036901016501026000015A0101550201510500
651F0C7E3C1678380124D30200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075901D9F76484C260E3A0D03
3806033601053C0206490105650408800307990505AB0C02AC2D02E39819D6A605D5A701
E2A810C75C0DBF1A02CD0C09CF0A0BD10B0BCF0909D50B0DD50A0BD90D0DDA0F0DDB100C
DB0F0DDD100CE0140EE1120CE0140DD018167E0504BA827CF9E0DBF8EEEAF4EDEAF7EAE9
F3E1DFF6D8D8E9C2C1DDAEAED3A09FD09B9CCE9B9BD7A8A8DFB5B6E6C4C3F1D7D5F4E4E4
F6ECEDF4F0EEF2F1EDF1EFEEF0EFEFF1F0EEEFEEECF4F2F3F3F1F2F4F0EEFBEFEBFDEBE6
FDEEE8FDF2ECF9F1ECF8F1F0F4F1EEF5F2F2F2F0F2F5F4F5F4F3F4F4F3F3F3F3F2F3F2F2
EDECEAE4E0DCE8DFD9E6D7D1DFC5BEC99F97AA6A64862D2A7508078105078601068C0106
9501069E02099F02099C01079801079600079502089200069101088E01088E0209890106
8600068600068802088200047C01037501027000016F0001710101740101760103790107
7900067901037901027B01047D02057C06097402046E01026901026200015A0000550101
530400671F0A75340D7E3F0327D60300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00759222B19065BFA59233140D340808
3504053601053F04084A00046C0509890508990202B10E07AC2300E5911AD5A304D3A601
E1A90FCA650FBA1801C90C07CB0A09CA0707C90506D1090BD40B0AD60A0AD70D0BD80C0A
DA0C0CDE0F0DDF100CE2120EDE150FBF15145F0606D6B8B5F9ECE8FAEBE8F0D0CCE3ABA8
DB8E8DCC6A6AB03A3BAD2A2BB02626B22527AC2325A92628A62C2DA33433A14241B06365
CA9093D4B2B3D9CECBEDE7E5F3F0F0F3F1F2EFEFEDF1EFF0F2F0F1F2F1F0F5F2F1F4F2F1
F4F3F0F4F3F2F4F4F2F4F2F3F4F3F3F3F2F3F3F2F3F3F2F3F4F3F3F1F0EFF4F2F2F6F3F2
E6DEDAE1CEC6DCBDB0C5978BAF6E64842E277C0E0C87070A8C030890030A8D01078E0205
9401059E0309A000099E010A9C010A9800079500059201079001078E01078D0106890106
8701058701058601067F01047501016F00016E01017001007401027702037801037B0004
7D01057A01037701017501017601027C04087A03077601047001026B01026501025B0101
5601005304006A230B702D0465710300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B717B89770D3C1B1C7B8B5321B1A31090C
3205083502083D03084801056C070A8D060CA10507B10B09AB1A01E28717D7A206D6AA04
E0AA0ECD6D11B51801C60A06C90B07CA0909CB0909D00A0AD40E0BD50A08D70D0BD70B0B
D90B0DDE0E0DE00F0BDF0F0BDD140FBB1514520202C8ACA9FDE8E2E5B7B1C06660B3302D
B81F1DC21817C81413CD110FD21311D0100ED21313D11315D21917D01C1ACD211DCF2B29
CA3A39952E31613837E3D6D4F2EDECF0EEEFEFEEECEFEDEEEEECEDF0EDEEF1F0EEF5F2F0
F5F2EFF9F2F4F5F2F1F9F2F3F6F0F1F7F1F2F8F1F2F7F1F0F8F0EFF8EEEDF9EBEDFDE7EA
DAB6B5BB827CA0524988261F8712108E0D0C900406930205930105930107910108900207
9201079A020AA1020CA1030D9E030C9901079702079302088E00068C00058D01068B0206
8800058801078301067C01037301016E01016C01016E01017201017501027A02047D0204
7F02057F02057A02037600037602067702077C040A7A05087100026D02036B0204630201
5C01015601005709006B22077731014AA70500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028DB0DB39065D5C4B3D4CBC7C8BFC13A282A2D0B0D
2E05083101063702063E00015B010484070C950104A90908A91703DF7F15D9A208D7AA04
E0AA0ED07310B11A01C40C09C50907C40708C60606CA0807D10C0AD20A08D40A0AD70B0E
DC0E11DF0F10E0100EDF100CDE140FC81717690304A46E68EEB6AABF5B52B61E19C8120F
CE0D0AD50C0CD50C0CD50C0AD60F09D70F0AD8110DDB110DDB120DE01510EB1F16F7261D
F22B22D2302C620D0BBDA6A4F3ECEAF3EEEEEFECEBECEAEBF0EFEFF1EEEFF3F0F0F5EBE8
FDE3E0FFDDE2FFDEE3FFDFE3FFDFE2FFE0E3FFD9DDFFD7DAF2C3C6E6B3B5DB9AA0BF7279
8D313688191B8C0D0C930708970507970306960305940102920103930105930208910108
9201099801099E010AA0010C9C010B9701079400069201079002078F0106910107900107
8E01078801077D01037400006F00016C00006B00006E01016E00017001017401017A0202
7C00027C0104790004760005740106750106750509780C106F060A6A0104670102610202
5E02015C02015704005B0E016D2403833C0327D50300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0028DB0BAC8559D2BFAED2CCC9CDCCCDD3CFD1463B3D24090C
2E070A3403093B03094202075301047404098A03069D0504A61503DA7915DAA209D5A802
DAA70BD47A12B11D00C00C06BF0604B70001C50608CA0709CD0708D20A0BD30B0BD50B0E
D70C0ED90D0ED90E0DDB0E0DD80F0CCE11129C0708AE3F38E47263B82016CA100BCF0A08
D20C09D40C0AD30A08D70F0AD40D06D80E0AD8110BDB120CDC140BE0160DEF2215FA291B
F72A1AEB34288F191489605BF4E8E4F2EEEBF1EEEBEFEEECF0F0EFF1EFF0F4F1F0FFEEEC
D19594D57274DE7276E17377E07375E07273D9686AC15356A23A3D9F3234A42C2FA12123
961211990D0A9E0B089D06049C04029A0403960202950303910102900104940409900107
9200069901089F030B9C010A9A020A960006930004920106920107940208940206910105
8E02068702067B01037100006F01016D01016E01016F01016E01016D0101710201770202
7902027A0204790105770106730004700003680305C1666AA549506A060B6201035B0000
5C01015B0201580201530400621302762A0145A00100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007A9A35CBB2A0D2C9C6CFCDD1CECFD3D4D3D65D5657250D10
2C08093503093C02064703085402086901077E0206990809A01303D37215DCA30CD4A804
D6A508D37D11AE1D01C10C07C50A08BF0405C70609CB0709CF080AD1090BD10B0ACF0A09
D30C0BD00A0AC90404CA0303CD0606CB0706BF0806BE1712D22C22C71009CF0C07D10A08
D10B06D10C07D20F07D41107D31005D31307D21608D31807D31C08D51F0DE2301CE63624
E53B28E04636AE4035815249EDDFD8F1EDEAEFEEEAF1F0EEEFEFEDF0EEEFF3F0EFFBEDEB
EBB8B3E18A84E78881E7857FE8867FE68379E47E77D87570CD6D68C96760C65E57BE544A
A73C2C9E2D19A028149D210E981907941404900E01900C008F09018D06018E0403910205
9301069800079D030A9801079601059803079702069802079802089501079000048F0104
8B01048001037801027100007002006D01016D01006F01006E01016C01016D0101720101
7401017601027801037A01077500056E010467020591373EB05C64AF565D7115185C0303
5901005802025301025101005B0800701E033C940000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004DAF119D7551D3C2BCCFCCCFCDCCD1CFD0D3D4D4D77C76771D0A0D
2503053502084003074501075201066D040B7D0206930406990C01C66314DCA00FD3A603
D7A407D38111AF2001C20B05C80909C7050AC70408CA070ACF090DCF090CCD0909CD0A0A
CA0807C50303C30201C40101C60302CD0707CE0B09C80806C80A05CB0B06CB0C03CD1005
CB1203C71505C51905C41F08C2230AC42D13C7371CCC4529D35539DA654CF38C78F79C8C
FAA798FCB3A5F9C3B9EDD0C7EFE5DDEFEAE7EFEEEAF0EEECEDECEAF1F0EFF3F1EFF4EFEC
FAEBE5FFEAE2FFE8E0FDE3DDFEE5DDFEE5DBFFE4DCFFE6DFFFE3DBFFE2D9FFE1D7FFDBCF
F1C3B1E3AC97E1A489DA9A7CD48F71C87E62C17257B55F46AA4D35A4402A9D2F1F8D0F0A
9105089501079B0309990106960105970308980208980208970106950106930208900008
8902077B01027501017201006D00006A01006B00006E01006F01016C00016C01016F0001
7101007401027601027801047501057001056C020667070BA851589B464F9F4B528A3638
5803025701035001015001015D07016E1604585A0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063720B8A6049D8C9C7D0CED1CCCDD1CDCFD1D3D3D69F9A9C251114
2C080D3604093B00054301074F010570070F7F020696060AA11104C35714DC9D10D2A202
D6A206D68513B02401BF0C03C60908C6060DC3050AC3060BC6070BC7070AC60506C60506
C60405C30101C20201C40203C60303D10B0DD30F0FCB0A09BE0A05BD1608BB1F0BBF2E15
C33D21CA4F35D26548DA7959E38D6EEA9F82EFAC92F6BAA2F8C4AFFBCFBFFFE2D7FCE6DF
FAE8E2F7E7E2F6EBE5F4EBE6F2EDE9F1EFECEFEEECF2EEEEEDEBE9EFECECF0EFEEF1EFEF
F1F0EFF1EEEEF4F1F0F2EFEFF3F1EFF2F0EEF2EFEEF4F0EEF5F1EEF4F0EEF2EFEBF2EDE8
EFE3DDE9D7CDEBD7C7EAD6C4EAD3C0EBCFBEE9CBB9E9C7B4E6BEAAE7B7A3E4A693A6493E
840707920308980209970209930107920108920007920007950106960107950108910009
8601067700017200007402016E00006900006D01007101007101007001016F01016F0101
7001007101017201017200027001026E01026C0104700C0FC3676D711A23A858619B4E53
7523235C05065100024B0101570400690F03711E0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00742C057C4C3FDACBCAC9CACBCBCCD0D0D2D6D3D4D8BFBCBF2C1B1F
2A080C3302063B02084303084C01046502077C02068D0305A41403C25112DE9C13D2A103
D5A107D68512AC2300B90A01C10604C3060BB60306AB0003B50407BD0305C00304C20304
C10203C20101C30202C40203C90506D30D0FCF0A0DC0090B920402B34733E28769ECA184
EFB299F2BFAAF1C8B5F1CFBBEFD4C1EDD5C6EBD8CDEADBD2EEE4DCF5ECE7F2EDE9F0EDEB
EFECEBEBE9E7EFECEAF1EDECEEEDEAEFEDEEEFEEECEFEBECF0ECEBF2EEEFF3F1F2F0EEF0
F0F0F0F1EFF2F1F0F2EFEEF1F3F2F3F0F0F0F1F0F1F1F1F1F0EFEFF0EFEFF0EDEDEAE7E7
ECE6E7E5DCDAE5DAD6E3D8D2E2D7D1E0D6D0DFD5CFDFD4CCE1D5CCE4D4CAECD0C6B3746B
7B0D0C8B020794040A8E01068B01078C0009910108920008950108980208970208930109
8601067700017200007300007101016D00006E01007002016F0201700101720201710101
7101007101006F00016F01026D01006D01026A02047310118C3034AD5760A5576074292E
994A4C7320235305084700014F0201640D056C18013A950000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0053B11A6C20096C332DD7C2C0A7A5A4CCCCCFD2D2D7D3D3D8CFCDD1372C2F
27090A3104083802074303084E010662030877050A8300029A0C00B7450EDE9C15D1A203
D5A107D88511AB2200BA0903C00604C20609B80407AA0103B00003BA0103BF0205C00106
BE0102C10103C30203C60405CA0808CF0B0CCD090CBA0A0C7202027D4134DCB69DEED4C1
E8D6CAE5D6CEE3D8D0E3D8D0E3D9D0E5DAD4EAE2DEEEE8E6F0EBE9F2EDEDF3EFEDF3EDEB
F2EAE9F3E8E7F2E5E4F7E9E9EFE9EBEDEAEAEEEBE9F2EEEFF2EFEFF1EDEEF2F0F1F1EFF1
F2F0F1F6EFF0FBEBEEFCEAEEFBE8ECFAE7EAFAE8EBF8E7EAF7E7E9F8E8E9F4E4E6F0E1E3
EBDCDDE4D3D4E4D2CFE5D3CDE4D4CDE3D5CDE1D6CFE2D7D0E1D9D2E2D8D4ECDAD5CA9994
7E1E1C87090B8C0B0C961A1B8D121586070D8B030A910208940108950108960208930308
8601067B00027702027501027302016F00016E00016D01006A00006D0001700001720101
7301017302027302027001026D01016A00016601029035359F4C4FBA6F75AB656E9B565C
A15A5E883B426E21284A02074A01015E0B06671301555B0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF002EE012B27A54621B0B62201AAF8D89918583CFCECFD1D1D6D2D1D7D6D6D84F4748
23080A2F050B3502084002074E04095901056C0306860708980D04A93809E09A16D2A104
D39F05D98612AA2100BC0B05C10607C5060CC3070DBB0409B80105BB0104C10408C10206
BF0303C00104C20405C80707CC0A08D10B0CD10B0DC10B0E8407085B2420D4B6A8E8D6CC
E4D8D2E5D8D3E5D7D0EBDAD0EAD6CDEDD6CEF4DCD8F7DDDEFCDFE1FDDCDFFDDADAFFDBDC
FCCBCCFFCDCFFCBFC1E3A3A6875E62BCAFAFEEE9E6F1EEEEF1EFF1F0ECEDF0EEEFF2F0F1
F2EFEEFAE5E7E8ADB3EC9FA5E79298D3828AD0838DCE848DD78D94D38B92D28E96CE9197
CE959AD0979CCE9696C48F87C69489CA9C91CFA69DD4B2ACDABFBBE1C7C7E5C9C9E1B0AE
8A2F2D7F0D0BCB605CE88280C35D5DCB62658812168A030B9102099101079301068E0105
8300037B00027701017601017301017000016F01016D01006D01016E0101700201730201
7301027401027301017001016E00026B0002670103721A1DC1777AA5626764232BCA8A92
9C58608A3F498A414B530F1447010158060569110570200000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0059C229AC80665D1C115D130D91625D8E7C7ACDCACDD1D3D6D1D1D5D5D5D7696367
21090C2C040B3302083C01074703075202076002047601038E0801AA380ADE9715D3A104
D4A005D98912A92300BB0B04C20709C6050BC3040BC2050CBB0106BA0105BE0206C00207
BF0205C30207C40407CB090BD00B0DD70C0FD90F10D00F0FAF1111690907E0AAA2F9D5D0
EFCEC8E6BDB6E6B4A8E4A99DE5A096E79B94EF9C98F59DA0F18F92E98081E47776E37172
E06162E35A5CDD5151D14C4A903432886663F1E7E3EFECECEEEEF0F1EDEEEFEDEEF0EEF0
F1EEEBFEE4E5CA7A7BC64D4FC63C3DB7282CAA1D25AE2027B4252BA91F27A2252D952B30
8C2E319033368B2D2C892C2481251A83291D822D22803229964C4AA55E61A86364AF6262
9732318C201EDC7B7AC56A69953A3CC96F72C15C637F040C8E040C8D00088F01088C0207
8301047A01017701017701017501017302027001016E01016D00006F0101700101700101
7201017201017100016F00016F01026D0102690204620408600E14934C539E5A6397545D
8A454E9F5860954E585B161C4801025704046910086E1C0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE8351A07C6761241A60120D87524FB5A1A1D7D2D7CFD2D6D0D2D6D2D3D6878286
200B112B060C3303083901073F01064C01085C03076D00018C0903A63509E09A18D6A404
D6A206DF9118AA2700BB0C04C40809C6050AC5070BC10308BB0105B90005BC0104C00207
C40408C6040AC9060ACC070BD20A0DD70C0EDB0F0EDA120FD31915B91D1AE87471F99997
E68580C55F55BB4F41B64234B63D31B83C33C1423ACB4A45D04F49D55751DA645DE16A65
DD524FD33733D5463EE1695FD38177C8A59EF2E6E2F2EDECF1EFF1F2EEEFF1F0EFF2F2F3
EFEFEEF8EAE8F5C4BFEA9D96E17A72C14039B61E1DBE1717BD191AA81A1B90211F9F4B45
C27F78DA9993DC958DD58C80CA7C6FBB695CAE5A4DA24A3F9C41399335308624217E0F10
870E10901F21CC6C6EC46E6FD986899B464DC3656E8B19228A030C8C01088C0208890107
8401057D01037601017401007401017201007001016F02026E02026E01016E01016F0101
7302037401037301037101017001026E01016A01016401035F020658070C6C2129C07883
752E38BF7982AC6570671F274D02045905046910096D18003E970000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC875C997B696C332B62140F814A4CDBC9CCD3D1D7CDD2D5D0D2D6D2D4D8AAA8AB
1C0E1225050A2B01043501063C01074B01085A0204760405940E07A02F05E19C1CD6A505
D7A405E0931AA82700BB0C04C10506C7060BC8080AC4050ABD0104BC0106C20308C9070B
CA080CCB080DC90709D00A0CD40C0EDA0E0EDC120DDE1810D6180DDB2319D82924CF2D2C
C5302BB02C22A93426BC5140CE6C5CE78A7FF4A39AFCB4AAFFC1B6FFCBC3FFD6CDFFD8D1
F2A9A59B2E2A9B4840FFD7CBFFE7DEF6E7E2F4EFEAF0EEEBF1EFF0F5F0F2EFEEECEEEEEF
EFEFEFEEECEAF4E8E4FCE9E2FFE1DAF8BEB5BF554FAC1D1BA21B1B6B110CB68178F3D1C8
F7E2DAFAE7E0F5E0D9FAE1D8F4D7CEFBDBD2F7D2CAF5CAC1EBBAB3ECB4ACDB948C98312F
911113870B0FD56E71C97277BA6A6ECE7A82C96B74901D2689020B8F010A8E0108890006
8501067D00037600017300007201017201016F00016D00016A00016800016801006C0101
6F01017201027501047401047001026C01016901026501026402045F02065B050D73202B
74242F6C1D28994F5A6F232C5A070B6006066A0E076E15003D930000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B918A0805DA88F817140395F14117E464BDFCDD3D0CFD4CDD1D5D0D1D6CFD3D6BABABC
1B14161901042501043203083D06094902086106097A0608940E07A02D03E29B1CD7A407
D6A505E0961AA92801BD0E07C00607C5050AC50509C5060BC30509C3040ACA090ECC090D
C90708CA070ACB0806D20C09D70D0CDA0E0EDD150FDF2016F24636E43123D42016BE1F17
A2271FCE796EEFB5A9FBCEC2FCDCD2FDE1DBFAE5E1FAE9E4F8ECE5F8EDE9F5ECE9FAEAE9
FBD9D69F56545C2A21DFCCBEF5EEE5F8F4F0F3F2EEF2F1F1F2F1F1EFECEFEEECEDF0EEEF
EFEFEFEEEDEDEEEDEBF2EEECF4EDEAFBE9E4F8C5C1AA45437C1B19633530E9D8D1EDE4DE
EAE7E4EAE9E7ECEBE8F0EDEBEEEBE9EDE9E7E8E2E1F1EAE8EDE5E2EEE1DCF9DAD6BA7372
8A1417920A10981C23D87179CD717AD5767FC45963870A128D02099101089201098E0107
8400047D00037901027601017401017401017201006E00006B0001690101670000690000
6C01017001037301037301027001016B0002680103640002620104610105630109660610
6707116509137B263077242D650A0F6807096C0C087115033C910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC226A98E719D8B818059555A1817652C34D8C3CACCCBD0CBCED3CED2D7CCD1D4B5B8BA
201C1D0F00011700002701063402054501065600046D01048B0C079C2D03E39A1DD9A607
D5A605DC9315AB2C00BB0C04BE0506C30709C5070AC6070DC40409C7050ACB080DCE0A0E
CD090BCD0809D30C0CD60E0BD90E0CDA100EDD1510DF1F15F34638D02318AF18108A241A
CF9489F2D3CCF8EBE5F2EAE6EFEBE7EEECEAF0EDECEEECEBEEEEEBEEEBEBF3EFEEF6EFED
F8E0DCAE746D531E13BDA391E8DBCEF1EBE6F3F1F0F1F0F2F3F2F3F6F0F1F9ECEDF8E2E6
EBDDDFEEE9EAEDECEAF0ECEBF0EDEBF0EBE8FDE3E0CC8A886C21215B3835E6DED7EBE6E3
E9E9E8E8E9E8EBEBEBECECEDEBEBEBEAEAEBE5E5E6E7E7E7E9E9E8EAE9E8F2E5E4DDADAE
86202394080D97080F8E0A14991E2B9D242F8E0E168C030A900107930208940208910209
8701067E01037900017700017701017501017100016E00026C00026A01016B02016A0101
6B01026C01016E01017001016F01016D020468010561010460000661010865010967010A
6C040C6C070E7D2027832A3166080D660507680A086C11033A8F0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC82EB7A08B92847F9C7E7B551A1C5A1F26C9ADB3C5C2C7CCCED3CBD1D4C7CBCFB4B6B6
322F2E0900000E00002001052F020541010755050A6503077707048E2803E19B21D8A506
D5A505DE9515AB2D00BC0D04C20807C30709C6080BC6060BC9080CCC080CCF0B0ED10A0F
D0090CD20A0DD40A0CD80E0FD70C0DD90F0DDA130EDD160ED91812C71B177506059F6E65
EFDAD1F1E8E4EFEAEAEDEBECEEEEEDEEEEEDECECEBEDEBECEEEEEDEEEBECF0EEECF5EEEB
FBE8E3D19D91612315886353E8D5C5E8DDD7E5E1E0E6E3E3E7E4E3F5E9E9E5BCBFC57980
85494DCCB7B8EEE9E8EDEBEBEAEAEAEBE8E9F3E5E5EDC0BF7E3B3B461818CCBFBBE8E4E0
E6E6E5EBEBECEBEBEBE9EAEAE9EAEAEAE9EAE6E5E5EBEAEBE8E8E7EBEAE9F0E7E7EDCBCA
9C46449710109E05099C040B99040D94030C9202089201079300089301099101098E0108
8801068001047B01027A01027800017903037201026D01016D01016E01016E02026B0102
6900016900016B00016C00017001026E01036600036101055D00055C00046301076B030A
6C040B6D050C700D1274121869090D630407620606680F0277270000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
88A943B29C8CA296948B706F541A1C521317BE9CA1C8C2C7C9CBD0C8CDD1C1C7C7B5B5B4
4A43440C01030F00002101042F02073B01074801055A02076903018A2901DC961ED6A306
D4A406DF9618AA2B00BC0E05C00705C6080BC30709C8070ACA0A0ACC090ACC0A0BCE0A0B
CC0707D1090AD40B0CD80E0FD80E0CD80E0CDB120EDB110BD9120EBE1616570101AA9089
F2E8E1EEEBE8EDEBECEDEBECEEEEEEEBEAEAEAEAEAEDEDEDF0EBECF1E6E6F3E1E0F9E1E0
FCDAD3F8BAAC7E3325572A1FE4CEBDE8DBD1E7E2DFE8E5E4E9E7E3F9EAE9F0BEBEC24D50
A33333916262F1E5E3EDEAE9EBEBECEAE9EBF0E8E9FADCDC9B5A59651E206E4A4BE0D6D5
EAE9E7EBEAEAEAEAEBEBECECEDEDEDEAE9E9E6E4E5EAE5E4E0D8D7E8DDDDEDDEDEF0D2CF
B067628C0E0BA1070AA30308A202099C00079A02099702089401079202088E01088C0106
8901048401037D00017C01017D01027A01027601017201017101017001016E00016D0001
6C01016C01016D01027102037503057202056A01046401055E01045C00036501076A0207
6802076903086D070C6904096B070C68090B610605630D0074260100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78F5DB29E929B929199818056211F511011A47E81CFC6CBC1C3C8C7CBCFB6BCBBB1B1B0
655E600B02031201012401053001073D0108480207590207720803842100DB981FD4A205
D5A507DF9519A92900B90C03C00705C50809C60A0AC70808C70807CB090ACD0B0BCF0A0B
CD0A08D20B0AD40E0BD70E0ED90F0CD90E0DDC0F0EDC100DD8110DC51818650403836260
E9DFDBF0EDEBEDEDEDEEEDEDEEEEEEEDEBECEBEBEAEFEDEEE9DDDDE3C0BFEEAFADF3A2A3
ED8F8DE7786FA93930500E06C3AB9AE7DACBEBE6E0F3F2F1F7F5F3F0E7E5FED7D5CA5A5A
BB3935702E2BEFDDD9F1EAE8EBEAE9EBEAEBEDE9E9F7E3E3CA8E8D81222368191C8B6669
E8DDDEECEBEBECECEDE9E9E9EBEBEAE9E9E9E8E6E5DAD0CED1B5B4D2A5A8D29EA0DEA5A5
E5928F981A18A20609A9040BA70309A101079B0208980106B41C20C22D3195060B8B0003
8B01048702057F00017E01027F02027C0102790101760201740101730101710101700101
7001017001016F01017000027200026F01026C01056701046001045F0105630105650105
64020566020768050965010769050B6B090C650908631205742A0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9363BBA79E928A89AE9D9B5A2E2B511011885B61D0C2C9C0C0C5C4C7CBAEB3B3B3B2B3
7D7A7C09010416010329050C34020A40030B4601075F030983110D801A00DB9820D6A406
D6A607DF9319A92800BB0C03C10906C50807C50907C70908C80809C90708CA0607CF090B
CF0B0BD00A09D30D0AD60E0ED70D0CD80D0DDA0E0DDC110FDB120ED41816A414145A0D10
BB9E9EDFD8D7F0F0F0EFEFEFEEEFEEEEEDEDEEEEEDEFECECEEDFDEDDAFADBC605DC94341
CD2F2DD02821C42B26680C08947567E3D5C6E9E4DCF2F2F1F0F0EFF3F0EDFEE8E7C97776
AE32306D1D1BCAB1ADF2E8E6EFEBE9EAE9E8ECE9EAF3E5E5E8B8B6932B2B9B1E2172151B
8F6268E3D7D9ECEBEBEAEAE8E9E9E7EBEBEAE9E9E7EADFDCCCA5A494484990292D9E2E31
B4383CA31315A7060AAA0308A80208A10006980105980104B21418C22327B41E248E0105
8E01078C01068501027E01007C00007B00017A0002790202780202730000710000710100
7201017101017202017101017101037001056D01056700046000035C00045E0005610106
61010662010566040866020867030A69060B650A0A6E21157E381400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9063B9A69EA69E9E8D807D734A49500E116E3A43D2BCC6C3C1C7BFC3C7AAACAFB0AFB0
928F8F0D050717020426030B30020B3801083F0007550209760D0B821D00D8951ED6A507
D5A605DA8F16A82600BA0B02C10705C70908C50807C80808C70607CC0A0BCD090ACF080B
D10B0BD00A09D20C09D60E0ED60D0CD90E0DD90F0CDB110DDE130DDE1410D41B19A41417
69161BAA888EE5DDE0EEEDEEECEEEEEDEFEEEDEDEDEDEBECF2EBE8FCE3DFF9BEB8D76E65
C53125D7261AD0231C96211D643930DCCCBEE9E3DAEFEFEEEDEDEDEEEBEBF8E8E6D89A9A
A332308729259F7A77F4E7E2F1EBE9EDEAEAEDEAEBEFE7E6F8D4D2A84746AD1C1CAD1A20
7E161E86565CDDD1D2E8E6E5E7E6E5EBEBEAE8E8E7ECE8E5F3DBD7D89C989A35319F1718
A90E13AB080DAA0408AB0408A90208A6020AA10309980305B11E23A8161D990A118E0209
9001089202068C01038100017C01017A0102770001760000770101760102730000720000
7101007000007101017101027201047301057002066701035E00025A01035B01035F0106
63030961020664030765010767030A66050B5F08096D2218CBA99C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE976BB6A89F9A9898968D8C8866664E0F13582028CAB1BBC0BDC3B8BBBFA9AEB0AFB0AE
A2A29F140D0C19040624040A2E030C38020B40010A4700075F0604761901D0901BD6A708
D6A807DA9017A92700BC0D05C20806C60809C40606C8060AC80708CB090ACA0607CE070A
CF090AD10A0AD20B09D60D0DD60D0BDB0F0EDB110DDF130EDE120CE2120EE11612D91A1A
B71E2175121B9A6A72DFD0D7E7E5E8EDEFEEEAECEBEDEDEDECEBEBEEEAE6F7E7E1F8CDC2
DF8676C53B2BCF2A20AC221E53140DD1B9AEE8DFD7F2EFEDF0EDEDF0EDEEF5EAEAEDC4C4
B05B58A5524D9A726DEFDDDAF0E9E7EEEBEBEFEDEFECE6E7FAE0DEC0706CAC1E1BBF1618
B3191E84191F79434AD5C4C7E6E3E2E8E7E6EAEAEAE9E9E8EBE6E3F5DFD9DDA59EA43C38
A41312AE0A0DAE0509AB0307AA0207A80109A50209AB151BCC4C50D65F6382080A850004
8F01069200059001048701037D0001790001780101780102780102770201730001730101
7201007101007000007101027201037101036D01036802035E0101590101590103580003
5B01065D01066102076101056605096505095C0507641B11C6A59800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE9B6FBAAEA58C8D8DA5A0A27C6363470F13451014B69BA2BDB8BEB7BABEAFB5B4AFB1AF
B4B7B32723211C0A0C26050C2D01093E040E46040D49020A5905046B1600D0911FD5A609
D4A506D98D16A52300B60701C20806C50707CA0A0ACB090BCB090ACE090BCD090ACE080B
D10B0CD20A0CD40C0DD60C0DD80D0DDD1010DC110CDD110CE0140DE2120EE41310E51512
DF1A18CA212492171E77343DC1A6ABE0DCDDEDEDECEAEBECE9EBEAEAEAEAEEEDEBF5E9E3
F3CEC2E89686C13D30BB2A24610E08A98C84EBE0D9F1ECEAEFECEDECE9EAEFEAEBF7E6E6
F9D5D0FBD5D0F3DCD7F3E6E5F2ECECEDEAEDEDEBEDE8E4E5F5E3E2E4A4A2A52422BD1211
BF1111B1161A881B2169393AC9BDBAE8E4E0EAE7E8E8E6E7E8E7E7EBE6E4F3DEDBDCA39E
A0342EA30F0FA60205AE0508AE0508A80106A40107A1070DBE363DC5494E9D1B1E910409
9201069301069401078E01058400037A00017801017900017A0200750100730001740102
7201017101007202017301017301037001036B01026802035F0102590003560003550004
5500035900055D02075E00056102066105075E070763180FC5A29600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB986BBCAFA799999B8A87889E8A8A4314163F0B0BA4878AB9B3B5B8BABEBEC3C5C3C8C9
CBCFCE3D3B3D1E0B0F28070E2D02093F060D430309480108610B09691300CC8C1DD4A309
D5A307D98A18A62000B50802C30B08C40705CA0A09CA0808CC0909D00A0CC70305CD090A
D00B0CD10A0BD30B0CD60B0ED80C0DDC0E0FDA0F0BDB110BDE130CE21310E41412E71712
E81812E51B16D7201EAD21236C1B1F967A7AE1D9D7EBE8E7EBEAE9EAE9E9E9E8E7EDEAE8
EFE2DCF4CEC3DF877AB632297D16107C5552EBDEDBEDEAE7EBE9EAEBEAEBECECEEEEECEB
F0E9E6F1E9E6EFEBE8ECE8E9EEEBECEBE9EBECEBECEBE8E9F2E5E5F1C2C3A83939B61715
BA1410AF18149A252262231E786059DCD2CDEBE5E4E8E5E7E6E5E6E6E5E6EEE6E7F1D8D6
D5928E961F1BA50C0BAA0507AF070AAB0409A70308A4020A9E040D99050C9C060B980206
9200059502079701089602088D01068201037C00017C01017A0100760101740101760101
7301017101007301017401017501037301046E0104680203610103590103560103550102
5300025801045C01065F000563030863050860070767180FC9A59900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9667B5A89F9897968E8A8AA08F8F4B1F1F41090A8E6B6DBCB4B5B9BBBFC1C6C9C6CDD0
D2D7D95152551B0B1124050C2D060A38060A3F0307460004610A07691301C68619D29F08
D3A008D78515AA1F00BB0A05C40907C80908C80909CA0A09CD0909CF090ACE0909CD0809
CF0A0BD10B0CD10B0BD60C0DD90E0EDB0E0FDA0F0CDA110CDA120EDC1211DC120FE21610
E91A11E61710E11E15CE271FA12E2863312BBFAEA9E4DDDAEDEAE9EAE7E7E9E8E6EAE9E8
EBE6E4F4E2DDFAC1B6BF4941A0241F5B2220E7D6D3EDE8E6EAEAE8EBEBECECEDEDE7E5E5
F2EAEAF2E6E6F0E7E9EBE7E8EBEBEAECEBEBEDECEBEBE9EAEEE7E7F6D5D5B8615FA5201C
9A1A12811D14AA6358C3998FDCC7C0E6DCD7EAE5E4E9E6E9E5E4E6E8E7E8E7E4E5EDE2E2
EDC8C6AE57529B1511A30508A60308A60308A60107A40107A10107A00108A00108990106
9100049301069802089902089301068B01048300037D0100790001760101760000790202
7702027301007301017501027702057401046E01036701026100025B0004570103550103
5601045801045D030761020663030665040863070966160ECFAA9E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99262C2B5A99897939B97968F7F7E552928480B0B794F51C1B6B7BFBFC4C9CED1CDD1D5
D3D8DB7072741B0F12280B0F2B04083505093F02084F050A5E0908641100CB8B1ED4A10A
D4A008D68315AA1E02BD0B07C30606C9080CC90B0CCA0A0ACE0C0BD00B0CD10B0BD0090B
D10B0CD20B0DD30C0DD4090AD80E0DD80D0DD90F0FDA1312D61313D20D0DD00B06DE140D
E21912DA1C15C72519B03327C27165DCB6AFE9DCD6EBE4E1ECE9E8EDEAEAEBEAE8EAE7E7
EEE7E5F3E0DEFDC5C1C84E49BC2C275C0C0BBCA3A0EBE2DDEAE9E6EAEAEAE9E9E8E7E3E1
EAD5D5D1A5A9A6777C7D6164D6CBC9EFECE9EEECEBECEAEAE9E6E4F1DCD9CD8E8B862522
530602B4897EF1D7CDEFDFD9EBE1DEEAE5E3E7E5E5E6E5E6E5E4E7E3E1E3E4E1E4E5DDE0
EDD4D3BF7D778A120F9905089C02069F0107A10108A000079F01059E01079B0106960005
9000048F01049300059600069300068F01068801038100017C00027A01037A0103790103
7600017300017300017400037401057301046E01036900026401025E0103580004540004
5200045100045300055A01046103066303085F0407621107AE756000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99161C3B5A99F9D99858281A99C9C5E37364C0E0D64363AC7B8BBC6C7CCCCD0D4CFD3D8
D5DADE86878B1B1112280C0F2C050A34040B40030A53040B5705045B0F00CD8F1FD6A209
D7A30AD57F15AD1F01BF0C08C30607C9080CC7090BC80708CD0B0BCE0A0BD10B0CD20B0C
CD0707D20A0CD40C0ED60C0CD60C0CD70D0DD90E11D40D10D00D0ED00D0BD20C08DA140F
D51B17A81612A14036E9B1A6F8D8D1F1E5E1EFECE9EAE8E6EAEAE8E8E6E7EBE7E5EDE4E1
F2DBD9F7C7C7F09191CE3533CD28237A100F8A6763E8DBD6EEE9E6ECEBEAEEEDEBF1EAE9
F0D1D09C4B4F9C393D561415A88886EFE5E2EBE7E8E8E7E7E9E7E5F0E3DFE0B1AF7B3130
420F0BD9C8C0EBE3DDEBE5E3E7E5E5E7E6E7E4E4E5E2E2E3E1DFE0E1DCDCE3DCDCE4D5D5
DDBEBBB8726C840D0B9303059401059600059901079C0209990006990106980107960107
9100058F01059101049401059301059101058D02058601038001047A0002780102780102
7500007501027501027501047300047300047001016D0203660102610104590104560105
5400055001054F00055401055A01045D03065A0101620D0384351400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9060C0B1A69E9B98908D8DA2989A6A4648490E0E522226D2C1C5C9CAD0CDD3D8D2D8DE
D5DADE9C9CA11E1415280B0E2F080D35050C3E020A580A125B07085D1200CE9120D6A409
D7A109CD7411AE1C00BF0C06C40606C8090BC8070AC9060ACD0A0BCE090BD10B0CCF080A
CE0808D20A0BD30B0CD60C0ED50B0BD80D0ED70C0ED90F10D8110FD9110DDE1510D61411
B31413630C0BD9B0A8F3E2DBF0E6E5EDEAEAE8E8E8EAE8E8E8E8E6E6E3E3E3D6D5ECCAC8
F2ADADE07174D13839E02624DB231F9D19175E2B29E3D4CEEFEAE7EDEBEBEFEEECF2EBEB
FDE0DFBE6668AC3132791B1A7F4D4BEEE1DEEAE5E4E9E7E8ECEAEAF0E7E6F5D2D3995353
4B0F0CAA9590E5E2DEE7E6E6E8E7E7E7E6E8E5E4E5E3E0E1E1DBDADBCECBCEB6B0C79E97
BF7D7696312C8E0807950204950104930002950004950106940105940106930007930108
9201069001059001039301049503069001048A01048601058001047A0002780102770102
7500017300007400017601037702057501047201026C01026401025D01025A0103570104
5300044E01044C0004500106550004570103570101650D0286311100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BA905DC6B7AC969593A4A1A5897F84856769430D0D48161BC7B2B7CACAD1CFD7DDCDD6DD
D6DCE2B0B0B51F181A22080B2D060B33030B3700074600085806095D1100D09320D7A60A
DAA40DC76D11AD1900C00B05C50706C50709C70509C90609CC0808D10B0CCF090BCF070A
CF090AD40C0ED40C0CD60B0ED40A0AD80C0FD70D0DD90D0EDB0E0DDF120FE1140FD71613
A10F0E4A1313D8C7C1EFE8E6EBE8E8EDE9EAE9E7E8E9E8E6E8E7E5EBE6E3E4D3D0D19B9A
B94C4BD03130E42722EA211CE5221CC02323560D0ACAB7B2EAE6E2EEEBEAEDECEAF1ECEB
FAE5E4D08585A82E2E96292862211FE3D1CEEEEAE8EBEAEAEBEAEAECE7E9F7DDDFBD7876
7F27265C2827CFC1C1E8E7E5E5E5E5E7E4E7E1DDE1E1DCDDE2D8D8CBB5B0AD8074913F34
8B1C158E0907950303990102990103970203940003920004920005910006910108900108
8F01078F01059001049000039001048C01048600038200028100028A0A0C840C0D730101
7402027401027401037300027801057902067501046C01036300025D00015A0002590003
5400034E01044900024D0004580207580206550001620A028A341600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78D59C3B5A8A5A6A589898E9E989C836B6B411211420D11B79EA4CCCAD0D0D7DBCCD5DA
D7DCE2BFC1C5201D1F240C102E070D33040C33010640010858090B651700D49722D7A608
DCA40FC56712AD1701C10C07C40607C60609C80508CA0608CB0808CE0A0BCE070BCE070A
D00A0BD20C0BCD0705D40B0AD50C0BDA0E10D80E0DDA0E0EDD0E0EE1100EE41412DD1512
B71613520203A7908FE9E2E2ECE9EAECE8E9E8E6E7EBE8E8E6E5E3EAE7E4EFE3E1F1CBC9
E28E88CE473DDD2E20E8241AE7221AD428256B0B0A9D837EEAE4DFEEEAE8EBEAE8EEE9E7
F5E6E3E7AFAC9E352EA3352E6C221ABFA79FECE6E2EAE9E8EBEBEBEAE7E8F5E4E4E8ADAB
9B302E7B1819733E42CDBBBDE6DFE0E3DEDEDFD9DCDDD8DAE0D8D7E1D0CBCDA295A04D3E
8D12099304029701019902039701029501029201029101039201069302089201098F0009
8E01088E00059101048F01048F0106890004840003890002980407B11E21D14B4EBE4647
7A0A097101037001027101007A0304870B0F7600036C00026700026201035E00035B0104
5401034D01014900014D0003550207590208550002610801903A1F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B58D57C3B7AAA2A5A4909497979697806F6F3E14143D080C987D83D2CFD5D0D6DAD2D9DF
D5DCE0C6CACE282628220B102C060E36050F3502083C0109570A0B691C00D79924D8A90A
DCA410C06010AF1601C10A08C30708C60609C9070AC90608CB0909CD090BCE090CCE080A
D20C0CD20C0AD10C07D50E0AD80E0CDA0E0EDB110EDC100CDF120EE31210E31310DF1310
D218159710115F1A1EC4ABB0E7E0E3EBE8EAE7E5E6E8E6E7E7E5E5E8E7E6EAE6E5F0E5E2
FCDDD7F2AFA4D66152D73226E1251BD524208B16176F4743EADDD9EDE8E6EDEAE9EDEAE8
F1E8E6F2D2CCC17F73C07468AA7164BFA69CECE4DEEBE8E7E7E8E8EBEBEBF3E9E9F8CCCB
A73F3AA71E1D86161B74353CC7ADB1DFD5D5DFD8D8DBD6D7DBD7D7E0D6D5E6D0CAD6A598
A850428C0F079404029601029501029201028F00018E000290010390000691000891000A
9202099101069101058E01048D01068802078400039A0207AD050CAF060BA5080AAB1A1E
AA272C7300017000027201027A02038E11157601046E00036B0204670103630204600307
5602054F01034A01024B00035100065600075A01026408018F361D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18954CABFB2A1A6A59EA4A6808181A193934824263B090B765A5DD4CED4CCD0D5CDD4DA
D5DDE0CCD1D52A2A2D1E090F28030B35030F37040C3A01074B0506621800D29823D4A608
DCA513BD590DAF1400BF0907C4070AC30408C50608C60506C80708CB0709CD090AD00A0A
D00C0AD10B0AD10C08D40D0AD70D0CD80C0CDB0F0CDD100BDB100AD80B08DF110EE21212
DD1212D01919A014196B1720AD868EE0D3D9E7E3E6EAE8E9E9E9E9E9E7E8E9E9E7ECEAEA
EFEAE7F7E3E0FBC6BDDE736ACE2F27CC1E1BA21D1E4F1717D9CBC6ECE6E3ECEBE9ECEBE9
EEEAE7EDE2DEF6DED9F9DDD7F7E0D9EDE1D9ECE6E2ECEAEAEDECEDEAE9EAEDE6E6F4D4D3
BD625FB21B19B4151A8D131A651F25AD9194D7CDCCDCD8D6D8D5D5DCD8D8DED5D4E7D3CE
D7AB9DA852458D120B9303039100029000039001048E01038E01048F0106910108910108
9301099302089102058C00038802047F02048000029D0408B10208B40406AE0203A90307
9F050A8401037400027602057D07098F161A7300046E01056C01046701026201025C0003
5501044F00034900024800024F01055502055A00026407018A2E1500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18651CFC2B5B6BABA8B9394999B9C8C83834D2F2E3C0A0A694B4BD8D1D5D3D7DBCAD1D7
D5DCE0D5DADD393B3F1C0A102A040E33020C3702093D0105520706641A00CF9825D1A40A
DAA114B8500AB01300BC0604C4070BC30409C40608C5070AC80708CD090BCF0B0CD00B0A
CF0C0AD10C0BCF0A08D20A0BD40B0CD70C0CDB0F0DDD100BDA0F09DD120CDF120EDD0D0D
E11111E01315D71919B91C207C111A864A56D0B8C1E1DBDDE6E4E4ECEAEBEBEBE9E8E7E8
ECECEBECEBE9F6E7E4FECBC5CB5C57BF211EB42121590A09B9A09CEDE5E2ECEBE8EBEAE8
EEECEAE8E6E3E9E5E4E9E4E4ECE8E6EDE8E6EFEDEBECEBEAE9E7E8E7E5E7EBE7E6F2DCDB
DC9390AB1F1EBF1214B20E149212195D1217957776D3CBC6D9D7D3DAD7D5DAD6D6DCD4D2
E5D2CBD7AAA0A44D448C0D0B9102049202059101058E00038C00038D01058F0106900006
9201089302098F01058A0103840205750102760001980409AF0309B10104AE0002AC0102
A802059403057C00017601047E0A0C9B282A7101046E01046D01046601025F01015B0102
5401025101044C02054701024A0103500104550001640802862C1100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8DAD49D3C3B7AFB2B1969B9E989B9B8881804B2F2D400C0D603C3EDDD3D8D6DAE1D5DCE3
D1D6DDD5DADF4042471D0A122F081037040E40030C4E070C600F0C681B00D39A26D2A50C
DB9F15B24708B21202BE0706BE0407C4060AC50709C4050AC70608CC090ACC090ACD090A
CE0B0ACF0A0BD00C0CD40C0DD50D0ED70D0DDA100ED90D0BDB0F0CDE120DDE110CE11110
E11110E31212E1130FDD1817CD1F229D17206E1D28A38083D8CDCCECEAE7EAEAE6ECEBE8
EBECE8ECECEBEDEAE7F9E2DFECA5A2B62B27C52423871110935957F3DDD9F0E7E4EBE6E5
ECE9E8F0EBEAECE8E6EFE9E8EFE9E8F1EAEAF0E9EAEEE8E8EFEAEBEEEAEAEAE5E6F5E6E4
F7C4C2A8312FB70E11C20E13B60F15941115570B0B81625FCDC4C1DCD8D4D9D5D4DBD6D5
DFD5D6E7D2D1CC9B9592302B8B05059201049101048E02048C01048B00028C01028E0103
9102079001098B00058700048302056F0103690001890308AA060CB00307AC0001AA0101
A902039B03048100027902057801047702047301036F01036D01036701026000015A0102
5501035101044C01044801034600024A000256000165060281260C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B68853D2C1B6A7A9AAABB1B58A8D8F9A95966147483F0A0D542A2DDACCD1D6DAE3D6DEE7
D1D8E0D5D8E14D4F551E0A132C040D39050E43050D4F060D510302681D00D49B22D2A308
DCA017AD4006B21103C00908C00609C2070AC30607C3050AC50609C9080ACD0B0CCC0809
CC0A0ACF0B0DD00A0BD10909D40C0DD50B0CD40B0AD80C0CDC0F0FDE0F0EE11211E2110F
E2120EE61411E71712E61612E31916D91C1EBB1F227A1517875858D9CBC9E9E6DFEDEAE5
EBEBE6EBEAE8EEECEAF8E9E8F6C0BFB43532CC241FBB221EA93E3AFDC2C1FCD8D8FAD7DA
F8D6D9F9D6D9F9D3D6FBD4D6FAD2D5FAD5DAF9D2D7F9D1D7F8D4D8EFCDD2F3D4D8F6D2D5
FFC8C9BD4849BA1315C20D11BB0A0EAC090E8F0D11580A0C795959C8BDBBDDD5D4DDD8D8
DBD5D8DFD6D7E1C8C4AC6661810B089003068F01038D01038C01038A01018A01018A0001
8C01028B010687000487010483020572020560000072010395050AA30306A60202A80203
A802059A03067F01037300047902087801057300047000036C0002660103610203590001
5501035101054A01034600014300014900015E02046F060384230C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CD37D2C3B6C0C3C59BA3A79FA4A78C888A6952523E0B0E491B21D9C7CED7D9E0D2DAE1
CED8DED4DAE1575A611F0E172A060E3302093A010A44010B4C04036D2502D49C20D6A509
DCA017A73700B21003BD0805BF0607C00609C20508BD0207BE0206C8080CCB090ACB0709
C90609CB0709CE080AD00809D30B0BD30A0CD40C0BD80C0BDB0F0DDA0C0EDE0E0FE31111
E61510E91611E7160FE81711E81713E61714E21C19CC252386171966393BD4C8C4ECE7E3
EAEAE7ECEAEBEDE9E9F5E4E4F0B7B8B83636C41E1ABC2B26C7544EBD605EC46B6EC36169
CD636ACE6067C85B60C15258BD4F55CA5D63CB5D65C65C63C35E66B95B63B96168C66C6F
D76C6DC53937BF1412BF0B0CB7050AB00308A6080D88101544050679635FD1C6C5DED5D7
DBD5D8D9D4D4E2D2CEBF8A837E14108D03059001048E02048C01028A01018A01018A0101
8800018801028601038500028201027602045D00015D01017501038701039403049B0304
9C04078A02057000016C01047802077B01067901077401046E01016700016100025B0001
5300015101044D02044801024500014B000162010473040386210B46990400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DCA34D1C3B7BFC3C69EA6AA9EA4A7848485725F5E3F0F11411116CFBCC0D4D7DBCED7DD
D0DBDFD5DCE25E636A190B1425050C31030A39030E43020C500805722A08DBA225D6A509
DE9C18A83300B20C01BD0808BD0506BE0307C3060ABF050AC1050AC50408CB090ACA070B
CA060ACC080BCE0A0CCE0809D30B0BD60C0EDA100FDB0F0DDA0F0BDC0D0CE11011E5110F
E5130FE5130CE7170DEB1811E71611E61510E91B13E11D19BC2525550D0CAB9792EDE4E1
EAE8E7ECE8E8F1E7E8FADADED9878CB8262ABD1D1B820D0CEDAAA3ECADA4D17F79C05553
BE4140BC3737B83231B52F2DB5312EB3322DB23432AA322FA333329E35359D3737AB413E
B13932B32920B91D15BA140FAF0807AD0608A404088E0A0D5607054B2922BFAEA7E1D6D7
DCD6D8DCD6D6E1D3CEBE8F867F18138F03069101038E01028D01028D02028C01028B0101
8902018701018600018500018400017D02036501015200005A00006A00017601037D0003
7E01057001045D00026400027901067F01057F01067901047101006C0002690104600202
5801025101034D00024901034701014F0000670305740402801A0544960200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CC37D8CABFB5B9BBB2BBBE848D8F929394877878401213430E13BCA8ACD0D4D6D0D9DF
D0D9DFD4DAE07074791B0E1724050B31030B38020A3F01074E0603772F0BDCA222D9A50A
E09919A82B00B50D02BF0808BE0608C1070AC30709C3050BC20409C8060AC9060ACA070B
CA060BCC080BCE0A0CD10A0CD30C0BD70D0CD70D0BDB100CDC110CDE110EE00F0DE5130F
E61410E71610E5140EE91610E81711E5140EE4180ED81A16A618157A342DDDC2BBF1E3E1
EEE1E2F2DEE0F6D1D3F3AAB0C04348C41C1FC61C1B941416894B49F9D9D5FDE2DBFFD5CF
F9BDB6EDA7A1D88E85D1867CCE867BD18C83DF9D95E5A8A1E8B1ABEEBCB5EEBCB6F8C3BB
F6B8ACDF9284D6786BB64338A31D15A5120E9C07077D0304590D07906755D1B9ADE4D4D0
E1D6D4E4D6D4D9BDB8AC6C647F0D099202039501039101028E01028C00018E01018C0001
8A01018701008601008600018601018402037D0A096409075608077223225E0B0B5D0104
5D01045700035200016301037B02068201058402078001057701027101016B0103640203
5D01035401024D02034701024301014F00016A03047302017C160246970300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D9CDC3BFC4C5A1ABAD959E9F8486867F7271441819481015B0969CD7D8DDCFD7E0
CFD7DFD7DBE27D8086190C1326050C2D02073805093D03074A0702813A12DCA221D7A308
DA8E17A82500B80D03C1090AC00509C4060BC5070AC7060BC60508C70508C9070AC80609
C9070DC9060ACD090BD0080AD30A0AD70C0CD80E0BD80D09DA110ADB100ADD100AE1120E
E3140EE81811E5140EE6130EEA1611E91710E81B14CB14119E1C1BE9A19EF8C5C1F9CACC
FAC3C8E99EA4D26C71C0373CC72020D11717D01715C11D1E87181CAD777CF1DCDCF6EAE7
F6EAE6F6E6E3F6E5DFF3E2DBF9E9E1F6E7E1F5E6E2F5E8E5F0E6E3F1E7E5EFE7E3EEE6E1
F0E6DFF4E1D9F7D7CFEEBDB4D1877EA94039991B17800906AB5247D09181CE9D91CBA19C
CBA3A0C89895BC7B7594302C8C06049301019401029101018E01018E01009001008E0101
8C01018801008701008600018601018601018205039B37306C211CD69A97CD92935C1818
4E00025200015C00016F02047D01058302068601068702077F02057401026C0102650001
5E01025500024F02034500013F00005000026E04067403017D150245950200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D8CCC2C6CCCDACB6B89DA5A7787C7B908684563232440D119F7F87DAD6DFD1D7E2
CED7E0D6DBE486898F1A0B1326050C2D02093301064003075107028C4312D99F1ADAA40A
D68416A71E00BC0E06C20809C3060BC7050DC6060CC8060BC70608C80708C80707C7060A
C7060BC80509CD080AD0090AD50C0CD60B0BD60C0AD90F0BDB0F0ADC100ADE110AE2120E
E4150FE5150FE6160FE7150EEA1712EB1713EA1B15DA1917E24748EF7678E76B6FDA5B62
C33D47BC2631C92228CF1A1BD61715D71414D51413D11516C31E23951E28AC6970EDCED2
F3E5E7EEE8E8EDEAE8EBE7E7EDEAE9EDEBEBEBEAE8EDEBEAEBEAEBEAE9E9ECEAEBECEAEA
EAE9E7EBE9E6E9E3E1E7D9D7EED4CFE8B7B0BB69628E211B971F1BA0302CA33B3AA64343
A441419B31318E16168E08079603049601029401029100009101009102018F02018C0102
8B01018A0100870000860101870101860101820202851613AA534E85423D995C596D2525
5F06076802057502077E02068201058B050A8E050B8B01088502067800027001026A0001
6201015901025101034801024200015401017104067401017F150547950300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8AAA45DACEC4BEC5C7C2CCD1838E90888F8F9894924C2E2C440D108E6972DDD6E0CFD5E0
CED8E1D3D9E38F8F981D0D182B071030020B3401073F0206580F058E4612DAA31BDCA30E
CF7712AA1B03BA0C07BF070AC20509C5050CC6050BC9060CC70508CA0708CA0809C9060A
C70609C90708CC0809D20C0DD1090AD50B0CD90D0CDB0E0BDD100BE2130FE3130DE71611
E51510E71611E1120DE5140FE7170FEB1812EB1A13E71814DF1D1BDE2323DE2325DB2026
CC1118D1131AD71718D61213D61312D51313D51314D71416D7181BCD2025AE222BA13F48
CA8890EFC1CAF7D8DEF7DEE3F9E4E9F8E5E8F6E3E6F7E1E5F9E3E9F8E3E7F4DDE2F6DCE0
F7DDDFF4DADEEAD4D7E2D1D3E2D4D3EAD8D6ECC5BFC0736E9019179C0C0F9E070D9B060B
9E080D9C06099A03069801039801029701029601029300019301029201018F01018A0002
8A01018B02028802018600028702038701048601048104078212139C3C39A34846A34140
9727287F04088301078601068901068E030A91040C8E02088801067E01057501036D0102
6401015901015300034B01024800005D01027502047702028014064D9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B0814ED7C8C0C3C8CDA9B4B98B999B8992948483825E42424911127F585FDED6DFCED1DB
D0D8E1D2D8E191939C1B0C172A050F31020B35030A3A01054504008C5017D8A51BDBA30F
C66A11AB1903B90B08BC0509C00609C4060CC6060CC7040AC80609CB0709CB0909CB0909
CA0909CE0B0DCF0A0BD10A0CD40C0ED4090CD90C0EE01011DF100CE0100BE3110DE5140F
E51510E51410E00F0DE71511E8170FE7160FE91810E91813E71612E81816E31715DA1212
D40E10D30F11D91516D20F10D31011D71515D31112D51213D91615DA1919D41C1ECA2126
B8262EB43844BB535DC96B77DE8791E897A0DA8691DC8693E38998DD8491DC7F8CD97B86
CB6A74C76A73C57279B06D73B27F84C5A0A2E1C3C2EBBFB9A54C46950B0AA60309A60107
A40006A100049F00049C01039A01039700029601029600029400039401039200048D0101
8C01038A01028701018600028601038600038700048600068201077E04077E0507840609
8603088802088A02098C020891040B95070E94060B9003088A01078101057801046E0102
6501015C01015501014D01015000006701027B03057D03047F12064C9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5EC935D6C6BDCDD0D5ABB5BAA1AFAF7E87887B7B7E84696C47101371474EDDD3DCCED1DB
CED3DCCED5DD8D9298160A1426060D32030C37010B44060D490A039A601AD6A516DEA412
BF5E0FAD1604B90807BC0508C1070AC3060BC20409C7070CC8070ACB090ACB0909CD0908
CE0A08CF0909D10A0AD2090AD60D0DD70B0DDB0D11DF0F10E0110EDF100CE1110CE61512
E2120EE2100FE41211EA1613E5140FE81711E6150FE91813E81713E61815DB110ED10D0B
D00D0DD4110FD51311D31111D41313D41211D71514D81312DC1814DB1513DE1A17DE1B1A
DB1C1FD11C20CE2126CC2329CB272DC6252EBF1E2AC3212EC21E2CC41F2DC31F2BC11B25
C21C22BD1B20B2181E9F141B8E131D7E1B2489464AC89694D58E868E1510A00406A40003
A20102A00003A001049E00049B00049A0105960003960104970106970107930003900102
8F00038F01058B01048700028500018501028701048601058601078501068700058C0208
8E02098E020991050B91030A91020A95030B96050C8F01078A0107820005790003700102
6601015D01015702015201015901016E02037D01037E03037B0D034D9C0C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC733D9C9C0C6C8CDBFC8CD8B9799858E90929296654E524B141864353DDBCDD5CCD2DA
C8D1D9CCD5DD90979E18101729081034030D39020D3B0105480A01A36A1BD8A414DEA114
B64F0AB11503BC0807BD0407BE0408C2050AC20509C20308C30408CA090CCC0A0AD00A0B
D00A0BD20A0AD50D0CD50C0AD90F0CDC100EDC0F10DE0F0FDD100DE0100EDE100EE11111
DE110EE51311E71512E61510E71611E4130FE3140EEA1711E91814E41614D70F0FD00D0C
D00E0CD10F0ED71513D31111D21110D51311D81511DC1614DD1713DE1716DD1715DF1917
DC1916DD1916DD1A16DB1614DA1717D81719CF0F14D21217D31115D7151AD31114D31214
D11113CE1012C30C0FB4070CAE0710A00811890C13761417C36461A42624A10408A50106
A101029D00029E01039F01049D01069C01089A0106990105990106970006940003930103
9100039101048D01048901028802028601028601038500048601058701058800038C0005
90010890010890020A8D010792030C96030D99070F93030B8B01088401067D0204740101
6901015E00015801015700006502027503037D00027D0203780B0149980800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC832D6C4BBC7CACFAFB8BD8E999C8E989A888A8D7C696C43101358282ED7C9CEC9D0D6
C3D1D5C9D3DA9AA1A61B111826070E33040C37020A390205400701AB7318DAA714DF9F16
AC3F04B51303BE0A07BD0307BD0408C3060CC4060BC5050CC6060BC60408CA0809CE0809
D10B0CD1090AD30C0AD60E09D80F08D70C07D90F0BDA0D0BDE110EDD0E0EDB0D0DE11111
E41412E41310E4140FE61511E71712E71713E61612E91813E51612DB0F0FD40C0ED10C0E
D40F0FD20D0ED41110D10F0FD00E0FD61414DA1714DE1816DE1816DC1514DB1615DE1818
DF1B1AE01A18DD1914DE1815DD1816D41211D41212D61413D71414D71314D21011D20F10
D10E0FD10F12C3090EB8070DB0040AAC0208A5040999070B960B0EA30E11A30207A50106
A101049E01039F0104A001059F01089D01099C02089A01079A0106990106960004920104
9100049100058F01058B01038A01038801028600018501028500018601028701038B0105
9101089101098F020A8B01088F030B95040D96040C94040C8C01088401057E0103770103
6E02036201025900005D00016D01017801037F01047F03057A09006B600A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59C42CD8C7BACCCFD3B2B9BFA5ADB17F888A8083859A8B8E3F13154B1C21CEC1C3C7CED3
BFCDCFC8D2D69DA3A71A121727090E2E030838040B3D050A450B01BC841ED9A510E29E1D
A83400B71104BE0808C00609C00709C4070CC50509C60308CA070BCA0709CD090AD10A0C
D20B0DD50B0ED50D0BD70D0AD70D08DB0F0DD70C0BD70B0CD90C0DDC0E10DC0E0FE41213
E41312E51313E2110FE61413E61511E71413E71512E51413DD100FD30A0AD30D0ED40C0F
D60F10D40E0FD71313D00F10CE1010D31113D71415D91415DA1515DB1515D91614DD1717
DD1717DC1615DB1513DD1716DE1817D61111D61314D81514D91415D61213D10E10CF0C0E
D00C10CF0E14C1080FB4030BAE0108AC0107AA0106A50106A50208A30007A50108A40107
A30106A10106A001069F02069D01069C01069B01079C03089A0107990106970106920105
9000049001069002078F02058D01028700018500018400018400018400018600038B0106
91020991010A90010B90040D91040B94030B94020995040C8D03098400057D0004780003
7001036702036101026801027201017801017E02037E0204780700902D0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C22ADAC9BCBFC1C7C5CCD58F979C7A82849497987B6D6F3B1214431317B9A7A9B4BBBF
B4C0C2C6CFD19EA4A81B141926070D2F030937040B3C0508470D00C28A20D9A410DF961D
A42900B70F06BD080AC2080CC3070AC40608C70606CA080ACD090ACD0A0AD00D0BD0090C
D20A0CD60B0ED70D0ED70B0CD70C0BD90D0FD80C0DD60A0DD80C0DDA0D10DC0E11DF0E10
E31111E41213E31110E20F0FE51410E81411E61412E41314DA0F0FD60F0FD81111D80E11
DA1214D50F10D61314CF0F0FCE100FD01111D31313D41313D71415D81415DA1716DC1816
DD1715DC1715DA1714D81412DD1917D71413D81515D71414D41112D20F10D10D0FD31012
D10D11C9090FBC040BB10208AD0107AB0106AD0309A80109A9030BA6010AA5010AA30008
A10108A3020AA101079F02069B00039A00039A01049A0105980004980003970103940104
9100049101058F01059101059002038B02018601018400028401028401028500038A0106
8F000891010A93030C95040E96050D95040A94040A93050B8C02098500078101077B0106
7200046A00036A00027602047901027701017A01017C02037407008F321500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC32CD8C5BBC5C8CFB3BDC48A95988C94967E838584797B3B13153F1013A99698B3B6BB
B6BFC2C9D1D4A0A7AC1810182C091331010B3703093902054A1300CA9525D8A50FD78A17
A62303B90F0ABE070BC1060CC5080DC30506C70807CD0B0CC90608CB0808CF0C0ACF0B0C
CF070AD50C0FD60C0FD3090CD50B0DD60A0DDA0E10DB0D0FDA0E0DDB0F0FDC1010DF0F10
E21010E21011E2110FE61313E81511EC1914E61612DF1210D80F10D81112D60F0FDA1314
D60F11D00C0FD10F10CF100FD11312D31514CE1110D11312D41415D21214D41514D51814
D71D1AD1201BCD251CCC241ECE251FCD221ECD1F1DD11E1CD31817D31313D51112D71112
D71114CE0C11C1080EB40209AF0208AC0107AB0209A9010AA8020BA50108A20107A30107
A10107A00007A10207A102079E01049C01039B01049A0105980104980103980204940104
9200049000068F01069000059001038B0101860000850001860102850102870004890006
8E010992020B92010B93020B93020A96050D94040B93050C8B01088700088100087E0108
7600057200037A00058401068201047800017801017802037007008F361700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BF29D0BEB3CBCED5ACB5BA9CA7A9777F826C7072A59C9E3E1C1E380B10A59295B8BABF
BCC5C7CDD6D9A2AAAE16101828071231030C35020A3601044B1800CE9E26D8A711CF7D15
A41B02BA0D0ABF070BC0060AC5080BC20406C20403C70507C9060ACD090CCE0B0CD00C0C
D20B0DD20A0DD20A0DD30B0DD30C0DD50A0DD80D10DB0E0FDA0E0DD90D0CDA0E0DDF110F
E1120DE41311E2130FE81612EA1611EC1A14E31711D80E0DD20C0BD30E0ED3100ED71213
CF0D0FCC0C10CE1011CD1012CD1010D11315C90E0ECD1212D01717C81516C41C19C0261E
B22A22AB362FBA554DCE6D65E5847CE6817AE47872DB635FCA3F3CC52420D01A18D81716
D31011D21012C80C11B9040AB10209AC0209A80107A60006A70106A50105A30105A40105
A101049F01039F01059F01059F00049E01059C01049B01059901049500029101058D0206
8F02079002068F00058F01048D01018A01008700018601028701028801048902068A0106
8E010992010A92010B92020B92020A94040C92020A8E020A8701078400088101087D0107
7701047A00038A02089403088C01037D00007800017803036E040092381A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C028CEBDB1C4C7CEC1CBD1929E9F727C7C969B9B7C75773D1E2031060B9C8B8FBBBDC1
C4CDCFCDD7D9A0AAAC1411161F070C29030A300208370706502103D0A126DCA918C26D15
A11601B90A08C00809C2070AC30608C90A0CC60808C70609CC0A0CCE0A0CCF0B0CD10A0C
CF090AD30B0DD10A0BD60D0CD50C0CD60B0DD90E10D80B0BDB0F0DDB0F0DDA0E0BDD100D
DE120CE2140FE51610EB1812E91812E1140FD80F0AD20C0AD00D0AD20E0DCF0D0DD41213
CC0C0FC90C10CA1011C90D10C90F0FCE1414C61112C01816BC201CAB241F9E332CAE5D53
DA9E95F3C8C2FCDCD7FBE1DCF9E1DDFCE1DDFDDFDCFED8D6FCC3BEE88E89C2403BC41F1A
D01514CF0F10CD0E13C0080DB5060CAC030AA80209A80208A70105A40104A20104A30105
9F01029F01039E01049D00049E01049C01059B01049B01039900039401038700047B0002
7F01048B03078E02058F01048D00028B01018700018701028600028901048A01058B0107
8E020992020A94030C92030B94070E93040C94050E8D030B8600068301067E00067A0104
79010285010497030A9C01089501038701017B00017702036F040090331800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C027D2C2B3C6CBD0C5D0D88B999B8E9898868E8D7671713E2022370B0EA18B8FC7C9CE
CCD4D7CDD7D9A0AAAC1515181A060B2703092C03082D0202532605D2A225DDA61AB65C11
A51404BC0C0ABF0708C10609C50709C9080BC80A0BCB080CCD0A0BCE070ACD0809CF070A
CF090AD20A0CD60E0ED60C0AD60B0CDA0C0EDB0F0FDC0F0BDE110CDE110DDF120DDC0F0C
E0130EE41811E71812E71410E51712DB100ED50E0BD10E0CD3100CD81412D41112D00F11
CB0D0FC90C0FCC1213CB1213C81312C51715BD1D1AAC231E9022199C4A42DAA59DF7D7CF
F6E5DFF1E6E3EFEAE7EEEAE9EAEAE8ECEBE9EDE9E8ECE5E5F5E6E4FFDCD8F5ABA5BC3E38
C71E1BCF1414CC0C12C3080EB6050CAA0107A70108A70108A60007A20103A000039F0004
9F00049C00039D01059D01049C01049B00059800029800029A0002940003890105780001
7300008301058C01068E01048E01038C01018800008600028700038901048900048C0107
8E010791010995050C8F020891060D91050D9407108D030B8600068200057E0105790002
7C00008F02069D0208A102079C03068E01047E01027602026C03008C2F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55C025D1BFAFC7CCD1ABB7BE95A3A68D99986771709795954224253E0E11A68D91CECFD4
CDD6DACDD4DBA0A9AC1211151A03092B040B2C02062B030162340ED29F21E1A61DAE4E0C
AA1303BD0B0CBF080AC10609C5070BC5050AC40608C9070ACD0A0BCD0708CE0809D1090B
D20C0CD30B0BD20B0CD60B0CD90D0DDB0D0FDC0E0EDF0F0CE3140FE3120EE3130FE21210
E3140FE61711E71712E71511E31510D9100FD40E0DD6100FD50F0DDA1516D41211D21111
CF1111CE1213CE1616C71615BE1C18AF211D9A27209F4B44C89187E8C6BFF1DFDAECE3E0
EAE6E4ECE8E8ECEBEAEAE9E8EAEAEAEBEAEBEBE9EAE9E7E8ECE9E8F0E7E5FADCD8DE908B
B5302BC81919CB0E13C60B11B9050DAF040BA60007A50007A60108A20105A001059D0104
9C01049A00049A00059C02069D03069900039800029900029C0204990104930205870306
7A00028302068D01078F01058E01038D02028A02038902048901048C01038B00038D0105
90010792010892020892030A8D020992060D92060E8D030A8701078402087F01067C0003
8601059A050AA10207A50308A00408910306800103730102680200862A1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C127CCBAA9C9CED2B3BDC59AA8AD768485798484888989452A2B3E0D10A4878BD2D2D7
CCD5DBC6CFD79AA1A7140E1422080D30040D34050C310402784816D5A21EDF9F1BAB4004
B01206BC0A0DBF080AC2080BC4070BC20609BD0205C5060ACB0809D10B0CCF090AD20A0D
D30B0ED60C0CD80E0ED90D0EDA0F0FDB0E0FDD0F0FE1100EE41410E4130FE51410E10F0E
E4130FE51410E61611E51511DF1411D50D0ED30D0ED71212D51211D61213D41310D11312
CE1513CB1A19BD1D19AA241D972E26A1564ED1A29AEDD3CCF2E5E0EAE4E3E9E8E7EAE9EA
E7E7E9E8E8E9E6E7E8E1E1E3E7E8E9E7E8E9EBEBEDEBEBEDECECEDECECEBEDE7E5F2D4D0
E49793B62829C61317C80D13BC070EB1060CAA040BA50108A7040AA30208A001059B0002
9A00029800039701069900059801039701039902049B02059B01039B0105990206910205
8701038801048F01059001048E01028B01018B01028B00048B00048A01048A01058C0106
90010792020893020995040B90020993060C92060C8D030A8901088300077F0106800004
92020AA2040CA20209A402099C02058E01048201037101026301007E250E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C026C6B4A3C6CACECCD4DC859398808E907985856C6F704D3434400E129F8186D2CED5
CDD3DACDD4DD9A9FA5170F1623080E2B030B2F030B2F02028C5C1ED6A41BDA981AA32F00
B10F06B80508BE070BC00609C00607C0070ABB0302C5080ACC0A0BCD090AD00B0CD40B0E
D60B0FD70D0DD70D0BD80C0BD90F0CDA0D0CDB100DDF100DE3130FE31110E51410E61312
E61511E3120FE41611DF140ED70F0CD30E0FD00C0ED20F11D41212D21211CE1711C21A14
B8221DA92B23A03F36B7766CDEB7AFF0DBD4F2E8E3ECE7E6E9E8E8E7E6E8EBECEEEBECEE
E8E9EBE9EAECECEDF0E8E8EAEBECEEEAEBEEECECF1ECEBEFEDEDEFEEEEEEECEDECF1EAEA
FBD6D6BF5C5DBB1C1DC71012C10C0FB3050AAA020AA70308A60208A50108A000059C0104
9B01049A01049700049700059A0105980004970105970104980003990005990106950106
9301049302069201059001048D01028900008901028C0105890104860002860003890006
8C000790010892010996030B96040996060A94060B8F040B8901098100067F0005880106
9C040DA3050E9D00089C02089602058A000281000273010264010081250F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C025C8B4A2C1C5C9BAC4CC9EACB0909EA05A67669397974F39393E0F148D6F76D3CED5
CAD0D6CED5DD9A9DA21C111822070E2702092C0307330704976A1DD7A61BD38E1B972000
B10C08B70307BD060ABF0708C00607C10609C10607C40608CA090ACD090AD20C0DD30B0E
D50D0FD70D0FD40D0BD80F0DDB110DDA0E0DDB100CDF120FE2120EE3120EE51511E3140F
E3140FE2130FE21913D40F0BCF0D0BD01010CE1010CC1311C91713C6231BB2271DA53A31
B2645BDBA59DEACCC3EFDED8EDE4E0EAE6E5E6E6E6E5E4E5E6E7E6E8E7E7E8E7E7EAE8E9
EAE9E9EAE8EBE5E7E9E5E5E7EAEAEBECECEDEDEDEFE5E5E7EAEBEDEBECEEEAECEEEEEDEE
F5E4E5EEB0B0B02D2CC31414C30D0EB50609B0060BA70308A70409A50308A101069D0105
9B01039A0103990105980106980106970004950003930104960106970106960106930104
9401049402059301059102078F01068C01048C01048B0004880003870102870102870104
8800048C010791020994020A95030A96050C95050C90030A8B020A850006880106940106
9F030A9B040B8E02088B01058F02068C01048302027301016701007F200A21CA0200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD22C8B3A1C3C7CBBBC5CEA8B5BB7A8588818C8D9296984F3D3F3A0F157B5F66D5D1D5
CCD2D7D0D7DE91969B170F1423080E28030B31040A3A0702AB791ED7A51BC278159B1B01
B20C09BE080DC0070CC0060BC3060AC40409C50709C8070ACA0809CD090BCF090AD20A0C
D30D0ED40D0FD31010D91716D81211DB1011DB0F0DDF120FE1140FE0130FDB1811D61B14
D81C14DC1D15D51A13CC140FC81610C61B16C3241DB4251CAF3328BE5B51D7948AF1CCC5
F6E2DCF3E7E3EAE6E3E8E7E5E7E7E5E7E5E6E7E3E7EAE6E8E8E5E6E8DFE2EDDDE2EDD5D9
E8C9D0B595A0B2A1AAD4D0D6E2E2E4EBEBECEBEBEDECEBEFECECEFEAECEEE9EBEDEFEFF0
EFE8E7FBD6D5B95353B61616BF0C0EB9080BB3060BAD060CA50208A50309A20107A10109
9D01059B01039A0103990103990105950105940105910003920003920005930006920105
9100049201069000058E01058D01068D01098C01068B0004890103880102850001850002
8901058C000790020992020994030A96050C97070D8F02098A00078B000795010A9F010A
A0030B8D01077700038914178504088B04088202037501016A01007C1D0843950300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59BF24C3AE9DC7CDD0C5D1D998A5AB8A949891989B6F7174564448350B1483686FD3CFD4
CBD4D6D3DCE1889193110D1220070F27020B2B0205431102BD8A21D8A31AB35F11A21602
B40909BC060BC0060BC4070CC5060BC4050AC50709CA090CCC080BCC090BCE070AD20C0D
D20D0DCC0A0BC90F0EE62E2FCA090CD90F12DC0E0EDF120EDE1310CD0F0DBC1F19E96E66
D35A4FCA4B40C74639C6463DC85348CC665BD57D73E7A399F4C4BCFAD9D4F7E6E2F2E9E8
EDEBE9E9E6E5EAE9EAE9E8E8EBE9EAEDE4E8ECDDE3F2D9DFEEC9D1E8B1BDE69DABD87B8A
C35765A63D4C601C2A61454ED1CBCFEDEDEFEAEAECEDEDF0EFEFF2EBECEFEBECEEEDEDED
E8E7E5F6E0E0D28487B02022C41316BD080CB5050AAD040AA8040CA5010AA20008A10108
9F02069A01039A01039A01059600059001048E0104920206910102910102910005920106
9202069001058C01048901028A0104890105890104880003880004860102820001850203
8B02078D02088F020894040C95040C98060E97060F90030B8D010895010AA0010BA5010B
A0040B8401057402058B181D7901058203077C00037001016701007A1C0843950400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BE22C2AC9BC6CBCFBAC6CEA4B1B59BA4A969737592969A58494E320B13836870D6D2D8
CDD5D9D3DDE280898E140F1421050F2B030B280001411300C79525D9A01AB0530FA61203
B7080ABF070DC3090CC6080CC40709C4060BC4090CC1070BC1080CC4070BCD0B0DCF0B0C
D20F0FC00808B91010BA1313C2080ADB1012DE0E0DDF120DDD110FCA1010870202B66C68
F1BFB9FED4CCFFD4CCFFD6D0FFDCD3FDE3DBF9E4E0F6E7E3F4EAE9F0EAE8EFEDEBECEBEB
EAE9E8E9E5E5EDE4E4EAD8DBE8CBCFE3B2B9E6A1ACDB7F8BC3525EB6303EBA2634C3212D
C81E26C32026901B213D050DAA999FEEEDF0EAEAECECEDEFEBEDEEECEDEEEAEBEDE6E7E9
EDEDEDF6E9EBEBB2B6AE2C31C7161AC80D12BE080DB20308AB030AA6020AA20007A10107
9F02069A01039701019901039701068F01038A0005900208920106930106930205910104
9100058F00058C01058800028800028700028901038800048801058601048001017F0101
8601048A02068D010791020894030B98051096050F94040D97010BA2020DA9030CA70108
9C030A7D00027702077A02077500047802078413166E010266010076190843970600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
53BB1EC6AE9DC4C6CABAC3CAA9B4B97A85898A9598989FA35C4F533A131B80646DD8D2DB
D2D8E0D5DCE57D838C1810182707102F030A3305054C1C01CE9E29DA9E1EA13B05A30901
B70809BF090DC2090DC00508BF060ABD060AB7090CA502089D0106A80407BD090CCB0B0D
D20F0FC30D0FC32828DD4646C91512DA0F11DE0E0DE0100CDF100CDA1614B61112750B0E
965B60DFC1C6EEDEE0F2E6E8F1E9EAF3EAEDF1E8EBF1E9EAF1EBEBF3E9ECF3E9EBEEE2E4
F1DCDCEEC8CDEFB5BEE897A1CD656CBE4048BC2C36C3222DCB1E27CA151EC91318D1171A
D11818CD191AB022235B090D644649E4E4E6E7E8EAEBECEEECEEF0EBEEEFEAEBEDECEDEF
EBECEEF3EBEEFCD3D7B84B4EC31B1ECC0F13C40B0DBB080BB2050AA80209A30006A00005
9F01059B0004980002980102980103960207920209920108930107920006920004910104
9101059001068E01068C01048C01048D01058C0206870104880106880105840103820102
8400048801058E020690030795060C97050E95020B9A050CA3040CAB050EAB020AA50108
9603097700017602067C040977010777030876070D6F03066701026E120542950500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD20BEAA97B8BCBCC6CFD6A1ADB488959B9DABB06E757A675A5F3811197B6068D9D3DC
D5D9E2D7DDE7767C85140E1625070F2D030B3406055B2B0BD2A22CD59622972A00AB0D08
B50709B9050BBF070EBF070CBB080CB1070A9D0104BB2E34D5585DB027299C0405C30E12
CF0E10CC0F10E1373AE23A3ED21516DD1112E11110E21210E2120DE11411D81414C1161B
95111A882937B56F7CD198A4DFB0BAE2B7C2E4BBC4F4CBD1FACED5F5C0C9EEADB9E49AA5
D67B85C4525EC13944C62935CE232ACE1C22CF191CCF1418D21518D4141AD41518D21516
D31716D3191BBD1C1D8A1A1D441113C8C5C6E7E9EBEAEBEDEAEBEDEBECEEEDEEF0ECEDEF
EEEEF1EFEAEDFADFE2D07A7DB92023C81014C50C0FC0090CB6060BAD0209A60007A30109
A100089C0106990103960001950001960105960107940109920108910108920107910006
9000069101079001078F01068F02048D01038C00038A00048B0005890105860004830103
83010387010490040A8E01088F020A93030B97030BA40710AB050DAB0209A90209A30108
97030C7500036D020578050B7600057B04096E02076B01046901026C0B0142930400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52BB1EBFAB97BABEBFBBC7CEADBAC2A8B5BC6D7C7F91979C695E62331117785E64D6D1DA
D5DBE4D7DFE9696F78160D1621060E2C050D3106046D3E14D2A129CF8C21901C01AB0909
B6080ABA060FBB060FBA070EAF060A9F0103A00308C82C35C63038B524288B0000AF070A
CB0D0ECE0B0DD00E12D31116D81012DD0F10DE110DE21210E1140FE0110FDB1111D20E11
C81115C01620B71F2AAF222FB02D38AE2E3BB13642C84C5AC44654C13846C02F3BBF2530
C5222ACA1D23D41E20D5181DD5161AD41517D01312D31315D71618D81519D71619D7161A
D41416D01317C7191CAE2225580A0C948889E4E8E8E8EBEBEBECEEE9EAECEBECEEEBECEE
EBECEEEBEBEEF4E5E7E3A3A6AC2327C81416C60D0EC0080ABA080CB3060AAA0108A50108
A101069C01049900029600019701029601039501059301078D01068B02088E0209910208
9000069101079001078E01068D01038C01018D01028D01038D01058A0107870005850004
8500048800068D020A8E010A91010A99060E9B020AA8060FAE060EAC040BA702099F0007
98050C7501045D00026A060C7302087B050B8E24286802036F0305700B0142920400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B81BBFA893CED1D3BFC8D2B2BFC88493998291939DA5A96C6368341218775C63DBD6DF
D1D9E2D7E0E95D626B1B0E1627070E2E050C34060589571AD5A325C1771A8E1301AA0A0A
B5080BB8060EB80811B207109D03079C0104B50710C00A13BD0912B10A0F8F0000A90609
CA0E0FCF0C0DD30E0FDA1014DA0E11DF0F11DE110FE0130FDF120DE01410D7110FCD0B0B
CB0B0ACD0E10CD1114D01417D11618D2161BD2191FCF171FD01921D2181FD51A1ED3181B
D11718D11515D71616D81918D51817D81D1AD31915D31C18D31D1AD31917D71F1CD6191B
D41518D21419CB1618BE1D227B1216614547E1E3E4E5E8E7E7EAEAE9EBEDEAEBEDEBECEE
EAEBEDEBEBEDF0E8E9F3C6C9AB373CC11719C60E0EC20A0BBD080CB6070CB0050CA8000A
A301089D00049900039801039802059400029301029201058801037C00018301038E0207
9102068F01058D01058D01058B00038A00018C01028E02068B0106880004880004870103
8600038701038E020890010A98040CA70B13A7050CA70309AD050DAA030AA301089F0007
99030A7C040A5C090C4C00046301067C050D810E156F0004700203720C0243930600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
29DB0DB59A84CBCDD0C6CFD89EABB3839297A6B4B7747D826A616836141B7A5E66DED9E2
D3DBE3D7E0E950555E1C0D1527060C2D0508360904A4741ED7A525AE5C138F0D00A60708
B1050BB3030BB0070D9F040B8D0002A8060CBD0710C4060FC0070CAD070A8C0000AC090B
CD1011CC0809CD0708D80D11DC0E11DC0E10DB0D0DDF120FE0140FDC1210D00C0BCD0E0E
C90C0CCB0B0CD00F10D21010D61411D61414D61918D21817D31D1AD31D19D61C1AD51B19
D21715D11513D01918C9211DC62D25C9372FC5382DC63E33C8463AC8493FD14F46D2433F
C61F1FD4181CD2171BC7171BA21F22451114D3CFD0EAECEBE9EBEAE7E9E8E8E9EAEAEBED
EBECECE8E9EAECE9EAF6DADCB65B60B81C20C40D10C30B0DBA0409B5050BB3050EAD030A
A702099E00059A01049701049400049100029200019200029002058501028501028C0103
8F01028E01028B00038E01068D00058C01048D02048D01058B01078900068C01058B0003
86000187000290060C93030AA30811B00811B0070FB1080FAB040BA80309A40109A00107
9B020981030AAE5C615D23255903077E040A86060D7C020674010370070044920700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC8F74C7C6C6C3CCD5AEBBC1AAB7BD7D8C91868F956C656A32141B7B626ADDDBE4
D6DEE7D9E2E94A4E561D0E1427060C2C0508340800B48421DAA5279B4009970E02A70608
B0040CB0040CA9090E8A0205880203B10A12BE060CC3050AC1090DA60407890000AE090A
CD0F10CF090CD10B0CD40D0ED80E0EDA0D0EDB0F0EDA0E0EDF1514D30D0EC9090AC8090D
C70B0CCC0E11D01013D01112CE1813C9211BC52D25CB4339CF5247D2554BCF4B41C73830
C52A23C9231EBA1F1D7D0908D98A83F5B4ABF1B4AAF3BCB0F5C3B7FCCDC4FECDC6FDBCBA
BA3E3ECB1C1FD11518CE171ABC22245608099B8B8CE8E8E7E9EAE9E7E8E8E9EAECEBECEE
EBECECEAEBECEAE8EAF3E2E4D28E90B12528C51215C1090DB9050BB4040BB4050FAF030C
AA020AA200089E02089901059500049401049400039500039201038E02048C01048E0303
8D01018C00008D01028F01069202089101078E00058C00058C00068C01068B00048C0105
8B01068900048E01069E060DAC080FB70B14B4060FB30810AC050CAA040BA60108A10108
9C01088C040C85232B954F565C030883040D86010881010678010371050044910600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00947452CCC9C6C2CBD1C0CBD492A0A884939896A1A76C686C31161B79626ADFDBE7
D6DEE7D6DFE63C3F471D0C1429070E2F06083E1000C6962CD79E278D2C019B0C03AB060A
B2050EAE050F9F080F790001890205B1070EC1070DC6070CBD080BA003048E0000B80C10
D00E10D50C0ED50B0ED60E0ED70F0DDA100EDB100ED60E0FD61011CF090DC8080CC80A0E
CC0E10CD0D11C71113BD1918A7211AAE493FD99085FECAC1FDD4CBFFD6CEFECDC5F9BCB6
ED9F98D17068A6453F4B100E98817DEBDFDBEEE2DFEDE4E1EFE6E4F0E7E5F4E8E7FDE0E0
C46C6FC5262BD3191BD11617C71E1E7911136D4F51E8E7E8EBEBEBECECEDEDEEF0ECECEE
E8E9EAE7E9E8E8E9E9ECE4E4DEACADA32B2EBC1316BD0B0EB8070CB4050BB3050BB1040B
AD030BA70109A201069D01059A01059800049702049601039201028F0202890001870101
8C01018D01008D01018D01038F00049101059201069001068F02078C01058A0004880103
8901038C0002960105A50409B1080EB5070FB1020CB2060EAC0209AC020AA70108A00106
9C010895020A91151D710C1473040B89030C890108810004790103730600655B0700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0084623CD0CCC8C5D0D5ACBBC2819299A8B8BC7681896A676C31151B816770D3CED9
D6DEE7D3DCE52E3038210C1429050C320604512000CA992BC98E26741500970A07AB060C
B1030CAE071193050C710001890307B2090FC3090DC5090FB9090E970103950102C10E13
D10E0FD40C0ED70D0DD90F0FD40D0ADA100ED9100CD91211D00C0DCD0A0EC9080CCD0C0D
CD0E0EC91010B41416780B08A86960F1D0C9F7E7E3F2E9E7F3EDEBF1EBEAF4ECEBF5ECEA
F6E6E2F7DBD5E6C5BE8D7671766D69DCD7D6E5E3E5E7E6E8E6E5E7EAE7E9EBE7E8F6E4E6
D49295B72A2FCE181AD41719D11E20991A1D4A1C1FDBD8D9EBEBEDEDEDEFECECEEEAEBED
E6E6E8E8E8EAE7E8E9EDE8EAEFCFCFA7474AB0161CB6090EB3040CB60711B3060EAD020A
AD040BAA0209A70208A203079B00049800029600029100028E00018D0101890000880101
8800008B01018B01018A01018E00029101059100059201078F02068C0104880104880001
8C0001950103A00105AB040AB40810B4060CB5070EB3070DB0060CAD040BAA030AA30207
9F01079B010991040BA5262C8F0E178B010A8B010880000476000173060085220600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F6C46C6C2C0BBC6CDAABAC1ADBDC4798990808B90716E7133151A816970DAD6DF
D8DDE8CDD6DF2B2C35210C152B060C360803693810CE9D2DAC721F6B0C01900708AB080E
AF050CA908118904096D0003810206A7060DBA0A0DBC0B10A8060B8E00029D0506C60C10
CF0C0DD40E0FD20C0BD0080AD40C0CD50C0BDA130FCF0B0BCB080BCB090CCC0B0CCE0E0D
CA0C0BC213148A0D0E612A28E4CFC8F2EBE7EFECECECECEDECECEDECECEDEAEAECECEBEF
EBEAECEDE9EAEBE6E4E6E2DDD8D4D0D3CFCFE6E5E8E7E7E9E7E9E8E8E8EAE8E7E8F3E8E8
F6C8CAB53D41C91B1ED11318D2191DB620274F070CADA3A4EAEDEDEDEEF0ECEEEEEAECEC
E5E5E8E9E9EBE9E9EBEAE6E8F2DCDEAC6266A41C1EB40D11B60910B4060EB2060FAB020A
AC030BAB0209AB0309A702069F00049900039701049302068E00018D01018B0202880001
8901028A01018B01018E01029001049101069301099101088D00048B00048C01048E0002
980104A20208A80208AC0209B40510B5050FB6060FB2040DAF030BAC0309A90308A70209
A30107A001089A030992030B8D020B8A00088902077E010373000073050089230900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0093714CC7C4C2BEC9D0BAC9D19AA7B07D8B9195A1A475737432151A866C73DBD8E0
D6DEE7C5CBD32220292007102C060C33050481511BD7A5349A5B1B760C02940407AC070E
AF060EA6060F820207650001760105920309A10409A1040A9002078300029E0607C90E12
D00C0ED40C0ED20C0BD20C0DD50D0DD50D0ED10C0FC60408C6060CCA090DCD0D0DCE0C0C
CD0E0FBB13156907077F5F5DEAE0DDF1EFEEEEEDEDEEEEF0EAEBEDEDEDEFECEAEDECE5EA
DECFD7E2D2DCEBE3E9EAE8E8EBEBEAE2E1E2E3E3E5E6E6E8E7E9E8E7E8EAE7E8E8ECE7E8
FBDEE0C4656AC12023D21A1FD3171AC51E226E0E147A6368E9ECEDECF0F1E6E9E9E7E8E9
E8E8EAE8E8EAE2E2E4E5E2E5EBDEE0CA92949A1F22B21014B1070CB0040BB0050EAB040E
AA030CAC030AAE0209AD040AA501079C01069701069400049100029001008E01018C0103
8A01028A01018B01018D01018C01038E01059100099100088F0005900104930005990104
A40106AA0108A90108AA0109B1020CB5050FB60711B3050EB2050EAE040CAB040BA40106
A202079F020899020993010A8E00088901078803077F010472010070040088210900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C6B46C2C0BDBECBD2ABBABF7D8990A9B7B97784886E6A6E34161C8E747BD9D6E1
D1DAE3B0B7C119131E21060F2E040A3506069F6F20D39E2E853A0E8A10079E0609AC040C
B0060EA9051088050A6400026C02067F02088701098602087F01057E0001A3070AC50C0F
D10C0DD30B0DD20C0BD30B0DD50E10D10B0DC70709C3040AC7070ECB080ECF0D0ECC0A0B
CE0F10BA171A5C0506917B78ECE7E5EDECEDECEDEDECEBEFEBECEEEAE7ECEDE3E7DEBBC1
9D56638C3D4DA26879D4B9C4E6E1E6E9E9ECE6E5E8E5E5E7E7EAE9E5E6E8E3E4E6E9E7E9
F4E3E5D79096B9272DD42124D7191ACC1B1D93191E50272CE2E1E4E9EBEDE6E7E9E6E7E9
E8E9EBE9EAECE6E4E7E4E2E5EAE2E5E6BDC19F363BAE1318B2090FB2060EB0040DAE040D
AD040DAD030CAF020BAF020BAB040B9F01089901069500029401029301029102018E0202
8B01018901018902018C03028B02028F01049301079301079200039601059C0105A10005
A70206AA0208A60208A40207AE060CB3060FB90A13B3060CB1050BAF050BA90209A40106
A000079A02098B01058D040A8D03098700038701057F01057401016F030080190400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B6A46B0AEACC4CED5AAB7BDB1BDC27E8D8F7D878D716C6F33151B947A82D4D3DE
CCD5DFA4AAB51C141F280A162F040A3A0A03B6852AD29C30711A00910C09A4060BAF050C
B3040DAC030E8F040D6400036201066F01087A040C78030A760105880105AA0409C60A0D
CE0B0AD20C0BD10B0AD50C0ED30D0ECC0A0BC7090CC5060DC7080FCB090FCB080CCE0B10
CD0E0EC0191C610708866F6EEAE8E6ECECECEBECEEEAE9EEEAEAECEBE8EBEEDEDFBB7A81
AC2A35B8202BAB2634822735956F7BDED7DEE8E7EAE6E6E8E7E8EAE6E7E9E3E7E8E7E8E8
EDE3E3F0BDC1BA373FD2242AD71A1DD0181BB01E244A080FBBB3B6E6EAECDEE0E3E8E9EB
EBEBEDE9E9EBECECEFE5E5E8EAE7E8E4C9CBA24F52A21519AF0A10B30810B0020CB1040D
AE040CAB0109AE020AB0020BAD030CA501089E02069A01039501029100019001018E0101
8C01028B01008801008700008A01018E00039200059500069B01089F0207A40207A40106
A501079E0206900102950306A6050BB3070EB6080EB5080EB1050AAF0509AC040AA40006
A001079902098600048001048803088700058701068100057701026D01007D190500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00856143BBB8B8C3CCD6C0CED69BAAB178888D959FA57A757A33181D947C84D6D4E0
D0D8E18F94A0150D192306122C0307411200C79735C48B2979180298090AA80309B2060C
B4050CB0040C9E08116D00055C01056B0C138A2E33882D337002089B070FBB0A10CA0B0C
D10C0BD20A0CD20A0DD70E11D30E11C6060AC10609C3060CC7080DCA090ECD0A0ED00B0F
D00E0FC2151A72090C705355E7E2E3EDEBECE9EAECE8E8EAE5E5E7E8E5E7EEDEDEBD7A7E
B02529C5171BC7181EB62029711521725761D8D6DAE4E4E6E2E2E2E4E5E7E4E7E7E9E9EB
ECE7E6F8D5D8B95257C6282CCF191CD2171BBC1B20610A0F7D6C6FE1E4E6E1E5E6E7EAEB
E8E9EBE9EAECE6EAEBE3E5E7E7E7E8EADADAB5767992161AAC0B12AF0610AF040EB20710
AE030CAD020AB0040BAF020BAA010AA8030AA502099E01079701059200048F01018D0001
8D01038C01018900008901018C02028F01039500049D0106A4030BA60109A60107A50004
A200059600038301027C0001940308AF0810B60810B5070EB2050AB00509A90105A60208
A101079C01088F01088200048401068801078600068201057901026F01007A150400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00896547BBB9BAC1CCD5B8C5CE77868EA7B6BB7D878F6D696E2F1318977F87D5D1DD
D2D7E07C848D110C1520050F2804054E2105D19F3BAB6A1F750C019D0A0AAC060BB4080C
B5060BB3040BAE0A12830307620204C97E85FEC3CAE3A1A8760F12AE1316C00A0CCB0A0C
CF0C0DD30D10D20D0FD00A10C7060BBF0308C00609C2050BC80A0FCE0C10CE090FD10A0F
D31013C815198A0E13532F32E1D9DDEBE7ECE7E7E9E5E5E7E5E5E7E6E3E6EBE0E0D09C9C
A62A2CC01619C81217C2151B9E1B243D080FB0A8AAE1E1E0E5E5E5E7E7E9E6E8E7E7E7E9
EEEBEBF7E2E2C97E80AC272AC92023CE171BC3191D8013194C2C30DADADCE1E4E5E3E8E8
E5E9EAE6EAEBE6EAEAE6E8E8E2E3E3E6DCDDCFA2A48D2327A80F16AE070FAB030BAC020C
AB020BAD040CAD030CAC030CA6010AA50109A502089D0206970109940108920104910104
9101049102049001038C00018E01019200019D0104A50107A60108A70109A60007A40104
A201059E020698050B840104880204A90A11B80C15B60610B3040CB0030BAE040AA80208
A100089C01099301078700058601068801068701048402057B010370010079130300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00967053AFACADC9D1DBB3BFC8B0BDC587969B7F8A906D676B3313199F868CD5D2DB
D2D8E267717A0F0B131C050B230203623715D7A43E9149137F0A039C0509A70207AD0305
B4060AB20108B5080F9F050B81080D8C343C934D557B2E32AE3C3BB91817C40C0CCD0B0E
C9080CC20206CD0D0EC9080EC2040AC1070AC3070BC5080EC5060ACB0A0CCD0B0CCF090D
CE0C0EC710139E13173F0B0DC6BDC0E7E4E7E5E3E6E7E5E8E5E5E7E3E3E5ECE6E6DFBCB9
9E3D3AB81C1FC41217C7151AB41B2057070C706061DCDADBE6E4E5E4E4E6E4E5E5E8E7EA
E7E6E6F0E3E6E2AFB1A03539B52024C31216C012189F1C233F080FBAB4B7E2E4E5E7E9EA
E4E5E7EAEBEDE8E9EBE4E4E6E6E6E7E4DCDEDBBABD983E42A41419AC080FAB060DAC030C
AB020BAA020BAC030DA9020BA60109A40108A10107990105940006980108980105950104
9201039101029001039101029300019C0104A50106A90108A90109A60007A50007A40105
A10103A100049F02069303078A0004A0060DB20910B70911B3040CB3050CB0040CA70109
A0010B9C010A9701079001068901058600018601038301047B01037201007A120200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956F4BBBB5B2C7CFD7C3CED8A8B6BE7C8B9097A2A8767376301319AD979DDAD8DF
D4DCE5525B65130C1420060D2504027C4F1DDAA43F8331078B0C04A2070AAC050AB0050A
B5070CB8060CB6050CA90107A41015BB4349BB5458D16464BF3333BD0E11C70B0DCA0A0C
BF0106BF0207C90C11C4060BC10609C0060BC40A0DC5070DC7090BC90809CE0D0CCF0C0D
CE0C0ECA0E13B41A1E4B020597888AE3DDDFE8E3E7E5E3E6E3E3E6E5E5E7E6E3E3E6D0CD
B26864AA2020C01616CB171ABE161B7E1017422325C8C5C5E5E5E3E7E7E7E6E5E7E9E7EA
E7E5E8F0E8ECF7D6D7B66669A62427C01419C11116AF1A2053060B88787BDBDBDDE5E5E7
E5E5E7EBEBEDE8E8EBE4E4E8E3E3E5E1DDDFE0CCCDA55F6198151AAA0911AD070FAE060E
AD040CAB0109AC020BAA020AA70209A50207A40208A3040A9F02089F010A9F01089A0106
9500039000018F00029601029D0003A50207AA0107AA0107A90108A60007A50107A30106
A00004A00105A001069E02099A0108A5030AB1060CB6080EB4060EB5050FAF030CA60009
A2010A9D01099800059401058B01038701038402048301047F02057400017B110300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805A32C4BDBAC3C9D3B9C4CE7F8D94A7B6BA8290946464672F171AB6A2A9DADAE1
D4DEE5454D57150B131E0509250503986C24CB9234771E018A0602A20409AE060DB3050E
B8070FB9050EB6030CB00108AC050BB0151CB52529AC1519B60C10C3080DCA0A0DC8080B
BE0005C00309C3090EBE0409BE0508C1070AC3080BC6060BC80A0CCB0A0CCC0C0ACE0D0C
D00F10CB0D12BC161D67070C62494CD9D2D4E7E4E5E5E3E6E4E4E5E4E4E6E4E3E2EBDEDB
CC99939F2B28B81615C81516C5171A9D191E3906089E9999E1E1DFE6E6E6E8E8E8E7E5E8
E6E4E5EEE8E9F3DEDDE2A6A9A53638BE1A1DC21016B8181E74111851363AD2D0D3E2DFE2
E4E2E6E6E6E9E6E6E9E3E3E8E1E1E5E1DEE1E5D8D8C48F908F1C1FA60B12AD0710AE040D
AE030BAE030BAC020BA9020AA70109A70109A9040BAA040BA8030AA6020BA3000B9F0108
9A0104980103990002A00104A40004A80107AB0209AC0109A90108A70107A50107A30106
A00004A00104A20107A6020AA7030BA90209AD030AB5080EB5070DB4050EAD010BA7020A
A001089C02099701079101068A01048400048100048201057F02067600027B0E02439002
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008E643DB4ABAACED6DFBFC9D2B0BCC38A9A9D828E916763662F181CB8A9B1D8D9E1
D2DBE22F3841120B131B05092B0C02AF8330B47A27690B01900806A6050BB0060DB2030A
B6050DB7030BB9050DB40208B6040ABF0A10BE0A0FBE080CC3080BC8080BCA080ACC0A0D
C40609C5080EBD030ABD0409BE050AC0040AC4070BC50609C80A0CCC0B0DCB0E0BCD0E0D
CC0D0EC80C11BF1216830E13401D1EC9C2C3E8E4E5E6E4E5E6E6E6E3E3E5E4E4E3ECE6E4
DDBDBA9A3F3DAD1618C81419C7141AB1181E57080C655658D8D7D5E4E6E5E5E5E3E4E2E2
E8E6E7EAE7E8ECDFE0F1C9CBB05557B91F21BE0F14B812198D161C380C10B4AFB0E2DFE0
E1E0E2E3E3E5E1E1E3DEDFE0E0DEE2DFDCDFE5DDDED4AFAF922F32A61016AC060EAE030C
B1030DAF040CAC020BAA030BA70209A6020AA7030CA6020AA60209A5010AA5000BA60109
A50107A50106A60206A50004A70106A70007A80108AA0108A80106A60106A50106A20105
9F0003A00103A40007A70108A60107A70106AC0209B50811B70A11B2040DAC010CA5010B
9C00099800079200068D01058700038201047D00047F01057C0104750101790B01418D01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00855A31B8B0AFCBD3DCCAD4DDB1BDC67081868D999E79767B321A23C0B4BCCDD2DB
C7D2DB1C242E110A101F0708371500C3943D99591D6B08018F0709A8060DB1070DB5060D
B6040AB90509B90509B80308BA0308C4070DC80B0DC50809C40907C7070ACA090BCA090D
C5090CBC0308B80206BA0409BD050ABF060BC3090CC00409C10408CA0A0ECA0C0CCA0D0D
C90C0DC2070CBF0B10A1141A3C0307AEA4A5E2DEDFE5E5E5E5E5E5E4E5E7E5E6E6E7E4E5
E5D3D1AF6967A92022C5161CC71318BE181E7C11183C1C21BFBCBDE2E3E1E2E2E0E3E2E0
E7E7E7E8E7E8EDE5E7F4D8DBC57E80AA2224C21617BE1114A51A1F4403078B8183DCDBDB
E2E2E2E2E2E3E1E1E3DFDEE0E0DFE1DEDEE0E1DDDEDBC1C29D4C50A0141DAE0913B0050E
B2060EAC0109AC030BAA020BA70209A7030BA6020BA60109A7010BA7010DA9000BAF010A
B3030BB10409AD0207A90006A90105A90108AA0107AA0107A90107A60106A50105A20104
A00004A00105A30108A50109A50105A60004AE040BB3070FB3050EB0030DAC020DA4000B
9D01099801089200068D01068801078100057C00037C00057A0105720002750A02428F03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF007A4B23BEB3B1C3C9D3C7D2DA7E8D959DACB2838E94625E61301922C7BAC5C8CED7
B7C2C8151B22160A0E2206054F280BD19F46803A0D750A038C04079C030AA8050AB1070E
BA080DBC080BBE080ABD0409BC0308C6080CC90B0DC30809C20708C8080CC6070AC1040B
BA0308B50208B60409B50309B9050BBC050BBE060BBD050BBF050BC1070CC5090CC3080B
C40A0CC0070CC10810B2141B570709796769D7D7D4E5E5E5E4E4E4E3E3E5E5E4E6E6E2E5
ECDFE0CB9998A32E2CC21B1CC81517C315199B192039030A8F878ADCDADCDFDDDEE0DFDF
E3E4E3E4E5E7E7E5E4F4E4E5D8A7A8A12B2EBE1819C01113B3181D610A0F584548D1D2D3
E0E2E1E1E2E2DFDFE1DFDFE1E0E0E1DEDEDDE1DFE0DECDCFA5686D92171EAA0A12B20810
B2060EAD030BAD040CAE050CAA040BA6020BA6020CAB050FA7010CAC010DB2020DB7020B
B9040AB8040BB3020BAD0109AA0108AA0108AA0107AC0309A90108A60006A40106A20006
9F01059E0004A10106A50108A50106A50106AA0108B2050EB80A13B0030DAA020CA4020A
9B01069700069300068D01068801088001067D01067C01067C0306740103730801438F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956A42AFA49FCDD3DBBFCCD3AAB9BF92A0A57B84885A5555341C23CEC3CCCED4DD
A5B2BA0F131D18090F2205046E471ECD9A437025047A08058E03089300059C0105A60107
B5070EBA060DC0090DBE050AC1070AC90C0ECA0C0DC90B0EC40709C7070CC5070CBC030A
B6020BB1020BB0030AAE010AB2060DB9060FB7020BB8030BBB050DBE060CBF070AC2090D
BF070AC40A0DC50D12BC141B790C1346292AC5C3C1E3E1E2E2E0E1E5E3E6E2E2E6E5E3E7
EAE3E3E1C1BFAA4B49C02322CA1618C9161AB0181E5A09125F4E54D5D2D5E3DEE0DFDEDF
E0E1E1E0E4E5E1E3E3EAE3E2E9CACAA54549B41A1FC01217BB161D7F11173A181BC0BEC1
E0E1E1DFE1E1DDDEE0DEDEE0DFDFE0DDDDDEE0DFE0E3D9DAC4979B8C2126A90E14B20810
B0060EAC020CAD050DAC040BA9030AA3020BA3040EA6010CAC020BB4060EBA040EBB030C
BD050DBC040DB8030DB3010CAD0109AB0209AA0107AA0107A80007A70108A60209A4020A
A10107A00106A10207A00107A00109A40108A80108B1060FB20810AB030AA60108A00006
9C00069800069301068D01058601078201077D0107780104780102750202740700418D02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF009B7048A79B95D1D7DFC3D2D9B6C7CE75858C8A92976D6869372228D2C9D0CDD4DE
8F9AA611101C18080C2106028B6529B48538530901800B0D93040B9C030CA3040BA90108
B4040CBA050EBF080EBD0409C1070AC80B0DC90B0BC9080BC6080AC50608C3080CBA050A
B5020BAE010AA702099F0108A00308AE060FB5040FB9040FB9040DBD050DBF080DBD060B
BF080DC0080DC20A0EBD0F16921016330506A5A09EDDDDDDE2E2E1E1E0E2E2E2E3E5E3E5
E6E4E2E8D4D3C07A7AB22627C7191BC51014BA171C7A0F1838191FBCB8BCE1DFE2E1E0E2
E1E1E3E0E1E4DFE0E1E5DFDFECD8D9B56D71A51D23BC1119BF141B9C181F3B0307A59C9F
DEDDDFDFDFE1DFDFE1DCDDDFDEDEDFDFDEDFDDDBDDE3DCDDD1B0B294373CA71318B2090F
B1070CAE050BAF050EAC020BA8040B970004950106A5040CB2070FB8070EBA040CBB030C
B90209B90209B9030BB4020CB1030BAB0006A70105A70105A80107A60108A50107A30007
A10106A00105A001079801069201089A0109AB050DB1060FAD040CA70107A60108A00107
9B00069901079502078B01058301067D0106780105740002740101740101750700418E03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805328C9BBB4C6CCD4CAD7DF80929A95A5AC818A91534C513B242BD4CBD2D3D9E3
767E8A130B1919050C1F0501A37B37905E245707057D0509900007A3040BAB0309B3040E
B7050DBA050CBD060BBC0309C0080AC7090DC9080BCB090CC8080AC6080DBB0509B20207
B0030AAB020A9D00048F00028B00019C0107B0060CB5040BB8030BBC050DBC070DBB060B
BD080DC20D12C00B10BE0C14A7141A4704067F7576D4D7D6E1E3E2E0E2E1E1E0E1E2E0E1
E2E1DFECDFE0D0A1A2A23032BC1B1CC51719BD181A951A1E3B070C978F91DCDBDDDEDDE1
DFDFE1DFE0E2DEDFE1E2DFE1EFE1E3C49193972429B11119BB0F17AE192254050A6E5D60
D6D6D9E0DFE1DFDFE0DDDDDEDDDDDEE0DFE0DCDCDDE0DDDDD8C3C2A3595A9C1419B00B10
B2080DAF050BB0050EB0040EAE050DA3040A9B0206A8050AB60610BA050DBA030BB9030B
B90308B90509B70208B5030AB20409A80004A20004A00004A60208A40006A20006A20107
9E01059E00049F01059802068900038C0003A9090FAE050DAC030BA80208A501069E0006
9900069401059101058901047F0004770104760205740103730101740202760A02418F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00825021B5A59DD0D6DEC2CED7ABBAC392A1A97F878E51464D462F37DAD2D9D2D8E3
5F6571180C1820080D2A0C00B28841743C1A63080587050D9C050DA8030BAF030BB4040E
B6050DB8050AB90409BA0308BD0508C7090DCB0A0DCA070BC6080ABE0409B20207A70004
AB020AAA010BA40208A003099E0408A20206B3080BB40408B40309B6040CBA070FB8060C
BA070CBD080FBE0912BB0913B01119660A0D493234CACBCBE2E4E3DEE1E2E1E2E2E3E2E2
E4E4E2E6E1E2D8BEBEA55756AA2D28B62D25B12F289B342E5E2B2780706ED5CFCDE3E0E1
E2E2E2E0E1E0E0E2E1E1E0E3EAE2E4D5B1B2973538AC141DB90D16B5131E710D15402729
C5C6C9DFDFE1DFDEE0DFDFE0DFDFE0DEDEDEDEDFDFDEDEDEE0D3D4BA838591191DAF0D13
B50910B3070DB1050AB00207B7060CB90910B1060BB00308BA070CBC050CBD050DBB0409
BB0409B90408B50207B20306AD0205A501049F01049C0003A10207A10005A10107A20207
A100059F0004A001059E02069A050A920107A5070FAA040BB00710AA030CA602099E0107
9600049301058F01058700047F01047500027201027100036F00036F02027B150C46960C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00814B1AA08D83D2D5DDC3CED9BCCAD676868E838C936C6369533F49DCD6DED0DAE5
424A56170B13230706472108BF90465C1F0967050591060FA7060FAF050DB3040DB7060C
B60509BA0609BB070ABC060BC0080AC8090DCC0A10CC0A0FC3080CB70309AE020AA70007
AB0209AD020BAD030BB0040CB3080DAF0407B7080AB80509B6060CB3040DB5060EB8070E
B8070DBB080DBE0B13BB0914B40E158B141832090CB4AFB2DFE1E1E0E1E3E1E3E2E1E1E1
E1E2E1DFDEDEDFD4D3C49F9BC58B80DA988CD99E91D2A296C7ABA2C8B9B5D1C9C5E5E0DF
E3E2E0DFDFDFE1E2E4E0E0E2E5E1E3E4C8C9994347AA1820BA0E16BA131A8A151A310A0B
B4B4B4DCDDDDDFDDE0E1DFE2E0DFE1DDDDE0DDDDDFDEDEE0E5DCDFCDA3A7922930AF1118
B70911B9080EB9080BBA060ABD070CC0090EBE080EBB050CBD060BBC040ABD040CBD040A
BA0208B9030AB60409B30409B1050BA90208A201059B0001A10206A10006A30107A60108
A50208A20005A10106A00006A2040B9F010AA8050EAE050CB0050EAC040EA6020C9E0007
9800059201068D02078601057E00047701047402056F01046A010369010273140D44980F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00834F1ECBB8ADC4C9D0CCD8E28898A18F9EA5899297544B525D4A53DAD6DECBD7E0
2E3741180C132107056A4421BC8B4454110070050790020AA8060DB0030CB3040AB8070C
BA070ABD0709BD0809BE070BC2070AC8070FCA0910C8090EBF070BB40209AE010AAB0209
A90007AD020AAF040BAD0208B20509B20407B6070AB60609B3040AB3030DB1030CB4030B
B8070DB7060CBA0B11B80812B50912A5171E4B020778636ACFCDCFE2E1E2E0E1E1E1E1E2
DFE1E0E0DFE0E3E0DFE7DEDBE9DDD6EEDED9EADFD8E9DED9E7DFDBE6DFDEE3DFDDE2E0DF
E0E0DEDEE0DFDDDFDEDEDEE0E2DDE0E5C7CBA0484FAD171FBF0F16BB0E149B1419380002
888284D7D8D9DEDCDFE1DFE4E0DFE4E0DFE4DEDDE2DDDDE0E1DCDFD7B7BC9E444CAA131C
B7080FBF090EC50D10C2090EC3090FC0090EBB050DB8050DB9050EB7040CB9030DBB040D
BC040DB7020BB5030BB2030BB1040DAB0109A501079D0003A10106A40007A50107A70106
A90108A70108A50106A40007A30109A6010AAB040CAD0309B0050CAB020CA6010C9F0109
9901079201088801077F02067A01057501037301046D01046800036401026B110C4D520C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B5323B8A49CC9CFD6C3D1D9A4B3BA9AA9B07E868B41353D6B5962D9D7E1C0CAD5
1A222D180C132007068E68309D692F5E0A017C040798060FA9080FB1040DB5050CBA060C
BC060ABF070AC0090BC1080CC1060AC6080FC3060DC50A10BA0409AF0006AC0109AD020A
AE030BAF020AAC0208AB0106B10408B10207B4050AB2050AB0020BB3030EB3030DB8060E
B7060CB5040CB80910B70711B60910B01017820E174B161FAE9AA3E0D9DEE2E0E3E1E0E3
E2E0E1E4DFE2E4E0E2E4E1E1E6E2E1E4E1E2E2DFE1E4DDE0E6DEE0E5DCDFE2DBDEE2DADE
E0D9DAE0D7DBDDD4D8E0D3DADFC9D0D89FA9982630B1111BBE0D13BC0911AA101955050A
5A4B4DCFD0D2E1E1E3E1E1E4E3E2E7DFDFE2DEDDE0DEDDDFE1DEE0E2CCD1B86F77A2161F
BB0A10CA1114C90D10C6090FC2080FBF090FAE0309A40207AA040CB3060FB2020CB5030D
B6030EB4020CB5030DB2030DAD020AA90108A502079F0104A30207A50107A60007A90207
AC0309B1050BAD0209A70007A50107A70208AD050CAD040BAD040BA8010AA6010AA00109
9901069001088100057601057600087601077101066A00046701026300016A0F0D5B0F0D
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00905323AD958ECFD4DBBCCCD3C0D2D974858D6A7379493F46786972DAD8E3B3BBC7
13182214070E1F0602AB8243743C1971120888060A9A040CA50209B1060EB4040CB9050B
C0090EBF060CC0080BC1090BC0090BBE060BBA0209BC080FB3040BAD0109AD020AAE030C
AC0109AD0208AB0205AD0208AE0107B00209B2050BB2050BB2050CB2020CB3040CB6050D
B6050CB7070FB5060DB80A12B5080EB60C13AB131A7E0D186C232FB1838FDBC1C7DECAD1
DECACFD6BFC8E0C7D1D9BCC7CEAFB8CAA7B0C9A1ACC89CA8CF9FABCA96A1C68F99C38793
BC808BC0808BBD7987B97080B76271A63540AB1721B60C13B9080FBD0A0FB40F15710B10
3A2122C6C8CAE3E4E6E3E2E5E0DFE4DFDFE3DFE1E4DFDFE1DFDEDFE4D8DACE9A9D9D2125
C11416CA0E12C6090EC6080FC3070EBE080FAF050C9D0106A00006AB020AB0040CAF010A
AD0009AE010AAC0109AB0109A90109A70107A40207A00005A40107A60107A50107A60005
AC0208B4060DB2060BA70104A60105A80208AA020AAB010AAA030BA80209A50108A10107
9901049303088302067600067801097300066E01066B01036501015F00016309095F100F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00874B1AB2978EC4C6CDCBD7E08FA1A8768A8E7884883B373C837680DBDAE599A1AD
0E101B1304092D1001B78B4A5B220A60060285030A9E050DA60309B0050BB4040CB7030C
BB060CBE070CC1080CC1080BBF0709BC060AB60308B4050AAB0108A90007AC0209AC010A
AB0208AB0307AA0407AA0208B0050BAC0109AF040AB2050BB4050BB3030DB3030DB6050E
B6070EB6070EB3050AB70A0EB70A0EBA0E12B70E14B0111AA21621931F2DB65864BD6775
B45F6CAB5160AB4E5CA84556A03A489E3140A330429F2A3AA02836A22735A62534A7212F
A81F2DA71D2AA71D2AA91B2BAF1A27B3141CB80F15BD0F12C00D11C51114BF12168F1217
310508AFB0B3E5E8EBE2E3E5DFDFE2E1E2E6DFE0E4DEDFE3DBDDDDE4DFDFD4AEB09F3537
BD181BC50E12C20A0DC2080CC0080DBA040BB3030CAB030BA70209A80108A90108AA0108
AA0108A80007A60006A60007A40006A50107A30107A10107A50109A60109A60108A70107
AB0208B5070DB4060CAD0106AB0207AB0209AC030BAD050CA90309A60108A70208A20106
9A01069201078901087F00077F02087802067001046D010467010260010261080664130F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00894A178E6C62CFCDD4CAD6DE9CAEB493A6A6828B8A292324978B92DBDCE67E8691
100D19170407492913B78A4B4D12015D010287060E9E030EAA050AB0040AB4040AB6050D
BB060DBD060BC1080DC1080BBC0406BC060AB8070AB20409AB0109A70107A70108A80108
A90209A80208A70208A70309AA0308B0040AAE010AB3040EB3030DB2040DB2040DB4040F
B60610B80811B4070EB5090FB70A0EBC0D14BB0C13BC0D14BD131AB5111BAE131EAC1623
AC1723B11926B21722B51823B3141EB2101BBC1823B91722B7131DBA131EBC121DBC121E
BB111BBA121BB61218B81019B70E16BB0F14C01315C11213C71417C91115C81518A6171B
4102058C878BD8DCE0E5E6EADFE0E4E2E3E7E3E4E8E2E3E5DCDDDFE3E0E1E5CDCDB15E60
AE191DBD0D0FC00C0EBD070ABF0A0EB7030AB20108AE010AAB0109A90006A70004A80005
A80007A70007A60107A50107A40107A10006A20107A30107A60209A70108A60108A70108
AA0209B1030CB4060DAF030AB0050CAE030AAE030BAC030AA80208A80309A60207A10106
9A01059200078B01088601078001067900047201036B00026800036201026103025F0A06
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4816886256D8D1D7BEC9D0C0D1D87E8E92767B7D2C2024A79AA1DADCE5626975
120B141B04046845259A69364D060174050C8F030DA0020DA80209B1050DB3040BB7060E
BC070EBF070DC0090CC0080ABB0405C00B0DB40407AE0107AC030AA90108A60104A50006
A70208A60208A001069F0004A60208AF0309B1020CB5040DB3030DB2040DB0020BB4030E
B4040EB80611B70711B4050DB60A10B5090FB70A13BD0D16BD0F15B80C13B80F15B20C14
B71217B61116B81317BB1418BA1316BB1218BD1318BB1319BA1318B91117BD1519BC1317
BC1517BB171BB61719B8181AB61415B81515BA1615BC1415C11517CA191BC61717B11D1C
5E0C0E5F4E51CED0D3E0E2E4E4E6E8E5E8EAE4E5E8E3E3E6E0E0E3E1DEE1E7D9DBC48589
A42123BB1010C10E0FBC090BBB080EB4040BB1030CAC0109AC020AA90107A60103A80104
A80007A70007A40004A40105A40207A00006A00005A30106A70208A60107A40007A50008
AB030AB1050EB1040BB0040BAD020AB0030CB1040DAB0108A80007A80108A70209A10108
9B01079400058E01068701067F00037701037001026B02026601026202016001015C0502
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F4A18A27A70C6BFC6CCD6DE96A8AF7E8D9384848B2C1D25BAADB6D8DBE5444A56
180C15200404916B3B784322620C0485080E9A040DA6030CA90109AE0209B3040BB8060D
B9050CBD050EBF060BBD050ABC070BB60409AC0106A80107A90209AA0108A80206A90209
A80309A70208A40107A30108A70209AF030BB4040BB4040AB20309B3040DB2040DB4040E
B60610B70510B80711B5070FB1080DB0090DB30D10B71212B71112B61213B61514B41513
B11712B01714AE1914B5211CAF1D19AE201CAD211DAE2320AB261FA6251FA82A21A92B25
A82E28A32D27A23029A33029A4312AA6312DAB3631AC3730AE342EB53531B83733AC3B36
732D294B3633C3C2BFDFE1E0E1E4E3E5E6E6DFE0E2DFDFE3E2E0E5E0DEE3E2DADECFA5A8
942829B31615B80E0DB90E0EB2070AB0040BAE040CA90108AA0209A80107A50004A80106
A80007A60007A50106A40105A20106A20107A40007A50108A50107A30006A30009A6010A
AA0209B0050BB4070DB2040CAF0209B1030CAE030BAA0108AA0209AA010AA9030BA4010A
9D01099401078A01078402067F01047C01037401036A01016100005F01015E02016C1813
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00934E188E655CCCC7CFCDD9E28D9EA58B989F82818A2E2028C2B8C2D2D5DF2C303C
190B12270902A87E475C230D5F070184060B9D060EA7040DAA040BAE050EB40810BA0811
BD0810BC050DBF070DB80209B6050CAF020AA70007A30005A60006AB0209A80106A90209
A90209AC0107AD0108AE020AAC0209AC020AAD050BAE0407B2060AB3060CB3060CB5050F
B3040DB70810B4080EB10C10AC110FA81610A51A12A41D13A22116A3261AA62E23A9372B
A63E30A44538A74F42B9655BB7675CBF736AC87F76CC867CCE8E84D4998FD79E92DAA59A
DFAEA2D2A69BD9AEA2D9ACA3DFB3ABE4B8B2E8BCB5E7BBB4E9BAB3E9B7B2F1BEB9ECBFB9
DABDB6CABFB8D9D7D3DDDCDCE0E1E1E1E2E2E1E2E3E0E0E3E0E0E3E0E0E2E3E0E2D9C1C1
975451992B27A1211BA11A15A117139F100FA00A0CA20409A30107A60107A70107A80109
A80108A60007A50106A40008A5010AA5000AA50009A40008A40106A40107A6020AA50108
A80308AF0609B30509B3040AB2040AAE020AAA020AA90109AB010BAC030EA8010EA4010C
9E010A9300088001057701027C01057C01047600026D01026300015E01015B02027E2E29
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00944D17895C50D1C9D2C1CED6BCCBD36C7A8168666E30202ACDC5CFC3C9D2191F27
17090A381707B185514B10005B03027E030899040DA3060EA1060B9C0207A20408AE070D
B7090FBC070DBD0810B2020BAD0109AC010AA80209A50106A70108AA0009A80108A9020A
A90006AD0107AF0207B1020BAC030AA601089B0103A00105AF070DB0030CB3060CB60610
B2040DB40A10A10A0E88100FA23F35AE5648B56858C47F71CC9080D59F90DDAB9DE5B7AC
EAC4B8E8CABDE9D1C6EDD6CEECD8D1EBD9D3ECD9D6ECDBD7ECDCD8EBDEDAEBE0DAE7DFD9
E3DFD8E4DEDAE5DFDBE4DEDBE5E0DDE4DFDEE5DFDFE8E1E1E6E0DFE4DFDEE6E1E0E7E2DF
E1E0DCEAEAE6E6E6E6DEDEE0E5E6E8E3E4E5E1E2E3DFDEE2E0DFE3E0E0E2E3E2E4DAD3D3
D3BCB6C99F97D09891C0817AAE6961A1544C9B3E3A9018179A0509A50108A50007A60007
A80108A70107A40005A50108A50009A50009A6010BA40008A70308A60107A50109A40109
A60308AC0509B20409B5060CB3050CB00309AF040BAD020BAC020BAB020DA8010DA4020B
9D010994010A8102057100017701057A01067601037001036701026002015A03027D302B
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00954D1883534ABDB2BCCDD7E0A1B0B86F7E836B6C71332730D4CED7AFB7C110161D
18080654301C98683B4806006305067F020898040D99030B9100068E00078E0005990005
AA040BB8060CB9070FAB0109A50009A9020CA8030AA70107AC030AAB0209A9020AA80108
AB0207B1040AAF0207B1020CAD040BA8030B9C01069E0006AE070EB1040DB4070DB4040E
B3050EB10911920B0F450201AE8B82E4C8BEECD7CEEBDAD5E7DDD3E6DCD3E6DDD7E5DBD9
E4DCDAE3DDDBE1DDDBE3DFDEE3DFDFE4DFE0E2DDDEE2DBDDE5DFDFE5E3E2E0E1E0DEE1E1
E0E3E3E2E1E5E0E0E2E0E1E2E1E3E2E0E2E4E2E3E6E0E1E4E1E2E5E0E1E3E0E1E3E0E3E3
E1E5E5E3E6E6E5E6E9E2E2E5E4E4E6E2E3E3E1E1E3E2E0E4E0DFE4DFE0E4DFE0E3DCDBDC
E4E0E0E1DADAE4DADAE2D6D6E1D2D1DECBC8DAB8B5A55C5C890A0E9E0108A60109A70108
A70007A60107A60107A40107A30108A50108A50009A50109A40208A50108A3020AA0010A
A4020BA70108B1050EB2040DB0040CAF030AB0030CAF040DAD030CAE060FA8020BA5010A
9E01099201088601087A01037801037C02067600046E01036500025F0101570100792A24
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0099511C78473DB2A7B0CFD6E0A1AFB78C9CA06E70743E373ED7D3DC9099A20B0F16
1706047650317746274D0A015E020483040D9A050F98020B9101088F01098F00059B0108
AB030BB6060DB5060DA70008A10008A50107A60108AA0208AD0208AB0109A70107A80108
AC0308AF020AB0010BB2030CAC0208AD030AAC040BAB020AB3060FB4040EB3050EB4060C
B5060DB50811A11117430103786767D3CBCBE4DFDFE2DFE0E1E0DEDFDEDCE2DEDDDEDCDE
E0DEE0E1DFE1E0DFE1E2E0E3E1DEE2E4DDE3E1DBE0E0D8DFE3DADFE0DAE0DCD9DDDAD5DB
D9D4DADCD3DBDED7DCDCD6DBDFDADDDCD6DADAD2D8DCD3DADDD5DCDBD4DADCD5DBDED8DD
DDD9DEDBD7DCE0DAE1DFDBE0E0DDE0E2DEE2E4DEE5E6E0E7E3DFE3E2E1E5E1E0E5DCDCE0
DFE0E4DFDFE3DCDCE1DCDBE0DAD7DCD9D4D8DDD0D2AB7A7C7E10159C030AA60109A70209
A60108A50006A50106A40107A30108A2010AA3010AA40109A40008A400099F010B980009
9D020AA40109AD030CB0050EAC020AAD010AB2040EB0050FAF050FAB040CA70209A40107
9C01069000068801088201067D01047B01057501036C01026301015E01025801016E1E17
2F880200FF0000FF0000FF0000FF0000FF00
00FF00954A165B291EB3A6ADB3BBC4BAC7D08B989F4E4F54494349D8D8E06A737D0B0A14
1B0705936B454F1F0C4807015B000180020B98040D9701089200069400089C020AAB040E
B5070FB90710B3050BA80107A50107AB020BA70107AA0107AF0309AC0209A90108AA0108
A80108AB0109AB0106B0040AAA0108AE030BB0030AB4050CB3050BB3040BB2050BB40710
B4060CB7060FB2121967070D503436C9BFC2E8E2E4E6E0E4DFDADDD9D1D5D9CDD2D3C6CC
CDBFC4D0C0C5C4B0B7C3ABB5C7ABB2C4A2ABC19FA9C29AA7C89DAAC799A7C0929EBF8C9C
C18C9BC78E9CD599A8D699A7D697A4CE8C9AD593A0D5909FD995A5D592A2D695A6D092A1
D69BAAD09AA8D39EADD1A1AED5AAB5DDB4C0D8B3BFD4B2BCD1B2BBD6BDC6D2BDC6CEBFC7
D0C4CDD4CBD3D3CED5D8D3DADCD5DCDBD4DCDCD2D8B591947E1E239A060EA60109A8020A
A8010CA60008A40006A40107A40007A3020AA3000AA3010BA3010CA4010CA3030D980109
980009A1010AA60108AD050CAE040CB2050EB2060EAF060CAD050CA9030AA7030AA30108
9A00068F00058801078301067D00057A01077400056C01026201015D01015701016F2019
2E870100FF0000FF0000FF0000FF0000FF00
00FF00924A185C2B23AC9DA2ADB5BC929FA8808B914F4D525F575FD5D6DF3C455007050D
1F0B019B724A400F014B030169020686010A99040C9C01099B0109A1010AAB060EB00610
AF0810B20912AD060BAB040BA90209AC020BAC0209AC0109B0010BAC0109AC020AAC020A
AC0208AC0109AD0208AE040AAE0509AF020AB3040BB3040BB3040AB3040DB3050EB4060F
B5060DB80711B40A14900A13520B0FD9AFB5E6C4CAE0BBC4D1A5B0C68F9DC28490BE7A85
B56A77AA5A69A34F5B9E4351A03E4B9F39459B343F9F31419B293A9B25379C24359E2133
A12133A51F30AC2233B22233B72433B61F2EBC2432B82130B92233B71F32B82134B21F31
B22233AF2332AF2638AC2A3AAE323FB23B49B54152BD4B5EC25465C55D6FCA6C7EC47183
C3798AC88495C18897BA8B98BA909DBA97A2BEA2AAB48A8F8F343996070EA6020AA7020A
A6000AA60009A50107A30006A50108A40109A2010AA2000CA1000DA3010CA3010B9F0109
A0030BA00008A40007A9020AAF050DB2040DB3070EB1070AAD050BA60108A6020AA2020B
9B02099100068901078001057B00047800057401036D01036501025D00015701006C1D13
31890200FF0000FF0000FF0000FF0000FF00
00FF00944C1A4D1B11A09295A5ACB06A767B838B91605D636E666ECFD1D9252C35050205
351F137F59373B05005903077D040C90030B9C030CA1010DA5020CAC040FAE050EA4030F
940107970309A10409A70308A90209AA0108B0030CB1010AB20309B00208AE0106B0020B
B2040AB00108AE0108AD0107AD0107B1040AB1040AB3030DB2020DB2010DB4060FB4040E
B5060DB60711B60811AF0D1699111AB84752B64A55AC3A49A42838A62132A51B29A81928
A61322A5101FA50F1CAA111BA90E17AE121CAF141DB1131CB1111AB2111BB5121EB40D1A
B70E19C2111CC9121CD0141FD3151DD31319D6151AD4131AD3131DD2121CD3131CD0111B
D0111BD2141ECB111BC60F19C20F18C2101BC41121C41122C91724C11221BA1425B11324
AE1526AE1B2CA61C2F9E20309927369C35459F414FAD515DAB343F99030DA6020AA60108
A50108A40007A30006A30106A30107A30109A2010AA3010CA3010BA4010AA40009A30009
A20109A20108A00005A50107AC020BB2050FB3060EB1060DAD050CA70109A301099E0109
9A01089201078900058000047A01047801047401036D02036301015B01005601006E1E14
31890200FF0000FF0000FF0000FF0000FF00
00FF00964E1B4D1611A492988A8F968F999D7A82853532397B777DC1C4CB14181F0C0102
593D286A432B3D020164030886050B95010A9F030EA5020DA7010CAE040DA9050E95010A
85000584000498050DA5020BA50007A80107AF0309B2020AB50309B30308B20208B5020B
B4020AB70309B60208B3020AB00106B20408B00509B1040AB3030DB3010DB4040EB4030D
B5050DB60610B60610B50710B40A14B8111BB9131DBB111DBD0F1BBF0E18BF0F17BF0D19
BB0A16B80813BD0E16BA0D13B80B13B70A13B70C14B91217B71115B71014BA0E14BF0C15
C40D14CD1017D21118D20E15D50F14DA1315DA1113DB1318D40D14D60F15D70F13D50E13
D30E14D00B12CF0C14CC0B13C90B12C60812C80914C80A13CE0E15CA0A11C50911C40913
C10712C10B15BB0714B50715AF0915A80915A006159D09179D0511A3020CA70209A60008
A40006A20005A50108A40107A20105A00005A00007A4020AA30109A20109A30109A4000A
A4020BA10007A00105A20004A70007AE040DB2040FB2060FAA020AA9030BA5020A9C0106
9601059101068A00058001037900027501027200016B01026001015A0100570100701D15
31890200FF0000FF0000FF0000FF0000FF00
00FF00974E184F170F927C828F9097727B7F5D65672221268F8B92AFB2BA0C0B11170403
805B3D471A104904046B020786000798030C9E010CA4010DA7020CAB040EA3050B8C0006
7E000380000591020B9F010CA20108A80207AB0004B20207B50208B40109B50309B7030C
B7020AB70208B70207B60209B10107B2040CB1040AB3040BB4050CB6050FB5030CB8040F
B8050EB90711B7070EB8050EB90810BA0A12BA0911BB0712BD0913C00B14BF0B13BE0A13
C00D18BC0811C20D15C00C15BF0E16C00E16BA0B13B70C13B70D12B60B0EBF0E12C91115
CB1113D21118D41217D40F13D71113DE1718DD1416DB1217D50E15D30C12D71014D60F13
D50F15CE0B12CC0913CA0811CE0C15C90913C70610CB0911CA0810C6040DC80811C50811
C2060FC3080FBE060EBA060FB1010AAF040BAA030CA9030BA6020AA7010AA70108A60107
A30007A40107A50108A50108A30108A10007A10108A3020AA10109A0010AA2010BA2000B
A20109A00107A00005A20006A70209AB010BB0040EB2070FA9010AA7020BA200099C0005
9801059001068A01078001057801027401017201026C02036301025C0100590101711D17
388F0800FF0000FF0000FF0000FF0000FF00
00FF00964E19481108947D8295999D596464535C5C26232899929B92929C0B070D1D0602
8F66463C0A0254060A73040C8A040A97030B9C0109A3010BA9020CA9040F9B040B860106
7E00068300088F030B99010A9E0108A50107AA0107B1020BB3020AB7020BB70209B8030A
B70408B60309B6040AB40409B2030AB2020CB3040BB20109B20208B5020DBA060FBC0510
BB060FBE0710BB070EBB070EBD0910B8050DB90710B90510B8070FBA0912BA0A11BB0C11
B70910BC0A14BF0B14BD0914BE0D15BF0B15BD0C14BB0B15B6080FBF0F12C71113CE1214
D11013D31017D41116D60F14D71113DB1415DE1718DB1317DA1217D70F15D60E13D20B0D
CF080DCD0810C8060ECC0813CC0915C80611CC0812CD0911CA0810C6040DC70711C40711
C1080EC2090EBE060CBA060EB4040CB0040CA80107A60107A80209A90109A90109A50108
A50007A50108A50107A50107A10007A00109A00007A001079E00079F0009A3010BA30109
A20106A00007A00008A10008A40109A9020AB0050EB40811AB020BA60109A201099D0107
9600068D00068700077F01067600037301017101016E02036702035F00015B020168120D
3A910A00FF0000FF0000FF0000FF0000FF00
00FF0067720E4610059881837375796A747562686A141115A29BA2636369070207260F09
82573E3401004D00046C010788020A9401099E040CA5030EA6010AA7030F920107800004
7F010883010A8A0109A3101AAD151D9D0007A8020AAE010AB2030DB3020BB50209B70209
B70408B40309AE030AA20207A00207AE020BB7060BB60309B30208B5020CB9050EBE060E
BD050DC1080FC20A0FC40A10C30A10BE050DBE070EC10A12BE0B10BE0D13B90B11B80B13
B2040DBA0A15BD0C14BD0912BE0C14BF0B16BC0914BF0A15C10D13C40D11C70F11CF1116
D21017D20F17D41015D71015DA1315D91214D81114D71014D91116D70F15D91116D71012
D40D0FD40D11D20C13CD0911CC0912CC0912D30E15D00A10CC0910C6070EC1060EBD050E
BB040BBD060CBB060DB6030DB0020BAC030BAA030CA70008A80109A80109A70108A50007
A50007A50106A50107A50108A10109A001099D0108A002099F0107A00208A5010AA50109
A30107A10107A00108A00009A10109A4000AAB020DB10512AB020CA50109A000089C0007
9600088E01088700078001087601046F01026F02026E02036701025F00015A0100610905
388E0800FF0000FF0000FF0000FF0000FF00
00FF0066700E490F07886D6D7472756C7275525757141113A9A3A8434348040102351F19
653D2A3B05034E00066D020A87050C8B010797020BA0020CA7020CA7040D8F0005800004
80010880010A7E010695061099070F950106A5030AAB020AAC0109AE020AB2020CB6040C
B7050CB30309AB03099A0103920000AC040AB9070AB90509B70308B7040AB9050EBB060C
C30B10C90C13C6080FCA0C12C90C13C5080FC50B11C50D12C00D10BC090EB90A0FB7080F
B80911B80712BB0712C00B14C10A14C10A16C10C16C60E18C60E13C90E12CA1013CB0E14
CD0E15D3111AD41016D81317DB1416DA1313D61112DA1417D81015D60E12D60E12D60E10
D81013D70F13D20B11D00B13CC0810CD0911D30E15CD0912CA0810C4060DBD040BBA030C
B9030BB70209B7030BB5030DAD020AA80109A8010BA8020CA60108A60007A70107A60007
A50106A50107A40107A10107A00107A00107A00008A001089E02089D0106A2020AA20109
A100089F00089D010A9D01099E010AA00109A5010AAE050FAA020CA6010AA2020A9B0109
9501098D01088700078101067301036600006901016D01026A01026301015C01015D0501
378B0600FF0000FF0000FF0000FF0000FF00
00FF003995015318107F63628B8788595D5D4244421C1717A5A2A526262A05000150392A
3F1B1337000359030C7A050F88030B84000492020B9F030DA5030CA2040D8F0107840005
8001077C020970000482071085050A880005A1020AAB030BAD030BA90108A60006AA0108
AF0308B5050AB2050CAC030BA60308B3040BBB050BB90308B90409BA060DB50109B50106
C30B0FCE0E13CE0C11D31016CD0C13C6080EC50C11C30C12BD080FBD0912B8050EBD0A12
BC0A11BD0C15BD0914C00912BF0810C40B16C70F17C70E15CC1216CD1114CC1011CC1215
CB0E12CE0D15D11116D41215D31012D91516D71213DB1618D91415D81113DB1416D91013
DA0F13D81013D50D11D30D14CC0810CD0B13C8050FC7050FCB0913C3050EBB030CBA030D
B9010AB7020AB8040CB3020BAE020BAB0209AA030BA6000AA7010AA60107A60004A70207
A40107A40008A20108A00005A10006A30107A201079F01099901069701069D02069F0105
A102089D01089B01079B01079B00079E0008A20109AB050DAB050FA6010BA1010B9A010A
9300098E00098800088101067802046B01016B01026D01016B01016602015E00015B0200
33870200FF0000FF0000FF0000FF0000FF00
00FF003B9701430A038163636B66675A5B5C6362612D2727A8A7A91212140600005E4433
2706013901055E010A8003108C030C8C000895020B9C010AA0020A9C020A8F0107870006
8501067D0106670103620104690001830105A2030BAC020BAA0308A10004A00004A40005
AC0207B5050BB30209B30109B5040ABA050CBE050DC0070DBE060BBF0810BA040BBE070C
CA0C11D10E12D51114D50F14D51118CB0B12C3090FBF0910BD0910C00D12BC090EC00C12
BC0B0FB90B0FBB0B10C20B12C70F15C80F15C71015C81115C81113CB1215C91014C81215
C51413C71517C71517C71416CA1616CE1816D21B18D41B19CF1513D01512D71919DA1719
DC1317DB1014D90E13D40B11CD060FCC0811C90712C6040FC80712C2050FBB020BBB020B
BB030BB7010AB5020DB2020CAF030CAD020AA90108A70108A60108A60308A50207A40107
A40108A20108A10107A00006A10106A10107A101099D01089401059200039700049B0004
A001099F01089E01079C01069C00069E0108A1010AA7030CAC0710A6010A9E0209900107
8C02098D020A8801088101057A01037202026E01026F01026D01016801016101025B0100
65100300FF0000FF0000FF0000FF0000FF00
00FF00399500460A027251536E68696A6A6C4544443E383A9B9B9D0708090B0401533D2E
1C01003A01065F030A7F010E8D010C92000A9B040D9D020A9A000997020A9101098E0108
8D01088A020A7A060E9F3B4295282C93060DA4020AAB020AAC0408A70104AA0306AC0308
AD0306B5060CB60409B8040BBB040BBC0309BE050DC0060DC0070DBE040DC0060CCB0D13
D00D13D41013D00E0FD20E12D41014D00E14C90E14BF0810C10F14C11214BD1111BB1212
B71412B71613B81614C11617C31415C51215C81316C70F13C91113CA1217C1121AAC161B
AF2C27B23631B13835B43B38B63D39B9413BBE443EC54842BF3F3ABE3D3AC33C3AC52A2A
CD161CD10B11D60D12DA0E16D30B15CF0913CD0912CB0811CA0710C60610BF040CBE050C
BD040CB8010BB3010CB1020CAD020AAD030CA9010AA70108A50007A40109A20008A40007
A50108A30107A00106A00007A00108A1010AA1010B9C00099902089401049601059B0106
A0020BA1010B9E01079D01079C00089C00099F020B9D0109A1040DA1030D970209820004
7D00048301098001067D02067A01047400027200037100026F01026901016302025A0100
64100400FF0000FF0000FF0000FF0000FF00
00FF003A95004A0B04714F51877F7F5E5C5C3835324D45477C7B7E0201021C130E432F25
1800003601045D02087F030E8E020D93010B99020B9C010C96010A93000B92010B92010B
93010B93020C950F1AB73B46A31D269F040BA60208AC020AB10409B20308B20308AF0208
B00209B30309B70409BA040CBA020ABC040CBE070CBE050DBE050BC4070EC70810D00C12
D20E13D41014C8070CCE0B11D00E11CE1113C41013B81015B4191BAF221DA92C25AD3C35
AA4138AF473EAF433BB03B35AD2C28B12320BE211FC21817C71515C81518A70D13590001
AC7774E1B6B1E5BCB6F0C8C4E9C2BDEFC7C2F3CAC5F2C8C2F3C7C2F3C4C1FBC4C4F1999B
B92A2DC60F14CE0A0FD50C12D60E15D00910CF0910D00C10CF0C11CA0A11BF040BBA0308
BD070DB5020CB0010BAE030BAB0209A8020BA7010BA6010AA50009A5010AA40009A40008
A50007A30106A10106A20208A2010AA1000B9F010B9D010A9C01099B01099800079A0108
9C01099E010A9D00099D010A9C000B9C010C9C000B9501099100089C061195030E840308
7A00057C01087300046F00037402067501047100036F01056F0105680103620202590100
630F0300FF0000FF0000FF0000FF0000FF00
00FF003B96004B0B017C58596D656452514F4742405952556160630401022F211C2A1714
1900003700015B00047C010A89000A92020B97010A99010D92010A91000A8F010A91010A
91010A93010B91010C95030EA1060FA40208A80307AC0209B0040AB2040AAF0307AF0209
B4050CB5020AB60309B6010AB9040BB90109BA0207C0050CBF050BC60910C6060ED00D12
D20E10D40C0FCB080BD00D11CF1215BF1314AB1B1A8B1A1B933E38BE7E75DBA9A1EEC5BD
EACAC0EAC9C0E5BFB9E7BCB7DCA8A3D08B85C06962B1413BB62A26BF2120A71B1C450204
665A5EC8C8CAE7E3E1EBE5E5EBE6E5E9E5E4E7E3E3E4DFDEE9E4E4E5DFDFEFE3E4F5CCCE
B5494EC1171CCB090FD50D12D50D12CF080ECF0B10D00D11CB080EC5060DBD040AB9040A
B9050DB2010AB0030CAD030AAA020AA7010AA7010AA70108A70109A50109A20009A10109
A10107A10107A10108A20209A20109A0010B9F000B9F010A9C00089A0106990007980007
9A00069C01089C01089C00079C01089C01099E020A9C010C96020D95030F88020A790104
7C02077F01077B03086C01036B00027301047001026E01046D01046801036202025D0200
67120600FF0000FF0000FF0000FF0000FF00
00FF003B96004B09006F4D4D6961636B6A6A353331706B6C404043040001402E26190503
2200024502056002057701078201058F020B94020A95020C8F00098D01088F020A91010B
8E010B91010B91000A98020BA00309A20106A60105A80106AB030AA80107A40005AA0106
B20409B7030CB20107B6020BB8030ABF060CC1060DC2060DC2080EBE030AC2050BCC0B0F
D00D0DDA1214D40F11CF1415BD191B8A13117B322CB68D86E0CBC3E7DCD7E9E1DFEAE4E4
EAE5E4E6DFDFE6DFDDE9E2E2E6E0DDEADDDAE8D4CFE1BAB5D2918CBD5D599F3835521215
2E252BB9C0C4E0E3E5E3E2E4E8E7E9E3E3E5E3E3E5E5E5E7E8E8EAE4E3E5E7E3E4F0DADC
C67478BD2128D41219D50D10D30C0FD10B11CD0910CB0810C5060DBF040BBA030ABA050C
B6020BB3020BB0030BAB0208AA0209AA030BA9030AA60107A80209A40008A10108A00008
A00007A001079D01079F01079E01079E010AA1020CA2010B9D0109990005990106990007
9A00079900059B01069D01089C01089D01079D01079C01099B030F91010D810108760001
82020789020A85030B7B02097300067503077001046C01036B01036902046201025F0301
6F190D00FF0000FF0000FF0000FF0000FF00
00FF003C97004C0A01664142857C7E605F601E1B1A8B868728282A070000412F26150100
2901014A02066101047101047C00038B010893020993020B8E01078C01098E010A91010C
90010E92010C94010B97010A9C020A9F0106A20106A90309A90209A50108A10004AB0209
B5070CB6040AB40309B7020BB9040CBD040CC1060DC2050DC2070EBF060CC40B0FCC0E0F
CD0B0CD30E11CC0F11B61418760A0C7B4544D9C5BFEBE5DFEAEAE4E2E3E1E2E4E3E5E5E7
E7E5E8E6E2E5E4E3E4E4E4E4E3E3E3E2E1E1E2E1E0E6DFDEEBDDDAEDD1CED7AFAB614242
131216A4ABAFE1E5E7E7E8EAE3E3E5E6E5E7EAE9EAEAEAEBECECEEE6E5E8ECEAECEFE3E5
D2969AB1292FD81C20DF1418D50D11D00A10CB060FC5040DBF030ABB030ABC050DBB040D
B9040DB4020AB2030BAE010AAC010AAC020BA80209A8020AA70109A50007A20108A10008
A10107A001079F000A9E010A9E0008A10109A1010AA0000A9C0108970005990106990005
9A01079B00079B00069B00079C01099B00079B010798010996020D8D020B820207830207
8B040A84010681010880030A7501066F02066A01046701046A01056801055F01025D0301
74201400FF0000FF0000FF0000FF0000FF00
00FF003F98004C0900754F50736A6B4F4C4D251F1F928D8F1413140E0806362520160000
2C00034E01056703077201047B00038A02088E02088B01088A00078B01098C010A8F010C
91010D92000B96030D97010B9801099B0006A10107A8020AAA0209A70108A50207AB030A
B1030AB6040CB7030CB6020DB8030BBD040CC0060CC5080FC3080EBD050ABB0407C70C0E
CB0C0FCF0F14BE1014820C0E4B1919C7B5B5ECE7E4EBEBEAE2E3E4E6E5E7E1E1E3E4E2E5
E4E2E5E6E4E7E2E4E3E3E4E6E2E1E2E0E0E0E2E2E0E3E3E3E3E4E2E7E5E4E9E5E3D5D2D0
6E72718A8F91DFE1E3E9E9EBE4E4E6E1E0E3EBEBEDEAEAECE9E9EAE8E8E9E8E8E9EAE6E7
E8C1C6B04149CB1A22DC1219DA1016D20B11CB070FC3020ABF030ABE040DBA010BBD060F
BA050EB6020BB4020AB10109B0030CAB020AA70108A70109A70109A60108A40107A30107
A20006A10007A0010BA0010CA10009A3020BA1010B9F020C9A0209940005970106970005
9900079C01099D01099D010A9B01099A010798010793000596020A90020A810004850208
8B030A8301067B00027F02067600046D00046801056501046902056501025E0101590100
66120700FF0000FF0000FF0000FF0000FF00
00FF003D98004D0A00744F4D655D5C5854552C26288D888C09070919100F241311190101
3101035001046902067401057B000484000784000784000785010988010A8800078B0009
8E010A92010A92000A94010A9600089B0106A10209A7030AA60207A40107A30106A80206
AF0108B5040CB3030BB5010BBA050BBE060BC2090BC5080EC6090FC1070DC2090EC4080E
C6080FC60D13B0181E4E03048E7877E0DAD9ECEAE9E8E8EAE0E0E2E6E4E7E4E4E4E1E0E3
E0E1E0E3E3E5E1E3E2E2E2E4E3E2E5E4E2E4E3E2E4E4E4E8E4E5E9E5E8ECE5E8E9E6E7E8
E6E8E7DDE0DFD2D6D7E7E8EAE7E8E8E4E4E5E9EAEBE9EBEBE6E8E8E6E8E8E7E9EAE7E6E9
F0D8DDBD6871B91B24D6131BDA0F18D70E14CE090FC6060BC3070CC0050DBF060FBD050E
B9020BB8030CB6020AB4010BB1020BAD020AA80108A60108A7010BA6010BA50109A30107
A40108A30108A2000AA1000BA10009A2010AA2000BA1020D9B030B920006940106980006
9A01089E010AA1010A9D00089C02099B00089A02099701099B030B9C040E93040B8A0107
8B00088D020A8701068601068202077301056601036301026401026402035C0202540100
5F0E0400FF0000FF0000FF0000FF0000FF00
00FF003F99014B0A00613C39756B6A6D69692B2428827C810501022A1B1B1B08071D0000
3300015401056C02077100057701057E01097C01077B00097E000B85010A8903098A010A
8B02098E010A90010A97030C9A010A9B02069E0007A40208A101069E00059B0003A10003
AE040AB4030DB2020CB5020CBA060CBE060CC0060CC5090FC1060CC3090EC60A0FC4070C
C80C13B90A10880C11360E0EC3BCBAE7E6E5E6E6E6E8E8EAE8E8E8E8E8EAE6E7E7E2E2E4
E0E1E0DFE0E2E1E3E2E6E2E5E6DAE1D2BAC5C7AAB9D0B9CADACEDEE4E1ECDEE1E7E2E6E9
E6EAEBE8E9EADDE1E2E0E2E1E7E9E8E3E5E5E6E8E8E4E8E8E3E7E8E5E9EAE5E7E9E7E7E9
EDE0E4D597A0AD242DCB1119D71119D70E16D30E14C9080FC2050DC10610BD030EBB010C
BB020DBC040FB6010AB6020BB4030DAF010AAA0109A60109A50009A5010AA6020DA5000A
A6010BA5010AA4010BA3010AA3010AA2010AA2010B9F01099A0209940106960208990108
9A00089E0009A000099F01099E010A9D01099D010B99020B9302079C050CA0050C9E040C
9B030C94020B90030A8E02088602087702076802036002035B00015B01025602034D0100
5D120800FF0000FF0000FF0000FF0000FF00
00FF004099014A09006E4A47766C6A534F4C392F306D666B0500002C1919140101230102
3D01025E03076B02047001047402047601067702077800097D010B83010B87020C86010B
82000681000788000895010A9B010A9B02079E0008A7030AAA040BA60108A10006A30005
AC0208B6050FB0000AB3040BB9060CBD060DBF050CC3090FBF060BBC040BC1080FC1060D
C1070EBA12186C080A3C2727CDCBCBE3E3E5E6E6E8E8E9EBE9E9E9E4E5E7E8E8EAE5E3E6
E2E2E2E4E3E5E7E4E8E8D8DEC38F9AA34659982A3E91294286354C925E74B09BACCACAD5
DBE0E5E4E6EAE4E8E9E5E6E8E5E7E6E3E5E5E5E8E9E3E6E8E4E7E8E4E6E8E7E8EAE5E5E7
EAE2E6E1B6BFA7343FC71821D7131BD40F17CF0C14C90911C2040DC1060FC0060DBE050C
BA030AB90109B8020BB7030CB5030BB3030BAD010AA70008A50007A40109A4010CA5010A
A7010BA5010AA3010CA1000BA2010AA2020BA000099C020A9203098801078F030A96010A
9A010A9C010A9F010AA1010CA1010DA1000CA1010C960108850002900206A80810AB060F
9F040E8801078402078E030B8101056B01026502045B00015400015800025802044E0000
62160C18C50100FF0000FF0000FF0000FF00
00FF003F9A014A0A007553516A625F5854514A42444C474B0801023522220E00001F0001
4705066003046A020270010271010373000574000779010A7C020A7D010B81010A82000B
80000680000689020896020B9D010A9F020BA00108A8030AAE040CAC030AA60107A80208
AC0208B3040DB10309B00309AC0106B30309BC070CBC050AB50105BA050DBD060FC20710
C60A15B40E175D0305493638D4D1D4E6E3E6E8E7ECE7E8ECE5E9EAE8E9E9E7E5E9E6E4E7
E5E3E4E6E4E7EAE3E7D1AFB79E3946BE1F2DCA1823CC1827C6212EA61D2E6F11226B394B
A89AABCECEDBDBE0E5E2E6E8E1E4E4E2E3E4E3E4E6E4E5E7E7E8EAE7E8EAE7E8E9E4E4E6
E6E3E5E9CED3AE555EB81A23CA0E15CC0C14C80910C5080DC3060EC4060DC4060BBC0208
BB0409B8030BB7020BB6020BB50209B10109B0020BAC0209A80108A7030AA40108A50009
A50009A20109A20109A3010AA3010AA2010A9F00099A01088500046C00007301058D030C
9801099B01069C00089D000AA0010CA5010CA6010D9F020D920208940208A70710A9050E
98050E78000372000188050A8503096D01026402036002045B00035B0103590202530100
61120A318A0200FF0000FF0000FF0000FF00
00FF003D9900460A006847477269696965675E595B2F2C2E110807251313100000250001
4000015B00016900016D02026D01037001077201077301077101077400077F020A84020B
8401078300058A01079A040DA2030DA0010B9F0008A50109A90209A90108A80206A90209
AA0106AF020BB0030AB4060FB0020AB30209BA060BB90308B70207BF0810C1070EC60A13
CB0C18BB101A660509412E2FD6D4D7E8E6E9EAE9EBE9EAECE9EAECE7E7E9E8E8EAE6E4E7
E8E8EAE8E6E9EAE1E3B5858CA82A33CA161FD01016D61215E01D1ED81B20C11922981625
5D0D1F69485BA7A7B3C4C9D1DEE3E6E2E4E6E4E6E8E2E5E6E5E7EAE3E7E8E4E8E9E3E5E7
E4E5E6ECDDDFC28089A91F27C10C14C70B11C6090EC70A10C3040CC8060DC7080DBF040A
B80109B7020BB7020BB6020BB3020AB1020AB5060FAD010AAA010AA7010AA7020BA6000A
A50008A50108A50108A50008A4010BA2010CA0000A9C01098F04097703056A0001800207
96020A9B01059D01089F010CA3020DA6010CA6010CA3020C9E030B9A0108A1040DA3050E
96050A7F01047A020584010889020A7802066B01026A0205630001590001550202510100
5D0D0632890200FF0000FF0000FF0000FF00
00FF003F9C03440B006C4B4B83797B4440466C676B1F1A1C180B0B1906071A0101350304
4B02025F02026A02036D00036B01056F01067201057201076D00037201057C010984010A
8201058500078B010897030C9F030E9D01099E0007A20008A40106A60107A60107A60006
A80007AC010AB0010AB3030AB5040BB8050AB9070CB4040AB8060EC20A12C1080FC10810
C1040EC0121975090C31181AC5C1C5E5E2E8E4E4E6E8E8EAE3E4E6E7E7E9E7E7E9E7E6E8
E7E7E9E9E8EBEFE6E8CC9CA3A82731CB161DD21014DC1417E01819DB1417D71618CA141A
B117227310203615256F6B78BFC3CADFE3E5E1E5E6E1E4E5E4E5E7E4E5E7E3E5E7E5E7EA
E2E3E5E7E1E3D1A5ABA02B33C3161CCA0F14CB0C12C90A11C4060FC3050EC4070EBF050B
BE050CBA030AB70409B60309B20209B1010AB0010BAF020BAC0009A90008A80108A80109
A70108A70208A40107A00007A0010BA1010CA0020C9B01099401078701057A0103840106
9602089C02059C0106A0010AA2010BA40109A4010AA0020A9801099B040C9E030C9B0107
A00A0E8F04098803098801078802097B01057100047101046D03055D01025000014D0000
580C042E880100FF0000FF0000FF0000FF00
00FF003E9A01460A007E5A5B7166673E393B767072100A0B2517151302021D0000390202
5302026503036C01026D00036C02067101077602077502087101057400057C0107830109
82000588000989010892000A99010B9C01099F0006A30106A50004A50106A50108A50008
A70209AC010AB2030CB5020CB3030BB00309A90206A40005A80107B80710B5030BB5010A
BE060FC01019890C122A0507B1ADB2DFDEE3E8E9EBE8E8EAE6E7E9E8E9EBE8E9EBE8E9EB
E9EAECE6E6E8EDE5E6E4B9BFA52E37C6141BD41216DF181CDC1519D60F13D30F12D20F14
CC1319B11A235306101D070F9D9CA2D8DCDDE2E4E4E4E4E7E6E5E9E3E3E5E5E6E8E5E5E9
E3E3E6E5E2E5DDC1C7AA4D54B7171FC60E13CB0D13C60910C0050FBB000BBC030DBF060D
C0070DBF060CB90308B70309B5030AB4010AB3010CB1010DB2010CAF010BAA0109A80208
A60107A60108A30109A00108A00109A0000B9F000A9C01099702078F00048901048F0106
9801089B00079C01089D0109A2020CA2000BA2010A9D01098F00069102099D060E9B0309
A0090F96040C8F020A8D02098403087903077402077302066F0205660304590100510100
580B0430890200FF0000FF0000FF0000FF00
00FF003F9B02480B00795455625657534B4E726B6F080102180A0A1101011F01003B0002
5802026802046B01036A00046C01057402087802087400087501087501067C010781010A
84020A8B010B8B010891010A96010B9E010BA20209A60208A60107A30107A20106A20109
A50107AB010AB1020BB4010CB5050DAF020BA80309AA040AAD0309B8050CB8030ABC030C
C1050CC30A12A6141A3A0102847A81DBDADFE6E7E9E8E8EAE6E7E9E6E7E9E9EAECE6EAED
E6E8EAE4E4E5E7E1E0EDCACDAC424BC71922D41118D8141AD61317D00C13D31016D41016
D01017C4171D7E0D142A00046B6269D0D3D6E5E6E8E6E5E8E5E5E7E6E6E7E2E2E5E4E3E8
E4E3E7E1E0E3E4D3D7B56F77A81B23C30F14CB0E13C1040BBE040CBC030DBC030DBD050E
BB030BBF060EBE060EBC040BBC060FB7010CB5010CB5020EB3020DAD020BA8010AA6020A
A60209A50108A10107A20108A20108A001079F010A9C0109990107940104900003950106
9901089B00089C01099C01099F010AA0000AA1010A9E020B96020B90010798030C99050D
91020995070F8B01088802097401066401026800036E01036C0103680203600201580100
5C0C05328B0300FF0000FF0000FF0000FF00
00FF00409C034809007B56548074743B31356A5F62090302180C0C110000280101460102
6003046901056901036801046A01057202077600067500087700097801097801077A0008
8401098E020B91020A9100099500099E030B9F0009A10109A20008A10006A30208A40009
A50108AA0109AE030BB0010AB2020CB2020DAF050DB0040AB7050CC1080DC90B10CB090F
D30E13D8131AC41C215B050748363CCFCDD3E6E7EAE2E3E5E5E7E6E5E6E8E8E9EDE6E7E9
E9EAECE5E5E7EBE7E7EBD3D4B75E63C31F26D11319D4121ACF0F17D10F17D20F15D31016
D31115CB131A9E131A470005382328C9CBCFE4E5E8E4E4E6E7E8E9E3E5E5E4E5E8E6E6EA
E3E3E7E4E4E6E7DEE3CD9CA2A12A2FC1161AC80D11C80B12C2060DC1060EBF070EB9020B
B8030DB9040DBA030CB9050CB60209B7030DB5040EAB020BA4040B9F050E9A040D9F0610
A2040DA4020BA4020BA50207A30106A101089F010A9D020A9A0108960006920004960207
9A02099B02089A01079B01069C01079F01099F010A9F020C9E020D96000A8D01088F060C
8F050C91050C92040C8A020A7702086001036401037104076B00026300006002025A0100
600E07338C0500FF0000FF0000FF0000FF00
00FF00439C044A09008B6663776A6A372C30584E4F0601010902021702023704054F0202
6102016701046302026201026701036E0104730105750108760107750108740005790105
8302098A010A8E020B91000A9400089A010A9C00079D0107A001099E0007A00105A4010A
A60108AA0109AB0109AF030CAC010AAB020AA90108AB0108B00109BC050ACD0D11D30D10
DB1013DF1318D1191D7E0A0E2B1013B6B5BAE1E2E5E6E7E9E8EAE9EAEAECE6E7E9E7E8EA
E9EAECE9E9EBEAE8E8EBD9DAB36E72B6252BC91319CF1118CF1118CF0F16D10E13D20E12
D31013D01218B6161D6D07102C050AA7A6ADDBDDE2E5E5E7E9E9EAE7E7E8E3E3E7E4E5E8
E3E4E6E0E0E2E5E0E4DEBEC3A34147BA181EC1070DC50710C50811C0060EBE060EBB030C
B8030CB6030CB5020BB2020AB2020AB0030BA7030B8B02057A0102A12129CC4B57A6252F
8C030B9E050EA4020CA40107A10207A1020A9F010A9C0008990106970007930006910106
9502089A01099D02099C00079D01079D01079E00079F010A9E010B9A020B8D0106880104
970A0F9703089F070E95040D85020A7101066B00027301066E02056100005E01015C0201
5E0C06328B0500FF0000FF0000FF0000FF00
00FF00419B034A0800886061604F52463B3F3C3437080101080001180000380101530203
6103016302035C00015F01036601046C00057102067301087300077401077401067C0108
83010A8701098B010892010A9401089800079C02079B01069C02059C01079C0006A00108
A50108AB010BAE030CAD030CA60006A40005A70107AF040DB10208BB050ACC0B10D91114
DE1215E01318D314189D12172D0002928F95D9DDDFE9EAECEAEAECEDEDEFE8EAE9E6E6E8
ECECECE6E6E8E7E5E6EDE2E2D5A4A7A92D34C3161BCA1116CC1116CD0D14D10E16D30E14
D10F11D21015C4171C95121A4201076F676DCDD2D6E4E8EAE6E7E9E5E5E7E3E3E6DFDEE2
DFE0E1E0E0E3E4E1E5E9D4D8B2666CAA181FC00B12C2070FC1060FBF0510BD040EBC040E
BA050EB6020BB5020DB3020CB0010BA9020B96060C7000017302069008149A101EAC2B37
7B01078B02099F030BA40209A100099E010B9F020D9D010A9A01069401068C0005850002
8C00059A01099D01089D00089E010A9E010A9D00099C00089E020A9F020B9A020B930108
9A080E9E060CA0060D95020A8600077B02067201027301057202056602025D01015B0201
5B050032880300FF0000FF0000FF0000FF00
00FF00449D054A0800855B5D7C6A6F4E41452A25260F05050F00001B0000380101530101
5F02025F01025B00005B01016201036B01076F0107700107700006740106780106800108
8601088801088A00078F010A9201079500079701069801069700059A00089D01099F010A
A4010AAA010CAE030CAC020BA90109A70108A60006B4050EBC0810C4080FD00D12DA1115
DD1317DA1014D31015B315194602035A5358D2D6D9EBEBEEEAEAEAE9E9EBE8E9EBE9E9EB
E4E6E5E7E7E9E1E1E2E8E2E1E2C0C4A64249BD1921C91218CD1218CC0D14D01018D00D14
D20F14D31015CA141AB1161F61050C3E2C31C1C5CAE6EBEDE2E4E7E3E3E6E6E6E8DFE0E2
DEDFE1E0E1E4E2E2E5E7DDE1C692979E2029BD0F18C30A12C0070FBF050FBC050DB9040A
B9060CB7030BB6020DB7030FB5030FAA040E8403096800018B09129F030EA1020E9E0614
87030B81010799050DA2030AA2010AA1020D9E010C9C010A9A01089400059101068C0205
9001069901089C01079D01089C00089C01099C01089C02099D010A9B010A9A010C9A020D
9C060F93010899071090030B8101067902056F02056C01056E02046801025F01015B0100
5E070234890400FF0000FF0000FF0000FF00
00FF00449D04510B00875D5F705F635045471510100C0101130101280202430202580202
5D01025C01015901005A00025E01016901076D01066D01056E01047301057A0105810108
8401078701088800088D010A9101099201069400069601079700079A00089E030AA0000A
A3010BA7010BAB020AAC020BAC030DAA020EA60009AF020BB40309BD030BCD0D13D41013
D71112D60E12D20F14C0151A680A0C2C1C1EB9BFC2E6E9EDE7E8EAE6E5E9E3E4E6E0E0E2
E0E2E1E2E3E5E1E2E2E5E3E2E4D3D4B86D73B01D24C8131BCD1017CE0C15D10F17D10F16
D10F16D00E15CA0F17BE141B820F1328060AA5A6ADE1E5EAE3E4E8E4E5E9E3E4E6E2E3E6
DFE0E3E1E2E5E1E3E5E6E3E5D3B1B5963139B20F19BE0811BE0811BD060FBC060DBB070C
B6050AB3030AB5020BB7020CB7050FAA07107301055B0002880910A0040CA5020EA2030F
91070E73000287040A9E040EA2020CA1010B9E020A9B00089B0008990108960106940106
9A02099B00079C01079C01089C01089B00079C01099C010A9C030C920008920109960109
9A050F89010785020988030C7900046F01026701035D00016403056402045F01025D0102
60080466140800FF0000FF0000FF0000FF00
00FF00459E03520D008B61615648495247480A07070400011000013002044C03035C0204
5C02015A01015801005900025C00016700046B00066B01056C0103730107780105800009
8401098700078801078C00098D00099100099200079500089801089A00089E020CA0010A
A10109A00006A60207A90108A60108A5000AA9020CAD010AB40207BA0207CD0C11CF0C0F
D00D0ED20E12CE0B13C00E167F0A0F200305888B8FD1D6DADFE2E4E2E2E4E2E2E2E2E0E1
DFDFDFE0E0E0E2E4E3E3E3E3E8E0E0CB969AAA292EC8161ECE1018D10F17D41219D10F17
CF0D16D00E17CE0F16C40E15A3161C3B00066C676FCDD1D7DFE3E5E4E7E8E4E5E7E2E3E5
E1E2E4DFE0E2DDDFE0E0E0E1DDCBCE9C5257A4141CBA0B15BA0611B9050FBB060DB70309
B6040AB3040CB3030DB3020CB6040FA90A126B01044700006C060B90050E9B040C9A020B
8B080E640001730307990510A1020DA0010B9D01099D01079B00069B0207960006950108
9801099B00089B00079C00069E01089E01099C01099C010B9A010D920109910007960109
9A050E8A02097C00048302097F010876010673030A6101035B01025B00016001015F0102
61080566160A00FF0000FF0000FF0000FF00
00FF00469F044F0B007953506A5C5B483D410402020600011401003201014B0201580201
5802015301005101005401015A01016701066B01066E01066F01047300077B010881000B
85020B88010A8801088C01098E010A90000992000A9301089401089700079B010A9E010A
A10109A40108A60107A90209A60107A70008AE030CB8040DC60C0FCC090FD10C10D00D11
CC0B10CB0B12C80B12BD0B139711163101025C595DC1C5C9E1E3E3E1E3E2E1E1E1E1E1E1
E1E1E1E0E0E0E1E3E2E1E2E3E6E3E2E1BDBFA73D42C51921CD1117D20F17D00F14D00E16
CF0D16CD0B15CF0F17CD111AB7151D5B040A3F2E35C1C6CBE7EBEDE6E6E8E4E5E6E1E2E4
E1E1E3E1E3E4DEE2E2E0E2E1DFD8D8A67477931A1FAF0911BA0812B8040FB9060FB6030C
B7040CB6050EB4040EB1020CB2020DA907107403073E000044010366030B7B050C7D060B
6A0408500101680207910410A0030FA0020D9E020B9D02099B0106990208930107910006
9501079901089B01089D01089E01079E01099E010A9D010C9A010C97010A97010A97010B
9D041096040E85000786020B84020B7E02087903096A0003630103630203610101610102
60080467190D00FF0000FF0000FF0000FF00
00FF0046A0064C090086605F695A5D433A3D0200010800002002023D0303500201560100
5201005101025000015101015800006400036C02066D01066E01047201077A01087F000B
84010C87010B8600088A01088E010A90000A92000A92010A9500099800079C020A9E010A
A10109A50109A9020AAA010AA70007AE010AB9050DC2060ECD0C11D20C0FD10B10CA0810
C3070EC40A12C30A11C00B12AA11174F030734272BB6B7BCDDDEE1DFE0E2E3E3E5E2E2E4
DFE1E0E1E1E1E2E4E3E3E3E5E5E3E3EAD1D3AF5B62BA1C24C91217D10F17D10E15CF0C12
CF0E14D00C15D21019CE0D17C2111C7D0A1329080C9EA1A6DEE3E5E4E6E8E3E4E7E3E4E6
E0E3E4DFE3E4DEE2E2DDE1E0E0DFDEB9999A8E2B30A80D16B40710B6060EB70610B6040D
B4030BB5030DB3010EB1010EB1030EAC050F8A060D4D01013400014200044C00034B0002
3F000240000367020B9405139F020E9D010B9D020B9C01079A01069600089001068E0004
9400059900079C01099C01089D01079D01089C010A9E020D9B000B9A010B96020A900107
91010A94020D8901088302097E02097901077501067001026D0103670102620001620202
5E020162110900FF0000FF0000FF0000FF00
00FF00459E054B08009169664E393B372A2C0300000B0101230100400201500202530201
5100005101025201005501015901006300036801056800036C01037100047A02087E000B
82010A86010A86000989000A8D010A9000099100099201089601089900089C0109A0010A
A20109A6000AAA020CAB010AAB0209B4030CBB030AC70910CC0A10CF0C11CB0A10C5080F
C0060DC10610C30913C00910B50F17700A1020080B9C9EA2D3D7D9E2E2E4E2E2E4E1E1E3
E3E4E6E5E5E5E1E3E2E3E3E5E4E3E4EDDEE0C5878DAF242DCA161DCF0E16D20F17D00D15
D00F14D00D15D20F16D41018CF131BA0141C380107747177D4DBDCE5E7E8E2E5E6DEE2E3
DFE3E4DEE3E5DEE3E4DDE2E2DEE0E0D1BEC191454D9E131EAF0711B4050FB3040CB4040C
B3030CB3030EB30111B20312AF040EAD040C9F060D7503094800026124276427293E0507
3300033D00016B020A9604119E020B9C010A9B01099B01099B010A9601099101068E0003
9300049800069B00079D01089E010A9E010A9D01099C010B9C010C98020C8F01098B030A
8C020A90020B8802087502076801066801056B01037202037303066601025F0001600202
5D030062100700FF0000FF0000FF0000FF00
00FF0047A006500900734744553F3D271A1B030000090000240203420202500101520100
5201005100015101005801025B01016200036A01066B00046F01017300027A02067E0109
80020B85020D84010A87000B8A000A8E00099101089502099801089B02079C0109A00008
A10008A6010BA9010BAB0009AF040DB3020CBA050DC50A10C90A0FC90910C3070CC2070E
C0070CBF060CBF070DBE080EB90D14890D132B00036B6A6EC0C5C8DFE1E3E1E1E3E1E1E3
E2E4E3E0E0E2E1E3E2E1E2E4E2E1E1EBE1E4DCB2B6A53138C51A1DCC0E13D21116CF0D15
D11015D20F17D10F14D20E14D11117B7181E55030941353AC2C7CCE1E5E7DFE3E4E0E3E5
DFE3E6E0E2E6E0E4E7DDE1E3DDE0E0DFD4D5A26971911723AD0C17B1060FB1020CB3030C
B4050EB1030FAF0211AB000EA9010AAC030BA70409990C10811E208D4B4DCD90937B3C3F
42000159010584050D9C030D9F010A9B00079800079B000A9B010A970109930107930106
9601079800089A01089B01089D010A9D010A9C01089B010899020B8D010A7E0005810108
8A030C8C030B8503096800025100015C00056D02057401047303056502035B01015D0201
5C030165140A00FF0000FF0000FF0000FF00
00FF0048A206520C0071433D5C4643160D0D0100000700011D0000410203550303550101
5302015401035302005700015E00046501046B01066E0105700103730105760207770109
7201077502097A020A83010B89010B8A010A90020A9501099801089A01069B00069C0108
9F0008A40009A60009A90209AD020BAF010BB00106BF070CC4080DC60A0FC1070CBF060B
C0070CBF080CBF090DBE0A0EB90B119F11194202063C353AA6ABAEDEE1E4DFDFE3E3E3E5
E1E2E2E2E2E2E2E2E4E3E3E3E4E3E4E6E1E2E1C6C7A74C52BC1E23CD1318CD0E13CE0C14
D00E16D00D15D10E16CF0C14D00F16C1131A780B11290C11A7AAB1DCE0E4E1E4E6E1E3E5
E2E4E7DDE0E2DFE0E3DEE1E2DEDFE1E4DCDDB98E9389202BA70C17B10812B1030DB2020D
AF020CAD030DAD030FAA010DA9020BA80109A9030BA2060CAB2E32B1565C8F464D7E2F36
811D2386070F9B040EA4010CA1000B9C01099B01099B0109980108950108910006950007
9800089700089900089C01089C01079D02099B01079A01079402098201077600057F020C
7E01097C010584040B77050A5D01045A00047004087501037002045F01015801005D0201
5A03016A1C1100FF0000FF0000FF0000FF00
00FF0048A3094E0C008E615F4029270F04040100000A0000210101410203530202550204
5201005201005201005701025E02056501056A01056C01066B00046B00046C01067A0E14
A33D428220296501057B020A86010A8A00098D01099301099701069A01069C01079D0009
A10109A50108A50007A90208AE020AB4050CB5040ABF070CC3090EC2090EBE060CBE070D
BD050DBE060FBE080FBE0B0FBC0C12AB121A5D080C1F1012868A8DD8D9DDE0E0E0E2E0E1
E1DFE0E4E2E4E4E2E5E4E2E5E6E4E5E3E1E2EAD9D9BB797DAD2025C71315D11317D00F14
D31018D30E15D20D14D10E14CE0D12C8131999141B33000579787FCDD2D8E3E4E8E2E3E5
E1E2E4E2E3E5E1E2E4E0E0E3DDDDE0E1DCDECFB4B88B3840A0121CAF0811B50812B1030D
AD020BAA020BAD030EAA020CA6010BA5010AA5020BA7040FA30815981321A12A39A12836
9B131E9F0610A5010CA6020CA101099B01079A01099A010A97000995020A920006960107
9901089A010A9B00099E020A9E01099F020A9D01099A00069703098701078100058B030F
88040F7800067D020A7B02096E05085D00026904086D03066702045C01015900015A0100
590200681A0F00FF0000FF0000FF0000FF00
00FF0047A2084F0D017C4F4A361D1C0C02010400011101012601004001014E01024F0101
4F00015101025201005500025A01026301066801056A010666010363010266010289151D
89161F760C165D000571020B86030A8C010A9000099301089601079701079B01089E010A
A20109A40107A50107A90108AE0309B8050CBC050BC1060DC3090EBD040ABB050CBC070F
BC0711BD0713BD080FBF0A0FC00C11B410157C0D132001046B6B70C4C5C8DFDFDDE2E0E1
E1DFE0E3E1E4E3E1E4E3E1E4E6E4E5E2E0E2E9E1E1D0A3A5A42C2EC6181BCE1314D01015
D00D13D10C13D20E13D00D11D10F13CB0F16AF151C4F020A494147C2C9CEE2E4E8E3E3E5
E1E2E5E2E3E7E0E0E3E0DFE1E1DFE2DFDCDFDACBD09B5E6696171EB00C14B3070FB2040E
AF050DAE040DA9010BAA030DA8030DA4010BA2010BA4000DA5010FA505159F04139F0313
A40211A7030EA7010CA5010BA3020C9E02099C01069B0008970009940109930007970108
9801079900079C01099C010A9E0209A1010AA1010A9F01099C010995010991010997030F
93030E8600097F020B7600057103066501045E01025D01015D01025D01015E01025D0101
5B020164130900FF0000FF0000FF0000FF00
00FF0048A3084F0D0171453C2813100801000500001701013202024702034C01014C0102
4C00015001015501015701025801015F01056501046801056201035A000163000382040E
8A040E83040F6401056401067E020B8A010990010994010997010A9600099901089C0009
A00108A10108A3010AA7010AB1030DBC060DC1080DC80D12C2090EBC040ABA040CBD080F
BA0610BD0811BD080EC20B10BF090DBD1117950F163401034D484DB2B6B8E1E2E1E3E0E1
E4E1E2E0DFE2E2E2E4E4E3E5E5E5E7E5E3E5E8E3E3DEC0C1A74548BE1A1ECD1317D11218
D21017D31019D10E15D31116D11015CE1016BD131A730B122A1218A5AAB0DDDFE4E2E2E5
E1E2E4E1E2E5E1E2E5DEDEE0DFDFE2E1DEE2E2DADEB1878B8D2127AC0E18B50B14B2070F
AF050DAF070EA80209A60009A8020BA40007A5010AA5010CA4010CA3010CA4010DA5010C
A6010BA8010CA8020EA5010CA4010CA2010C9F01099B010798010898020996010898020A
9801089800079B01079D01099F0109A10009A1000AA2010CA2020B9D020C99030D960510
90010B8E030B8A030B7E01087701076F00066B03076101025F0102640204650303600101
5B010063100717C30100FF0000FF0000FF00
00FF0049A4094D0C00825A5121120F0601000901011800003903034D03034D01014D0101
4F01015201015801015901005701005B00036201056701085C02054D000069020885020D
8D020A87040B6B02065C00047A020A8901098F010893010797010798010A9801089A0008
9E030B9E010AA4030BA80208B4040ABC060BBF060BC1070CBE050BBC060DBA060DC00810
BF0811C10A13BC070DC20B0FC00A0FBA0811A710194F04092F22279D9EA3E0E0E2E1E1E1
E1E1E3E0E2E3E2E5E4E3E4E6E4E5E7E5E3E5E3E2E2E5D2D5BB7076B51F27CA131AD2131B
D3111AD00C17D31018D00E16CE0D14CF1016C5111995131B30000875757DCBCED4E1E1E5
E4E4E8DFE0E3E0E0E4E0DFE4E0E0E4DEDEE0E4E2E4C9AFB18D363DA5131FB00A14B10710
AF060EAB040DA9030CA7010AA9030DA5000AA20109A3010CA2020D9F010AA2010CA3010C
A5000AA6020AA7030CA4010DA2000DA0010C9D00089D02099C02099A0108970108970109
98010A9900099C01089D01089F0109A2010AA2000BA6020DA7040FA1050E900108860108
89020A90030C8C01098601088102097C02087A03097001056C02056401035F01015F0203
5901006C1A132E860000FF0000FF0000FF00
00FF004DA70C5310037A4F491709070400000800001B00013901024B02044900014B0102
4D00005300005701005901005701005B000062000363020654020444000169040980030A
86020A7F040B6302055A00047B040A8C020991010A93010A94000898010A9701079A010A
9C01099D0008A10107AC040AB4030AB9040ABC070CBB040BBB050CBA060FBA050EBF0610
C0070FC00711C0080FBF080DC00B12BD0A14B1101A6B070F21070E8B8A90D5D5D8E1E0E2
E0E1E1E0E3E4E0E5E4E2E6E7E4E5E7E5E5E7E4E3E6EADEE2CF989EA7262EC6171DCE1017
D10F18D40F19D31018D00E17D00F16CE0F16CA1119AC161F4902084C424ABABEC4E2E5E7
E0E1E3E0E1E3DFDEE2E0DFE4DFDEE3DDDDE1DFDFE1D8CACD97585E94141EAC0A14B10812
AE0610AC0510A7000CA6010DA6020CA2010BA00009A1020DA0030E9D010B9D01099F010B
A1000BA5020BA50109A3000AA1010CA1010B9F01099D01099B00089B010A9A000A9A000A
9901099900089A01079B01079F010AA2010DA4010DA9040EA7050DA6081397040E870106
8C030B91010A8A01088601088601098002087E02097801057301046702035C01015E0202
58000075251E2E870100FF0000FF0000FF00
00FF004FA90D561303683D381204030300000800002401013B01014A02014800014B0102
4F01025702025902015C02015B01016202046500056202084C020437000057030773050A
73030A6302075101065601047A020B8B010992010891000995000998010A9B01099D020A
9F010AA00008A50208B1050DB8040CBA060DB8050BB8040DBA050EBF0A12BC070EBC040E
BE070FBD050FC10911C20911BF0A13BE0B16B50E18870D172A000769646CC4C4CAE3E3E6
E3E4E4E0E1E4E1E2E4E2E3E3E5E5E6E5E3E6E4E4E6E7E2E5E3BFC3A43A40C11A1FCF1319
D31319D31019D20F15D20F17D00E16D00E17CE1019BD17216A0810291217A8ABB1DCE1E4
E1E3E4E0E0E2E0E0E2DFDFE2E0E0E2DDDDDEDEDDE0E1D8DDAD7F85871A22AA0C16AD060E
AC050DAB040CA9030DA6020DA4010CA2010B9F00099E01099D010A9C010A9C000A9D010B
A0010BA4010BA4020AA2010AA0000BA1010C9E00099F020B9D010C9C010B9A00099A0008
9901089900079A01079B01079E0009A2010BA8030FA8030DAA050EA90512A2041095020B
90010991020B89010886000786020A7900057401057701067301046B0205630103610101
5A01007020182E870100FF0000FF0000FF00
00FF004DA80D521202754E4B1006050300001001003303044902035003034A01024B0102
4D01015402015801015C01025A000063020568020864030B4703062800003801014D0205
4E01054400034100025801037D020B89000790010892000A95010B9700099801079C000B
A0020BA3000AA8030AB2060FB6070FB8080EB6050CB6020CBB0710BC070FBD080EBB060D
BE090FBD080FBE0A10BB060FBE0912BF0A15B609149F121D45020C3A3139B9BAC1E2E2E5
E1E2E4E2E3E7E3E2E6E4E2E5E6E4E5E5E3E4E5E5E7E5E3E5E6D0D3AA5C60B81E25CE131B
D01218D31117D11014D10F15D41318D00F15D01219C313198D111A2E0109858389D1D3D8
E0E1E4E1E2E4E0DFE1DFDFDFDEDEDEDDDDDCDCDCDCE1DDDEBEA0A4842831A5101AAC060E
AD060EA9020CA7020CA5030CA5020DA3010C9F00099E02089D01099F020D9D000C9E010C
9F010CA2010BA3030DA0000B9F020D9D010C9E010A9F020C9E010C9B010A990108970006
9801089901089A00089C01099F0109A5020AA8020CA9040EAA0712A3020DA60611A0030D
97020C87010783020988030A88020A7B02087200047401066B01035F0102630305620102
5C02016D1C132F880200FF0000FF0000FF00
00FF004FAA0F521406724E4C0802020300001601013B03044C02024E01014C00024D0101
5001015400025801005D01015B00016201036701046302074C0206260000260000330102
3901043A00044600026803078101098A01088F010892000A95010996000997010A9A010B
9D0109A5020BAC080FA20309A10409B30912B70611B8040FBB0510BC0710BC070FBC070F
BB080EBB0710BB080EBD0912BD0912BD0814BB0C15AC111C640811231017A3A6ABDDDEE1
E1E2E4E1E2E6E3E4E8E3E2E6E5E5E7E4E2E6E4E3E5E3E2E4E7DCDEC28990A9252CC8191F
CE151ACD1418CE1519CE1519D0181ACE1518CD161AC6181AA91E2546040B594F55C6C9CD
DFE0E3DFDFE1DEDEDFDFDFE0E0E0E0DDDDDEDFDFE0DFDCDDD0BDC19148529B131FAE0A13
AD0610A8010CA9040EA7030BA5020DA3010EA1020CA2040EA0010D9F020D9D010C9C000B
9C010A9C0109A0030D9E010C9D010C9B010A9B00089C010A9B00099A0108980007990107
9A00089B00089B01089B01069E0007A40109A8040CA7030EA807139D010BA50712A6040F
9D030E8402067700048202088301077B01077A0208740205670203550000570101620204
5D0001600C0430880200FF0000FF0000FF00
00FF004FAA0F551709623D390900000400001600003901024B01024D01014C00024F0101
5301015900025900005E01025F01016301036501036301035803053401012901015C3033
8355583E05085D03077A03098701088D010A91010A92010A920108930108960208980108
9A0106A7050DA8050C9702038D0001A7050FB4040FB7030EBA0611BB0713BC0611BA0510
BA0710BC0812BB080FBC0811BB0A12BF0B14BA0A12B40F18810F162101047D7D84CDD1D5
E2E3E7E3E4E9E1E2E6E3E2E7E2E1E6E1E0E5E3E3E8E2E2E4E7E2E4D5B5B79A4042B32D2F
B72A28B72A26B52B28B42B28B22B27B32C29B5312CB02F2C9D2F2E5C222345393CB3B5B9
DEE0E3DEDFE2DCDFE1DBDFE0DDDFE0DFDFE1DEDEE0E0DEE0DED3D7A06A728C1520A90A15
B00812AD040EAB040CA9040CA8030EA5020DA3020FA2010EA2010E9F010B9D020A9C000A
9C010B9B00089D020B9E010C9B000A9700079900089B010A990109990109990109970108
9A010A9B00099C010A9F010AA10108A3020BA7040FA90411A8091499020B9A050EA20611
9B030D8F050C7C00047E03087901047300047803097201056B0204610305580000630203
630203630C082F870200FF0000FF0000FF00
00FF004FAA0E551607542C250D00000B00002202014103034F03024E01014D0101500102
5401005A01045B01035E01025E00016201026201026201026304064B0203380309996B74
8E6269621D24760A1285020B8B020A8D01098E0109920108910106900106940008980009
9D000AAA050EAA040CAA080EA40409AF060FB70610B90410B90510BA0612BA0410B9030F
BB0711BB0812B7060DBA060FBB0A14BB0712BF0C16B90E179C161D3701044C464EC2C5CB
E1E2E6DDE1E5DFE3E6E4E5E9E0E1E5E3E2E7E1E2E6E0E1E5E2E2E5D9D1D0BB9996CC9491
D89B97D59B96DFA8A1DBA39ED69F9AD8A39ED7A29CDCA9A3D1A6A1C2ABA8BCB8B8C0C0C3
DBDADEE1E1E4DDE0E2DCE1E1DBDFE0DEDFE2DEDDE1DFDDE0E1DBDEBD999F87222DA50B16
B0050FAF030DAC030CAE0911AB050FA8040EA3020CA3020DA1030E9C01099E030B9E020C
9C010C9C000B9C010B9C010B9C010B9A000A9B010A990109970008980108980208950006
9901089B010A9D000BA2020DA4020BA2010AA4020DA7040FA807129C060F8F0109980911
9101088D03097C00047A02077C030A7300066F01056B0204690204680405600102630103
63010268100B31880300FF0000FF0000FF00
00FF0050AD0F591D0D5E3C370900000D00002C02014904045002024B00004D0101510002
5601015901045801025D01045E00015E01015F010262010266030461070C752D377C414F
8D4C5B7D202D7E030E89010C8C010B8E010A8F01099100089002068C00059302099A010C
A0010CA8020AAE030CB0040DB2060EB5050FB9060FB8020EBB0511BD0713BB0712BB0712
B90611B80711B80810B90611BA0913C00C18BB0914BA0B15AB131C56060A2B1C21B1B2BA
DFE2E6E2E3E7E1E5E8DFE3E6E1E2E6E3E2E7E4E4E6E3E1E6E4E4E6E3E2E4E2DEDEE7DFDE
E7DFDDEAE1DFE7DFDDE9E0E1E8E1E1E4DEDDE5DFDEE8E2E1E5E1E0E4E2E2E3E2E4E2E1E2
E2E1E3E1E1E4DEE1E3DCDFE0DDDFE1DCDEE0DCDDDFDEDDDFE0DDDFCDB5B88E3940A20F1B
AF0512AD020BAD050DA9040CAB050FA8020EA6020FA2020DA10611A20C159B020C9D010D
9E020D9C000C9C010C9B000B9C010C9D020D9C010C9A000A9A00099B010A99010A990009
9A01089C01099D020A9F020BA1000AA3020AA5030CA6030CA9060EA70A1292040B840208
90080F90030A8201057A00057E02097B020A6D01066200025F0001630103650102670203
6501016C120E358C0700FF0000FF0000FF00
00FF004FAB0E6026175B3C380800000E00012A01014601015002024B00014B0100510102
5C080A5B080A5201015901025C01035E0105630206640104640103620105680B16721827
6F0E1D7A051386020E8C010D8C000A90010A91020892010A8E01058C000592010699000A
A2020DAD040CB1040CB3050EB2050EB40911B90910BB0710BC0612BB0713BB0712B80711
B60610B70711B70812B60610B90911BB0A15B80712BB0A13B7111B7A0A142402098E8D97
D1D4DAE0E4E7E0E4E4DFE3E5E1E2E4E2E2E6E3E3E5E4E2E5E4E4E5E3E3E5E3E3E5E2E2E4
E4E3E3E3E1E2E3E2E3E2E1E2E1E1E3E1E0E3DFE0E2E3E3E6E4E3E6E3E2E5E2E1E4E0E1E4
DEDEE3DFE0E4DDE0E2DBDEE0DBDEE0DCDEE0DDDEE0DFDEE0E2DDE0D8C1C494444BA1121C
AD040FAB020BAC030DA9020CA7000DA90310A5020EA2020DA106119E05119D030E9C000B
9C000B9D020B9D010B9D010C9C010C9B010C9B010C9A000B9C020B9C010A9C010A9B0009
9B01099B00089C01089E020BA1010BA5020DA8020DA9030CAC070EA8060E9D061087020A
86020994040B8E02088501098002097402086B0309600106610204660103690103690102
6703016C120E358C0700FF0000FF0000FF00
00FF0051AC105A1D103F1E1C0800000F00002C03014604034E01014C01034900014D0002
5002064A01025202025701015A02035D020561030761010564010464010369010770010B
77020B82010F8A020F8E020D8E010C91010B8E010991010A8F01059100059601079B0109
A4020BAC040BB1060BAF050BAA0309A80309B40710BA0810BB0610BA0612B80711B7070E
B4060EB3050FB30811B4070FB5090FB3040EB6060FBD0B11BC0F179D111B4302094E404D
B9BCC4E1E4E9DFE3E3DEE2E3E0E2E2E0E1E3E3E3E4E3E3E5E4E4E5E3E2E5E3E3E6E3E1E4
E4E2E5E2E1E3E2E3E6E2E3E6E3E3E5E1E1E3E2E2E4E1E2E3E1E1E3E4E3E5E1E1E5DFE3E6
DDE1E4DEE0E3DDE0E3DADDDFDBDEDFDCDEDFDCDCDEDFDEE0E3DCE1D5B9C1903B44A3111B
AF060FAE030DAC020DAC030EAA020DA7020CA2000BA3030D9F020C9E010D9E020F9D020D
9D010B9E030B9C010A9B010B9A000A9B010B9A010A98010998010A9A010A9B01099B010A
9A00099C010A9E020DA0020DA2010EA3010DA6030DAA050EA8030BA8070EA507109B0810
8C010992040D90020A8A02097E03076400015801055701055F02056602056901046C0203
650200640B074B4E0600FF0000FF0000FF00
00FF0052AE125C1E1042221F0B00001300012B01014201014A01014B02024A01014D0102
661B1F530A0E4F01035002034E03044E02055303075702075F03066802066B0004740008
7E010B89010F8D010E8F020E90010C93010B8F010990020A9001079301069802089C0008
A60309AF040CB2030BAE010AA90208A50208AE040CBA0A14B6040FB80511B80711B5040E
B2030DB1030EB40812B0050DAF050DB60B13B80A0FBD0C12BD0C13B4111B820F19390310
7C6B79C6C0CDE0DFE4E1E1E6E2E4E7E2E2E6E2E2E5E3E2E7E5E4E9E6E2EAE5E2E8E5E0E7
E3DEE2E3DDE4E0DEE4E2DDE5E4DFE6E5E0E6E1DBE2E1DCE2E2DDE3E1DCE2DDD9E1DBDBE2
DBDAE1DCDBE2DBDAE1DCDBE1DDDCE1DEDCE1E0DCE1E2DAE1E0CBD7BD8693901F2CAA0D16
B1060EB0050FAD020EAD030EAA010AA7020CA2010BA0030B9F020B9F030E9D010D9F030E
9D010B9E010A9C010A9B010C9A000B9B010B9A00099A000999010A990109990107980108
9900089B0109A0020CA2010BA4020DA4020DA3010BAA050FA7040E9F010AA5060FA2050D
97030B8A01098703098101057C02066D02065B00035301025801025D0103600102680202
660201600702600F0400FF0000FF0000FF00
00FF0054AF136528194225220C00001800003402024B04054C01014D0101510201500103
5F10145404094C01054300023C02035B1F226223274C080C4C01036001046D0002790109
85010E8C020F8E000C8F020F8E010B8F01098D01078C01088D01089201079501079E0107
AA040CB2030DB4030EB40410B1040EB2060FB4060FB1030CB60710B80612B70610B60611
B0020CB1050EB3050DB0040DB0050DB60B12B70A10BB0C13BB0A11BD0F18B1121D890D1D
5B081C773F56B389A0D1B2C6C7B3C1D1BFCBD9C4D0D5BDCADBBECCDAB8C9DAB7C6D7B1BF
D5AAB8DDADBDDAAABFD7A7BDCE9CB1D7A4B7D19EAFD6A3B3D9A5B5D8A5B7C596A8CB9DB1
C095A7BA92A3B78FA0C59EAFC9A4B4CAA4B4CDA2B3CC98A9B66B7D9C2C3DA50F1BB20710
B2030DB0030EAF0510AA0109AB030AA60108A5020CA4030FA0010C9E010A9D000B9D010D
9E030D9D010A9D020A9C010A9C010B9D020B9C010A9B010A9B010B9B010A9A00079A0107
9A01089E0308A2040CA2010BA4020CA2020BA2010BA6030EA60510A0020CA5040FA6040D
9E040D8701057E01037F01067C01067302066B0006660205620003620306590001620203
6704046A100C691A0F00FF0000FF0000FF00
00FF0054B011672D192F14100D01001A00003801014E03044C01014B00024F0202500104
5102045103054A01024901038030389B4854A4505E9C48554C01035900036F010682020D
89020D8B010F8E020D8D010E89000A8800088B01088C00098D0209910109940106A20208
B1060FB4030EB50510B50512B50510B5040FB80711B70610B70711B80711B6050FB0030B
AD0209B0050DB3070DB3050EAD020CB50710B80B11B80910BB0A10BE0C12C00E17BB121D
AE14239D142A9319349E354FB1556CBA6076C05F75B9546ABF5268BD4A5FB84458B53D52
B6384EB7374EB33149B33049AF2C44B12E44B02C3FB02B3EAF2A3DAC293DA9273DA7273E
A6273FAA2D44A52A40A62E43A73246A83248A83047A8253CA81729AE0B1AB60811B80610
B4040EAF020BAF040DAE030CAB030AA60109A6020BA6020DA4010DA1010C9E020D9D020E
9A000B9B010B9A010A9B010B9C010A9D020B9B010A9B010A9A01099700089A01079D0209
9B00089E030B9E020BA1020DA2020DA3020DA2010CA4010DA90710A7050FA8040FA7040C
A0020B92010A8A020889030A7E02057200037503097303076F01066B03075A01025C0102
640304650D096E211600FF0000FF0000FF00
00FF0054B1126229122A0F0A0D00002101014304044D01024A00004B01024B00014D0103
4B00014901014E000262040871040D7804137A06167A05156D040D6001046E000781010D
87010C89010D8C020F8D020E8800088901088C00098C00098C0108900007960005A40208
B0050BB4050DB3030EB4020EB90611B8040FBC0712B9050EB7070FB4050CB3040AB2060C
AF0709AF060DB1060EB1060FAF040DB2040DBB0D16BE0F16BE0B11C00B14C20B15C30E19
C00E18C0101BBE111FBB1322B91528BD192AC2192AC71A2BC91928CD1828C91825CA1725
CC1725CD1724D01926CD1524CC1522CB1421C91420C9131FC8151DC5141DC2101CC00E1C
C00F1EC00F1EBE0E1DBF0F1EBC0E1CBB0C1BBA0D1CBB0B1ABB0915BB0612BB040FBA0610
B3020CAE030BAC020CAA010CA9010DA6020BA4010BA4020BA4020CA0000A9E010B9C010C
9D020F9C020E99010D98000B9D020B9C01099B01089901079700079A02079D03099C0108
9C01099E020C9D010AA1030DA2020CA3020EA2010DA4020DA8040EAA050FA7040FA4030E
9F020B9801099402098F02098501077801047401047501057502067102056201035D0001
660405660A07701F1600FF0000FF0000FF00
00FF0056B2146C3219260B070E00002702024703045002014C00004D01034D01014B0102
4701024500015A02046E02057401047D01097F010A81010B7C030B6C02066C010881030E
86010D8A020D89010B8D030D8800078B00098D010A8A01088C00059300079C0108A80309
B3060BB4050BB5050FB5040EB6050EB6020DB90510B90510B4040CB5080EB5080DB1050C
B1070EB20710AD030CAE030CB20610B5050FBA0A12BE0E18BF0D13C30C14C20A13C40D16
C20E14C30F14C00D12C40F17C51019CB141BCB1217CC1017CE1119D0111AD01218D01217
CF1218D11218D3141AD3121AD2121AD11119D01016CF0E15CE0F16CA0E14C80F14C90F15
C60914C70A15C90C16C30912C30912C10911C10811C00712C00714BF0614BB0411B6030D
B2030DAD020DAA020DA6000CA6020EA5030FA3020DA1000BA3000CA1000B9F010D9C000D
9E020F9C010E9A010E98020D99020B9B01099B01089A01079701079701089A020A990008
9A01089C010A9D020BA0010AA0000AA3020CA1000AA2010AA6050DA90710A6040EA4030D
A3030D9E020B9901099301078C01078202077701047201056F01046D0205670204630002
6501026506036C191000FF0000FF0000FF00
00FF0054B2137E482B1F0B070C00002801014B04045303024C01014B01024B01014C0102
4501034801026302047402057801037C000681020B84010982030A6C02066401057B030D
84030D87020D88010B8A010B8801078C00098D010A8C00089101089601079E0008AF080F
B1040BB2020BB4040EB90912B4040DB7030EB70610B60410B4040EB4040EB60610B4060F
B0040FAE020FAD030EAE030BB3050EB70711B70711BB0B15C00D16C20C14C30C12C20D13
C10E13C11017C00F16C10D16C61118CA1116C70E13CA0F16CB1117D1151BD01317CE1115
CD1013D21318D6151AD31017D41119D10E16D10F15D00E14D00D15CE0D15CB0D14CD0F16
C80911C80813C80A13C50910C2080FC20910C10711C00711BE0511BA0310B90410B4030D
B1040DAB010CAA010EA8020FA6010FA3010FA40410A2020EA5020EA5010CA1000D9C000D
9B010D9C020E9B020E97000C9A020C9B010A9A000899010998020C97010A950109940008
9700089900099E040D9F0109A2000BA3010DA2010DA3020CA5040DA6070EA60D11A50D13
A1060E9D030C99010A9701079000068700077E0106730105680003640103640103680103
680102650200630D0500FF0000FF0000FF00
00FF0053B3136B381A1905020F00002C00004E03035302014A01014801014B02014B0204
4001024A01036703047702067800037D000682010885010C81030C6802055D000376030C
81010D84010E88010D8B020D8A01098C00089000099202089201089300069B0106AC050C
B0040BB3020CB6060EB5030EB6040FB8040FB70610B5030FB70610B4020EB50410B2030F
AD020BAE020EAC010BAF020BB2040CB90914B70712C1101AC5121CC30B15C50D15C20E14
BF0D13BC0B15BA0A14BF0D18C40F18C91019C70E15C70E16C80F15CE141AD01317CF1216
D01215D41316D41115D61319D41117D20F15D20F15D41218D20F16D00C15D00D16D00E16
CB0B12C90A11C6070FC60A11C2080EC20910C0070FC10911BA040CBA050EB9050FB6050E
B3040CB1040DAC030DA8020DA3010EA1000FA2020FA5030FA6020DA5010CA0010C9B000B
99000A98010B98010B99010A9B010B9A020A980109970108940108930108920208920109
95010B99020C9C020B9D020B9F010CA1020CA3020DA2010AA2060D9D1213A12F29A63E3A
932222900B1295030C9601099200098A01088301087A02076F0104670103660104680104
6A03046A030169110800FF0000FF0000FF00
00FF0054B314622F121C04001800003B03045403035402014D01014A0002480101440202
3600014601026703057601067B010681020683000881010B78040C5E01055A010477040D
83030F89031188010F8A010D8E010B8E01099201089401099401079201069D0108AA030B
B0040CB5040EB6050DB5050EB5050DB8060EB5040EB60410B5030FB60410B5050FB0020B
AC010AB0020FAD020BB2040EB3030EB40610B60611BA0913C00F18C00C13C00B14C20D16
C10E17BB0B15BA0A14C1101AC20E17C50D16C70F16C80F15CC1218CF1218D11217D11118
CE0F14D00F14D00F12D00D13D51217D20E13D20F15D41118D31018D20E17CE0B14CD0B13
CE0D13CA0A11C5070EC60A11C3080FC3090FC20910C00811BB060FBB050EB9050FB7050E
B6060DB0020AAE040CA7030CA1010DA1010DA3020EA3020DA3020CA4030D9F010A9B0009
9B010A9A00099A010A9A010A9B010B9B010C98010A96010894010A92000992010894010A
96000B98000A9B010B9B010A9C020A9D010AA3040DA2040C9A0C10A53F3CE5A9A3E8B4B4
E09AA1A24249870B1290050C8E030A8701088300087E01087600066F0105670102610001
6702026A050379231C00FF0000FF0000FF00
00FF0055B4147341201C04001E01014303045704035401015002024C01014601023E0102
2E00014002036304057301057A01057F01087C020875030960020649000155010672020B
7F010C84010D86000E8B02108D010C8D00089201099201089401079500089E0108A80209
B0040DB6050FB4040CB3040BB3050CB90912B4040EB3030EB3030DB3020EB3040EB0030C
AD020EAD010DAC000CB0010EB3050FB50711B50710B80812BC0D14C00D13C30E15C40D17
C00D16BC0C16BC0D16C01118C10F13C40E12C70F12CB1116CB1014D31318D21116D10E16
D21114D31016D11015D21015D41116D51216D20F13D41118D10E16D00E17D00E16CF0F15
CA0B10CA0B12C70910CA0D14C70B11C4090FC1080FBF060FBC050FBC050FBB030FBA040E
B9060EB10309AE040CA9040EA3020DA0020D9D010A9C00089D010A9E010A9D01099C000A
9C010A9C010A9C010C9C010C9C010D9A010D97000A940109920008910008910107940109
96000999010A9C020B9B01099A00089D020AA1050CA2080F8E1115C98486E0BEC3A67380
802F42C86C7987252B89212383191B79050B7E02087E01077901067300036E0104640002
66010168040175201900FF0000FF0000FF00
00FF0056B4146A35141E03001E00004002035201035100024E0101480102410101390203
2300002C01015003036803066E030571040A6A04095B01074500023F000159020777030C
7E010B83010D87010E8C01118D010D8D010A8F0109920007950006990008A2030AAB030B
B2050FB3030DB2020CB3040DB3060DB50610B2040DB4040EB7080EB1030BAF030CAF030E
AD030CAE020EAD010DB2040EB20310B50711B3050EB4060FB90B12BE0D13C20E16C10E18
BE0E18BF101BBB0D16BE0F15BF0D11C60E13CB1115CC1215CB1012D51318D41116D41117
D41115D61319D31017D10F17D21317D31418CF1116CD1119C91218CC1519CC1318CE1418
CB1015C60B12C60B14C50A13C50A10C3080EC30810C30A12BD050CBD060EBB040FBA0410
B9050EB2030BAD040DA9030EA4010EA0010D9C00099B00079B000A9B00099B00089D020A
9B01099A01089B010A9D020D9D020D9A010A96010792010791000793010893010896010A
97000A9B010B9C020B9B02089A00099B010A9E020A9F0911841318DAA3A9DDBBC67F3747
8B15298C1D2BBE6F75D4999ABD7E8197444872070C7D050A7A01057800037601056D0103
6B0202680201741C152C860000FF0000FF00
00FF0057B4145B22031E01002201014203035001035001024C00024300013D0000390204
2001011E00003701014A01034F01035200074C01083F010535000244000567030B7C020E
80010C84010D88010F8C02108E020E8D000B8F01099301099701079D010AA6020CAE030D
B1010BB0010AB4040EB1030DAF010AB2040DB0020BB3040BB4070CB2050BAF030CAD010D
AE030CAE020EAC010DB0020EB2040EB2030FB0030DB40711B60C13BB0E16BD0D15BB0B15
B90D16B90E17B50912BB0C13BB0B11C30C13C90F14C90F13CE1014D10F16D31117D41217
D11115CE1015CE1219CC141CC8181EBF1C1FB01B1EA81D20B2302FB5332EB22C28B42421
BB1D1EBD1218C10D14C40B11C60B11C50910C1060FC0070FBE050CBD040DBB040FB7010D
B7040EB2030CAF040EA8020DA3000BA2000CA1010A9E01099B010A9A000A9C010A9D020A
9B01079A01079B02099A00089C020A990108950107920006930007940006970108980109
9801099A00099901099900089B01099F010AA1010A9E070F831319DCA6ACDAB3BC792432
94101D8C0F18AF6168DCB2B9683A42B8797F7427297D2023700509780206790104720103
6E01026901006C130B2E870100FF0000FF00
00FF0059B6145A24021B00002600014602035001024B00004601014301014001013D0303
2201011800002501003505033905043903083601092F000436000254010772020C7D010D
80010D83010D86010C8A020C8B020B8D010C8E00099301089801089E0009AA040CAE020A
B00108B1020CB5060EB50510B2040DAC0109AF030BB3030DB5050EB1020AB40610B1030F
B0010EAE020EAC010AAB010AB20710B1040EAE030CB0050EB50C13B80E17B90C15B60711
B70912B80C15B90E15B80A10C31118C50F17C50E14CB1116CF1115D3121AD11318D11419
CA1619C2191CB31C219F1B1E8D1D1F8B3434A46160C38C8AE2B1ACE8B7B2E4AFA8D79992
C77571AF4341AA1E1FBB1518C30D12C30910C0070FC0070FBE050DBC040EBB030FB9020E
B5020CB3040EAE030CA9030CA3010BA1010BA1010A9F00099B01099801099A010A9C0109
9B01089A00089B01099B010A9C010A99000997010A960109960009960108960107970208
96010798020997010999020A9D0109A00109A3040D9C040B881319D79CA2DDB4BD7C2331
950D19900B13974148DEB0B85F2D37935960A37273C48E8F691C1F6D0A0C720305710101
7101036A0001660C052F870100FF0000FF00
00FF0059B7155D28061D00002B01014C04045202014F0102490102460102460101440305
2C02011901003A2120A9908DA9929032161A2902092E00044701056B040D79020C7D010C
7F010C80000C84000B8C030D8A01098A01098D01089101099500089D0008A80109B0040B
B10208B3030AB60610BD0C17B3040EB0020CB1030CB4040EB6050FB5040EB4040FB1020F
B0010EB0020FAE030CAB010CAF0510B30811B40A12B60B13B60D14B50A13B70912BA0C15
B70912B80A14B90A14C00F19C20F19C50D18C60F16CD1419CB1217CA131AC4151ABB1B1F
9F1A1E841B1F883C3DA87173C9A5A4DFCCCAE5DBDBE6E0E0E5E1E0E7E3E1E7E2DFE6DEDB
E6D4D1E1BCB9C37D7BA83334B01217BE0B14C00710BF070EBE070FBC0610BD0612B7010E
B9040FB4020DAE010BA9020BA3010BA1010B9E00089D01089B01099701099A020C9B010B
9A00099800089900099E020B9E010C9D000B9B010A990109990109970108950107920107
9301079401079601099600089700079E030C9F020DA005118B0C17C67E86E4B7BF802B38
920C189309138F3038E4AFB768323D7E464FBA979BB4979B6F4447B5777A6716196B0509
7102056B010270160E2E870100FF0000FF00
00FF0059B8175726071D00002F01014B02025101005000024C01004A0102490201490102
3E02022501025A4247CCBDC6C3B7C038242D2D010844010762020B76020D7D010B7D010B
7E000B80010C83000B89010C8A01098C00098D010A92010B9500099C0009AA030BB4040E
B4030BB4030DB5050FB4030EB3050FB2040DB4040EB6050DB7060EB3030CB3030DB1010C
B1030CB0020EAE030CAA000BAD030EAF040EB1060FB40911B60C13B50812B50710B50A13
BA0E16BB0B16C00D19C3101CC20D19CD1420C81019C8151BC0181CAE1A20921B1D7F2626
8D5654C9ABA9E1D1D0E6DFDDE6E3E2E6E6E6E1E3E5E0E2E5E1E3E6E1E5E7E0E3E5E3E3E4
E2E1E2DFDBDAE2CFCED29D9DA2383DB0161EBD0C16BE0811C00812BB030EBB0410B6010D
B5010CB2010CB0020EAB020EA6020CA2010A9E00099D010B99010A94010995000997000A
9A020C9B010B9A00099C010A9D010B9C02099B00089B010A990109960106940007950009
9601089601079601079501089300089B020D9F020E9F020F950917A44753EFB9C28F414C
900F1B960611841721E09FA9773E497A434DC9AAAFAD9B9E8A7577BA9C9FA97D81722C31
69090E690204741A122E860000FF0000FF00
00FF0058B8175120031E00003201024F02035201004D01014700004800014B01014D0102
51060B481215290811462D3F371D2E37101D601C2463050C70020979010A7D010B7E000B
7E010980000A84000B89010D8A010B8C00098E010A92010B95000A9C000AAC040FB4030F
B3030DB3030EB60811B3060DB1030CB0030BB4040EB5060DB4060DB0020BB1030CB2030E
AE020BAD020BAD030BAA0109AC020BAE040DB20810B60A12B70C12B90B14BA0C15B60B14
BE101AC10F19C41118C30E19C5111BC01019B9161AAA1E21881C1B7E3534AA7F7CD4BEBA
E1D9D5E4E1DFE4E4E4E3E3E4E4E4E6E2E3E6E2E3E6E1E4E6E1E3E6E1E3E6E3E4E7E2E2E4
E0E1E3DFDFE1DFDDDCE4D6D4C29191982B2FB21118BE0912C00612BE0510BA020CB8020E
B4010CB3020EB00210AB020FA6010BA3020A9F020B9B010A99020B94000A94000998000B
9B000D9C010D9C000A9B00099B020B98010898010999010A970108940105940108950109
97010A94010994010995010993000A9A010E9F020EA3030EA009148D1924E49FA8AF6772
87111E970813870C19B6636F985C657C4A52C8ACB1A5949AB9A6AC8F777DB598A0AF8089
782B306203037319112E860000FF0000FF00
00FF005ABA195828092000003701025504055601024F0101480102490102480100500103
550108681D267B424F7341547D46577D34436D0D1971020C7501077901097E010C7F020C
7E010881000A86010C8C03108D010C8D000991010B92000B95010B9C010AAD040FB2030D
B4040EB4040FB4060FBD0E17B1050EB1030DB4040EB4060EB3060CB1040BB4070EB3060F
AD020BAD020BAD040BA90209A80109B00610B30811B40912B50A10B60912BC0C14BB0C15
C0121BC31319BE1217B9161CB51F2495181881231F864740B28E87D8C7C2E4DFDBE5E4E2
E4E4E3E2E2E3E2E3E5E3E2E7E3E2E7E5E4E9E0E1E4E3E4E6E2E3E5E2E3E6E3E4E7E2E3E5
DFE0E2E0E0E2E0E0E0E1DFDDDECECEB172749B1A1FB70D14BE0712BD040FBD050EB9020D
B8040FB2010CAF030DAB020CA8030BA6020CA1020C9C010B9C010B9A010B99010D9C020E
9C000D9D010D9C010C99010A9601089500079701079A0109980208920004910005920007
94010993010A92010993010993000997000B9E010DA3020DA30711940B16A4434FE59CA6
7D1E27871118A83940791B26BD747FA4717BBC9AA4A48C96B69CA5705158BC98A16E3A44
7F2F37610203670C0630880200FF0000FF00
00FF005ABA195E2D0E2500003E03035302025601024E01014601004800014B0001520102
5A02045F030C620D1B671626680D1D6F041376030E7500077400067801097A010A7B0009
7C010680010A86010C8C02108B010A8E000892010994010B98010A9F000AAE050FB3040E
B3040EB3030DB3050FB1030CAE030CB3050FB2040DB4060FBC0E17B5080EB2050BAE030B
AB0209AA010AAA030AAA040AAE040DB20612B10610B30912B20A11B10910B50C12B81117
B31316B11C1A9D1E1B87211E853934A27169C9B1A8DFD6CFE5E1DCE5E4E2E1E2E2E4E4E7
E1E1E2E3E3E7E3E4E7E2E1E6E5E5E9E4E5E9E1E3E7E1E4E6E1E5E6E1E3E4E2E4E5E1E3E6
E1E2E5E0E0E3DFE0E2E0E1E2E3DFE0D1B1B4993740B0111DBE0814BD050FBB030CB7020C
B8030DB4020BAE0109AA020BA8020CA5010CA2010E9D010C9C010A9B00099C010D9C000D
9C000A9C000C9D010D9B010B9901089901079B01099D020A990208940207910106930208
93020A92010A92010992010993000997010B9D010DA1020DA3030E9D0510900E1AB7535F
CB757F924247DB8C9273121E7E1726A24A5C7D3A4AAA7E8A9A76806F474EBE929B6D2F39
610A1066020366080331860100FF0000FF00
00FF005BBC1C5624092A00004503025602035201014A00014601004800014E0101530101
59010162020564010867020B6F010A77010A7A0109760006740107770109790208780107
7B010780010B86010C8C020E8E010A8F000993010B99010C9B020A9F0008AC030CB4040E
B4030DB4040FB1030CB1030CAF040DB1020DAF010AB50510B50710B70911B0050BAE040C
A7030BA4050DA0090CA20C0EA60A0DB10F16AF0E15AD0E13A60D11A81417A418199B1C19
90221C8B382FA16E63C8A9A2D9CAC4E3DFD8E4E4DFE2E3E1E3E4E4E2E4E6E1E4E5E4E3E8
E5E3E8E4E3E8E2E1E6DED9E0DDD6DED3CAD3C3BDC9CACBD5D8DEE3E1E5E7DFE3E5E2E4E8
E1E4E7DEE0E4E0E1E4DFDFE3E0DFE2DBCBCFAB676EA31823BA0914BE0610BB030DBA020C
B9040DB1010AAC010AA70009A6010CA6010FA2010DA0000B9E020A9C000A9C010D9B010A
9C01099D010A9D010C9D010C9B00089C01089D020A9B010A9B030C970108940006930107
93010892010891010890010791010795010A9A000B9E010CA3030EA0020CA00913940C1A
992736B65867C86E7C80111E8604138406176F091AAE717D8E666E895E67AA7E858B545A
5C0A1065030571130D33870300FF0000FF00
00FF005CBE1D4D1A042B00004703025603045001004A00014A02024E02024F0101530002
5A01015F01026001026400036D00077600087B02097500087400087900097A0108790109
7901077E010B85000E8C010D91010A94000B97010B9B010B9D010A9E0008AC050EB4050E
B4040CB1010CB0020CAF010AAF040CB1030DB1030CB50510B5040EB3040EAE030BA9030A
9B030A810409903230953F3B902F2B95292592241F942822912D27963E39984E48AC7269
C59D93DDC9C0E3DDD5E4E3DFE1E4E1E1E4E4E0E4E4DFE3E5E0E4E5E1E4E5E1E2E6DBD8DF
DCD2DADDCAD4DFC0CCE4B7C9E0A5B6C67F93652A414A3445ACAFB8DBE2E5DFE3E5DFE3E5
DFE1E5E1E1E5E0E0E4DFE0E4DDDEE1E2DBDDBD929695232CB20B16BC0710BD070FB8020D
B80410B2020EAB000BA7010CA6000DA6010FA2000BA0000A9D01079C01079B01089A0008
9B01089D01089F030B9D010B9D010A9C010B9B010A99000999030A980109970108960008
9501099401099201079402089301069701099B020B9E010CA2030EA0020CA206119F0511
9706158C06188905178D04128C010D8A020E76040EAF6A72956771A6727F96656F8A5860
722C3260050772150F4B4D0500FF0000FF00
00FF005EC01F4D1C072900004302015301025201005002024C00004E01014D0000520002
5800015C01015F000164010370010878010A78010A7400077400087D020C7C0109780007
7600077E000B85010C8C010D92000A97000B9B020B9D01099D020A9E010AA50109AE020B
B2050CB1020BAF010AB2040EB0020CB0020DB1030CB2020CB2020CB40510AC020AA70209
98050A6401034517178E7576D2B7B6D8B7B2D5B1A8D7B2AADDBDB4E4CDC5E7D8D1E8DFDA
E5E0DEE5E3E1E2E2E1DFE3E3E0E4E6E1E4E8E0E2E7DFDEE5D8D3DBD8CBD5DEC5D3E2B6C7
D792A5C86B80BE4D62B7364DB5253BB51E2FA11F2E44040F686066D2D8DBDFE4E5E2E5E7
E0E0E4E0E0E3DDDEE1DEE0E2DDE1E2DFE1E0CFB8BA9B434CAA111DB80811B8030CB8040E
B5030EB0010DAF020FAD0311A80110A6010DA4010CA001099C00089C01089B0108990007
9B01089C01089C01099D010B9E020D9B000A990009970108970008990109970108960108
95010B9300099401079702079800079B00099D010C9E010CA0030EA104119C040D9A040F
94030D8E030E91031092010C92010A8D010A79030CB66872A86B787429397C34429C666E
8A4B515A040671151061120700FF0000FF00
00FF005EBF1F501D072E00004503015502025401015302014D00004D01034E0101530102
5A02015D01016402046A01057101077501087500077401087400097A000A7E020C7A0108
7800067F010A88010B92030D95010B9A010B9C010AA1010B9E01089D010AA30109AA030A
AD020AAD020AAF010AAF010DAF010BB1030CAE0108AE0207AF0409B0020BAC0209AB030A
A1030A84060D4B010442202A887B88BCB8C2D8D7DBE1E0E0E2E0E1E3E2E2DFE1E0E0E2E4
E3E4E7E2E4E7E2E4E7DEDEE3DAD7DDD9CFDAD6C2CFDCB7C9D69EB1D4869CBB546CB6364F
B91F38C4182EC81225C80D1DCE111DCD1018BF161C70090F351D1FC3C6C9E0E4E5E2E4E7
E0E1E4E0E1E3DFDFE1DCDFE0DCE1E1DCE1E0D5CCCDA867709E1421B70A14B9060DB7050C
B4030CB0020CAF010DAE030FA8010CA5010BA4010CA2020D9D010C9B00099C01099C0109
9C01099C010A9C010B9E020A9D010A9C010A9B010A99020998020899020A970109960108
94000A9201099501089801089800089B010A9D010C9E010C9F020D9E020D9401098E010A
8701087D000481010A8A020B8F020A8B010982040C8D2532AB4B5B7507176E0613A3535E
9347505E04086B0F0A63130800FF0000FF00
00FF0030E0104E19053200004B03025903035901005601014D00014B01024C0000550101
5C01016101016701036C00057102057500067602067500077400067A000B7D010B7D010A
7D01058401098B020A93020C96020C99010A9C01099E010A9E010A9D010AA20209A9030A
AF040CB1030DAF010BB0020DB1020DB1030CB0020BAA0105AC0207AF010AAE030BAD020B
AA030CA2050E8F06106C0714520D206B3F5794778DB19EB1BAACBDCABFCCCDC7D0D1C8D0
D6C7D2CFBCC7CEB8C5D9B6C6D9A4B6D2889EC86982B8435BB3293EBC1D33C71A2CCB1424
D21422D6121FD20E18CE0913D00D13D00E12C91217971017320106939298DADEE3E2E4E8
E0E1E5DFE0E4DFE1E4DDE1E3DBE0E1DCE1E2DDDADBB78A90921C27B20D15B7060EB5040C
B3020CB2020CB0010CAC010AA80108A50009A4020EA1010E9D000C9C010A9A0107990106
9C010A9D000C9D010C9D020A9C01099C010A9B000A99010897010897010998010A960108
9301089301099701089600079500069800079A00099C010C9D010B9D020D95020C8B010A
8A060F7C01097A01098201098602097C020777030979030D8003108803107F030D71060F
700C136A030665060263110600FF0000FF00
00FF0030E0104A16033500004F02035C02035B01015901015101014E0101500102590203
5F02036302046500026A01056F01067601067800057800057801077C010B7C010B7F010B
81010887010B8C020A93020B96010A9B010B9C01099D020B9B01099A00099F0207A70208
AE030BAF010CAF040DB1030DAE020AAC010AAC020AAC030AAD0307AE0208AD020AAD020B
AA0108AC020CAC050DA50813960C1A840C207911297D213A7E2A448F4059AC627ACD8097
C8738AC86B82C15B71AE384FB0273FB61A30C1172CC91526CD131FD4151FD2121AD31119
D51219D30E17D20E17CD0A10CF0C10D10E11CC0F14B0131B50030964575ECACDD3E0E3E6
E1E3E7E0E2E6DFE1E4DDE0E2DCE0E2DCE0E2E0E0E2CDB2B68F3039A80E18B3030EB6030E
B6020DB3020DAF020BAC020AA80108A50109A4020D9F010C9D010C9C01099B02099B0008
9C010A9D000C9D010D9E010C9E010B9F020C9B000997010795000696000998010C940109
9100079201089401089601089600089701089801089B01099E010C9E010E96010C850005
87040B81020A7F040B83030C7C03096300015A00017003098101098A020B830108780105
7201046E0103640100600B0300FF0000FF00
00FF0000FF00521C073A01015202025E01025E01025A0001530000500102500100560101
5E01036000026401046500036A00027700067C02077A01087802087D01097D010883020B
83000888010D8E020D92000B96010A9C030B9E020B9E0209980008940008980008A8030D
AC010AB0020DAE030BAD020AAD020AAC020BAB0209A90107AB0207AA0106A90108AB010A
AA0209AB0109AD030BAF050FA9030CA70410AA0A17AF1422B11728B1182CB2192DB61A2F
B9192DBE182DC11628C81525CB131DCD121CCD0E19D21019D11016D21018D10E16D31018
D10F15CF0C14D10F14CF0B11D10D11D00D0ECD0C10C4171C73090F391D21C5C7CBE0E5E7
DEE2E4DFE2E4DEDFE3DFDEE3E0E0E4DBDCE0DFE0E3D0C0C49A535A9F121EB20512B6030F
B6020CB4010DAD000AAA0009A70108A40108A0010A9C010A9D010C9C010A9B02089C0209
9C01099C01099C01099E020C9F010C9D020D97020B94020892010797020A97020A920108
92000892000A93020A9301089600089600079700069901079D0109A0010D9D030E8F0108
8F050C8001067300037C030A7701076C03065B010264010579020981030A800308780204
7201026D0201640200610B0300FF0000FF00
00FF0000FF00511D073B01005D05046402025F01015A01015301005301024F0000520102
5D01056301046401036700036900027501067B02097500057300077E020A80010A84000B
83000A89010F8F011092000E95000A98020A9C01089C0109950007920009950008A4030D
AA020AAE020BAF040BAF040CAB030AA80208AC030AA70007A60107A90007AA030AAA0009
A80108A60107AA040CAC050CAD040BAF050CB60B14B70D15BC1018BE0F19C5121CC7111B
C8121AC8121AC71016CF1519CD1016CF1118CC1015CA1217CA1517CC161ACB181CCB171C
CA171CC71418CC1A1CCB1617CD1316D01014CF0C11C911179613183203069D9BA0DADEE1
E0E1E4E0E0E4E1DFE4DEDDE2DFDEE3DCDCE1DDDEE1DBD3D5A8747B901723AE0814B4040E
B4030DB2010CAE010CAB010DA8010BA6020CA2000C9F020D9C010B9B01099B01089B0107
9B01099A01099C01099B010B98030D8E030C83030A7E010687030992030C94020B940108
9200069201099201099101079300079601079701069901069C010A9E010C9C010B99010A
99050E90050E7F01067D02077D01057D03087004086000026A03076C0104710205720103
6D0101690201620200630D0400FF0000FF00
00FF0000FF004C15014100016907086702025E01005A0101560000560102510100520001
5B01036101036501036801046900047501067E020A7B010879000780010A84010B86010C
86000989000C90021095011099020E99020B9A010898010A92000991000994010A9D010A
A4010AAA0209AE050AB1060EAE050CAA0108AC0309A70107A70208A80007A70007A70008
A70209A50007A70209A70108AE050CB50A12BB0E14BB1016BA1217BC141BBB171BBC1C1E
BA1D1DB91D1DBD1B1AC51819C9141AC91319BB1113A71717B03630B6423CB64440BA4949
BE4F4EC05450C55A53D15D58C63B3CC4181ECC0A12CB0C13AD131A490204645B5FCBCED2
E1E1E6E0DEE4DEDDE2E0DFE4DDDDE1DCDEE2DADEE0DFDDDFBD9DA188262FAA0E18B3030E
B3030DB1010CAF020DAC010CAA000AA8020AA4010D9F000D9D010A9D020A9D020A9B0109
9800079801089A010B95030D84020973000693262C9C353971060A83040B900109930107
9301069300079301099201099201079401069801089901099C020C9D020C9D020B9C0109
9C020B9A050F90020A8E030A8401067E0206790408660002650104650203620101660102
670101680102630200630D0500FF0000FF00
00FF0000FF005216044E01016F06076801025C00005B0000590100580100540000570003
6002076101036602046800036E00047A010883010986010A84010983000B85020A85020A
8600078A010B90010D97020E9B020D9C010C9A020994010991010791010A90000A99010C
A3020BA80208AE070AAE030AAF040CAA0009A90209A60006A60105A60104A60107A60107
A70109AB040CA80108A90009B0070EB50A12B60F17AF151AA11A1B941E1DA7433FBF6761
BE6F68BC6B66B15451AB3B3AAE2929B11E21971415510303CBA19CE1BFB8E1C2BADFBFBD
E3C3C1E3C5C1E8C9C2EBC1BDE4989BAE2029CB121CCD0B15BE141C6B090E372125C4C4CB
DEDEE3E0E0E3DEDEE2DEDFE3DEDFE3DCE0E3D9DDE0DCDEE0CBBABE8D4048A0121BB0030D
B4020EB3010DB0010DAE000BAD020BA9010AA4010D9F010C9D010B9C01099D01099C0109
99000896010895020B88030A710002760108890D18A22D37A2343B7901078E030B940209
9501069401079301089100069301089300089601099801089E030D9C010A9C010A9C030B
98060E95060E99040D98030B8703077A01047F04097501047201056C02055D0001570001
60020266020263020165100700FF0000FF00
00FF0000FF005415045402016E04046701025E02015F01025901015301005601015C0103
6503076401036601036A00047201057E010786020A88000C88010C82010B800109830108
88010A8E030E8E010A95010C9D050D9C010B9801089401099101079001078D0006950109
A10309A90207AA0404AD0409AC030AAD030BA80108A70007A60106A80108A80107A90108
AB010AAE040DAC050CB0060EB0060EB00B159E1219720F116A2825AA7E78D2B7AFDCCBC5
DDD2CADDCECADAC3BED6B3AFD7A39EBA736D85433F270A0B7A7A7AD9DBDAE1E2DFE0DFDE
E1E0DFE3E0DFE3E0DDEBDFE1E7BFC4A83942C3151FD00F17C6111A8C10162D0307A09EA4
DDE0E4DFDFE2DFDFE3DCDEE1DEDFE3DEDFE3DCDFE1DBDDDFD2C9CD9A626B931420B00712
B4030EB2010DB0010CAD010AAC020AA70009A4010DA0010E9D010C9B010A9B00079C0108
9A010997020A8D030C7601077501068B040D92010D91030E8C08117B0005890309920108
93000794000695010795010897010A96010A9300079600079C010C9C000A9B0008950108
8200037C010490030B99040E8304086B02037604067E03057C0103760205630203510000
560000610302620200630E0500FF0000FF00
00FF0000FF005413025703016D03016601025D01005C02015701005300005600015B0101
5E01025E00016601036F01067401057E010786020C8A020E86010C81000A7D000682010A
8A020D8C010B8F010A96010C99020B9A000B9701079401069101079001078F0107950006
9F0107A80407AA0608AE090DAC050CAC030AAB0209AA0109A60007A80108AA0108AD020A
AC0109AB020AAA030AB30811B20711A10C1962060C442121B0A39EDDD9D4E0E0DBDFE0DE
E1E2E0E2E1E0E1E1DEE3DFDEE3DED8E2D8D1CBBEB8817D7B6C7273D2D9D9DEE3E2E0E2E3
E0E4E3E2E3E4E1E3E2E5E2E3E4CDD0B7626BB51922CB1018CC1319A7131B440206716A70
D0D5D9DEE1E4DEDFE2DDDEE1DDE0E3DEE0E4DADDE0DADDDFD9D6D9B08991881C28AB0B18
B30510B2020FAE010BAC0109AA0209A70108A3000AA0000D9F010C9D010A9B00089A0107
9A000895010A8002096400017D080E91020B96010B96010B90030B7F0105820206900209
9401099501099502089400089401099401099601089701079901089B010A9C010A98020A
8C030B7B010587030A92050E7601045500005A000077020688050A800307680002580000
5901006002025F02006310072C860000FF00
00FF0000FF005311005803026F05046802025D0000580001550101550101580101590100
5900006101026901027201057300007E010683010888000A86010B81000A81010884000A
8C010C90000C94020D99020C9C030C9801099702089300069101078E01088D0005930105
9B0206A50509A50207A80208A90209AA0108AB0209AB0009AA0108A90007AA0109AC010A
AE050CAC040BAB030AB40A12B00D15870C152F00027D7578D3D3D1E0E1E0DFE1E1E1E1E2
E1E1E3E0E0E2E0E1E2DDDEE0DFE1E2DEE1E0E1E3E1DEE0DFC9CECCC7CDCBDDE3E1DFE3E2
DEE4E2DFE3E4E0E3E4E0E1E1E4D9D9C98D92A42028C41218CC1217B5131A61080E3C2B31
C4C9D0DDE2E6D9DBDFDEDFE2DCDFE1DBDDE1DBDDE1DADCDEDDDBDDB99FA3872E39A20E1C
AF0613B20411AE010BAB0109A90108A70209A4000AA2000CA2010C9F010B9D010A9B0008
98010896020C7B050B59000175070C8F030C96020D96010B91030A7B01047901048E0308
9300069401079300069101078E02098E02099302099601079901089B010A9D010B9C020B
98020C8B030A8601068F050C82040A6802055700006E01068A050D850308710102680202
6502026101015B010067160F2A850100FF00
00FF0000FF005514015D04026F03026601015C0000580100540100530002570102590101
5C01006400026C020373010677010480020685020689020989020B85010C84010B87000C
8C010C93020F95010D9B030E9A030B9801089701059400069101098C01088B00068D0004
9401049D0207A00004A50107A80108AA0108AA0108AC010AAB0209AC010AAB0109AD020A
AA0008AB030BAA0108B10710A80A13700810200707A09EA2DFE1E1E0E0E2DFE0E2E0E1E4
E1E2E5E1E2E4DFDFE3DAD7DFCDC3D1D7CDDCDFDEE7E0E4E9DFE3E5D8DBDEDCE2E2DEE2E3
DEE4E4DDE1E4DDE2E2DFE1E3E3DEE1DCB5BB9E3239BE181ECA1215BB11157D0E1526070D
9EA1A8D8DDE1DCDEE2DBDCE0E0E1E5DEDFE3DBDDE1DCDCDFDDDCDECBBCBD934F5695101D
A90613AF0412AE020FAB010CA80009A60109A5010BA3010DA0010DA0000C9F010C9A0009
9B010B97030C79040A5000015D020681050D8D020A9001098A03097101036F0104890209
9201079501089401088F020980010575020481030791020999010A9D010D9C000D9D000B
9B020C91030A87020884010687020A82050E6801046C010484050B7F02067402046E0303
6B02026301015B010066160F2A850000FF00
00FF0000FF005A17016003027003026701015E02015902015401025101014F0001590101
6502026901046D01047201057601057F010884000788010884010B7C020C7B020C83020C
8B010B92010C95010D98000C98010A9B01099701089402078E01068A01058800028B0103
9301069C0107A10006A70209A70208A80108AB030AAE030BAE020BAF020DB1040DB1040A
AD0208AC0209AF040CB30711A6091469070E220C0EA7A6AADDE0E1DFDFE1DEE1E3DCE0E3
DBDFE2E0E1E6D8D1D9C39DAE904A63782F4D8C617AC2B7C8D9DCE5DDE0E5DFE3E6DEE2E5
DDE1E4E0E4E7E0E4E5DFE4E4E2E4E5E0CACEA55158B31A21C61114C00E139A151C330005
6F6D74D0D6DADDE1E4DADCE0DCDCE0DEDFE4DBDCE0DCDDE0DADCDCD6CED1A4727A891624
A60917AB0310AB020FA8010CA8020AA6010BA5020EA1010D9E010C9D010D9C010C97000A
9A000B98020C7C030A4A000143000362030A79030B82040B7A070C5E020463010485030B
91020994010896020A9102098202076C01026D01018802089601099C020D9B010D9C020E
97020D8A01088303097E010685020889030B7B04097301057D0408710001640001600100
6801026702015E010067160F2B860100FF00
00FF0000FF006119016503017604046801015D01005900005501015001014E0001580101
6702056B01066E02066F00027300057E010A84010A86020B7702086100035D010477020B
8A020D93010D96020D9A010D9B010B9B010B9601099001078A01058800068801058B0103
9101039B0006A60209AA020BA9020AAB010AAB0209AC0108AF010AB4030EB5060EB5050F
B10309B1040DB1070FB10711A609156E08111F070C9B9BA1DADEE0DFE0E2DCE0E3DBDFE2
DEE2E3E2E1E6D9C7D09B4D5FAA2035B11C358C1730601F38907E93D5D6E1DDE2E6DFE3E6
DEE3E6DEE3E6E2E6E7E0E4E7E0E4E7E4DBDEB77A82A72029C41217C40D12B0151C520308
4A3F45C0C8CEDAE0E3DADDE1DBDDDFD9DCDEDCDDE1DCDDDFDEDEDFDEDBDCB2919882212E
9E0A18A80410A7020BA7010AA7010BA6010CA4010CA0010C9E020C9C010A9B010B9B010B
9B000B9B010D8B060F5402053100013F00055201075802084E02054000005B010584020D
91010A91000794020896020A93030B86040A79000489020897020B9A010B9C020D9B010C
98020E8601087D01068304098702068D03088001057E030589080E7801046601015E0001
630101690203620201620C062D860100FF00
00FF0000FF006C1F066E07027703026800005D00005A01005601015201005201015A0103
6502056A01066A01046C010375000680020B87020B89040D7602085D01055200026D0109
89020C96010C98020B9B020A9C01099A010B9601078E01068801078900078A0206880002
900104970105A3030BA9020AA80108AB0209AD030CB0030CB2020CB70511BB0A14B4020C
B4050DB4050EB30911AD030EA808137E0D17210004838489D5D9DBDFE1E3DBDFE2DBDFE0
DEE2E3E3E2E4DECACFA6545FB31825C5121FBF1621A0192C4E0B206F6475CFD5DCDDE2E5
DDE3E3DFE3E6DFE4E4DFE1E5DDE0E3E2DFE1CFA7AC9C2931C3161CC80F15B91016750C10
291013A6ACB1D8E1E3D7DDDDDADEDFDBDEE0DBDCDFDCDDE0DADBDDDBDADDC4B1B7873B46
960E1BA4030EA9050EA7010DA7000CA7010BA4020AA1010C9E010C9B000B9A010B9A020C
9C020A9D020B92050E6704093801014212153A070B2E000429000233000160010789030C
93010B9100069201059501069501069001078B01078F01079601089801099C030D9B010B
9A020D90030D7E00048102068A02078702048002048102058B070C8002057202016A0101
680101670001630201610A052D850100FF00
00FF0000FF006C20066F08017704026A01015E01015A01015701005400005301005B0101
6301036601036700016D000177000381000887000A8B020C85030B7B040D6F0208770108
8D020C97010D9B020C9D020C9C020A9D020C9602098C01078700048901078D02058C0104
9002069300069D0107A6020AAA030AAC0209B0040CB3030EB5040EB5040FB60410B3030E
B3030EB2040EB20710AD030EAC09118D0E18310106625F67C8CDD0DDE1E3D9DFDFDEE2E5
DDE1E2DDDEE1E0D5D8B26F78AC1B28C40F1AC9121ABD151F8711212D0918A7A9B4E0E4E9
DFE3E5DFE3E6DDE3E3DFE2E5E2E3E6E4E2E4DEC3C7A3444DBA1820C70E13C00E13971419
3100037B7B7FD2DBDCD9DFE0D6DADDD8DCDFDADCDEDADDDED8DCDDD8DADCD2CACD945E66
8C1421A50715A6020EA4010CA6020BA50208A2010AA0010C9D000B9B000A9A0009980108
9901089C010A96030C800B10540B0DB58689A4808424070923000041000270030A8C0109
9101099000059301069501069401049301059401079601079701079A010A9B010D9C010E
9A020C94020C8401068001048602077E01027900027B0104770103790305750203710202
6C0101690101660202650D082B830000FF00
00FF0000FF00631B027108037A03026D01015F01015A00015500015301005301005B0101
6101026501026901027101027A01038000078601078D020D8B010A85010A82020A85010C
90020E99020E9B010D9B010B9C000B99010A9201098B01088801058800048A00028D0006
9101089400089A0007A60209AE030CB0030DB2040EB4040EB80410B8040CB7060FB4020E
B3030DB2030FB1050FB50B14AF0A11981019430207413940B9C0C4DEE3E6DCE0E1DDE1E2
DCE1E4DBDEE3E0DCDFCA9CA2A42833C5141ECD121BC8121DAB172243020D635A68D7DCE3
E0E4E6E0E2E6DDE3E4E2E6E9E1E4E6E3E3E5E5D6D7BA7278AD1C25C60F17C30B12AC121A
4F020853494EC9CFD2D8DCDFD9DEE1D6DADDD7DBDED6DCDFD7DCDED6DADBDAD6D9A9838A
811926A00917A3010EA4010BA30109A3010AA1010C9D000B9D010A9D020A9B0108980006
96000799000A98020C8B0710A2434B793C4585555F420F154901046C030887030A910109
92010890010790000694000696010696010597000597000598010799010B9B000C9C010C
99010B95020B8402067D02048102067C02047900047F03097401047302047102026D0201
690101680100630100670F092C840000FF00
00FF0000FF00681C037006017B03026D00006100015C00015701005401005201005A0100
6101026401026901027002057601037E01078601078C020C8D010A8700078600098A010C
8F010C97010D9C020E9E010E9F010D9B020B9401098E01098C01068A01048800048E0209
910009940109980007A6040CAD040FAE020EB1030DB4040EB8040CB90509B5030AB2010A
B1010BB1020CB3050FB2040FB0080FA20D175D060F24141BA3A8AEDBDFE2DDE1E2DDE1E4
DAE0E0DBE0E3E1E1E4DCBEC3A8454DBE1B24CD121CCE111CBD161F6B0A133A2430C8CDD4
DFE5E7E1E4E8E0E4E7E3E4E8DFE2E4E0E3E3E6DFDFC49296A1252CC5141CC70D14BB131D
6F0912321B21B1B4BADBE0E3D9DDE0D8DBDFD7DBDED8DCDFD6DBDDD4D9DBD9D9DBC0A7AD
7F2B36990C19A4020FA4010BA4020AA2010A9F020A9D010AA0030D9E010A9C00099A0008
9901099A010C9A010C95030E90121EA3404CA44A588825327C050F8C040C910109920108
91000591000693000793000695010797010899010898010998010A97010B9B010C9C020D
98000A9201078001047300027902057500017E020584020A7E0108710104650102630101
660100660100620100660E092D850100FF00
00FF0000FF007223057909017E03016F00006201005E01015900005800025801005E0101
6501016701016800016D01037200047C01078501088C020C8E020B88000A8700098C010A
91010B98010D9D020FA202119F010F9D020C97020B9100098D00068B00058B00058E0008
910107930109950107A0020BAA040DAF050DB2040DB4030DB8030BB8050BB7060CB2040B
B1010BB4050FB3050FB4040FAF030DA3061175091421020A84878ED2D7DBDDE1E1DCDDDF
DCE1E1DDE2E5DDE0E1E5D5D8BC757AB22029CA131AD01219C6151B8F121A2F0610A8A7AE
DBDFE3DADFE3DDE2E3E1E3E7E0E1E4DDE0E1E4E2E4D7B6BB9C343CBF1821CA0F16C01017
870D162A020984848BD4DBDEDCE0E3DADDDFD8DADDD7DBDED8DCDED7DBDDD8DBDEC7BBC0
89485191101CA30511A5030EA2020CA1040C9D010A9D01099D020A9D010A9D01099C010A
99010A98010A98010B99010D95020F8D05138A08178D061492030E93010B93010B930109
9300079300079501099301069200059501099801099901099A000A9A020B98010A9A010B
98010A93010A8A030A7901037C03077901037C02048202088102087603065F01025C0202
6903026A0202620100630A052E860200FF00
00FF0000FF00701F047B08018104017301026200005D01005B01005C01015D0101640101
6902036B02036801046B01047101067C01078501098C010C8C000B87000988010A8F000D
93000C98010CA00311A0010F9F020E9A000B9401098F01078C00058C01088C0108900107
92010A95020C94010A9B010BA6050CB0060EB3040EB70410B8030CB7030CB4030BB2020C
B3040DB2050EB1050EB20610AC030EA706128B0E1732010850505ABDC5CBDBE2E2DDE1E2
DDE1E2DADFE2DDE2E3E3DDDED5A9ACA62D35C81B21CF1218C81316AC1A1D4503096F676F
D4DADDDBE0E2DDE3E3E1E5E8DFE1E5DFE0E4E1E1E4E4D0D5AD5D66B31A26CC141AC61117
A4161F3E0107625C62D0D7DADADFE2DADDE0DADDE0D5D9DCD6DADED7DBDFD7DBDFD3CED3
996B74861520A20814A60611A3050FA1030DA1020DA1020E9F010B9C01099C010A9B0109
99010C97000998010A99010A98010B95010B95010C95010B96010A95010993000894010A
92000893010895020A9201088B01058C020893000999010899010797010797010998010B
97000B9300088E02098201058002068003067702057001067603077503065E0102550000
6602026A0202660101610702550A0100FF00
00FF0000FF00701C037C09018102027000006301015E00005C01005C00015F0202620202
6802026901026501016900047200067E020885020889010B8B020C8B000B8D010C93010E
93000A98000B9E010B9E020D9B010B94000B9101088E01098D02098E01098D000691010A
92010893000A94020C97010C9D020BAD050EB3050EB5030DB6020BB7030EB3020AB3030D
B1030CB0040AB0060CAD030CAD040FAA0411970B164A050C2F262EA3ABB3DAE1E4DBE0E3
DBDFE2DCE0E3DFE4E5E3E2E4E0C8CCA94D54BF1E25D0131ACF1419BF1A1E6D0C13402A34
CCD3D8DCE4E5DCE2E2DFE3E6DEE2E3DFE2E3E1E2E5E7DEE2C88F99A7242EC6141BC71015
B1121B5B050C403035C0C5CADBE0E4DBDEE0DCDDE0D7DBDED6DADDD8DBDED9DCDFD8D7DB
AA8C9380212E9D0C19A30611A2050FA2030EA3020FA3010EA1010C9D010A9B0109990109
99020B9901099A00089B010A98010994000793000895010A94010B93000A950108960107
9401089401079200059002088200027E00028F020999010A98010796000597000897000B
98010B9501089002088101057A00047D03086B02045300005A01016D04056602035B0001
650203690102660001640904590B0100FF00
00FF0000FF00771F028009018203037300006500006301025D01015B01015900005D0101
6501036600026300006801017201047D01078200068700088D020C8E000B8F020B92010C
93000A9B020CA0020B9E020D97010A93000A9102088F010A8D01088F020A8B0005900209
91010894010897010A96020C970009A20209AE030CB5040EB4020AB3020BB4040BB4040E
B2040DB2060EB1060CAC010AAC020DAB030F9A061064070D1E080D8B9099D7DCE1DCE0E3
DBDFE0DDE1E4DEE2E5E2E2E4E4D8DAC68589B32429D0161ED11219CB171E97151E310510
ACACB5DCE3E6DEE4E4DFE3E4DEE2E3E1E4E4E0E3E4E5E3E5D6B2B7A0343DC21923CB1219
BC10197F0E172D0C11A5A9B0D8E0E3DBDFE2DADDE0D8DCDFDADCE0D7DBDED9DDDFD9DBDE
BBA7AD813340970D1DA40613A2030EA3050FA0000FA1010E9F010B9C01099C0109970009
98010B99010B9A020B98020A97020993000794010A94010B94010A940209930007940107
9401059200049201059101058C02078601058D0106970109970108960107960107970109
98010A97010A8F01058301047500047201057206096204075500016303056A0306630102
6802046A0103660101660B065D0E0400FF00
00FF0000FF00792003830A028403027500016901006802036202025C01025B0101610102
6701046B02046701016800017000027D000687020C8A000C8E010D90030C8E010A91020C
93000A99020BA0040D9E030E95010992000990010891010A9000098F00098F0107920007
94000799020B9C030D9A020E98020B9B0007A7030AB2050EB1020AB2030AB2030CB0010A
AF040CAE050CAB030AA90109AC040CA70209A1060E83101826000563626EC2C8D0DADEE2
DBE1E1DEE2E5E0E2E3DDE0E1E1DDDDDDB2B6AB333ACA1921D4141AD2171CB71C234D030B
726771DEE2E4DFE5E5E0E4E7DFE3E5E1E5E6E0E4E5E2E4E5E8D2D6AE5862BB1F2BD11620
C8121C9D141D36000784858CCED8DBDBE0E3DADEE1D7DBDED9DDE0D4D8DBD9DEE0D7DADC
CDC2C791545E901321A50615A5030FA5030FA1010DA4040F9E010A9B00099B000A9A000A
98010A96000A93010994000895000895000795010B920009920008940006940006910006
9100069100059101059101069001078F0107900107930108930007930006930106960107
9801089701079201068C02067C02046E00027301057505085F00015B0001640103690004
6C01026D0202680202670D0860120900FF00
00FF0000FF00792104830C028603027801016B00006701006200005E01015F0101660103
6900046D01046B01026C000375010680010A8A020C8C010E8C010C8F020D8E010C90010B
92000B97020C9B030C99010D92000A92000A91000A93010B92000B93010B93020993020B
96010A9A010B9E020D9E030F9D050E9D010AA5030BAF050FB1030CB1010BB2020CAE020B
B0080FA9030BA60108A40007A50107A70208A203098D0A123B0207322C38A6AEB7DBE1E6
DDE1E3E2E4E7DEE2E3DBE0DFE0E0DFE7CED1B75962C5202AD6161ADB191ACE1F237A0E16
4B333BD8DADFE0E4E6E3E7E8E0E4E5E4E6E8E1E4E5E0E2E4E7DDDFC48690B32833CD161E
CF1219B81A2254040C61565EC8D0D5DCE2E5DCE1E4D8DDE0D8DDDFD9DEE0D6DCDFD8DBDF
DBD4D8A47981841624A40918A70310A6020EA5020EA4040E9E00079C01089C000A9D020C
98010896010995000A97010B98010A97010A95000A93000A9100089200089200078F0005
910006920106910105900106910108910107910208900209920209920107950209970108
9802099401079101068B01038303057A01057C01067E04066F01016502036602036C0304
6F02046E01016A010266090663120A00FF00
00FF0000FF00782403850D028A04027E0103700100690101650101600001600001670105
6A01056D01056F02057101067400057D020985010C87010C87010A8C020E8C000B8E010A
91010A95010B98020D94010B91000992000A92000A93010A92010A93010B94030A92000A
95020C98000C9C010C9D030D9B010B9C010B9F0109A8020CB30710B2020CB4050EAC010A
AC040DA9030CA40208A40108A80209AC030CAA050DA00D165D070F201019929AA4D9DFE5
DEE3E5DEE2E3DBE0DFDFE4E5E0E2E2E9DBDED49197BC2A33DC1E21E51C1EDC2025A61923
3F0A15C2BDC2DFE3E4E2E3E5E2E3E5E3E4E6E5E7E9E2E6E7E6E2E4DFB4BAAA343ED01E25
D9151BCA191F770C133D242BD0D6DBDCE3E5DEE4E5DBE0E1D8DDDED9DEE0D9DEE1D7DBDE
DDDCE1C2A4AD872936A30D1AAE0814AA0310A6010FA3010CA2010BA0010C9C010B9A0008
9A00089801099700099B010C9B010B98010A96000A94000B930109920109910107920005
9201069201079000068F00048F01059000088D030A83010586010691010A96010A950008
9400089401099203098502057601027A02048302078402087A0103700203650102630101
6D01037002036B0101640301630F0700FF00
00FF0000FF007B2304860D038903038002047301016D0101670101630102610102640003
6500036D020570030671000672010578000680010A82010B80000887010A89000A8E000B
92010B94000A94010B91020B8E010992010892010892000A92010892020B910208900109
94020C97010C9A020B9A010A9C020C9E010C9F010BA6020CAE030DB2030DB3040FAC0209
AA040CA8030AA6020AA40106A80108AF040DAD030DA909157B0812240109727682C8CFD8
DDE2E5DEE2E3DFE5E3E2E6E7DFE4E1E9E3E1F6CBCEC24B51DE2A2FED2729EA2B30D02F3A
67111DA18F97E4E7E8E6E8E7E4E7E7E5E7E9E6E7E9E6E7E9E6E5E7F4D9DDC1616AD82D34
E61D22DC1C219D161A3A0A10C5C5CBDDE4E7DEE4E6DBE2E3DADFE2DADEE2DADFE2D7DCDE
D9DDDFD3C2C7934751A2131FB10812B1030FAD0410A7010EA6010CA4000D9F000B9D0008
9C01099A010A9B010A9B000A9B000998010997010A97020A96010A930209930008930108
9200079100069000069000069101088F01078C02087F01037E000490020C9A020C9A010B
96010A9301078E01068101046D0001730103840207820105780103710304670204620001
6C02026E02016B0101660201600B0300FF00
00FF0000FF00822809890B038C03048301047601016F01026801026400036101025D0001
6101016A01056C01036C00056E00037600067E020A80010C7E000884010988010A8E010E
92020C92010C90000C8E010C8B0109900009900009910009910207910208910208900009
93010B96010C99010D9700099D020DA2020EA3010CA5000BA8010BB1040EB30610AD020A
AE050DA80007A70108A80108A90108B1030EB1020EB208159B101B45030E4D4552BEC3CD
E0E5E8E2E6E7E0E6E5E3E7E8E2E5E6E7E5E6F6E2E3DA8F91D34F51E15050E65D60DC626A
A95D65B19DA2F4F4F4E6E7E9E8EBECE7EBECE7EBECE7EAECE6E6E9F7EBEEEEACB2DD454B
F53133ED2728C9262854030CAEA2AAE0E5E9DFE6E9DDE4E6DDE1E4DCE0E3DBDFE2DBDFE2
DBDFE2DDD3D6AD6F79A11A26B70915BA0612B70511B50511AF050FA8000DA6020EA2010D
A0010C9D000A9B000A9B000A9B00099B010A9A000A99020B970109970108960009930108
9201089201089101079101079201089101079001078D02088B000894020B9C010B9B010A
9701089200058C00048702077C02067901038201057D02047001036501016903036A0002
6E01016D00006A01016605026A170E00FF00
00FF0000FF00862A088C0C038E03038502037601016F01026901016101015E01015B0000
6202036A02066A01036B01056C00057401087D020A7E010B7B00078100098401098A010B
8F020B90000C8E010C8F020E8901088C01098E010A90000990010891010A8F020A91010B
92000A94010B97010A99000A9D010BA2020EA3010EA2000BA4020AAC050EB0070FB2060D
B3070EB1040BB1030BB2020AB8050EBD0711BB050EBD0B13BA18217D132040202DC5C5CD
E4E8EBE1E5E7E5EBEBE4E8E9E7E8EBE9E8EAF0EBEBFBE7E7F9D1D1FFD7D7FFE4E4FFE6E8
FFEFF0FFF8F8FDFCFDF0F1F3EFF0F2EFF0F2EFF0F2F1F2F4F1F1F4F2EFF1FFDADEE7696C
F64340F73831E73835780C158C717CE1E4EAE1E6E8E1E6E7E0E4E6DFE3E5E0E4E6DEE2E5
DDE1E4E3DEE2CF9CA6A32230C20F1DC60916C20614BE0612BB0610B2030CAE030DA8010C
A4000CA1000BA0010B9E010B9C01099A00099B010B9B010B9901099A010A99010A970106
96000697020B93010992010892010791000693010794010996020A99010C9C020E9C010C
9A010A9600079301078F02098601068301068402057B01036C0001630102670202700203
7201017001016801016003016D1E1500FF00
00FF0000FF008125048B0C018E04018302027400016C00016901016502025F01015D0001
6101026502036600016B01046E02047702077C010B7C000A7900077E0009830009880008
8D020B8F010D8E010E8C000C8800088A030A8E020B8F010A8F020A8E010A8E0109900009
94000A9600099A020C9D020DA0020DA3010DA5020DA1000BA1020BA8040BAD030AB70A0E
BC080DC60D13C70C11CD0F15D11117D7171CCE1115D81B1FD72127B9252F651927C8B6C0
F2F2F5E7EBEEE9EDEEEBECEEE9EAECF1F2F4EDEEF0F6F4F4FAF7F6FCF9F8FEFCFCFFFDFD
FFFDFEFFFEFEFEFEFEFEFEFEFDFEFDFAFBFBF7F7F9F5F6F8F0F1F3F6F5F7FFE8EBF08383
FD5951FD4F42F84843A12029916571F8F7FCE4E8EAE3E6E7E6E8EAE1E4E5E0E2E5DFE3E7
DFE1E6E3DFE3E6BDC6AA3441CC1926D00D19CC0816C80714C10511C00712B7020DB3040E
AB010BA9010BA6010BA0010A9C00079B01079D010A9E020C9D010B9C010B9B010A9A0008
9B010A99000B95010A9201099000079101079301089600099A010B9D020E9D020F9B010C
9A00099801079500059001088400058001048302067C03057302046A02046401026D0203
7201017001016801006003006B1A1314C200
00FF0000FF008426078C0D038D03028001027101016B0101680100640101600001610103
5F01016001016401016D01017101027500067B01097900097A01087F010B83010A87000A
8A010A8D010E8D020E8A010B88010888010A8901088900088D02098E010A8F020A8F0008
9701099D010C9F010CA4020DA6020CA9000AAD030DAD030DA90109AE020CB4040DC40C13
CE1016DC171AE0171AE2161BE81D20EB2023EB2225F32A2EF33034ED3C43B03040BE8096
FEF7FEEEEDF0EFF1F3ECEDF1F2F3F5F1F2F6F5F6F8F0F1F3F5F7F6F5F6F8FAFCFBFBFBFD
FBFDFCFCFCFCFCFEFDFBFBFDF8F9F9F6F7F7F5F5F7F2F3F5F0F1F2FAF6F8FFD8DFEC7176
FA514BFC453BF43C37C332397F4451F4F0F6E2E6E7E4E7E9E3E5E8E4E7E9E2E4E7E0E4E6
E1E3E7E3E0E6F5D6DFB54A58CB1F2CD10F1AD10C19D00C18CC0915C60510C50712BD050E
B7030DB2020BAD010CA9020CA300089F0007A10109A2010BA4030DA0020CA0020D9D010B
9C010B9B010B97000993000891010791010995010A99010A9B010B9B010B9C010D9B010C
9900099901089700079301088701077C02057603066E01036F02026D0205600001660001
7201027001016801015F02016F1D18298400
00FF0000FF008D2B0C8F0D038A02017D02026D0100690101640101610101610001650105
6501056601036901037100057401047A01087B02097A010A7701097C000A85010D89010C
8D020D8C010E89010B8A00098A02088900088800088C01098F010992010A900007940006
9B0006A5020AAA040BAC030AB4060FB6030DBD050DBC050DBA030AC20710C60A13CD0B15
DB1319E71B1FEF2023F11F22F52225FA282CFD2E32FD2F34FF3B3FFC3D44F14554B93552
E39EBAFEEAF8F4EFF2F1F0F3F0F0F2F3F1F6EEEFF1EFEFF2F4F4F4F7F6F8F8F8F8F9F9FA
F7F9F8F7F8FAFAFBFBFBFBFDFAFAFAFAFAF9FBFAF9FAF7FAFCF6F9FFE9EFF199A3ED5559
F7463EFB4036F63733CB2F34692431D3D0DADFE6EAE0E4E7E1E5E8E0E2E6E0E2E5DBDFE1
DFE3E6DCDCE1E8D1DAB05363C4202ECE0F1BCD0C16CC0C14D00F18CB0D14C80B12C10910
BE0912B9050FBB0A15B0020EAC020DA9020DA6010DA5010CA5000AA7020CA8040FA5020D
A2020D9E020D9B010B97010A95010993000894000999010D9B010C9C010C9E020E9C010A
9C010B9B010A9900089501078C02077601055E00006101026D03046B0204650103690101
7201026F01016500015A00005F0E072B8601
00FF0000FF008B27098C0B018803017A01016A0000680100640101640001670102660003
6501016801026C01027101057501067C010B7901087501087001087A010A85010C89010D
8B020C8A010D8600098A01088C01078E000991010A94010C96000B9C020D9E030CA10108
A70107AF0208B30307BF080CC5090DCB0C0FD00E11D31014D00C13D20E17D31019D7111B
DA111AE71A23F11F25F52024FC2729FD2729FD292CFC292FFC3134FA2F35F9353DEF384A
D4405BE989A2FFE4F2FFF2FCFFF5FDFFF3FCFFF2FBFFF0FAFFF0F8FFEEF7FFF1F7FFF3F7
FEF9FBFEFEFFFEFBFDFBF5F7FEF2F5FEEBECFEE5E6FFDEE1F9C8CCF0969BF16C6DFC5851
FC4C3FFC4538FD423ADE373A701B26C6BDC6E1EAEDE1E6E9DDE2E5DFE2E6DEE1E3DCE0E2
DFE3E6DEE0E4E3D3DCB56675BB2132CE1321CF111BC90C13C80D14C50B13C10812BF0712
BB0511B80510B70612B50612AE020EAA020DA7010DA8010EA8010EA9010DAA020CAA020D
A5010EA1010D9E010A9C010C98000B96000996010999010B9E020EA1020EA2010CA3030D
A0020E9F020D9D010B9701088E02087F02076902056400036F04066801016501016E0102
7301027101016901025C01005F0D062D8601
00FF0000FF00822506880B028502017800006A0000680102670001690102690102640002
6401016801026B02037001047600097D010B7C01097200056B000479010885010A8C010C
8E020E8B010B8800088B000892010A96010D99010D9B010DA2020CA7010BAB030AB0020B
B5030BC00810C4080CCA090ED30F10DF1817DB1513D81012CF090FCD0812CB0711D10C16
D00A14D30A15E4161FF01C21F11A1DF82223FE282AFB2729FA2C2AFC2F30FC3336FC363B
F63A44EB495BEE7286F38EA5F497ACF492A7F290A2F292A1F295A0F8A0AAFDB0BAFFC7D3
FFE2EFFFEBFAFFEAF8FFDFEAFFC9D2FCAAAFFD9F9FF99090F97F7DFD746EFF655CFF594D
FF5146FF4940FE413BF140447E1724C3AEB8EBEEF3E4E8ECDFE4E7DFE3E6DEE2E5DCE1E4
DBDFE2DCDEE2E7DCE3BF7D8BB12232C91320C90E19CA1017C60C13C60D16C10915BD0614
B90411B70512B50411B2020EB2070FAA0009A8000AA9010EAB0010AD0210AD020EAB000D
A7010DA3000BA101099E000B97010A9202089402089801089E010CA4020FA5010DA6030D
A80611A606109F020B9A01098D01058402057B04086C01026F03056E02046F0103760203
7701027101016A0102610100630D062E8500
00FF0000FF007E2306870A008401007A01016B0000670000670001690102690102620102
6000016700036C01057000067801077F010C7F01087A01057600067E01098601098E010D
90000D8D00088D000791010797010A9D020EA1020FA4010EAA030EB1040FB5050FB8030C
BD040DC2060EC7090ECF0D11D10D0ED00A09D6100DD20A0BCB050BC4000AC6020CC9040E
CE0912CC050FD60C15E7151DF51D23F82125FE2B2BFF3030FF3530FF3631FE3838FC3536
FE393BFB3E46F84C5AF55264F35566F85B6CF75B69F45B67F7646CF5686FF36D7AF2798A
F389A0FE9CBAFC97B3F4879EF07686F26870F76567F8615FFB5B57FF5953FD4D47FC433F
FE3D3BFF3B39F93334EE383F821424997D8CE5E8F0DDE3E7DEE3E7DDE2E5DDE2E5DADEE1
D7DBDEDDE0E4E3DBE2C58B9AA72334C21221C50D1AC60E18C60E18C60E1ABE0714B80312
B80413B60511B3020EB1010CB2050EAC010AA9010BA7000CA9000EAC010EAE030EAB010C
A8010BA6010AA40009A1010C9100078500048D02089801089E010AA3000DA70210A80210
AB0714AC0C15A5080F9A020A8D00068700058202077200026A01036B0204730306790203
7902027001016900016201006811092D8500
00FF0000FF007F2204890C028503017B01026D00016A0101670101670102640102610101
6101016800036E01057300057C010784020B84010783010882010887000A8B010993020D
97061196030D9401099B030B9F020CA3020DA5010BAA030EAF040DB4040FB4040DB4010A
B8020ABE0309C0040AC6050AC90508CD0607DA1512D40D0ECC080DC9060FC9070FC8040E
CE0913CF0B13D50E18E61621F31D28FA242BFD2C2DFB2A2BFC2D2BFF322EFD3230FE302F
FD312FFE3436FD3A3FFB3B44FA3D46FD414AF83C45F93F45FA4449F64349F64651F14655
EE4B61EE4E69EE4B67F14B5FF14554F44149F64144F94342F53C3BF93C3BF83637F52F31
F42A2CF62A2DF0272CDC28308213235E4153CCCEDBDEE4E8DDE2E5DDE1E3DCE1E4DADEE1
D9DDE0DCDEE2DED9E0B18390972131B71120BC0C19BD0B17C4101DC00C19B90615B30313
B40514B20410B1040EB1020DB0040EAD020DAC020DA7010DA8010EAC010DAC010CAB010C
A8010BA5000AA40009A1020C8F01077C000185010698010B9D010AA1000BA5010FAB0513
AF0B19BC1E27A70A12A0060D9402098B02078502087A01066700016401016F0103760102
770102700101690102620101650E082D8500
00FF0000FF00862905860B018203017B01016F0100690100630101600000600001630101
6501016C00047201047A010582010788020A8701078801088A01098D010A92020CA20E19
B11D27A50D19A10610A5040DA9050DA9030BAA030BAC030BAE020AB0000AB00109AD0006
B10106B90107BC0208C80A10CB080CCC0A0DD31614C80A0CC80A10C3080DC60B12C10610
C30712C40712C90B16CD0916D80F1DEB1C29EE1E24F12024F72629F72429F9292AF92728
F82827F92A2AF62A2BF62A2EF42C2FF42C2FF42E30F63234F43333F02F32F33437ED3237
EB3539E7343AE9343DE73137E73236E83438E93738E0302EDE2E2CE02F30E02E2FDB282B
DA282AD9292ECC2327C129307E1D2A3A2030B0B6C1D8DFE3DCE0E4DCDFE2DADEE1D9DDE1
D6D9DDD7DADEDBDAE0A68590831F2DAA1321AC0915AE0813B00814AF0513AE0513A90111
A7010FA7010EA6010CA9030EA6000CA7020EA7010CA5000AA7010BAA020BAC010CAB010D
A6010BA3010AA1010AA0010B97020B8701058A010799010C9F020BA10109A4010CA60010
AA0415B41220AC0D18A60A119A040C8B02097E00047E03077403066800026F0103760103
7702036F01016700015F01006A140D2E8601
00FF0000FF00832504850A018002007901026F01006701016101005F0101610101650101
6700016E01037802067F000783010788000A88010888010B8B010991020C9F0C16B01924
BF2731AF111FA90814AA050EAB040CAB020CA90108A80108AE020AB20109B4020CB20108
B7050ABE070DBF060CC4070DC1050ABA0309B00102AB0103AC0107AB0007AB0209AA0008
AB000AAE020EB20410B2030DB90512C90A19D81620D9151DDC1B21DE1D23E02226E3272A
E32A2ADF2C2BDC3131D83234D43537D83D3CD63E3BD54340D84A47D84D4BDD564FDA5A53
DA6259DE6C63E1716BDF6E6AE0726EE57976E57B77DC746FD46F69C05B56DA736FDC7673
D26E6EC06060B55758A55051854C525F50588C9398D5DCDFD9DCE0D8DCDFD8DDE0D7DBDF
D7DBDFD4D9DDDADCE1AB99A16F293490192599141C990E149D0D15A10C15A20613A20412
A0010E9F010D9E000D9F010D9E010C9E010D9E010C9F010BA4010BA9030DA8010DA70210
A2010E9F000B9E000BA0020C9D020C9201079501089D010AA1010AA40109A30009A6010E
A60111A40111A103119C06108D030B86050E7904097702057F04077600027801047B0103
7B02037201026700015F0100650F082F8702
00FF0000FF008425058509017E02017601017002006901036202005F0101600101640100
6900027201037B01058101088601088801088701088700078A0008980510A50B18AE0F1B
AF101CA70614A90510A8030EA8010AAE020EB0030DB0030DB2020CB6030DBA040FBA050E
B9050DB20107BC0810B9060DB10209A90107A102049C00029C00049D01069C0206990006
9900079C010B9F010B9E000AA5040FA8010EB00915AC111CB2292DB53738C14A48D05E5B
DD706CE4807CEA9391EFA4A3FABCBAF7B7B5FBC1BBFDC5C2FCCBC8FCCFCAFAD0CAF9D3CC
F9D9D1F9DAD4F9DDD6F8DDD9F9E2DEF8DEDDF8DDDCF8DFDBF3DAD5EDD5CFF4DCD7F0D7D5
EFD6D6E7CFCFE6CFCEDDC8C6D4C7C6CBCBCAC6CCCFD7DDE0D7DBDFDBE0E3D8DCDFD7DBDF
D6DBDFD7DCE0D7DBDDB6B2B48467698D53568D46478B3C3D8A30348B282E8A1A22900C16
9A040F9B010C9A010C9A010B99010A97010B97000C99000B9C000BA2020DA2010F9F000E
9E010D9C010C9B000B9B010B9B010A9A010A9B010AA0010AA3010AA5010AA4010CA50110
A502119F000F9B020F8901087500027A030B78080F6A00017A03067D04067B02047F0205
7F03057501026B01016200015E07012E8701
00FF0000FF008223058108027C02007401017001006900025F00015B01015D0201640102
6D01047601047C01038301078801078801068801068A00078F010B99020EA90916AD0914
A70610A1000CA2010BA8030FAB030DB30512B50510B4020EB4030DB4030DB6040CB4050C
AE030BA80108AA010BA80008A101069D02099901079600069301059201059102038E0005
8E010692000A93000997000B9A010D9C0310950715650109864C53D0ABAAEAC8C3F4D4CE
F6DBD7F8E2E0F4E3E2ECE0E1EEE7E6EFE8E8F0EAE9EEE9E8ECE7E7ECE9E8EBE8E8EAE9E8
E9E8E7E8E8E7E8E8E7EBE9EBEAE8EAECEBEDE9E9EAE7E7E9E7E8E6E6E7E5E3E4E5E7E7EB
E7E7EAE6E6E8E4E6E6E1E4E4E2E5E4DEE2E3DBE2E3DDE4E6DADFE2DDE1E4DBE0E3D9DDE1
D9DDE1DBDEE1DCDDE0D7D9D8D3D0CDD1CAC7CDC2BEC9B7B5C5ADADC0A1A2BD8C8F8A2F37
8F08129B030C9C010B98010A94000793010894010A96010C99010C9C010B9D020D9C010C
9B010B9A000A9A010B9901099A010A9900099C01099F010AA3000AA6000DA7010FAA0312
A502109D000D97010B8A030976010578020879040A6E0105720509680203670203770305
8002057A02046B00006200005E0501444902
00FF0000FF008126067E08017801007401017201036901035A0000530000580101620102
6D01037801057F00048501078901068A01068A00048D000894010C9E0410A70612A8040D
A6040EA1020DA2020EAB0512AB030FAE0410AF030FB0030DB2050EAF040DAA030AAB060E
A1030A9B0008A1040C9F01089601079201089101079200088F01078C00038B0103870003
89000690010B94010C9A010D9C020E9F04129A0C1A5F0514442D3BCECFD7E5E8E8EBEBEB
E9EAEAEBECEDEAEDEEE8E9EBEAEBEDEAEBEDEDEEF0EFF0F2F1F2F4F6F6F8EEEFF1F1F1F3
EDEFEFEEEEF0EEEEEFEFEDF1F0EFF1F2F1F2F5F5F6EDEEEFEDEDEEEAEBECE8E9EBEBEBEF
EBEBEFE7E9ECE6E8EBE4E8EAE3E7E8E1E5E6DFE4E6DFE4E8DCE2E4DADFE3DBDFE2DCE0E3
DCE1E4DDE0E3DDDEE1DBDDDFD9DCDDD8DDDDD7DCDCD4D9D9D4D8D8D4D6D6CFC6C88C545D
8A0F1D9D020EA0010C9C010C96010993010793000896000A98010B9A020A9A000997000A
97000A99010A9800099600099501099600089A01099E010AA4020CA90210AF0515B20A19
A804109E010B9801098D01087600037502057E05087301046D03085300004D00006D0205
8002067B01036F01016501006006025B0D03
00FF0000FF007C24057B07017902017301017201016C01035A0101520000560000630101
7000027B00048101068600068901068C01078F010593010797020B9D030EA2040EAC0A11
AD0C12AC0D15AA0F17A70714AA0813A80410A5010EA7020CA7040CA1020A9D01099C040C
8F00078E00069601079601069200059100099101089200089000099100078F00048D0005
8F000797010CA10510A60411A7040FAB0510AB0C17860F20370F1FC4C1CDE7EBEFEBECF0
ECEEF1ECEDF0F0F1F3F2F2F4F1F2F3F2F3F5F4F5F6F6F6F7FBFCFDFEFEFFFDFEFDFFFFFF
FDFEFEFDFDFEFDFEFEFDFCFEFDFDFDFBFBFAFBFCFBF8FAFAF4F6F6F6F6F7F5F5F6F2F2F5
F3F3F5F5F7F8F1F2F4EBEEEFE8ECEDE8EBEDE3E7EBE1E5E9DEE5E9DCE2E8DCE1E8DDE2E7
DAE1E5DAE0E6D9DFE3DAE0E3DADDE2DADDE2D9DDE0D7DCDFD4D9DCD3D7DBD3D1D59B6F79
891424A60615A80110A4020E9B010999000999000A9B010C9C000C9C010B9C010C9B010D
98010D97000B97010A94000893000896010A99010A9E010BA4030FAC0715B6111EC01C27
B2101AA2030E9B010A90020A7801046E00027A04097201046F04066405075600006F0307
8103067C01027201016700006307025D0E02
00FF0000FF007D25067905017601017201017201007103036302025C00016301026E0103
7801038001058200058801088C01088B000791010796020999030997010AA0050EAA0B14
AE1117B41B21B62228A7121CA20814A10311A1030F9D030E9600099100089001088D0109
8700068800069101079400069600059B00099C020A9A00099901089D00099A00069E0109
A2010AA7020CAE040FB40611B70510C10D17C3111AB31C2A58091CCBB9C8F7F5FBEDEDF2
EEF0F3F9F9FBFDFCFFFEFDFFFDFCFEFFFCFFFEFDFFFFFCFFFFFCFFFFFCFFFFFCFFFFFBFF
FFFAFFFFF9FFFFF8FFFFF8FFFFF8FFFFF6FFFFF5FFFFF5FFFFF4FFFFF4FFFFF4FFFFF2FF
FFF1FFFFF1FFFFF2FFFFF0FEFFEEFEFEE8F9FDE6F9FAE1F4EDD9ECEAD8EEEADCF2D9D0E4
D9D5E7D4D3E3D2D4E1D2D5E1D4D6E2D4D7E1D5DAE1D6DCE3D4DAE2D5DBE2D4D3DAB98D9A
8C1829AA0615AE020EAB030FA3010B9F000AA0010BA1010DA2020E9F020D9D010C9D010D
9B010D98010C96000995000895000997010A99010B9C010CA20311AA0917BA1B26BD2029
B2141EA509139B040E8F030B8003087700057C030A6C00026B0103700508670002780206
8402058101017701026B0101670602610F03
00FF0000FF007B21057905017701017400017701027700026F01026A01016E0102760105
7E01058201068401058A01088D02088C01088F020792010A92010993020B9E0713A00612
A20A14A8121DB01F2AA3111E98051197010D96010B95020C8F01098C0009890107890007
8900068F00069801079F0008A40208AD050BAD040AAE0408AE0207B4040CAF010AB5040E
B8040FBC0712C00A13C60F18C60D18CF121FD0151DC91C288C1026A96A87FFE4FAFFE3FB
FFE7FDFFE6FDFFE4F9FFE3F9FFE4F8FFDFF4FFDEF3FFD9EDFFD8E8FED4E3FCD1DFF9CFDF
F6CBDBF2C5D7ECB4C8EAADC1EDABBFECA2B6EA9AAFEA94ABEA92A7EC92AAEB8CA8EA84A2
EC85A4E8829FE8809AE87B99E77797EC80A0E47898E47799E0799DD97AA1D37BA4D184AA
D28EB0D598B6D7A3BFD6A7C3D7ADC9D1ADC6CCADC4CDB2C8D0B9CFCCBBD2D0BCD1D299AD
94172AB20918B5040FB1040EAD050EA7010AA7020BA6010CA5010CA5020FA0010C9F020D
9C000C9B000B99000999010A97010999010A9900099B000C9F010FA60514AB0B19B0131F
A90D199F051191020B8000067F040C81040D81050D750106710103720305700002810206
8801048400027A01016F0001680401600C01
00FF0000FF007A20047805007701017801017E02018102037C02027501017301017A0104
7E01048200048500048A01068D02088B01088801068B01088A01078B01098F010D930210
95031299061798081796041694021293020D91000992010A8F01088E01098E010895010B
9B010A9E0008A70208AF030AB40509BB080CC61212D11918C50C0FC70C12C10710C50A15
BF050FC10712BE050EBF0711BD0511BE0512C40A16C20D1AB10F23AC284BBF517BB64B79
BE4D7CD15787D65A86DD608AE2698CE36A89E36D87E57085E37782E48086E2878CE18E96
E29CA9E5A5B6E3A0B0E398A5E59099E98287EB7478ED6B6DED6065F15B63F15562F04D5B
F14C5AF14C58F24753EF3D4EF03C4FEF394DEC3449EA3148E42D46DC2945D42445CD2645
C42443BE2444B92849B52A4CB12B4FA92D4EAE3B59AB405FAD4A6CB1597EBC678AC85E7A
9E0B1EB30513B4010CB2020DAB010AAB010AAA0109A90109A70109A8020DA7020DA5020C
A2010CA1010C9F00099D01099B000B9B000C99010B9B000C9F020FA30412AB0B19AB0E1B
A60A179C020F91020C7B00076E02066B03087201077901067C02067601037B0103880205
8A01038500027C01027201006C0401650D04
00FF0000FF007720037606007701017A01008201008801038801028001007900007B0002
7F00048601078701058700048D030A8A01088702078603098000057F010781010A85020F
85010F8D03129707159F0C1A97041298041096030D9401099301089601089C020AA6020D
AE050FB0020DBA070FBD070EBE080DBF080CC60F0ECE1614BD0407BC0309B70107B7010A
B5000AB4010AB5000ABA010EBA010EBC030FC10612C30713C60B1BCB132ACD1A36D72442
D92342E62D4EF44160FD536EFF5A6EFE626EFE6B71FF7977FF867CFF9689FFA89DFFB8B6
FFCED5FFD7E6FFD6E6FFCEDBFFC1C5FFA19CFF877EFF776BFF695EFF5C56FF5653FF514E
FF4D49FF4E48FF4542FE3C3DFE383AFF3537FB2C30FA272DF9272FF11F28EC1B28EA1C2B
E31A28DE192BDB1A2ED7172ED0142CCB142AC31225BD1125B71029B31231AC0F2EAC0A25
B30619B6020FB4020DAF010BAC000AAB0009AB0109A90008A90108A9010BA9030BA8020C
A7010DA5000AA30109A000099D010A9D010D9D020D9B000C9E010EA20311AA0B17AF131F
AA0F1BA0051295030E7E01086100014F00005F0206740308790409790205800203880205
8901038601017F01007601016E0300680F04
00FF0000FF007722027306007901027E01008701018D01029001018D0101870102830003
8101038802068601058301048903098801088000047F0007790004780106790007760008
720008840714A81D29AF1B28A20B179C05119A020E99000B9B0108A1010AAB040DB0020C
B3030DB2010CB6040EB7040DB8030CB50106B60203BF0907C00A0BBB0309B90209B50009
B8030FB6010DB9030EBC0410C20814CC101DCD1119CE0E18D8151FE51F2AE9222CE21C27
E82430E42232E32837EB3442F23E48F8484CF5494BF75451FE625CF7615AF66763F1686C
EF6C79EF6C82EB677CEE6578EE5F6BEF5356F54E4BF64742F63F3AF93A38F83636F93333
F93231F73030F3292AF02526F02425EE2223EB1D20EA1B1FE5191EE1161CDE141ADA111A
D20F17D1111CD0111FCD0E1CCB0C1AC80A18C50A16C10916BF0817BB0718BA081AB60314
B90514B70410B70511B1020EAC000CAB010CA9010AA90009AB010BA9000BA7010AA8010C
A7010CA6000AA6010BA3020A9F00089E01089C000A9C010B9E010DA20210A40413AB0D1C
A80B1AA3081695020E85010976040B5B01035801036100026200026E01047F0206870104
8801038701027F01017801017307026A1103
00FF0000FF007828077407007D01008601028E02039102029601029801039502058B0003
8401038602068202058102078101088201087F02057C01067A00057B00067D0209790109
75020A7E0410A31D2AA6131FA00A169C04119C020E9F030FA0020BA4010AAA020AB0010B
AF0009AD0008AF0109B2010BB4010AB80309C00B0BCE1814CF1A18C30C11BF0911BB0712
BC0814B90611B80510B80511B4030EB80612BC0812BE0711C50A15C80B16C70D18C20714
C40D1BBE0918BD0A19C3111DCE1925DC222EE62833EC2C37F4353DF6393FF83C41F73F42
F84046F93F4BF73C47F3363EF7383DFA3A3BF83835FB3632FA2E2EFC2C2DFC2B2AFD2C2C
F9282AF01F23EE2023EB1F20E71C1EE31A1DE0181EDA141CD31019D11018CF0F18C80C15
C60E19BE0A17BC0916BC0915BB0713BA0713B50310B20210B20312AF010FAD010CAD010B
AF030DB1040FAF040FAA020CA6010BA6010CA7020BA6010AA9030EA9020FA8010CA6000B
A6010AA6010AA30109A1020A9F02099E01089D00079E010AA0010CA0000DA20111A20213
A003129D021196020F8F000B8B040D7503076401026602046301036901037C0205850203
8701028501027F00017801017106016C1502
00FF0000FF007829097505008101008A01019001009200019902039C01049D0306960307
8701037C01037800027B02057B01057D00067B00037C000680010785010987020A900812
950E1988051295101B96071494020D95010C96010B9B010CA1010BA50007A90007B20309
B3030AB00109BB0810B8030DB5040DB7070EB6070AB40709B0060AAC0309A70109A8020C
A4020CA2000AA4020BA3010CA0010AA0010CA5010FA8000DAD020FAF0310B30815B40716
B30716B00615AF0614B40B15BC0E1BCC1626DB1E2BE7222DF02730F62D34FB3838FB3C38
FC413CFC3C3AF93936F93833FB3A34F93933FC3A35FB322EFC2D2BF82726F82724FD2D2B
F42424F12023F22225E71A1DE3181BE1191FDB161FD91621D0111CC90E18C80F1AC30D19
BD0C16B30612B10511B20711B30611AF0510AA020EA9020FA8010EA7010DA4010BA40108
A5000AA6020DA2000C9F010B9C00099C00099D00099E000AA1020DA5020FA6000EA5020E
A3010DA2020B9A01079301069701089C02089D00079F010AA0010BA1010CA20210A30514
9D020F9A000D97010D93010A91020A8203087101037303066F02046F00027A0103810204
8001017F01027D0102790201740A016C1600
00FF0000FF007B2A0D7B08018902028F01029401019501019903039E07089B0708940307
8702057700017300037601037901037C01067C01058001088601088A020C8D020B91040D
93060F8D020D85000989020B8B01098D0008910107990008A40209AD040BB00208B60609
B6060CB2030BB80911B1060EA50109A10109A000079B0007990007960007920007920008
91010790000891000794000B95010B99010E9D010E9F010EA40310A90412AA0411B10818
B20815B50815B80B17BB0C17C00E1BC81321D61A26E7262EF22F35F6383AFB4944F84D43
F64F45F54F46F45148F65149F34D42F64D41F94E41F13A2FF7382FFC3832FB3530FB3430
F8302EFB302FF72B2CF02326E91B20E61A22E41C26E11B25D5151DCF121BCC121BC50E16
C00B13BC0A13B80913B30511B10410AE040FA8010CA6010BA6020CA5010BA2010BA1000A
A2010D9F010D9B000B9900099800089800089701079700079900099C010D9F010E9F030F
9C010C9D010C9401088900039001069801099C01089C000A9C00099D01089C000B9C010D
9B020D97010A9200079101059000078501067700017601027400027600047A00047B0103
780101790101780002730201720D026A1900
00FF0000FF008231117C09018E04039502029A02049B02049705038D05057F02017F0306
7F02067500017200027701057B01047E0107800108810108840106870108890108890007
8B01098B010A8701078701078801078C00069301069B010AA5020AAE030CB7070FB5060E
AB030CA2010B9E020998000792010791000891010A90000A8E00088A0007880006870006
8800078B00088C01089100099300079A010BA1020EA4010EA7020EB30917B00412B70613
C4111CCA141CCF181DD51A21DB1F28D81F29DF262CEF3A3CF74D4BF76057F87364F67D6D
F38879F38F85F5978FF4968EF39085F48876FB846DFC725BFB5F4FFC5449FF4E46FF4A42
FD423EFD3E3BFC3A39FC3738F92F33F62A30F3262DED2227E92226E21D22DE1C22D7171D
D11319CC0F17C60B15C00713B90510B50611B0030FAF020EAF030CAC020DA7010BA6010E
A3010E9E000D9C000C9A010998000799000797010794000693000795000A97000A98010C
98010B9801099201088E000692010898010B98000999000999000999010896010895010A
95010A9201078E01038C01028D01048B02068201047F01047B00047B01057B0104750001
7200007401017401026D0100711205681B00
00FF0000FF00893A187C0B018D0201980102A005079B04058E0504800A0BAB43457B1316
7202047401037200017401037B01047E01067F01067D01057C0004810005870108880109
89010A8901088701078701068702048D01079401089D020CA4020DA8010DA9020CA80410
9A010B93000A8D00078F010A8901088801088A00078D00088D01098A00088B00078C010A
8E0008900009940208990209A00208A8040CAF020DB70612BB0711C10A14C80F18CF121B
DB1A21E9262CF02E31F7383DF73940F73F48FD4F53FF5F60FF736EFF978BFFAF9FFFBDAF
FFD6D1FFDEE3FFE1E7FFDEE3FFD6DAFFC1BEFFADA2FF907FFF786BFF6861FF5752FF554F
FF4E4AFF4947FF4647FF4446FF3A3DFF353AFF3236FE3035FB2E33F82C31EE2429ED232B
E72028E51F29DA1621D61520CE121CC20A16C00915BC0511BE0712BA0711B3020EAD010D
A9010EA5000DA2010CA0010B9F00099D00089A010697000596010797010999010B9A010C
99010B97010895010893010994010A95010C95010B98010B98010B97010C93010B910009
9000088D00058900018A01028B01038B01048901048501058001057B0003790102770102
7400017201017202016F05017216046A1C00
00FF0000FF0094471C7810018C05019C0305A70A0B9905058101019421239A29307D0C13
6E01027B02057A01037600017A00037E01057E01047900027A00027F0105840107850109
8501098701088803098B080E96141897101695061198020F9D020FA204129E020F98000C
91010A8A00078900068E030C8901088C00089000069500079700079800079A01089E0008
A1010AA3020AA50209AB030BB1030CBB0711C70D17CC0F19D5151EDD1D24E72329EE272E
F0292FF63138F7323AF7353FF63744F63948F7414DFB4B55FC5B61FA676BFB7A79F98081
F4858FF48698F38297F17B91F07285F06674F66066F14F4DF84846F43C3CF83838FA3837
FC3939FC3638F93134F92E33F92C31FB2D32F6272CF6272CF4262CED2027E81D27E81D29
E01822DF1823D8121EDB1824D1101BCC0E1AC70A19CA0D1BCA0C19C10612BF0713B80310
B4020FB1010EAE010EAA000CA9010CA50009A000079D00069D02079D01099F020D9D010D
99010B98000896000695010990010A88020B8B020C9A05129D03149B031594011091010B
8F01098C00058701028700028B01048D01048D01048A01058301047D01027C01027C0002
780103720000700200750C037117056B1F00
00FF0000FF00429D02751B02830A019A05059F05079303037C01017D030688050B810409
7000018001048803058101037C00027F01048101048300058100038001058001057F0006
81000889040E98121DA01C28AC2D37A11F29970F1B96061595000D94000C92000A8F0009
8D01078C00078D000593010A96020A9D030BA40209AB040BB1070AB70C0FB3070BBA0A11
B70811B80913B90A14B70811B3040BBD0B14C50F18CA0F1AC70A14C60914CE1019CE0E19
D1131DCF111CD31420D41323D31625D51525DA1A29E82533EF2A37ED2C38F33943F6434A
FA4C55F84B58F54453F33C4CF43948F73943F7373BF43030F82F2EFD302DF92924F92723
FB2A27F82727F42224F21E23F82429F21E23ED191FEC1A20E6161CE2151BDC131CD7121C
D00D18CF0E1ACD0E1BC70915C20512C30815C00614C20715C10713BE0511BB030FBC0411
B80410B7020FB60210B4030FB1020CAD020BA80109A50108A40108A40108A5020DA2010D
9E000B9C01099A01099601088C010A7500037B010A960617A1091DA0091D9C081995020F
9000098C00058801048700058B01058E02059002068C02058401027E00017E0101800202
7D010376010172040179150A671501349000
00FF0000FF004FAF0A9D56287C18078F08049102028902037701017A02038A0307820205
6E00008101059202058F000387000286000290030894040A90050A8602077E01047D0106
81010A8A0311970F1E9D1627A423329C1A28950E1C9106138F010C8F010B92010A93010A
95020899020A9B0109A1020AA7020AB0050EB6080FBF0E13C31214C61919BB0D11B5070E
AD040DA50308A30108A400089F00059F0108A5010CAB020EAF040FB00310B10210B50412
B60410BA0512BD0512C60B19C70B17CB0B17D8131DE1161DEF1F27F6262CF72B2FF62F31
F83736F93A3DF6393CF7383AF73637F93635F83531F7322CFC342CFB3129FB2C22FB2B22
FA2C27FB2D29FA2A28F52222F82324F72222EE1A1BEC171AE81419E61519DE1115D50D14
D00C15C80813C70B16C30814C00713BA0310B6010DB6010CB6020DB2000AB2000AB1010B
B1010BB2010CB3010CB1000BB0010AAF030BAB0109AA010AA90109A8010AA7010CA8020F
A5010BA3010AA0020C9A010992020A7F02077C00079404159D04199D04199B0417990211
96010D9101098B0107870005840105850203890004890104870102840102830202820102
7C010177010174070176170A621500369300
00FF0000FF002EDE0B7F410E6712018309038801027F0102730000750102870405830305
6E00008302069A0307A303089F04079801059902079B040A9202078501077E01047E0107
80010C8C0313950919990E1EA82331A11B29950B1A9003108B01088D000998030E9C020B
9D0208A10209A6030AAA040CAE050DAC020BAD040DAD050CA70408A10306990104970007
9400078E01038F000394010490010493000798010A9D000AA2010CAA0210AE020EB3020E
BA040FBD040FC90B14D5131CD61018E0181EE92022F22A2AF93331F73631F53834F13C37
F2463FF3504BF35955F15855F15652F4544EF65147F64A40FB4B3FF84234F83D2DFD4234
FC4036FD3E36FD3932F9312AFC312AFD302AF62823F82624F62122F31E1FEE1C1BE51517
DE1117D30C14CF0D16CC0B17C70A16C00712BC050FBB050EB7030DB4020CB4020CB3030C
AF010AAF000AAF000AAD0109AA0007AA0007AA0109A90109A8010AA8010CA8000CAA020D
AB010DA8010CA5010BA1020B9A01099101098E00099702109E04159C02169A01149A0111
99020E93010B8D01098502077501037402037E0105850104870104870102870102860102
7F0100790100750A036B1304671B0000FF00
00FF0000FF0000FF008548156312007F0B038101007E01027501017201018506087F0305
6E0001820306A5090DB1060BB3080DAE060CA202079B03088E01058101068002067D0108
83030E88020F920616990F1CA6202A9D14209206108F010C90020C92010A98010A9C0109
9B01069D00059E0004A00105A100059D00069900079600059300048D00038A0002890003
8B00048D01058A00028F00039401069D0108A6030CAA010DB2040FBE0814BF060ECA0A12
D30F15D91217E81E22EC2024EF2527EF2A2AFA3B37F94339FC5246FC5F54FB6C62FA7B72
F58881F59994FAAFACFAB4B5FAB0B0FAA5A3FB948CFD8174FE7264FD6859FD604EFF5F4C
FF5649FF5246FE4D3DFF4C3CFF4939FF4336FF3F35FE3730FD2E2BFD2C28FB2824F6221E
ED1819E6161BDC111AD9101CD30F1ACE0D16CC0D16CA0E15C30911C00710BC040EBB0510
B5030EB2010BB1010BAD0108AA0007AA0108AA0109A9010AA8000AA8010CA8020BAA010B
AC020CAA010BA70108A300079F00079E01089C010B9A010B9C010E9C011199021097010F
94010B9001098B00088201076B00026500027701067F00048401058600028A01028C0204
8702037D0201760B0467110050580000FF00
00FF0000FF0000FF004CAD0D6A1E00790E017E03018201017E03026F0000780505750304
6500007F0304A5080BAD0207AE0308B2070EA9050B9A01078D02077E00047B02067E020A
84040E880310910A1796101C900B148C040D8B02088D01098F020B91010A930208940005
9800069D00079F0004A10005A20004A100049F00069900049600039301009701029A0204
9D02059D00059B00059D0206A50209B2040ABB050DC70B15CF0E16D9121ADE1419EB1D1F
EE1E20F52727FB2B28FD3332FE3B38FF4843FF534AFF6057FF6F66FF827CFF918FFFADAD
FFCACFFFDBE4FFE3EFFFDEECFFD9E6FFD4DEFFB7BAFF9992FE7D73FF7168FD685CFF6255
FD574BFE5749FE5243FD4E3EFF4C3EFE4338FC3A30FF3830FC2D29FE2C28FE2B26FB2420
FB2322F01D1FE8181FE41722DD151FD50F19D4101BD10F19CD0C16CB0C15C30611C20814
BE0713B90410B6030CB4030AAF0008AD000BAD000BAD010BAC010BA90009AA0109AC0008
AE0109AD0009AA0008A50007A20005A10005A101089D00089B00099B010C97010A94010B
92010A8D01088A02068601077703076E00027801047F01048400048801048D01048D0204
8A0102810201780C036D15001DCA0100FF00
00FF0000FF0000FF0000FF00914C177111007C04008803028605047102026802036A0808
5F0000800304AA0F10A90407A50005A70108A9030A9E020A8C01067701036A0104720209
7E020C82010C83020C81010B8401098600078600068700058700068800068A0006900005
9C0109A7020CAF030CB2030AB7050ABA060BB9060BB00209B10709B20A0ABA0E0DBC0C0E
BA080DB8050EB80811CC2027C11018CB1016D00F15DB141BE0141AEB1C22EE1E22F72528
F62426FC2C2CFE2D2BFD312FFE3B36FE423BFA463FFB4E4DFC5758FB5B62F86169F76D7B
F4798AF6849CF2809AF17792EE7188F16F82F9707AF96668F85855FB5653FF5954FD524B
FD4E47FF4D44FD4A3FFB4037FC3D35FE3C34FE372FFC3029FC2825FB2522F31D1AF41D1A
F21B1AEE1A1DE4161DDC111BD8101CD40F1BD10D1ACE0D19C90B16C70B17C20815C00714
C10815BD0512BB050FB6010AB6010CB4010CB4010DB4000CB5010DB6030DB6020AB80309
BD060DB7020AB1010AA70107A20005A20106A301079E01069A0006990008970008930007
9101068C01058A01048901058002057B01027F01048101048301048701038900048B0103
8B02028404027B0E066F180000FF0000FF00
00FF0000FF0000FF0000FF004FAB0D751D007F09019007048F05037D04046A0D0C7E2F2E
5C06048D0C0CA6090AA70305A50006A50107A80108A8060E9402077300025900005E0002
7402097D0209830C11860C14830209820005830105810004810004860208850004920106
A30109B2030EBB040EC0030BC7070ECF0C13D21216C3080EC20C10C50D10C81012C50D11
C0070DBD060FBF0A15B3030CBA0811C30A12C3060ED10D15D00910DA1218DB131AD80E18
DF141CF12127F11E20FA2929FC322CFF3932FD3A33FD3F3CFE4142FA393FFB3C44F73D48
F53E4CF84656F64352F43E4EF63F4CF73E49F94146FE494AFE4645FB4240FC4543FD4543
FB3D3CFD3E3BFD3C37FD3733FC342EFD322BFC2E28FE2B28FA2423F61F1DF6211EF11B19
EB1517E8161BDA0D16D00A14D10E1ACC0B1AC40815BD0815B10713AC0915AA0613B10513
B6030FB90411B6020EB70410B5020DB8030EBB0410BD040DC20712C30611C70811CD0D14
D10F16C90A13BA040DAC0108A40006A50107A100059E02059A0004990106970005950105
9301058F00038E01038B0103860004860105870104850104840104840104840003870204
8B0608820604780D026F1A0000FF0000FF00
00FF0000FF0000FF0000FF0030DE0D782402800E01950D059405018E0709822124ECA8AB
6A1315930D0FA40609A70308A60208A50007A70107AE060DA7080D8500036F0103680002
7101077B01067701037B01058101068000048300058401058401038500048A0004970106
AC040CB7040FC30812CC0A13CF0A13D10C14CE0D14BF060DB7040AB5040BB1030AAF0208
AC0008A80009AA040DA5010AAD0710B90F19B4030FBC0410C30913C2070FCF0E18C80714
CA0511E71B21F21E21F92423FE2F2AFC2E29FB2D27FD2E29FC2F29FA2827FA282AFB2D2E
FB302FFC3132FC312FFD3330FA2F2EFE3333F62828F92D30FC3436FE3A39FE3B38FE3A38
FD3534FD3433FB312FFD312EFD2F2AFB2B26FA2724F62121F62121F21C1DF62222EF1A1B
EE191CE7151AD70D13CA0811C60815BF0715B40615A3030FA7121EDB515DAE26339B040F
AD0411AF010FAF020DB1040EB2020DB7020DC00711C40912C60810CB0A12D00C13D30C12
D40F14CE0B12C10510B2020BA90109A30107A001069C0104990003990104960003950103
9502059302059201049102048D01038D02058C02038700028501038301047E00027F0102
8607088009067D180854540000FF0000FF00
00FF0000FF0000FF0000FF0000FF007F3008871D099717079A08039A080B800D12701A1E
720A0D9207099D0204A00105A30105A60106A80207B3060DB6090FA20207940207870207
7B00037F00048001038402068601068901078E01099002098F01079001079802099F010A
AC060EAC010AB6030AC70A11CB0A0FC9060FC1040EB30008A90007A301089E00089D0008
9A000795000697010995000A9500089E020DA7020EAF020EB3020DBE060EC7080FCC0B14
C9030CE61A1CF01C1CF51F1EFA2523F5211DF7231DFA231EF6211BF8221FF92323F72422
F92622FB2A25F92A23FD2D26FA2B25F72824F32123EE1D22EC2023F32928FB332FFB322E
FB302CF92E2CF92D30FA2D2FFA2C2AF52725ED1E1FE91A1DE7181CEA1A1EE91A1EEB1B1F
E9171BEA191EDD1219CB0812C20512BA0513A704119000099C0A17A00E1FB126368F000B
A1020CA7000BA9030BA90108AE000AB8030FBA010CC10710C30610CE0E16D20F15D10D10
D10D10CE0C13C30812B0020BA80209A100069D0205990104980104980004970104960104
9101048901048E02069402069301049000028C00018A01018701028201047D00037C0003
7C02037B0901771804388F0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00883F0E8C2E119E23109B0A02970404901112962C28
89110C9304039902029B0002A30204A70106AC0107B5040ABC080DB30309B1060BA9050B
9801059001068C01058F02069101079501089801099C050D98020A9701089B02099D010A
A0020AA40108AC0309BD060EC4070EC4060DC70913BD080FAA00069E00049A0005970007
9300079000089101078C00078E000798010AA00008AC0109BB050BCE0E11D6100FE31718
E41615F0201DF6221EF3201CF2221EF72923F42A22EF271FED2921E82921E52C26DE2A23
DF2C24E1302AD52721D42720DB3028D32923D02723CA2220C5221DC4231BCF2C26D6322B
D42E28CD2722C11C1BC82325C82221C62120C11A1ABF1518C51B1FCA1E21C7181ACE1A1D
D51B1FD81A1ED3171DD0161EC50E16BE0C17AB0C158700088C06109A08189A071597010B
A7060EA90209AD0209B00209B9050EBF0711BE060EBE050CBF050EC60610CD0B14D00D12
D10F12CB0B11C10912AE020BA401099D0005980003950005970106960005970106980106
8E02047900018001039201089501079101048C01028B01018801018501038000047C0204
7903037D13076D170238930000FF0000FF00
00FF0000FF0000FF0000FF0000FF00965116792403901B059E1107910301870402961D17
910D079402019801019C0001A30104A90007AF0208BC070CC0090DB90209BE070DC30B11
BB0A0EA70206980004970207990109980108980108990108950107920006950107960007
9D0107AC060EAE020BBA050DC20910C50911C80C13C30911BE0B10B90D10AB0407A10007
9A0007950007920005900004970104A20307AF080AC10F10D61D1AE3261FE72920E5281E
E83024E32F24E03226DE362ED6382FD43F33D44437C63C30C9483CC85244BF5345BD594C
C66457C6685EC26A5EC77064C77165C47066BD6C60BE6E60BC7061B97061B66D61BD7165
BE6F63B6685BB06157AE5F57A85951A5554BA250489F4943A149429E423C9C39339B322C
9D2D27A029259F221DA3201CA21B17A319199A1A1A791312CF787AA240467D0A128E080B
AF1418B30B10BC0E13BF0D13C50E16C20B11C1090EC60D12C2090FC6070FD00D16D00D13
D00E13CC0D13C00910B0030CA3000A9B0108970106960008940007920006970107990107
9103077E01037F00039202099401088F00048C01028B0101890101860101810204790103
7607037E1E0E6D1F0300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A203762801871A03940F058B0201850001870200
9207039601029B0102A10003A90206AD0106B40408C40D0FC2090CBE050BC3090DD11013
CC0E0FC10B0DA801049F00059C01099800089300069300079201088F0007910008990109
A5030AB90B15B80710C10C14C0090FC20A10C40B11BF070DBD060CC61316C31214B50B0E
AE0D11A50C109E0E0E9F1211A81B17B2221CBC2D26BD2F25C13A2DC44033CA4D3EC65141
C65C4CC76757C56D5CC47467C47E72C3887BC18B7EC59588C39C8EC3A393BAA090C0A99C
C2AA9DC1AAA0C6B2A5C7B4A8C4B4A7C3B3A6BEAFA1BDAEA0BAADA0B6AC9FB2A99EACA398
B0A599ACA396A69C91A1968D9D93899B90859D8F879B8A8398887E948077998076987B71
96766C926F638F685A936555945E4E9256478C51447B4E44906F6AA07A785F282473221C
8C231B9218139C1613A31412AC1615AD1010B81213C01314C20E10C90F14CE0F16CD0D13
CE0E14CA0C13C60D14B7070FA5010B9C000B99010B96010B930009940108970107970005
9301068C01058D01069502099201078E01048E00038C0103890102860101800001780101
760B03751C0967210000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028D8067A36027F2203830B03860202870200910705
9606039B0301A10102A60103B00609AD0002B30204C91111C10809BD0409C50B0DD11011
CE0D0CCC0E0FBC070AAD0306A100059C010993010995040E96060D95030C97010A9F010B
AC040DB4050EB7070EB8070FB8080CBA0B0FB80E10B10F12AB1011AD1915AA1C15A51F18
A227219E30279E3B30A14A3EA85649AE6153B16D5EAF7466AC7C6DAB8071AA8575AA8A7E
A78E82A48E83AA988DA89A91A79D96ABA59DAFABA3B2B2A9B2B5ABB7BCB0BCC0B6C3C6BC
CCCDC5D1CFC7CDCDC4D0D1C9CDCFC6CDCEC4CBCCC3C7CAC0C3C7BEC1C5BEBEC4BDB3BBB3
ACB4ABACB4ADA9B2AC9DA5A29FAAA69AA5A1969E9D9097978B93908A918C8A8F88878C85
85888281857C84857C817F747F7A6C80786880796878756776766B747166796E60806859
8763548A5B4D88524487473A8C3F33852C218F251D9F241DA51B15AD1514B61214C01417
C51316C60F14C51017B70710B00612AA06139F010E97000C94000C96020C970108980207
9702099401089401069200059100059001039202049102048B00028801028302027A0201
78100567160133910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00925616782C04720C007F02018B0401960702
9C0702A20402A70301A80101B20808B20406B50304C81010BF0709C0070CC50B0DCA0B0B
CC0D0CCF0F0FCC0D0FC50C0FB8090DA9050B9E090F9D0E15A41418A40E14AB0D15AD0A15
AE0911AF0A11A90B0FA10E109D1310981613941F188F29228F382E964A3D9B5B4B9E6756
9F71629E7769A081709B837497847695837994867E958D8692918894978E95998F999E97
98A0989FA39E9CA39FA4A8A7A6ABA9ADB3AEB3BBB7BCC4C0C8CECAD2D7D1D6DAD4DCDED8
E3E4DEDDDCD8DFE0DBE1E2DEE2E3DFE3E4DFDADBD7DCDFDBD9DED9D2D7D2D0D6D0C6CEC8
C5CBC5C0C6C1BFC6C0ACB3B0ABB4B2A4AEAD9DA6A599A2A1969E9E939A988D938F8A928D
868F8B848D8A838B897D848178807A798279798277768276747F73767D71777A6F7A7B6D
787A6B7574667471647971637E6F617D68588262528A5B4D90514490433A91342E952723
9A1D19A41A17A61415A40C0FB9141BB80B17B50B19A705139C000E9A000C98010A950107
9602089400079301069101059001049201049403049102038C01028801038502037A0101
771206691C001BCB0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B61678390B6810017F0602940B07990200
A10401A80503AE0604AD0403B30606BD0B0CBA0608C40F11BD070ABD050AC3090BC90B0C
CC0F0DD0100FD11011D11013CE1315C51518B01113AC1A1EAE2023AD1D20A8171B9F1418
9414148F191887221E86342C8C4B3F955F54986E6198786B967F729180728F84768C8777
8A88798D8B7E8F8C808B89818C8E868F908C92928F939493929794939C9998A29C9BA49F
9EA8A2A5AEAAA6B0ADB0B8B8B5BEBDC0C7C5CCD5D3D5DBDCE0E4E4ECEDEDF2F4F2F7F7F6
FAFAF9FBFBFAFBFBFAFEFDFDFBFAFBFBFBFBFCFCFCFAFBFBF8F9F9F6F8F8F4F6F6EDEFF0
EEEEEFECEAEAE2E2E0DADAD8D1D2D1CBCDCCBFC5C1B6BBB6B5B9B6B2B5B1AEAEA9ABABA6
A5A6A29B9F9B969D9A949A978D928F868E89848C86848C857F867F7F847D7B8078798075
747D71767C75747A73737A7271796E72786C76786B787568786F617A6B607C655C846258
87594E8A4B438639358123209B2122AE1D21B5181FB7131DAB0712A5020EA0020C960006
9300059301089001068A01038A00019101049303049001018D01038A01038301027B0400
791605378E0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009056236B17028A11069B0C05A10302
A60301AE0606B40907B40707B20502C00F0CBB0808B60407B50207BB0308C80E10CB0D0E
CC0E0FD11012CF0F12CF0F14D2151ACF1B1CBC1D1CA724239F2D2E942E2D8F3330873B35
8D534998695F9A786F917E718D85768C877B89867B8B897E8C8B7F8D8C828B8D838B8E84
8B8E838E8F878F908A8E8F8A91938E959894969996989C9C9EA4A6A4ACADADB7B5B6BEBE
C4CDCCCCD5D6D8DFE0E3E8EDE8EEF3F1F5FAF6F9FFF7F9FFF8F9FFF5F3FBF4F2FBF3EFF9
F2EDF7F0EAF3EAE6EFEBE4EFE9E3EEE5E0EAE0DAE6DED7E3DED7E1DAD4DED9D3DCD3CBD3
D5CBD3D7CAD3D7CCD1D5CCCFCBC4C6D0CDCCCDCBC7CBCAC5C9C6C3CAC6C3D1CBC8CEC5C2
CDC3C0CDC7C3C7C2BEC2BEB9BAB6B2B2AEABADABA7A9A5A0A29C999D969197938C8E8E84
898D8283887F83877F7C81797B81787B83787B8277787E73747B6F767D73767B73757870
737469756C6577645E7C5D5586544B8C423D943230992122A51B1FAD151BAB0E149F0309
9B02079302068901038601028700008D01038F01048F01028C01028900018502027C0501
7D1A061EC90000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A4672D7B2707961E0BA21004AB0A03
B20A06B60907BB0B0ABC0C0ABC0C08BD0B08B80705B00203B40105C1080CCA0D0FCD0F12
CC0F10CE1113CB1314C81619C01C1DB32421A4332C94453F8E5953936D669579728D7E74
8882758B877C8B89818A8B82848A7C8B8D838A8C828C8C828E8F858F8F8791938D92948E
979B93989C959B9F9BA0A39FA5AAA5ACB2B0B4B9BAC3C8CABFC7CAC4CBCFC5C9CFC4C8CF
C0C5CDBFC1CBB5B6BDAEADB5A5A5ADA09DA99B99A79D99A69C99A4948E99948C98948898
9688969A8C99988A969487959589969B8F9B988B958F808891838895878C9284888E7F80
9583828F7C7C8E7C7A8D7C7991827F9086818D8780918983958A869185808E807B8F807A
94847D8F827B958980978B81A0918B9F918CA59891B2A29BB2A29CB2A099B2A299AEA197
A79E92A6A1959F9C8F9B968B9794899390868C8B8086877B82877A80857C7E847E767E79
757F7772787176797376756E76726A7667607B5D5883514D853C388A2C2891211E951313
9F121593090C8902058A01048801018800018700028801018A01018601018103017C0800
791A0400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0050AD0F782704901D04A41303B41006
BE1109C5140DC2110AC3100ABE0D08C30F0DBC0C09B80908C00C0CC60E0EC60B0DC90F13
C61314BF1816B01B189F241F99393298544D966E64917D738A837985837B84857C82877C
83897D888B82888C848B8E858B8E828E8F8692938A92948B9899939B9D999DA09DA3A7A4
A2A9A4A8AEABAAB1AFA8AEAAA8ADAA9EA0A19495978E8F9288898C88878A868585878485
8784858A8687918B898B83828F87858D8382887F7D90868491868191857D90837B968680
92817A9180789B8C869A8D86988D86A19590A0938B9A8B7F9485789B8C7E98897B99887A
9A8978998877988977928273988A7B9E9385A49D8FA69D909D92839A8C7D9A8A7C8B7A6B
8D7C6A8979668879658777628A78668C796A8A77678975658D78688C75658D75648E7765
94816F9586749C8C7CA29283AA998CA8988CA39689A4998C9D968B9A958D92908C8A8B86
868A8181867B7C81797C817B797F7B75787672706D70696571605A745850744A4072312B
751B1981151485080B970A0F9303068900018301028401018601018302017F04017C0E03
6E160300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B742B018621039D1703B71509
C21508C7160BD12017CF1C16C5120CC20F0CBC0C0BC71919BC0B0BBF0E0CBB110EAD1110
A31E1B9830299B4F479E6E64987F768D837C84867D83877E848A81878E84858C7F898E84
8B918690938C8F938990928B91938C93958E9899949598939A9B9898999794969490908E
8A8B898485848C8E8C9899948A8982918F87938C85938D84938D83989287948D80989184
9D96899992849E9687958C7E9B9383988D7F9A907F9B8F7F93887590846F8F836C978973
968871978A758C826F9388759D907F998D7E958977968973988B76978B76998D789C907A
998C769A8D77978E779B907CA29585A198879D968499917E9B907B9587718F7E678C7A63
8B7A608A7A5D8B7A5E8A775C8C7B608E7B628C785F8D785F8C775E8D765C8B73588A7056
8C7259896E578B715A8B725C8E74609077658E7A6A9584759A887CA19288A1948CA0948A
9B93859590808E8C8085877D7E817B797B7975787675767373736E6C6D666A6760695A54
694A4367322D6F1C198B1716960F0E8B03048100018001018101017F01017E06017C1407
34870100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007E3C05772200982108B2190A
C82214C3160CC6180FC81611C6130CC1100CB80E0DBA1B1AAD120FAA1B149A261B913C30
8F584C9071678B7B7289837C858882818A827E8980848D858A958B8D978D8E978A8D948B
91978E90948E90938A8C8E87898A8583857F80817C7D7C777E7B7687817A8E8A808E8A7F
93908599958D9A988FA29E959894879B9587999281968D7C9C94819C94829A937F9B9381
948D7A918A7698927D978F7EA29B889E9885A19A889E938499917F98907B98907B988D77
988D77908670989179A1957F9C907D988B7B958675948671968A77998D7C9A907E9D9581
9F9883A09884A199859F9684A29888A39C8B9F988698907C9B8F789080678E7B638F7C64
8D7B60917F62927E618F7B5F8B795D8B7A5F88755B8A785E8C7A5F8A775A897458897258
8A71588B70588A70568E74598C7156927960A08C77A392819789789081718D7C6D8D7C6B
8F7E6C988877998F7D948E7E918D8187867D81817B7B7C7677787373746F6C6D6A686865
62615B60544D62423A6B2E25791B1487120E8506067E00017C00017B02017D0C02751507
2E850000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009A59187A2E04871F03A91D0E
C6291DBC1D13C3251DC11A14C1140DBC140EA7120D9F261F8C281C9247378D6151806B5E
78736880807A85878083857F878D86838C848A958B909B918E9B918F99908E958D888B86
8588827F807977776A78766A8582778B887D929084959083968F81988F8098928096917D
9693829B9788949083949183908D7E979181999581928C7899927F98907E99927F9B9281
9B938298927C96907A99917E9B94819892809E97869C9284A19786A097859C94819C937F
9C937E978E7A99917C998F7D9C927F9C917E998B789D907DA39985A096849E97849C9783
9D97849E9785A09887A099889F998AA39D8EA0998999917F948973918067907C648F7B63
89785D897A5E8B7B60897B5F8A7B60887A6085785E8479628276607D725B7F715A7D6F59
7D6E5980705A86735C89785D90806297866D9A8A76978A77958976978A7695857191816B
8B7B6387775F85755E8576628B7C6B95897A91877B8E887C8A867C7D7B737575706F716D
666B6561645D615D55614F46623A2F6A22197B16137F07087E03017C0500801406671204
29860000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029D808803B077F2708A93729
A91F18B32523E86D6CAE1916B71A11A71B128C261B985B4E8663547A6B5A727162707569
797E76848681868882888B84898E878A90898F948D8A8F87858C827E82767C7D727F7E73
8381758A86788C88748C867397907F9189799B938498928097917E958F7D9A9581958F7B
928D79928D7B958F808F89798E8B7A98928194927D9994809D96839A92809A927F9C9383
97907F958F7B96917B9C9481A095849D9583A19B899F97879D95849C9281A29886A19886
9E9784A19C8AA49E8DA49D8DA39C8CA49D8AA69D8B9E96839E9783A19A889D98869C9986
9F9A88A39C8C9E97889F998C9D9B8D9F9C8E9F9C8D9A9585968E7C8C7F6B8A7C67887A64
847962847D65827F6683816A85826E84806F817E6E83837483847786877A8E8E80908F81
959285908C7C938F7C98927D97917A968E78988E7B988B78978B77998B769B8D78998B75
978A7096886D93836A8A796187755F84725D8575618B7D6B8F8574928A7B8B87797E7D72
74766E6A6D6662635E5E5D585B52495C43375E281F6F1712810F0A7E0B027E1B0E560B01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A6692F793717D18076
992B27A52324E06367A5201BA3281B933D2E875A4A7565586E6B5F6C70636F7969757C70
82867C8B8C848C8E86888A8384867D83827B7F7D747C796E8280708A8876948F7D96917E
9D98859A938098937E99937D9A94809C94839A93819A9380958F7A94917D99958198917E
968E7B98917F9A9382968F7D958F7C9994819995829A94819B94819E95849E96859E9885
9995819996819E9A86A19A889C95839C96859F9B889E99879F99899D95849D9584A79E8E
A09A89A09B8C9D9B8A9E9A8B9C998A9C9989A39F8FA19E8EA39F8EADA797A5A1919C9A89
9F9B8E9C988B9B988B9B988D9A9A8F97998B999C8E98998C98988B979587949584979987
949787999F8FA5AE9EA7B0A29CA499979D968E989186938E7C89857D8A877F8A877C8481
808782858A81888C818A8B7E8C8A7B928D7B948D7A9C917EA0947E9F917BA0907B9E927A
9C90789D91789B8D779687719989719180678C7B638B7B648D7E69857763897D6B8B8171
8C87797D7D726F6F686667605D5D5657524853423657291E68170C751709651204500C02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0066CB2F91603EB1746B
A74945AC2B27A526209B32258F4C3B80614F726958706E626F736671786A767F6F7F8376
85877A86867B8180747D7B6F7C7669867E6F948B7A938B79928D7894917A95917C97907D
97917E9A93809B948198907C9B948196907D99947F98917B96907C9A94819A95829B9481
99917F9B948297907E968F7C98907D9B93839F9A8799927F9A93809A93829B95829A9583
9795819A98869A98859B97869896839694829696839795859E9A8BA09C8C9E998CA09A8D
9B978A9D9C8E9B9C8E99998A9E9E919D9F929A9C8E9A9B8EA5A398A9A79CA9A89DAAAA9F
ACACA2AFAFA5AFB1A7ADB0A8ACB0A8A8B0A7A7AFA7A7AFA7A6AEA9A0AAA597A39C9AA69D
98A39B99A49C98A39A98A19791998F848D837F89807B847D77817C727F7D737F7F798584
7C88867A868477837E80888085867B8F8B7C928A789C907E9D917C9F917B9F907A9B8F78
9C917A9E937C9D907A9E917C9C8E789989729A8B739585708F7F6A9889739384707D715F
827968857F6E8A8577827D716D6B605F5D53575247554335552A195F1E0D500E00268601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C6966D7C4030
9033299E2A1F9837278C53437862506D6A5A6A6C5E7072627379687B81707E8472808172
807C6D807869827D6A8F8876948A789387738C7F6B9B907C96907B96927B908C76948D7A
99927F97907F9992809A9280968F7C97917E96927D97917E96907E9D96859B96869B9787
9D99889D98889E9A889E9988A09A8AA29D909E9B8CA49F91A39F8FA39E91A6A092A39F91
A09F909E9F91A3A294A6A6979E9F8FA2A395A4A798A5A79CA4A59BA6A89FADB0A7AFB2A9
B5B9AEB4B8ADB4BAB0B5B9B0B3B8AFAEB5ACAAB2A7B0B7ACAFB4ACB0B4AEB0B6AFB3B9B2
B8BEB8B6BDB7B5BBB7A5ADA9A3ACAA9FA9A898A4A195A09E8794937D8C8B778580758179
7E8780868D84898D818E8F818C8C7D8081707A7969777263706E5F696A5D68685F64645D
5F645F5B65625F6E686F7B75797E778382778F8878968B7A9C907C9E917CA1937C9F927B
9F937EA0927E9D907B9A8D77948770998C76A0917BA3937D978871988B75938876827969
746D5D6B6656726D5D807A6A827C6B777262655F50574F3F513E2B572F1C460E01248601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8BF59804527
782A18914433875645705A4C6B66556C6D60707363787C6A7C806C7F816F7B7967827C69
8A816C8E836C938871968B77978D79998E79998D78978C7A98907B908A71928D7499927F
9C95839893839C9888A09A8BA6A090A8A192A7A495A7A294AAA597A39F92A19E91A19E92
A2A0939D9C8FA5A4989E9C959999909F9F98A2A49CA3A39CA9A79FB4B1ABBAB5AFB3AFA9
A3A39C9899939B9F969D9F9793978E8F938C919590929995909895919E9992A19C9BA7A3
AFB9B3B9C1BCB5BFBAB3BABAB1B9B8AEB7B3AAB5ADAAB2ACAEB6B2A8B1ADA7B0AAA6B0A9
A1ABA5909A968189857C82817D8482727B7967726D5D69625A67605D69616B776B7E887C
8E9488A8AAA0BBBBB1CBCAC0CBC9BFBBB8ADA8A294958E7C847C688B7F6B82705D7A6754
695B49544E3F4D4F42575E566870697A7D728782749187769C917E9E927DA1927C9C8D77
9D8F7A9C8F7A9C8F79968971998C739A8E759C90789D8F78998C75958B77979080817E70
6A6A5D5D60544D5245535444736D5B887E697D735F685E4E584B3B5A402C451606248701
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003AEB1DB07D51
6C3E237F5D486E5B496D6252736C5C7774647A7A677E7D69797864726F5E76725E918874
958A7292856C988C75988D79978F7A958D799A927E968D7A9F9582A39A86A39D88A19B89
9D99889B988A9A988C99968A9C988D9D988E9A988DA5A196A4A095A5A195A6A497AAA79C
A9A69AAAA89CAEADA6B2B1ACB0B0ABB3B2AEB8B8B5BBBBB9D2D0D1E5E1E4E7E0E5DAD5D8
BFBEBEAFB1AFA0A6A4969D9D8C93938893918D9999919D9F8F9E9F8D9F9F96AAA98FA09F
92A09D949D9C96A09E989FA09CA3A29EA6A3A2AAA4979D98949996929893969D95A1A79F
A4ACA4A4ACA4A8AEA8AFB5B0BAC0BBBCC4BDC3CCC6C6CDC8CCD2CCCFD5CEC2CAC2C2C9C3
D6D8D6EFEEF1F4F2F7F5F2F8ECE7ECDAD4D3BBB1A89C8E7F9A8974A78F76A284689B7A5C
8E7153816A4E6F61495953425453486A685C888270918674958A749F937C9E90779D8F77
9E8F799E90799C90799D927B9B90799B90779E947B9C917B978C769289768E897C76766C
646961444E443A453B3E46394D4C3B6D644E8879628577636E604C59442F4E281600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C99D68
755A386C5C42695E47766A577F7462827966827C6478735E6964526864557A7866908976
938975988C76988D77978D79938B76A199869A948198927F968F7D98907F989281979382
989385999287A29B939F9A919F9B91A7A29BA4A198A39F94ACA59AA7A095A6A293A8A295
A49F92A49F92A5A094A09B92A49F95AAA29AAFA8A2B0A9A5B8B1AFC3BABBC1B8BDB6AFB5
ACABAE989A9D8A9396848F957D89907584896E808469797E6778796373745C6D6C657571
7D8A83939F989FA7A1A6ACA7B0B5B0B4B9B5B7BDB8C3C7C2CFD1CED4D7D5DEE0E0EBEEEC
EBEEEDE6EAEAE4E8EBE1E5EADADEE1CCCFD2B2B2B6A5A2A5969093888280736F6B736E6A
7B73738C8287948990978B9294868892827B8D7A698D775F8F75599070518F6E4B8E6C48
8A69438768438368457C65496E5E4660553C75684F9182699C8D75A597809F937A9E927B
9C8F789C8F79998D799B907C998E7A988E79978C77958A75958A77938D7C88867D6A6C69
4A555039483E3C4A3D414D3F474B3C54513D6D664C82765C83735A68553B5D3E2400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007D9D33
6E57306C5D3C786A4D81725A83775F7A6F5A665F496A6451696755666557787868878272
8E8674958A769C947E928B768E8971948E7A97927E999582938C7B958A7A948B7A97907D
9A918096887B9C91849E94889D9789A19E919E9B8D9D95889E96879E95889E98869C9685
9B95849994829994829992819A91819B8F81999080988E839A9087958B83938C85898484
7B7E8161696D5A676E5062694D5C6348595B4E5F5D4F5C5966706C79817C8F9791A6AEA7
BDC6BED0D7D1DBE1DFDFE4E4E5EAEAEBEDF2E9E9F1E7E7EEE2E0E8D8D3DCC7C2CBB8B3B9
ABA5AA9D979B938D928882867E76787B6F6D7D6D677C685F7E685C836C5C84705B8A7760
907F6892806D9B8879A08F80A18F7FA18F79A18E74A08F6E9E8A689B8664967E5D8F7756
8E735095754E98764D93724B8B6E48876E4879633F8C7657A5947BA3967F9E927B9E927E
A0937F9A8D799A8E7B9F97829E937E978B769487749B907F9791828C8A816A6D6B4C5654
404E484352464755454A55454D53455355466C6D587D775E84755A826E4F6A4C2D00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6025
755A3179684584755384765A6B6248504A354F4C385A594763655565675B7A7B6E888576
8A8371978C7998917B8D88728E8C759B96828D8875807A68978F7C9C8E7B9385708F816D
91836C8F7F6993836E918572938B7896917F9590809B938498917F968F7F97917E96907D
9A94809993819994819B93819B93809C95829A927F9A928099917F958E7C888778767871
5A61604551513748483445433F4D48545F5762695E83867A98978CABAAA3C2C1BBD2D0CE
DAD8DADBD9DECECAD2BDBAC2ADA9B1948C94837881776A717B6C6E7F6E6E7F6D68836F65
8C77688E7868957F6D947D68987F69997E63977959987955987852947854917A5A988666
9B8C6C99896B9E8D72A09177A2947C9D90799F947C9F957F9D947D99917D908A77807968
7A6F5C856F509B794F9F794C9D794B9978488E6F457F6443A8947AA59680A1937DA4957E
A1917E9D8D799C8D788E81688B7C628E7D65887866877C6F8C8A83686E6C4C5758475552
46544C4B584B4E5B4C50594B535A4B596253737B6B9394817D72588F7A5B7B5B3800FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0C7D551C
81643D897551887A586C61444D4A2E4A4A33484A364B4D3D55584A5B5E5374756B818073
86816F958B799C917E8C8571928E7998927F8B8572938A7691856F84755E8E7F669F8F78
8F816790806794846E998B78978D789089758D8774908776938C79908876958B78978B77
958974928873958B77988B779A917B9C927F998F7C9D9480948C79938C7B858677686E64
535953404742444E43545B4E646959979989837F6F92867791837484776C7D70667E706A
7D6F6E7C6F6F7D6F6E80726C81716B87756C8D7A6E8E7B6A957F699B8066A185659E825E
9F8461A99072A99074AA9072AC9370A98F66A284569D7C4C9E7F51836C4882765F877F6D
8D8571918872958C779A9581ABA695B1AB9B9B96889190858C8B8282847B787B7270746A
6D6C5E7261459C7A4F9F7644A37B479F7845967344876944A18A7097856E98856D947F67
927D658C775D867257816C517D6A4C796A50756A5877756B6268644B59594857544B5851
4F5A50505C50525F525662545C6759616D5F737F7393998B95927D8774578C6A4100FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310835F2B
8C6E488C785673694A5550354B4C314B4D364D4F3A4E4F3D4B4E3D5052466263597F7F75
8A877A8D84729C917F988E7C9993809D96849189759E937D958B738A7C639080669A8A71
9A8C7294846B8B7A638C7A6390806792856B968970988B7395897194876C96846999866B
99856B98856A98866B98856B99886F9D8F7A9F917D9F917D998C78988E7C8A85736D6D5C
5B5A4A6360526F6B59746F5B7B755E887D66817158826C538870548D7458977F629D856B
95836B8D7F6B948573AB9D8BC5B7A7CABCADB2A39192846B8A7A5D9A8361A289639A855F
8E81627E76627F7766867C68968971A99776A58B6098794A9C7E51816F4E69665671746B
76766B7F7E7286867A949288AEABA2BEB9B09B998F8F8E8786857D7C7C72787A6D6D6E5D
6660487C6743A68453A27A44A97F4AA37A45997342987B549C8467927B618E775A897154
877151826E4E7F6E4E7F6F537F725A7F7967707366555F584C5A554C5C544E5C53535E53
5861565961565763565B675A6570636E7A6F7480768D968BB1B0A1816F5494704400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047B110916E3D
9477518471526E684F53523E4A4D364A4E374D503D4F51414F50415153455355495D5E57
7979708683778A85759C958496907D948D7B9C94809D937EA59A858E816B95856D9C8C72
9B8D72988A70847157978167A38D73AA977CA1927395876B95866A958564948361958161
9681619881629781619781629984699A88719989729D8C769F8E799E8E78988B73766D54
7E73598274597D6E4F7F6D4C8874519B8361A48C66A28963AB8E67AF8F6AB0926DAA8F6A
968160908168A19581AFA391BCAFA1B6ABA0A19689998F7B94896E96886C938669928B6F
91927D6D7468787F7593978A736F5F796A50AB916B9B7A4C99784A96805B544F3A696D63
84867D807F738783778E887DA0998FA49D919993868E877B81796B6E6A5A62614E66624B
8576569A7F53A3814DA37B46A77F4AA07B489D7E51947E5A8976598B785E8C795E917F64
96886C9B9076948D75898573858378666B6257615A52615B526257536153535F52596656
5D685A60695E606B616772676A746A757F77737E768D948DACA99B836F5498724200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3742C987441
93775283755A7C7B695156474C52404E54424F54444F544550534555594B54594B515449
5659526F716A7E7F748685788F8C7B97907F938B779D9581A69A889D918090846E94876D
97896E9D8E769C8C728C7A609B8971998A71A5997DA2967D9C8F77988B6F998D6E9A8E6F
9C8D709D8B719D8C6F9B886A9B896D9B8A739A8A719B8B729D8E74A1917A9D8E74847356
8E7855896F468D70429C7F51B5996EB6966EB59770AD9069AD9069AC8D6CAB8D6CAD9170
AA9273A590789E8F7B9E92829E94839A938298917F9B957F99947C9490798F8C76949581
A5A8989EA3979DA29698978B746B5A847054AD9269AE8C5E987442A2845A78684C5D5647
736E60786C5A8776608D7F68968E79B2AB99A29E8E8C8779837D707771637E7B68857C62
8E7A569B7E509D7D499B79479C7D4FA88E66AE9C7DA89B81A69A84ABA08DAFA696AEA798
A29E8E9391838384786D71686067625C65605D69625C695F5E6B5C5F6A5A5E695A5F6D5D
626F61646F6468746B6A776D717C7376817979847E8E928B9A93848E76569F753C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB8169D7844
917753857C657F817462695C545A4D515749535C4B50584752594A555C4E565E4E555B4D
545A4E5A5E57686C648788819293889491838C87769B95829F9786A9A292A8A38F9D967F
988D77988D799F9581A99F8B9E937E988F7BA39B87ACA593ADA593A39A88A7A18CA69F8A
A49E89A39A86A29682A1947E9E927A9B907C9B917C9D937A9B93799F957E998E76857254
8B6F4891703FA3824EBB9D6DAF956BAB8F68B2926CAC8C66A88962A48866A088689E8568
A186699E866F8C80708F8A7E88887BA6A897A1A191A9A998BEBEADC1C1B1C0C0B0B5B3A4
A09D8E91918280807079725E8D7A609C825EAA8C5FAC89589F7944A581519F845F89775D
968771A59178AC9378B5A289D7CBBCFDF8F3DFDDDA928F8A7169606A6051746951897858
947B54967C519B8255A68F68B6A586B4A891B2A998AFA89AAFA99EA8A59D98989194958E
86898071766C646B5F626960636964636B64626C64616A61656E626971656B7569657368
63716768766D6E7B746E7A75727E797B857F878D8795928A897B6795774D7C9A2900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051B9169B7741
8D7853827B657E7F746E7369596055585E51555C4D51594A565F50555E4F535B4D595F52
585F52585F535A615963656074756F8D8D859595899493859A97879B98899895859C9586
A39C8CA59F91A8A393AAA494A09A88A9A291A6A090A49D8F9E97879D94869992829A9382
989180A1988A9990829C93839B947F99907F98917E97917B97927C99917E9E9683AFA08A
A68F6FA1835AB4986DAB916AA68F69A58D67A98B66BB9670B7926B9F8362978265937D63
9F8368A58A727368597E7C74868882A9ADA4B5B9AFAEB0A7BBBBB4B5B5AFAFADA79B978D
817B6E7671607B745D827356967D59A4875DA78859A78552A47D49A47F4DA384589A825C
947F5E9B8264AB8F72A68E79A9968DB6A9A99A908E897E738877658B785E927E5F9F8868
A89272AD9B7BBAAE92B6AC96ACA697ADA89DABA99EA2A199A6A6A18B8C887C807C6F736F
676C65666D636A73666A7167686E676E756E6C766E6C766E6D766E6E766E6D787068776F
6879716A7A746F7D79717C7A7B8482858A858D8D858A7F718E76599C763F2ADD0C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BF1A9E7840
A18C67877F6A7E807270766A626A605F665B5A6156575D53596256505A4D555F515C6357
5A62555A65565B67595E635A63645E66676273756E898B82A19F97ABA89FA9A59CA39E94
979388919084918E81969284989584A09B8DA39F8FA39D8EA9A393ADA596A7A190A6A08F
B1AA99B0A69BABA195A89E90A59D8AA39B8A9D9886A29E8C9B96849A93829891809F9685
94826C8D7254967B579E845FA28B66A08965A78B68C19A77BE9776967D618F7E65937C67
9B7E67B0917A9A86768C817AC2BEBBD2D1D1C6C7C4C8C7C5C5C0C0BBB3B4AFA5A392887D
8A7F6A88785D917B599C8057A18256B19469B3986EAA8E62A68659A28356A3885BA48D62
A089639B82619C83649B856A9785719786779A89769B896F9A846AA59277B5A38AB8A993
BEB19EB1A999B0AC9EABA9A0A3A39D9C9C9794958E888C84767B7570736D70746E6D726C
6F766D6F776C767E737980767F857D79827A737F786F7D756D7B74717D766F7D76677A73
6C7F7A72817D7984807F8683888A868A8A81857D7085735B98774B56BF2000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A1773B
9C845E9187707A7C6C73796B697267646E655C655A5F655D5A6357545F535761555D655A
5D685A606C5B636D5D676D626568606668626669636669646E6E697D7B788C8A869E9D96
A3A39BA2A197A5A397A19E91A19E909E9A8D9894889994869B96869A95859F9A899F9B8B
A6A090ADA598ADA498ADA499B2AB9DAEA99CAFAD9FB9B7A9B7B2A5B4ACA0BAB3A5B1A999
A699849681648F7853957D549781589C865FA08663B08F6FAE90728F7B628A7A628E7A65
947B649A7E679D8571978679C0B5AEBBB3B0A09893958B858E807A8C7A718B7667907B63
927C5C96805A987C539B7F53A0875DAA946FA89574A99677AB9677AE9A79B0A07CAD9E7C
AB9D7EB1A386AEA086AFA289B0A58CB9AB94B3A48CB4A58BA89A82B1A593B2A99BB6AEA4
ADA79EABA79FA3A29C9899958A908A7E847F7E837F787D78747B73797F777B7F777B8077
7A8176838B7F878E84898E87868C8478827B737F7A76847F71807B71807A75857D71837C
6F817D7787837F89858589838989808B857785745D94764E7F9E3300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA1A
947647AA9C807C786571736570796B6C766B636F65636E655E6A5F5E6A5F5B665C5F6860
626C60656F626870646C7369686E64676A62676D63686F66686D64696B64696B646E7169
797A7489888298958E9E9B929F9E93A7A39BABA69EA4A1979D9D8DA0A08E9E9D8A989584
9994849D95889D96899B9589979385908D7F9390829690839C9486988D819A90829A9180
989078968C6F998C6A9C8C6695835C98855F9884609781619A866893836884765C8A775E
917C61957D6297836897866D9E8E7A9E8F7DA2927EA79680A89780AA977FB19B82B7A384
B8A582BCAB89C2B190BEAF8FBEB092C3B99EB7AD97B2A994B4AA96B8AF9BB8B09DB6B09C
B4AD9AB8B1A1B3AB9CB2AB9BAEA593BDAF9FBAAA9AB9AB9AB8AA9DB5ACA2ACA69EA6A19C
9E9A9693908B8A8A86878984858A8480857F82858381848283888281877E80857C868B83
848B818E968C8C938D858B88828B8876827E74807B7884817884817C87827D89827A8882
7E8B8884908B8890898B8D85807A6D87775F96754E79982D00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9F75389A7F5B8C7F686F6D5C727668787D72717B736A756D626E66646F66616D64626E65
6672686772676973696E766E6D766C6E736A6E74676F776A6E7669696F636D70646D7065
6C70676F716B76777175766F7C7D75817E79938F8B999892999C91A0A297A5A69AA8A699
A9A799A9A499A9A498A7A296A7A396AAA697AAA797AAA595A59D8DACA292A79D8CA39C88
A7A289A5A086ABA58BAEA58EB2A68DB0A389B6AA8EB9AB91BDB095BCB397BCB598BBAF93
C3B698CBBCA0C7BB9FCBBFA4D4C8AFD8CCB5D8CDB5D9CEB4D7CCB3CDC1AAC5B8A1C6BAA3
C4BAA3C7BEA9C3BBA7C3BEAAC4C1ACBFBCA9B9B6A6BCB9A9BBB8A9BFBCB0B9B7ADB8B7AB
B6B5A9BBB8AEBCB6AEB9B1A7C3B6AAC8B6AABFACA3B7A59DA699929F96909A948F938F8A
98959195959192938E8F918C8D918B9295909192908F918F8F948E8A9089888E87898F88
888F8889938D86908E828D8D808D8B7A89857C8B857F8D86828D89858D8989908B87918C
8B93908D928F94958E8C857788745B95714786A33700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2CDF0F99713A987F5B887D687B79697E7F747E847D777F7B707B756C767063716966736C
63716868736B69766C6F7A726F7A706D7568707768787F72787F71767C70777B6D74786A
72786D72766F70766E75766F73756D74756F7979747577727C817B83878291938F91928C
9FA097A5A6A0ABABA5B1AFAAB3B1A9B8B8AFB5B7ADB6B7ADB7B7ACBAB7ABB5B1A3A5A190
B6B3A2B4B2A0B5B2A3B6B1A5B7B2A5BBB6A5C2BDABC3BDABC3BFACCAC6B2CAC6B0CCC8B2
D2CFB9D9D2BFE1DBC9E1DCCBE4DFCFE3DECFEAE5D6E8E3D5E4E1D1E1DECFDAD5C7D7D2C4
D5D2C4D8D6CAD1CFC3CACABCCDCEBFCCCEC0C8C8BDCACBC1C5C7BEC2C4BEBFC1BCBCBDB8
BBBDB6B3B4AEB3B1ABB2ABA2B8ABA2B8A89EAF9F97A69993A49B95A29C979C97929B9792
A3A39D9C9E98969A959DA09D9B9F9B939795969997959A978A928C8E97918E98918E9690
88918B87928D86949182918F82918F83948F84948D7F8F8784908B8C958E8D948D929790
93959094918A8E82728E7756A1794729DD1000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDF0F9B753B957C579A8D77908E8085898080878279837E75807B6C79726B7770
6B776E6D77726D7871707B74707D73737F71737B6C7D8377787E727E8176808378818478
84887E7C817A72786E73776F72796F7579727478717279726F7771737A76747876787975
7B7D797B7F7E7D8183828787888D8B8D94939BA2A1A6ACACAEB4B2B0B5B0B7BAB3B3B6AD
B4B6ADB5B9AFC0C1BBB9BAB3B8BAAFC0C2B4C3C6B8CDCFC2C8CBBED3D5C6D2D5C5D9DACC
DFE0D4E2E0D7EDECE3F4F2EBF8F6EFFAFAF3FAF9F4FBFAF5F6F6F0F0F1E9EDEDE6E8E9E2
E5E6DFE3E5DFE1E3DDE3E6DFDDE2D9D5DCD4CAD2CCC6CDCAC1C9C6C7CECDBCC1C2C2C6C6
B0B3B2B8B9B7BABAB5BCBAB2C3BCB3BCB3ACB7AFA9B9B6AEB7B4AFB5B3AEB1B0AAA9A9A3
AFB1ABA5A7A4A3A7A6A0A6A59FA6A59BA0A0979C9B99A09D939D99929D99939D9B919B99
8A94928894908C98948B99958B99948F9C98909C988A989386918D929792979A9396968F
958C808B796192734982A33700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE2107294289A7F57A498819898898B8F85888E87848D877C878078847C
77837A707975737D7979868076847B79857B717C707A81787F847C7E847C81877F878E85
8C91898E938D797E76767B74787E76747B73737D737682787580787C868178817E7E827F
7B817E767F7E7680817B85887783857C87898491928591938793948E999A95A29E98A3A0
9EA8A4ABB4B0ADB4B1B1BAB7BBC4BBCCD4C9CFD8CFD0D9D2D8E2D8DEE6DCEAF0E7F2F4EF
F7F9F4FCFCF9FEFEFCFEFEFDFEFEFCFEFEFEFEFEFEFEFEFEFEFEFDFEFEFDFEFEFCFEFEFC
FDFFFDF5F7F6F0F1F0EAEDEBDEE3E1D9E2DFD7E3E0D4DFDED8E2E2D2DCDEC4CDCFCDD4D5
CACECDC6C9C8D2D4D1D2D2CDCDCBC5CAC8C3CAC9C4C3C5C0C4C8C3BEC2BDB8BCB9B4B8B5
B4B7B5AAAEACA6ACABA6AFAF9CA6A59BA4A3A0A7A69CA4A2959F9D939E9E949F9F95A09F
8E9A998E9A97929E99929C99939E9B929C99919A978D948E8E938D97958E978F838F7C67
9476527A9C362DE11300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0050BC1E9B7C4DA59377A0988792908691948C8A938A848E86
838F85818B857E89867C8B867A8982808C8577817A7C837F7E85827F8883818B8587918A
89928A8C928C898F8885898380857F7A817A818C837D88808A958E929C98828C89878D8B
7A83817A83837C86877B86898693948B999A8B99998795968797968D9B9C91A09F99A5A6
9FAAA9A8B1B1B0BAB9B5C1BFC0CEC8C5D0CDCAD4D1D7E1DFE1EAE7E3EBE8EBF0EFFBFDFC
FDFEFDFEFEFEFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFEFEFDFDFEFDFDFEFDFDFDFDFEFEFD
FEFEFEFCFDFDFBFBFCF5F8F8EAEFF0E3EAEAE3ECEBDCE6E5E4EEEEDCE4E5D0D9DAD7E1E1
D2DAD9CFD6D5D6DBDBD8DADAC7C8C6CDCECBD1D2D1C9CDCBC1C6C4C0C6C5BAC2C1B5BCBC
B4BABAAAB2B1A1ABAAA5AFAE9FA9A7A2ACAA9FA9A79FA9A89FAAAA96A1A299A5A598A4A3
9AA5A395A09D99A19F979D9C9097959095928B8C868C877C8A816E88765B92744D7C9D38
2EE21400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002EE213799C359B7D55A6947AA299889A988B909488
8B958A8B948D727D757E8B8488948E87928E828E8A828B897D8786848E8B89948E8B9691
88938E8E98938C95908D938E939994949A95939C968D9794939E9B9CA5A49099989EA6A3
98A19F7D88877D898A8490908F9C9A919D9C939F9D94A1A094A1A098A5A49AA5A5A8B0B1
B0B8B7B7BEC0C6CFD0BECBCAC6D3D2D0DAD9D7DFDFDBE2E4E3E9E9E7ECECF3F7F8FCFDFF
FEFEFEFEFEFEFDFDFDFDFDFEFDFDFEFEFEFEFDFDFDFDFDFDFDFEFDFDFDFDFDFDFEFDFDFE
FEFEFEFEFEFEFAFBFAF2F4F4EFF4F4E8EEEEEEF4F4E2E8E8E1E7E7E0E5E6DAE0E2D6DDDF
DBE2E3D8DFE0D9DDDFDDE0E1D7DAD8D2D5D3D5D7D7CFD2D1BFC3C2C2C6C7B9C0C1B6BDBE
B8BFC0B2B9B9AEB5B5ACB5B4A8B1B0A9B1AFA6AFAEA3ADADA5AFB09BA6A7A0ABAB9CA6A5
9FA6A59A9E9E939395918F8E89867F8C847886776189724F95764452BF2500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DE113799A3498774F9C886A9E957F
9B9A8A98998D878B808A92888F98918F9793909A988F9A9888949189939286918C919B99
8F9B988F9B9A909B9A8C9695949C9A9AA29F98A19F9AA3A39EA8A7A0A9A98F9A9A949D9C
A1ABA787948F82928D8E9D9997A7A2A6B1AFA3AEABB4BEBDB7C3BFB6C0BFB5BEBEC5CDCC
B5BCBCC2C7CAD1D8DAD4DBDED8E1E3D9E1E0DBE1E1E5E9ECE4E9EAECF0F1ECF0F1FAFBFD
FFFFFEFDFDFDFEFEFEFDFDFEFDFDFEFDFDFDFDFDFEFDFDFEFDFDFEFDFDFEFDFDFEFDFDFE
FEFEFEFCFCFCF0F0F1F3F4F5F1F3F5EAEFEFE9EEEEE8EEEEE3EAEAEAEFF0DDE2E4DCE3E5
E4E9EBDEE2E4DCE0E2D5DADAD9DEDECCD1D1CACFCFC9CECFC4C9C8C5C9CBC0C5C7B4BBBB
B5BBBCBABFC0B5BABAB3B9B8B0B5B6AAAFB1AAAFB0A9B1B2A9B2B39EA7A89EA6A79A9FA1
9797978F8A858C7F788D79698D73589A78507C9F392CE11300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050BC239E7B4C
947C589D8B71A094809B95869C9A909A9B96999D9A929995949C99969E9E949C9B919A9A
949F9D97A4A3899797808B8C949F9E96A1A19BA6A4A0ABABA5AFAE9FA9A97B87867D8889
A1ADAAA2AFAA92A19A929F9B9DAAA6ABB6B4B9C2C3C5CFD0C8D3D2C5CECECFD7D8D7DFE0
CAD1D1D7DBDEDEE3E5D4D8DCD4DADDDEE4E4E1E7E7E7EBEEE8ECEDE7E9EBF1F3F3F7F7F9
FCFCFCFFFFFFFEFEFEFDFDFDFDFDFDFEFEFEFDFEFEFDFEFEFEFEFEFDFDFEFDFDFDFDFDFD
FEFEFEFAFAFAF7F7F8F3F3F5F2F5F6EBEFEFEDF2F3E6ECECEAF0F0E9EEEFE0E7E8DBE1E3
E6EBEDDBDEE1DDE2E3D5DDDCD1D8D7CED7D4C9D1D0C8CECFC6CCCEC4C8CBC3C9C9BBC0C0
BCC1C1BCC1C3B8BDBFB8BEBDB0B5B6AFB3B6AAAEB1A3A8AB9EA1A4A0A0A19A97938F877F
8B78698F73589D79534CB9255CC52900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB921A17C4D9A7C5B9D866DA1927FA2998B9E988F9A98929897969B9D9B9CA2A0
9BA2A0A1A9A88D9896818B8B9CA7A69DA8A7A4AFADA4AFB0A6B0AF9FAAA7838F8A7F8B89
A2AEACB3BEBCB2BEBBAEBAB7B7C2C2BDC6C7BDC6C9C3CCCFC7D1D3C8CFD2CFD7D9DBE3E5
D8DFE1D4D9DCE1E7E7DDE3E4DCE3E4E3E8EBEBF1F1EAEEF0F3F6F7F1F2F4FAFBFBFDFDFE
FDFDFDFEFEFEFEFEFEFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFDFEFDFDFDFDFDFDFDFDFDFD
FFFFFFFCFCFCFCFCFCFAFAFBF3F6F6F3F5F6F6F8FAEAEEF0EEF2F4E9EEEFE1E7E8E1E7E9
E1E5E7DDE2E4D5DBDCD4D9DAD0D6D5D3DBD8CED3D2CDD2D3C9CED0C3C9CAC6CCCBBFC4C3
BDC1C3B9BDC0B3B7BBB3B7B8B3B6B6AEADABA4A09D9C959091857A8E7A67967A5CA38054
52BF282FE31600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0062C92C51BB24A47D4D9A7953997E61A08B76A29184A1958AA49D95
A29E98AAA6A4A8A6A2A7A8A5A8ACA8A6AAA8A8AEADABB2B2A9B1B0AAB3AEA4AFA8A9B3AE
B0BAB7B2BABCB5C0C1B3BDBFC0CACBBDC5C8BCC6C8C1C9CDC7D0D2CBD0D4C9D2D4D6DFE1
D1DADCD5DCDEDBE4E3DFE7E6DDE6E4E7EDF0E8EEEEEFF3F4F4F6F6F7F7F7FEFEFEFDFCFC
FEFEFEFEFEFEFEFEFEFDFDFCFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFEFDFDFDFDFCFDFDFC
FDFDFDFEFEFEFEFEFFFCFDFCF7F9F8F8F9FAF4F5F7EFF0F3EAEEF0E7EBECE3E8EAE3E7EA
DFE3E5DCE1E2DBDFE1DCE0E1D8DDDCD2D7D6CDD2D0CDD1D1CCD0D2BFC4C5BDC2C5BCBFC2
B1B3B4B0AEAFADA5A4A79C959E8F7E99836A9B7F61A47F584EBC2A5DC73034E71900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC42982A23DA881559C7A559A7C5E
9F886EA5907CAE9C8BB1A397B1A89FB3ACA8B5B1AFB3B2B0B3B2AFBCBBB8B7B9B4B5B7B2
BBBDBBB8BCBDBDC3C5BABFC3B7BEC1BBC1C5BFC6C8BFC6C8C3CACBC9CDD0CBD4D5D0DADA
D0DADAD5DBDEDAE0E0E3ECEBE0EAE9E7ECEDE9EEEEEFF2F3F5F7F6F6F6F5FCFCFCFEFDFE
FFFFFFFDFDFDFDFDFDFEFDFCFEFDFDFDFDFDFEFDFDFEFDFDFEFEFEFEFDFEFFFEFDFEFEFD
FEFEFEFEFEFFFEFEFFFEFEFEFBFCFCF7F8F8F8F8FAF2F3F5EFF1F3E9EDEDE7EAECE4E8EC
E2E5E9DEE1E4D8DADED9DBDED2D6D8CDD1D3CACBCBC3C0BFBAB7B3ABA69FA0958DA19185
9A8673998067A07E5E7CA04354C12C63CC3235E71900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE315
57C1274EBB24A98151A27E59A18262A58A71AC9682B29F8EB8A598BEADA1C3B5AAC7B9B3
CABDBCC7C0BFC4BEBFC1BCBFBDBBBDC1BFC2C7C7C7C5C6C4C9CBC9D0D3D3D1D7D6D0D6D5
DAE1DFDBDFE0DFE3E4E6EDECE5EDEBEBEEEFF2F4F3F7F7F8F9FAFAFBFBFBFDFDFCFDFDFD
FEFFFDFEFEFEFDFDFDFEFCFDFEFDFDFDFDFDFEFDFDFEFEFEFDFEFDFFFFFEFEFEFDFDFEFD
FDFEFEFCFCFDFDFDFEFDFDFEFCFCFEF6F6F9F7F8FBF2F3F7EDECF0EBE9EDE8E6E9DFDBE0
DAD7DAD2CDCFCAC3C2C0B6B1B9AEA4B0A195AD998AA28B74A28666AB8A6282A54757C22F
61CB3468D03400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005DC52B54BE28BA8D5A7E9F3FAA8158AB8563B59075
B59380B49686BBA193C4AB9FC9B3A9CEBBB3D0C3BAD7CCC3D8D0C8D8D2CEDDD8D6DCD7D5
E1DFDEE7E6E9E6E7EAE9EAEDE7E8EBE6E6EAEEEDF1F9F8FBFEFDFFFFFEFFFEFDFEFEFDFF
FDFEFFFFFDFFFEFEFFFFFDFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFCF9FB
FCF8FAFBF6F7F7F1F2F4EDEEEEE5E5E4D9D7DBD0CCD0C2BDCDBBB5C4B0A7BAA497B39A8A
AF947FAC8F76AD8D6FB38E68BB916259C63262CC3768D1376BD23300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0037E81A6CD036
66CC345FC63159C22E55BF2D55C03052C03280A84DB3916CAE8E6DAF9075B2967FB79D87
B9A290BBA698B8A799BCAA9FC8B6ACC6B4ACD0C0B8D3C2BBD8C8C0D6C6C0D5C6C1D8CBC7
D8CAC8D6C7C4DBCBC6DAC9C4DBCAC4E0CEC8DECBC6D8C6C1D5C2BDCFB9B5C9B2AAC1AA9E
BBA393C0A492BB9E88B99B83BB9B80BC9979BF9973C0986D5BC8375DC93663CD3967D038
6CD3396CD23637E91B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0108209 0.97619 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE1152FE11600FF005DC32B
5CC42D5DC52F5AC42E88A645B8895CB8885C5BC533AF875FAF895FB08C60AD895EAF8960
B0885E59C533B18860B0875EB1885F58C43359C4335AC53400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002EE1165DC22C5CC52FBA8A5DBA8C60BA8B62BD8C65BC8F68
BC926DBC9472B89472B89676B9987CBB9A82BB9E8B988579887D73A194829889758F7E6E
A99686BDAA98BDAB9ABEAD9CC2AF9BC3AD99C6AD9AC4A9976ADD5767DC5466DB5361D64E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32C
5BC430B6885E89A84AB98F65BA9068BD9773C29F7EC6A488CEAD95D5B29BCDA991CBAA91
CDAF99C5AC9AC5B19EE0CFC1D1C6C2A8A0A1CCC4C75554632C364F76808DC7C9CCAFB3BA
9CA6B4B9C6D5BAC9D5778994CCD6D8D9D7D3D9D3CEDBD4CFDBD4CFD9D2CCD6CEC8D5CDC8
D7CEC7D1C9BDD1C5B8CFC2B49ACF8769E35F68E05B67DD5863D8525DD14957C83F51C136
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32D88A5445DC734BA9168BE9977
BF9B7FC8A68CD2B298C8A992C4AA93E3CFBBE7D5C8DAC6BBDBC7BBDCC9BBCBB6A7C8B3A5
E1D2C7E3D9D2D3CAC4D9D1CCB8B4BA676673B8B4BAC6C2CBABB2C6A6B4CCC8D7E8AABCD2
223D661B3C696683A75069858D9FB3CCD5DCD3D5D5D5D6D5D3D2D4D1D3D4D0D2D2D0D2D1
CFCFD0CECDCBCFCDCBCECDCACDCAC9CDC9C7CEC9C5CEC6C4CEC7C3CAC2BCC6BBB4C4B6AB
BCAB9DB3A08EB29B8A86B36758CB4150C13500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002FE1155DC52D5DC52FBA8C62BF936DC19976C7A386C6A68DE5CBB6EAD7C5
D1BCABCBB3A3E5D3C6E7D6CCD1C1B6DFD2C9E1D5CDD1C4BCC6B6ADDDCFC6E4D9D4D7CBC6
D8CEC9DFD7D3B9B1AEC7BFB9D9CFD0DED8DDCCCACEDCDADFC0C6DA364A714A6388A1B2CC
4E6082354E766F88A7C1D2E7A5B6CBB3C5D5CED7DDD4D8DBD4D5D9D3D4D6CED2D5CFD3D5
D1D2D6CFD0D3CFD0D3CBCECECDD0D0CBCECDCDCECDCACBCCCBCACEC8C9CAC7C6C5C5C3C0
C4C1BDC4BEB9C3BCB8D2CBC6D3C9C1CDBFB6C1AEA2AE968454C43D28DE1900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE116
5DC42E8CA747BC8F64C59870CBA17DCEA68ACEAB94E2C7B4EFD9CBCFB8ACD1BCAFD7C6BC
DCCCC2D2C2B9E7DAD1E1D6D0D8CBC1D0C2B7D9CEC5E3D9D1DBD0C9DED3D0E3DADADED4D3
CCBFBBD4CAC6DFD9D6D7D3CFDBD6D3E0DFE1A9ADB7ACADB8BDB9C87276936D7996BCC8D9
C7D6E7A6BCD46F8DA8A3BFD76B85A14B6B87C3D6E2D0D9DDD6D8DBD4D7DAD0D4D5D0D5D6
D3D5D9D1D4D5D1D2D6CACED1C9CED0CBD0D2CBCFD1C8CBCECACBCFC7C8CBC6C7C9C5C6C8
C4C4C7C7C8C9CBCCCDCACBCCCCCCCDD0CECED0CECDD2CACAD0C2BDC1ACA583AF6829E11E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42E8DAB4BC0926B
C69976CCA284D2AB8FD5B295D9B7A0E2C1AFD3B6A7D8C1B2DCC9BBD4BFB1D1BDB0DFD0C7
EDE1D9E0D2CAD6C7BEDBCBC4DFD3CBDACEC5DFD5CEE7E1DCE8E1DED4C9C8DDD3D2E0D7D6
DCD2D2DBD1CFE4E0DDDCDBD9CDC8C6D2CDCCAAA7B0ADA8B2D1CBCDDAD9E2B3BFD38195AE
ADC4DB4B6580183B642B4E739AB0C9657B94AABECFCEDBE0D3D9DCD1D6D7D1D3D5D0D4D5
D1D5D8CFD4D7D2D6D9CDD1D4CCD0D3CBCED3CBCED3CACFD2C8CCD1C9CBD0C6C6CBC8C7CC
C5C4C9C2C4C6CBCCD0CFD0D2CED0D4CDD0D3CBCDD0CBCED0CECDCECEC9CBCDC4C3C8B9B6
AC979048BE3A24DD1900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC22C5DC52FBA8C5FBB9266C19B77CBA588D3AE93
D3B098D3B29DD7B6A1D9B9A1D9BBA6E2C6B4DAC0ADDAC1ADDAC5B5EAD9CBDFCDC0DCCCBE
E0D2C7DDD0C7DACBC1DFD1CAEAE0DCE9E0DCDACFCCDED6D2DFD7D4DCD2D0DED4D3E9DFDF
E9DFE2D9CECEDBD3D1D0CBC8CDC7C4D3CBC8E7E2E2DEDBDFC9C9CCD4D4DC717C9720375E
6C819DA0AFC46E7F9B6C829DC4D5E7C5D8EA87A0B6B8CFDBD1DADDD5D9DCD5D6DAD4D8DB
D3D6DBD2D6D9D3D7DAD1D5D8D1D2D6D0D1D5CFD0D4CBCFD2CACFD2CBCED3CBCCD1CAC9CE
C2C3C7C1C5C8C7CBCECED3D4D1D5D8CDD2D5CACED1C8CCCFC9CFD2C5CACFC9CBD0CCCBCF
CAC6CCA6A2A9938B8B78675A5883301BD30B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF005AC42EB98A5FBE8F67C39A72C9A07DCDA889D0AE94D4B59DD0B39D
D2B6A1D5B9A4DABAA5D9B9A4D6B9A4D8BEA8DCC3ADDCC6B1DFCCBBE6D7C9DECFC1DECDBE
DDCFC3E9E0D7E8DED6E2D7D2E7DDDAE6DDDBE2D9D5E2DAD6E9E2DFE9E3E2E3DAD8E2D6D7
E4D8D9DDD2CFDBD0CCE8E1DEE7E3DFDBD7D3E0DBD9CED0D579808BB5B7BEB7BAC68692A8
9FADC0CBD9E5D0DEEB9BB0C75B789992AFCE28486A6989A3CCDBE6D4D8DDD6D7DCD2D6DA
D1D7DAD2D6D9D3D5D9D4D5D8D1D4D8CFD2D7CED1D6CDD1D5CCD0D2CECFD3CDCDD0CBCCCF
C9CBCFC7CCCFC9D0D3CED5D6D0D4D8CED3D7CDD0D5C9CDD2C5CBD0C6CED1C7CCD0C9CBD0
CCCBD58081933B425B3942526363637467533CAF2100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
88A44489A749B88E64BC956AC59D77CAA483CCAB8BCFAF94D2B39ACDB199CFB59ECFB5A0
D4B9A4D5BAA5DABDA8DCBEA9D9BEA9DBC3AEE4CFBCE0CDBCE0CDBEDECCBFE0D1C4E5D5C8
E7D9CDEDE2DAEAE0DCE6DAD6E3D9D4EBE3E2E8E3E2E1DBD8E7E0DDE8E1DEE0D7D5DCD2CF
E7DFDDE9E3E0E0D9D6E5DFDCE6E4E0CFCECACFCBC8D8D4D5C2C1C8C6C5C9D9D9DACBD5E0
7189A0668199ACC0D3566D8A11346454759A95AEC87490A7C5D9E7D2DAE2D4D7DCD3D7DB
D2D7DAD0D4D7D1D3D6D3D4D8CED2D5D0D4D7D0D4D7CED2D5CDD1D4CED0D3CDCED0CBCED2
CBCFD2C9CFD2CAD2D5CDD2D5D2D3D8CFD2D9D1D3D8CCCFD4CACFD3C1C8CBC7CACFC8CACF
CACCD1B7BAC6575D71838EA36F7A89878C8FA2989066944600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42F8AA84A
BB8E6ABF9773C29E7BC6A382CDAA8DD1AF94CDAF96CBAF97CAAF96CDB399D4BAA2D1B7A2
D4B9A6D9BEA8DEC4AFE1C7B5DFC8B6DBC6B4E1CDBAE4D2C0E6D4C4E6D5C7EEDFD5EDE0D6
EADDD2ECE0D8EBE1DBE9E0DCE6DDD8EDE6E2EBE6E2E4DCD8DFD5D0E2DBD6E8E4E1DFDBD9
E2DEDDE6E3E1E0DAD7D9D2CCD9D6D2DAD9D9D9D4D3E2DBD9E2DEE0CFCED2C3C2C4B2B6C3
304668223D637D91A8B7C2D67489A88CA7C3CAE0F494AEC57091AAC7DAE8D2D7DFD2D5DA
D2D7DAD0D4D7D1D5D8CFD3D6CED2D5D2D3D8D1D3D8CED1D7CACFD3CCD0D3CCD0D3CBCFD2
CACED1C9CED1CBD0D4C9CFD3CED1D6CED3D7CDD2D8CED3D9CAD0D6C5CACECACDD2CACED2
CACFD3C7CCD1AEB6C28E9CAD90A1B297A7B6A1A9B1ABA5A26E9C521CD20C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0059C22D86A646B58C61BA926BBE9774
C29C7EC49F82C6A386CAAB8DCDAF95CDAF98CFB29DCEB19BCFB29BD1B79ED9C1A6D6BFA8
D8C0ACDCC4B0E1C9B7E2CABAE4CDBDE1CAB9E4D0BCE6D5C0E3D6C4ECDDD0ECDCD4EDDCD4
EBDCD2EBDED6ECE3DCEEE8E2E9E0D9E6DAD3E1D8D0E3D9D4DDD4CEE4DDD7E8E4E0E4E0DD
D6D0CCDBD6D1E0DCD7D9D5D0E0DCDAE8E5E5E3DDDCD7CCCBD7CED093949B9B9CA1D0CED2
B1B6C6A2ACC1B0BBCCD0D9E4ACBED34060857191B26A85A425466CA2BBD1CED7E0D0D4D8
D0D5D8D1D6D9D0D5D8CED3D6CFD3D6D0D1D6CED2D7CBD3D6CAD1D4CBCFD2CCD0D5CCD0D3
CBCFD2CACED1CCD0D4CDD1D6CCD1D5D0D5D9CED3D7CDD2D6CED3D7CFD4D8CACFD3C8CDD1
C8CDD1CBCFD5999FAD293A513E5570364A654153677E8891958C8B8F74651ED41000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002DE117B3885EB88E68B8916CBD9876BF9A7AC29F84
C5A289C7A58CC9AB91CAAD93CFB39BCEB39DCEB49DD0B7A0D1B9A3D2BBA5D8C2AAD9C5AE
DCC7B4DAC6B2DFCBB8E1CBB9E2CCBAE4CFBCE7D3C0EAD7C5E8D9C6EBDBCCE9D7CCE9D7CD
EFDFD6EADBD1E7D9CEE7D9CFE3D5CCE2D4CBE7DCD6EBE3E1E7DEDBDAD0CBDFD7D1DED9D2
DAD3CDDCD7D2E8E5E3E7E2E2DAD1CFE0D7D4D5CCCBCFC4C3D4C9C7DAD5D7D4D0D3CCC8C7
DCDDE2BCC6D3697D948196AA7F92AC1C3B6737587FC0D2E88C9EB49CB3C5C5D8E1CCD6D8
D3D8DBD3D6DBCFD3D6D1D5D8CED2D3CED2D5CED2D6C9D1D3CCD1D5CDD1D4CDD1D4CBD0D4
CBCFD2CACECFCDCFD3CBCFD2CACFD2CED3D7CCCFD6CCCFD5CBD0D4CED1D8C9CDD5CBCCD5
CBCED6C9CCD3BCBECA5F697D7B8BA1576A7E8191A488949FA6AAAFBCB4B2A98E851ED511
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0058C12C57C12CB1885FB9926DB99574BD9B7DC1A183C1A386C5A88D
C7A78EC9A991CEB29BD0B7A0D0B9A2D1B9A5D1BAA7D6BFACD6C0ADDAC5B3E0CBB9DEC9B6
E1CCB9E2CDBCE2CDBBE0CDB6E0CBB5E2CDB9E7D2BFE9D7C4E7D6C4E8D7C6EBD8C9E8D5C7
ECDACDE9D7CAE8D6C7E6D6C8EBDED4EADDD4E7DDD4EADFDBE1D7D2DCD0C8DED3CCE8E3DC
E7E4DEDAD3CEE3DBD7E3D7D6DECDCCDACDC9E9E0DDE6DEDBD2CAC6E1D9D7D8D5D7AFADB0
C6C3C89FA2AF44516E5E6D86D2D6E6A2AAC18998B4B8C9DCB8CCDE496A8390B1C6C8D9DE
D0D6DACFD4D8D0D4D7D1D5D8CFD4D4CED2D5CED3D6CDD2D5CBD1D5CBD0D3CDD1D2CBCFD2
CDCFD4CACECFCFD0D4CDCED2CBCED1CBD0D3CDD0D6CBCED5CACFD3CACFD5C8CCD5CACBD5
C7CAD2BFC2C7CBCCD3ACB3BF8996A793A6B68494A68797A29DA5ACAAACAFC1B7B89A7F75
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0083A243B2885FB68E65B69067B99570BB9878BB997CBD9D82C0A28BC0A48DC4A68E
C9A992CFB199CFB49FD4BCA9D5C0ADD5BEADD6BDADDAC4B2DBC7B3DDCAB8DDCBBADDCAB7
E0CAB7E1C8B8E0C8B8E1CAB6E3CDB7E1CBB8E6D1C0E4D0C0E5D2C0E8D5C3EBD9C8EAD7C8
EAD7C9ECD9CAEAD8C8E7D6C7EBDDD2E8D9CFE6D7CDE1D3CBE9DFDAE7DCD8DDD1CBE5DDD8
E3DED7D6CDC6D6CBC5E5DBD6EBE0DEDBD0CDE9E0DCE7DFDDCFC6C4CCC3C2C5C6CE92939F
C9BAC3EDD7DFDCC7D5D9C2CFD9BDC6DEC6D4675F7C2E3E618198B53551724C6D8CC6DAE5
CED6D9D2D7DACED3D6CED4D7CCD3D6CCD2D5CFD4D7CDD4D6CCD1D4CBD0D4CBCFD2CBCFD0
CCD0D3CACFD2CDCFD3CCCDD1CDD1D4CBCFD2CCCFD4C8CBD0CBCFD3C5CBD1C6CBD1C8CBD2
CACBD3C2C5CCCCCBD39D9FAD2D37504C607B2B415A536779808F9B878F969C9A9FA19492
668E4500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C12C
86A749B68D68B8936EBB9672BF9C78BE9A7ABD9C80BD9E84BFA288C0A58DC3A791CEAF9B
D1B39ED1B5A1D0B5A4D7BCAED9C1B3D6BFB0D7C1B0DCC7B5DBC7B6D8C5B4D3C1ADDBC7B2
DFCAB5E1CBB8E1CABAE4CEBAE2CCB7E2CFBCE7D4C4E7D4C4E4D0BEE6D3BEEBD9C6EAD6C6
E6D1C2EAD8C9EAD9CAE7D3C5E6D2C5E7D6C9E5D6C9E0D3C8ECE2DAE8DFD9DBCEC6DACCC3
DED5CEE2DBD5D9D0CCE8E0DDEAE4E1DAD0CDD8CCC6D7CECAC9C0C0C7C1C771778E7F7B9C
AF7C96C47283CE7082C65F6FB74956B64C5A9F5066513B59959EB4B8C7DB8A9FB4B9D0DE
CBD6DDCFD8DACFD4D8CAD1DAC1C8D6CBCED9D3D0D6CFD0D4CDD0D3C9CFD2CACFD2C9CFD2
C8CFD2CACFD4CBCFD3CACED2CDCFD3CDD0D5CBCDD2CBCBD3CCCED3C8CDD1C8CDD1CACDD4
CBCBD1C9CCD1CBC9D2B5B0BD5E5F756C78904F60778798AA8998A5AAB5BDBCC0C7B9B8BB
B5A29F44B22B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002AE015AA8559B28E65
B8926CB7916EBA9776C0A07FC2A282C1A184C4A38AC2A48CC4A891C9AE98C8AC98CFB2A0
D4B6A4D6B7A6DAB8AAE4BBB0DBB0A4DFBBABD8BDAAD8C1ADD9C3B1DBC6B3D7C2AEDFCAB5
E1CDBAE1CEBEDECABCE4D0BFE6D2BDE6D4C1E8D7C7E9D5C5E7D0BEE6D0BCE9D2C0E9D2C0
E8D3C0EAD6C6EAD7C9EBD6C8E8D5C6EDDCCEEFDED2E3D2C5E1D1C6DCCFC6DCD1C9D7CBC6
E4DCDBE7E0E0E2D6D4DACAC7E1D2CFE1D1CFD7C7C3E2D5D3E6DCDED9D1D987849E463766
8F416CA3203CB6172ABB111EBF0F1CBA101BAB202EDC9AAC9894A8B7C5D96B839E496B89
BDD3E2CCD4DACED3DBB5BFD1464D6E806D8BCAA8BAE0C8D2D5CCD1CECFD3CCCFD3C8CED3
C5CED5C6CED8C8CFDAC9D0D6CDD2D4CACFD2CACFD4CBCFD6CACDD3CACDD2C9CED3C8CCD4
C8CBD1C8CBD0CAC9D2C2C0CA9F9EAE737C90919EB38A9BAA909EA9A1AEB5ABB5BAADB2B7
AEA6AAA68D8400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02DAC855FB18E69B49270
B69271B89376BE9D81C2A488C3A68BC3A68EC5A691C7AA96CCB09CD3B6A2D5B6A3DAB9A7
D9B1A0D5A598E1A89DCD867DBD7166E0A694DBB7A1D6BBA6D7C0ABD7C2ADD6C1ACDBC6B2
E4D0BEE4D1C2E1CEC0E0CCBBE2CEB9E1CFBCE9D7C6E8D3C2E6CFBDE7D0BEE9D4C1E9D3BE
E9D3BFE8D1C1EBD4C6E7D1C3E8D4C4E7D3C4E6D2C4E2CFC1DECDC1DDD5D0E5E1E1D5C9CF
CCB6BFDEBDC4ECBCBFEAB2B2F9C2C3FCCDD0F6C9CDEABEC1F0CDCFDCBFC4C2ABBE513A64
854673A22C4AB81425C50B14CA0B13C80C13B80C18BE4D62503056556285788CAD243F63
9AAFC7CAD5E0CCD3E08E96B138265182355A8B1F3BB0596DD8A0AFDFC0CCD6C5CFC4BBC8
ADAABD8B8AA36C6A83A9ACB7CACED3CED2D7CCD1D7CACED5CACDD4C7CCD1C7CBD3C5C9D2
C7CAD2C8CBD3C7CBD2C9CDD27E8291232F484C5D75394B6160728396A6B098A3AB9EA0A7
948F9497828042B02700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002AE017AB835EAE8867B08D6EB39274B79578
B89478B9947BC2A188B19176C2A38CC3A693C4A695D3B4A1D6B3A0DCAE9EE1AB9BD39787
DE998AB56959EC9A8DBB5E54CA6B5DDA927DDFB49CD8BCA5D3BBA5D8C2ADDBC5B0DCC7B3
E2CEBCE4D1C2E3CEBEDCC5B2DFCAB5E0CEB8E4D1BFE8D3C3E5CDBDE5CBBAE4CCBBE6CFBC
E6CDBAEAD0BFE9CFC2E7CFBFE9D0BEEAD0C1E4CFC2E5D6CCD6CDCDB9B4BFA18EA3AD768F
C16279C85062C7404EC83743CB3847CE4151D04858CF515DD76972DE838FECA4B79E6485
722B53BD5271B51A2CC50C15C7070FC90810C20711AF1C2C95516E5E5B78CAD5E9A4B5C9
95ACBEC3D4E3BEC6D94D45666E3455951C31A3091BA20B1F9A172DA2364BA74C628D425B
7A334F77334E6E30479C7D86D3CED3D1D0D5D1D2D7CECFD4CBCDD2C9CDD4C8CBD2C8CBD2
C7CAD5C6CAD4C8CBD2C8CDD49294A05C6173687386425062808E9D93A2ABAAB3BBBBBFC6
B3B1B7B1A3A891746900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB82350BC2A7CA043AA8662AE8A6BB18F72B19075B3937AB6967C
BA987EC09F87C6A78FBB9A83CAA995CFAC9AD8AFA0DEADA0E5A69ABC655AB64F43D36C5D
D2745FBF654EED927CB85545DD7767C87663E2B29BD5B7A0D5BBA5DAC1ACDBC4AFDEC9B6
DFCAB9E2CDBCE4CCBBDFC7B5DDC8B4E0CCB7E5D1BCE7D2BFE1C9B7E4CBB7E2C8B4E6CBB6
E6CCB6E9D0BDE9CEBEE8CFBEE8D0BEE9D1C2E4D1C7D4D0D58685A17F5A82B35476C03143
CB212AD21F23D21B1DD21B1CD31B1ED21A1ED11A20CE1A22C71823C41E2DC0263ABD2F49
B42C46DB4B5FCB2732C80D13CB090FCC0910C80910B20D15DC7B88A6889C87879F8A93AD
2E3E62757CA16852757A39589C263BA70917B0040FAF030FAB0311A60615A308189D0A18
980C1890151B852E30D3AEAFD3CCD1CECECFCFCFCDD0CFCECBCCCEC9CCD0C8CBD0C7CCD2
C8CDD4C4CBD3C4C8D2C4C7D0B1B3BC9295A07A818D858F98879199879198979EA5A6AAAF
A4A3A9ABA6A9B1A19D43B42B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0047B6267F634992745BA88668AB886BAC896FAD8B72B08F77B09076B5967C
BC9C83C1A38CC6AA95D1AF9CD6AB9ADDA899CA8477AC5448DE7C6EC35B4CC65544D8634D
C95D45D26F56E28069BF5944E27968BA6451E6B09BD7B7A1D9BFA8DBC2ACDEC6B4DDC6B6
DAC3B3E2CBBBE0C9B9DFC8B8DBC4B3E2CAB8E7CEBDE7CEBDE2C9B5E3CAB4E2C9B3E4CBB5
E6CDB8E7CEBBEAD0BFEAD1BEE9D0BEE7D0C0DFD0CC8C90A85B4D7FA94C79C62438D41D20
D21D17D0221ACD251DC92623C32626C42A2CC4282CC22229C21F28C21A25C21823C01421
C01420C2121BC81217CB0B0ECC080EC8050BC7060CBF0910B728349740585C2B4D805579
6432597E375C9C324EA5192AAE0915B3030EB3020CB1020BAF020AAD020AAD030BA90509
A00D0E91241DC48C85DCCCCACFCDD0D1D0CAC3BEA5CBC2A6D0CDBFCDCFCDC7CCD1C6CCD4
C7CBD4C5C9D2C4C6D2C4C7D0C1C3CF6368792E384A64738346586467767E9CA4ABA4A8AC
97959A938D9193878546BC3600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25DB11648D3C5C4D4A272429766C65A38974AA8971AB8A73AC8C76AD9079B0947EB69A84
BDA18BC3A792D1AF9CD39E8FB86A5EDA8272B45845C6604CC9624EEF8F7BD7735ED2614D
BE4C37E0705BC14F37BE5339F08F78AA5540E7AD97DCBAA5DABEAADBC1AEDBC2B1DBC4B4
DCC5B3E2CBB8E0C9B7E0CAB5DEC9B3DEC9B3E5CFBAE3CBB8E1CAB5E5CDB7E3CAB3E5CDB5
E7CEB8EAD0BCEAD0BDE9D0BCE8CEB9E7CDBCDCCCCC5A6183684E86AC3459CD2225D02E21
D04938E17364DB8074C97C76C98585BB787FB5717DB26979AF5F71AC4E61AC4252B03947
AE2A38B32430B41923C01218C60B10C9070EC9060EC4060EBB0A15B81C2CB02437A51C30
A4152AA80E21AD0715B2060EB3010BB5010AB4020CB00209B1050BAD0509A9080A9F0F0D
972A24C4897FDAC7C3CFCECECECED1D3D2C5B7AB7DB8A65DCEC392CFD0BDCACFCEC7CCD1
C9CDD6C7CAD2C6C8D4C8C8D2C7C8D6676A7C585C6F5B67783E505D80919A9DA9AFAFB8BA
C5C8CDB3B2B7B1A9AC85726800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0024DB13
816850403C400E19360A173569676EA08A7AA78973AC8F78AF937EAC927EB49B88B99E8E
BDA291C5A896D4AB99B16B5BBB5646B44835D87A61DF836ABE5942D26755C45743D56A53
B0432EB94C35CB6A4ED7896DEEA88FA45A42E5A891DDB8A2DABEA9DCC0AFDBC0B0DDC4B3
D9C3B0DDC5B2E0C6B7E0C9B6DDC7B1DDC6B0E6CEBAE3CDB8E0CAB3E2CDB4E0CAB2E6CEB6
E6CEB7E8CFBAE8CFBBE9CFBCE7CEBBE6CDBCE2D1D06D6F8F5D437CA3395BC63935EE8570
FDBFADFAD2C5E2C1B4E5CABEE7D0CADAC5C2D2BFC0E0CCD3DCC6D2C4A7B6A9829492697E
8458747C4B6A823F5FA83A4FB5121EC3070FC5040CC7050DC4060EBF0811BB0911BA0A10
B8070EB9070EB6040BB40309B40209B3030BB1050CAB0608A70B0AA0100C9B1F19A64E45
D5A39DDBC9C5CFCECEC9CED0CDCFD2CFD0C8C5BC98B8A255C0AB5CD2CB9DCED0C2C5CDCC
C6CDD3C7CDD5C4C8D3C6C9D3C7C7D59594A38887956C727D7C848A8C96988F979A999EA2
AAABAFAEADB3B6B2B8A496941AD10E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC12765F48
2D2E390D1E42011648031541595B6B9F8E82A88E7AB09681B29A87B69D8CB69B8DBEA294
BDA18FBD9F8ACAA28DAB6D59DD8673B14C39D6715BCE6851C65A45BA4834C0543FE48E74
D1896EDC9C7FDDA98CDAAE96DDAE99BC8770DDAD95D7B69FD9BEAADCC0B1DCC0B1DEC4B2
DBC1ACDDC2AFE2C8B6E2CAB9DCC5B4DDC7B4DFC9B4E4CDB6E4CCB3E4CBB3E5CBB4E5CAB5
E6CAB8E7CCBBE8CFBDE7D1BCE8D2BDE6CFBDE4CFC6A69CAF5547728E516CD27E78F3BBA6
E6C9B6E5D2C3D7C5B5D6C4B5DCCFC5E8DEDADCD1D1DED4D3E8E0E0D7CBCDCAB7B7CEBFC0
C9C1CE9D9AB646436D603C69A12B47BB0C19C70710CA0810C6030CC1040BBD0A0BB6110A
B2110DB0110FAB0D0DA90F0FA80E0FA5100FA01511971C159C332AAE5F53CE9A91DBC2BD
D4CBCACDCDCFCBCED1C9CED2CBD0D4CDD1D2D2D0C2C7BB8DB7A159BFAE69D0C9A3CACDC2
C7CBCEC6CDD3C2C9D1C4C8D2C4C8D4AAADBA52566A303A4D74818B5C6A71869197A6ACB0
A6A5AAA29FA6A09AA292848737A82400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0094725542393E
0A183F061D5601165604184E454E679C908CA79082A89181A89381B79E8FB99D8EB99E8B
B59A83B89C84C09F87C99B85C87E6CB34C3CCC5746AD3B26E57D66C15B46D8735FD4866E
DBA68AD4AA8FD0AC92D0AF97D2B09AD2AF99D6B69ED8BCA6DAC0ABDBC1B0DCC3B0DAC1AB
DAC1AADBC0ACDFC6B3E1C9B8DDC6B3DBC4AEDFC6AFE5CDB6E4CCB5E3CAB4E5CBB4E5C9B6
E7CCBBE7CEBBE8D0BAE4D0B7E4CFB7E2CCB7E4CDBDDBC9C7847784C3A7ADE7C0B3E4C6B1
DDC9B3D8C7B4DECEBED8C6B9DCCCC3EADED9DDD2CDCEC2BBD2C6C1DCCFCED5C7C5DBCFCC
E1DADEE0DDEC888BAD322A6195446DB01327C40912C7070DC8050DC00609BB1911D55846
B75344AE5044A447459F4A49AC5B54B1685DB97B6ECA9A90DAB8B1DAC7C3D3CBCCCECED0
CBCED1C8CCD0C8CDD1CACFD3CAD1D7CAD0D6CDD0D1CFCEC0CFC09BB8A666C1B071D4CDAF
CACCC7C6CBCFC3CAD0C2C9CFC5C9D2C0C4CE40425843455D595F6F525D688C98A1B0BAC0
B6BBC1C3C4CCC3C1CAB3ACB05A894500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC10A6835D937B6D4B475B
06164902175901185E051B5A333D6290878AA69184AE9785AF9783B59A88B49685B3947F
B79A7FB99C80BD9E85C59C84C47E69A43E2AD25B4AC85744E68570CA6A56A4442CBA6D52
D4A285D0AC90CEAD93CCAC94CFB09ACFB4A0D5BBA9D6BDACD8BEACDAC0ACD9BEABD9BEAA
DABFAADCC2AEDFC8B3DDC7B2DDC6B0DCC4ABDDC4ACE5CDB7E4CEBAE2C8B5E5CBB6E1C7B2
E4CAB7E5CCB8E8D1BBE6D0B8E4CEB8E4CBB9E4CCBBE4CEC0DAC5BBDDC8B9E1CBB8DCC8B2
DAC6B0DAC7B6E8D7C9DBC8BBD7C2B5D9C5BBD8C8BFD6C4BCE0CDC8EDDCDBEDDADCD3BCBD
E2CACCE3CCD4C7B0C6553C678A426DB12239C20A16C6070DC30409BF080AAD0D0CDB6B66
8F4C4C916266AA838E5A3D4EC8AFB7E1C8C8E0CAC8DBC9CAD4C9CBD3CDD1D0CCD2CDCED2
CBCDD1C8CCD0CACED4C9CDD1C8CDD1C9D0D2CCCFCECDCFC6D4CDB6D3C58DBBA854CABB7B
D0CBB2C9CCC8C6CACEC6CBD1C4C7CFC8CBD371717F72707F6E717A868C938D949C9398A1
9C9FA8A2A5AFB4B6BFBCBAC18C7B7900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006E973BAF957E917F7B54546B
06174A01155C011764031B6124305B968C94AC9689B19886B19583B0907DB08F78B39178
BA997DB8997CC09F84CA9D87CA806DBE5A44CE5C46A93A24B3563DD68E72D29679D4A587
CCA68ACBA98DCBAB8FCBAC93CCB39DDAC8B8E7D7CCE1CDC2D9C0B2D9BEACD8BDAAD8BFAC
D9C2AFDAC4B0DBC5B0E2CCB6E0C8B1DBC2AADEC7AFE4CDB9E3CBBBE4C9B7E1C8B4E2C8B4
E6CBBAE2CCB9E5D0BCE6D0BCE6CDBCE7CFBCE6D0BBE4CDBBE2CBBADEC9B7D9C9B7D8C8B6
DAC0B0DFBCAFE2BCB1E1B9AEE7BAAFEABBB5FAD0CEFACBCDE6B1B3F1B8BDEEAEB4DB9096
D48288E48F98E6909FAF516BB43A57C62739C10812C4060DC2050BC2060CB6050DBE2932
A32C3B953243B55D707E2E47B36E85D296A4D59FACD9A9B5DAB3BEDBB9C3DDBFC9DDC6CE
DAC7D0D5C7CED2C8D0CEC9CECCCCD0CACCC9C2BDACCDC49ED0C387C2AF51C0A82DBFA938
D3C582D1CBAECCCCC4C8CCCBC4CACDC6C9CE8C8F9D464D60616E7D81919E73828C97A0AA
AFB2BDA6A6B09E9EA69A979F7F6E7000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007CA44BAF98819484749D8F8B4D4D62
0D1F53021962011668031763192654968E96AA9387AE9383AD917FB3937FB49279B59277
BA987DB8997DBD9C80CD9B839A4832A8482DD57F60CF896CD59B7FD0A387C8A489CAA98F
CAA98FC9A98ECAAA91CAAD94CCB8A4E9DFD5E7E0DDEADED9D2BFB4D4BBA9DAC0AED9C1B0
DAC4B1D8C2ADD6C0ABDEC6B2E3CBB5DBC3ABDEC6B0E1CCB7E3CDBBE2CAB8E2CAB6E2C9B6
E4CBB8E2CAB7E4CEBCE4CFBEE5CFBFE6CFBDE5CFBBE3CCB8E2CAB9DCCABCB8B5AFB6B0AF
D5AFABE19590DE7F7CDD7272D45E62D05259D24E5ACB424FC4343EC32E38C22631C01D27
BF1921C31C24C21822BE141FC00F1BC20A13C4070DC3060AC1060BBF040BBD040CB6050D
B10813AA0914A70A17A40A1AA00B209C0D229C122898142B981D339924399D3046A34456
A95566B16877BF8290C599A5CFB4BBD4C8C1B7AB8AB39F57BDA43BBCA21BBEA40BC0A610
BBA528C4B45CCCC28EC8C7A7C8CBBCC7C8C5ACABB32B2E415E6577505C6C4B596895A3AE
AAB1BDB2B5BEAFB2B7B6B7BC998F9118D00F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0079A246A89480A99D919D9388AAA19C595D6F
172B61021A6702156501145D1524518C868DA28A80AA8E7FAD8E7CAD8E79B5957CB7947A
BA967DBA977FBD9A82C3987EC2886BC38666CD9A7CCBA289C8A58DC5A78FC2A690BEA58F
C5AC97C3A991C6A990C8AD93CEBBA8E7DED5E7E0DEE2D6D2D0BBAED4BCA8DBC2ADD9C0AF
DAC4B1DAC3ADDAC1ACE1C7B6E1C9B6DBC3ADDDC3AFE0C8B5E1CAB7DCC8B2E0CCB4DDC9B4
E2CDBAE1CBBAE3CCBCE3CCBDE3CDBDE0CBB6E2CCB6E2CCB5E4CEBADDCDC3787C8A4E5472
A46B82B12B37C92226CB1B1DCD181AD0191CD0181AD3171AD31518D31617D31516D21414
D11312D21513CD1310C9120EC81211C30D11C30C13C3070EC2050CC2050CC1030ABE030A
BC040AB7060AB6090DAF050AAE060DAC060EAD0611AA0611A90814A80714A90A19A00716
9C09179B0C1A950E208D1627842E3BDAB4B5D5C8B8C8BC92C3AE5FBCA228BCA209BBA202
BDA508B8A213B59F28B2A343C3BA77C9C297C2B99E6E665B7370737173797D8388888F96
8C8F97909197949298A1A0A6AB9FA435A82600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00769D40B4A28B9C9087A79D969489819D938E757485
09194D02166100115D0112540D1A457D7882A0877EA7887CAB8C79AE8F7AB5927CB8967E
B9977DB9967EBD9982BF9A80C39A7FC2997EC39F85C2A38EBDA28EB39D8D9C8B7D8D7F73
958A7DAEA18EBEA890C7AD93CEB6A1D8C4B8D9C6BDD5BFB3D1B8A6D8BEA8DABFAADBC2AD
D8C0ABD8C2ACD9C2AFDDC6B4E0CAB4DDC5ADDDC3AFE2CAB8E0CAB7DDC8B2DDCAB1E0CCB4
DFCAB5E2CBB7E3CAB7E0C9B5E2CCB5E1CBB4E1CBB4E3CDB5E3CEB6DEC9BCAEA9B6364066
996D90B22D3DCF1E1DD41912D51A11D31B11D21D12D11E13CF1E16CE2119CB2318C72318
C5231BBF2219C1281EBD291EB62722A11721A61325B80F1BC10710C2050CC1020BBF020B
BB070AB51711AB1B15A41B14A11B149D17139E14129E1212A01111A20F0FA50E12A40B0F
A50A0EA2080DA108119E0914870D19C18286DAC9C5CFCCC2D6CDAFBCA957BCA31ABDA304
BFA603BCA004B39904B19B0DB19D1CB2A02CB29E3A8A783A45423769727B8896A0818F95
A8B0B4AAABB09C99A08D898F8B7C8235A72600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0051BE2AAE9882B8ADA69A9491C1B9B699908DB8AEAE92909F
13204E0B206401155B0214560B18477A7681A38C83AB8D80AB8C7CA98A77B3937FB4947C
B29378B9967EB99781BA9B83C1A187BD9E82BFA188B99F8C9D8B7B82726686766B877A6F
766C65726B61A89C89C5AF98D0B6A0D2B8A5D2B9A8D1B7A3D5BAA5D9BEA8DAC0AAD9BFA8
D5BCA5DBC2ADD9C0AFD9C2AEE0C8B2DCC2ADDBC1ABDFC7B4E1CBB9DFC8B5E1CAB4E1C9B1
E0C7B1E2C9B3E1CAB4E1CAB4E3CCB5E3CCB5E4CCB7E3CDB9E4CEBAE1CBBBD5C7C667657D
81637FB5545CC03226C7331FCA3D27CC482FD2563DD8624DDA6D5DDE796BDF8474E28F7F
E6988BE49C90DF988CDA988AD49A957A4459742E53A82841BA0A17C1030DC2020CBC0208
AF0808D85F54D08075B1756DB27E7A9A69699D6A68AE716AAE6864A95B57A34949A03D3C
A034319928249720219116198B181D90494DDEC7C8CCCBCCCFCDC5C6BA89BAA130BFA50B
C0A402BFA404BAA00AB39D06B39C04B39D06B19B0DA39025332C084B5056505D6B62727C
A8B2BAB5BBC1B1B4BAAAA8AEABA1A440B63500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0026DC11AA8F70B3A49DABA4A3ABA7A79B9797ADA6A6988E8F938E9A
232C5303155502145B021459061448726F819E887FA68A79AA8E7AAB8D79B1917CB2937A
B4967CB6987FB79881B89A82B89D81B99E82B8A08A9E8D7B8274669D8D7EAB9886AC9989
94857B6E6861797368C3B19FCFB5A0D2B8A2D3BBA4D2B9A2D6BDA6DABFA9D8BDA7D7BDA6
D7BDA6D8BDA8D8BDA9D8BFAADEC5AFDEC4AED9BFABDEC4B2E1C9B8E1C8B7E2C9B4E2C9B3
E2C7B3E1C9B4E1CCB7E0CCB5E1CBB4E2C9B5E2CBB7E6D1BCE4CFBAE0CBB8DECBBDC3B2AD
C1A5A3DEAA9FE09C89EAA793E9AD99ECB5A0ECB8A2ECBBA6E7B9A9FDD3C7F1CAC1E1BBB3
F3CEC5EBCCC3CEB4ADBAAAA6D0C0C5B397AC622B51B3435FB60D1BC2050CC3040BBF0409
B2080BBB4140DC9EA255374968647C7A8397657080CDD0D7D0CCD2CFC1C7D7BEC3DCBBBB
D9B2B0D0A7A4C59795BA8482AA70718F6466D2C2C4CCCDD1CBCCCBCFC9ADB9A44BBCA511
BFA504C0A90E8F7B079E8F11AC9E10B7A40AB39B04B09B198B7C337B776474787A858E93
90959B8F949893959A908F94A69FA2806D6800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0078A045BCAB9EBBB3B39E9C9DC9CACC989799CDC9CB91898CBCB8C2
39406102124C01145A011459051348625F7298827AA68875A88975AA8B77AF917AB0917A
B2937CB3947CB7967FB99980BB9C80BB9F85B19D8A7D7164918577A99787AE9985AF9C89
9F9084766F6B69645FBAAA9DD0B6A3D3B9A3D4BAA4D3BAA4D7BFA8D4BCA4D5BBA4D8BFA7
D7BEA7D7BCA5D7BCA6DBC1ABDCC5AFDDC7B2D8C1AFDBC5B3E1CAB7E0C9B7E0C9B7E1CAB7
E4CCB8E1CAB5DEC8B3E0CAB5E1CBB7E1CBB9E0CCB9E4CFBBE4CFBAE3CEBBDEC9B8DCC6B5
DBC1B2DAC1B2D3BEB4C6B3B0B89D9EBF9998D9A7A1EDB1A7EDABA6F4B1B1EDA4A7DE8E90
D08080C48281E0B9BC6460757A7595A8708DAB3E56C32F3FBB0A14C4060DC3050CBD0409
B8070DAD131DB740527C2542572A4DA297B079859B899BB75C648271617D9A768ACCA4AD
D4AFB5D8BABDDCBEC3DEC3C6DCC6C7D3C6C7CCCBCDCAD0D3CBCFCFD1CFB9BAA858BBA414
BDA504BDA7127D6B183D38035B570C9E971BAD9F0CAF9E0EB09F31867F4397987D9AA295
A6ABAAAEB3B5ADB0B3A4A3A8928B9179646600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0029E015AC967EB4ACA9A8A6A9A3A5A8B9BDC0AAABAF9F9CA18E868C908893
40435E031146000F530211570312465B5A6E99847DA08472A38673A78A75AC8C77AD8C75
B2927AB4957DB6957DBB997EBB9C80B99E859A897A736961978B80AA9889A99887A9988A
96898278717068635FB3A496CFB6A0D2B8A2D3B8A4D6BCA7D6BDA7D2B8A1D6BAA3D7B9A3
DBBEA9D7BBA5D6BBA4D8BFA8DCC3ADDCC5AFD8C2ACDCC4B0E2C9B7E1CAB8E0C9B8DEC8B8
E0CBB7DEC8B3E1CCB7E1CAB5E2CAB7E0C9B5DFCAB5E2CDB8E8D3BCE6CFBDDEC8B8DCC6B6
D9C4B6C9BFBE8587977B6A80BA7C8EC86370C94A51C83A3DC93238C62A33C4232CC42026
BD1D23AB2227DC868E957E993E356590476EA9152ABD0A15C5060FC4030BC2050BBC0509
B7060BB3060FAB0614A10A1B931D32B67A879E94A920264C60436B86304D8E192E901826
91212F932E3D9A3E4DA15262A66976C5A7ADD1CCCFC8CFD2C9CECDD1CFB6B6A34DBAA211
BDA503BEA8117C691B100C001519013335028F8814A79A14A99916948614978931928B4B
81805AB2B3A3B4B7B3B7BABCAEACB1998C8F18D10F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A48862B5AEA3B1B1B2A0A2A5C7C9CEA6A9AEC5C6CB8E8A8EC1B8BD7E737D
7E7D950C184702104F01105206134955526A9B8582A28677A28671A78B76AA8E78AC8E76
B09175B3947AB6977CBA997DBD9D82BCA18B8C7C6F766E668F867E9E91879A8E848F8780
817C7A686868696660BEAD9DCCB29CD1B59FD3B8A2D6BDA5D5BDA5D1B9A0D4BAA2D7BBA4
D6BAA4D6BBA5D8BEA7DEC3ADDBC1ACDFC7B0D9C4ABDBC4ADE1C8B3E4CAB7DFC7B6DEC9B7
E0CBB8E1C8B6E4CAB6E4CAB5E2C9B6E2CBB6E0CAB3E1CCB6E4CFBBE1CBB9DDC6B5DBC4B7
D6C7C37E8699505479B57998B73242C81D26D2181ED6171AD71319D8131AD51014D51313
D01312C21815B93637D39BAA3F325E7E4C7BA31C35C10C16C6060CC6070CBF0709B8110F
A80E14A20716AD0717AF0310A60916A43B46966E851C123C7C4C70871127A10614A4030F
A405129E05119B06139A0B198E0E1C8B3943DDC1C7CCCDD1CBCECDCFCAABB39F3FBDA50F
BDA402BEA7127E6A1A1B140324280E33380A807C28575207898317A59B19AB9B14AA9A1A
A39228A092459791679392848D8B8794898831A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF004DB926A59384A6A7A8ABB1B4A8ADB1BFC2C7A7A8ADB7B6BB908A8FA2989D837780
7A7890091345010F5101115306154C504F689784809F8372A58770A78A71AA8C75AE8E76
AF8D70B59378B6967BB9987DBC9B82BB9C898A776C6D67637C7875847E7B827E7B797775
6D6F6E5F6260817C72C6B19FCCB29CD0B69FD3B9A2D2B8A1D4BCA4D5BCA5D0B59ED4B8A2
D5BAA4D6BCA6D7BDA7DBC2ACDAC1ADDCC6B1D9C4ACDAC3ACE1C8B3E0C9B4DFC7B3E0C8B5
E1C9B7E1C8B4E4C8B5E4C9B6E2C7B5E3C9B8E1CAB6E1CBB6E4CFBAE4CFBBDFC9B9DCC5BA
D3C7CA4755775D5F8EAE5E79C1232BD61719DA1312DC1412DC1112DD1315D5120ECF1A10
C61D11BD2012AE291DCB817F75617E4A37689C3A5BB9121FC6080EC5090BB70A07DA5951
B1565E690F2B8C0A28AB0517B104109D0B16AC53684221436A43618422329F0913AA040C
AB030CA60109A5010BA4020A9E070E861219CA959BD4CBCDCDD0CDC6BE9FB49F41BDA415
BDA405BEA60E8A72162D1C05343216141600847E3B302B001B1D00636414A2991CAB9A10
B09D11AD9A18AC9D3CBBB17B9F977F84776B31A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00729D45B0AAA6A3AAAEA5AEB0C3CACDA7A9AEB8B9BDA2A1A4B9B4B58B8383ADA4A7
66667B18255403135301105204124848476097857F9F836AA9895FAD8D5AAD8C5DB59265
B08E64B29171B5957BB8977EBC9982BA9A87967F7567605F6B6B6D7271736E6E6E696967
6667636E6A63AE9F90C9B09BCDB19BCFB59FD1B7A2D0B7A1D3BBA2D1B69FD6B7A2D5B9A3
D4B9A4D5BBA7D4BAA7D6BEAAD6C0ACDAC7AFD9C5ACD9C4ACE0C8B3E1C8B4DFC5B1E0C5B3
E2C9B6E2CAB7E3C9B8E3CAB7E2C9B5E2C9B8E1CAB9E1CCB8E1CEB7E0CFB9DCCAB7DCC8B9
D8CAC7656E8D444E7EB2809DB22D36CF1B1ADA1714DA1310DB1211DA1411D02216EA6753
E88169E1876FDC8C77D5A093B29FAB36335F824774A7172CC20A14C3070DB5090CD66160
C1848D5D3350630E38A00C24B50712AF080FA125309B65793C244081465C8E1622A0040E
A9020CA70008A8030AA3080A9A0E0D8A1718945154DBCBCCCED0CFCDCCBCBFB379B8A536
BCA513BDA70AB59B185F44063F2F052922008D823C3A3205181902292C0777722070660D
A69A18AA9B09AE9C14B6A73AB2A35CA798703FB42800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00967F689D9FA2949FA5AAB3B9B8BDC398999FB0AFB3A5A4A6B6B2B3888382A49B9E
6E6C7D16204B02114F021050020F45424058978377A58756BC993FC39D33BA922FC59D44
BC974FB79462B59374BC9982BC9985BC9B88AD9284726460646163636165656263736D68
84796EA08F7FC5AD98C7AB95CCB098D2B6A0CFB39ED1B6A0CEB49CD1B49DCEB19CD3B9A4
D4BCA9D2BBAACEB9A8C7B5A3CEBEABD5C4AFDEC9B3DDC4B0DEC5B2E2CAB7DEC6B5DFC4B3
E4CAB8E2CAB8E2CCBBE3CABBE2CAB9E0C9B7E4CDBBE3CCB8E2CFB7E1CEB8E2CDBADFC7B6
DEC8BCBBB3C1515D836B678EB67389B52E36CC1C1ED81514DB1412D71411C71F18FB8F83
F3AC9AE1B09BDBB39ED2B5A3C9BBBB5A5C7D5B42749C304EBB0F1DC5080EBC080CAF2225
D2888B8A6A7C42103B870D31B00518B2040D9E0C15B467727862773E2A437E3D4E8D131E
A0050EA60108A304079F1C17BB6058A36359895F5DC7BCBCCCD0D2CCD0D1CECCBDC7BE89
B8A941B9A415BEA50DBA9F179B82164936009A882F4F410E211E031D2200928F4359500E
6F650FA29919A79B0FB3A316AD9A20A08B3746B92000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
27DC13806E628F93999BA3ABBCC1CA9D9EA8B1B0B7A9A6AAA7A3A5B1ACADA8A1A2897F82
8F899711173C020C46020F4C041143434356978369B39440C3A11BC8A50EC7A017BD9528
BE9A46B79359B49170B6947DB7957FB8977FBA9984A1877878655E7A6B6593847A9F8D7E
AE9884C7AD97CAAE98CCB198CEB29BD0B49ECFB39DCDB19BCEB39CD1B69ECDB29CD3BAA5
CCB9A7B5A495AD9B8DAF9E8FA8998ACBBCABDAC5B3DAC1B0DFC5B4E3CBBADFC9B8DDC7B3
E1CBB7E1CBB9E0CAB8E1C9B8E4CABBE4CAB8E4CDB8E7D1BBE5D0BBE2D0BBE0CDB9DFC8B6
E0C9BAD9C7C1BAB4C0626687695F85B27993B3414CC42226D31618D71314D01416C82B2B
E0706AEC9E93E3AD9DD4B4A3DDCDC7A6A6B9332E5F914C73AA1526C00810C1070DAD0E11
D37274BE95A148244A6F0F3AA80820B50310A8050E9D2F35B1878D8579884B344B7F3B4F
89111D9D060DA2040A921310D58D88D7B7B2BEB2AFBCBCBDCBCFD4CACED7CBCDD2CECDC0
C8C08FBAA843BEA518BEA307BDA30CB49C12B59C1D6853102D24011B1B00807D36554E05
58520384801F756D09A59817B2A014A28C1848BB1200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
50BF309A928D858E98A5AEB8B2B7C19B9CA3B1B0B6A8A5AAA9A3A7B1ABB0A9A2A58D8286
A19CA8192042020D45010E4B0311444343549A8554BE9E29C8A70CC7A704CAA613BA922A
B28F4EB08E64B08E71B39279B4937CB5947DBB9882BA9984B69886AF9484B39985BCA089
C6A991CEB099CDB09ACAAE98CBB099CCB29BCCB19BD0B69FD2B7A1CFB49ED1B7A1CFB8A4
B19F8EBEAB99D2BBA8D4BCABC4B2A2AC9C8DDBC9B9D9C3B3DBC4B3DFC8B7DDC8B6DBC8B4
DECCB9E0CBB9E1CCB8E2CBB8E0C8B5E2CAB6E2CBB5E6D0BAE2CEB9E2D0BCE1CFBCE3CDBC
E2CBBADEC9B8DBC9BECEC3C58F8CA05A547393738EBB6778B62E35C91B1ED31418D01318
C61B1FC12E2ED6645FE7A299DCBAB2D1C6CD44466B6444709C2740B90B15C1070DB90B11
B93740B86F7F7B4A6A680F3AA10A25B2030FAF040D971017C3868AD5CAD0938F9F48324C
7D3D5287142399051099081090222ACC939ADAC7CBCCCDD0C9CDD2C7CED4C9CDD5C8CDD0
D0CFC2C4BA87B6A235BDA30EBBA203B9A103B7A008A68F1465510A2E22008A7F2F706510
665E0F7A74205F5704675D0BAEA11DA997127AA71800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
729B457C7A7C697581A8B2BF8A8E99B1B0B7ACAAB09C9AA0B7B5BB9B989EACA3A89C8F95
867D8B33375803104801104E02114342434A9E8742C19F1BC9A707C7A602C8A50DBF9826
B5904EB08E6DAE9078AF927BB1927DB59681B99981BF9D86C09F89C0A18BBFA08BBFA08B
C9AA95C9AC97CEB09BCBAC97CCB09BC8AE97CDB19CD0B49FCDB19CCFB59FD0B6A0C5B09C
AF9A88D4BCA8D4B9A5D6BCA9D5C0B0A49284D7C4B4D9C3B1DCC4B3E0CAB7DEC9B7DDC8B7
DDCAB9E1CCBADFC9B5E1CCB8E2CFBBE1CBB7E0CAB5E2CDB9E2CFBBE1CFBBE5D2C0E6D0C0
E3CCBBE0C9B7DFC9B7DAC6B8D7C7C1BCB1BA736E89665A7CAB7C97B74E5DC02128CE1317
D01013CC1114C11719C13D3BE0908ACFADA890899F362E5A944467AF1122C00710C0070E
B40C15C13C49BB4B63981B37AA0B1EB2020CB2030BA007138F36449A8892CFD0D99C9DAD
49385174395187192A9807129A07148A1B2AC48A96D5C5CACBCCCFC5CBD0C7CED5C5CCD4
CBCFD0CFCDB8B0A559B9A523BDA50EB8A002B69F02B6A108AF98148D780F917D17807012
615508665E1D696210716C0E9D951E9C90119F8A1352C10F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
B4997F9699A196A5B6A9B6C39098A1B7BCC2A8AAAF9C9CA3B6B7BC949298BAB5BAA69DA3
918A9555587803114501114B0710394C4633AF9533C3A40FC4A502C6A802C5A405CAA41D
BD9642AF8C68AB8E7AAB907BAF937CB3967EB89880BB9982C09D87C29F89C09F88BFA08B
C2A691C7AD9AC8AE9ACAAD9BC9AB98C8AD98CEB39CCFB19CD2B39FD0B49FD0B5A1C7B19F
AD9A8AD2BDADD3BDACD3BDADCCB8ABAE9C8FD9C5B4D6C0ADDCC6B4DEC9B8DDC7B5DDC5B4
DDC7B6E1CCBBDFC9B6E3CEBBE2CCBAE1CAB6E0CAB4E1CBB6E3CFBBE4D2BFE3D0C1E2CDBD
E3CBBAE1CAB7DFCAB7DAC5B3DBC7B5D9C6BCD1C4C9989AB3494F78886A8CD16D7CC11F22
D01211D10F0ECE0E10C41416B62E2BDD948CDCC5CE3C3A5F7547729F1D35BC0915C2070D
BD050DB60911AE0713AE0816B0050FB4030CB4020BAA040F931B26885A61CFCDD1C7D0D9
9FA6BB382D49783D528A13209D0512990614881B2AC6909BD3C6CCC9CCD0C6CCD3C4CBD4
C8CCD2CACBC4B2AD82C3B663C1AC38B8A110B8A104BAA403B49B03B19908AE950BA68E11
6550047465216D631D444000958F26867D0E28E20654C51000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
BCA99777808D697B8F6B7A8987919A9DA3A99D9FA6B0B1B695959AACABB0979298A49CA3
867D89393A5904114208143E1F20207B6822C1A31EC4A606C4A902C6A900CAA804C7A215
B48C35AD8A64A98A76A88C79A98F79B1937DB6967EB9987FBC9B84BD9D87C0A18BBFA08C
C5AD9DD2C1B3D6C5B8CFB8ABC5AA9BC8AD98CDB19BCEB29CCDB09AD4B5A0D2B6A2D4BBAB
A59084C6B4A7CDBBADC7B4A5AE9C8DCAB7A8DBC7B5D9C4B2DCC7B7DEC8B7DCC2B1DEC4B2
DFCAB8DFCCBCDCC9B9DECAB8E0CBB7E2CCB6E3CEB7E2CEB7E3D0BBE5D2C0E3D0C0E4D1BF
E1CCB9E1CCB9DEC9B5DFCAB6DCC9B8D5C6BECBC2C6AEACBE736B908F688DE38194C6282D
D01311D3100CD10D0CC80B0AB91511B95145DAAFAC776E8A42315F9C3F5EB10E1CC0070F
C0040ABC060BB40B12A80C14A30716AB0514B1010EAD020B980911A5565DC1B7C3ABBDD0
7783A2443956753E54A83D489B0510A0020B980813882430D2ABB1CECACDC7CDD4C6CDD7
C6CAD5C6CBCFCCCEC5CFCEAEC7BB75BFAB36B9A414BAA307B39C02B59C03B09802AF9707
A38C0C9B87148270184C40039E922E897D1054CC1400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
CBB9A788919D798A9D83909EB0B9C0A2A6ADA1A1A9BDBDC48A8A8FC5C3C98C8990C4BFC6
918A95454866132146282A26806E25B99C1EC2A00CC2A30BC4A707C7A802C9A903CAA614
C19A36AE8A58AB8A71A98C76AA8D77B1937BB6987FBA9B83BC9C85BE9E88BDA08CC4AD9D
DDCEC5E2D9D5DFD6D2E6DAD3D3C1B6C7AD9BCAAC96CEB29BCEB29CD2B6A1D4B9A4D6BEAB
CAB5A4AE998CAE9A8DB39D8ECCB7A4D7C1AFD9C4B2D8C3B0D7C3B0DEC8B6DBC5B2DDC7B6
DFC8B9E6CFC1DFCBBADECCB9E0CEBAE1CDBBE3CFBCE2D0BBE3D1BCE2D1BEE4D2C0E4D0BE
E2CCB9E1CBB7E1CAB9DEC9BAD5C5BEB2B1BB72758F907491C87B95C54C60C2242FCC1418
D2100FD00E0ACD1108C3160AB32412C06451D1A69BBAACB835315A854D75A4192EBC0815
C0050EB2080ACF524FC1666E6B122F880B2DA70519AD020CA5050F93253658385A232C59
4B3E6784435D902434990F18A1020AA60108A4050C900C13985255D9C8CBC9CCD2C5CDD7
C4CBD6C3CBD4C6CED1CDD2C8B9B286BEAE56C3B13BBAA51CB8A00CB49C03B59E04B29D03
B19B04B29A08AB94117B670B7C6A1292841781B52100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D5C3B0848A985B6B7E6D7D8C919CA591949DADADB59E9CA49E9BA29E9AA29C98A09A949B
847E8743465C131C21746A2CBB9C1EC3A10DAD910F7D6601B49A10C5A605C5A208BC9615
B79234AF8B4CAD8A61AC8C70AB8B76B3927DB99882B79982BA9B86BD9F8ABCA292DACAC0
E1D7D3C7BBB7C1B2ABD5C6BFE3D3CBBFA898CBAD97CFB09AD1B49ED2B7A2D3BAA6D3BCA9
D5BEACD7BDACD5BCACD7C0AFD9C3AFDAC4B1D8C4B1D7C3B0D5C0ACE0CAB7DDC6B5DEC7B7
E1CABAE3CCBCE0CBBADFCEBBE1D0BEDECDBDE2CFBEE4D1BEE4D1BDE3D2C0E5D3C3E5D1BF
E4CDBBE2CCB9E2CCBADDC8BBCFC5C8536180676892B56B87B62332CE1A21D51418D41112
D0100DC60E06C32011D1553CDA866BE7B8A1CAADA1D5C6C6646280543B69982E4FB30C1C
BE0811B00B0FCF6466EFC5D0493057590F429A0B29AB020FAC030E99101F80395B1B0D3B
6F4C6F7A14279D0915A5030BA70208A70208A5070B950F0F7F3130D6C0C0C7CAD0C4CCD6
C4CDD6C0CAD4C0CBD3C5D0D1C8C9BAB9B488BDB371C7B864B7A336B19B15B39F0BB19F04
B4A104B6A003B8A005BAA410A9950FA1911A998B1F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D3C0AA7F838D48586980909D8B959EA4A9B0B6B8BE8A898EC3C1C5827D83C7C2C7807B7F
B9B4BA494B54272708A59127C2A10CBFA011826906604D088C740CC4A50ACAA614AF8B16
B99430BF9B3ABA964DA98860AC8B75B3917DB99883B89882BB9C87BC9F8AC1AB9BE5D8D1
D2C6C2BAA79FC0A99CC4B1A7E4D2C8C1A89BCEB19ECBAC97D2B4A1D4B9A8D4BAA9D4BBAB
D5BBACD5BAACDABFB1DBC1B1D8C0AEDAC4B1D8C4B1DAC6B3D8C3B0DBC6B3DDC8B5E1CCBA
E0CCBBE0CCBBE2CEBDE3D1C1E1D0C0E1D0C1E1CFBEE4D0BFE7D2C1E3D0C0E3D0C0E4D1BF
E3CFBCE2CDBAE2CDBBDFCABECBC4C83D4F74656897A85A75C2232ED41519D71013D30E0D
CE100BBC1005E55948F49D85DBAB94DFC5B1C8B2A5C1ADA6A198A53830598A456EA31126
B90611B70A0FAC2B31E0A9B545365C3A124A850D38A80315AE020DA00514A13B5237173D
553D5F792337970915A4030AA70108A404069E15119B4033A2766FCFC6C5C6CCD1C4CBD5
C2CBD4C1CAD3C1CAD3C6CFD8CAD0D5CACFC9CBCFBFCFCFB8C6BF95B8AA5EB0A233B3A61E
B1A313B3A30CB7A508BAA807C1AC1596821284751700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C7AF9693959B6877886C7D8C7C8995A4ADB5A0A5AA979A9FA8AAAE918F93A7A4A8837D80
A0999B4E4A41564C0EB89E1EC0A00AAC8F10594404604A07A5870DC7A407C8A40EBB9713
C49E1FC8A221BB9738AC8C5CAC8E76B08F7EB79683BC9B87BF9F8BBEA18EC0AC9EE7DBD5
CEBFBABEA99DBFA799CEB9ADDCCAC0C8B2A3D0B5A0CFB39CD1B49FD3B8A4D1B7A4D4BCA9
D6BFADD7BCADDBC0AFD8BFACD4BDA8D9C3AFDAC3B2DBC5B4D7C2B0D8C2AFDDCAB4DDCBB8
DBCAB8DFCDBCE0CDBEDDCCBDDECDBDE0CEBEE4D0C0E6D0BFE6D0C1E7D1C3E0CBBDD5C0B2
E5D0BFE0CABADEC8BADDC9BBD9CAC88589A3394674A684A7B14251C31C23D31417D30E11
CF0E0EC8120EC11F1AD35D51E59C8DD6AC9ACAAFA0C4AEA2BEACAE5049695D396794233D
B40A17BA070EA90E14C56C72C4A2B74D2C596E0B3DA3071FAF020EA9050E9718285F2748
261A426C415C821928990811A5030AA005089A2521D59F95CEBFBBC9CDCDC6CDD3C4CDD4
C1C8D2C0C8D3C0CAD4C6CFD9C5CDD7C7D0D6C7D0D4C8CFD2CBCDCBCCCCB9909168969955
959640ABA63CB2A625B5A611BDA811B39C19826D1482B21E4FBE0F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C4A786A8A5A857647555657586939FA8B2BB878F93B6BABE929398BAB8BD8E888CC0B6B8
8678729C8B6890781CBA9D13BEA111806409664E0C876D0DC3A112C4A008C29F17B39216
BF9F1DC3A01FBC973DAF8D61AB8B73B18E7DB18F7DB99A86BA9B87BC9F8EBCA698E2D5CE
DCD0CBBEAEA6C8B6ABDFCCC1CCB5AAC9AE9FCCB19CCFB59FD1B6A1D0B4A1D1B6A3D4B9A7
D3BAA7D4BAA8D7BDABD4BCA6D8C0AAD6BFABD8C3B1DCC6B7D9C5B5D7C5B2DBC9B5DBC9B5
DAC8B4DFCCB9E0CCBBDFCCBBDECCBAE3D0C0E4D1C1E6D3C2E4D1C0E6D3C2E3D0BEDFCCBB
E2CFBEDECBBCDECBBCDDCABAD9C7BCD0C5C881859F505277A47F9BB45262B7232AC71619
CE0E13D00F12CC1113BF1515BA302BD97B71EAB9ADDBC1B4BEAAA38C83933425508B3A5E
A91020BC0911B2090EBC444BFCC1D0915B7B720F399E061FB0030FAE040C9809148F4157
766786443A5A75425B841D2B980A149D050C8E0C11A95E5FD8BEC0CCCACDC5CBD5C2C9D3
C2CAD3C0CAD3C2CAD6C4CCD7BCC6D0C0CAD3C4CED6C2CCD5C4CCD6C6CDD2A9B3B59EABA3
B3BDA5B5BB92BAB772B5AC41B8A621C0AA1BA4900BC1AB2283AC1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
94BD64C3BDBF6E7C8D677B8C9DADB99DA8B191969CACADB29A989EB0ACAF978E8AB7A798
8D784FB99E4CB39419B99A129A8008AA9230654E00B3971AC3A10BB99513A88728A68938
B4963CB89942AD8C54AC8A6EA98975AE8E7BB09280B39684B89B89BD9D8DBDA193C9B5AC
DDCFC8E1D3CBD9C8BECCB5A8C9AE9ECBAF9ACFB49DCBB09ACFB49FD1B6A1D2B7A3D3B8A5
D3BAA6D6BEABD2BDABD1BDA9D5C1AFD9C3B1D8C1AFDCC4B4D8C1B1D7C2B1DBC6B4DBC6B1
DCCAB4DDCBB9E1CEBFDFCCBCE0CFBEE5D3C4E8D6C8E8D4C6E5D3C4E6D5C5E4D3C3E3D2C2
E1D0C0E0CEBFDFCBBDDCC9BADCCABAD6C6B8CEC3BFA59FAE645F7D7E6883B77484AE373D
BC1A1DC81315CB0E10CC0E10C41011B51C1AC95E5AE1A79BC7A89AB9A9A94842616F3F69
9B1C34B80A16BB050EAD0F19BF3D4EA72B419E0F26AB0515B2030EAE020B9E060FAB4959
C2A6BCACAEC354496573455C832131930C189908118A0F189C505BD8BBC4CAC9D0C3CAD1
C0C9D1BEC8D1C2CAD6C7D0D9C5CFD8C1CBD3C5CED5C4CDD5C4CCD7C3CBD799A3B2344451
727E776C7362919780929261B3A84BBAA823BBA914C3AF18BB9E2200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
60CF40D5CBC95B66766173848695A379838DB1B5BC959499B0AEB0A7A098BDAB8DA9904E
BB9B35BB9817BD9B12A688125A44016A57128B7208AD8E09C3A10DB08C16B18C3FA78653
A2835AA58764A78A71A88978AA8B7BAD8F7EB08F7EB69685B99A88BE9E8DC09F8FBFA393
BFA698C3AC9DC5AF9EC6AD99CCB19CCFB69ECBB19ACDB29DCDB19CCDB29DD1B4A1D0B5A0
D3BBA6CDBBAABBAC9DB7AA9BCCBCADD7C1B2D8C0AFDEC6B3DAC2B0DAC3B1DCC6B2DBC9B2
D8C8B2DDCBB9E2CDBFE0CCBDDECBBCDFCCBEE2CFC1E5D2C4E5D2C5E5D2C4E6D3C5E5D3C5
E3D0C3E0CDBFDECBBDDCC9BADBC8B7D9C6B5D7C6B4D4C3B9C6BBBF8D84985F516A9C7185
AE565EA82B2DBA1C20C71214C90D0FC50F0FB91817BE4D44DEA193C8ACA583788C432B55
973856B0111EBC080DB6040BB30814AF0713B20710B1030BAF010AAE0309A9060F951424
844B61C5BFCEBCBCCE5F546E6F465F822C3C8E0F189708148B0E1E9A4E5BD3B9C2C6C7CD
BFC8D0BDCAD2C2CCD5C9D3DCC7CFDAC8CFD8C7CFD8C0CBD4C1CCD6C1CCD798A4B44C596A
586262828A7F8D9590949789AEAA76B1A73DB5A71FC0B027BDA43125DB0800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
59C632DED0C88189987E8EA081909D8D97A0AEB4BA98999DACAAA8ADA38ABCA75EB39820
BA9C0CBC9B08B29212705807533E02796007BA9A13C3A00AC29E0FB38B1AC29C46AC8A54
A082689F8273A28578A58879A88B7BAA8D80AB8D7FB49584B89986BC9E8ABD9D89BE9E8A
C2A491C7AB97C8AD98CBB09ACCB09BCBB19AC8AF96C7AE96CBB199CDB39CCFB4A0D0B4A1
D2B9A8B3A294AEA195AC9F92B5A596D4BEADD8BFAED9C4AFDAC6B2D8C5B2D8C6B2DBCAB6
DBCAB7DDCCBBDFCEBEDFCBBDE0CCBEE3CFC0E5CFC1E6D0C2E5D1C3E4CFC1E5D1C3E7D4C5
E6D2C6E4CFC4E2CDBFDDCABBDAC7B7D8C5B4D8C5B4D7C4B5D3C2B7D2C2BFB9ACB5796C80
6D576DA27587AE5D67AD262AC21416CB1011C71010AF1611D3776BD2AAA0B8A6AE4E3E5D
8245609E212CB31519AF100EAD1010AA0F0EAD1010A90C0DA90C10A7090FA80A119A0F1B
883B4CB9ACB8CDD1DBC2C5D4685F7967455D7F2E418B0E1C950616860C1BA15C6AD0BFC7
C1C6CEC0C9D2C4CDD6C7D0D9C8CEDAC5CCD9C5CED8BECAD6BDC9D5BBC8D2B2C1D09BADBF
9FB1BFA2B0B6A4B0B5B0B9BAB5B9A6AAA86FB4AE5BC6BF72A89B59628D2300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
2ADF14DCCABE8F96A64D5E725D708099A7B0899197ABACB0AFAA9DB2A36AB39B29B89B0A
BC9D05B6990D8F770D7C67187F6501BC9B16C39F07C4A009B69219A58031A7844FA28160
9F8172A08078A48378A9897CAA8B7FAD8E83AE8F81B09382B69987BC9D8BC09F8BC5A691
C9AD98C9AB96CAAD98C9AD98C5AA94C5AB93C6AC92C6AC92CBB199CCB29BD0B49FD1B6A3
D4BCABA39183C4B6A9BCAF9EB9A896D3BFAAD5BEAADAC5B3DBC7B5D7C5B1DAC9B4DAC9B4
DDCBB8DCCABADCCBBBDDCCBBDFCEBCE0CFBDE0CEBEE3D0C1E5D1C3E2CFC1E6D3C4E6D2C4
E6D0C3E3CEC1E1CDBFDECABADCC8B8D7C5B5D7C6B6D7C6B6D3C3B3D5C4B7D3C1B8CFBEBE
9D91A15650695D4F6CB17386AE252FC51115CB1010BA150FC35A4DD7A99EB4A3A4ADAAB6
C2ACB5B37273BE625BBC5F51B85E51B05847AA5246A84E46A54843A442429C383C8B333B
804C56B9B5C0C6D0D8C8CFD5C9CAD77772875C415B7D3045890B1C9307167D0F1EB88C95
CCC8CEC1CBD1C3CDD6C7D0D9C8CFDBC6CEDBC2CCD8BFCCD5BFCDD6BECBD5ABBACE49617C
3B547457708667798587939A88908E969A86A1A587AFB49F7B7B71604D3900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00DAC2B0ABADBA4B5A6D6E7E8C9DA8B38D939AAEAEACB3A886AF9A40B29810B99A06
B7980B9B81135644005441019A7F0AC2A00AC4A005BF9A13A7842C9D7C55997965997C6F
9C7C77A17F7BA4827AA6857BAA8A7FAC8C80AC8D7FAD907FB89A89BE9E8CBF9F8BC3A791
C3A890C8AA94C6A792C4A590C2A58FC3A891C4AC92C9B096CFB49DCCB09AD0B59FD1B7A1
D3BCA7B9A491A59484B3A491D3C2ADD4C0ABD3BEA9D8C3B1DCC7B6D6C1AED9C7B1DCCBB7
DAC9B8DAC9B8DDCCBADDCCBBDFCDBCE0CDBCE1D0BFE3D1C3E4D0C2E4D0C2E6D4C5E3D1C2
E3CFC2E3D1C4DFCFBFDCCAB8DDCAB9DCC9B8D6C4B3D7C6B7D4C3B4D6C5B6D4C1B2D3C0B2
CFBFBEBBB6C54B51735D4D6FBB5B6BB9191BC31710B52113C76D5DDFBCB1ABA4A85B6A7B
BCC5D1CDB7B9C99E96C39A8DC19F95B69B92D6C0BADDC8C7C4ADB0D9C0C7AE99A5564859
817F8F566877B9CDD6C6D3D8C9D0D5C8CDD862637D563A587C23378C071588081588414B
D1C3C9C3CAD0C5CFD8C5CFDBC6CFDCC6D0DAC3CBD7C1CDD6C0CDD6BDCAD5B6C1D42C405D
415776475C726E7E8A8F9BA1929B9C999D989EA2998C91926D6F7C4E404400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00D0B39ABCBCC64F5D70788697707886A7ABAFA4A08CAF9F58AF961CB69907B89908
A0840E5B45005B480E998320BA9A0DC3A005C19D0EAE8C2398794594776694776F967772
9E7B79A5817DA5827DA4827BA9887EAB8B7FAB8E80AE9284B5988BBB9B8CBC9C8BC3A390
C8A895C7A894C1A58FC4A891C5A993C6AD96C9B099CCB19BCAAE99CEB39CD2B8A1D2B8A2
D2BBA6D2BCA7CFBAA6D3BEA9D2BDA8D2BDA9D6C3AFD7C4B0DEC9B7D7C2B0D9C7B3DAC9B7
DAC9B8DBC9B7DDCCB8DECCBAE0CDBDE1CEBEE2D0C1E1D0C1E2D2C3E3D2C2E2D1C0E5D2C1
E1CDBFE3D0C2E0CEBFDDCCBBD9C8B6D8C7B6D9C7B8D7C4B6D5C4B3D6C6B4D7C6B5D5C3B5
CDBFBCB1AEBB4D5674766C88A86066AD352BBD442FCB6E56D49F8CD3B9AEC5BBBC6F7588
525A76907A8CA67378D09C9CEEC3C9BFA3ACAA96A3A999AA937F94877087725B764E3653
6E5D738D8B9CB8BCC6CCD0D5CBD1D5C9D2DB9BA5BD221F427E425A800C198A0C1475262A
D0BFC0C5CCD0C2CDD6C2CED8C5CFDBC5CFD9C6CED8C1CBD4C1CCD6C1CBD5BCC5D38392A7
96A8BEA3B5C49EAEB8A3B0B8A7B2B5AEB6BAB2B9BCB1BABF959AA8514C552FA01A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00C5A285D0CDD36371837A8999747C86B2B2A8A1955DAA9427B09709B59706B0920E
7860094D390377631690760ABF9E09C2A00BB1921C9A7C3C93776093766F9577749B7A7A
9F7B7B9F7C7AA07D7AA3817BA7857DAB8B80AA8C81AB8D83B49488BA998ABE9D8BC1A08D
C4A28FC1A08DC2A58FC8AE97C8AF98CCB39DCDB39FCCB39ECDB39ECDB19CD1B6A0D3B9A4
D3BEA9D2BDA8D2BDAAD1BCAACCB7A4D5BEABDAC3B3D7C2B1DCC7B6D8C3B1D8C2B0DAC7B6
DAC7B7DDC9B8E1CCBBDFCCBCE0CEBEE0CFBFDFCFBFDECFBEE2D3C1E0D0BFE3D0C1E5CEC1
E3CEC0E1CEBFE1CEC0DECDBBDAC9B8DAC8BAD9C5B7D8C4B6D5C4B4D5C4B4D7C5B7D2C0B5
BDB0AE77737C6E6E7EBCADB3CDA599D8A28EDCAA92D4AD97CCAE9EC8B2A6C1B0A7B4A9AB
6E667C7561798F55658E3241A33B4CA64053A34055A03D54A13A529E364C9D2F45962C3F
9331449E4F60AF7787D2AFBDD8CAD5CACAD658627B3B3D58825766751D217D1B1C7E4341
CBC0BEC5CDCFC3CCD6C4CDD7C7CFDAC8D0DBC4CCD7C4CED8C2CAD5C3CDD6C2CAD96E7C95
374F6E657E94687B8A7E8D9689939B8790978B949B969FA79098A748475533A72500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF006ADB50D7D2D3707E8F63748497A1A399956FA59232B0960DB29703B3980C846C03
6E59066B5400A28613B6980BC09F0AB795159A7C2E9074578D716A917572977977987878
9878779D7B799F7E79A98480AA847EA9877EAE8E82AC8C7FB49587B79987BB9D8BBE9F8D
C1A18FC4A694C4A894C9AE99C5AC95C8B19CC7B3A3CCBCAFD0BCAFCBB4A3CFB7A2D3BAA5
D1BAA5D0BAA7D1BBABD6C1B1D9C3B2DAC2B3D9C2B4D8C1B3DAC4B4D8C3B2D8C2B0DBC8B6
DAC8B8DCC9B8DFCAB9DDC9B9DFCDBEDFCEBFDDCBBCDECDBDE2D0BFE2D1C0E4D3C2E3CFC0
E5CFC1E1CDBEE0CEBCDFCEBBD8C8B8D5C5B5D8C6B7D8C6B7D7C7B7D5C4B6D5C3B7D1C0B3
D1C2B7C6BAB1CABEB9CDBDB1CDB9A8CBB6A3CCB6A3C6B29FC2AB9DC4AFA4C7B6ACDDCDC7
B7AAB1776C7C755D6EA066749A38439B2027A1161EA9141DAA0F18A80C14AA0D16A40B14
A10A179A0D1B9211248B2239A96579D9BAC7A9A1AE8E8995958386937370977771AB9D98
C7CBC9C3CCD0C5CED7C3CDD7C9D2DCC9D2DCC6CEDBC5CDDAC4CBD7C2CBD5C4CCDC6C7894
1E335653698257677A8B95A19CA3AD959CA49CA4AB9098A18288983D405066514800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0060CF41DBD1D0757E8E5D6C78949A8B958940AA9515AE9703B19804B399127F6700
A38B20A5890BB8990BBD9E07BA9C13A587298F72488E73668F7370907373957775967775
9A7B789D80799E7E77A3807AA8837DAA857EAD887FAE8C82B29386B59A8AB99E8CBEA18D
C1A291C5A795C7AA97CBAF9CC5AE9CC1B1A4D7CDC8E0DBDAE5DDDCD2C3BBCBB6A6D0B6A4
D2BAA7D2BAA8D0B8A8D1BAAAD9C2B4D7C1B3D9C2B4DAC1B3D9C2B2D5C2B1D5C3B2DAC7B6
DAC8B8DBCABADBC9B8DECABADFCDBDDFCDBDDDCBBBDDCCBBE3D1C1E3D1C1E1D1C1E2D0C1
E3D0C2E2CFBFE2D0BDE0CEBBDDCCBAD5C5B2D7C7B7D7C6B7D6C6B7D5C4B5D1C1B3D1C1B4
D2C2B6CFBFB2D0BEB2D2C0B3CEBCB0CBB9AAC7B6A6C4B3A3C6B0A3C9B5AAC3B1A7C9B8AF
BDAEA7BAACAAA0969D85768394707CA6676CA1484A9F2F2FA12220A41E1AA01C1A9D1E1A
9B1D1C981F22961D268D1A28811C2F894253D3B5BFCFCBD0C9C9CBC7C3C5C2C3C4C5CCCD
C5CFD1C3CCD3C5CDD6C5CFD9C6D2DEC4D0DCC4D0D9C4CDD7C3C9D7C0C8D3C0CBD7AAB9CB
8294AB99ACBDADBBC8A4AFB8A5AEB7A7B2BBB2BDC7B2BDC7ACB5C63F485C6C605D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0057C330DAC9C18488956B757A99976FAA9830B19809B29B06B19806B29710776003
7E6809AE930FB99B07B69B0F9B841B8F76408B715F8E736D8E726F927374947274947273
9B7978997A759D7F77A3837BA6837DA5837BAB8A7FAF8F82AF9183B39888B99E8CBFA491
C5A896C9AC9BCBAF9FC8B09EB9A898A79E96B4B2B3BDBFC4DEDEE0DAD1CBCBB8A9D0B8A6
D1B9A7D1BAA8D1BAA8D2B9A9D4BDADD8C1B3D6BEB1D8C0B2D7C1B0D8C6B3D4C2B1D8C5B5
DAC8B9D9C8B8D9C9B8DECDBCDFCDBEDFCEC0DDCDBCDDCEBDDECEBFE2D0C2E1CFC1E2CFC3
E3D1C2E3D2C1DFD0BDDFCFBEDFCEBFD8C8B8D5C5B6D5C5B6D5C6B7D3C6B6D0C3B2D0C1B1
CEBEAFD0BFB0CEBCAECFBDAFCBBBACCDBDAEC9B7A9C5B4A4C5B0A3C7B4A6C4B3A4BEB09F
C2B5A7BBB0A4CBC4C0DEDCDEB2A8AD9482849177798D6A6BB2827EC18F84C08E85BA8C84
C59B96C09699A0797F9369708E5C67824B5B795462C6C0C5CACFD2C5CDD2C5CBD4C4CDD3
C6CFD6C3CDD6C4CED7C3CED7C3D0D9C1D0DAC2CFD8C1CDD5C6CDD9C2CBD7C1CDD98DA2B4
5F7A935B768B70859376838E828C95848D96858D998C97A28B98A73A485B6E666A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D6C1AE9F9FA1737468908840AB9715B19804AE9608947B02AE92128F760E
715900B4980FB79B118E7D16534816847261886F6B8C726E907471927371977675987374
9A75759977739E7E79A2827CA6857DA9897EA9897DAD8E7FAF9283B6998BBA9F8EB89E8C
BEA290C0A491C2AA95BDA8959A8D7DC3BCB5DDDDDDB3B6B9D7D6D5CFC3BDCDB8A9CFB7A5
D1B7A7D3BBACD1BBACD3BDAFD5BEB0D8C0B2D7C0B1D8C1B1D8C3B0D9C7B4D5C2B2D8C5B7
D7C7B9D5C8B9D8CCBCD7CABCD8CCBDDACEBED9CEBCD8CEBCDDCFC1E0D1C1E0D0C0E1D0C1
E0CEC0DECFBEDFCFBEDDCDBEDFCEC1D8C6BAD5C3B6D4C4B5D3C6B7D2C5B6D2C3B3D3C3B1
CFBFAFCFBFB0CEBEB0CCBCADCBB9ADC9B9AACCBCADCABAAAC8B6A8C3B2A3C2B4A4BEB1A1
D9CEC1C4BAAFBAB2AAC1B9B5B2A7A4AFA59DC1B9B5C5C1BFBAB2B3D9D1D1DCD6D8AEB1B6
C6CBD2949DAD3E4D64AFBBC8B6B3BE857B89635A6D848791C7D0D7C5CFD6C7CED6C3CCD3
C4CDD6C3CDD7C2CCD6C2CED7C3D0DBC3D1DCC1CED8C2CCD6C4CED8C2CCD7C3CEDB6D8096
3852712B4660697F906C7C869AA4AD9DA4AD979BA6939AA389909E424E626B686F2C9E16
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D3B897BDB6A5827C4EAE9F37B4A00FB49B04B29912755B00A88E18B3960D
B39509B89A0C9B851A342F043A3A347E7072856E6F8E72729173749071709677759C7A78
9C79759C7B76A07F7AA5837DA28079A6857CAB8C81AF9183B49788B49888B89B89BDA08C
C1A58FBEA28CC0A790B7A39096897CB2AFA8B7B8B89C9C9CBEB7B2C4B3A7CDB6A5CBB49F
CDB5A2D1B7A7CFB9A8D3BEADD5BFB0D4BFAED5C0AED5C0ADD7C2AFD8C5B2D3C0B1D3C3B6
CBBFB5BFB7ADAAA39AACA49DC2BBB2D3CDBFD9D1BED8D0BEDBCFBFE0D2C2DFCFBFE1D1C2
DFCFC0DECDBFDECDBFDDCDC0DECDC0DAC8BDD9C8BCD6C8B8D5C5B6D6C6B7D3C3B4D2C3B3
CDC0B1CFC2B5CEC0B3CBBDB0CBB9AEC9B7AAC5B4A5C5B3A5C5B3A5C5B3A5C4B2A6C0B0A5
C0B1A7BEB1A6B9AFA6B7ADA4D0C8BFBBB7AFC7C6C2D8DBDCCBCED2B9BCC1BDC5CE495D6F
63768963748B132D4E7993A9C6D4DFCAD1DB949CAB516070BAC9D3C3CFD6C7CFD6C6D0D6
C4CED8C1CDD8C2CCD6C3CDD7C5CEDDC4D0DEC5CFDBC2CED9C2CCD6C4CED8C2CDD692A2B2
7C90A48DA1B2A2B4C2B0C1CAA8B5BEABB7C0ADB6C0B2BBC3A9B3BD5C697B6B6D782EA11D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D0AC7DCBBA8D93842FAB9816B49F0AAC9504B0960F7C62059F8515B59807
B99905B498186257140D13133E3F517D6E75866D6F8E70729272779474799575789A797A
9B7977A07F7BA0827CA5877FA5847DA7867FAB8A81B09084B5988AB69B8BBC9E8FBE9F8F
BC9F8DBFA38FBFA48EBEA7938D7F728E867F918A87817974AA9D91C9B5A4D0B6A3CFB6A4
D3BCAACFB8A6D1BAA8D3BDACD1BEACD1BDABD8C1B1D7C1B1D8C4B2D9C6B5D5C5B6BDB2A8
978F899E968EA89F959F958F807B789C9991D1CCBDD7CEBCDDD1C0E1D0C2DFCEC1E1D1C4
E0D0C2DFCEC0DDCCBEDDCCBFDDCDBEDBCCBED8CCBCD1C6B5D5C7B7D2C5B4D0C3B4D1C5B7
CEC2B6CDC1B4CDC1B2C7BAABCEBFB2CBBBAEC2AFA3CCBAACC9B7ABC6B3A8C6B4AAC6B3AC
C2B1A9C3B5AAC5B9B1B8AEA6DDD7D1D2D0CCB0AEABBFC2C3A8ACB294969CAFB4B96B7988
6A7788BFCBD998AABD99B2C5C0D5E2C4D3DCC8D6DDA7B8C0B9C8D1C3D0D7C6D0D8C6CFD6
C5CFD8C3CFD7C4CDD8C3CCD7C3CCDBC2CEDAC3CDD9C4CED8C0CBD6BFCBD7BFCCD79EADBB
7A8EA36F879B74899A7A8D9A818F9987939C89929C8089927F8895536376646A7963493D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00C79A58C9AF61A9951CAE9B0BAB970D8B7701A38C11866D0C8F780DB59908
B5970999852128290E0711294A4B627F6E76866D6F907273917274927476947677987879
9A787A9D7E7D9E807DA1837EA48580A88883AB8983AE8B84B19389B89B8FBC9E91BD9E91
BA9A8CC2A392BFA28FBEA5919785779A8C80A59589AE9C92A29082CBB6A5D0B6A5D1B8A8
D2BCAACEB8A7D0B6A7CFB7A7D1BBAAD6BFAFD7C0B1D5BEB0D9C2B4DAC5BAC7B8B089817B
ACA49EC8BEB3C6BAACC4B8AEA19996767471A8A89ED5CFBFDACFBEDED0C1E0D0C4E1D0C6
DFCEC4DFCEC2DBCCBEDACCBEDACCBDDBCDBDD6C9B9D3C8B8D2C6B5D2C6B6D1C5B7CFC3B6
CFC1B8CCBEB4CFC3B7CBC3B4CBC0B5CDC0B3C9BBADC9BAABC4B2A4C4B2A6C2B1A7C7B5AB
C1AFA5C6B8AFCFC2BBB9AEA6BBB1ACB2ABA8ACA8A3ABABA6CECFD0C3C4C7C1C3C7D1D7E0
B1BDCA9CADBAA8BDCF3F607C99B8CFBFD2DEC2D2DAC2D1D7C6D3DBC5D1D9C7D0D9C6CFD8
C6CFD8C3CFD7C3CED7C2CED8C1CDD9C1CDD9BFCBD7BFCDD6C1CED7C2CCD7C0CBD8A6B4C6
3F5571435F79455E7081929F94A0AAAAB5BBA3ACB499A1A88B94A05666795C66756A554C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0065CE21C8A83AAF9910AA980C8172056B5B009B87147E6A0E79660BB2980D
B59B1F867A390F151B08133653536C7F6F77866E718D707391737691737596787A98797B
9B797CA28081A17E7DA2827EA2857DA98B85AB8C86AF8E87AE8F85B5988CB79B8DBA9E90
BEA290BFA18DBC9F8CC0A594978274B5A596B7A796A89686B3A090CBB6A3C9B4A3CAB5A4
D2BDABD4BDACCFB7A7CEB5A6D3B9AAD4BDADD3BCACD2BDAED8C3B6D7C4BD9C918F86807D
B7AFA9C7BEB4C7BEB3C7BBB4ABA0A07E7C7B888880D5CFBFDDD1C1DED2C2DECFC1E0D0C3
E1D3C6DDCEC1DECEC2DCCBC1DDCCC2DCCCC1D8CBBED2C8BBD2C8BAD2C5B8D2C5B8CFC3B6
D0C4B9CCBFB6CBBFB4CBC2B6C8C0B3C6BDB3C4BAAFC3B8AABBAB9DC3B2A4C2B2A7C0B2A7
C1B1A7BDB0A5B7ABA3B5ACA5AEA6A2CCC9C8D2CFD4AEACAFD8D4D8DBD5DAB2ABB1B4B3BD
6371872F44617F92AA203D5B6E91A8BFD5E1C0CED697A5AAC8D4DAC6D0D9C7D1DAC5D1D9
C5D0D9C0CDD6BFCBD6BFCCD8BDCBD6C1CED7C2CDD6BDCBD4C0CED6C1CED6BFCBD7A4B2C3
879BB271899F95ACBAA1B2BBB5C2CAA8B6BCACBAC0ACB8BEA7B2BD697A8C54627270625E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00C39F19B39B0C95840A5A4E005143009A86168C750B8D7609B09712
B49F3D877E610A112B09123A605F757E6E75856E708C6F7491717896767C97757B9B787E
9A76799E7A7B9E7C7AA1807BA68883A88B87A98B86AA8A84AD8D84B4978AB89D8FBCA193
BEA290BFA28FC0A391C2A595AC9284998676A09080A49081C4AE9EC4AFA0B4A196AC9C8F
C7B4A4D1B8A7D5B9ABD3B8ABD3BBABD2BCABD3BDAED6C2B4D8C3B8D7C3BD877B7B878383
AAA6A3B8B2ACBCB6B0B0A9A79894967A7B7B898981D3CCBCDBD0BEDED2C1DFD0C1E0D1C3
E0D3C6DDCFC1DECEC1DACABFDAC9BFD9CAC1D4C7BED5C8BFD1C5BAD3C6BCD0C2B9CFC5BA
CBC1B7CCC2B9CDC0B7CDC1B6CAC1B3C4BBAFC2BAAFC2BAAEC1B6A8C0B3A3BFB1A6BBB2A7
BBB0A7BAB1A7B3ADA8CDC9CB9E96A3978B9FA48DA4936F83B58995C2949CB88F93B8A0A3
9292A24C5A71A6B5C5A3B3C49AB2C3C2D4E0C8D4DBBCC7CDC7D2D8C7D2DBC6D0D9C6D0D9
C2CFD8BDCBD4BFCCD5BDCAD3BDC9D5C0CCD8BFCAD6BCC8D4BFCBD6C0CCD6C1CAD7ACBACB
7D92AB758FA46E85957D8E9A7E8C957F8B94838E97808A947D8692606F814D5E6F786F6C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0092B80DAF9B0F7B6F025D5201796705A7910DAC9509AD960EB19C27
92844368665F0B15380A163E6765797D6D7189727390727794737D96747D99767B987478
9B797C9C7B7A9C7B79A38481A48784A68886A98984AD8B83B18F84BB9A8EBC9D90B89B8C
B99B89C0A18DBFA28EC0A38FC6A796BB9F8FB9A190C3A999C6AD9CB9A597A4948CA7988F
B8A597D0B7A6D7BCABD1B9AAD0BCAACFBDAAD3C1B0D6C3B4D6C3B7D4C0BA897C7B827D80
8F8E919896999998999290937E7F837475749E9B91DAD0BFDDCFBEDFCEC0DECEC1E1D3C4
DFD2C3DDD0C2DCCFC0DACCBFD7CABDD4C8BDD5C8BFD3C6BDD2C5BCD4C6BED2C4BDCEC3BA
CDC4BBCDC3BACFC2BACDC0B6CDC1B6C8BCB3C4B8B0BFB5ABBFB4AABBB0A7BAB0AAB7B2AC
B6B1B1ACA7AE8D8595826E888253719A4C6A9E334EA4263CA21C2DA21F2D9F2C35AE5B63
E5BCC7D7CCD99096A3ACBBC87D94A7B9CFDDC9D6DFC8D2D9C8D1DAC4D1DAC4D1DAC4CED7
C3CED8C0CDD5BFCCD5BDCAD3BCC9D2BFCDD6BFCDD8BECBD4BBC7D3C0CAD6BFC7D8A1AFC3
213A594D6986536D8470839395A2ADA2ABB6AEB7C1A5AFBA868FA13E516A44576D7B7778
2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005FD00AAB9A13706200716101A08B0DAE9706AE9604AB9512C3B35E
8A81638A8C941922481019426F697D8572758D747590737792737A94757A95787B997B7E
9A7C7E9B7E7E9C7E7DA28582A48683A58684AA8984AA8981AD8E84B7978CB6968AB7998A
B89B8ABDA18CBEA28CC1A58FC3A793C3A694C5A996CAAD9AC8AE9BB9A4959E8E83A9998D
C3B09FCCB49ECFB5A0D3BDA9D0BDA9D1BFAAD5C4AFD4C3B2D2BFB1D5C2B6AB9B96776E6F
7C7A7F7F7D847E7D81797A7D727170847E76C5BAADDBCEBDDFCEBFE1D0C2DECFC2DED0C3
DACDC1DACFC1D9CFC0D9CDBFD5C8BCD4C7BECFC5BBCFC5BBD0C6BBD1C6BDD1C4BDCEC1BA
CDC2BCCDC2BCCDC3BACAC1B5C9BFB5C6BBB3C2B8AFBFB7ADBFB7B0B9B2AFB4AEB4A49DAB
81728B7C5C7B925576A54663A5243BA80F21B20A19B40814B60611B60711B00811A00C17
A2303FB26D80523D5372798E5D7288ACC1D1C9D6DFCAD4DBC6D0DAC5D2DCC6D2DBC5CFD8
C2CCD5BECBD4BECBD4BBC9D2BCC8D4BDC9D5BECAD6C1CBD5C1CBD7C3CDD7C1CAD7B7C4D5
374C68839BB48DA4B7A0B1BFB3C0CCB9C3CFACB8C4B0BCC89FADBF2D415E344663797A7E
32A72200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005DCB0D9A8409776703907D0EAD9609B09803AE9504B09920AA9C5C
8B857A64677809143C182047787085856F798D74788B6F749173798F717594787B957A7C
997B7D9C7D7E9D7E7D9F7F7DA48482A58482A6847EA8887FAC8F85AF9388B29589BB9C8F
BE9F8FC2A691BEA48DBDA38DBEA38EC7AA95CAAB97C8AB97C8AE9AC6AE9ABEA896C0AD9B
CFBDA8D5C1ABD6BFABD4BEABD0BEABCFBEA9D2C2AFD1C1AFD2C1B1D4C2B3D1BEB39A8B85
7E757580797A8A848298908B9B9188C0B2A5DBC9BDDDCBBEDECDC0DECEC1D9CABDDBCDC1
DBCEC2D8CCC0D8CDC1D7CBC1D7CBC2D4CBC1D0C9BDD4CBBFD1C7BCD2C7BECDC2BBCEC3BD
CDC3BDCBC2BBCBC2BBCAC2B8C9C1B8C4BDB7BFB8B5BBB6B5B5B0B69E97A57D6B85815978
A05574AB3B58A71A32AF0E1EB70A15B9080EBA060EB6030BBA030DBB050DB70309B2040B
AB08169B16269B5062907E8DC2CAD6BFCED7CBD5DECAD4DDC7D1DBC6D0DAC7D1DBC5CFD9
C1CDD6BECBD3C0CAD3C0CAD2BFCBD4BDC9D4C3CDD9C2CCD6C0CDD6C0CDD6C0CBD6BAC8D6
74859A899EB37E94A47E909C8C97A387919B848E9A848E997A83962B3C582F3F5B74787F
4C7D3500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6F03806C02A18D0EB09905B09702AE9404AF9929978A58
B9B6B45D637A07133D22294F796F82836F788B737A8A6E738D6F749072749376799A7B7F
99787D9D7C7F9E7C7DA07E7DA28281A88886A6847EA88680AC8C84AF9186B09387B79A8A
BDA08DBCA18CC0A791C1A590C1A590C6AA95C6AB95C5AB93CBB09AC8AD98CAB19CCEBAA5
D0C0ABD1BFACD7C3B1D2BDACCCBAA7CFBEABD2C0B1CEBCADCEBCADD1C0B0D9C6B6D2BFB2
BBA89FB0A096C1B3A8C9BAADD3C3B3D8C7B8DCCABDDBCBBEDBCBBEDBCDC0DACCBFDACBC1
DACDC4D8CBC2D5C8C0D5C8C1D6CAC4D5CCC4CFC9BED1C9BED1C9BFD0C9BED0C7BECDC4BC
CBC2BCCCC5BECAC3BFC4C0BBC2BFBFBDBBC0B3ACB990859980668196637EA9526EAC324A
AE172AB70E1CBA0A15BA0B10BB0C0EB70D0EB30C10B10C13B30710B7070EB9050AB7040B
B5040EAE09149A1F2AC0868F9E959EC7D1D7CFDAE0CBD7E0C5D2DBC5D2DAC5D2DBC3D1DA
C1CED7BFCCD4C2CCD4C0CBD1BDC7D0BFCCD4C4CED8C4CED8BFCBD6C0CDD8BFCDD9A6B8C7
6D839B27445D6D8A9F7A909F98A5B29FABB4A9B2BCAAB2BE9CA3B7303F5E293A56697076
6B5B4F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6C02A38E0BAC9706B09A02B09804AB930AAA97379F9573
8F8D925C617B08133D2C33567A73828370778870768B6E768E6F7592737994757B99787F
9D7C819F7D81A07E7FA28081A28281A38380A6837DA9847DAE8B83B6948BB4948AB6998B
BD9F8EBDA08EBDA28EBFA390C3A694C5AA96C7AB96C5AB95C8AE97CBB19CCDB4A2CDB8A6
D1BDACD3BFAED3C0ADCDBBA7CFBDA8D2BFADD2BDADD3BDAED1BFAED2C3B0D6C6B4D5C4B4
D3C1B3D9C6B7D9C8B8DBCABADAC9B9D8C6B7D9C6BBDAC9BCDACABCDACABCDACBBDD9CBC1
D5C7C0D3C8C2D6CBC5D6CBC5D8CFC8D3CDC8CCCBC8CBCAC6D1CAC4D3C8C0D4C6C1D1C2C0
CEC1BFCBBFBEC8BBC0BAADB7A392A294788E9B6C88A9607DAA4059A72134B11523BB121B
BC0F15BC1113B71311AF1812A91F17A72B23A73733A5393DA2252EA91019B4060DB6040A
B60208B40409A50A11A138417A5863BCC3CBCCD8E0CEDBE1CCD8DEC6D4DCC2CFD7C4D0D8
C5D0D9C2CCD6C0CAD3C0C9D2BEC7D2BCC8D1C4CED7C2CFD6C5CFD9C2CFD9BDCAD6A4B7C8
6C849D435F7887A1B49AAFBCA1B0BCB1BEC9B3BFCCAAB5C3A1ACC0384B692337535E6A6D
6D635600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00709702AD9508B09B05AC9905B39F19AB9927998B42C8BFAA
7B7A818A8FA708143A363E5B78727D816E758970758F7177906F7795737B97757C99787E
98787B9A78789F7D7DA07D7EA38182A28180A7837FAB857FAC8880B3928AB7998FB99C90
C1A192BFA18EBFA38EBFA38FBFA593C6AC98C7AC98C5AA94C8AF98CEB6A1CDB6A4CBB4A3
D4BEADD0BDACCEBBA8D0BBA8D2BDAAD3BDABD0BBAAD4BFAED1BFAED2C1B0D5C4B5D7C5B7
D4C2B4D7C5B7DBC9BCDECDBFDCCBBDDAC8BADBC9BBDBCABCD9CABDD8CBBCD7CBBDD3C7BC
D3C5BFD4C9C3D4C9C3D5CBC4D3CBC7C5C5C78E9CA9A4B6C5CAC8D2D1B9BCDFB8BBE2B3B8
CF9BA4C08896B4768AB66A81B85A72B64359B42C42B31B2BBB171FBC1315BC1716B51813
AE2019AE3328B54D3FBE6F5FCA8D7DC89788B68F8A6D505B794E639A3849A70C18B3040E
B60309B50309B0050E9A101899545FB5ADB5CDD6DDCFDAE0CDD8E1C7D5DEC6D3DCC3CED7
C6CED9C6CFD9C0CAD3C1C9D4C1C9D5BFC9D1C0CDD5C2CFD5C5CFD8C5CFD9C2CDD9AEBECE
7C8FA6748A9E8B9EAD7F909D808D9A7F8B97808A987E88957683932F405E24395457646B
6C665B16CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF005AC906AF9606AC9803AC980FAE9F34B6AA5EA2986AC1BCAF
7879808389A20711393D42607B727E846F768C727890727A92717A937179926F76947177
9874769A76769E7A7AA17D7FA58384A78584A5827FA9857FAD8982B3948BB79A91B89B91
C1A095C3A294C0A38FBCA18DBCA491C2A897C8AB9BC8AC98C7AD98CBB29DCAB29FCCB4A3
CFB8A7D4C1ADD4C2AED2BEAAD0B9A8D0BAA8D1BEAAD3C1ADD0BFABD0BEAED3C1B2D7C4B8
D1BFB2D5C5B8D8C7BDDACABDDBCBBDD7C7B9D8C8BBD7C9BDD9CCBDD9CDBDD5CABDD4C8BE
D9CBC3D9CCC5D6CAC4D5CAC4D4CBC7CBCCD065788F446287AFB7D4957182A95D6CB44F5E
B94656B83D4FB63347B42437B81F2FBD1D29C01A22BF1A1AC01D17B72015AB261AAE4032
BD6A5ACE9182C99B8CC1A293B59F91B29F91B1A19A8D86922D2745935A75941020AE040F
B4010BB6030CB1030CA50A119F4048BAA3AACED7DECCD9DFCED8E2C5D2DBC6D2DDBECCD4
C0CCD4C6CFD8C1C9D4C0CAD4C2CAD5C2CCD5C4CED7C4CED7C2CFD8C4D0DCC2CDD8B0BFCF
435A756E8BA36E88998599A59AA9B594A1AA96A2AE98A4B08D9AAA293B5B2A3F5B54616A
69645E2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE503AE9603AB990BA69625B1A761A8A37CADA99595938F
8E8E9859617B08163C484E697C737E826F768971778F737A92727A917078947278967378
9874769E79799E7A7BA07C7FA38183A58484AA8785A78481AE8C86AF9188B79A90B79A90
BF9E95C09F91C3A393C0A292BCA090C2A896C7AB9BC9AD9CC6AB97C9AF9BCBB39FCAB3A0
D0B9A6D5BEACD2BFABCFBCA8D0BAA9D0BAA8D0BCA9D2C0ACD1BFADD4C2B2D6C3B4D7C5B7
D3C2B4D7C6B9D8C7BDD8C9BED8C9BBD7C9BAD4C6B9DACBBFD8C9BCD9CDBED7CCC1D7CDC3
DBCEC6D9CCC6D6CAC5D7CBC7D6CCC9D1CDCDB5BECC5E73945E6C93A392B1A56C829E4253
A6303DAA2834B62834BB252DBB2329B72523B62A24B33228BB483BC76858D48677D69E8D
CBA595C2AA9CB4A397AFA497AAA195AAA294ACA29BAAA8B0393E5E6D54768B2436AA0A16
B5040EB5030CB2020CAE081098242D9C7481C1C9D5CBD9E1CFDAE4CAD7E0C5D1DCC0CED7
C3D0D9C6D0D9C5CDD8C1CAD4C3CCD6C2CED7C5D0DBC6D2DDC3D0DCC2CFDBC1CED9BBCAD9
3F56735C7D994F6E8295AFBD99AEBD9CAFBFA2B5C7ACBFD0A2B4CB2035582D435F5B6870
645F5C32A61F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE603B19B09AA9A1FACA55EA9A990969693BDBEC086878C
ACAEBA515C7519294B5259707C737E806E75866F768B71768D707691727797757B9A767B
9A76799C7878A17C7E9F7A7EA38081A78684A78784A78783AC8B84B09086B6998EB99C91
BC9F94C2A297C09F93C1A094BFA090C3A592C5AA98C5A999C8AD9CC9AF9DCCB4A0CBB5A0
D2BCA8D7C1AED0BBA9D0BDABD1BEADD0BCACD3BFAFD4C1B2D4C2B3D4C1B2D6C2B4D6C4B5
D2C1B3D7C4B8D9C7BBDBCBC0DACBBFD9CABCD4C6B8D8C8BDD7C9BED6CBBFD8CEC4D6CBC4
D8CBC4D8CAC6D9CCC9D7CBC9D4CAC7D6CCCBD0CACBC5C5D29BA2BA717792857C94A98B9D
B3828FBA7B86BF767CC87777D2827CD68E81DC9C8EDBA597D7AC9ECDAE9FC9B3A7C1B3A6
BAAFA4B7AEA4B2AAA1ADA69BAAA398AEA59CADA6A0D2D0D27F859F3131588D4D65990F1B
B1050FB2010BB2010BAF040D970C179D5B6A9696A6CAD9E2CDD9E2CEDAE2C8D6DEC6D4DC
C2CDD7C4CFD9C3CED8C5CED9C4CDD9C1CDD8C1CDDAC3D1DDC2CFDDC2D0DBC0CFD9BCCCD8
8699B453718D7799B493B4D17796BA5E78A25C73A0586F9D4B6293102554364C695A686D
5A595236AE2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CE07AE970BA89C3AA7A5809EA3A09EA2A8A3A6AD94989E
818590535C740A18395D62777D727D816E75856C748A70758F727794727899747B99737B
9C777C9D787A9D787AA07A7CA4807FA68480A6847FA6847EAA8981AF8E84BB9C91BA9C91
BB9F93BB9F93BA9D91BC9E91BFA190C4A491C8A996CBAF9ECCB1A2CEB4A2C9B29ECBB5A2
CFB9A8D3BFAED2BFAFD3BFB0D2BDAFCEBAACD1BDB1D2BFB3D2BFB2D0BCADD4C1B3D4C4B4
D2C1B3D5C2B5D8C5BADAC9BDD8C6BBD7C5BAD6C6B9D7C9BCD6CABDD5CCC1D8CEC6D7CBC5
DACCC6D6C9C4D5CBC6D3C9C5D6CBC8D4CAC9D0C8C6D3CBCACCC6C9CAC8CFBEBEC7B2B2BD
B1ADB5B3AAB0B8AAADC4B2B2D2BFB8CEBDB2CCBCB1C6B9AEC4B7AEC2B8AEC1B6AFBCB3AB
B8AFA8B8B0A7B4ADA3B3AEA2B4AFA4B3ADA4A8A39DAEAAA79D9EAE2A345872577A861A2C
A70612B0010BB2010CB0030CA309149B3E48CEBBC3CFD9E0CDDAE3CFDBE3C9D8E1C6D4DC
C6D1DBC3CFDAC5D2DBC5D2DBC4CED9C1CCD7C3CEDCC1CEDAC3D0DDC1CFDABDCDDAAEC0D2
8297B558749A31507E132F68031C5E01165C01155E00125B02145C011452273E63576871
5F615A5F4E3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CD08B29916AEA24F999A82A6AEAFB2B8C094979FABAFB6
8286926B748D0C1A396468797B6F79806C74886E778E727A92727A9371779571779A757C
9C757D9A75799C797B9E797BA27F7EA78280A5827FA5817DAD8883AF8E86BC9D94BB9D93
B99C8FBDA191BA9D8EBB9F90BFA291C5A593C8A896CAAB9DCBB0A1CCB2A1C9B19ECEB8A5
CFB9A8D3BEADD5C2B2D3C0B0D2BEAECFBCADCEBBADD2BFB1D0BCAED4C1B2D4C2B5D3C1B4
D0C0B2D1BFB2D8C6B9D8C7B9D7C7BBD6C6BCD6C8BCD8CCBFD5CBBED4CCC0D5CBC3D5CAC4
D3C7C1D0C6C1D0C8C4D2C9C5D2C7C3D2C8C5D1CAC7D1CAC7D2C9C7CBC5C2CBC8C4CDCCC7
CBC9C4CBC8C4C9C3C0C8C2BECBC3BDCAC4BBC8C0B9C5BDB6BFB7B2C0B9B2BFB6B3B7B0AE
B7B1ACB9B0A9B7AFA6B4ACA4B2AAA2AFA8A0ACA69FA9A5A0B0B0B65864833839648F4A64
9A0E1CAE050FB3020DB2020CAA05108E171EDBB0B4D6D6DACED9E2CBD8E2C9D7E3C7D5DF
C6D3DDC3D1DBC7D4DDC5D1DBC7D1DCC3CEDAC7D2DDC3CFDBC4CFDBBDCDDCB9CCE48CA5CA
29447807216000175F00125E01125F01125D01115D01115C01115C011359031749394C61
5C62615F544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0030E504B0971DA39A4E9799819AA2A39FA5ADA0A3AB9F9FA8
7A7B89565E7814213D6B6C7B7B7076816D76876E798B6F7A8C6C769573799874799C747B
9A70789E767B9E7B7BA38182A17E7EA4807FA78382A98684AB8784AF8D87B4968DB4978C
B4978ABB9D8EBD9F90C3A597BEA090C3A491C6A896CCAFA0C9AD9FCCB2A2C9B1A0CDB6A5
D0B9A9D2BDACD1BDADD6C3B3D1BEAED2BDAFCFBDAED3C1B2D2BFB1D3C0B4D1BFB3D5C2B7
D4C0B4D2BFB3D7C5B9D7C8BBD7CABED4C7BCD7CABFD5C8BDD1C7BCD4CAC1D3C8C1D4CAC3
D3C8C1D2C8C4D1C8C5D5CBC8D3C8C3D1C7C4D0C8C6D3CBC9D2C9C7CBC4C2CCC8C4CCCAC5
CAC9C5C7C7C4C6C4C3C4C1C0C5BFBBC8BFBACABEB9C3B9B2C2B8B4C1B8B6B8B5B99FA7B2
ADAFB8BDB0B0C0AAA7C3A8A5BEA29FBCA4A1C4B5B0B5AFABBEBEC0B1BCCF25325D806285
8B1B2CAB0913B2020BB1010BAE040F970B17BF7880DFD5D8D2D9E1CDD8E3C8D4E2C5D3DE
C4D2DCC3D1DAC6D2DBC6D1DDC5D1DEC4D2DDC6D3DDC2CFDBBFCDE2ACC2E06984B2142F6F
01196401166601126300115E000F5C01115C00105901115901105B011258010F4A0E1D41
545E655F594E15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00B09938908D58A6AB9DB1B8BC959AA4B2B6C09E9FAA
9291A14D546E2029447371807D6F7583717786707A876C778F707997757C9570759B7279
A1777CA47B7D9F7A7AA17E7FA38081A48180A48180AA8684A98581AD8B85B4958DB79990
BD9C93B9978CA9877BBE9B8FC1A092C0A291C4A997C9AD9EC8AC9CCAB09FC9B2A3CDB6A8
CAB5A5CFBBABD6C3B4D3C0B2CFBBAED0BBAFCEBCAECFBEAFD1C0B1D2BEB2D2BFB3D2C0B3
D4C1B4D2C0B2D6C5B8D4C5B9D4C7BBD5C8BCD5C7BCD4C7BCD3C8BED3CAC0D2C9C1D1C9C1
D5CAC3D3C9C3D1CAC5D2CAC3D2C9C2D1C9C3D4CBC8D3CBC9D1CAC6CFC9C4CBC7C3C9C9C8
C0C7CEB7C3D0A6AEC0AB9FB0D3AFB9DCADB2DCABAED8ABACD1AEAFC8B0B2B1A9B7384768
8182A1A47787B56670BB6066B75861B86269D6A0A2BCA9A7B0ACABA9AEB75563843F3D69
8C3E57A10F1CB3050FB1010BB0040EA3081298363FE7CDD1D1D6DCCCD6E0C7D2DFC6D2DD
C4D2DBC4D0DBC5D0DCC3D0DCC3D2DEC5D3DEC1CDDBB9CBE096AFD3314D84031D64011868
011265001263001160011360000F5A011159011158011058000F58000F56010E4D020F3D
3E4C5B5D5C532BA01700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00CCB67A80816E8690939FA5B0989DA8A3A7B29698A4
8687974A4E68252B45756F7E7B6C738573788670788A6F77907078927077977278987378
9F777CA078799E7978A37F7EA58181A48180A88584A88382AB8684AD8A85B5948DB79790
BD9C94BA988EB69489BD9B8DC2A291BB9F8DC0A593C6AB9ACAAF9DC8AE9CCCB4A5C9B2A5
C9B5A7CFBCADD3C2B3CFBEB1CBB9ADCEBBAED0BEAFD0C0B0D3C3B3D2C1B2D2BFB2D2C0B3
D4C1B5D4C1B4D7C6B8D9CABCD2C7BAD5C9BDD3C5BBD3C7BDD2C8BFD1C8C0D2CAC2D3CBC3
D3C9C3D2C8C4D0C9C6D1CBC6CFCAC1D0CAC2D5CDC7D3CCC7D1CCC4CEC9C2CBC9C3BFC6CD
7C94B0485D82867CA0B46F8CB8495BB3343FB4343EB73E47BE535CC77279D59CAC7D6587
654B7194455EA61D2EB41521B91320B11721AA3E43CFA4A1B5ACA9ADAFB293A1B6202E5A
8961838E1428B00916B4040EB1010AAD061090121DCF9CA4D5D2DBCCD4DEC8D2DDC7D4DC
C4D2DAC1CED7C3CFDCC2D0DDC1D1DDC0D0DEBCCEE57F97BF17346F011A64011667011365
01126200116000115F01135D011156021554021553011154010F5502125502114E010E3F
1E2D435C605B32AA2300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D3BB979297958896A199A3AEB3B8C39DA0AA9597A1
9294A1474E6132364C766D7B7E6E748571778870778C6F76906F75957177977177997378
9D767A9C74769D7676A27B7C9F7C7BA3817EA88584A88383AC8685B18A88B4908BB7978F
BB9C92BD9D91BE9E90BE9F8FBEA08FC1A493C0A594C6AB9BCBB0A1CAB2A1CCB5A5CDB5A7
CBB5A7D2C0B1D3C2B4CFBEB2CCBAACCCBAABCCB9A9D0BFAFD1C0B1D1BFB0D0BEB1D4C2B6
D4C1B7D3C1B5D4C4B6D6C9BDD3C8BDD3C8BFD2C6BCD0C6BDD1C7BFD0C7BFD2CAC1D4CAC2
D3C9C2D2C8C5D1CAC7D1CAC7D0C8C2D1C9C2D2C9C3D2C9C6D2CCC8CFCAC5C8C7C59FB2C5
2A4C797681B1AD779BAC233BC61927CA161EC9141CC6141BC01921B31C26AA2A38B55167
AC5B74D16C7DAB1421C20E15CA0E16C40F15A41619DB9794C3B3B0AAACADC3CED94A5A7C
584E7689314AA60D1BB4060FB3020CB0040F9D0A179F505BDECFD7CCD2DBCAD4DEC8D3DC
C6D2DBC4CFD8C4D1DAC1D0DCBECFDEBACFE5738CB60C2768021967011462011161011160
00115F00135D03165A0217530D1F4E28385F3C4D7711235B06195025386319275104123D
0B19365A6468568E4700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D4BC9DA7ACB0768593949EACACB2BD9899A39697A0
9096A13E4A5B42485A766D7A7F6D76836E778970788C6E73906E74926E759772789C757A
9D757AA2787B9F7678A07A7BA48182A4807FA78282A88282AA8382B38B88B28E89B6948E
B5968CBA9D8FC0A395BC9E8FBE9E8FC3A495C2A698C9ADA0CBB0A2C9B1A1CCB4A5CDB6A7
CDB6A8D2BEAFD1BEB2CCBAADCEBCADCCB9A8CBB7A6CCB9A9CFBDAFD1BEB0D3C2B3D2C2B6
D5C3BAD4C3BAD0C0B6D5C8BED3C7BED2C8BECEC4BBD0C6BED2C9C1CFC7BFD1CBC2D5CDC4
D5CBC4D7CFC8D4CEC8D2C9C6D4CAC5D2C8C1D5CCC5D3CAC5D1C9C6CECAC6C9CACC7A94AF
28497BAEA9D7A1506CBF1C2ACD121ACF1015CE0F16C71414C22523B73337A82E3D9F2539
9D2035C53E4DBE1924C91017CC0D14C70D12B10F13C15D5FD1ADAEAEA7A8A8ACB17E8CA2
263158865875911224AC0511B0010BAD020CA60713861A25DBB7BFCDCFD7CAD3DDC6D0DB
C5CDD9C5D0DAC5D0DBC4D2DFBBCFE87590BB0B2669011A6801146501126000115E00125E
02155B051D572A416D4C60807E8DA48492A6627392061B48223A606A7C8F6B74882B3552
04112F4755606A625A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D1B498BDC1C7808F9F9AA4B39CA0AC9DA0AAA5A8B2
6F7886233247484D62796F7C816E78836D77876E788A6E74907176906E74967278997279
9A7176A2797AA07879A27E7FA27E81A57F81A27B7BA98181AA8382B08A87AF8C86B6948E
B9978FB99B91BFA096BF9F94BF9F93C7A89BC3A79AC8AC9FCAAFA0C6AD9CCCB5A5CAB4A4
D0BAABD5BEB1D6BFB1D4BFAFD5C1B0CAB5A5CEB9A9CEBBACCEBDAFCEBEAFCEC0B0CFC1B4
D1C0B7CFBFB7CEC1B9C3B8B3C8BEBACDC4BED1C7BFD1C7BFD3C9C3D0C8C1D3CCC4D3CBC3
D3C9C2D5CDC5D3CCC4D4CCC5D5CCC5D3CAC3D6CDC8D5CBC8D3CAC7D1CCC9C9CACE859DBB
254579A4A0CDA85671BF1D2ACF1119D21115CF1015BC1713E87972D49494A26F7F965972
943C579D2037B51321C70F18CC0C15C50910BD0C13A51F25D09092B9A8A8A8A7AABFCAD7
3043666253787E2037A10916AC030EAB010AA8040E8F0C18BB7A85D6CED4C7D2DBC6D1DB
C6CFDAC4D1DAC4D0DCC2D1E87A93C00A276D011A6D01176A01146401165F01175C021C5B
0C255D6C8BB289A3BDA5B9C9ADBFD08CA0B7324871041C475A71897A8A92727B83606878
0B192F36465263625C13CD0900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C6A785BABCC18E9CAC9BA6B5999EAA9EA0ACAAAFBC
59667C091A3752556B796B77806D76826C75856D768970778F73789472789671789A727A
9A747B9A7477A17A7CA67F829F7A7DA67F81A57F80AB8385AA8283A07A79AF8D89B2928C
B99A94B89991BF9F97BE9F93C1A294C3A797C4A898C7AB9CCBB0A1CBB2A3CAB3A4CDB7A6
CAB5A5D4BDAFC2A896BCA38DDCC6B1CBB5A5CDB9A9CCBBABD2C3B4CDBEAFCEBCAFCFBFB3
D0C0B8C1B6AEA59A92ABA19CA99F9D9E9794C8C1BBD1C7C0D1C6C0D3C9C3D3C9C3D1C8C1
D3CAC4D2CBC4D3CDC5D3CBC4D4CCC5D4CCC8D6CECCD4CCCBD2CAC8D0C8C7CDCACDA7B7D1
26467A6974A7B37797B41F2FCE141BD11014CD1013B81A18EB948FCEB1AEC1B6BBA49BAB
6A547184506F9E324BB31524C50D18C60910C10A10AE1117C76B6DE6C9C8A6A5A5B6BFC6
647690272D547F4260920E1FA70411A9030DA7020B9B09148D2F3DDEC6CDCAD0D9C5D2DB
C6D1DCC5D2DCC1D0E294AAD0142F72031D7201186F011569011763021E5C2745737591B7
1E3B617D9DB95E798EA3BACD7B95AD4C698F021A4A1B3456697D897182866F7C7F6C787F
222E3E2D3B466B6C682FA51F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C29C75C0BCBF7D89998A94A2A0A6B2A5A6B2828897
29385408163758586D7769747D6971806A72846B74886E758C6F77916D7799717B9C777E
9D7B819B787DA07A80A47B81A0777C9E7779AD86899F777AAE85889D7675AD8A84B3938C
B5958FBF9F98BE9D95BE9F90C0A290C2A593C4A896C1A593C6A99AC5A99DC6ADA0CBB4A5
CFB8A8D5BEAEC5AA97C9AF99D9C1AECCB6A5CBB6A5CDBCACCEBFB0CEBDAFCFBEB1D2C1B7
CCBEB7A39892C2B8AECFC4BACCC1BCB1ABA7B0ACA6D1C8C1D1C6C0D0C6C0D5CBC5D3CAC4
D3CEC8D0CCC7D2CEC8D1CCC6D1CAC4D4CCC9D5CCCBD3CCCAD3CBC9D4CDCCD0CBCEC5CCE0
3C5B8B2A447BAA8FB4A2263AC91720D01015D01117BE191BD46F6ED6B2ADC1B7B5BAB8BB
A9AABA575879704F77A63D59B81422C20A12C30A0FB80D12A82D31D09B9BA79D9D929798
8A95A424335771557A80172D9F0516A5020FA5010AA10512830C1BC4959ED0CFD8C5D2DB
C5D3DEC2D0E0ADC2DE27427C021E6F021A7000176A001A630B2862567399A3BCD48399B0
5E758B61788B728696778CA14964880520520A204D556B7F6B7C82717F826E797C6E797E
35424F28373F676C6839B22D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0065D344C4BCB97279889FA8B4A9AFBAA9ACB77D8192
1B24450C1739626276766A747C6973816B74856C75856A7290717B916D7997717A967279
9C7A80A17C84A27A83A57C839A7076A1797BA77F81A27A7DB28B8DA27C7AAA8681B4928C
B3928ABA9B92BD9D93BB9A8FBF9E91C2A291C5A796C4A797C7AC9CC8AD9FC7AB9ECAB2A2
CBB5A6CFB8A9D3BBABD2BBA9D1BCA9CBB6A5CEBAAACEBCACD0C0B0CDBEAECEBDAFD3C2B8
CDBDB8A69A95CBC1B8CCC2B7CDC3BBBCB6AFACA8A0CFC8C0D0C8C0D1C8C0D4CBC3D2C9C2
D2CBC6D1CDC9D0CDC8CFCBC7D1CAC7D5CCCAD3CCCAD4CCCAD4CDCBD1CAC9D1CACBCBCBD6
778DB21E3F73767BA9A64F67BE1A27CF1219D01118C7161BBA373BE6A9A7C7B3B0BEB7B4
B1AFB4939CB52C3768966793A01B33BC0C18C0070DBD090DAB1318BA6466BFA7A59B9B99
B9C1C75C6C873B38617E365394091DA20210A5020CA4030F9208159A4D59DBCCD4C9D1DB
C5D0DFBFD0E74F689703216B011B70001A6B0120651C3E707C9ABAACC3D5B5C6D66D8296
98ADBF7E93A3A6BACD6D85A4132C5F0621533D567496AAB3849095748082757E80707A7D
3C495525363F596360675C4D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC735CFC2BA7E84928992A099A0AB989CA78F94A5
202849131B3D6B697C766A737B6B75816D77867078876D778E707B916F7A96717A97737A
96737A9F7981A07A81A47C81A17A7DA68083A78084A78083AB8587A07B79AA8483B28F8C
B4938BB8998FBF9D93C3A295BF9E91BE9E90C4A695C5AA99C8B09EC5AD9CC4A99AC7AC9D
CAB2A4CCB6A7CDB7A7CBB7A6CEBAAAD2BEADCCB8A7CBB9A9CFBEAFCDBEAFCDBEB0D1C2B7
CFC0BAA49894C8C0B9CDC7BDC9C3BCA6A198C1BBB1CFC9BECFC8BFD0C9C0D4CCC4D4CCC4
D3CBC4D5CDC8D3CDC6D2CBC7D2CAC8D2CBCAD1CDCBD2CECCD2CBCAD0C8C7D1C8C7C9C4C7
B3C0D63A5883374F86B383A5AE2334C9131CD01119CB1017BC1C23DB7D7ED1AFABC0B4AF
B6B0B0B0B3C14E5F8A5D568A953859B41222C10911BF0A0DB30D139E2D31E7BDBCB7B3B2
A0A7AA8D98AC1C254D7D5679820E25A10516A80310A5020E9C0613831C28D8B5BDCECFD8
C6D1E397ABCE0F2A6B021E70001A6D04256735598898B8D2B1C7D8B2C2CFB0BFCF435B73
6A859F6E8AA46280A51B3569031B56213963788C9C7B8B906974796C787971797C737D82
394854283A4256615C5C544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C12ADAC8BCA2A8B5A4AFBE9CA3AEA1A6B1B1B7CA
242D4D1A21426B6979766B7373646E826F7A826D76876F778C707990707A96717A946F76
98757B9C797F9F7C819E7B7EA58486A07F82A07E829E797DA983859E7878AE8786AE8787
B5918CBA968DBD9B8FBB9D8DBC9F90BDA191BCA18EC0A793C7AF9DC7AE9DC7AD9DC9AE9F
C9AFA1D0B8AACFB9AACCB9ABCBB9AACDBAABCAB5A7CDB8AACFBEAFD1C0B2CEBEB1CDBEB2
D0C0B7BEB1AAA29892AEA6A0A8A29CB8B0A8CEC7BCCEC6BCD0C9C1D0CAC2D1CCC3D6CFC8
D3CBC4D3CBC4D5CDC4D3CCC5D1CBC8CBC7C5CDC9C8CECACAD0CCCACEC8C6D1C8C6CBC7C5
C2C9D4889EBD27487D8F87B3A63F54C11924CC1019CD0F15C6141BBB393CE7A9A7C2AFAA
BEB7B2B4B3B6909DB92B386C93628CA1192EC11019C00A10B90A109D1319BE7778AC9A9A
98989B9498A540486A56486F7C264099081AA60311A5020DA10410890B18B37882D4CDD7
C2D0E744608F02216A011F6D0627685377A1A6C4DBB3CAD6B7C8D3B8C6D1B3C1D05B7088
2B466559779C0420530019521B335E63778F737E886F797D717A7D6A76766D777A6C7A81
293A492F444D5865605D564600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D7C4B3ABB1BE98A4B499A1AE9EA4B09A9EB2
292F4E2327446D69777569715E50597C6C75826D75846C738B6F758E6E76916C76957079
9B757D9B757C9D797E9D7B80A483879172779173789C7B80A68084A57D7EAC8484AD8585
B28C88B49188B9988DBC9D8FBB9F91BCA18FBEA391BAA18EC5AC9BC5AD9DC9B0A2D1B8AA
D1BAABCBB5A6CCB6A8CCBAABCCBAABCEBCADCAB8AACDB9ABCCB9ABCFBCAECCBAABCDBCAD
CFBFB1CCBEB3CCBEB6C5BBB4C9BFBACEC5BECDC5BDCEC7C0D0C9C2CEC8C1CFCAC3D4D0CA
D2CEC8D5CFC9D4CEC7D4CDC9D1CBC9CBC7C6CBC8C8D0CDCDCFCCCACEC9C6CEC6C4CEC7C4
C7C6CABEC9DC5B77A0485C8FB47A99B22131CE141FCD0E15CD1119B81A1FD87879CBA9A5
BAB3AEB4B3B1AFB6C6465A8564588B933151B40F21BE0914BA0810AC0F16AA4548C9A6A5
B3ADAEA4A6AD8991AA262C54814C6C8C0F22A10411A6020DA603119607148B3340DCC5D0
AEB9D5122F6902236C082B6D5D80AAB0CCE2B8CDD9BBCDD5BCCBD4BAC9D5B0C0CF96A9C1
50678D0F285800194E1F3D6671879EA6B6C0939DA4808A8D8690936B767769767A61737F
12243B4155615A67645D584C15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D3BBA6BBBEC99CA9BBA2ACBAB0B5C187899B
4449652A2D466C677473676F74656B7D6A737F6A71836B708B6F748D6F7596737D97707A
9A727A9F767BA27B7F9D787D9771798A696F896A6F896B6FA38183A68080AD8685AC8483
B28B86B38E86BC9A91C1A197BFA295BC9F8EBC9D8CBCA08FC6AB9BC8AE9FCDB4A5BBA392
C9B4A1CDB7A8CBB5A7C9B6A7CBB8A9CDBAACC9B7A9CBB8AACEBAACD0BDAFCDBBACCEBCAE
CCBFB0CCBFB3CFC1B9CBBFB8CFC4BFCFC5BFCEC6BFCDC4C0D0C8C4D0CAC4CBC7C1D5D4CE
D5D1CED4D0CBD3CECBD2CBCACFC7C8CCC8C7CCC9C8CCCAC6CECEC9CCCAC6CBC7C3CDC6C3
CDC6C8C6C7CFA1B2CA2545769F8FB89F3247C41622CF1218D01118C11118B63337D99D9B
BBACA8B4B2AEB2B5BA8A98B5303D738C5582A0142CBA0A17B90510B1081196161DC78B8D
D1C3C599999E939AAA2A355B6853787C1D349D0818A3020FA3010F99020E7C0C1ACEA1AF
9093B008215F0325684B709EABC8E1B8CCDABACCD6BACBD3BBCBD5BCCEDEA2BAD56983AE
163267021B51112C5866809A8294A196A5AB717D836F7C7F6C777A63727461737C3F536C
05193D48617557696B5C5E552CA21B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00CAAF92B9B9C2929EB09BA6B5A0A5B285899B
3E45602D324A6E687574696F776A6F7B69707E696F81696E856A708D6F7890717995717A
9A72799E7278A2767EA379838E646F9E757EA07D81866A6CA18586A48383AB8988B08A88
B69089B7928AB59389BFA195BDA093BEA091BFA091C1A192C1A595C2A796C8AD9BBEA490
C8B19EC6B1A1C9B5A6CAB7A8CCB6A8D1BAADCBB6AACDB6ABCEB8ACCDBAAECEBBB0CEBDB2
CABDB2CDC3B9CEC2BACCC0B9C9BFB9D0C7C0CFC6BFCDC5C0CDC7C1CEC9C1D2CEC7D3D0CB
D3D1CED1CDC9D4CFCBD2CCCAD0CCCACDCBC9CBC9C5CECDC7CDCDC7CBCCC7CCCAC6CDC8C6
CDC6C6CBC8CAC4C9D74D6892546395AE6E89B41D2BC91118CD0F14C80F15B8191ECF7070
CBA8A5B9B0ABB6B5B5B5BCCC4658864D3C6F89203EB3101DBC0912BA0B14A50D15A5474C
B395959B97989596A06069863535607D3E5D910C229E0212A1000F9B020E8A0714A15666
7F7192061C571B40779FC0DDB7CCDEBBCDD8BBCCD7B8CAD7B6C8DDA1BADA486698042562
031F581C365F6E839E657585738189707E816B747A6B767A6774795A6E763E51690A1D48
011345132A4E4E6473585F5C41752900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0094BE69C5C3C87B889897A0AE9499A4ABB1C1
1E27423B41586C697571686D74676B7C6A70806B71816A71886B768A6975916E7999747D
9D757EA37980A0757D9E757E8B626C9E767BA28182A18C8BCABABBD0BCC0B2979CAC8A8B
B38F8CB28F88B49388B99D8DBEA292BB9D8EBE9F91BFA192B79D8DB49C8EB9A496BCA897
C1AD9CC3B09FC4B1A2C5B2A4C9B2A4CDB6A9CBB4A8CBB3A8CBB5AACBB7ADD1BFB5CEBDB5
CDBEB6CEC2B9CDC1B9C8BEB7C5BDB6D0C8C1CEC5BECDC5BECEC8C0D0CAC2CFCBC3D2CFC9
D2CFCCD3CFCCD1CDC9D3CFCBCFCCC8CFCDC8CAC8C5CBCAC6CBCBC6CCCEC8CCCCC7CCC8C4
CCC7C4CDC8C7C8C6CE96A6C429477CA391B5A02E42C31820CC1016CE1016C7161AB43234
DEA4A2C1AFACB9B4B4BBBEC58998B630396B93577CA3192CB90C16BE0B12B20B13941A20
C39091CDC5C7A2A2AC8D94A9232D5776567B7B10299703159F010F9D020D970511811323
784B6E0C1A504971A0B1CFE8B7CBDEB6CADAB2C8DDA5BFDE748FBB1E3C73011F5C02255A
46618672889D9DAEB985939BA6B5BA7E8C928B979F71818C6376882F4561061843010F46
000B46000F4224375656606655493D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0061D245D2CCCE909AAAA4ADBA9CA1ACA0A7B7
1B26403D4A635E637565626E71656D7D6B717E6970836B748A6C79886674906C789D7682
9D74809F777FA37A8199717A8B666D957779B09B9BDACED0DBD3D9DDD3DAD6C4CBA5898E
AE8A8BB5918CB7958AB99A8ABB9E8EBA9A8CB99A8BB4998BA58F839481788C7B7391847A
B6A69ABEAC9CC5B1A2C7B1A3CBB5A7C9B2A4C9B3A6CDB6AACBB5A9CDB9AFCFBCB6D3C1BC
CEBEB7CBBEB5CBC1B9CBC3BCCBC5BDCDC6BDD0C7BFCEC7BECFC8C1CDC7C0CFCBC2D1CCC6
D2CECAD2CFCBD2CECBD1CDCAD1CDCAD0CDC8C9C7C3CDCAC7CCC9C7CACAC7CCCBC6CCC8C4
CBC7C3CBC7C5C9C7CBBFC6D544628E596997A76580B31F29C91219CB0D13C90E14B4171A
D17475CBA9A6BCB2B0B8B6B9B6BFD23D507B72608D952E49B30F20BD0A14B205109F0D17
B15F67C8B3BAA09FAB999CAA4551744B456D752643940B1D9F02119E020C9B010D880512
8237531D1B4D33598E9EC5EEA9C8EB95B3D76382AF20417903266401215C1A3C6C688CAD
89A6BCA7BCC891A2ADA4B5BF93A4AF8497A36F8295415773142850011145000C43010A42
010A43020E44091A444A5A685A564E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0059C837D4CAC6848E9B98A1AFA8ACB8858A9C
2632501F2F56142148313654645E6D7A68717F69718368728A6B778D6D7991707A977380
9C73829F7580A37A829A727B836268857072D0C5C6CFC5CBA497A1A89AA4E2D2D9AB9196
AC8A8BB18C87B7958ABD9D8FBB9E90B29486B19585AA948784736A9B8A83A5948E746964
9B8F86B9A799C1AA9CC2AB9DC7B0A2C6B0A2C5AFA0C9B3A6CBB6AACAB8AECFBEB6D2C2BD
D1C3BDCBC0B6CFC6BDCBC3BBCAC3BACEC5BCCEC6BED1CAC3CEC7C1CEC8C0D1CDC4D0CCC5
D1CDC9D4CFCED4CFCECFCBCAD0CDCBCDCBC8C8C7C4CECBC8CDC9C7CDCAC8CDC8C4CDC7C3
CBC7C2C8C4C1CBC9C9C5C7CE8B9FBE254577A490B59D2B3CC1141ECB1015CB0D15C21117
B53439DDA0A1C1ACABB9AEB1C2C0CB818AA847426BAF6884AA172BBB0A16B5030DAB0912
98252CB78B8FAAA2A99B9EA5747E99222A54744668820C1F9B03119E020C9A000C91040F
7D1C30563E620D245C193D7C1D3F7D0B2C6802226103245F1A3A6A647FA55978988FAFC8
2F4C6191A6B55D6E7C7B8A95637381596E86223960031647000C46010A4701094200083F
000A40020E4402123F41546761646010CB0800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0051BF28DBCFC39199A5A3ACBAADB0BD858A9F
2B355B020E41020C440A123E605D757767727E6A718068718669748E6E79907079987480
996F7D9C717D9B717A9B727A9C797E988083DCCFD5AB9BA5A189939A8289DDC9CEAA9396
A88A88AA8881B19086B8988CB39488B09184AE90849884797D716A9B8D8A978A8A736C6B
847C76B4A599BCA798C0AA9BC5AFA0C1AA9BC4AE9DC7B3A5C7B4A8C9B8ADC9BBB1CEC0B9
CEC3BBC8BEB6CEC4BFCAC1BAC9C2B8CDC5BBCEC7BFD1CAC6D0CAC4CEC7BFD0CAC3CFCCC6
D0CDC9D3CFCED2CDCCD1CDCBCECBC8CECDCACECCC9CCC8C4CFC8C5CFC8C6CFC8C5CCC6C2
CCC7C3C7C3C0C9C5C5C7C6C9BCC5D73C5B876170A0A05E77AE1A28C60F18CE0F17CA1117
B4151CD86F75D899A0CE9CA4CD9CA9C99CAFA87793D37C93B01E2EBB0B16BA0611B30610
9C1118AF6C6DDED3D4C0C7CF8B95AA2A3A6056466C70152B9307149C020D9A010C94020D
760814B98B9D6F71932C3F701D33681D36683C57816E88A8A3B9CEB8C7DA4D6177647C8F
657D8E7C939F899CA58091988999A71F355901134A010D48010946020A4502094100093E
000B3D01103E02113B32455B63686827A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DAC9B9949AA89DA7B79DA0AF7C8198
0E173F020B40010843030A3D514F6D7365737A676F7B666F836974886974916F7A95707C
976F7B9B707D9A6E79986B759E767D9E8287DFCDD49F8892A6878F9F8389D6C0C5A48C8E
A88986A7857EAE8E84B29287AF8F84AF8E80B09184917D737065627C7376756F72686262
7B726CA39489BBA799C0AA9BC3AD9CC3AD9CC4AF9EC4AFA0C7B4A6CAB9ABC6B9ADC9BEB4
CEC3BBCBBFB8CBC1BACCC3BACAC3B7D0C9BECEC6C1CDC7C4CFCAC5CECAC4CDC8C3D1CDC8
D1CFCAD2D0CBD1CECAD0CCC8CFCCC8CDCAC7CECBC9CFC9C7CBC4C1D0C9C6CDC9C5CCC7C3
CCC7C3C7C3C1C7C4C5C7C6C6C5C7CF8C9EBC2B477B9C88AE9A3044BB1823C60F16CB1318
C31218BA2129B2303BA92F3AA72A38A82A3AA52635B12431B6141EBA0C15B50910AF0A10
9D1116974A4AC1B1B5979FA78C96A65768862D305A703550880A1C9A030E9B010B96020D
8307119A5862D5CBD6BBC6D7B1C1D5B1C3D8BACCDCBACCD8B9C6D1BAC5D0A1B0BF8AA0B1
AAC2D56D8CA29CBACF748F9C9DB2C122395F00124D010C49010B4500093F000A3C010E39
0E1E3F293B5511254122364B636C6F2AA52100FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00D4BCA99EA1AE9DA8B98C91A27F859D
02083001063902074102093E4545667467797765717E6A72886F798E6D7992707C916C78
97707C996F7B9669739E6F79A0767F98787FDBC6CBB29DA3A2888ECDB4B9B69DA2A7898B
A5817EAA857DAD8981AD8A81AF8C81AF8F7FAE907FA48A7F6E5B58695F5F655E5E7B736D
9C8F849F8E80BDA799BDA797C1AC9AC1AE9DC4B0A0C5B1A2C8B4A5CAB8AAC8BBAEC9BEB4
D0C2BCD0C2BCCDC4BACCC5B8CBC4B8CDC6BBCEC6C2CEC7C3CDC8C4CAC6C3C9C5C1D1CEC9
D3D0CCD6D4CFDAD8D3D5D3CED1CECAD1CECAD3CFCDCFCAC9CBC6C4CCC8C6CECBC9CEC9C7
CAC6C6CAC6C6C9C7C7C8C8C6C7C6C8C0C5D46B7EA44F5882A0718C9F303FB22025B71B1A
B81E1BB4201EAD2222A82122A71F23A92327A82627A92726A62323A52324A1242299231F
8B28269E6664A297999EA4A9A2AAB9788AA118284F6B4C6F7A0F269504129C010D98020C
9107127A202BD7BBC5C8CCD4C3CFD8C0CCD8C0CDD8BBCCD5B7C6D2B5C4D1B3C4D7486381
43618D0421571C3B6E385B78648090374E6D02134B000F4B000E45000F3D07183B26394D
475A634F60662F4352182C3F5D666D55483F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CAAE94A2A2AB99A0B37E8599424966
01062E01043401063E02083F3F3F637267797B69737F6871886C768D6D788E6E78906C74
9770789B7179956A6F9C7177A0767DA07E83B2999DD9C6C9D1BCC2B69DA2997A7EAB8986
A5827AA9857DA9837BAD867FB08C81AE8D7DAE907DB194859F877B927E759180778D7B71
9A8579B59E90BDA596BDA896BFAA98C1AC9DC5B0A2C5B1A2C4B1A2C8B7A8C9BCAEC9BDB3
CDC2BAD0C6BECAC3B9CEC7BDC7C1B7CDC7BECDC7C1CDC9C2CBC5C0CDC7C4CFCBC6D3D1CB
D7D5D1D7D5D1D6D6D2D6D4D1DAD6D4D7D2D0D2CECCD0CCCBCCCAC9CAC8C7CDCACACCC9C9
CBC7C7C8C4C4C8C7C6C6C4C0C5C2C3C6C4CAB9BCCD9098B1827C91AA828DC57E7FC77872
C87770C77C71C58177C4837BC88781C88B83CB9189CD9690CD9691C8928EC48F8BBA8883
AF8985B5A5A2949698C0CAD1BBCBDA94A9BE31456748436872243E8E07179A020F9A000C
96030F7D0B18B8838DD2CCD2C5CED8C0CCD8BCC9D6B8C9D5B8CAD79AADBE72889E455E80
05225C02196201175D1835616B889A5C728C01154801134B05164220324D465864566668
5866645460603E4E5914253558676C625C5500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0098C26CACA8AF84889B84899F141939
02062E01043401063D020A3F3C3D5E7868797F6672856975886A758B6C76916F788F6870
986F769A71769B71759A70769E767D9E797E9C797DA08287A5878CA281859D7678A57F79
A7847BA27F76A58075A9847AAC8A7EB19183AD9080B09685B89F91B8A191B49C8DB59D8F
B99F92BDA395BCA394BEA895C0AA97C2AB9CC4AEA0C7B2A3C8B6A5C8B7A8C8BBACC9BFB4
CAC0B7CDC3BBCEC5BFCDC5BFC6C0B9CAC6BFCCC7C1C9C6BFCBC7C0CFCBC6CFCBC5D2CECA
D9D6D1D7D5D0D5D4D2D3D1CFDAD6D5D5D0D0D3D0D0CDCDCDCBCACAC9C8C8CCCBCBC9C8C8
CBC8C7C8C6C3C6C5C2C5C2BFC6C1C1C5C2C3C4C0C4BFBEC3BDBDC3BFBBBCC4B7B3C6B7B1
C7B6B1C1B4ADB9AEA8B8AEA9B7ADA9B2A8A3B0A7A3B6AEAAB1A7A5AFA8A5B1A8A6ABA2A0
A6A1A1D2D4D5B5BCC2A1ACB76B7B8D7083976779951F2850784868840B229903149A010F
9A02108F09168D3D48DCC9CFC8CED9C2CFDBBFCDD9B7C8D3B7C9D696A9B8768C9DA9BFD5
1B326503186102155F041A4E59758D748CA0071C41172C4F3E516654666C5B68685B6663
576160535E603C4A5415253257686D79797410CB0800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065D549BCB4B48A8EA1696D87070C2E
00042E020533010639030D3D3F3F5E766475816674866A77896A778E6C788E69748F6772
976F789B71799E737B9E737BA078809F767D9D7277A4797CA57B7DA1797AA27779A47978
A67E79A07971A37D71A68374AE8E80B39688B19585AF9585B39B8CBAA192B8A08DB9A28F
BAA292BCA395BEA697BEA694BEA793C3AC9BC2AC9DC5B0A1C9B5A6C8B6A8C7B9ABC7BDB2
CABFB6CCC2BACFC6C0D0C8C2CBC5BECAC6BFCAC6BFC7C4BEC9C6C1CECAC6D3CECAD4CECB
D8D3CFD9D6D2D5D4D1D3D3D1D9D6D5D5D1D2D0CED0CACACCCAC9CAC9C8C7C9C9C5CBCAC6
C8C7C2C8C7C2C6C5C1C5C4C1C3C2C1C2C1C0C2C0BFC3BFBEC0BFBEBCBCB9BBB9B6BBB8B6
B9B7B4B6B6B3B2B1AFB0B0ACAEACA9ADABAAAEACAAADACA9ABA9A6A6A4A3B6B7B6B9B8B9
9F9EA3A3A6AA989DA3949AA199A0ACB9C6D295A6BC23345D654E777715319405199B0210
9C010F9305107A1420CFA8B1C9CBD5C2CED8BFCDD7B6C7D1B8C9D5B8CAD8768DA1AFC6DB
42567F01135600125901164A4A6580657B884D60705A6D755D6F715A6B685B69645D6963
5B65655763672B3D481C303C55676A8B8F8C239C1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005CCA39C6BBB7737B8C4A516B000528
03072E16163C22234A070D35494965746374816A778569778766768864728A66738E6A75
956F7A9D747F9C727B9C6F7A9E727BA0747CA4767DA6787CA6797BA4787AA17477A37678
A276759F7470A47C71AC8879B19082B59687B59889B69A8CB89D8EBA9F8FBA9F8EB9A28E
BBA292BFA697BDA496C1A797C0A794C4AD9BC3AD9DC7B1A3C7B2A5C7B5A9C7BAAEC7BEB3
CAC0B7CDC4BCCBC6BDD0CAC2C8C2BACAC3BFCEC7C3C8C4C0CCC9C5D2CFCCD5D2CFD4D1CF
D4D0CDD3D1CDD2D0CDD4D2D1DAD8D9D5D2D3D0CCCECCC9CBCCC9CACBC9C9CBCAC8CDCBC8
C9C7C3C8C7C2C7C6C2C4C5C3C0C1C0C2C2C0C3C1C3C4C1C2C0BFC0B9B7B7BEB9BBBBB7B7
BAB6B5B7B1B0B7B0B0B5AEADB6ADAFB2A8AAB1A5A7ACA4A2B0A5A5AEA1A1A69E9DB1A9AB
ABA2A79F999EC4C1C5BCBABFB1B0BABFC7D79AAAC64152793F37617B2F4B8F0A1D9A0311
98000D92020E810816A2646ED3CBD4BFCAD3BDCCD5BBCBD5BAC9D5A0B2C12D435B5C7289
6B7D990D2051041853051B4860778C6E81886F7E816878775F6F6D5E6C685B69645D6A64
5B6867526067112332253D474B60618C94922BA52300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02ACDBBB0868B9A343C5902072A
0A0D2C49415A4E455E0E0E2C57536C7A6B7C7E6A77806875866576866172835F6E886270
9169759B717C9B707B9E727CA0727C9C6E77A3727BA6767DA4757A9E7073A07375A07275
A27575A37876A88179AD8B7DB09081B29283B49586B39587B39587B59889B69C8ABAA08D
BBA191BCA294BEA496BEA393C2A997C1AC9AC2AC9EC7B0A4C7B2A6C7B6ABC7BCB0CAC2B7
C8BEB5CAC1B9CAC2BBCEC6C0CBC3BEC8C0BCCDC4C2CDC6C4CCCAC7D3D3CFD5D5D4CECECD
CFCECED3D1CFD6D3D2D4D1D2D2D1D2D4D3D4D2CED0CFCBCCCCC8C8CAC7C8CCCBCBC9C8C7
C8C8C5C3C3BEC4C4C2BDC3C3B8C2C4BEC1C5C4BCC2C7BABEC6B4B9C6B2B7CAB1B7CEB1B7
CFAAB3D2A8AFCCA1A8CA9DA2CA99A2C9939DC48D97C08993C18490C0828DB97D84B87D84
B97C87B27985D3A0ACDAABBAB07F949C728C724E70866888623C5A9F4C638B08199A0212
98010E91010C8804137B2633DBC1CBC5CBD5C1CCD8BFCBD6B7C2CF7E8E9B9AAAB9708390
B2C2D066778F2F43643348628697A46C7C826E7D7F6C7A78677172626B6A5E69675A6867
5363692C3D5002132C314B594961646F7D7C51474000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0052B920CFB8A68A8C9D1B234203092A
23243B5E5260564A5C15122A645C7279687777636F7B6370816271825C6E7E56678D6272
906571986D77966B789A6D7A9B6D799F6F7B9D6C77A27077A17177A071749A6C6EA07372
A07573A57A76A9827AAA8679A98879AF8F80B49686B19585B59888B69A87B89D8BBAA090
BBA091BCA193C1A698C0A797C0AA99BEAA9BC1AC9FC1ACA0C5B2A5C5B6A9C2B9ADC6BEB3
C9C0B5CCC0B9CCC1BCCFC5BFCAC2BCC3BCB5CAC4C0CCC7C5CCC9CAD2D1CFD1D2D0CECFCD
D0D0D0D2D1D2CFCED0CFCED0CECED0D2D4D4D1D0D1CCCACACACAC9C7C6C7C7C6C6C7C6C6
C7C6C5C1C1C0C3C7C99DABBA658096B4BACDBF9EABCA8894CA7884C56D79B75966B54E5E
B34154B13A4BAB3443A52D3BA326349F1F2EA01E2D9C1A2AA0192B9C17279C16239B1824
9A16259A17279B1A2F961A30971B3092172E901A33891A308A1D2F9317299706169C0210
9A010E93000C8F02127B081AB67086C4A0B8C5B0C7C9BDD0C9C4D2A4A7B2BFC9D196A7B2
9EB0BC8EA0AA70838D6D7E8569767C6A76796F7B7C6F7A79676F71626C6D5D6A6E50616B
293A51041234000C2F152A42435A645666675B554E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B71AD4B6A08A8B9A101A39050C28
3D3C4B60555D5449571C172E6F657878657278626C7E63707E5E6D7A56668057688C616F
966A74966A75986C7A986D7B976C7B9C717E9D707A9C6C749D6E729D6E709B6C6D9D7370
A07772A67C76A88078A78276A78577AA897AAF907FB09384B39787B69B89B69C8CB89F92
BA9F92BDA294BFA697BEA797BEA99ABCA99CC0ADA0C3B0A3C3B1A2C1B4A5C1B7ACC3BBB0
C5BDB2C8BFB6CAC0B9CBC2BBCEC6BEBEB8B0CAC7C1CCC9C7CBC8C8CCCBC9D0D1CDD0D1CD
D2D2D1CFCFD0D0CFD2D0CFD0D1D1D2CFD0D0CCCCCCCBCBCBC9CAC9C7C8C7C8C7C7C5C4C3
C5C5C3C1C3C2C0C3C89DAEC42143728592BA92586FA42738B61E2CB91C26B91924BB1822
BD1623BD1421BD1422B7121DB61219B31015B4141BB01219AF1118AD1217AC1116A71012
A71013AA1116AB121AAA121CA50E18A40F199F09189B09179C0A169B09159F0A1799040F
9A020E96020D960212900416850C247A163279223E7B314A87495E8A65729E99A273808B
61727F7284886273776E7C7E6F787B727C7D75807F707B7A697274616C7054667420304F
010D37000735010733000B2F22364A54656A59565100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B414CCA88E827E8C060E2C080D26
5B566262545A514653201A2E72677876636F79616B7C5E6B7655647C5A69845C6B8F6473
966975986D78956F7E86687E7C637C8B6E8298717D9B6E769C6C719A696C9C6B6C9D706D
A27773A67C76A77F77A68174A68475A88776AF8F7DB29284B29588B09587B19B8DB49F91
B6A294B6A092BBA596BDA799BBA499C3AEA3C2AFA2C1AFA1C4B3A4BFB1A4C0B6ACC5BCB2
C8C0B5C9C1B7C9C1B8CCC4BCD0C8C0C4BEB8CBC8C4CBC9C6CBC7C6CBC9C5CBCCC7CECFCB
CDCECDCFD0D0D1D0D1CFCDCED0D1D1CCCDCCCDCECCCBCCCBC8C9C7C8C7C5C9C6C4C5C3C2
C6C5C4C4C4C4BEC1C2BAC3D24E6B973C5588AE82A0A22A38B81F26B71D1EB21D1BAF221E
AC2120AD2726AC2A2CA5292AA62F2CA6352FA43931A03B34A13D379F3E379E3F379B3E35
9B3E35A1443D9E3E3B9D3E3A973836933333923035902D328B242A851E24881C2386171C
8812198810178A0C168C0C188B0B1A890A1A880B1D850A1D7E0B206B18278C6F77A1A6AD
7E8C9395A5A78392948996977A83866E78797581816D797A6C76795A6973263854010D3A
01093B010836000734010A340616334559615257560CC80700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C79C7B7B717F060B2A0A0D27
6A616D64535B4B414D2C26376E667472636E775E697B5C68795664805B6A89616E8F6471
936775926C7E7B637D352F5916164A3831598E758A986C7698676B9766689C6C6BA17572
A47876A67876A27771A88277A58373AF8E7CB0907EB09183B09388AE9489AA988CAE9F93
B4A394B5A193BAA496BAA499BAA49BBDAA9FC0ACA1C1ADA1C0AEA2C1B2A7C0B5ACC6BCB2
C6BDB3C6BCB3C7BFB7CAC2BACEC5BFCBC5C0CBC7C3CFCDC9CBC8C4CECDC8CACAC7CDCDCA
CCCCCCCDCDCECCCBCCCCCBCBCDCECDCACCCAC9CBC9CBCECBC9CBC8C8C8C6C8C5C4C8C6C4
C5C3C4C5C3C4C0C1C1BCBFC794A4C12A44719A92AEAB7077BE6A69C77471CC817ACF8A83
D08F8ACF9791CB9894C99B95CBA09BC39F96C1A098C1A39ABFA29CBA9E98BCA09AC5ACA5
AB948CB49D96B8A09DB49D99AB9492B69F9EA98F91B0989AAA8F93AB8D90A78284A77C7E
A775799C656894575C8D4A4F8A41478133397C262E761A227415226416207D5C60BBBDC1
A7B4BB86959B8B979B6E7C7D707C7D6974746C77786875776572793F4F6504103C00083E
02083C010837010733000835000E302C41504D585A17921000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C092688F848B050C29171A33
5C515E64515B49414F36374B5A5B6E615A6C6F5D6B7357647A5A66815D6A885F6C8E6472
8D6476826480342C570A124C0610530D134B706180956D7A95656A9A6A6D9B6D6DA27574
A17271A57573A27570A87F77AC877AAF8C7CB49181B19082AE91869F8A7F8879707F746B
A99A90B5A195BAA498B9A397B9A499BAA79BC0ADA0C1ADA1BFACA1C0B0A7C2B7AEC0B6AD
C5BBB3C8BEB6C9C0B8C9C2BBCBC4BECFC9C4CCC8C2CECDC6CAC9C4CECDC9D0CECBCCCBC9
CDCCCCCCCBCDCBC9CBCECDCECECFCDCACBC9C7C9C6CACCCACACBCBC7C7C8C3C2C2C6C5C6
C1BFC3BEBDC0C1C0C3BEBFC2B7BBC88B98ACA6ABB9C4BABCCAB8B7C8B6B3C2B4AFC0B3AE
C3B4B3BDB3B2B6B0B0B5B0AFB4AEACAEACA9ADABA7ADAAA8AFA9A9AAA3A3AAA4A4ABA8A8
9A9C98989B99ACADAFACAFB1A6ACB1CFD7DEC4CED9ACBAC998ACBBC5D4DCC9CFD5C6C9D0
CDCCD4C7C4CAC3BBC2BFB6BBB8ACB1AA9C9FA48F929980867C5F6B755963756A6F8C9499
87959D6C7881717B816C777A6773746371716473736372745D6D7A142446020D43010840
01073C010837010833000A34010F351C2E444C5A5F28632000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B686539B8D90090F29323448
685C6862515B3A36472D36510E173A222543685D70715A66775A65815F6C886270896071
86627A59456C14124139396A20235B060D435A4D6F916C7A95666C98686B9B6C6E9F7071
A27372A97A78AA7E79A67E76A68075AE897AB08C7DB39184B4978C8C776DA6988F867B72
8F8279AD9E93B7A397B5A094B8A396B8A698BEAC9DC0AFA1C1B1A4BFB3A8BFB6ADC1B8B1
C6BCB6C5BBB5C5BDB7C4BFBAC8C4C0CCC7C2CCC7C2D0CCC7CCCAC7CDCBC8CDC8C5CEC9C6
CECCC9D0D0CECBCACACBCACBCACBCBC9CAC9C8C9C8CDCECCCACAC9C5C5C6C5C4C6C5C4C6
C2C1C4BFBFC0C3C2C3C1C1C1BFBEC0BCBFC0BABDBDBCBEBDBEBDBDBBBBB9BABBB6BAB9B6
BCB9BAB4B4B7B2B3B5B2B3B5AEAFB0AAACACA8A9AAABA9ADAAA7ABA4A2A3A5A3A59E9F9F
9EA3A2949B9AC7CFD1D0DADEA4AEB9B2C4D794ADCA7C97B357748BC0D6E5C6D4DFC5D2DC
C7D1DEC9D2DEC7D1DBC7D2DAC4D0D7C5CFD5C7CED5AEB7C4374458515D6D87929A839096
8E9AA38792997B858C838D9068747562737061746F5F707344556904123F040D48010840
00083C000C35020E300917360314331121384C5B6338333000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005EC631A28D8A1113292C2B3D
5D515A5E505A2B283F0E173D0109370C1239554F646E58647B5E6A836270876371876275
7A607C221842393259827191463D68090B3F5344678C64739463699A6A6B9E6D6FA06F6F
A1716FA67874A9807AA58077A58177AD8A7CB19181B49485B6998C8A756A85776D807066
8B7C6F8C8073AF9F95B5A196B7A498B6A497BAAA9ABDAE9EBCB0A3B9B0A5BCB3ABC1B9B1
C3BAB3C7BFB8C8C1BCC6BFBDCAC6C3CBC8C5CBC6C3CBC5C4CBC6C6CCC8C7CCC7C4CDC8C5
CCC9C6CCCCC8CCCBCBCDCCCECBCCCDC8CACAC8C8CACBC9CBC8C7C7C6C5C4C6C4C4C7C4C7
C7C4C6C1C0C0C0C0C0BDBFBCC1C0BEBEBFBDBDBFBFBABBBCBABBBABBBCBABABAB7B5B6B3
B5B5B7B0B4B6B0B1B5B1B1B4AFAFB1AAABADA9AAADA8A7ABA7A7AAA6A8A9A3A3A5A2A4A7
D1D5D7A6ABAEA7AEB4B4BDC698A2B07E8DA5304A6B768FAAA4B9CBC3D4E0C8D4DFC7D5E0
C5D1DFC8D4E2C3CFDDC4D2DDC2D0D9C2CFD8C6CFDA919CAB95A4B5708291AFBFC9B0BDC6
97A2ABA8B4BB738087768185677575657571637571607176253551000D42000944010B3F
02123A12263F344757475A6524354708182E4A5B663B3C3A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BD25AB8E831F1B2B2C2835
6F65695F515B1E193401063102093C050B35554D66735D6A7A5F6B7F5F6E826070856679
58486917103971607D876F89352C570B0D415B486C8E637198656A9A67699D6B6C9B6A69
A47471A67A75A47B75A58179A7837AAC8A7CAF907FB29382B095839682748D7C70AA9688
B5A293918276A5968BB5A296B7A498B8A69AB6A799BCB0A1BAB0A5BAB0A7BDB4AAC0B7AF
C3BAB3C3BBB5C5BEB9C8C1BEC8C3C2CBC7C6CBC6C4CDC8C7CCC8C8CBC8C6CECCC8CCC9C6
CCC9CACDCBCCCBC9CACCCACCCACACCCBCBCDCBCBCDC9C8CBC7C6C7C6C5C4C6C3C3C5C2C3
C4C1C0C2C1C0BEC0BDBDBFBCC0C1C1BDBFBFBFC1C4BABCBDBBBCBDB8BAB9BABAB9B4B5B6
B3B4B6AEB2B3B1B3B6B4B4B7B0B0B2B1B2B4AAABAEABACAFA7A8ABB4B8BAA7AAAC9DA1A2
A6AAAE9AA0A392989D848E97ACB4BE949EABB0C3D7BCD5EBBAD1E2C4D7E0C2D2DAC4D3DE
C4D3DFC6D3E0C7D5E1C6D4E0C3D1DCC1CFD9C3D0DB9EAEBAB5C7D3A9BCC68A9BA7A4B2BE
7A879178858C707C816E787B68737467767262737160727A122246010C44010E4303163F
20364D4961664F62614F5F5F44525B06162A475A663339380DC80700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD10B28D76463E48443F4B
62585B584C55120D2801053103093E030735564C69745E6D785B6A7D5D6D8262727B647A
2E254A372F5489728A7A64811712440E0C436E57778D616D98646A9A656A9C696C9A6968
A27571A27772A27872A37B75A9837BAB887CAE8D7EAD907FAE96848C7968A89788B29E90
B5A0939C8A7FA29084BAA798B9A699BBAA9DBCAD9EB9AD9FB9B1A6B9B3A8BBB4A9C4BBB4
C4BAB7C5BCB8C5BFB9C6C2BDCAC5C2CCC8C4CDC8C4CCC8C5CBC8C6C9C6C6C8C6C3C9C7C5
C9C7C7CECCCDC9C9CACBCACCC8C6CACAC9CDC8C6C8C8C6C9C9C9CBC7C6C8C5C3C6C1C0C2
C0BFBFBFC1BFBDBFBDBABFBBC6C8C7C9CCCDBEC1C4B7BBBBBCBDBEB8B9BAB7B6BAB3B4B7
AFB0B3B0B3B5ADB0B1ADAFB1ADB0B2A9B0B0ABAEB1A7AAADA8A9ADA1A5A99FA3A69A9E9F
979C9DA6AFAE9DA7A9A8B3B8D0DCE3B6C5D096ABBD59799983A4C0BFD6E2C3D4DFC3D5DF
C2D1DCC3D4DFC5D3DFC4D2DFC3CFDCC0D0DBB7C8D88298AF6F889A6E85925C6F7E7B8994
717E8777868A7683866D787B6873736474705E716F5D6F7A09193D010C42011040223651
4D6368546763566660535F5E4A576008182B425A672635390BC80800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B68A685E525666626E
685F654E46510A082402053102083D050A3B494161705A6B7C5E6C8261718264776C5A74
1510355F517290769056476D0B0C441B1649795D7790626E97636A9966699C6B6D9D6D6D
A07170A27672A77A76A37974A78077AC877BB18F82AE9283AD95868A786AA49388AE9C91
B29F95928074AA9788BAA597B8A699BAA99CBBAC9EB9ACA0B8AFA5BEB6ACC2BBB1C2B9B4
C3B8B6C0B6B4C4BDB8C6C0B9CAC5BFCCC8C2CECAC5CCC8C4CBC7C7C9C5C7CBC7C7CBC7C6
CAC6C6C8C6C8C8C8CAC9C9CBC7C6CACCC8CDCDC8CDC8C3C9C9C6CBC5C4C7C3C4C5BDC0BF
BBBEBEBFC1C2BABDBCBABEBDB8BCBDB8BCC0BDBFC3B9BDBEB9BABBB6B7BAB5B4B9B2B4B8
AFB2B5ADAFB3ACAFB1AFB5B6AEB6B7ACB6B6A9B0B2A6ABAEA0A4A8A3A7AAA1A5A89CA1A1
969C9CCBD5D4C8D1D6959FA99CABBE7E97AA8399AE2745656988A5C2D7E4C5D5E0C5D4DF
C3D0DDC4D2E1C2D0DFC3D1DDC6D2DDC5D3DE96A5B7394F6A415A709FB2BF8D9DA98A98A0
AEBDC375878A8A9A9B69777967737163736B5F72705F6F7B07153C010E410F2247506371
596C6B596A64566561556464465562091A313852660D20310C8D1200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B92C6E5A5C5A5563
635D66453F4E030223020532030B3D070D3B3E3954644F5E7B5E6B81616F826679534664
1C173B7865838E76952B2456070C473B315D89667A91616A915E659968699B6A6D9E6C70
A37174A37272A47571A47973A98177A98477AD8C7FAF9183B09586A38C7F88766C98877E
938178A59285B6A292B9A495BBA89BB6A499BCAAA0BAADA1B6ADA1BAB1A8C4BCB4C3B9B5
C4B8B5C2B7B3C7BDB8C8C0BAC9C3C0CCC8C6CCC8C7CEC9C6CAC7C6CAC7C8CAC7C7C8C5C3
C7C5C4C8C7C9CBC9CDCBC9CEC6C4C8C7C5C9C5C2C6C2C0C5C6C5C9C4C3C5BFC0C0BDC2BE
BBC0BDB8BDBAB8BCBABABEBDB8BBBFBCBDC2BBBBBFB7B9BBB5B6B9B3B3B8B7B7BBB2B6B9
B0B4B7AFB3B6B4B7BAA4AAAD868C8E909798ABB2B3A1A8AAA0A6A9A0A6A8AEB4B7BBC1C4
959C9F9CA6AA9AA4AD9199A5717F93748DA0AFC0CE90A3B1B7CAD9C6D7E0C8D6DFC9D6E2
C1CDDCC3D1DFC0D0DDBFD0DAC7D5DFC7D4DE93A1AEABBECD9BAEBEA5B6C1BAC7D07D8B94
94A2AA77878A6F7E7F69777569787466776F62747063747E09173D02113D374D63586E71
596C6A596B6859676753646B2C3C510B193B0D2144031432088C1700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052B927826B676E6876
68606E3730450203250209310913400A11395F586F6C5A65795F698163707E667A382F4D
322D4E816F896E60830B0D46070B455A486D8D6574915F67915E619867679E6F709C6A6E
9B686BA06D6DA3726FA47871A77F75AC887BAB897CB19083B29485B39889A99283A18C80
A99488B8A294B6A090B8A393B7A495B9A79BBAA99FBAAAA1B7ACA1B9B0A7BEB7AEC0B8B0
C1B8B1C1B7B1C5BCB5C8C0BBC6BFBED1CBCEB8B1B4C0BBB9C9C8C4CACAC6C7C7C4C6C5C2
C5C3C2C3C3C4C5C3C8CBC8CDC8C4C9C7C5C8C5C5C6C4C4C6C5C7C7C2C3C4C1C1C3BCBEBC
BABEBCBCC0BCBABDBBBABCBBB8B9BABABABDB8B7BBB5B6B8B7B8BAB5B7BBB5B8BCACB2B7
AFB3B8B2B4B8B8B7BC9392968F91928E91919FA3A4A5ABAEA2AAACA1AAAC9BA4AC8A99A5
929EA98C949CB1B6BFC8C9D4ACAEBACED4E0D5D9E4A4ABB4CCD5DEC7D4DCC6D4DDC7D4E0
C4D3E0C3D3DDC2D2DEC2D1DCC3D3DDC3D2DF9DB1C197ADBCA8BBC877899884929E75818C
7A878F7D8A90737E7F6E7A7A68777565757063737167757E11204107173A4B626F576C6C
5B6E6D56686A54656D3B4D61061236010C39000D39020F3409122900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057BB24876C6166606C
67616F252138020526121B3B3841621317386960746D5B66725C6679616C79667C201C3D
4C46657B6B8834305B050D4718164A785E7D8C5E6C92606892606399696A9B6A6B9B686B
9A65689E6A6A9D6C68A1736DA87F78AD887EAF8C81B39185B49386B69788B69B8CB19A8A
B59D90B7A092B39D8DB7A292B9A496BAA899B7A59ABCABA3BAACA4BAAFA7BEB4ADC2B8B0
BFB6AEC0B7B0C4BCB5C7BFBBC6C0BECBC6C7C8C3C5C7C5C3C6C7C2C5C5C1C5C5C1C8C6C4
C6C2C2C1C0C1C8C7CBCBC8CCC8C3C7C6C5C7C2C2C3C2C3C5C3C3C5C0C0C4BEBDC2C1C1C4
BBBEBEBCBFBFB8BBBBBABCBBB8B9B7B8B9B8B8B8BAB5B7BAADB2B7A8B3BDA7B4C1A0A7B5
A8A1AFBBA8B4BFA0ADA3858FA58D93A09094ABA2A7ADA9AEA5A7AA9DA6A998A3B02B4361
5F72908D8296B792A6CA9CB0B7869AB7879BC094A8A37E90C9B5C4CED0DBC5D0DAC4D4E0
C2D3E0C0D2DCC6D4E0C2D0DBC2D4E0B0C7D84764815E7B927A8F9D637583899AA49EABB2
7A88909EACB1707E7F6C79796976766675726976766A767E22324C0A1C3B526B77566C6C
566B6F4C616E2F405908163C000836010938010A37010D330F162E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD119B7866524850
67626F16162B0308252E324B47486125233C6B5F7074606B735C6777616D6D5D75130E32
5A5275675D820C1145060F4A392F5C83607A8C5E6B905E66915F6497646A9C676D9C656A
9A63679D6668A2706DA3756FA77F78AF8982B28F86B19085B59487B49587B5998CB59E8F
B49D8FB7A191B7A191B59F90BAA496BBA799BAA89BB9A99FB6A9A0BAAEA6C1B5AEBEB1AD
C0B6B1C1B8B1C6BDB9C5BCB9C6C0BDC6C3C0C9C5C5C6C3C2CBC9C5C8C5C2C6C3C2C5C2C1
C3C0C0C3C2C3C6C6C7C9C9C9C7C5C6C2C0C2C4C3C4C2C1C3C1C0C4BFBFC4BFBFC3BDC1C3
BABDBFBCBFC0B8BABEBABDBEB9BAB9B6B8B9B2B4B9ABB6C393A8BF6A7D9B6A6A89967491
AA6781B0566BAF445995283C9D394AB05B69C07C89C595A0B4979EB4A8ADA8AABA384E75
273A6C765A7C771D3B8915318E132C8F14298D152E8718307E3349D9C3CFCACFDAC3D2DE
C3D4E2C3D3E0C2D2DFC4D1DDC4D3E09BB0C14D67835E7890ADBFCDBACBD48B9CA5B7C5CB
84929A818F94717F826C797B6976776777766775756B777C424F630618354660734B666F
42596D17284B020D3B000839010636010736010936020B321D243A148E1300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6346584A4E
6E69770D0C24090A264D495D453F543A334972637175606B6E586277616F5B4D69110E35
656085302E5D040D4A0C114A655177805A70845C6A865C678D616897656C9B646A9D666A
9B64689C6769A16F6DA47772A77F78AD8781B39087AE8E81B29284B49688B29789B29A8B
B69E8FB6A090B8A293B7A193BBA597BBA799B5A498B6A99EBAAEA4BCB1A8BFB4ACBEB4AE
C0B8B2C0B9B5C7BEBBC5BDBAC5BFBBC4C0BBC8C4C1C5C0C0CBC6C7C7C4C4C5C3C3C4C2C0
C2C0BFC1C0C0C2C2C1C8C8C6C3C3C2C0BFBEC3C2C4C4C2C4C5C3C7BEBEC2BABDBEBABEBD
BCBDBDBFC1C1BCBCBEB7B7BCB6B6BAB1B6BBA9B6C47490B136527E7A7099914D709D2845
A61329AF0E22B70D1FB80D1DB40D1DB11123A41326A5273AAB4657C88290C39CAD807A9C
17225777638B7B1D3897071BA40414A60514A204139F0719860D21C18C98D4CFD9C5D1DC
C5D3E1C4D1E1C4D2DFC4D2DEC6D3E1A1AFBFBACBDCB6CADB8C9EABAFC0CB80929C819098
808C9379868A727E826F7A7E6B797B69797868777567767664717D101F3A253B5C213658
04123F000C4100083E01063A010536010734010B35010D3030394A1E9A1D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AC815C77696A
5A566609092219152E5E51623F3448453E5272626F745E695F4753776171463B5914163E
565B870B124A040E4D211F507C627D7856666749586247537A5A6492676E9A676B9D6569
9D67699C6869A47172A47574A97E7BAC867FAE8C82B29183B69687B49788B39888B59A8B
B79C8CB89F8FB59F90B7A193B5A294B9A799B5A699B5A89EB9ADA4BBAEA7BDB2ABBEB3AD
C3B9B5C1B8B5C2BAB7C4BCB9C7C1BCC7C3BECBC7C4CCC8C8C9C7C7C5C6C4C1C2C1C1C0C0
C3C2C1C2C2C1C2C3C4C2C2C3C5C5C4C2C2C1BFBFC1C0C0C3C3C2C4BDBDBFBEC1C2BCBEBC
BCBDBCBCBEBDBCBCBFB7B6BBB6B6BAAEB7BF839DBA2045797D7EAD974A6AA4172FB70D20
BE0917BC0712BD0610BC070FBB0510BB0511BA0915B40817AE0D1FA013289B2B42A75D7A
54325E553B638C4057930B1CA40210A8020FA5010DA3020E970817903D4AE1CBD6C8D0DC
C8D5E4C6D2E2C6D3E3C4D1E1C1CFE392A5BB869AAB8A9EAC778B9B8496A380929A788790
94A0A77C888D727B806E7A7D6A787968787667797565777565737B2F3E5A000E3D000B3F
01074000094200063D01083B0106350009320110331F33492E3C4429A92900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC83B837574
7272820809232B243A615260332A3C514C606C5E6E725D6A735A677860723F3456151E4D
26356A010D4B050D49473E657B5E73694A586A505B5F4A55553F4988666C97686D9B666B
9D69699C6869A37072A67778AA7E7EAD8681AE8C82B29284B59585B29685B09682B49A87
B49A8AB49C8CB49E8EB6A292B7A596B9A89AB8A79AB7A99FBBAEA7BCB0AABFB4AFC0B4B1
C2B7B5C3B9B6C3BBB6C4BCB9C4BDBAC4BFBCCAC6C4BDB9B9C7C6C6C4C4C3C1C2C1C1C0C1
C1C0C0C1C2C0BFC1C2BEC0C1C5C5C5C4C4C3BFC0C1C1C2C3C0C1C2BFBEC0BEBEC0C1C1C3
B8B9BAB7B8BABCBCC0BABABDB3B6BBA9B8C7375D8B34538AA2779E9C1933B80A1CC00914
C10711BF060EC00710BD060EBB060FBC070FB90913B50C16AE0D19A50A199F0B1D971025
922644863654B55B718F0D1DA10311A6010FA6010DA4010B9D051280101DD1A4AFCECED9
C8D3E1C5D2E1C3D1DFC6D4E49FB2CA24405F5E789199AEBD7F92A2899CA9C0D3DC86969F
95A1A978858A6F7C807180826A797A67767567787666777663737C1D2C4A010A3F010742
01064100073F01083E01093A000B3502123222384C4C636C28393B47463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064D1448A797A
4C4C610407233A344661566129263A4B4F6A403F5B64596E745F6F766075392E550F174E
091653020D4B16194E6F60806F54667559657659616F5660533F4B74595F8E666999686B
9C696B9D696AA06E6FA8797AA97E7EAB8580A9887EAE8D80B29283B09482B09682B29884
B79D8DB39B8EB7A091B7A294B8A697B8A698B7A598BAA9A0BEB0A9BCB0ABBEB3B0BEB3B1
C3B8B6C4BAB7C1B9B2C3BBB6C4BDBAC6C1BEC4C1BEBCBBBAC3C2C3C5C3C4C2C1C2C3C2C4
C1BFC0C1C0C0BFC1C1C0C3C4C3C4C4C1C1C1BFC0C0C1C2C3BFC0C1C0C0C2BDBEC0BEBEC0
BCBCBEBDBEC0BBBCC0BABEBFAEB5BB9DB2C81640776273A5964B6BAE1229BF0917BF060F
C20811C10612BF0511BC0510BC0610B70D13A7161BA42F379A37438E303E88202F8C1424
971125941227A92A3D9E12219F020FA4010DA5010BA3010BA0020F910A189F5563DBCDD7
CCD3DFC6D4E0C6D3E0C8D6E698ABC06D87A087A0B4A3B7C4C3D5E18598A391A3AE81929B
828E96768188707E83697C7D6A7A7A6D7B7B69777766767763737C293956010B3E000741
010743000A42010D40000F380618352D44524D646A52666A2A3B3D51514A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0061CB3BA28D8D
4D4D65060A254740505B505D1D1F3B17224E030B3C3433566A5C7069586F2E2650040843
010949030A453C37617E6982685061775C697758646D546050404B6751578B6467916064
9865699D6A6DA27072A7797AA77F7DA8827EAA867FAF8E84B19386AF9584B19683B09583
B49A89B39B8BB5A090B6A093B9A599B8A699B6A499BAA9A0BFAFA9BFB2B0BEB4B3BEB5B3
C4BAB8C2B9B6BFB7B3C0B8B5C2BCB9C6C0BEC6C2C0C5C4C2BFBFBEC0BFC0BEBDBFC1C0C1
C1BFBEC2C0C0BEBFBFBCBFBEC2C5C4C1C4C4BCBEC1BFC1C4BFC2C3C0C3C4BBBEC1BBBEC0
B7BABDB5B9BCB7BCBFB7BBBCB2B9C092A8C1133B77737CAF984461B21126C00716C00612
C00712BF0511BF0713BA020EB50510A6181BC47070A87E857963706A596B68506881556E
893D54851C308F0F219C0917A0020FA5020DA504109E010DA0020D990612811B2AD9B6C2
CDCEDAC5D3E0C4D2DFC6D4E392A5B6A4BBC9ACC1CF7B8F9C8597A283939C85959D87949B
7E8B917681866D7C7E6779796C7D7E6C7C7D6A797C6675786270783A4A62010A3B010941
000942010D4103143F192E463F55604C62644F636353676831424451554E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC22E886F6A
3A384F0F122B534958574B5B0C1032020B400209451B1E4B62597066566D25214C020944
0009471012456B5D7E776074624C5E7059686E57635F4E5A4A3C486850578A6164925E63
9D686CA26F70A17071A37676A37A77AB847EAA847DAF8D84AF9185B19788B29787B69A89
B49A87B6A08EB49F90B6A294B6A297B6A59ABAABA0B9A9A0BFAFA9C1B3B0BAB0AFBDB5B3
BCB5B3BDB8B5BEBAB6C1B9B7C4BDBBC3BDBCC7C2C1C5C1BFBEBDBCC0BFBEBFBFBEBEBFBE
BEBFBEC0C0C1BCBEBFBCC0C0BEC4C2BFC3C4BCC0C3BFC3C7BEC3C3BBC1C0BFC4C6B7BEC0
B2B9BCB4BCBFB8BDC0B8BCBFAFB6BD98ACC4163E7A616FA5954968B11327C10918BF0512
BD040FBC040DB9010CBB030FB20812AA3336C39594A59DA299A0A696A0AA7E879B515873
4B4665735572813C54831525970A169B030E9600099501099C010C9A020D880A1CB37685
D8CFDBC7D3DFC5D3E0BAC9DD647D97738FA3657F8D6D8592879AA493A3AA829097A7B2B8
808D93798589707E7F6372736B777B6B7A7D6575766574766573794B5B6F010C3C000B41
020E3E0C1D41394D64566B725163655165645267644E6563364C4D47504C1E981200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE115B09284
3F3B4F1B192F5C4E5D473C5103062D020942020947101343665D77675B731B1A48030A47
030D47312F5977637C7E66765848585B505E5A4F5A50475346374473535C8C5E64915D62
996568A06E6EA27372A57778A67B7AA7807CAC867FAF8D83B19387B19488B29688B39887
B49A88B69F8EB39F90B39F91B29F92B4A398B8A99DC0B1A7C0B1A9BBAEA9BCB1B0C1B6B5
BDB5B2BEB8B5BCB8B4BFBAB6C3BCBABFBABAC6C1C0C5C1C0C1BFBDBFBDBBC1C1BEC0C2BF
BCBFC0BEC1C4BEC0C4BABEC1B7BDBCBBC0C1BCBFC4BCC0C4BCC1C1BDC1C1BFC2C3B9BCBE
B9BFC1B3B8BCB4B8BCB6BBBFB1B8C0A4B7CB214880415A969D6588A7162BBD0816C10513
BF040FBE050DBB020DB9020DB20713A73338C3999AA6A1A19BA2A3BAC4C5AEB6BD959EAD
75859C3C4B694542637B547281273E8C091895020E98020B9C020B99010B930617822939
DEC4D0CED4DDC6D5E29DAFC918375B58799297B2BFA3BBC5899CA5B8C8D08F9BA5838D95
7B868C728083758183717E7F6C797A6877786778776678756776795A697905143904153B
2638514C616D5A6F725F7373596B69546765516868425C6038505835434525A21E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B89683
352E402C273C5E505F342C44010630020A43030A470B0F3D655E794D45630A0C3C020B45
0B11445E55767F65797E6473554B594B4857484453433B49543E4A774E578B565E965F65
9B656AA16E70A47274A57778A77A7CAA8080AA837FAE8B82B19085B19286B29686B19685
B49A8AB39B8CB49E8EB19D8EB7A397B4A398BEAFA4C2B4ABC1B3ABB9ADA8BBB0AEC1B6B4
C2B8B4BEB6B1BFB8B4BDB6B4BCB8B6C1BFBEC3C0BFC3C2C0C0BEBCC3C1BFBCBCBBBEBFBF
BABCBCB8B9BDBBBDC1B9BEC0BBC1C1BCC1C3BDC1C5BCC0C3BEC3C3BDC0C2BFC1C2BABBBE
BDBFC2B9BDC0B2B4B8B4B8BCB2BABFAEBCCC4669971C41829A82AD941D35B60A19C10614
C20410C0050EBF0510B9030FB50815A3272EC69495A7A09DA0A5A4A9B3B2A3ACAE939BA1
8D9AA596A7B9798BAB25315C785C827B1D34980818A004109E030D9C010A990312800C1C
C28F9ED3CFD8CCD5E49CACC17B95AF95AFC38EA2AEAEBFC983919C7D8893838C977C858C
7B868B737E82747F816F7E7E6C7B7B697979677A78677876677777617277273B4A3E5261
566972586C6D5C6F6E6174725C6E6E52686C425B69152C4223394E27394244413800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C49F84
382F3D3D374A5D515F231E38030732020A400109420D123D63607E282547010639020A41
25254E76647D816172826170634F5C4A3D4E4F42515A455276515C8350598F565E996167
9F696FA16E72A27074A5787AA4797AA87F80A98380AE8A80B49486AF9182B09583AE9585
B3998AB4998AB49C8DB39E90B8A59AC2B0A7C5B5ADBEAFA7C2B4ADBAAEA9BDB2AFC1B7B5
BFB5B3BEB6B0BEB5B0BFB8B6BCB8B7C1BFBEC4C1C0BFBFBDBEBEBCC0BFBDBCBBBABAB9B9
BDBEBEBABBBDB7BBBCB9BEBDB8BDBDBCC1C3BEC2C6BABEC2B9BEBFBBBFC0BDC1C3B5B8BB
B8BABFB9BBBFB6B6BAB5B9BCB3BABDAFBAC2809ABC16407F7078AC93425CAE1121BF0815
C20612BF040DBD030FB90311B204119D121CC27E82AB9F9D9DA3A2939D9E9DA8AAA3AAB1
8D97A0B8C6D1C8D8EE415985283064804D6D880B219703119601099D030C9E0211900819
914152DFCAD6CDD1DF8C9AAB97A9B98B9EAD788A99808C9787919C7A848E9FA8B2838D93
7782877983876F7B7C717F7F7281826A7A7B6679776879786978776175715C716E546768
596B6E5C6F705D70705C7174586F7A364E63091D40000F38192C492037424D4E4800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BF9570
3F31374840515B4F5E15122C020831010A3E010941151B4955577A0C0D3802073C060B3D
574F6F7D6274845F6E8C64728862716B49596B4957774F5B875661864E5890575F996167
9C666CA06C72A37175A27576A57C7DA67E7EAA8480B08C80B08F7FB19381AF9282B19688
B19789B3988AB49B8DB9A499BCA9A1C2B0A9B9AAA1C0B1AAC1B3ADBBB0ACBDB5B0BDB4B0
B8AFABBEB5B0C1B9B3BEBAB5BBB9B6C0BFBCBAB8B5BFBEBDBDBCBCBCBCBDBABAB9BBBABA
BCBCBDB3B6B7B5B9B9BABDBDB8BCBEBBC1C3B9BDC0BABDC1BABFC0BBC0C0B7BBBEB1B6BA
B4B7BCB6B9BBBABABDB4B8BAB5B9BBB3B9BEA7B8CC32558A2E4B86A57E9E99182BB90A17
C10610BD030CBC010DB6010DB3020DA70A16B05057B49999A2A5A48F989AB7C0C6D3DAE2
A3A9B4A6B1C0B8CADD6A81A611255B715E877818318D05148D000696020A9F0211980516
7D1223D4AAB7C6C9D9687C947B90A3677B8B7B8D9C8C99A3B9C3CD84909A919DA588969B
758085768183707D7D7684846E7D7F6A7C7E6779796679776878775F736C60746F5C6F6C
5B6C6C5E7274576F764C647721385A041644000C3F010C3C0C193C2035444E504E10CA08
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0069D547
5B48484F4354594D5E0C0A2702083005103D010A3B202855383F6901063A02073E1A1B45
6D5E767E5F6E8059678B5E6E885A6B8554667543537C4655844D5A8A525C9159609A6368
9D676D9F6B6F9F6C6EA27372A57979A67E7CA8847DAD8A7FAF8D80AF8E80B29387B3968B
B09589B0968AB29A8EB7A298B9A69DBFADA5C0B0A8C0B1ABBEB2ADBAB1ACBBB3ADBDB4B0
BFB4B1BDB4B0BBB5B2BAB6B4B9B9B5BABAB5BBB9B6BAB8B8BBBABCB8B8BBB5B5B9B5B5B7
BBBBBDBABBBCB4B7B7B9BABCB5BABBB9BEC1BABCC0BBBEC2BCC0C4BBBEC2B7BCBEB1B8B9
B5BABBB6BBBCB3B6B8B2B6B8B2B6B7B0B5B8AFBAC57791B51136727F7EAE913750B2131F
BD0811BD040BBD030FBA030FB6010EB107129D2029C28E90D2CCCC9EA5A9A1A9B1B3BBC3
9CA2AE8592A4617A92ADC7E0324A783C41727C3E5E870B1C92020C94010A99020C96010D
890A19A7616FB9B0C23F58757D98B0A6BBCBB3C3CF7F8D9597A4AD808F977482897A898C
778488707E7F6E7D7D6C7C7C7382846C7A7C6A797A6576756977766374726274715E7070
586D70576D7A354C68091D4900124A010C4A010B46000A3C04103622364C424A4E209914
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064CC3A
735A5557495850465906042204082D3137591A234825325D161F5002084002073B322E52
74607280606E845E6C845A69875A6B8351617843537D4654824B588A535E935B63996268
9A65699C6869A47171A57574A47676A47C7AA6827CA9887EAE8D81AD8D80B09285AE9185
AD9185AE9589B19A8CB39E92B8A69BBCA9A1C1AFA8C2B2ADBEB0AEB7ADAAB8AEABBCB1AF
BDB1B0BAB1AFBAB4B2B9B4B5B7B4B4B9B5B3BDB8B7BCBABABAB9BCB8B8BAB8B8BAB8B7B8
B9B8B9B8B8B8B8B9BABBBFC0B8BDBEB8BDBFB8BBBFB9BCC1BABCC2BCBDC2B8BCBFB2B7B9
B6BBBBB6BBBBB1B4B8AFB4B7B6BCBFB2B9BBAFB8BBA1B4C72A4D83324B88A475989C1829
B70A13BD060CBE0510BB020FB7010EB40310A10D15B46568B4A2A1A1A6A996A1A88D99A1
BBC5CC96A4B25C758BBDD7EA7B95B911265A745B8376112695061594000A97020C97030D
950713831A28AA8191929EB199AFC180939F8B99A17F8D927E8B937B8990758389718082
7A86896F7E7E7181816C7B7D727D7F737F7F6C78786975736C78786676766073745D7379
465D721C3156021144000C48010B4B00094D010A49010A3F010C37263C56313E4625A21F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064C933
8264575C4C5742394C02021F0C0D2C58566D262948222E5B020B40020741010336373152
725D6D7A5A6884606F835D6B815865875A677A4955804C58834F5B8E5965915A64925C61
9965689B6968A1706FA67575A57577A67A7AA47E78A7857CAD8C81AF8F81AF9082AC9081
AF9486B19A8BB39D8EB8A596B9A89ABDACA3BCABA4BBAAA5B9ACAAB7ACA9B8ADABBEB3B1
BAB0ADBCB3AFBBB5B1BCB6B5B6B1B0B9B2B1BAB4B3BBB8B8B7B6B7BCBCBDB8B9B9B9B9B9
B5B6B6B3B6B5B8BBBBB7BBBBB7BBBCB8BCBEB9BDBFBDC0C2BFC1C4BBBCC1BCBEC3B7BABE
B9BBBEBBBDBFB4B7BCB4B9BDB1B8BBB0B9BAB3BABCAEBAC36681A7133677837DAE8A2D45
AE0E1BB9050DBA020EB9010CB9020EB7020EAD0810A13136BE9698AEACAFA2ACB18E9BA3
D1DDE4C9D7E08DA1B1A0BCD287A7C91B396D454678752F4C8C071B93010D95000A97010B
98030E8706108D434D9388927F8F9D7E929E8B9CA59FAFB67D8A93A2B0B788969D738284
7A8788718080717F806E7B7C6E7B7B74827F6976756A777766777763797D5A6F7D344B67
0A1D4C000E49000A4B00084A01094A020B4E020D4C010D4107183C374D61233139453E34
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0065CA30
9B786562505637304103041D242036625769252441111B4B010A43010842010638393454
745E707C5C6C805E6D886170845B698256617F505A7E4B55824C588A535F8C575F905D61
9664679B696C9F6D6FA47173A57376A47777A67E79A7837AAC8A7FAF8F81AF8F82AF9184
B29888B09988B29C8DB4A192BDAC9DB8A69BBEADA5BDAFA9B7ADA8B7AFABB5ADA9B7AFAC
B3ABA7BBB2AEBBB2AFB8B2AFB7B3B1B8B4B2BAB5B4BAB7B7B7B6B7BAB9B9B9BABABCBDBD
B3B5B6B7BBBAB6BABAB6B8B9BDBFC1B8BBBCBFC2C1BCBEBEC4C5C9BEBFC4BBBFC3B9BBBF
B7B8BDB6B8BCB6B9BEB5BABDB3B8BAB4BBBBB1B6B8AEB6BB9BACC521447C3D528D9A6786
9C1426B60815B9040FBB0410B9020DB7020CB406109D121BB87479D5C8CCCED3D997A0A9
A8B6C0A6B5C08496A927486D5882AD5C7FAD12245C78567B790C249505139B030D970109
97000A92030C8018209B777F5E6C7996B0BC899EA8BACBD386959D7A888F7C8A92738185
717F807382826F7C7D6C79796B7A7B6778776B7C7D64797B59727A4C677C1F345B021247
010C4C010B4E01094E010A4D010C4D000D4C0110490D1F473C51645367701C29304A443D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B28C706856592B26350505193933446053621B1836040C3F010A420D184B1018442F2B4D
715F737B5E6D7E5C6B865C6C8759698657647F4E587F4C5587535D8C55618F5B63966467
96656899686B9D6B6FA26F72A47275A37677A77F7AA58077AC897FAF8D81AF8E83B09185
B29889AF9789B29B8EB6A092C1AD9FB9A69DB9A9A2B5A9A2B4ABA6B6ADAAB6ACAAB8AEAC
B6ADAABBB2AEBBB3AFB8B2AFB6B2B0B8B4B4B8B4B5B6B4B6B9B9BAB5B5B6B9B9BAB6B6B9
B6B6B8B7BABABBBDBFBABCBEB8B9BCB6B8BABDBFBFBDC0C1C1C2C6BABCBFBABEC1BABCC0
B7B9BCB8BABDBABCC1B4B9BCB3B8BAB3BABAB5BBBDB1B9BCAEBBC85C7BA21335738C80AB
8C263DAE0C1CB60410B6030EB7020DB7030CB4030CA709129F3C42BF9FA4A9A7AE9AA0AC
7585989AAFC1BACCDF3F5C7E557CA1A2C1E3173063524B7B71233E90081A9D02109C020B
99010B97030D870711925059A3A0AAB1C4CD8091998393997D8B917E8A907D898F7A888B
707F81738382707E7E6B79796C7C7C67797A6B7E845B74813954710D235400104E010B4E
020B5000094C01094D000C4E01104E03184A21375C50657658687056686C222F35474543
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B18565735D602A223308051B4E45535C505D13113202093D020A412C325F1E2048211F40
7164777F6372825F6E83596886596785586283555D804F578957618C58638C5860946266
96656599696B9C6A709D696FA37174A47777A87D7BA9837CAD8A81AC8B81AC8C81B19485
B29788B0988BB1998DB39C8FBBA498B8A59BBEAFA5B3A9A2BAB2AEB7AEACB3A9A7B5A9A8
B8AEACB8AFACB7B1AEBAB5B2B3AFADB8B4B4BAB6B8B8B6B8B7B7B9B7B7B9B9B9BBB8B8BB
BABABDBABBBDB9BABDB9BBBEBBBDC1B8BBBDBCBDBFBCBEC0BDBFC1C0C0C4BFC1C4BFC1C5
BCBEC0BEC1C2BCBFC2B2B9BBAFB5B8B5BCBDB2B6B9B0B8BAAEB9C095ABC5173B774B5A94
9C5E7C9D1122B30512B7040FB8030DB7030DB3020BAF051097131DBA7E85B7ADB4C9CED6
7F8EA1849BB0CDE0EE97AFC188A5BBC1DAF15268931F2A6274486E7D0A209803129E020E
9A000D97010D92051282242F9B7E868E969C909EA67D8C92A9B6B9838E938793988E9DA1
7181846F8080728283697A7B697B7D63777E566E81263E6303164F011054010C54000A50
00094D010A49020B4A000F49091E4C3B536F5D73815F7277617274596C6F2D3E453E4042
1D961000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D6B436F555422192B120E22594E5A564A5909072B02093C070E3F55547B2B284D151739
6E647979606E7D5C6B855E6C8A606D855A658557607C4B538351598C5861905C62956166
9765679D6C6F9E6C729D6970A06E72A57778A37A77A57F7BAA8781AA897FAB8D7EAD9282
AF9585B19889B29A8BB59E90BAA59AB4A398C0B0A6B1A49DB9ADABB3A8A6AFA5A4B6ADAB
B2ACA8B7B2AEB5AEADB7B3B1B6B4B1BAB7B4B6B2B2B6B4B4B8B7B9B9B9BAB9BABBB8B9BA
B8B8B9BDBDC0B8B9BDBCBEC1BBBFC1B8BCBDB9BBBDBDC0C2C0C1C4C0C0C4BEC0C4BEC1C5
BBBFC2B9BDBFB9BEC1ADB6B8B0B7BAB6BBBFB3B7BBAEB4B7ADB7BDABB9C84C69991A3879
9983AC8A1E33B10B1AB6030FB7020AB6020CB4020DB10410A10914A0464EC3AAB3D8D8E0
B3BCC98EA2B591ACC087A4B64B687CB8D0E39CAFCF1529605143746916308F06179A0212
99020F96010D970410800D19956168A3A2A7B0BEC585969DA2AFB48994977B878C768387
7281846D7F826E81846C7F84647A8548617A122957021454000C55010953020B53010A50
01094D020C4A020F470A2049476177677D86657A7C5F73755C7171566B6D3C4F562F3639
229D1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB21F7E625A2119261F192A60525E4A3F5006062A0107371F224B6A6582312E510E1135
6C647C78606F7A5B69835E6C885F6E85596785546085525C88555C8D59618F5A62925D65
98646A9A686C9D696F9E696FA37074A57579A57B7AA47D7AAC8680AE8B80AC8E7FAB9181
AC9385B19787B09786B49D8FB6A097B6A29AB9A89FB8A9A3BBACAAB3A6A4B3A9A7B4ADAA
B0ACA7B3AFADB1AEADB3B4B2B0B1AEB6B7B3B6B6B3BEBEBDC7C8C9C4C6C8BDBFC2BABCBE
B5B6B7B7B8BBB6B8BCB7BBBEBABFC1BBC1C2BCC3C4BCC2C4BDC2C5BFC1C5BFC1C5B8BCC0
BBBFC1BABFC1B7BCBFB6BABEB4B8BDB2B6BAB7BABFB1B5B8AFB5BAB0BAC389A0C0143978
5B669D8C48669F0C1FB20210B7020DB7030DB4020EB1020FAA0612941B25B7848CAAA4AE
9DA7B3687F982A51778BB3D08EABBEC5D8E6C8D7EC3F537F262E63744262800A20910213
93000C94010C96010C8A071286353D9F8F91ADB6BC8593997E8B907E898B7C8688758083
7281846D7D806A7D846379883C5675081F53001258010C5701095401095000094F01094C
01094C010B48031242415B72647C846B8081687C7B6076755E7374596D6F4E60651F292C
27A32000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB61D7458471E17202E283363555F39304604072D040A34413F5F6E647B3A355506072F
665E7A7760717C5D6B815C6A88606E8559668451608856628857618C5863915C66945F69
925E669561669A646AA16D72A16F73A57578A67A7CA57D7CAE8680AF8A80AE8E80AE9282
AC9282AF9584B19988B39B8EB59E96B6A29AB6A59CB9ABA7B1A4A3B7AAA8B2A6A3AEA5A2
AEA9A5ADA9A7A8A7A7979998939695ADB0AED1D4D4DBDEE0DBDFE3DBE0E3D6DBDFC0C4C9
B7BABDB3B7B9B2B7B9B7BDBEBABEC0B7BBBEB7BEBFBBC2C2BABFC1B8BDC0BCBFC3BDC1C3
C1C5C6BBBFC0BBBCC0B8B9BDB2B5BAB5B8BDB6B9BDB2B6B9AEB2B6B2B8BEA5B4C936558B
203D7F957AA28B172CAD0716B7020EB6020DB2000CB3020EB1030F9D0A18A553628D808E
CDD9E593A9BF1D446B6E99B6C6DEEDCBDBE4CAD9E7889BBB0F215667567F6E142D8B0517
92010D95020A96010B9304107D121CA1777986878A8793967A888A8D9B9B8A97996B797B
7182826A8081607A87355173061D5700135A010F5C010C57000C51020E4D010E4903124C
010B48000D431F335559727D657A7D6A7E7E677B7B5F74775D73775B6F73596C70152227
463E3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
58BD217C5D4620151C3A2F3A675763261F3904082E0A0E325B556F726478433D5D060834
50496B755F727B5C6A7C5B66825C698257648758658656628C5B668C58638F5B64905C65
9563699766699662679F6B70A06E72A47578A57A7DA88081AA8280B18B84B29085AF9181
AF9381AE9381B09886B0998BB5A197B6A49BB6A69FB6AAA5AA9E9BB0A5A1B0A5A1B0A5A2
ACA5A2A29D9B949392A7A7A6AAABA9C6CACACFD3D7BEC0C7BEC2C8CFD4DADAE0E7D2D6DD
B6BAC0B7BBBEB6BBBCBABEC0B8BBBDBBBEC0B5B8BABEC3C4BEC4C4BABFC1BDC1C5BEC2C6
BCC2C4BABEC0C0C0C5BCBDC2B9BCC2B7BBBFB6BABDB1B6B9AEB3B7AEB3B8AAB4C1788EB4
103373696FA18A3C56A50D1EB70612B6020EB4010DB5020EB5030FA90613922234876473
C4CCD8C8DBE97D9AB4769CB4C0DAE7C9DBE3CAD7E5BFD0E72C417033396C70355782091F
8F010E94010A94000894030C860813934951908184BEC6C98F9DA08796968A989D607376
6A7F81637F89304D70041D5900125C01115E010F5D010E5601124C061B492E456A1F3563
020E47010F40425D725D767A65797B6A7E7F657A7E59727C4B6777445E6C5069721F3138
3C3C3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0087604425141941333F66596717143203072F1E1F406C62767464774D4467070B3C
3C39607461767D5F6D825F6C8057668358668A5D69895A648C5A64905E688D5B65905D65
93616797676B97666A9C696E9F6D72A27377A6787EA67D7FAB8482B18C85B29185AF9183
AE9081B09281B29888B39F90B5A296B6A59CB1A29AB3A69FB3A6A2BAB0ADACA39EADA5A1
ABA6A2908C8AADABA8B0B0ABAFB2AED3D7D89FA2A8B3B4BCB7B9BFB6BEC2D8DFE3DADEE4
B9BDC4B9BDC1BCC1C4BABEC2B6BABEB5B8BCBABDC1C3C7CABDC1C4C0C5C8BEC4C7B9C0C4
B9BFC3BCC1C5BDBFC3BCBDC1BABDC1B4B8BCB7BBBFB3B8BBAEB3B7ADB1B6ADB3BDA2B2C8
2D4E822A447E997394931528B10616B5020EB6020DB6030EB6010DAF0310960B1AA86472
9C96A89BB0C37E9AB130566FB9D5E4C9DAE3CBD7E3C9D7E96F82A90F1E576D517C6F0E27
8B031393010D94000993000A900411841C279F777E98989C8993997B898C7482865B6D72
657C8938547403195702156200105F01135F02145B021651172E5746607A506983081D49
02134A051743526D7E60787B6A7E7F677C7F627886334B6A08204B041D4338546B2C4550
2D31330EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AA7F5E2C171A4D404A5850600A0B2B04082E3D3953695B6C6E5E7253496F06093E
2726536E5D757C5E6D805C6C8159668458658759648957628B58628E59658A5562915D65
9462699A676E9B676D9E696E9C666BA47275A97A7EA3797AA9847EAD8C83B19085AE8E81
B19285B19286B2978BB49F91B6A497B5A29AB5A59DB4A79EB4A9A4AFA6A2AAA29EABA4A0
AEA7A58D8987B0AFACADAEABB5B8B6CED2D39B9DA3B2B3B8B2B6BAB3BCBED5DFE1D6DBE0
B0B3BAB8BCC2B5BABEB7BBC0B8BBC0B9BEC1B9BEC1B9BFC2BAC0C3BAC0C3B8BEC1BABFC3
BEC3C6BCC1C4BEC1C5B9BBBFB7BBBEB2B6BAB6BABEB4B9BCB3B7BCB0B4B9AEB3B9A4B1BD
6882A710346F77749F872D44A80B1DB60411B8040EB6040CB4010CB1020DA50715932D3E
745E7A647E9DA3C2DB638398C8DEEBC9D9E1CBD8E2C9D7E3B4C5E01D3162413E70682341
85061994020E96000C94010C9402108408169B58628F8387838B8E808B8F76858A62767F
475F7D061D5801136001136400115E011559061E53314C6D556F82577182294061001344
1A35660A1D46557081627A7D667D82617A8833496D05174F01115001124A13294F3B5467
1C262A1E981300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE815A2C18154E424A453F5106092A0C0D2F584D62695B694D43595B5779080C3E
101344695D7A7D61727F5C697D5964875E6A895A678956628B57628C58628D58638E5960
9461679A676D9C686F9B686C9E6B6EA57476A6787BA97F7EA9857EAD8C82B19084B08E81
B19184B09388B1988CB39E90B39F93B09D95B1A299B0A49BB0A7A0ACA3A0ACA4A0B1AAA5
B2AAA78A86859A999BB1B1B3ACADB0C2C6C9B9BCC0ACAEB3ACB2B6C6D0D3D9E1E5C7CCD2
B8BAC1BABBC2B8BBC1B9BBC0BCBDC1BABEC2B5B9BCB7BEC1B7BFC1BEC5C8BBBFC2BEC1C6
BEC2C6BDC1C5BABDC1BEC0C4B8BBBFB2B7BAB3B9BCB2B9BBB4B8BDAFB3B7B0B4B9A7B1B6
9AABC2224479334780956384961126B00413B6030FB6030EB4020CB1020BA903118F0C1F
8C56713F4C6BAFCBE1C3D9E4C9DCE6CAD8E2C9D7E2C6D7E3C6D6E85C7095152255704A6E
760A1E90021193000C93000B93010E8B04128329349B8082999D9F939FA26D7D875D748B
0E285B03176302136603166401145719305F4C67805F788361778149637A061D490C2251
3A55800316404B66805D7786557085254169021753010F54000C50000F4A0214423A536C
121E272A631D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00BA8E5C311C11574B51352F430407281C1A356456655C526222223B5D61810A0F3C
050A3C544D6F7A61737C5966825D68855A698A5A6A8756638C5B6585555E8C59618D585E
9360659B68709D6A719F6C71A06F729F6E72A5777AA87D7FA88380AC8B83AF8F84B19084
B19186B3968BB0968AB29B8EB39E93AE9B93AB9C93ADA199ACA39DA9A19DA9A09DB6AFAB
ACA4A2A49E9E8A878A8E8D918D8E91B1B4B6D4D7DBD1D4D9D2D7DCD3DAE1BFC6CDB4B7BF
B7B6BDBBBBC1B9BAC1BCBDC3BCBDC1B9BBC0BBBEC3BFC4C8BCC2C5BEC2C6BCBFC3BABDC2
BBBFC4BCC0C5BFC1C6BCBDC2B7B9BDB4BCBEB2BBBCAFB7B8B1B8BBADB4B7AFB3B8A9AFB3
A8B5C05B769B12316F8376A386233CA90A1AB20211B5030FB4020DB0010CAC0210A00919
98394C99879D92A6BBC9DFE9C9DBE4CCDAE4C7D7E3C4D6E1C6D5E3A4B5D1132656534973
6D1D3685041390010C91000A93000C91020F7C0C17A06E72898484818E916D7F90263F69
021A60011466021463041B5B29416A587085657A8164797D5C74831C33590116482F476C
455D7F001244183061374F7C162D6201175A02155F010F58000C51020D49001042283E5E
192735312B2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0058C22C402615564A5028223B0408282F2C426356624841560A0F2F5A6084161A4A
01073D3A385E725D727958667E59667F56658557668B5A698856638857618B5A618D5B60
9360669663699C696E9C686DA06E72A16F73A77579A77B7DA98381AB8983AD8D83B09084
AF9285B09488B59A8EB59C90B5A096AA978EA3948AA99D95A99F9AA19796AEA4A3ABA2A0
B1A9A7B1ABA8ABA7A5ABA8A7B2B1B0ABABADABABB0B0B3B7B3B7BDACB0B8A6ABB2A6AAB0
B2B3B8B8B9BEBCBEC3BCBEC4BDBFC3BDBEC2BBBDC2B7BBBFBCC2C3B8BCBFBABDC2BABEC3
BCC2C6BAC0C4BCC1C6BDC0C4B9BCBFB2B9BBB6BDBFB1BABAAEB7B8ACB5B7AEB6B9AAB1B4
A8B1B993A7C018377145548D9055749B1125B00314B50210B3020DB0010EAD0110A70411
92142595687C5F6E83C7DDE9CADAE4CBDAE3C9D9E2C7D7E0C8D6E1C4D5E742587E2A3262
6F3E607A0B1E8F021093010C95010B94010B8706108B3F439581817D868D576D89051C5A
011767001563051C5A365073627989697C81687B7C627880324B69021949112853576D83
52677F03154800135600115A00115D00106101105F021059010D52000E49000F4217294C
2736482F2D2E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF005EC42B5433205547511C1834070A2C4A43596557672D28450409324E537A212452
030940161845685A737B5D6C7E5D69805966825663875564824D5D8854628B5A658B5A62
91606596666A98696D99696E9E6C719D6C70A67778A67B7CA67F7DA9857EB08F85AF9184
AE9284AF9488B1978CB49C93B39E96AB978FA6958CAB9E96ACA29DA09795ABA1A0A69C9A
ACA3A1B5AEABB4B0ADB6B3AFB5B2B0A8A6A5A6A5A7A0A0A1A3A2A6AEADB2A5A6ABA5A9AD
AAADB1ADAFB3B1B4B9B7B9BEBDC0C4BDBFC4B6BABEB9BEC1B9C0C1BAC0C3BBC0C6B7BDC3
BDC5C9BBC2C7B9C0C4BCC1C4B8BCC0B3B9BCB2BABCADB4B7AFB5B8AFB7B8ACB5B8A7B0B2
A6AFB5A2B1C244608F1735748D79A1891D35AB0718B60412B50210B1010EB0000DAB020F
980818944B5CB1ADBDCEDDE7CDDBE4CBDAE4CAD7E2C9D7E0CBD7E0C8D6E296A7C2142451
634B7370142E8A041593020E95010B9200098D030D7A151D9E767C7F8595223A68021A65
02196905215E3D597B637A876A7E816C807F6B7D85496078081F4C051D4B455D786B7D86
657685132750021358010D5D020D61000C5F011060011058000F4C071A4B0719410E1D3C
3748572C2F310EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0067CA306D48354F414D13102E0F0F305B516660546915123903093840446B32355E
040A3E05093B4E48677661727A5A697C56647F53618553618A55658C5767905F6A8A5B64
8F606794656C996A719D6D759F6F749F6F72A37676A67E7CA98481A9847EB18E85B09085
B09489AF958BAF968DB39E93B09D93AD9992A8958EAB9C97A89E9BA79E9CA89F9CB0A6A3
B1A9A5B4ACABB9B5B4B6B5B3B4B3B1B4B2B0B0AFAEA9A6A7A09EA1B4B3B7A7A7AB9DA0A3
A3A6A9A5A7ABABAEB2B2B6BAB7BBBFB2B9BCB7BDC0B8BFC2B6BEC0BDC4C7B8BEC3B9C1C5
BCC3C8BAC1C7B7BEC1BCC2C4B9BEC1B4B9BDB4BABDB1B6BAB4B8BCB0B6B9AFB7BBA9B3B5
A6B1B4A7B4BE8298B9133573525C918E49679E0E20B30513B60210B4020EB1010EAF0210
A40516922A3AEEC6D5DCD3E1D8D1E2D7D2E4D5CFE1D2CCDED4CCDFD3CADFCDC5E0494168
583A5D84334A8404168E010E93000C92010B8F020C7D06108E505D77758E0A1F5B011867
0721643D5C80627B88667A7D6C81826D8389596D8510265200154826405F657B876E8183
6D7E883F5471031551011059010D5B010E5C01115B0217530F2651445A7534475E07172D
42555E2A31321C941100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007F593E5448530B0A281C1A3665596B50465E070833030A3936395C474668
02053401063B262850695F75765C6B7A55627F546181505D8854638A55648C58658E5D66
93626B9A6871A06E779E6C75A07074A47478A5787AA57C7BA98380A98580AF8E85B09188
B0938BAF958CB0998FB29D92B09C93A9968EA99791AC9B96AC9E9BB1A6A4ACA39FAFA7A2
B5ACA8B3AFABB4B3B2B5B7B6ACADACB4B3B2B0ADAEACA7AAACABAFAEB2B4ABAEB0A3A6A8
A9AAADACAEB1A6ABADB3B9BCB3BABDAEB6B9B5BBBFB3B9BCB7BFC1BCC2C6BBC1C5B3BBBE
B6BEC1B3BBBEBABFC3BEC3C6B9BDC0BABFC1B4B9BBB2BABCB0B8BBAFB7BBADB5B9A8B1B4
ACB3B7A8B3B89FADC23453861935739578A089162CAE0A18B90613B3020FB1000EB20211
AF04179C0C21B44C66AA57749E5170974C6A9548679145669043668E41648D3F637C2C4F
862E4A8B1E328903138F010D92010D91010B8F010D8806147A2435624E7008195C031E64
37537F678091697E83677C7E678188567289142D5800164B142D535871816B7E836D8080
6D7D82697C8B21365C01144E0012550112560218511C395E4E687C5369714D5F6B041626
485C632B3536219C1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00946D4B4539430607242F2842695A6C332D48050C35050C374B4A68595370
05063102063C080D3E4F4B6B6F5C6C7A5A647C535D804F5C804B59854E5D8A55618F5C65
92616996656D9B6B739C6E759E72779F7578A6787CA97E80AA8281AA8682AE8D87AD8E88
AE928AAB9289B19A8FB39E94AD9991A7948EA8968FAE9F98ADA19CA79C9AB2A9A5AFA7A3
B1ABA7ACA9A79D9E9F9B9CA0AAABAEADADAEB7B5B6ABA7A9AAA9ACB1B4B6B1B4B4AEAFB0
B0B1B3A6ABAEA3A9ACACB2B5B2B9BCB3BABDB7BBC0BABDC1B8BCC0BBC1C5B9BFC3B8C0C3
B5BDBFB6BEC0B8BFC1BAC2C4B9BEC1BBC0C2B4B8BCB3BCBEAFB9BBB2BDBFADB6B9A9B1B4
AEB3B8AAB1B6A6B1BC798FB112326F6267998A415D9F1021B40715B2020FB2020FB0030F
B20212AD0417A70720A00B26990823980B249507229407229005229007238D04208D051C
8E05198F021390010D92010B92010B90000A8F000C8B0310780E20643F630B1758112D65
65809A6F848D6D8286677F88527089123160011D540C28534D677B667A806D7E7E70817E
6B7B7B6F7E83607382263E5B0C234D1029512E4A66607D895F787C536B6D495E67071B28
485F6533424126A31E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0072943B3A2D35070823423B51675A6E1A1936020B3414183C5F5771685D76
0B093101053B01073E191C485D536E795D6B7E556181505C84505C8954618C5865905F68
906268986A719A6E75956D758E6A71967378A47C81A47B7DA88080A78280AD8B87AC8D87
AF938CAB9489AC978AAD9A8EAB9A91A8978FAA9A92AC9F99A69C99ABA19EADA5A0B2ABA6
ADA8A68C8C8A92949695989C828489AEB0B3B2B2B4A1A0A2B2B4B5AAACAEBCBDBFAEAFAF
B5B6B7AEB2B4A2A7AAA9AEB1B6BABEB8BCC0B3B7BCBABEC3BBBFC3BABEC3BBBFC3B7BCC0
BAC0C3B9BFC2B6BEC1B8C2C3B6C0C2B6BEC1B3BABDB2BBBEAFB8BBAFBABCACB5B8B0B9BB
ACB5B8B2BBC09DA6AFBCCADD425F8F203B778C779F86273CA51020AE0714AF0410AC0410
B00511AE0511AC0512A60411A306119E07129B05119604109806139404129203108E020F
90021190031090020C90020B8F030D8D020C8F020E8B030E7A0A196F42600E17521B386B
67869E69828E667D903F597B0C285B001F5A0D2C5B4B687E60797E677A7B6D7E7C70827C
6C7D7B6F7F7F6A7B7D5F767B5B747F5D747D60767B6279795B7172536A6C425864071C2C
485F663C4B4B41393000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052BF2F281C200A0C24514C5F5C5468080C2C030B322D2D4C66596C6A596D
1C163A02053901064102073D27264F6C576E78536182566183535E83505B8A576190616A
93646B96696F996F7687636A896B747C616A95777D9F7C7EA47E7FA68281A98785A88984
AB9086A99185AD988BAB9A8EAA9A91A99C94A79B94A69C96A09693A59B97ACA5A0AAA5A0
9B99979A9E9DCDD3D2CACFD191959BA3A6ABABACB09397999EA2A4A6A9ABABADB1A3A6AB
AFB2B6A6A9ADA2A6AAA2A6ABB3B6BBB4B7BCB2B6BBB3BABDBBC0C4BBC0C4BEC3C7BCBFC4
BEC1C7BABEC4B8BDC2BAC2C6B9C1C4B7C0C2B5BDC0B4BCBEB0B9BBAFBABBB1BABEB0BABC
BBC6C9D1DDE2A3ADB7A9B5C08AA0BA2E4D7E32477C8A70968A374F921A2A98111F9C121C
9D12189C1618961618961B1C911A1D88161A8B191E86191D851A1F7F171D7B131879141B
79121C760F187B12197C10147D0F157C0C12810D157A0C126914198566761924550A2661
3B5C8C416088213D6D031D5A021C59163260536E85687F86687E7F667A796D807E6E807D
6A7D7C6D7E7F6D7D7D697A7A6B7C7B6978766977776678775A6E6E53696E2E45550E2337
4D626B49595C43413B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0058C3303321201310255D566747435902072B060C315049616F5B69715C6C
3126460304370105410105410708385343617452637C525F7F525C82525A8A5B6291636B
94656E966A7190676F936E7795767F755E677D686E9E7D81A78184A88284AB8787AA8A86
AC8F88AA9186A99489A9978CAF9E95A2948BA0968D9B948B9F9791A0969297908B9E9A94
A8A8A4AFB4B5D9DFE2D7DDE2A1A5ACA9AAAFAEAFB39DA2A5A3A6A896999BA4A6AA9FA2A8
A0A4AB9B9DA39DA1A79FA4AAB3B7BDB3B7BBB1B7BBBAC1C5B6BBBFBDC2C6BCC3C5BFC4C7
BDC1C6B9BDC2B9BCC2BDC2C7BBBFC4B9BFC2B4BBBEB4BBBDB2BBBEB6C1C2CED7D9B3BDC0
ABB5BBAEB9BFAAB3BBA7B5BCA9BAC5B9D0E8415F8D2E42726B658589677D87576D986373
A56E71A56E6DAB7774AB7A77AA7D7CA67A7BA67A7DA37A7DA57E809D7A7C97787E94747B
8364707B626D8C6A6E895F5E8B5F5E8D5B5B8E57598453538565638480844B5A760B2259
021F5E01205B021F58082357334C7260788B6E82887080836D7F816D7E7E6E7E7E728282
6E8081697B7D6D7C7E6D7C7C6C7A796C7A776674746373735D7072566A75152C421F384C
4F676E4E616040463F0FCB0700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF005BC32C52392F1B1223665D6D36324D050A331B1C3E615668715C67735C68
4D3C5A0602330307400206400A0A395E4D69775364794E5B7C4D5881535B8C5E679C6E78
9C6E78976B758E646E936C77896A7677616B7A64699D7C7EA78082A98285AA8687AA8987
AD8F8AA88E86AA968CAC9B92AB9A91A6998F9B92889E968C9A938AA19993968E8A9D9A95
BDBDBAB7BBBDB6BCC1B7BDC4B6B8C0ACAAB0AEAEAF9EA2A39A9C9F9192949C9B9F98999E
989AA094989F90969B989EA3B8BEC2B3B9BDB2B8BDBCC1C8B7BBC0BBBFC3BEC3C6B7BEC1
B5BDC0B5BCC1BBC1C6BAC1C4BEC5C8BCC2C5B9BEC2B7BEC1B5BCC0B2BBBFB7C0C3B3BABE
AEB5BBB3BCC2CED9DEA7B7BF9CACB7C9DBE6A9BED47F98B87D97B2A3B6CB617595425A79
C0CED8CDD2D4D1D3D4D2D4D6D3D3D6D2D4D7CFD2D8D0D3D9CFD3DAC7D0DE7389A1ADC0D6
5362754155658B959D7E8182868A88A0A19F8785878B8D8D9CA2A07985867A8892576A84
334A6F2C466B405A785D75896E838D6E82857081847181846F7F7F6E7E7E6F7D7E6E7F7E
6E80816D8082697A8064757A6576766273706476746274745C6F7745596E03163A27415E
48656F506665424B43209B1300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE01361412D271C246860701E1E3C040B3131314B6B5D68705B62755E69
5F4B620D063103063D01043A12103C6A567076506180536183545F885965936571986A76
996A779A6B77956B7687626D836570775E658B6D70A07A7BA67F7FA88282A78484A68785
A88C88A38B84A8938BAB99929E8E869D9187A2978EA1978E9F978D9D958C98908A93908B
ADAEADD6DADCD1D6DAD5D9DFBCBDC4A9A9AEACADAFA3A8A8A0A4A5A2A3A3ABABADA0A1A5
989B9F93979D888F93969D9FB2BABCB0B7BBBABFC7BBBDC6BCBFC5BEC1C7BCC0C5BEC4C7
BDC2C6B9BDC2BABFC6BBC2C7BCC4C7B6C0C1BBC0C4B5BCBFB5BDC0B2BABEB4BBBFC2C8CC
BDC2C8B0B8BFD2DCE2AFBCC798A6B3A0AEB9ADBFCB97B2CA5F84A7B7D9F46384A45B809F
C7E2EECEDFE5D0DDE4D1DCE3D3DBE3D0DAE2CCD8E1CAD7E2C9D6E2B4C5DC223E655F7D9A
74899A6B7E8BADBDC5A3B0B688959BC5D3D994A1A77B898C808F917787897B888D76848B
73838E6F828C7084897183867484877083837385867284856F7F7F6C7D7B6D7E7C6F8280
6E82816B8182566B76364F5B5B72775E72705E72715870754E657A12244A000D4001123E
233C554E686F4755522F6A1E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006F4929342225695F700F0F2F080C304D485C6F5C61715C5E755E65
6C586A1B133702043503063A19174169546D7753627F545F8355618659658E606C92636F
9969759A6B76986E78946D77906D759A787D9D787BA57D7FA67E7EA67F7DA4817FA48683
A18681A18A83A8948BA39189A6978EA4988EA1948CA2968E978D85958C839A918997918B
989594B5B5B7C0C2C6B1B3B7A0A1A4A0A0A4A6A8AAAAAFAFA6ABABACB0B0AEAFB3A5A6AA
9B9EA2999DA2888F929DA5A7B0B7B9B2B7BBBABFC4BEC2C7BDC0C5BBC0C6BAC0C5BBC1C4
BDC1C6BDBFC5BFC1C7BCC2C7B9C1C5B9C1C4B8BFC3B7BFC1B6BCC0B4BCBFB4BBC1D2DBDF
CAD0D6AFB6BDAEB7BDB1BBC4AEBBC995A9BCC8DDF0728FB50D39735982ADA3C2DAB2CDDF
CDE1EAD0DFE7CFDCE4D0DEE5CFDDE4D0DCE5CDD9E5CDDAE6C9D7E4B1C0D3596D8AA1BBD1
B8CBD9899AA8A8BBCABFD0DE7E8E9B83949D808F9678888A798A8D79888C7A878D768286
7785887585887284857385857386866F84836D81817688887282816F827E697B796F8281
6E81806A7E7F3F56650E273E57747D566E71556D763B546A11254E020F45000945000B41
03143C3B576848595B3C372B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00875A31422A2763576B09082B131435655969715C5E6F5A5A715C60
6F5C6934294703033103053A1B17416C566F7854638157638458648D626D91656F93646F
9969749B6D77996F789970789D747B9F777BA37B7FA67E80A67D7EA57E7DA3817EA58582
9D807CA3898299837BA6948BA3948B9E9389978C839A8E869A8E869D928A9F958E9C948D
948F8B9995939998989A9A999A9A97949493A3A6A7A4A9AAACB1B2A5A9ACAAADB1ABADB1
979A9F95989C8E92969BA3A5B3B9BBB3B8BBB6BEC1BAC2C5B5BDC0BDC5C8BCC4C8BCC4C7
BAC0C5BAC0C6BAC0C6B8C0C4B7BFC3B8BEC4B8BEC3B5BBBFD1D5DAC2C8CEB2BBC1B5BEC4
B2BAC0ACB7BBA6B2B6CBD7DEAABDD5415F81A6C0DB9CB5D343648E6489ABA5C1D2CCE2E9
D0DFE8D1DEE6D0DCE5CEDEE5CEDDE4CBDBE3CCD9E5CCD9E4C9D8E2C3D4E399ADC55D7D9B
98B7D19AAFC45B6E828393A47B889476848D88969A8191927B8A8D99A8AB768588798789
7583857382847584847383847283836F81826F82847283857181816D807F6C7D7E6E8182
6D7E81697E7E4F6573051B354E6C7E4D6A7B2B4262051643010B44010A45000944000B40
000D3C243C564B60633F3E3400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006986254D332954495A0606282626426B5E68725F60705D5F6D5B62
715C6A5647620604300104371C1A416C59707955647F54618459658C626C906670946973
956973986C769B717A9E757D9D747C9E747AA2787CA07678A47B7CA37B7DA47D7DA58181
9D7B799B7E799B857CA08E83A6968DA4978E988E85948A819C9389A39A90A0978F9D968E
95918A9B9891989691A09F9A93938E91928E989B98A3A9A8A9AEB0A7ABAFA5A8ACABAEB3
95999C8D8F938E9195959C9FB4BABDB8BEC1B0B9BBBAC3C5B6BFC1BCC4C8B9BFC3BCC2C6
BBC2C8B1B8BFADB5BD9FA9AFB4BCC2BDC3C7C2C8CCB7BDC1BEC5C8B8C0C4B8C1C5AFB9BC
BCC8CCCADAE0A4B7C1C1D3DDB8CCE2607A9A92A9C29FB4C4B6D0E56388A4A6C4D6CAE0E7
CEDFE7D2DFE7CFDBE4CEDDE5CDDDE5CADBE3CCDAE4CDDBE5C9D8E7B2C6DAA5BCD61F3E63
40617F8298A9798895909EA9B4C2CA808E969BA9AF9FACB17C898F78868B768589758384
7683857684867681837583847583846D7D7D6F80837080857281856F81836B7C7F6B7D7F
6A7C7E667A7B5E7280081D3C314B6F102851011145000945010846000842010B42000C41
010E3C10223E496062484B3F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0047AF195B3D2D453B4C070829403C536E5E676F5E63594F5A544B5D
6C5C6E64546C110E3604083919183F6E5B737C5967835B678C656E8B636C8C646C936A73
966C769D737B9B72799F767F9D737C9A6E779F757A986F71A0777AA57D81A47F829E7A7B
987876A38984A08D84A4948AA18F879C8C85988D849A91879F988DA1988EA39B93A29A96
95908B9E9B949D9B95A09F9A9B9B96999B96999C97A3A9A6AFB6B6AAB3B59EA5A7B4B6BA
A0A1A694959A8C8F938D9497B2B8BBB5BCBEAAB2B4B9C1C4B9C1C3BCC4C8B9C0C4BFC5C9
B1B6BDADB4BBB8C0C6B3BCC2BEC7CCBDC5C8BDC6C8B7BFC4B6BEC3B8C2C4BFC9CDADBBBF
BECDD3CBDDE6899DAAA5B7C2AEBEC9B6C8DB8EA9C793B3D0AACCE42A5474B3D1E7CDE0EA
D0DFE7D2DFE7D0DDE6CEDCE5CCDBE6CBDCE6CDDBE6CBD9E3CBD9EA677C948498AE768DA0
7E96A6BFD4DEA6B5BE909EA8BFCED98D9EA67B8A907D8A8F7A878D7A888C7A898D798889
7686867283827182817283837482837383826F81836E81847382866E7F816E7E816C7E7E
6A7E7F61767D556C830D204B011148000B48000846000846000845010943010D41010F3D
020F3C041533465E634C564A10CC0800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB41A6B4936372D3E080728524A606855605F5364171837101534
5A546A675A6D2E284904083614133E6D5B747D5C6C825D6A8E67728B646C936A73976D76
9970799C747C9B717A9C737C9D727C9E737C9F767BA0787B9D7579A0787DA17C7F9A797A
A08381A58F8A9F8F889D8D859C8A839C8C859A8E859A91879D968C9F989199928D9D9792
96908B99948EA2A099A09F9B9A9B979A9B99979997ACAEADA2A9AA9BA5A799A2A4B3B4B8
A7A5AB94959A8E95988D9699A7AFB1B4BBBDAEB6B9BCC4C7BDC4C8BDC3C8BCC3C7B9C1C5
BAC3C6A8B2B5B1B8BEB2BBC0B6C0C3B6C0C2B1BABEBDC5CAB5BDC2C6D0D5D2DEE6ABBAC2
AEBBC4B0BFC6B2C3CCAABDC9B0C5D2C1D8EE2C52831C4A808BB0D381A1BACBE0EFCFDDE6
CFDCE5D0DDE6CFDDE6CEDDE5CEDBE5CEDCE7CBD9E6CCDAE5C7D7E77A91AABCD4EABFD4E3
879CAFAAC2D3B3C5D27986957583917B8B947A898E86959794A1A77281859CAAAF8F9FA1
7486867286846F827F70817F7583847180826C7E8172868778878A7484866F7D826C7F82
687E87536C811B315B010F46000949010847010847010846000843010D4102153D142D4A
1025440113303D565F505D55219D1400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057BB1D7B563D2E202E0D0C275E54646A5B6639344E040B35030D36
464761675C6D4F455E0608320C0E396C5E7B7C5D6E86616F9269788D6571926872946A73
997078966D76966C75996E789B7079A4787FA3797F996F72A07779A2797BA27D7E987978
9F83819E88839D8D869D8F86A2948C9E8F889D8E889C90889A918CA9A29E9B979298958E
98948D9A968EA4A39AA4A39F9A9A99999998989898AAA9AA9A9B9D8E94968A9092ACAEAF
B1B0B49FA2A68B9396929B9FA6ADB0BCC2C5B6BCBFBAC0C3B6BDC1BABFC5BBC1C7B7BFC5
B5BFC4AAB5B9B0B7BDB9C1C6BEC7CAB6BEC2BCC5C9D5DDE1BDC5CDB6C1C9BECBD4ABB9C1
B1BDC3B2C1C6CCE0ED87A8C47598B7B2CEEA42648E2E588587A4C1CDE0EDD3E0E7D4E0E7
CFDCE5D0DEE6D0DEE7D1DFE6D2DCE5CFDDE7CBD9E8CBDBEBC6D7F15B749B5B729EA5B1D5
707696464B66969AAB9398A47D85917C8A9277858D8D9FA3BCCBD27E8C947B88917B898E
78888A7386847484817382817381836F7F807184847083847587897486886E7E86657B89
3F57780F2556011350000C4A01094A010848000845000940010C3D0B1D40324B604C6773
4A617105172E38515E4F5F5A336F2300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007C53342519211B182C675D69655968181736020A37030B38
34345465586A68596C1E183C070A345E55757A5F72866373916A7A8F6675916873946874
916770916870956B73996F789D707AA0737BA1757B996E71A07578A4787AA17A799B7A77
997C79A087839E8A849D8C84A5958EA3948D9E9089A09390988E89A59C97A39D97918E85
98958B9490889A98939999979A9A9A919190969595A8A7A79A999A9E9EA2929495ACAEAE
B5B7B6A2A4A4999FA299A1A59DA3A8BCC1C5BEC3C6BCC2C5BDC3C7BBC1C5B2B9BEB5BEC2
B2BCC0A6B1B4B3BCC1BBC3C9C1CACFB9C2C8BDC6CBCBD4D8B6C0C7B2BBC2B8C2C9CDDAE1
C5D6E0ACC0CBC5DBEC4165854A6F9298B1C9A6BED791B3D086A4BAD1E3EDD3E0E6D1DEE4
D2DFE7D2DFE7D1DFE8D1DEE7CFDDE8CBDEEEC3D6EFACC0E17880AE3C356C4F2F68683462
733256753754A16C84C8A4B69A889783858D8188917C8991818E9A74838B717F87758388
79878B7584847585847182816D7D7D708181708282718383748688728589637886253E63
03195601145A000F57010B4E010748000845010C4102143C1C304B475D6953686E586C6F
5D6F78142738364E5B50605F4A453700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00845B3524181F2822356C5F6B51475808092C030B3A020A38
312E4F6E5C6C6D56644E405B08072F45406379647889697795707F956C7A926673946773
916672916870986E769C727B9D727B9D737BA1787D9C74779F7578A4787A9D75759D7A77
9C7E7BA08682A28A86A28D879F8C869B8C859B8F889C928B9A90899F9590A49B95968F88
948E86928D8893908E9999989293928F908E9B9C99A4A6A49E9FA2A2A2A79B9B9FAFB1B1
B4B5B4B0B2B3A5ABAE98A0A39FA5AABABEC2B6BCBFB9C1C4B6BFC2B8C0C3B5BEC1B7BFC3
B9C1C4AFB9BAC0C9CEC1CCD1C9D5DCB1BEC6B4BDC3B6C0C2C2CCD2C0CAD0BFCAD0D2E1E9
8DA1B398AEBFAEC2CFA6C1D1A7C6DE92B1CABDDBF5486E8F7C9FB7CDE1EBD2E0E7D2E0E6
D2DFE7D1DEE8CFDEECCADDEEC6D9F4A2B6DB656C9B5B497C6A376B75214E7D0E35870726
8C06228807218209267D15317B2E448F677493898E81878E79848E91A0A67B898F788389
7C878B7A88897A8A89798A8A778688738484697A7A6B7E7D707F8272848A54687E02194E
00115D00105F020F5B000A52010849000C41081A3D2D46584F6A6E576D6C576869596A6A
5E6C74182938364F59526264514E4600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008D61362112143831416E606A3C324604072D030A3B030A39
312B4D6D58696E525E70596D20173A27244875657A816372906C7B9268759265718F636E
916672906670966B759C727B9E767EA17A819E767D9870759B7275A178799871729A7776
A0807FA186839E8581A18B859E8A839A89839B8E89998F899C928CA29894A49B979C948F
9C94909A94909997949B9B9A969796929492979997A2A4A59C9EA19B9DA1A9AAADAFB0B2
BFC0C2B0B6B8A6ADB0959DA1A9B1B3B3B9BCB9C0C2BAC3C5B6BEC0B9C0C3B6BFC3B8C1C5
BAC3C6C4CFD0C5D1D4B4C1C7B2BEC6B2BEC3B7C0C7BDC6CAD8E3E9D1DEE6B7C4CDBBC9D3
A9B9C7AFC3D0A4BCC6C2DDE9779DC12B5A8D769EC96E91AEBBD5E6CFDFE8D1DEE7D1DFE9
CDDCEACBDCF0C4D7F599AAD363639763497F783B6E801E478A0B2D94061E970115970211
95010F9301119201148D021786071B731526B88E97C7C2C7869198A8B6BC8C99A078848B
7B878D7C8A8B7B898A76868678878A77868A76858873858674858771848962758B04184F
01105D00105E010F5D010F55000D48152A50465F6C566E6F58706C5A6F6A576B69576C68
586A711525353A525C5366685555510FCA0700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006988271F0D0A413B466C626C262037050933010A3C030938
3931516F56687254606F536052425B1811326A5B737D606F8F6B7A916776916470936671
9265719468739569739B71799B737A9E777E9D757C956B729C73769F767A9770749A7778
987B799C817E9A827D9A847D98857E9B8A849C8E889A8E88988E889D9591A29B969C9691
97918D958F8C9E9B999999989A9B999294929C9D9D9C9D9FA1A3A5999D9FA8ABADAEB1B2
BCC1C3AAB2B3A4ABAE939A9EA4ACAFAAB1B4BBC1C4B3BABDB9BEC1BEC5C7B9C1C5B8C0C4
B4BEC0BBC6C7BDC9CAA9B5BCB6C1C8CFD9DCCBD4DAB6C1C6C2D0D7B2C2C9B3C0CAADBBC3
C7D7DFBCD5E787AAC4ACCEE93E66930D3B78416B97B9D5E7CCDFE9CDDEE8CEDEEBCCDEF1
BDCFF08C9AC6625E9367447D7F356A881B47940D2C9C061C9F02159F02119D020F97010C
94000C92000B91010C91000D90010F880619832D3DD0ADBA95949D7E8A907D8B907C8A90
7A888E7B898B7A888A78878B78888A76868978878B76868977858B75868C7083960B2052
01125A01125B0115560C215807164837506A577074576F6A5A70675B706A5A6E69576C68
50646D05172B425966566C6E5359561F981200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0043AC19250F06493E48685E6A13102C040935030C3C040A35
3C324F6E546272535B74555E6F57673628424F3E5880627386616F8F65738B606D956874
996B779C6F7B996C779C707A9B717AA078809E757B9B72749C7376976D7392696E977374
987A789C807C937B749E88819A88819E8D869D8E87978B849B928C9F9794A09A969C9792
958E8B8E88879D9A9990908F9395929394939A9B9C989B9CA0A6A69FA4A6A3A7A9A9AEB0
B5BCBDA9AFB1A0A4A7A5A9ADA3A8ADADB2B6BCC3C6B2B9BCB9C0C3BCC3C7BBC2C6BCC4C7
B5BEC0BEC8CAC6D0D2B1BCC1B6C0C6CED8DDC9D4D9B3BFC5B4C1C7C0D0D6C8D9E3B6CAD5
C4D7E4819DB81A426A84A6C28FADC886A9CE89B3D4BEDDF0C5DBEEC2D7F0B0C1E2898EB9
67568B6940787A2E6286173F960B2C9C061E9F05169E0512990511960813940B15890813
8805138C030E8F010A91010B93010D92021185081A7F303F9B808A808489808D91808F92
7C8D90798A8C79878D79888D78868A78868A7A868B768487738187738388738696152C55
021853051D532942695A728D1C2F502C445E5971765A716D5C716A5A6F695D706C586C6C
31465603162F4A626F586C6E53605B24A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004BB21C2A110451444B5D52600907260309302F345A0C0D2F
473B5272576376555D73545B775B66715B6C4E364A7E607085606E8C6370926773976977
966977976A77966A74986C769B707BA0777F9C7277986F71986F71966B6E966C6F95706F
967874947B749B837C9D87809A87809F8E87998A849A8E889B938F9E97959C97949F9996
968D8B968D8B9995918B8B879293908C8D8B979A9B959A9A9AA0A19CA0A39DA1A4A6AAAD
B2B6BAB5B7BBA7A9AEAEB1B6A3AAADA4ACAFBAC3C6BDC4C7BBC1C5BEC5C9BDC3C7C1C8CC
BBC1C6B9C0C4D0D7DCD1DAE1B6BFC5B6C1C6B5C0C5C0CCD2B5C1C7C8DAE4ACC8E07EA2BE
A9C0D39FB0C48CA0BAA2B7C8ABBED0A2BDDA4A6C95A0B8DD8F93BC7E719E7953867E3D71
802353841138910D2B980D209409168D08108D101784121880202685363B8848527B4153
7D374E7713258A041291020D95010D93000B9002107F0B1B965A648C8487858E91879598
7E8C917C8B907C8A9178868C7584887684897883897784896E7E8372848872848E29425A
1F385A4E6680657D8A687E882D42591D364E59727B5D72725E716F5A6F6A5D706D596D70
12263712273B4F696F576D6C58666135732700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0054B92031140355484F5A52640506260E11315C5A74171229
4F455470596275565D75545C755761785C677B5D6A7E5C6A845E6C9066748F64728F626E
976975986975986A749A6E78996E78A0747E9A6F769A727699717493686C93676996706E
93736F967C769D857F9B857F9A867FA290899B8A859A8E8A958D879994909D9894999390
938A8898908C96918C8A87828989848C8C88979997929797959A9C989B9FACAFB2A7ABAD
AFB3B7B8BABFA6A9ADA7AEB1A3AEAFA5AFB1AEB8BABAC3C6BDC4C8BFC4C9BCC2C6CED3D7
C0C4CAC1C8CCC0C7CCBCC3CAB9C1C7B5BEC4CBD7DDD4E3EAC5D3DCB2C6D7638AB14073A4
9DB9DBB2B2C7DAC8DBBFA7BD997D9B85678D7B59878653817F38668429548B1A40921234
99122B930C1E94111F8D18207F1D207A2C2B7E3F3E8053539075797B727E595E774A5476
2C2851693B5D780C2390041594011194010C94010E8D05168026349B8083818687808B8E
7F8A8F7E8C917D8B8F7D898C7C888B79898B77858A7381856F8083728586738588687D85
687D876B7F866B7F836A7E85455B6E0E263F57727C5D72736174735E736E5C716C5A7070
182D37385059546C6D5A716D56686146463800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDE103A1806594A52453F5504052522203A685F721B1325
5E525E6C555B72555B76575F7456617A5B677C5C687E5C6A896473936B7A8D6471926672
936571976874976A74996C77996D779B6E77966B73966E73956D7390666A92676997706F
95716E9576719E847E9F888299827D9C88839D8A86998B87988E8899928D9E9995999490
8F8885A29B988B86838B8884908C8893908C9898948F949291989999A0A2A9AEB1AEB2B5
A9ADB1B2B8BBA3A9ACACB5B7A1ABADACB6B8A7B0B2BFC7CBBEC4CABBC2C6BFC5C9C6CBCF
BEC2C6BEC5C8BBC1C6C4CACFD3D7DDC1C8CFC3CED4BDCCD4ADBDC6B1C5D27D9EC01B4C84
567AB38081A9774E6D823A5A872C4C8B24438D193694173395142D9213288F13238A151F
881C2380232884393D8954538A6967978683ADA5A5BEBFC5B0BCCA5E728A092247627EA0
2E436E3B3463681D3F85051A91011192010D93000C9003107C0C1A9D6A6E8B8787848E8F
818D8F7F8D8F7B8A8B7E8B8C7C898B7889897585867385856D7E7F6F8281718383718484
7184876F82856E7F826A7C815A6F7D0720375570795D72745E71715E726F5D726E576E6A
4258594F6766536967596F6B5A6D654D524700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004C220B57434B39334B040727363349685B6A1F1322
6B5A656F565C75575F72545D6E515B7657637959627C5A66825F6C8A6271916775926774
90636F946773946974986D779C71799C7079996E76966D74956C718F6367956A6C946E6D
9A75729B7875987B77977F7A9A837E9986819E8E88A2938E978D88968D899F9895938E8A
9F9B97A7A39F908C89938E8B918D89989694999B998E9392969B9C9A9EA1A1A6AAA0A4AA
9EA3AAB2BBBEA2ABADBCC3C6A8AEB2ACB4B7ABAFB3B0B6BBC8CED3BFC4C9C1C5C8C3C7CB
BDC3C6BDC3C7B8BEC6C9CFD6DCE0E7CAD1D8BAC3C9B8C4C9C8D7DDC3D5DDB4CADD779CC8
0E397E3B56937F79A7926C908D4D6A89364C892A398827338628338330377D383B7F4745
8E62609A7D7C9B8D8DB1B1AEC1C9C7CAD7D7CBD8DCC1CFDD49627594ADC0768CA49CB4C8
7C94B6131D516137617508218C021492010F92000B90010B850511863A40968283858A8B
808B8C7C8A8B7B8A8B7C8A8C7C898C7B8A8C79898A7284847485866F80806F8080708082
6F80817081827281836C7E816577821F38465772785C73755D72725F72715C706D5A6E6A
5B6E6D516866455C5B596D6B5C6E69575E541E960F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006032155842472C2640070A294E475A64545F291A26
6B586170575B7053586F51596B4D5670505A75545E7756607B586386606C8C636F8C606D
8E616D9669759268729970789970779B7077946971966D74956C7293686B9D73759B7676
9B78779977769B7D7A9A807B98827C96847F9E9089998F87978D88958B8899918E999590
9E9C97A4A19D99959299959191918C989D989CA2A18B909195999C959A9EA1A7AD999FA7
828992848C9299A3A6BEC7CAB5BCBFB5BABEB6BABFB4B9BEBFC5C9C5C9CEBFC2C8C5C9CE
D5DCE3D7E1E6C3CDD3B8C1C8BEC6CDBEC8CEBDC7CDBCC9CFCEDFEAB1CBDCADC5D996AFCA
4667946183B552719E596E95535C7E7E778B8A76818A6F799C838A9885899E9496ABA9A8
C3C5C4CAD1D2CDD8DACAD9DAC9D8DDC6D8DEC9D7E0BBCCDE658296BDDAE8C0D5E27994A6
8AA7C7152A5C4233646B173686031990010F92000C92010B8D040F77141C9D757988878A
7F8A8B7B87897D8B8E7B898B7D888E7B898C7382846C8081748589738184738284738084
7482837180807281836E7C817180876B7D8365797C5F77765D73725F73715E726E5D716C
5D6F6E586C6C33494B5268685B6D6B5A635B229D1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0076461C533D40201C370E0F2D6156675A4A56332637
5A4E5F5C4A556950556A4C536D4C56724E5974525D75545E7D57628259658A5F6A926570
946572956672966A74966D76966E769A7177976D73976D75976D75966D72986F729C7577
9A7879997B799E827F9D858098827D927F7A9E918A978D86948B848F86808F888197938E
A2A09BA4A19D9E9A9897969391938E989C979BA09F8E92968E95988F979B9DA5A97C848B
949DA39DA7AA889395B2BABDB7BEC1B7BCC1B9BFC4B6BDC1B2BABDC4CACFC4C8CFC0C5CE
C7D1D9C8D3D9BEC8CEB8C2C6BAC5C8D4E2E6D4E3EBBAC9D1AEC0CF516C8397AFC2B0C2CF
BED5E8A9CBEE739DCC8CB5DC7094AEC1D7E5CAD6DCCFD5DBD0D6DBD1DADFD0D9DFCEDADD
CDDADFCBDAE0C9D9DFC8DAE1C7D9E1C7D8E0C8D6E3C2D4E94968897092B294B0C5486178
37526F536A911C1F516C375A7A071E8F021292000C92010B8F020B7D070E9252588F8687
828C8E7F8A8B7E8A8B7C8A8B7B898E7A898C778688748588748388758386748386737F84
778286748284728084728084717E83707E836B7E80657B7B5F74755E72715E73705C706D
5C6F6D5D70702A41463E585E54696B59655F356F2600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002E970649343316162F1E1D38685C6A4A3E4C302C45
1818371C17315A4B5A674D566F4E586F4A56744F5B78525E7C5460835765895B678B5F69
8D616B91626D946772926772956D769B737A936A6F9B7176986D7592666C9B71739A7274
9B777A9F807F9D827E9D86829B858098847D9A8B83978B849188808A827B8B867D96928A
9C979398928EA49F9C9897959395919A9C9AA2A6A88A8F937B80837C83858F989A798286
8F989D8C969B949DA0B7BBBFC0C3C7B8BDC1B2BABDB4BDC1ADB6BAC6CFD2CAD1D6BEC5CD
B7C1C7B9C4C9CDD6DCCAD3D8BEC8CCC8D7DEAABCCAB5C6CFB7C6D0B7CBD8C5DDEDB4CEE0
B7D1EC3862950B408443729CC1DEEFCCDEE6CFDCE3CFDAE2CFDCE3CEDDE3CEDAE3CCD9E0
CCDBE2CADBE3C6D9E5C2DAE7C4DAE7C6D8E2CAD7E6AEBDD6142C59062250859FB7AEC3CF
90A2B3AABED7152451513C656C112D8A051692000E90000A90010A87050E7C242A9C8183
8287897F8A8C7E8B8C7C8C8D78888B78878B79868A77858878858A738387728185727F85
738085728084717F84728183707E827181866C7F85687D806276796074745F73725C716F
5B706F5A6F70324A5219343F465D645A69674E483C00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF003BA40F3B26220E0F292D2C43695F6A3931420F1131
04083005062B494157634C56694A526E4955724C5A76515D7A535F7F54618558638B5E68
8B606A8F626D9467739469749970799A727A997176976E7390646B94676C9A6E719C7376
9C777B9C7B7C9B817D98837E9A86809B8B829889819B8D869689859187838C847F958E8A
928A87928B88A2A09C92928F9599959BA09E909798838A8C828788888B8C7B7F8294989D
7E8488878F94A5ABB0B5B7BCC4C4C8BABEC2B9BFC4C1C9CDB6BCC0BFC5C9BDC5C7BCC3C9
B4BCC3C0CBD1D6E1E8D8E1EABBC4CDB9C5CFABBBC7C3D2DBBCCBD3C5DAE985A6CC5481B1
8DB3DB48709C285488779EBDC9E0EFC9DDECC9DDEECADBECCFDAEAD1DAE6D1D9E4CED8E1
CCDAE2CAD9E8A8BDD67D9EC1ACC6E5BEC6DFC4BFD7BAAFCB584D74373356AEB6C8C5D5DD
A5B7C48299B13349732322536C325580091D91020E92010A93010C8E030C7D0C159E6A6D
8883867F8C8C7A8A8A798B8D7A898C7C8A8D7C898C7B878B79878A708085738287728183
7281836F7D80738185728081707F806E80836C8082677D7D687B7E6276775C72725A7172
596E70556B6D415A603A5760415A615B6B6A56524900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BB119341C14090722403D537065722D253A030528
01042D0204293D344C644D5867494F6C4A53714D5774515A754E587D525E835561895A66
8A5C688C616D936874926772956B76946E76956F77966C7593656E95686E986F72997274
9C787B9B7B7C9E83819E8A849C8A839E90879A8B85978885998B899388868B828099918D
8E88848C898494938D8F908B90938F9FA5A37C858592999B7F8484919496777A7E95999D
959B9E98A1A2ACB4B8B9BDC0BFC2C5BDC0C5BBC1C7BCC4C8BAC1C4B9C1C4CAD4D5D6DFE2
C5CED5C0C9D2BDC7D0B4C1C9BDC7CFBAC4CCCDDCE6C6DDEFBFD7EBB0C7E0325789174A83
78A1C6A6C5DDB4D3ECC1DDF1C3DCF49CB9DC7186AE908DB1AD93B2AA86A3BC9BB7C9B3C9
D2C9DDD4D5E999A6C6122E623E4C7F563A64692A4F7126446B1D3B611E37826273A8AAB4
8494A23E5469647A9C0F1A4B6245706E0E268E051392010B94010C94010C8D09158A3B40
978586808C897B8B8B798A8B7A898B7B898C7B8B8B7A8A8B77878A75868A748285728383
7483846E7D7F6F7E816F80807082826C7F7E6A7F80697F7D687D7E6378775D7673587271
5A6F71566C6B4E64691A353F415B6358686963615C20960F00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056BB1E4428190E0920585067706273221934020229
01032E0304293A3047644B556B4D506C4D5170505572515777535C7F56617F525F855461
8E5F6C8C5F6B90666F8F6470936874946A75946B75976A759666719568719C73779A7577
A07E809E7F7F9C817F9D87849D8B869D8D88978884988B87948B85918B8788827D918C85
8F8A858884808C8A859693908D8B899B9C9B8186878E9497818589818588818588929699
949B9DA3ADADA9B2B4BAC1C3B9C0C2BABEC3BBC0C6BBC3C6C0C9CBB8C1C5C5CED1D1DADE
C2CBD2C0C8D1B9C3CBCAD6DCD7E2E9C9D3DBC0CFE15F82A4587EA3A6BED890AACA8EB6DE
9FC9F08CB2CF8EAEC4BBD8F26484B230497F614D817C37618623488B1F41841B3F7E2449
874062A26E8CB897B94032634331636B2E55780B2C81041B8204187A081B6B1F2F95828B
BEC9D099ABB8A6B9D02E436B38346268264385071994030F93000B97010C9405127D141D
A0787A8689867F8C8C7B8B8B78878A7B8A8D768889778A8B76888B77878A768587778484
7482837182826F81836D81816E82826C80806D81826D82816B8081657B796077745B7470
586E6D596E6C586C6D243F441F3B43546969626963229C1600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00583620160B1B6F63766E5E6F140C28020329
00012D0201273B2E45664D546A4D4F6C4D5170505672515977545F7E57627D525D825560
865A64895D678D626B8E636C956A74946872966A74956771966570986B749F747A9E767B
9E7A7D9D7D7E9C807E9A8382978382978683968985958D88C4C0BBCAC8C69D9B99888480
908A8687827F8D88859792908B86869796949799998081847C7B817C7C7F90919395989A
9A9FA29EA7A9A9B3B4BBC5C6BBC4C5BEC4C7B6BABDC4CBCDD9E0E3C0C6CEC3CAD1C5CDD3
CAD3D9CAD2D9BBC5CBCFDCE2C2D3E0C2D3E1B5C4D5809CB797B7D5C0D7F0AABFD97295C4
17498A245488A9CDEA99BBDD0F316D60629573284D90112C98081F99081D990C248F0B25
840E2B811B3B7117396E23477D3A5E9745607E0C228B061689010F83020F700816946771
CED0D6C1D1D97B8DA04960820F1A4A664263750A208F021194010C96010C950210820612
9552599286887F888B7A898B7B8A8D7C8B8F748688778B8B758788778789728081778585
7382837183847183867084856C80816E83847084857084837082826A7E7D667C7A5E7672
5C716F5B6F6C596C6B49656529484D4D6A6B5E6C6942382900FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00734A272412176F606E6A5B6C0B0521010327
00032A020225392E43654D54674B4E694C506C4E5570515974545D7A565E7C535C7F545E
875C688A606A895F688F636D9569739468729367719A6C7590616A9669719C7178A1797E
9E787D9F7D809D83819A848095807E9D8B87978B87B3B0ADD5D6D6D4D6D8BEBDC1817D7E
867F7E837D7B8A8582938F8C8A87859291909C9D9A8F8E8E8F8A8D8783868E8F91909397
91969B97A0A2A7B1B2B5BEC0B7BEC0CCD1D5B9BEC1C3C9CCC9D0D3BFC6CCBDC3CAC7CFD3
D9E2E7D9E3E9D0D9E1BFCAD3899BAAABBECBBECCD8B7CCDAAFCFEE89B0D88CB0D73A6193
0E3C80225082BAD9F47597BA0F316B7D729D7919369B0C1F9F0817A10C1B9B0B1C900F1B
84212C7223356C1E386E173378143290243E890D238E07168E03108A010C880C1A7A2C3A
A9959FA1A8B06F7D8A5667821928544538606A193488051792010C93000B93010D8F0513
80222E9E7E8483878A7D8B8F7A8B8D7A898D78888C798A8A778989778889728183738284
7281847081826F80836D81827083836E81836F82827083816E81806E82806B807E667B79
6376765D6F6F57696B476166193640415E625B6C6A47453600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008D5D303F2520705E685A4D6105021E030426
0206280202203F3345654D52694D506A4E526C4F5671555B74565C77555C79535B7E545E
825664875A67895D678B5F698D626C92677097697497697294666E91646A996D739C7478
A17B7E9F7E7EA186839A84809F8A86998782948884B7B4B4D3D5DAD4D5DEAFADB4817C7C
887F7D867D7B847F7B908C898787848989889998989392919492938786888A8C90898D92
8C93978F989BA6AFB1BABFC3B8BDC0C8CDD2BAC0C5C3CACDC4CCCFD3DADED8DDE2C6CED2
CBD6DCBAC9D2C5D0D9BDC6CEBFCBD5D0E3F0CDE3F5B0CBE0466E9B0E4380406F9C7FA1C0
7B9BBDA5C4DECAE1F37D99BB0D2C666C62907B1E3B9A0E219F0A1AA51222970B1B82191F
B98387A189926750664C2A476122456D11307E061E8F09198E02119103109005137A0E1D
8F5E6ABFBCC2BFCAD27D8B9C3F4E73191B486C3A5C7B071D91030F94020D92000B910210
7B0A189A666E8A86897D898D7A8A8E7B8A8C7A888A788789798A8C748589748487768588
7583867483847381847282827584857181826F81817185836D81816E82826E81816B7F7E
66787A5E7273586D6F3D545B0B2531415E625B706D4E524510CB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0046AF1C78594C735D6543374A03011D080722
2D2B4405021A473A496950566B4D506A4C526C4D556F515772525977545D7A535D7D535E
825463885966895A668C606A8D636C936970986B74956771936670946870966B729E777B
9F797BA17E7DA186829E89849F8D889B89849587849B9293BDB9BFB2ADB48A8285837A78
89807B877E7A807B788D8C888B8C888989869795959393948B8D8F86878B878B908A9094
88919497A1A3B9C1C3B8BEC1B8BDC2BABFC5B9C0C4C3CBCEC9D2D4D7E0E3D7E1E4C3CCD1
B8C4CAAAB9C0CDDAE1D4DDE5BBC8D698B3D15A83AD90B4D46E90B4416C9893BCDDA7C7DB
B4CBDCC0D2DFCFDEECA1B8D50F2C6756568B752948931023A30D1FA10C1F9107187A1C25
DCBEC2D5D7DCCCD2E18C92AB3D355A502D556213337A061A8701108E0110920312870917
7C333EC9BABFCAD4DA97A6B2657390101B4757406870142C8F051496020C95010C90010E
850515873C469282847F888A7A888D7C8B8E7A898B7685887384887284886F8283728484
76858676828475808475838579898B7485857183837185846D81826D81836E81816E8382
677C7D5D7274586D6E5267692A4248365052596D6950574A0FCB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049B11B84614E71585C2F2233030219221D2E
584D5A1006174F3F4D644C50694D4E6C4E536E4F576C4D5570505876515C7A535D7E535F
8354618959648B5C678B5F6990656E91666E93676E93666F9268719369729870789D767B
9C75779D7A7A9E837F9C88829D8A879D8A8A9786869183838B7E80887B7B887B78877B75
877D77867D78827C7885807D878581908F8B9797948B8E8D8C8F917F818683888D838B8F
8A91959CA0A6A1A7AAB6BCBFBFC4C9BAC0C5CFD9DAD2DCDEC0CACDCAD3D7CBD4D6C9D2D4
C1CBCDC5D1D6D2E2ECD4E5F3BDCCDF607E9E3260899CC1DCA9C3D9AFD0EF7DA8D55C8AB6
8EB3CBCADFEBD0DDE9C5D9EF2D4B803846817E4D728C162DA10E1EA60F2098091B7E1727
C3A0AAD4D8DFCBD9E0CAD8E4A7B4CE262E59422B576D1F3A860B1E9004129302118F0513
7913209C777E93999E83939B69798C323F652824506E314D80061690010B94000C91010C
8C031079171E9A76798083857B8A8D78888C7586887385877383867385896E8183728585
7786867584857282847184856F81857284857082837386866F81847083856F83846E8583
677B7F6175795B6D6E576B6A536968485E5D5C6D695B625720991100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B81E835D446C55552016270402163F3741
57484D1408135947526B4F556C4F536E51556C5157694C536E4E57714C5779525D7E545F
84576382545E8658638659658D616B92656F94676D94686D946870976D759971789D7479
9F77799C7A799D807D9D85829C8787A08B8D9A898990817F8C7E7B8E7F7B8B7D77867A72
877D76887E79847B77877E7D8B86848B8A87959593898B8B898A8E88888D82848B8A8F94
8D9197979BA09DA4A7B1B9BBBFC3C8B6BABFCAD3D5C5CFD3BBC5CAC0C8CED3DBDFD7E1E4
CFDCDFBDCDD4A5BBCB748DA4B5C6D7AAC0CEB3D4EAB5DBF7ABCFF07BA0CB114083083E7F
79A3C3CCE1ECD1DEE6D1E1F06682AC152D6C735F8C76173296091CA20D1C98081B830E22
945A6ADBD5DECDDBE1CBD9E1CCDBEA6B7E9F1E295C6E456C780E268F0615940111960414
83071785454D9E989CC3D0D3A3B3BF5E6D8A0D144268486D6E0D218A031091000B92000B
91020D7F07109252588E83867D888B76878977888B74868974858875888C73868A738588
7485866F80846C7F816C81826E82837083856C7F81708385748487738585708585708885
6C7F8364777B5F7172596D6C586D6B576B695F706D5E6661356B2100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002DDE108C6444604B49130C1B08051652454B
5342441B0D15634B566D4E556A4C516C4F536D4E556B4B53714F58734F5977525D7D5560
7C515D845664875867895A688D5F6A90646D90646C93666C94686E986C72976D72997072
9D75769F797A9E7D7B9D837F9C88869E8B899989858D7E798E80798F817C8D8078857A71
877D768A807C857B7A837A7A8781828E8B8B8F8F8E88898C84858A888990878990899093
8C94979BA3A59BA4A6C3CDCFD4DCE0BBC0C6C2C8CCC2C9CDCDD6DBC3CBD1CDD7DFD0DFE6
C5D5DBB6C6CEA5B8C6A1B9CCD0E2F1C3D6E19FBBD6356498285B97739CCC395E92385F8C
B0CDE3D1E0EBD1DEE6D0DFE9B0C3E219346D575D907333528F12259E0B1D9704188E0B1E
792032C9AEBAD0D8DFCDDAE2CAD9E1B6C7DC25386744396C6E1D3F88061C960215970415
8A0314731926A68C93C9D0D4BCC9D46F7D951B295240386368244080071790010D93000B
92010B8A050F7F252D9A7F837D82857B888C78858B77868D74878B7084877285896F8185
6E80846E81877084886D81826E82826D80836C80826D81837282867184866F84846E8685
7083856B7D806476785E72725C7070586D6B5D706E606B69433A2C00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008E65405D46430C051219121F5A4B4E
50404124131B664B566B4B516B4C526D4E556C4A536E4B54734E57734F5877525C7B555F
8057628257648457658457628B60688E646C90666F92676E91676C946B6F956C70996F72
9F77799D787A947472967C7899837F9B888499878396868091827C8F837D8A8078857B75
887D788B817D8A807E847B7A85807E8D8A898C8C8C88898B838589878B908A8F93858D90
90999BA7B1B29CA6A9A6B0B6B0BAC0B3BBC2BCC2C6CFD5DAD7DFE4CDD7DDC2CED79CAEB7
C2D3DAC6D6DCBDCAD4C0D4E7AFCDEAABCBE883A0C418447B24548F98C0E48EABC2BFD7E8
CEDFE8D3E0E8D2DFE7D1DEE8CFE0F44C69951F37717F648B841E3595071A9D071A9B0B1D
7F0A1D905764D9D4DCCFD9E1CCD8E0CEDBEA66779E19205B62315E7D0925930418950113
9002127B08178D5562949198919EA67C8A9B3C4D6F131A466B4464710A1D8C030E910009
93000A8F030C790C1598696D8885867F8A8D7E898E78868C74858975888775888C738689
7385896F82876E82866F83847183856D81836C7F837082867181877284896D83836E8685
72868670828466787C6376775F72725B706D687B7B6170704A463A00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009A6F46533E390A030F2A202A604D4E
453436322027664A4F6E4E516B4C516C4D546D4B526F4C53734F5777555D74525A78555E
7D58617F58627E5660835A63885E668D636B90666F9268718E656C90676D976F72997174
A1797C9C787A937272997D7B9E88859A86849E8B899583809587819086808B827C8A807B
897F7A867E7887807B87807D837F7C8A8787918F918A8B8C898B8D878B8F8F94998F9398
9AA2A5A5B0B298A4A5A5AFB3B6C1C6D3DDE0C4CDD0C5CBD1C0C8D0BEC6CEC4CED5BAC9D0
CEE2E8CFE3EACBDBE69BB2CC28518347739FA8C5E283A5C79AC6EE9CC8EF89ADC7C6DDE7
D0DDE5D4E1E8D3DFE8D3DFE8D0DFEC9AB3D213336D5E61917B334F9612269C06189C0918
8D0717701625C9ADB7D3D7DECCD6E0CBD8E5B0BEDA1F31674F3F7570193A8D071D950112
9501118C06167A23318C777EBFC9CFC0D0D96E809912214C55456C68172E88041393010B
94010B92020B860611883E4295848381898A7D888D79868B7A898C788A8C74868A718586
7386897184886F82866F82857382857486856D80826F82866C7E857386896E83836E8382
708484708283677B7B6477766679775F74726B807E6A7C7D4F514A0FCA0700FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00719032412D2807010C3D3035644D4B
3B2729422B2F6B4C4D6E4C4D6B4B4F6C4C516E4E546F4D5474535B74555C74555C78575E
7A535B805A627A556076515B845A658A5F688E636D9066708E646C8C6269926A6C987173
9772749C787B916F729C7F8098807F9D88869B88869483809A8C86958B839189828C827D
8B827C837D7687837D868481817E7F8683838C89898A898A878A8D858C90A5ABB0909399
8F979B8A96999EACACA7B3B3B5BFC3D3DEE3BCC5CAC3C8D0BABFC9D1D9DFD4DCE1BECBD4
AFC7D89CB8CEB5CBDEA6BAD05271978EB3D9C5E5FD89A9C93F6FA30F44883D6D9AC7E2F2
D0DFE9D2E0E8D2DEE7D3E0E8D1DEE7CADDF03A5B892B41788F698B85162C9C0D209C0A19
990B19850E1E9D5E6CDDD3DCCED5DECAD7E1CAD9ED5B709A232963703C65800A23940214
9A03119404137B0A1A90606AB4B4BDC2D1DB899AAE35496E2225536D39567F081B92010F
97010C97010D8F040F7A161C9D797C8485877E888C78868976858875888A7386886B7E7F
6F82847184877082866E81856D80837284846F82827082866F82887085886E83846E8282
7386866E8381687F7C607674657A786279776A827F687D7D575E581D960E00FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004FBA2937251C08030A493B3E604B48
301C1E533C406848486C4A4A6B4B4E6E4E536A494F6E4D5471525972525B73515C78545C
7A525A7C555F6D4A566C4A567B5561875D688C616B8F646E8E626A8E626891676B926A6D
946F719C797B9373759C7F809B83829F8A889784839A8B889A8D89948B85948C878D8380
918784857F7A87827F87848285828282807D8888868B8D917F87916975808B959B92989B
929A9D98A4A6D3E0E1C0CBCFA5AEB6A3ACB3B3BDC2BBC4C9B3BBC1D5DFE4D5E0E5C6D5DE
738A9F4E6C85AEC5D8CADBE7B1C7DD84A7D35D89BE719BC92C588F0B3D7C4C79A2C9E3F3
D0DFE9D4E0E8D2DEE6D4DFE8D2DDE6D1E0EB85A0BF133066746C95792942910E209A0C1B
9B0A1B960E20832237D3B3C0D3D5DFC9D7E0C9D8E79FB4D016295F5846777115348F0519
97011095010F8705138536428F7D87848E998294A15C708C0F1E4D6751766E11288E0515
96020E96010D94030F7E091193585D8B84867E898C79898B75868776898B7588896C7E7F
7382857282847385886F83856B7F816C80806D807F6F82836E81846F84876F8486708584
7085836C8280667E7B647A77607674607977728C89778C8B5F6A641F9B1400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C12E3520150E070C5142415E4A45
2716175B4648664B496749486A4B4E69494E6B4C516D4E53704F5875505C785260764F5B
7A535C77515C6F4F5B72525F7A5460855B658A5D6792636C9161698F5F66906368946A6C
9A72739B7878907271947B7A9C888695828094827F978884998D8898918A98918B918583
9186838A84808C87858C8786878281868381828384878F98516072687887828E94A4ADAF
9BA3A78C969BB0BBC29EA9B1A3ADB3A8B2B5D2DCDED6DEE2C0C8CFAAB8BFB6C6CBC5D5DA
B5C6D0B6CBDBC9E1F2C8E0F59EB8D61C457D0A3C84628FBF94B6D87D9FBCB6D5E5CFE4EB
D4E0E8D4DFE7D4DFE8D3DFE7D3DEE5D1DEE7C5D6EB2D4A784655877A4F6F8111278F0515
990819960818830B1F9C606FDBD4DCCCD6DFC7D7E3C4D5E84D648E252A61703A5F810921
90011093010B8D030F77101C936B75A1A6AEBFD1D99BAEC12A3E653A38636C2B4884081D
92011193010F93010D87060F7F2D349B83887F858A78898A778A8975898A738686738585
75858876878778878A7083867084866F83827183846E82826C7F836F83867285876D8381
6E84826E8382677F7C647B785F77736078756F88857A908E63716C346E2400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0061C83340271A190D0F5946435F4944
2616165D4D4D644D4F62484C67484F6A4B516C4D526D4D55714E57754E5A78505F784F5D
7A515D7D55626F4A566F4B568058618659638D5E6791636B8F5F698B5B648F646A956C6E
9A74759E7B7B937574997F7F97817E93807B93837C94858090857F99958C9A958D938785
8A807D8B8480918B8A958D8F8D8587807D7E7F81886B7A8C394F647B8A988D969DC8D0D3
B1B8BD8E969C8A939BAFBAC0C1CBCEABB5B7C7D2D6CAD5DBB6C1C8AAB9C1C2D4DBD0E0E6
C5D4DEA9C0D46E91B54673A38BB1D65E81AA4B72A59FC9EEB8D7F19EB7C4CFE2E8D2E1E6
D5E1E8D2DFE7D2DFE7D1E0E7D1DFE5CFDDE5D0DEEC748DAF132F67625886711A38890618
960515980717910B1A761B2BD2B5BFD1D5DDC7D5E0C7D7E59DB1D11225595945736C122E
8B051692010E90010F7E051383434E948D94BAC9D1A6B7C45A6C8C131C486B476A760D24
8F031492011091010D89040D720D179F727883848979878976898A778B8D75898B728688
75888A7286857384876E80837285867084837084857186876E81856F81847082846D8180
7084846F84846A7F80667D7D6076756279776E85847A8E9067767447413500FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0031E3174D2E1A251512604A43604640
3925234C3A3D5B464F3B242F5E444C694A516B4C536C4D5370505874515B744F5B744C59
784F5B8258638156617E545E7F545C8659618C5E6792636E91626D8C60698F666C977174
9A75779F7C7E9B7C7D987D7D947A798F7A768E7C769A8B849B92899B988F99938F948B89
89807D8B84818985828A8484878283828084788390324761667A8F89959E929A9E9AA2A5
989EA391979C8E979BD0DBDFD6DFE4ABB5BBA5B3B8B1C0C4C8D6DAC0CFD6BBCED9C8DDEB
BDD1E1A5BDD54266911F508597C1E2B5D3EC81A3CC4875AF3A659A95B5CFCDE0EAD2E0E7
D2DFE7D2E0E7D2DFE7D1DFE6D2E0E7D1DDE5D3DFEABDD2E82340732F3B71713D5D841025
920415940311960714871020A56A77D9D2DACAD6DFC6D6E38DA0B9364B762C2D5D6C3150
80091B90021091010D880410731A2497778080868D8D9BA58090A61A2B53504770681B33
88061790000E91010D8C020D79051188464E8B83857D8A8A78888C788B90788B8F738789
75898A7587877385877386887082857184866C7F826D80826F83847083857384866E7F7F
6D7F81697D7F687C7E6A7D7E66797A6176756C80837B8D926D7A7C53504600FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00563316331D18624A3F63483D
5C423D462F332B18233D283260484D674B4E6D4F536E4F556C4E536E4F5671505974535A
7E5F66A2848A83606B825864805360845964895F688F656E9267718B616A8E656D936E75
9672779D797E9D7B7E9576779073728F7773907D769588809D938A99928B9C9693918A88
88807E8F8A868884808C88848884857E838A51637D1E385698AABA959EA4929A9F919B9E
B3BABDCED2D699A0A6A8B2B9B9C3CAA6AFB6A6B1B8BFCDD1D2E0E4C6D6DF92A9BB4B6B83
A5C2D3BFD7E49DB7CD90B6D8ABD5F99FC6EA476DA10938870737807A9FC1CDE2EDD2E0E7
D2DFE7CFDEE5D3DFE8D2DDE6D2DDE6D1DDE4CFDCE3CCDFEC6881A510295E725F876C132C
880619920311990714930A1A7E2032D8B8C4D2D3DDD0D7E7717891979CBF312B557F4E6C
7B0E238F021193010D8D020D7707138E5961858185C6D2D6BDCDDC455A7D2229586D3B5A
7E0B208E010F91010B8E010B82030F721B2393787C7F868778898B788B8E788A8D76898B
75878A78878978898D74878974868A728286718386728486718483708385748386708181
6E8081687F7D687D7C6B7D7E6B7C7C65787A6A7E817B8E92738184585A530FCA0700FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00643B1841251A664B3D684C3D
6A4D444E373638252A5D494E5E464A694D526C4D526E50556D4F546D4C526F4E566B5258
A99A9ECBBFC4A089947B5365835566875B69845B668C636B9168708E656E8D656D97717A
98747B9D787F9572768C6B6C8D6E6E8C726E927F799887829E918B958B869B9390938B8B
8D86838883808C86838F8885868284767D8E182F51435A7782909B8991958F969B99A2A7
B8C2C5D1DAE09DA6AE87919AB6C1C7D3DCE2C5CED7A2AEB9B8C7D2A3B3BD9AAFBE7794A8
BFDDEAC9E2EDBFD7E75F83A921508E1C4D88769DCA294F854970A0B4D1E8D0E1EAD0E0E7
D1DFE6D0DFE6D2DEE6D2DCE5D1DDE4D0DDE4CEDDE3CCDDE6B3C7DE193362373D6F62304F
76081C8E0414960412940312850A1EA35266B37F97A475938655788D547889486B963F59
880D2191021194020D91020E810715925058ADA1A8A3AFB7AEBFCC6A8099172753685378
6C0F2889041390010C90010A8B020D74070F8F595E8883847D8A8C798B8D798B8D798B8D
76868B73838975848B76878C7584887281837283857587887284866F83856F82846E8282
6C807F69817E6C807F697C7B687B7C677B7C6D8285788C8D78898C5B635F219B1400FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075461C4B2A1E6C50416C4F3E
6B4D425C413F45333A362832463339664C517051566B4B506D4D53704E55714F58675059
B4ACB2C6C1C8A18E9C81596D865569875768865B688F64718D626E8A616B8C676E936E75
9872799C747B8F696F8B696B8F706F8F75738F7C799988879A8C8A938783968C898E8583
89837F86817C8D89858F8B8888898F505D7A132B516C7F96869096A3ABAED0D8DD9FA8AF
9DA5ACA2ABB2ADB7BF9DA7B0AFBCC4D3DFE7B8C3CF8897A47C8D99C8D8E0CBDAE2A1B6C6
A4C4E197BCDD92B5D64C709C0A377A21528BB4D8F788A9C87195B2C9E1EFD2DFE8D3E1E7
D1DFE7D0DEE4D4DFE7D4DFE8D2DDE4D1DEE5CEDDE4CDDCE4CCDDEC677F9F1228595D527A
631933820A1D9309189204148E0617870C2280112D80123282113384113089122D880B1E
8C07178D08128F09138908117E0D19753540998D967B858F818F9B8D9EAF33476B3B3C65
6B2A4781061990011092010D8E010C8305107E2E36978384808A8B778A8C77898B7D8F90
7A8D8F76898E79888F7A888E788689758486748387708284697C7D6E82836D82826D8283
6E82826F82816A7B7B687D7B6A7F8064787B697E81778B8C74878A5F6B69209D1800FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00299101522E1F6E51456C4D3F
6D4C41684A491F101827212E4F424B634C4F6B4D506B4B506A49506E4C546F4E56684F58
A2939EC3B4C285697C82566A855565885867895B6B8B60718B606E8B626B8A646B926E73
956E749A7178946C728F6C6D927573917977917E7F928283968A89998F8C968C88908681
8C857E88857D8988839090907A8396172E56324B6F8594A38A929899A1A8B1BAC39BA3AD
99A0A8B6C0C5D4DFE5C8D5E082909C9AA9B399A7B09CAAB38E9FA9CDE0E9CEDFEA8EA4BF
274E800E3F795A87B4B1D1F05B7FA889B4E393BBE75E88B64F7897CBE3F0D3E0E9D3E0E6
D4E0E8D4DFE5D3DFE8D0DFE6D2DEE5D0DDE4D0DEE5D0DEE5CDDBE5C4D5E5556B8C2C3B61
5A44626520337718247E161F8018207B1720801F2C7C1F2D7C2130802A3981303B873539
83323883383C81383B7D383A783D44856A71A7A8AE87919A9FACB5C5D3E07E90AD16234E
704A6E770B228D021491000D8F010B89030E740F17956D7183868878898C78888B7E8F8F
70828478898E78899077888D78898B77888B74858A7285876D81816E82826E83836C8183
6D7F83728184707F7F6D807F6B7F7F697D7D6B80816E84856F83845F6D6C453C3100FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00369D08532E1C6E5142684B3A
6C4B3F6B4C482E1B21180F1B261B24654E526B4C4E69494C67464C6A49526E4B546E4A57
7353617C5C6E7D5769805665865863885866895D6D865F7085626E855F67845E66946F76
9A7578956D718D6568906D6D917371977D7D9C87899585869B8D8C9C918F9A908B938984
9189828C87828D8B89959AA34A5D7F092957627C98C3CFD69BA1A58C939A8D959DB6BFC6
ACB5BDA0AAB3C4CFD9A4B0BC77879292A1AACFDDE4D2E0E6A3B4C0869FB38CA7BB94ADC3
47688D3F659198BCE1C6E4FE9BBBDC2C5892083C881D55919EC6E4CBE1ECD2E2E9D1DFE6
D5E2EAD3DFE6D1E0E7D1E0E7D2DEE6D1DEE6D1DEE6D1DEE5D0DBE4CFDBE4C7D6E597ABBF
6C798C776E7A927579906C6E90696C9874759C7D7EA1888AA9939B6D6273827B8A9E969A
9B9094928C918C898EACA7A99B9A9F929EA7C4D5DEB9C9D48A99A5B0C0CD899BB421345C
4E40686A193588051990010D90000A8C020C7C051086474C8C85847A89897B8A8F7B8B8E
7A8B8D7D8D917B8D92788A8F7A8B8F76888B72858974888A7185877488897286876D8284
7284866F80837081836A7E7E6D82816B807E667C7A6D82827386876470704B453D00FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A8105129146D513D6B4F3B
6C4A3E6B494260464643323B3A2C35654F53684A4B66464A66464C68454E6C46536D4551
71495579505E7C505E7E535E8256628459677D59686E536264505C6F58627F6067946F74
9A72769A7276936B6D957071917070957A79937F7F8473749788869A8D8A978C88978D8A
9289878F8887918F92858FA4102D5D193B6A7990A49CA6AB8C9295898E939DA5ABD4DDE5
C7D2DC87939F8C98A3ACB8C1BBC8CF9DAEB6C2D3DCC0CFDA9AABBC46647C7290A8CCE3F2
B3C8DD87A1C1799BCA537BB2709ACA204D8A073986376CA2BEE0F6CEE1EAD1DFE8D1E0E7
D1DFE7D2E0E8D1E0E7D0DFE6D2DEE7D2DFE7D0DDE5D0DDE3D4DDE5CFDBE2CCDBE3C6DBE0
C6DCE1C7D7DBCBD4D6CBD0D1CCD0D1CBD2D4CDD5D7CCD8D9BFCBD66B8299617E997992A6
9FB1BD6F8397617990C0D4DFBACDD78194A3A5BACAA3B7C57B8A977787938EA0AF586C8A
2227536933558008208F021092010D90010B890510772025967C7D80898A7E8E91798B8F
7B8E907B8E8F778A8B798B8D778A8E76898C74868A71848872858976898A728587738688
7486867185846F83836A81806D83826F85856D828270848576878B69757654504900FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B51951280B6B4E3A6C4D3C
6C493C6C48416347472C1B252E1F2C5F484D6A4C4D67474B67454C67444D6B45526C424F
7349547C4F5C80525E825662815763765160614453634E5C5B4C5A50434F6C57608A6A72
977078926770946A6F926B6F917274947A799985838C7C7A988A87988E8999918C958E8A
97918E9893938F919D4C5D840A2B673E5C8795A4B399A1A5B4BDBDBEC5C98C949DA2AEB7
8E9BA48A969F8B98A0CEDCE3D1DFE5A0B0BA8294A29FAEBAC2CFDC98ACC09DB9D2BEDAF4
A2BCDA7595BC15407E083D886495C892B8E0537DB279A8D2C2E1F3CDE0E9D2E1E9D1E0E7
CFE1E6D1E0E6D2DFE7CFDDE3D1DEE6D1DFE7CFDDE5D0DEE4D1DDE6CCDAE3CBDBE3C8DAE0
C7DAE0CBDBDFCFDAE0CED9DDCBD8DCC7D7DCC7DADFC7D8DEBFD0DC728AA523447234557F
B8D3EA6A839C344C6BA0B7C8B3C6D48395A47082929DAFBAA5B2BB818F98C2D2DCA9BBD1
19275361436B770F2A91051795010E92010A8D020E770A1296646A8787898090917D8F91
7B8E907A8D8D7A8B8B738685788C8C7B8E916F818477898C73858875868876888B76888A
7183857085856C81816A807E6E828371868973888A718586788A8E6C797B5B5B561F950F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005B2F056848346C4D3D
704D3F6B473E55383919050F39262F61464C6B4A4C6C484C6A464D6A434C683F4C704652
754C57784D5A7F525F7F55617C58656043516C5260785F6B75616C594E59544653826874
916B768F646E936A73906D758A6F758C767A968483988986938883938B85948D88958F8C
98938F9B999A858FA6142C640629666B86A69AA5B09FA6A9C8D0D3C3CCD2919AA4808B95
BCC8CECED9DF98A3ACA6B5BFABB9C3909EA9758690C0D0D9D3DFEABDCBE06A87AF2A5588
618DB69FC7E94972A02D5D9497C6EEA1CAEE5D87B4306089C1DFF1CDDFE7D1E0E7D1E0E7
D2E1E7D2E1E7D3E0E8D1DCE5D5DEE8D1DFE6CFDEE5CDDDE5CCDDE7CBDCE6CDDCE5CBD9E0
CEDAE3CED9E1CDD7DFCDD7DFCCD7E0CAD7E0CBD9E3CCD6E2C9D1E2939FBE182B6113275C
97A6C5B8C2D79699B2898CA09DA2B3B7BBCB8E91A3CACADAD3D1E1A1A0B1A9A6B8ADABC3
4C4B7150375C791F3A8E051997010F95010D91010D860612883A459785898890937E8D8F
7F8D938190928392937C908E7A8D8D7F91936D8083798C8E728485768A8A758989768989
7285866F84866C82836B82826B818273878A6D808473868876888B6D7D7F5A615C219B15
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B3B0C67472E6E503D
6F4F3E6C483D5A3A354327286245456847476B49496A47496A454B6D444D6C424D69414C
754D58794F5B7C525F79505C70515C5A44507359667E626E7B66716155614D4351796471
8B69738E677086616C7B5D67775F69806B748E7C7E988887968A879A908B988F8A928B86
95918C9A9DA257698B062665193B6F90A7BABFCACEA2A7ABA9AFB4959FA5A1ABB287939B
C8D5DCD3DFE79DABB68495A1A5B5BED1DDE4BDC9D38E9FAEA8BBD09AAEC65977A10D3A74
5E8CB6C2E8FFB1D1EB6D95C24274B1356CA86091C05D88A8CAE3EFD0E0E6D3E1E8D4E0E8
D4E0E8D2DFE7D3E0E8D2DEE6D2DDE7CFDEE4D1DFE5CCDEE9C3DAEEC3DBEFCDDAE9D2D8E5
D4D3E2D8D2E3D4C8DDD2C3DAC8B5D0C6AFCBC2A7C4BE9DB9BD95B6AE83A96F447170436E
8957798953708E506F8A4A68915370955976874869904E6E9A57788C4869874262884563
8543628C415F92223C91021698021194010C93010E8F04107F121FA76E75977F8790858D
8D868F87888D828A8C7C8C8B7D8E907D8F9274878B778C8D798D8D798E8D788D8E738988
73888972898B6D8685677F7F6B8282748A8C5C6E727284877B8D907082845C6865336C23
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00834D166844266C4D38
6C4D3B6C4C3D6B483C67443C6946416C4A446B4B4767474768454969434B6B444E6C454F
764E597B515D7C525E79545E614651604C58755D6A7A616E72626C5E576147414D75626E
8B6A748A656E7E5C659070798C72797D676E927D80968383958685998E8B9C928E8E8782
8F8B898C93A2223A6C0326693958839CADB9B3BCBEA9AFB3A1A7ABB7C0C4D4DDE2ABB8BF
8A98A2A0ADB4AAB9C196A5B0AFBDC8D1DDE7BDCBD87990A843617EB5CFE7B9D2EC6C8EB4
9AC4EB9EC7EA96BCE0406B9F073E920C489495C3E9BCDAEBCFE0E8D3E1E8D5E1E9D6E0E9
D6DFE8D4DFE7D3DEE5D1DEE5D2E0E6D1DFE4D2DFE7BED3E24667905D7DAC979BBE8E6D8D
955B7D934E6F883B5E8631547A22447E21447E1C41811A3E84173D7E0E347F0B2E810B29
8109258509268808268807248808258807278C0A2A8C09288D08298D09278B0724890721
8B08218B071D93041998021496011092010B93010E91020C8D0614841523822637853548
843E51854D5B87666F8A888A7E8C8E798C8E76898D768B8C798B8D7A8E91788C8F758A8C
74898B73888A6E84846F83836F838375898A65787A697D7F7D9193708486637071474035
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DA1086A4221704F3B
714F406C4B3C6C493B6A463B67433B6846406748446748486846496A454B6A464E6B4851
734D5779505B7B515B7A565F58414C584A556A5A656B5C66665F6854535C47424C79666F
88656D89626A83626891737890767A7E686C957E83937E82958585968C899B938E948D88
979799667391032162163A7D6883A7A2ADB7A3A9ACB7BBBFA2A8AEB7C0C7CCD6DCA4AFB7
8D98A1B1BCC2D5E1E7C5D2DC94A2AF93A4B099ABB58EA6B754748AC2DBEECCE0F295B4D7
2857940E45894275AF83AEDB2251923A70B1A1CEF3C9E2F3D1E1E9D2E1E8D2E0E8D4E0E9
D3DFE7D5E1E7D4DFE5D2DFE5D1DFE5D1DDE3D1DFE7CADEEF4869951035747170A367244B
871538971836930E2B971029950F258F0C208F0A208C0A1F8C0B1F8E0D218D0B1F8B091A
8F0C1D900D1C8C08198D0B1B8A081A89091B8809198709188A08188C0B188A09178A0916
8C09168E0B178F08178F08168D06148B06118C05118C05108A030F8A04128C05178A061A
86071A7F0B1E6B142296777B858C8E7B8E927B8E92788C8D788B8C72868875898C73878B
768A8E768A8B7084857084837385857589897286876C8183758D8E798F906C7C7D4C4A41
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047A90C72441F724D3A
7551446E4C3D6A49396C483B69443B67453F69484666474667474A6A474D69474D6C4A51
714D5676505A79505A78546057414D4D44505A54605C57625858624A4B56524853836771
8C656D8861698261688C7074816A6D867076947B83957F859786889A8D8B9A918C97918D
8B8F98293D6A03236D1232708DA0BCA8ADB4B2B5B8D6DBE0BEC5CE9AA3AE909BA4B8C3CA
B6C0C8A5B2BBC7D4DEB2C0CB8A9BA97C8F9BCADDE4CFE2EA9DB3C394AEC698B3CD85A5CB
184687073E8B376CAABDE3FF97BAE64C7CB92A5B93B1D3EDCFE2ECD4E2EAD2E1E8D2E1E8
D3E2E8D2E1E6D2E0E6D2E0E6D1DEE4D1DEE6D0DFE8CEDEEB9BB4D4153A7455649A6C3E5C
7E1A2E8C19268C18238E1E26861D2781202880232F7A232D81303881333B883C438C4348
8A434889464F8B485386434A89474E84464D86494F85464C84454987484B834247844147
864145864043873E42843B4181363C7C30367C2932792429741B1E75171B7710167B0F15
820E17800C176E0C1883565B8B8C8F788A8C7D90937B8E8F748789758A8B73878A778A8E
75888C73868970848672868770848474888872878973898C71888C768E91758989585C55
0ECA0700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B211724219724C39
744F42714F406A49396E4A3E69463B63423A67474566484863464863464967484B6B4A51
6E4A53714D54764F5A734F5E634958463C4B4A48564F4D5B51505C4C48546B5865896572
8B616B8C636B7F5B62795B608266698D7578937D81947F83978587968888988E8D999596
767F960B225E02206C2B4477A5B0C4B3B5BAABADB2BEC2CAA4ABB59DA5AF9FABB4D2DDE5
D1DDE58D9DA890A0AAB4C1C9B3C1CB8D9DAABDD0DCC5D7E47E94AB35587F4C749BC3E2FE
86A6CF4972A8699AD277A5D78DB7E71545841A4C8EB3D4F3CEE1ECD3E0E9D4E1E9D3E1E8
D2DEE4D4E0E8D2E0E7D1E0E7D2DFE5D0E0E6CEDFE7CEDFE7C9DCF143658E28497879768E
7C545F936064986869986E709874779F8286A68F92A79496B8A6AAA89A9EADA4ABA6A5AB
B2B2BB7E849A6E7791ADB2BCAAAAAE83858985878C888689888789828183ACACAEA6A4A6
8D888AB3AEAEA89FA1928A8C8E85878F8587998B8D928180957E7E9277748D6B698E6462
8C5A5B814B4E6F3E42745D5C848B8A798C8C7A8D8F7B8F90788B8F768C8D6A7F8174888A
788B9074888B6C8086697D816E818372878772878974898B73878C73898E788E915D6562
1F981400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774618704B36
724F426E4C3F6C4A3D6C483B6F4C3F68473D6545426648476246476146486446496A4950
704D55754E57764D5A77505E7353614E3C4A48404D4B44515C535F675A65856D788E6976
8F68738F676F8E696D8E6B6D947575937777957E7F958183908080958A889A94928F8F9A
46537A051E67031F6B50648FC1CBD8C7CBD0A6AAAF9FA3A9C4CAD0C5CED494A0A9B0BDC8
9FABB692A0AB92A1AAD0DDE3D5E1EAA3B4C27D94A493AABBAFC5DA46678B4F779CC1E2FA
A9C6DF7FA2CC1C4C900B4494598FCB517DAC426792C4DEF2CFE1EAD3E1E8D4E1E8D4E1E7
D3DEE3D4DFE7D5E0E9D2DFE7D3E0E6CFDFE2D0E0E6CFE0E7CBDCE9A9C4D87E9DB69CADBA
B0B6BCBEC0C1BEC2C3C4CACCC6CFD2C7D3D6C9D6D8CAD7D9CDD8DECDD8E18598B0527396
B1D0EF3455821236688BA9C2B4C7D28D9FA781949A9FB0B3B5C5C88D9FA5BFD0D9BFD1D7
8999A2A2B2B89FADB3919DA297A4A78E9B9D909EA28896978E969A8C97978891908D9392
909294888B8C8285877D84827C8B8B788C8D7A8D90798D8F7A8E92758D8E73878C74888C
768B8F72878A6E8286677B7E697D7F6E828274898A768B8D73878C728A8D758A8D5F696A
31682100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C4A16745035
7151406F50406B493E6C493E6D4B4068463E64433E64454262444464474A66454B6A4750
6C4750714854764B597C53607E586571535E5C45506A576179646E8870798F707893707B
8F6A758E69718E6A6D9674749876799173748F7776998683988A86978F8A9A97978E93A7
1629600220720B2E726B83A1919CA3A6AEB1AAB1B4A9AEB3D3DBDFD1DAE09BA5AF8A95A0
B1BDC5CCDAE1A7B5C0B0C0CBB4C4D19FB3C15772859DB8C8CCE0EEBED5EB6D8FB4608AB4
8BB6DD76A2CD114288064095528BC6AED5EEB2CCDFD0E3EDD3E2E9D3E0E6D4E2E8D4E1E7
D4E0E5D3DFE5D3DFE8D3E0E8D2E1E7D2E1E5D3DFE5D3E1E6CCDAE3CADEE5CCDFE7CADDE1
CDDCE0CDDCE0CCDADFCDDCE2CBDBE1CCDCE1CBDBE1CCDDE2CDDCE4CDDDEA89A2C50E3874
7198C97697BF4C6D95819FB9A0B7C6B6CCD68DA6B0B3C8D0C5D7E09EB1BD9AACB9ADBEC9
97A6B199AAB4A6B5BDA6B5BB9FADB4B6C6CC92A2A991A0A78B99A18C9EA28A9B9F8FA0A3
87969C80909885959C8090927C8D9074898C788D90798D9175888C778C8F74878D758A8D
71898B728989718689667B7C6A7E806C808173878B768A8D71858B72888D7A8D93677375
443D3400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00825117745030
72533E7051406D4C406D4B416B4A416B4A4166453E67464266474667484C65444C6B4853
69444F724755794D5D7F536480556480596682616A886A718F707790707894707B98727F
936D79936E768F6B7198767A98767C97787C987F7F978582998D889B928E9C979C727B99
061D6104267A1F44818399B1929B9FB8BFC1D2D9DDABAEB6A7ABB5A1AAB3AAB3BC8E98A0
C8D6DBD3E0E9AEBCCA94A6B4AFBFCACCDDE6A8BCCC87A0B3ADC6D796AFC5426693083B7E
4579AFB4E2FF83ACD84C7BBB4578B77FAFD9BAD9EED1E3ECD4E1E9D3E0E7D3E2E8D6E3E9
D2DFE5D4E1E7D3E0E8D4E2E9D2E0E7D2E1E8D4E1E7D3E0E5D2E0E7CFDEE5D0DFE6CCDDE3
CDDDE4CCDEE2CFDEE6CCDDE4CFDDE6CDDDE3D1E0E7D0DFE6CEDDE5CCDDEAAEC6E2315687
779EC99BBAD2B4D1E881A6C3A7C8DFC1DEEC748FA294AABABACAD89AA8B698A5B1ABB6C0
B5C2CBAEBBC6C4D2DCC2D1DA9BACB5A5B8BF92A5AC93A4AB97A7AF95A6AD8E9FA78C9DA4
85959E80919984959C899B9E84979B7B8F93758A8E778C8F77898F778A8E70828972858A
71878A718788708487697D7F697C8162757A6C80856C808472868A71858A788B906F7E80
48463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C5A1A74502C
71533C7053426E4E3F6E4C416E4D436E4F466A4A456848466A4A4C68494E694950694952
6A4651734A58794E5F7B4F627E51648459678A636B8F6C728F6D74926F78926F7B967380
99768198747C96737A9B797F9A787E9B7C819981839D8C8BA093919B91919996A0394671
031C6C01207727447B9AA7BB9EA1A7B5BBC0D0D7DDA7A9B19FA1AABBC2C9D3DCE3B2BDC4
9DADB49DADB6A6B4BF8F9FACAEBEC9D3E1EBB8C8D9728BA6597A9AACCCE67593B91A447C
5E8BBBB7DDFAADCCED648BC30131841E5BA49DC9EBCBE2F0D3E2EBD4E1E9D5E3EAD5E2EA
D4E1E8D3E1E8D7E4EAD5E2E8D5E3E9D4E1E9D5E3EBD2E1E8D1E1E8CFDFE6CFDFE7CEDFE7
CFE0E8D0E0E9D1DFE8CEDFE8D0DEE7D1E0E7D3E2E9D1E0E7CDDEE6CDDDE8C2D8EC9BC1E9
70A0D1A1CCEE9EC5E42255866090B8B0D1E798B2C69FB2C1B1BECBC0CAD4AFB9C3BDC9D1
C7D5DDB3BECBB8C4D1B3C1CF99A9B6A1B3BDA3B5BD9EAFB696A8B293A4AD91A2AB93A2AB
8B9CA48C9EA48C9EA3889B9F7183896F8388788C92819498899AA17D909474878E6F8388
6A8083687E806A7D826A7D8166797E5063695B7177617A7E667E8170848971858A708183
51544C0FCA0700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A60A744E27
6D51386F55406E513E7050416F50457053496E514B6F524F6D50516A4C50694B506F4F56
6947506D4753744D5A79505F7E5364855B688D646F906B75926E78906B7794707C977580
98767E9B767F9C787F9E7F83A081859E8184A0888B9E8D8E9C8F909D94988C90A5162863
011C7502207348608ECBD4E1AFB2B79DA1A6A7ADB2B6BAC0A3A8AFBAC3CBD1DDE6A8B5BE
9AA9B1A6B8BFD1E1E8C8D8E37D909E92A4B296A6B86882A1183E659ABBD8C9E1F897B5DA
6E99CB6090C493C1EF5B89BE0A3E8E1856A197C5E9CCE4F2D2E1EAD5E3EBD5E2EAD7E4EC
D7E3EBD6E4EAD7E4EAD6E5EAD6E5ECD5E2E9D6E3ECD6E4EBD4E2EAD2E0E8D5E2EBD1E1E9
D1DFE9D2DFE9D2E0E9D2DFE8D5E1EAD3E0E8D2E0E8D2E0E8D0DDE9CFDDE9C7DEF35D8AC0
0E4C9E437EBC9DCAED4877A375A1C5A1C2D6B4CBD9A9BBC8B7C8D1CBDAE0BFCCD5B7C7D0
CAD8E4BEC9D6B8C3D0ADB9C6A1AFBB96A8B2BACBD4A3B4BD9CACB897A7B195A4AF94A2AB
93A3AB8E9EA48E9EA286989E879AA17B8E9476898F788C91788C91768D906A8085637A7E
6A8084687E80697D836B7F826A7D8153686E556B735D7679657C7F6A7F836E86896C8082
5E605D1F961100FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A90B744C24
6E4F366E533D6D523E6C503F7053447255496D514A7155536F5454694F516B4F536E4E54
69464E714C5578515B7A515D805664865C6A8C63708D6876906C7A8F6A77936E7A97727D
97737C9C777F9E7A819F80839C7D809F8184A28A8EA28F919D90939C959E656E91061D69
011E7D01206D6D84A9B6C1CBA9AEB39FA6A9B1B6BAD6DCE2C9D1DA95A0AA8E9BA4B5C3CB
A9B9BF93A6AEC1D3DDB6C8D48296A690A5B5C9DBE9BFD2E76A85A4A2BEDEB1CAE399B8E0
164C930B50A32E71B4A8D5F76F9AC67FB5E4B3DFFCD0E6F3D8E6EED9E5EBD9E5EBDDE7EC
DCE6EBDEE8EDDDE7EFDCE9EEDAE7EEDBE8EED8E5EDD8E5EDD8E3EAD8E2EAD6E2EAD5E3EC
D5E1EAD6E3EBD5E2EAD3E1E8D6E2EAD7E2EBD6E2EBD2DEE7D0D9E8D1DDEACADEF5658EC5
134FA44683C2B5DEFABCDEF7BFE0FABADBEEC6DEECB4CBDAB7CCDBC1D4E0BCCCDAB2C3D0
B5C4D0C5D1DCC5D0DDCCD8E4BCCAD690A1ACA8BAC5A1B2BDA7B5C2A4B2BE9FAEB99AAAB2
99A7B1919FA797A4AD8B9AA380909971848A70828971858A7084896D8488687E83657A7E
6B7F82697E80667C80667E81687D804E666B4159605A727664797C677F806A8384697E7F
616867229D1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB01077491F
704E377054416E54416B513E7155457153476E514B7153546D5153694F506A50526D4E54
6C49516D495279525C7B535E825966865D6A8C65728D6874916C79906B79946F7A97737C
99777F9A7980A08085A18084A18185A4868CA0888DA190929E91969894A63A487B051D76
06268824468D798EAD97A0A6ABB3B4B3BABDAAB0B5C7CFD8ABB4C08B99A399A9B0D1E0E4
CDDDE376879390A1ABACBEC6AABCC7798E9BC7DAE7C6D5E899B0CF7899C789ACDAA7CAF4
3465A43773B95E98CCCEF1FFDBFCFF7CB4D786BBDCD0E7F6DEE8F0E0E8EDE4EAEEE7EEF0
EAEEF1E9F0F4E6EDF4E1EAF1DFEAF0DFEBF1DAE6EDDBE7EEDCE6EDDAE4ECD7E3EBD5E2EB
D7E3EBD6E3E9D5E2EAD2E1E9D5E2EBD4E2EAD4E0E8D1DFE7D1DEE8D1DEE8CDDEEDA9C9E8
79A9DD8FC4F4ABD4F1B9DAF45E86AF83ADCEB9D8EB9DB6C89EB4C8A6B9C9B1C1D0A2B2C0
C4D3E0C8D7E4ACBBCABCCBDCBCCFDEBBD0DDB5C8D3ADBEC7ABB7C3A0AEBB9DAEB8A4B5BF
A1AFBC9AA9B394A3AD90A0A98A9AA3798C92768A8F7284887083887084886D82866A7D81
6A7E7F6E8384697E82677F8362777B526B6E5B747A566F735F777A647D7C6279776B8082
64706E433B3000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A4917
704E336E513F6E53426C513E70524273524770524B6E504F6E50536E53546A50526C5156
6B4C566E4E5874515C77515D7E5561845B688B616F906974936D79956F7C936E7997757D
98787F9E8086A18388A5858BA4848AA5898EA0878FA08E939E929B9191AD182A6C031F80
0223841233758B9DB799A1A5CDD5D6D2D8DDA6ABB3969EA7B8C0CAC7D2DAA3B2BAB4C4CD
AEBFC883939D95A3ACCBD9E0D3E2E9B8C8D3A5B7C67F92A78EA6C7183E762D558CBBD7F8
C6E0F6C9EAFCBEEBFEA4DFF3AAE5F97FBEE197C9E8DAF0FBEAF0F8F7FAFCFBFCFFFCFEFF
FAFDFFECF2F7E8EFF6E2EBF4E0EAF2E0EAF1DEE8F0DAE6EDD8E4EBDAE4ECD7E3EBD6E4EC
D8E5EDD9E5EBD7E2ECD3E0EAD4E1EAD2E1E8D3E1E8D0DFE7D0DFE9CFDFE8CEDFEBC4DEF1
94C0EB326EB06BA3D6B0D9F647719A7DA5C7ADC9DCB2C7D6AFC1D1B7C9D7C9D9E8B5C7D5
B9CCDBBBCDDDA6B7C8A2B3C6A1B6C49DB6C2AEC5CEC0D1DAABBAC4B0BEC9A8B7C0A6B6BF
A4B3BE94A6B090A1AD8EA0A98C9EA47D9195798F936D82856F83866E8385708587708487
7387877286866C7E82697D8164797D566E706881825A7376637A7B617877667A7B657A7C
66757447473B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00814F18
704B2E6E523E6F54426F514273504476534872534A6D4F4D6E51537153556D52546B5154
694E566B4F5973545D73515A7C55618257678C61718C6471926D79926E7A96737E977580
9C7C86A1838AA2848BA08188A08088A3858D9D858B9E8B909D939E757CA108206D032288
0122812A4882A9BACD9EA5AAB7BCC1B4BAC0A2A8AEA0A8AECDD6DCD4DFE8A5B3BE8C9CA6
AEBEC5C7D4DCB0BCC3C5D2DACCD8E1C0CEDAB4CBE3A5C1DBC8DFF6849BBA93AAC8D5E7F3
EFFEFFE2FDFF88C1E34CA8D86BB9E1C2F0FFD4EFFDE7F5FCEEF4FBF5F9FCF7F9FCF3F6FA
EAEFF5E4EDF4E0EAF2DFE8F1DCE5EEDEE7EFDAE5EDD6E5ECD2E1E9D7E3EBD6E2EAD5E4EB
D5E2EAD5E2E9D6E2EBD4E0EAD1DFE8D2E2E9D1E1E9D1E1E9CCDBE6CFE0EBCEDFEBC7DDF3
6F9ACE1051A53777BBABD6F4AFD1E9AAC9DFB6CFE2C6DBEBBBCFE0A9BFCFC2D3E4A7B9CA
99AABEA1B3C4A0B3C29CAEBBBED1DDA8BCC69EB3BEB4C8D298AAB6A6B6C0A2B1B8A8B6BE
A2B0B998A9B37D8E998699A08EA0A67A8F95798E93768B8F708789708788748B8C768C8F
768B8C788A8B808F946F80866A7E82597072657D7D546C6C62777A61777763777963777A
6375744D52480ECA06
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00865317
6E482A6E503C70524173524774514874514973524C6D4F4D6D4E516D4D516C4E526C4E54
6B4D566A4D586E525D71515B7C55638458698D61708D6471946F7B93727C95767F987B83
997D859D81889F828AA2828BA08088A4858CA3888C9E898F9D95A64F5A89041F75001F87
0425834B689EC9D9EBA7AEB4A2A8ACBFC6C8D1D8DAB3BABFB2BBC3AEB8C2929DA896A2AB
CBD7DCDAE1E5CED5DCCCD6DDD0DDE5D3E2EEA6BED59BB6CBDCEBF5EDF6FBF0FFFFD0F2FF
AEDCF4B8EAFF92CDED7FC7E7ACDFF3EAFFFFE8F3F8E1ECF2E6EFF6E7EEF3E8EDF3E4E9EE
E6ECF1E1EAF0E2EAF2DFE8F0DFE8F1E1EAF1DBE7EED5E5ECD4E5EDD5E4EBD6E3EBD5E4EA
D7E4ECD6E4EBD7E2EBD5E2EBD2E0E9D2E2EAD0DFE8D0DFE8CFDDE8D2E1EBD3E2ECCDDEF0
9EBDE25887BF7EB0E4A2CCE9BFE0F88FB5D692B6D9BED8F09DB2C895ADBFA7BAC9AFBFCF
9DADBDC4D5E2C3D5E19DB1BDC6D7E4B3C4CF95A7B494A5B095A5B095A5AD94A3AB99A6AE
9BA6B094A2AC8696A07A8D94788A937D9199788B92768A9070858B71888C738B8D768F90
788C90788A8D7B8E9273868B6F83885A70745C7275506667677B7D667A7C64777B637678
607272565C551C950D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00657E0F
724B276E4C3873514075504475524875524B70514D6A4D4D684C4E6C4F506C4E526B4D51
694A52674954664B586D505C795764855D6A895F6B8F6670916C7594737B987A82967A84
987B859A7F889E838D9A7E86A2848AA28389A68A8E9F8C939B97AD28387205217F05258D
072A83516DA09DACBC9CA3A8A1A8ABC6CCCFD5DCE0C0C4CBAFB3BDB0B6BED1DAE0CED4DB
CBCFD5DADEE5D4DAE4D9E3E9E4EFF5D9E4EDD8E4F0EFFCFFF7FFFFF2FCFFC4E5F9559DD0
4495C994D1F1CFF4FFDDFBFFDBFAFFCAEBF8D1EAF9DAEBF2E1EBF1E8EEF4ECF1F4F4F6F9
F6F9FBF3F9FBEEF3FAE7EFF7E4EDF6E2EDF3DDE8F1D6E5EDD4E3EBD7E5EDD4E2EAD1E1E9
D4E2EBD4E2E9D4E1EAD5E2EBD3E1EAD1DFE8D1DFE8D0E0E8D1DFE9D2E0EAD4E1EACFDEEA
B4C9DDBCDAFB729DD16696C8B1D9FE35608B5178A3A2BCD6A6BACC9DB1C0B8CAD5CBDCE6
B9CAD6C2D3E0C3D4E39CAEBD9CAEBC9DACB995A6B19CADB69BA9B1909FA593A1A79CA9B1
99A4AD8E9CA4899AA2889BA1798D93667A8172868D788D93677E836E868A748B8C788E91
798E92768C9072888B748B8C72878963787D4D65695D7275667A7B647778647577637676
5D706E5D655E1C9610
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042A809
734A226F4B32734F3C74504275534673524874544F6C4F4E684D4C6C50506A4D50684C51
684C536245506147546549577B5967845F6B86606A8C676F916D7492717993737F9A7C88
9E808C977C87856E79836B76967B84A4868DA4888FA290989090A9112566021D80082A92
0B31885E79A7A2AEBAD0D5D8CACBCFB8B8BFB9BAC2B8BAC1BEC0C6CFD0D5E2E3E8E2E3E9
D4D6DDE1E5EED7DFE8DCE5EDEEF6FCE6ECF3ECF1F9F2FDFFCDE5F6BAD8F3B1DAF96FADD9
8CC6E7D1F7FFEAFFFFE3FCFF96CAE26FB7DAA6D9F2DAF0FBE8F3FAF4FAFEF8FCFFF9FCFF
F5F8FDE9F0F6E3EBF2E0E9F1DBE5EEDCE9F0DAE8EFD5E4EBD3E1EAD7E5ECD2E0E9CFE1EB
D0E1E9D1E1E8D2E0E9D2E0E9D3E0EAD1DEE7D1DFE8CEDDE6D0E0E8D2E1E9D3E1E9D1E0EB
B0C3D69FBCE316478E134B947CA6D28BACCC94AFCCA6BED2CCDEECC3D5E2B6C8D6C9DCE8
B2C4D299ABB99DAEBD96A7B496A7B3BACED5A2B5BEADC0C9BDCCD59FAEB493A0A68D9B9F
909FA48E9EA583979E83979D879AA06F838864797D6B83865F787A738C8E7B9093798E91
738A8D6F898C6D86876E8786708787708689677F816A8081677B7B637675627272647775
596E6B606D64336C20
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0046AA0B
754B1E6C4B2F6F4E3973524078574876564B7454516D4E4E694A4B68494B65484B65484E
684C545D434D644A566C4E5C7D5A6987617187626F8C67728C6A7291727993737E9A7A86
977A868B727E836D798E7985836B769D818CA286919F8D9A797B9E051C67011E8401228D
042A80748CB7AEB2BDD9D6D9D4D0D5BEB8C0C9C3CBDCDAE0DADBE0D5D5DAD9D9E0D8D9E1
E0E3ECE5EAF4D8E1EBDAE2ECE7EDF6EDF2FAEBF3FAD3E5F7749ABD8BB2D3D6EFFFE7FEFF
E3FFFFCFF5FFA8DAF4B7E8FE95D4ED80CDEBA7DBF2D6EDFADFECF4E0EAF2DFE6F0DDE6F1
DBE3EED9E5EDD7E4ECD9E5ECD5E2E9D7E6EDD6E5ECD4E3EAD3E2EAD4E2EAD1E0E8D0E2EA
D0E1E9CFE1E7CEE0E7CDDEE8CCDCE8CCDCE5D0DEE9CFDDE6CCDDE6CFDEE7D2E0E9D3E2EC
B2C4D78BA6C7486FA4406CA48EB0D5BFD8ECBFD9F08EAECBC0DAF0B7CBDD94A7BA95A8B7
9EAEBB99A8B5B8C9D4BFCED998A9B3C2D4DDB1C4D08C9FAB95A7B292A2AA99A8AE9AAAB0
8F9FA682939B85999F7F939A879AA175888F687D81647C7E5973746B8387798E917A8D91
768B8F718A8D6F878969818270888A738B8E6E8487677B7C68797A657676617474667B79
5D72705B6B6346402F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB111
764B1C6E4C316D4D3971503F70534372564A72544E6D504F6A4D4F694B4D684B4E65484E
674A52654A5360444E7254607F5E6B83606E84606F8A65738C6A7491717A94737D957580
9577828E75817F6A767C6A7478646E937D87A58E989E8EA15B629006227801248F022793
0C35889FB7DDBDB9C3CDC0C6CBC0C6CEC8CDD6CFD5E5E0E7DDE0E4D7DCE1D2D4DCD7D9E4
DBDFEAD9DFE9D7DEE6E0E7EFE6ECF5ECF4FCE1EBF4D1E0EFCBE0F4E6FBFFF1FFFFE5F9FF
A8D7F54F9BD2368ECE93D2EFCBF6FDC4F0FCBDE4F9CEE4F4D8E5EED7E4EDD8E4EED5E2EC
D6E3EDD6E3EBD4E2EAD5E3E9D3E4E8D3E4E8D6E5ECD5E3EBD3E1E8D3E1E8D1DFE7D1E2E9
CFE0E8CEE0E7CEE0E8CDDFE7CDDFE8CBDDE7D0DEE7CFDDE6CCDDE7CDDEE8D0DFE8D3E0EA
CDDDEAACC1D4B8D4F0AED4FA86AEDBB2D5F689AACD2E59839EBEDC97AEC39EAFC29EB0BE
CCDBE6B9C9D3BBCDD8CADBE8A5B5C2A7B8C2A6B7C491A2AF8F9FAB92A3AB8799A099ABB2
86959E7C8C947A8B92768A907A8D9671858C677D83647D805D767963797E72858B778B8F
778B90738A8E6D83886C848771878B768A916D80866C7F836A7D7F667978637876637C79
5D73715A6A634C493A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B714
774A196D4A306D4C3971524073584874594D70544A6B504B664C4C64494A66494C684B50
664B526B505871535B77596180616983616B835F6D8864728E6B778F6E78906F7896757F
9776819478846F58656D586486707A826B75A48F98A498AB4C578B072885012796012997
0E3A8DA3BDE2C1BDC7D2C3C8D6CDD0DFDDE0DEDCE1DDDCE1D1D4D9CCD3D7D8DCE3DFE0E9
DDE1EADEE2EAE7EBF0ECF1F7DEE5EECCD6DFD7E0E9DBE3EDE9F2FAEDFDFFD2EDFFBEE1FD
6FAADC2A7EC42781C6A1DCF6D4F6FFB6D9EB82ACCDCCE5F6D6E3EDD4E1E9D5E2EBD4E1E9
D3E1EAD5E2E9D3E0E8D1E0E5D0E1E8D0E2E7D3E2E9D5E2EBD3E1E9D3E2E9D1E0E7CFE0E7
CFE0E8D0E1E8CEDFE7CFE0E7CDDEE6CEE1E8D0DFE8CFDFE7CFE0EACFE0EACDDEE8D2E0EB
D2E2EEB7CCDCB6D3EE5E8CC31C529C7AABDE8CB2D848729B9BBDD9BED7E8BCCFDFA8BECC
CADCEAC5D7E7A9BECFB7CCDCA4B6C39DAFBAABBBC89CADBAA3B4BFB9CCD38B9EA59CAEB5
8E9EA686949D7C8B9383969C7B8E956D8188667E83657E8261797D617679687D806D8287
758A8F6D85896A82866F878B71868B788B9172858B6E8184788C8D667C7A647A78657E7B
5F73745868624C4A3B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A4A16704B306E4C3872533E74584876584C75574C6E524B654B48654B4B674D4E664D50
715B5E8B7579755A617D5D6583636C85636D86606E8864708F6F7991717993727C957680
9879839476817E636D8E6F79A2808A8F727CA08A92ADA3B545548C072B8F022B9F012D9D
0530878DA6CFBCBEC9CDC6CCD8D2D8DEDEE2DADCE1D4D6DBD6D8DCDDE0E4DFE3E7E0E3E7
E3E6EDE4E8EDEBF0F5E9F0F8D8E0E9D7E0E9EAF2FAEEF5FDE4F0FAB2D0EE4B7EB97AB0E1
A3D8F974B0E177B4E7AADBFDBBE4FF76A8D25B93BEC7E5F8D4E3EED8E3EAD5E2EAD4E3EA
D5E2EBD3E2E9D3E2E9D2E1E8D2E1E9D1E2E9D4E3EAD4E1E9D2E1EAD2E2EACFE1E9CEE0E9
CEE1E9CEE2E8CEE1E9CCE1E8CCE1EACCE1EACDDFECCCE0ECCBE0ECCAE1ECC9DFEFC9E1F0
C9E1F3ADCEE793C0E92965B3094CAF5793D7AAD4F7A9D1EFA5CAE5BFE0F8C5E2F9A0BFD9
B3D0EDA7C3E28FADCB9DBBD4A8C3D797B0C3B9CFE2AFC5D69EB4C5AFC8D5899FAB8A9FAA
8FA1AD8EA0A9899BA3889DA17D949871888C667E826B83866B80826981815D7776657E7F
738B8F6F87896F848A71868B72878D758A8D778C91758B8E7287896D817F647A77687E7C
5D71725C6B674C4B3C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
824E15754F2F724F3A72533F75574974564A75564A6F52486B514C684F4E684F525D4A4B
978C8CC0B6BA76636B7C5C68805F6A85646F8A66728C68748F6B75926E7892727B977783
97778393737E8F6E77AA8089B38791B18D97A9919AB3ABBE3A4986062A910431A90434AB
0432927E9CCDC9D1E0D5D4DCCFCCD6D4D4DCCED0D9D1D5DDDCDFE5E1E5E9E0E4E9E7EAF1
E1E8F0DBE5EDD5E0EAD2DDE9D4DFEBD9E3EDD8E2EFD0DEEFD1E2F89EBEE53368A56FA6D9
A9D5F4AED9FA90C0ED2565AF3C7FC87AB4E56C9AC0CBE4F5D4E2ECD3E0E8D3E1E9D3E1EA
D3E0E9D5E2EAD5E2EBD5E2EAD4E2EAD3E1E9D3E1E9D0E0EACADDEACBE0ECCBE2F1C8E4F1
C4E2F3C2E3F4C0E2F3BFE3F7BFE3F9BEE3FABBDFFBB3DDFBAEDAFCA7D6FCA5D4FF9CD0FB
96CDFA79B5EE4E94DC2C7BDD0754C64C96E675B3EC71ACE8649FE268A3E369A3E4457EC4
5187CC5588CB598BCC78A9E38AB7ED6691C68EB5E78CB2DF7096C2769CC181A4C57F9DBC
85A1BD7F9CB3819DAF829EAB809BA7718C95647C84687E836E85886F8A8A6F88896F8789
728A8C758A8D6F83896E868A71858C6C7F85768B90778C8F778A8C728686677E7D677D7D
596D6D5A6965545345
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8B5418754F2B73533C74554473544873544A7354487153486F514B694E4E6850525D4B4E
A0989DBCB7BF7967737B5C697E5E6982626C8664718C68748F6A7493717B94747F987985
987A859E7F8893707AB88B97C695A2B18D98A7929CAEA6BE314281032890012EA60334B0
03359C6789C1C6D1E4DEDDE6CFCCD5D1D1D7D6DADFDBE1E7DCE0E7E0E4ECDADFE7D2D9E2
CCD7E1D4E2EBD5E2EED0DCE8C9D6E0CFDCE5CCDEEF7791AE9FBAD8BDD8F39CBCE284ACD9
90BDE6ADDDFF6296CC0D51A7175CB09DD0F8C1DEF5D1E3ECD6E2EBD6E2EAD8E3EBD9E3EC
D9E2EBD7E2E9D6E4ECD3E4EBD2E5EFCDE5F2C9E6F6C1E5F8BCE5F9B4E5FBA9DEFE9CD8FE
8DD0FB7BC3F473BEF45FAEF056A9F04697E8408EE93586E42D7CDE2572D61D69D11865CF
1561CF115ACD0F54CF0E4FCF0B4ACC0C4AC5124ABE1249BB1044B91348BC1145B91041B5
0E3CB0113EAF0E3CAC0E3CAB0E3AA70B369E0E3A9F103B9C0C3795113E951643951D4695
29539F325DA13D67A34E74A85B81AC567C9F5C7C9864819668869461808A6B89906D888D
738B91758B9071858C728A8E71868B63787D73898D6D8589778C90768C906F84886A7F81
667B7B5F6E6B525047
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
40A60B754D2976533F74534373554972534875544A72514971514D6D514F654D4C5C4A4B
83787FAA9DA8735B6A7D5D697F5E6A8562718965738B677493707B95727E9473809C7C89
A3838FA8869197727FB9909EB7919E957A86AD9EA8AEAFC6283F80062E96012CA40332AD
083CA1799ED4BEC9DDD0CED8D0CFD5D0D2D7D0D4DBD9DDE5D1D5E0C6C9D7D2D7E2DBE1EB
D5DCE7BECAD5C4D1DFC5D1DDBFCBD4CCD9E4CFDEEF93ABC58AA5C0A2BAD1B2CCEC305A96
114B94437DBA94C7F34D84B865A2DCA7DFFFC1E5FDCDE4F0D1E5EED4E6EDD8E7EEDCE8EE
E0EAF1E3EFF5DEF0F6D2F2F9BEECFDA4E2FF86D4FA66C4F552BBF73DB1F42DA7F12098EE
148BEA127FE71B7EEA176DE11A69E21A60DE1E58D92457D4254EC92546C02B46C22D43BF
3446C03944BB3D3CB44037AE4436AC4635A4462F9C4F38A4462E9C49309C4F339F4A2E97
4327934128913D28913927903827943627913328912C278D26268C22268D1F29901A2990
14278E11288D1029900B278908268207287A0D2C76193A7B274C81395E89567A9C6486A0
7291A3728E9B718A93718B90748A8E697F836D85886C86876D8388788D90788D90718A8C
7286896C7A7B545049
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
45A90D764C2673543C74574472554775564A75544874544971514C6F534F664E4A634E4D
6750557258637658657D5D68805F6A8663708964728A677493727D9A78859C7B88A2828E
A98894B08B97AF8A95A4828D9D838CAB99A1BCB1BABABED5314B8A052D96022EA90234B1
0A40AC527ABBB8C5DEBFBFCAD6D7DFD4D8DFC2C5CFC7CAD5C7CCD7C3C9D5CED4DFDDE3EF
CDD4E0AFBAC6AFBDC8D0DDE6C6D0DBAEBAC8BACADAA0B2C79BB4CC9FBDD2C4E0FC436BA0
245A9B477BB0AAD3F3BEE7FE72BCE63598D471C5EFB0E9FEB8E8FBC0ECFCD2F2FDE1FDFF
E3FFFFD5FAFFB4ECFE7ECEF458C0F52EABEF1BA3F00F9CF20C98F80691F50790F90383F4
107FF4286EE55164DA6559CC6F54C4774BB78544AB923D9F9833919C2C86A02A82A02379
A11E72A41E6CA71D67A81A5EAA1A5BAA1856AA1551AB1652A81652A61951A51452A1124B
9F104998114995104A900D49900D4A8F0E498C0F4D8511508212587F175F7816666F1A69
651D6C561E71481F793A1C7D30207F231C791817731217730E1A73091D720723710F2F75
244983416792597A9A67889D6D8A976C868E698288697F84677C80687E81688082718A8E
84989E7D898D524947
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
49AD0C764A1D73543872574173574475564676554770534771534C6E5250634C4B624B4C
684D5275575F7556627D5C6985616D8A616F8D6472946F7D9B78859F7A86A3808CA3838E
A88A92AE8F9AB0909AB99FA7BEACB2CBBDC5C0B6C1B8BAD2425997072E95032FA9012FAD
0333A52D569EACBFDAB9BDC9D5D6E0CFD2DCB5B9C3B2B9C1D5DCE5D8DFE9BFC6D1B5BDC9
B6BEC9BAC5CDAFBDC4D1DFE7CAD7E0A1B1BC9DAEBAC2D5E596B4D0507697C2DDF6BBD3EC
BCDAEBD2F4FFC5EDFDA9E6FF4EB5ED2DB4F335B9F841BAF552BFF669CDF785DCFD78CDF2
59BBF134A4E51F9AE61297E90C96EE0496F00292F2008AF1018BF60089F50086F7067FF5
2A6CE68350BFBD368CD33074D92C68DC2B5EDD2652DC2047E02045DE1B3DDB173AD81539
D20D33D20F2FD00E2BCC132AC61A31BD1B30BB152EBB0F28B81A31BE3148AD1733B10F28
AD1329A9192EA50E28AA0520AF031EAE051CA8071DA2102899132F961333971235931135
9211368C0F37880C3D860C437E0D4675114A6810505A11574A115F3817651F126616166B
0D1A6D081E6E0926701A3D7A345786547392607B8F5F788162797D64797A64797D667E83
8A9CA381888C3E7432
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28D90878491876523774544076564577554777564B74544B71544E6E5350674E4D674D4F
6B4F536F515773535D805D6A855F6D8B6270966C7A9A75829E7B889F7C89A58391A68792
A68A95AC909EAB919FB8A3AEC8B6C0CDBBC5C2B3BFB4AEC64C5D9906278D02279F0126A2
062FA12A529CC4DAF6C4C7D3B7B5C2B0B0BCC3C7CDB3B8BDCED3D9D5D9E3B4B8C4A3AAB3
D0D9DED6DEE4ADB5C0ACB7C3ABBAC6A6BAC6AFC7D3C7E1F2B5D7F09CC5DAD6F9FFCBF0FE
A1DBF37BC6F052ACEE32A3EF28ABF91CA8F60F9CF60D99F30A96E919A7EB2BAFEE24A1E6
1593DE1A96E21B93E21E99E61C9FEC19AAF418AEFA12A9F80DA4F80BA1FB0C9FFE1995FD
5978EABE449DEE2A5AF5233FF41D37F21A2FF01B2CE21320E51523E11220DC0E20D30A1D
CE071DCC071ACA0819BB121EE4737AEE9FA3CD6C789A1C2FCC6473FFC1CAB65D71911D33
E18995EFABB4AB4357A00921AD0416AC05119B0C16DD7F86CF8F99C0838FB97986B06977
A758689D435594273E930D2899042095031D9304218C0727880C327B0C3768093E5F114D
4811553216611F1565101667091A680B246723427641637F5573815F7B7E61797A5E7579
7D8D92787A7B2BA320
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007B4B197451347958447655427755437B5A4C7757507255516F545069504D684F51
6C52567053597958607F5B67885F6D8E6671956F7A9D7B86997B859F818DA28593A48994
A88E99AA929FAF99A6B69FACC2A7B5C3A5B3C3A4B2B8A2BC505491072282032293011F93
0324921C3F8AAAC0DFACB2BEAFAFB7BABBC2D8DCE1C2C9CDAFB3BBB2B8C1C4C9D4B1B5BE
D1D8DED5DCE4B9C4D1B4C6D6C0DBF0B8DFFB86BAE3A0D9FE83C1F274BAEE5EACED3895E9
198BE61C98F90B83EE0576E90277E80885EE087FE70A87E60CA1F313A9EF1CA1E551BEE9
81D9EFAAEDFEB3F1FFAAF4FF87E9FF62DAFE3BC2FA20ADF7109CFA078DFA0782F71175EF
4956CDB42E82E31B3FE61424E20E20DF0D1CD70B19D00915D10918CE0818CB0516C60618
C10114C00314C00516A90B1CE28C98F2CDD3ECC6D085394FAA6176F6D2DDAF798F833750
EFC5D2E8CCD8AD5F79960A26A70215A503108C0D1CE3A8B2DCC8D3DAC9D9E0CADAE0C8D6
E0C7D7DFC5D0E0B4C09033489509209802139304119219238C1F2D7E0E217C0A217E0A26
7B0C2F710B37660D434E0F4D32125916105A0A135C061F5B21436B4D6F845A7680577076
6F81836D6F6D239A15
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007D4E1875533578584376554375564378594A7C5C557658567255536C51516E5456
74585C795C617B5C637F5E688A6573906B7794707B997982997D889A828DA18895A38A98
A68E9BAA92A0AD93A1B394A3BB95A6CAA0AFCCA0AEC39EB94D47820B1F7C021B84021B87
011D8513307894A7C4A7AEB7BBBFC3B6B7BED2D5DCB4B8C0B2B8BFC3CBD3D2DCE5CFD9E6
BECCDEB5CDE5A9CEF19BCCF978B5F2418DE01974DA1375E40F6DE30C5EDB0963E00473EE
017AF30183F90283F90287F7038DF7099EFA20B6FE37C9FB3BCCFC4FD5FF70DFFF91E8FD
9FE5FD96DCF76DBDED48A6EE218EE81382E81077E9106EE61468E5175FDF1E58D92C4FCB
5F41B1A71B68D51136D90C1FD40917D10918C50211C20312C50516C50516C40415C40616
C30415BE0212BD0314B6071BBE4055E3A9B6EDD4DFA7778C935771F2D2E2BA91A582445F
EBCCDBD7B8CB9035589E0928A80115A30211860919D298A6D1BCCE826181935F859B678A
A6799AAD93AAD9C5D495576C860A259003157E0611CE878BD1A6AB7E4F56A86D778B4651
8731447E152C8507258308277309305B0E3F37104C1311520418580D2B5C395977516E7A
5F75785C5F5912CC09
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0082521775523174553F7555427859487C5E51795C53795A56785956755755745758
7A5B607E5F667C5D6582626C8565718C6B7891737D927A8299848C9B88919C87939F8796
A68B99A68C9AAB8D9CB390A0B991A2C79AAACB9BACBE97B3473D7708157001127901177E
041E810F2870828FAEBEC2C9DCDEE2B6B5BDB6B8C1C0C9D3C2D1DFB6CCE1BDDAF9A1C5F0
7FAEE8518DDA2B74D31568D40B63D80461E10262E90267EF0060EB0865EE0470F00684FC
058EFF038FFC0699FF0AA3FF0BA7FF17B3FD22B6FA2BB6F81FAAFA1398F1168BEC1A7FE3
217AE12372DE2165D8235FD62D60DA395CD74951CD5849C16A44B7793FAD82349E933192
AB297EBF1450D20F30D60D1FD70B19D10B16CC0814C70512C80717C60413CA0815C70510
C70512C80614CB0815CB0C1CBE152BC3596CF6CFD9D5B3C386546AF0D1DFC7A4B6864B64
EECEDED1ADC18C2145A50724AD0216A402128A0618C68492D8C2CE876A7F84516C7F465F
743956704860D5BFD199677D830E2C8F03177D0514B98089C3B8BC827F83B6B1B6BDB4B8
CAB2BBA36A7A7A0D228904178A031782041C700A2E3D0D430D105402175B051E5333516D
566D775C605900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF006783157B583172553B70543D785B487A5D4F7C5E547A5C547C5D59795B5A795C5E
7C60657E626782666B81656E8468748B707C90798494808996868D9989939886929D8794
A18996A78E9BAB929FAD8F9CB593A0B6919FBB95A4AE8EA73F376E08156E00117501167D
031A7D11276E8A93B3A5A6B1BEC0CBB3BACCB1C0D9B7D4F895C1F15A91D73070C81359C1
0A54C80453D00356DB0257E0015BE70060ED0165F1036CF70574FA0A82FD0B8EFF0990FF
078EFF0289FC068BFB0286FA068BFB0886F60C77EB0862DA1262DC226CE42A5AD7435BD5
5451CA6246BC7946B5893EA79133999F3092A72986AD287DAC2474A8216FA624729F226F
9E206CAE1D60CC1542D91026E0101DDB0F18D80D17D40915D50A17D30914D40812D50913
D40814D50915D30713D40B18CD0F22B5283AF8BAC6EFD1DC936C7CE9CCD9D4B2C48B536E
EDCEDED0A5BA931F42AE0822B20213AB020F960516C37280E0C6D0D4C7D2D3C5D1D1C0CC
CCBAC7C0B7C1CFC8D5A5768D88133197041B8B0919A2606AC1B8BDAAB5B9AAB5BCAFB8C0
8D8A95AC8B9A6F13298404148C020F8B020F7F0419550C33160D4C04145A011555061D4A
3B5468535B5600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0044AB0D815C3373563A745841795B477D5D4E7F5E527E5E557C5D597D5F5D806164
816367816769826A6D81676D866B748E7581917A8795818D947F8B9A869298838F9F8996
A48D9BA48C9AA58A99A48997A58795AB8C98B493A0B295AD352F6705136D01157B011882
011C831939888DA5D199A8C492ABCE88AEE44E7FCA2763C00F53BF074FC70450CF014ED2
0250D70154DD0155E20158E60562F1066BFA056EFC0673FC0976FC0671F80571F6046CF1
0769F00B69EE1068EB1360E41E5EDE295AD4243BB32A269B4225977437A3923299A62F8C
AE2A82B62C7FAD2876AA2976A9307E9E307E903286873A8E773E966444A15852B34755B8
4155BC634EB1AB2D77E01C3EF11C27EE1A1FEB181DE8141CE6111CE4111AE5111BEA1722
E00F1ADE0F1BDB0C18DA0F1BD50F1FBF1B31E38F9FF2D7E1B097A4E5CBD9DAB7CA95617A
F0CFE1CA94AD9B1C3FB40820B80414B70613AA0A1AAA4052B78294AD8DA0A891A5B09CAF
B5A8BAC7C7D2CEC6D4AD738E890D2D990319930819984C57CBBDC5B6BEC4ADB6C1A9B1BC
AFAEBCB193A3731A3184041788000B88020B8004135D0C301C0F4B04105601115401164B
11274647525200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0048AE10865F367E5D447E5D487F5E4A81614F83635385635883625A836260866667
8568697E6465846D6F887075896F778B747F8F7985967E8D93798A987E8F9A80919C8192
A48A999D82929D8091A18392A88A97B493A0B6909FB495AF35306B061A77041F8A02208F
022493042E904671C23A68B71C57B51456C70445C00344C40145C9014AD30050D90253DC
0659E4055CE9055EEC065FEE065FEF055DEF0259EA055DEA0A59E60D50DB144ED51C46CA
2D42C43C42BD5145BB603BA97D38A0852D8B7313697516667D1A6A9226729C28769C317D
9739868F44918152A06556A45562B24067BF2F6ECD2676D91F7CE01A81E71685ED1588F0
1585F43876E9944CADE12C5CF5202FF11C20EE191EE9161CE7131DE4101CDF0C1ADC0E1A
DA0D19D60915D60917D30B16CF0A1ABE0F24C75E72F5D6E1C5B8C3E0D0DBD4B2C5A4758B
F5D0E5BB77969F1638B00319B50111B50410A70A19CB6A76E2B6C2CAB1BFBDA7B7B39FB0
A294A4C7C2CCCFBACB883C5B960C2B9D01179507189D4D5AD4C2CAC3C5CEADAEBB91909D
AEA5B3946D8078183389051B89010F85010B77010F5A0929230F4807135501125801134E
04163D3C444D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0050B315875B32835E47815E4A815F4B84645286665587655A87655D886965866967
856B6A836C6C86707387707889727D8A73808F77859379899376889C7E8F987989957485
9B79899D7D8C9D7D8CA1818EA98894BB97A3BA90A0BC9BB8403E7C061F8003269501289B
052FA50130A50434A90235B1033EC10141C90145CE0248D0034ED90657E4065CE70659E5
0655E10251DE014FDC064EDD094BD90D45D11340C82240C33337B3472DA065319A74288A
8925808D1F7295237095216B9A25709B317B7A2A784F21763C2D874C53AD455DB5456CBE
5481C97CA2D69AC2DE97CDE48AD8F068D0FB3FBDFF1FACFE0F9FFD0C9BFE098EFB0884FA
0476F81866E96A4ABAC42662E0122CE5121FDD0E19D50914D80B17D50916CD0111CD0613
CA0610CE0812CE0513CE0714CA0617BF0A1EB4384EF5CAD5CFC8D3DBD3DFC4A7BCBA90A7
F3CDE2A55274A51134B10317B30110AF020E9E0A18CE7684DEB7C6D1BECBD2C4D3D3CAD5
D3CAD5D2C8D5E6C5D89B42609E0B29A30216950817994752DBC5CBC2C0C9B5B3C0B9B7C2
C5BFC8AE8D9E7A1C3889051D8A010F83000875020C5E031A380B38120D4909165702124B
021239252D3600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDB0C895B2D836046825F4C83604E8865548C6B5B8A695E8A6A628B6E69866C69
826969826A6C846A73816674856B788E73818A6F7F90738590718391718291707F93707E
9B79879B7E8AA08490A48694AF8E9DB694A5AB8DA5AA9DC23C4A9007298E032CA0022DA7
022DA8002FAD0030B20034B9023BC30646D0054BD60650DA0551DA0450DA044DD80547D3
0842CD0C3EC71237BD1E33B53130AD4A2EA2612A94782583881C72951E68901B5F8E2064
82216579266D682B77583A8E4B4CAA3956B62D68CE1A70D6167EE12598EA47B9F078D9FF
A5F0FFB8F0FFADE6FE7DCBF040A5EE1D95F50886F30281F6027CF60279F6006EF10067F1
015FED0B55DF3834ABA22067D40F31D90B1DD50718CE0411CF0511D20714CE0412CE0915
CC0510CB0410CB0411CC0715C80A17C11523A52939EDBCC8DDD4DFDACDDDBB93ACCA98B0
EDBAD1983959A50F2EB20517B30210AB0410A01D28C275829C7284BDA3B4BAA7B6B6A5B5
B39DB0A6859CBF829E9D2D4EA60A26A704168F0B17C6848BD2C2C9A9A5AFBEBAC8B0AEB9
C8C7D2CAAFC28026458C06208E020F8802087A01066C020E5606223D103B1D1449050F44
05153B1F242E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008A5B28825F4284644E8665528A6956906F5E8F70638F726891766F8C746F
846C6B80656A765B657A606D886E7B876F7C8469788A6C7B8465758867788B65778D6879
9776859C808DA38A97A68F9FA390A69D94B17A7CAE40559D0E3293022C9F012DA8032FAF
0232B40234B70237BC0742C70540C7033DC60340C90442CA0741C8093BC21137BB1B31B1
2A27A344269A5F248D731D7B85196D8A17618A195C871E5F7C2167702E78512D7F34338C
2846A42355B52067CB1872DB1684EA1591F21198FC13A2FF0E99FA1598F61999F6168EF0
1B89EB187DE41478E50E73E8046AEA016AF00168F20169F30060EB0063ED005FEA005EE8
015BE70553DC2E46C08D257BD0133CDA0B1DD90915D90B16D90916DC0C18D90915D60914
D50712D30612D50A17CF0C18C7222AD2565EB76872DDC0C6DFD8E0B8A5B5AC8196B48298
C08BA1C0708AAD2D48B0081CB40210AB0513B84350F6C6CFD8C9D3CEC8D4D1CBD8D4CEDB
D7CEDBC4B4C4D6A6BC9D3350A30822A40513911621D2A0A6D3CAD2C6C5D1C2C1CFC0C4D0
CCCEDAD0B3C987264995062395000E8F010885020772020D550318410728340F36151039
0B163627262D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008D5C2585604086634C8D69558F6C5795725E987A6891776A988177927D78
87727180696B7C626A7C626D7E646F7B616C7F64708062708363728766758F6B788E6B79
9174839A83959588A08D8BAE616DA228428C103592052D9B0430A90130AF0231B20237BB
053CC20234BC0232B70136BA073BBF0737BA0F3ABA1836B4222AA4382295531E87711E7A
84186A8C135E8C12578616587C1B60651D684C287934358D2644A8194EBB125BCD1773E6
0E7BED138CF81495FF078AF71399FD0787F90381FB017BF80275F6016BEE0068EE026DF5
0166EF0166F10164EE0169F10166F10062EC0061ED0064EF0067EE016CF1016FF3006FF1
0476F8036BED235FDB80399DD62155E91627E9131AEB161CE91219EC151AEB151AE40F16
E51019E40F1AE4111DD81620DC525AFDC6CCEDD1D8E0D5DFDCD6E3DFD5E5E3D2E3E2D2E1
E1CFDEF3CCDFBA5772B2102ABC0517B60719BA3249EAA8B9E1CEDBBDB8C7B6ADBEB5ABBB
BDB9C7D1CDDBE4C0D69A3452A60C26A4081892262FD2AAAECAC2CBA29EACBAB4C4BEBFCB
D1CBDCBD8AA8951E44A408239F010F9701088B01097004133C04231C03262A0B2D281633
19192C1F5A1C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00966326875E3E87614E906854916952947059987B6798817296807496807B
877270806A6E7D666E7961697258627359647A5F6B7F626F8564728968768E6E7C8E7383
8A79907A779B4D58901C3685092D8F042D9C032CA1002BA50436B50438BA0438BC063BC2
0438BE022CB00428A70B2BA414289E1F1F90381D85632583801F728E165E941255901351
8015546C1B615221713827812231941740AA1350C00D5DD11070E90C73F20B78F90A79FB
0370F50472F40577F70575F7016CF10069F20168F40063EF0469F5005FEB0061EE0066F2
0067F1026BF2026DF00577F40376F20677F1077EF30883F30788F2068CF4058EF6038EF6
038DF8058DF81C83EF785EC4D7346EF72739FA2328FC2324FB2125F91F22F41A1FF11820
EB121CEE1621EB1521DF1822DB4453FEAEC2F1B2CAE6ABC8E1A7C7E3A8C6E3A8C8DEA7C5
E1A8C7ECA4C5BF4568B70D2BBE0417BD0519B30B26B23B57F1BACFE0C9DDDCCCDFD9CDDF
D7CCDFD8C0D7A961839B1A3CA6071F9C0817AC565EDAC5CBC9CBD2C0C3CDA8A7B5C6C5D2
D7C1D79E4D729F1136A9071DA704119F020A91020D71071D2F08310C0A3D0C09331C122F
271B2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0043AA0E855B368B684F906E56936F558E6C559F8573A994869D8A80917C77
89727182696B775E636E575D765D657258627B606A82666F846772866C7C85728B726A8D
495083152973072584062B980129A00129A3032BA6012AA8022DAD0331B30534B60632B2
0C2EA80D1D921C168335167756166E751564830E51901350911754851E606C2571462376
2E2C861B34991340AE0A47BD0F5ED6106AE60863E70765EA0565E9096CF30162EC005CEA
015DEC005BE60060E90060EA015FEC005EEE0061EF0169F20069F1026FF60374F6057CF4
0981F00F86EC198DEB2294EA2D9DEC38A9F23DB2F443C1F33CC3F533C5F62AC2F928C4FE
1FBDFF12B0FF1B9FFD6682E5C04089F12A46FA222CF91E24F0181EEE151DEA121DE7111E
E20E1DE3101DE20F1FD80C1DD2152FCC254AC82956C22556BE2054BC1F51B81E4FB62050
B41E4EB51A49B61036B80620B90417B80316B5041CAE102EB1375DB04F7AB4628CBD759B
CA85ABB86088981840A60827A60215970614C66F7CDDBDCAC4BAC9CFC9D6C4C0CFC4BECC
B690AA952E53A50C29AD0817AC0610A3030C9203106E0B28270A3F07104E0310460C1136
2C1E2B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004CB112895D308C6B4B9273579E7F659C816BAB9787AD9B92A8989090807C
8975747E6566755B5E795E657457637458647D646E7E67727C6D7C6F6987464A7B142166
031B7003228601259402299F0128A10328A20125A00227A20427A50927A611269E181786
2F11744E1266690D567C0C4A830E467E0E4871135257155F43267E2C339A2043B60F41B8
0A45C1074ACA0851D40553D80455D90559DF0151DE0152DD0256DF0051DA0155DF0054E3
0054E30059E6005FEA0167EE0069F1006DF50174F70384FB0488F8088DF41295F129A4EE
54BDF180D6F1A2E6FAC0F5FFC8FCFFC2FFFFA7F7FF7FE7FC62DDFA32C0F61BB4FA0EA7FB
059CFC0393FB0682F6326FE58A41A1D1275CE51B35E41628E11427DE1328D40E26D2112D
CD102BC8112BC51030C00F31B90E35BB153FB61243B11245AD0F45AB1045A70E44A61043
A30F41A10E3F9F0C379D0B309C082B9F0729A1092B990729950831950B39970E3F971041
9A14429D0E37A4072BA6021CA401159C0317981B36C46F8AAE6D8DB582A1CFAEC7DEC6DA
DFADC7932645A80D26AD0613AD050EA2040C8D0313640F361D0E4F06155D021456061243
251D2E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADB0A895B288E6A47937558A489709E8773A39083A1928AABA09B9C8F8D
8C78787B6263785D5F7D61667B6069785E697765747069804D5278172562031566021A77
021F8402238E01249703269D01259D0121980521990D2297151A8B2D19824D1571711663
7D0B47850C407E0D41680C46511558361C6B2224801128921237AE0639B90D53DA0651DB
0247D30247D2024AD40149D30048D3024BD70048D5004BD9004ED90256E20057E30059E5
005FEA016AF20271F4037EFA0284FB008BFA0397FC0BA7FD1DB6FB3DC9F96BE3FE98F7FF
B4FAFFB7F5FFABEBFD9EE3F883D5F459BEF22DA2ED1497EB0F97F20690F5048FFB0289FC
017FFA0179F90272F81067ED434FC885328DAC2365B11D54AB1F53A522589E225E922062
8E256C81266F822D7D772C7E6A267A6C2D83642B84612B895927875325834F25814B247D
4B227C4A20784F21774A1C6C4D196B4E16644F146053155A5610535F0F516910516F0F4D
770E497F0D428409398C0A328D07288F0625910828900E319011388F163D9B3459C26A8F
B14C70A01737AB0A20AD0612AA040CA0040E87051B520E3C15135B04146403176304154D
1D1F3300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF008A5C228F6B45907355A28A72A692809E8E83A99F99BCB4B2A19494
8771727F65657C63637F686B7D6A72726275585475222A5F06145E02156B021978011B82
02208C011E8F011D91031E94061E930B188A19147E3713715E1164841359900D4689093B
74093B590D4938125D201C75101F870E2E9D0832A70837B30332B50031B80B52DA0552DD
0145D20244D10145D00146D10046D20149D7014CDA0154E3015CE90164F0026DF60272F8
027BFB0484FD058BFC0698FC09A6FF09AAFF0DAEFF12B3FD1DB6FA20B4F62AB5F82DB0F6
2AA2EE2399EA1A92EC168FEC118CF00987F20587F90384FB0180FB017AF9027BFC0174F9
016FF8026AF60366F30360EE115AE42C53CE4249B94848B13E42AA3843AD2C3DAB253DAF
233DB21F3DB41D3EB81A3FB9173DB8163CB8153CBA123ABA133ABD123AB91036B51039B4
1135B10F31AC0E2DA50F2BA10F289C11289812269410218C132088131C81171B811C1D82
221D7E291D782D197233166640155D4C10515A0E47670C4172093A7D0934880D368F1136
9C0F31A50A22AA0619AD0612A8030E98020F800A244714480F156102176A051D6E021757
171D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF009565258F6A419174569A846B9C897C9D8F89BAB4B3BEB8BA948687
846E6E856E6C836F6E7A6C746E697D3C3F690A155402105F01136E021778031B7F001981
001A85031C890518870D16821E12763C0F67620E57820E4A8D0B3F8A0E426F094448094D
250C5D1214730D1F8A062899042FA70732B00126A50029AA0A41C5033CC5074BD6044BD8
003DC9003EC80044CF014BD50254E0015AE8015FEC026AF20575FA0278FB0482FD0688FF
0890FF0794FF0796FE089DFF059BFD0294FC008FFA0494FC0592FA028BF70389F80489F9
0586F90383F9047EFB0279FA0176FA0178FB0277FC0072F90271FB026DF8016BF60169F6
0166F40161EF015AE80159E60258E30756DC0A51D40A4FD0084ACC084ACE0647CA0547CA
0443C80240C40342C60648CB0343C60341C30645C90441C70340C50340C2023DC0023CBD
0137B90235B50131B0022EAA022DA5032DA3022BA001279A04279A01249604269905269A
05249506249508249309218C0C1F85101B7F141A781A177126166832105B470E505F0E46
770D388D0F2E9C0B23A208199F0312920413740B2936134B081562021C70042173021B5F
141F3D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB0128E6437927052957A668773689B8B88B3AAAAAAA1A08F7F7C
8B77718A79768A8189636580202B5E03145801156501146C03167701157A01167B02157A
041475080F6B170A623A0C5B660E537F0C43830B3C760B426013543A105F1D0E6910187C
08208C04239604269D0228A1022AA7032EB00732B40131B5033EC50042CE054ED9034CD8
0044CF014AD40154DF0462EC0469F3026DF80371FA077DFE0683FF0685FF0584FD0380FC
017CFB017AFA027FFC0182FC0280FC007BFA017DFC017CFB017CFC017BFB0176FA0176FA
0276FB0173FB016DF90168F80269F9016AF7046CF90066F30163F00163EE0062ED0163ED
0260EA015AE30157DF0056DC0259DC0255D70354D40252D0034ECE054DCD064BC80447C3
0647C00747BD0645BA0745B80743B30741B00A42B0083FAA0B46B00B46AD0B45AC0B44A9
083EA3093D9F083A9B07369409359207328F07308F072E8D062E8D072D8C052D8E042B8E
032A8F032A9304299202258D01218B02218B021F8B041F890620870A1D800F1C78171A70
2818673C16575C10477A113A890C2A810720650B31280F4D061564021E72032477031F63
181F3F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0C956533916C4C9276608A7467A4938E9B8F8EBBB2B0928682
8F827E8D888E5F6686152763041B6C02187301167301147203167501147404147208106A
160D5C2703424C063A6D0B38750936690B3F470C5127116617197D0A1A85061F8F052296
05249A02209A011E9901209A00209D0127A60231B30039C00347D00251DA075FE90159E4
0259E4045FEA0369F40574FC0678FE0677FE0473FD0275FD0276FB0478FD0174FB0272FB
0270FC016FFB026FFB016CF7016EFA0272FA0375FC0374FC016EF80070F90170FA006EF7
026CF80166F70161F30261F2015FF0005CEA015EEB0261EB0362EA0262E70462E60360E3
055CDC065BD7085BD4085CCE0C5AC80C56C01058BC1357B71454B31A52AD1F54A82358A5
2858A22E5BA1315FA136639E4169A04368994C6A98516F9B4F719C4F709B4D6E9B4D6F98
496B934B6B9248688D46668A47658C43648845638A3F5D843957803656802F5380264B7D
254A801C427D193C7D13337A0C2C7907297906267D03257F042381021F7F021E83042085
0720850D2081161A752A196745165556124449124816105303176802227803287B06276C
1E234100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00758E249069438B6E558F7666917C748E807CC5BCB99F9997
9998A05A64830B205D052074031F7E021B8001177C021476010E6C070F651209562D0A4C
47083B58082B5C09294F07323506431F1061121C7F08239106269C03249B012198011E94
001B93001A94001C9600219B0126A3012DAB0339BC0243C9034ED70258E20766F10769F5
0464F00567F3036BF70471FC026EFB0168F70267F80166F70269F90269F80167F70165F6
0062F40162F40161F20060F10062F10267F20165F20369F40265F20063F00165F20265EF
0062EF0265F10462ED015DE50560E6055EE20860E00962DD0A61D60C60CD105FC71762C2
1E60BB2764B53269B23E6EAC4C73AA587DAA5C7DA45F7FA36582A26D85A26D849E70899D
73899C75899C748B9C748C99778C977C8D97808D967E8D977C8C967D8E987C8D977B8E97
788B957588906B7E87667A826578826A80886C7F886A7C8664768060757D60778159747E
5B75805F79855A7281556B804C637E435D7C3952782C487327437527437E113075062776
04257C02237E0323810826840E237F162176141E70071E7403227D032883042D81092A6B
24264000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002ADC0D94693987694A8E72618A706692817AABA4A1BDBDC9
535F841022600F1C6A0D1A75051B7C041D8302187D0816730E0D5B1F05464107395D0B2F
5A0826430424250231160B500B136C051983032295032AA30128A30126A001259F01249D
02249E0228A5032BAC012DAD0130AF0136B60343C6034CD30758E20459E6045DEB035CEB
015AE8015FED0465F50162F4005EF1015DEF035DED015BEC015BEE025FF00263F40261EF
015EED015CEB015CEA015CEA025EEB015CE6015DE7015EE70260E80160E80464E70766E3
0864DF0963DA0E62D4105ECA1860C42265BF2867B93871B84B79B8547FB06186AE6A8BAC
728FAC7892A77E96A48599A384959F87979F8C99A18B9BA18D9CA28A989D849295899A9B
91A1A390A0A38FA0A58A9B9F8B9B9E86959595A0A2929FA192A0A38E9C9F88979B93A2A5
929FA38E9D9D879496829193808F93899A9B8D9B9D8895988390927B8A8C7C8E90778B8B
768B897E94917F93928294977D909576899072858D6579825C6F7C5A6F8050667E3F5979
2D4A741D3D70113475082F7D082F89072F8F062E91032B8F022A8F012889042C820D2A67
2E263900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00AC814986654289695489706194847AA7A5AD6A779E
142464281B644A1B624316641A106D0A177B0B12731D0B5C39063E52072D5A08274A0528
28012C0E023C080C5A031672021E8503239502279E0127A30128A4032BA7032BAA022BAB
022DAE0230B40135BC0741C70541C4013FC20546CB0248CE0146D0034CD8014CDB024FDD
004FDC0155E20157E70157E80156E7035AE7035CE70157E4035CE9035CE9025BE80159E4
0158E30156E10158E30158E2025BE20560E10661DE055DD50D63D41165D11764C5236ABD
3170BA4379BA5A84BC698BB77590B47B93AE8197AD869BAC8999A88A9BA58D9FA48E9FA3
8F9FA49AA9AB99A7A897A5A49DACAC96A3A49EAAAB97A1A39BA6A99BA7A798A2A2929E9D
9CA8AA9AA7A9A0ADB099A6A898A4A69CA7A8A1AAAC9CA6A8A0A9ABA1AAACA1AAACA4ADAE
A1A9AAA9B2AEA8AEAEA6ADB0A3ACAEA6B0B0A5AFB19DA4A89CA3A59BA4A695A1A297A2A3
8894958D9C9B8A999A93A3A391A1A193A2A394A3A5879798879697879697819294778B90
687D86576F7A4B6376415D7D2343750C3579073489043291022D93022C8C052D7C172A5B
16901A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009DB84C966F4984614B8F7466998C8C6B7390202F6B
2E1C616A17508F0E39870F3E500F54270E61330A56590D44650A2F520628320330190742
06064D020B5E031775021F8600239001299A012AA10129A30128A4012AA9012CAF0233B6
063CC0033BC10139C3013EC60647CA013EC1013ABE013CC0013EC30141C90245CD0246D0
024CD60151DB0354E00455E40256E40153E10154DF0155DD0155DE0154DD0156DD0257DA
0458D80455D30759D40C5DD20F5DCA155FBF2367BA336FB54D7EB6618AB67697B8829CB4
8FA4B696A8B894A4B297A5AEA0ACAEA2AEAFA2ABADA2ABAEA5ACAFA3ADACACB8B5B2C0BB
B4BEC0B2BCBDABB5B6A7B2B0A3ADABA5ADACA8AEADACB2B3B4B8B6BDC2BCBCBFBBC5C9C5
C4CAC9CDD0D1CCCFD2CFD4D7D1D3D6D3D2D4D3D1D4D1D0D2D0CED1D1CFD1D2CDD0CBC8C9
CBC8C8C6C5C3C6C3C4C7C5C8C0BEC1BFC0C2C0BFC3BEBCC0C2BFC2C3C0C3BABBBCBBBABC
B9B9BBB0B5B5ABB1B3B0B7B6AAB1B0A8B0AEA3AAAA9CA4A4959F9F95A0A0949FA08D9D9C
7E9091788D8C718385687C815A727E415D75284A74123C7A073182053285082B6F202748
0CC70A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0035E617B38251856044927A6E80798722295A2E1E5D
6F1E519A0E2DA90617A5091E840731690A41690A3B66093048072F23063D0D0A53071166
02136E021676021D8301228E01279802299F0028A1012DA40130AA0333B30336B90339BB
0138BC043BC1023AC1013AC00240C20341C20338BB0236B80137B7013ABC013CBF003EC3
0248CE0555DA0254DB0150D90151DA0252D90355D90255D50355D20656CF0B58CB0E57C0
1B5FBC2664B9356CBA4B78B55F83B27491B27D96AE8AA0B096A7B3A2B2B6A7B4B6A6B3B2
AFB9B8AEB7B7A9B2B5ACB6B7B4BCB8BCC4BEC0C5C3BFC4C4BDC3C2C2C9C7C9D0CED0D4D4
D8DBDDD2D6D7DBDFDFE1E3E3E8E8E9E9E6E8E3E1E2DFDEDEDBD5D7D2CFCFC4C0C0BFBBBC
B4B0B2ABA4AAA199A298909C9489958F828C887A8384777D82757B82737A837178847276
817374786C6C7A6C70786B70776A6C736969776E70766D6C7E74757E7777837B7B867B7C
867C7D8783828D8988938F8D9996969896959F9D9AA4A49FA5A8A4AEB2B09DA4A397A19F
8D999781908C7E8D8B7788876C80806076785B7178435E702545681136640F2A56292636
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0060C52787603B8F79733C3A562B1D54631A4D
980F2FAC0816B40812AC050F9D021687062662072E3706381406420A105B04156C021775
01157501177B011E880224930025990028A0012CA5083AB10336B00232B40135B90136B9
0133B60134BB0238BE0239BE0138BC023ABB0032B30131B10234B30036B5013BBB013FC1
0248CA0048CC014DD10454D50353D00551C90A54C20F56BA1F60B92E68B44978B3668BB5
7792B3859CB790A2BA95A4B39BA7B1A9B3B99DA6ABA3ACAEACB2B4B5BDBDBCC4C1C0C7C4
C6CBC9CBD0CEC4C7CAC5C8CAD6D8D6DEE1DEE7E9E8ECECEEECEFF1EDEEF0EBECF0E3E2E9
D6D4DCC3C2C9B5B2BEA49FAC9891A08E85918376827F727B7C6E75766A7072666B716566
7164646E64636F6362706564726464716261756563766A62776A6073665C75655D77665E
75675F74675B75675D74675D796B6274675C71685C6F66596D64586D6358695F55665D56
645D53635D51625B50635B52645B56645D596B625E756F6A7A7572817D7A817E7B878582
868883868A828489837A837D71807B687975627370596D6C4C636639535B20333C139313
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0034E515976C427765662A2049541E50921837
AA0917B50A13B1040DB1060FA704137B0423360537120F51020C56021366011A73021C79
01187800177C01208B032999022BA1032CA6022FAB0330AD002CAB012EAF0131B20130B3
022FB50134B90338BC0136BA0135B7043BBA0239B70237B60239B7013CB9013DBC0242C1
0447C5084DC4084FBE0B54BA195DB72F69B2517FB67192B98BA4C09FB3C6A7B6C2AAB6BC
B1BBC0ACB5BAABB4B9ABB1B7ADB4B6B5BDBCB3B9B9BDC5C3C8CDCDD2D4D6DADDDDDFE2E3
ECECF0F2F1F3F3F0F5F2EEF6E9E4ECD9D4DFCCC3D2B3ACBC9F97A8908A99827B8B746F7D
6E6A756E6A716C667065616A67666C6D6B6A706B69776D69796D67776E65787066797167
786F64786F62797063786F63766C61756B5F7A6F647A71627A74627A7260766C5A7B6F5F
7A6D61766D5B776F5D796F5E766D5D756C5B776F5D766E5C786F5E746D5C746E5C6F6A5A
6A67576969576B69586D69586B6555696356645E53615A4F6058505D544D60574E625A50
6763596E6B5F75726676756973756D6F766C676F665D696251625B485F573D504427691D
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00809F425947503D1E4879193EAB1222
B70F15AE0D12A8080EB61017AC08177C06252F0A410C1A66031C7103207B022382012282
012084011E87012391032B9E032CA5032AA70228A60127A50127A6012AAA002FAF0231B4
012FB60335BB0235BB0336BB0035B60136B5023AB70239B6033DB6023FB50743B70A46B2
0D45A52657A54774AD6E93BB8EA9C5A1B5C4AEBCC3BDC5C8BCC1C4BEC3C5C4C7C7C4C9C9
C3C8C7C4C9C8C8CDCFCCD1D0CED2D1D4D9D7E0E4E3EDF0F0F2F2F5F1EFF5E7E5EDD3D0DC
C4BDCCACA3B39B8FA38B8195857B8D857A8B867B8A756F7C74707B74727C6D6E75717476
6F73726F7370696F6E626A6B636A6860685F6B6E63737164797265777160757361777563
76705F797260797260797160796E60776E5F7A6E617971607C7562766E5C7A71607C7361
7A705E78705C756D59736D57756D5B74705776705C726C5A756D5D766F5D76705D716D59
6E6A596E6C5C6C6A5C6C69596D6A596C695A6C66576D6859666154665E506A5E4E655D4C
625C4D5E58495E59495F5E4E6462566A6B5E6B6B5E676A5E5963584E6052465747434A38
12CF0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CA9A6F6243515A1F4990142EB8151C
AA1214CD5B5CBF4C50A8141CB10A179709235B14471C1B6906238202258B02278F022791
02299303289501269503299C0127A001239E00219D0227A30129A5032CA9032DAD012DB1
012FB50132B40031B20131B10133B30133B10236AF063BAC0A3FA513479F315EA55E81B5
8AA3C3AFC0D2BCC9D0C5CFCFC7CDCACCD0CCCED2CCD4D7D3D5D9D7CFD4D1D7DCD9DDE1DE
E1E2E3E4E4E8EDEDF1EDEDF1EBEAEEDCDAE1C5C4CFAEACBA9794A2867D8F766D7E6D6876
746F7C827D8797949DA4A5ABA5A8ADA2A6ACA0A4A9888E91737C7E697677687677667473
667473667473636F71646E6F636C6B5E686060675A65695A6F6F62777767767563787461
76705C78725D776F5F766D5E776D5C756E5B766F5B78715D79725F7A6F607C7062776E5E
797060776F5D766F5D756E5B726B566F6B53736E58736E5A756E5E736D5B746D5C77705F
766E61726B5F70695B6F69596C65556D66566F6A5A6D6B5869675768625169604F6B6450
68645165624E58594755594A494A3F4F504659584D6163546166565861514E57494B5040
37712300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065C836743F42721D399B1120B1191A
A12828F5ACB2DA8B99991928AC0B17A907188B113848185E13217E04278F012693002895
022A9801299801279902279E02269F0225A00226A00127A20127A2012AA5032CAA012CAD
0330B00130AE0031AC0234AB0537A708379F16429A30569A627FAF8CA1C1AFBDD2B9C3CD
C3CACDCCD1CFD1D3CED2D5D0DBDDD9DDDEDBD9DAD5E1E2E0E2E4E4EAEBEDEDECF1E2E0E8
D2CFDBC0BAC9AAA5B5928D9E7D7987706B7867636E66646C6C6C71797A7D8E8F92929699
909498878F907C8687717B7B6B7575687171697271626B6A5B6868596967586867586968
56686956696C56696D586A6C5D6B6C5D68645C665E5D655963665C696C61747264787160
77705C76715B756F5C766F5D726B59756F58756E57746E56746E59776E5D776C5C756D5B
7A725F756E5B746D5B756F5C726B586E6852736D57736E597B7565767061767062746E60
726C5E736D5E716B5C706A596F69566E67556E69566E6C596D68576C6553655F4868654D
676653666857565A4C50554A343A323239323F433A4F5242575A476163515F5E50535645
4D493312CE0800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF006BC82A8E472E8720279E171C9B1E1C
BB6767D097A0BC7B88B5505DA4131FAE0612A4081E7E13463619690D2488032896012597
02279801289A01289A02269C0226A002259F0127A10129A20129A20128A00129A3022DA8
032DA6052FA108329A143D952C5195546EA08798B89DA9BBADB5BEBCBFC6C1C4C6CACACC
CDCDCDD1D1D1D5D6D5D8DBD9DDDDE0E1DFE3D9D5DBD0CAD2BBB4C0A79FAD8F86967A7382
6C6573675F6D66606A63616866686C6E74728087857F8885798380737E796C757267706D
65696765696463675F64695E65675E66675D66655C67665A63645A5D62565A5E53575C55
5058554553544053544457594B5D605160605663605C685E60675B64675A6A685C756E5F
746D5B74705B746F5C777060797060776E5B746D57756F59776F5A78705C77705D79735F
756F5C746D5A726A55756D58746B58726954766D59756F5C767061736E607370616E6B5C
726D60756D5D716A596D68586D69586D68556E67546E68546E67576C67546A664F69654D
6362506B6C5F595A533A403B29342F28342D2D392E3C4535494E3D5254415E5D4B5C5E49
56533C29A31500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C0713A8D210C9D1E17B24E4D
D89EA2D9B5BDE5C0CBE3A2B0951C2CB10D19AD04119C09276E1752281B7509238F012596
01249801249902269A01259A02269D0127A00229A30128A000269A032899022799072D99
10329326408F4B5C97717BA1868BA19B9CA8A5A5ACA7A8ABB0B0B3BDBCBFC7C4C6C9C4C7
D0CBCFCDCACDCAC9CFC1BFC8B0ADB997919D8B808B80707A77666D7063676E6365716968
6D6C696B6E6C6E7474697474677272636F6B626C6B6169675B645F61665E67695F6A6A5F
6C6A5D6F6C5C6E6B5B6B6B596E6B5C736F5F77715F7A72607871617A75657D7464786E5F
746B5F5E5B54464A4439423D444D4A4854534D5C5857655D60695D6B6F62757168706B5F
706B5D6F6C5A746E5D746E5E766D5D756E5B736E58736F59756E57736C54756E5A756D5B
776D5C756F59736D56746C55786D5A7B705E776F5C706957726B5A746D5E7D7768898576
7D75697165567164546E65566E69596F6958716A577069576C65566E68586A645268634F
6B695A6465594D4D48373C37303C342F3E33314034424F414B53445355445354405A5B45
5D59412EA91B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007769079E2D18B8615E
A77278DAB9C2BE9EAAE1B1C0A34051AB101FB20410AC0619940E35511560161B82022192
02249901249B01259B01269B01269B02259D02249C01239803269208298B163286314386
585F8D7672918A8095928895968E94A0999CA09C9FA5A4A7ACABADBBB7BAB9B3B7B3ADB2
A9A1A8978F98837C88706773675D64655A5B75676183736983766A7D766B75736972756E
66706C6472715B6B6C54636457605E58605A5C615960635969695E6F6C5F736D5F726F5E
7877658B8B7AA8A59AC2C1BAD1CFC9D3D1C8D5CFC7CCC1B7BCAEA4B6A79AB2A193AC9888
A18E7F9181767E7466645F515A594E484C424651484E5E5458635A64675F7170687D7B70
767568686655736C5E766F60756C5B736C5A716C56706C56746B56766B57756958756858
756856756A56756D57756F56766E59716956776F5C746C58706956726B58756D5E746D61
7A7064796D5E786B5B776C5C777060726C5C716A5A70695970685B6F695A696454666554
64665B52554D41423B3B3F363842363A4737404E404855494D574D5961545F6251555540
5A573E2FAA1B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002CD506A04924CF8C85
E9BFC4EACCD5E1BECBF9C6D6AF475CAC1022B40512B30512A5071F78134A2B167108218E
02259702279903289C02269A0124970125940324910925861C33803E4B825D5D82746C84
8173828B7984917F8792818892848995898D9790939B959C9B959C958D93867F82767171
675E5C615451675A566E615A74675B7C6E607F71628076677F7A6B727067686C67586361
5162624C5F60495B5D4E59575F60576966586D6A5A6E6C5B7876678782779E9C8FB8BAAD
CBCEC3DCDBD8DDDADFCFCAD5BDB6C2A79FA8998F938D807F84726F7E6C647E685D7B6457
7865557A69587E6F5C80735F7C73616E6D5A4F5446414D434D59545B625B63665D6B6B5F
7C7C72817F74777367756E60786F5D766C58736E56726D55716952726B53756A58776A57
776854756955756A54746952776A57756B57786F5A756E59736B58706956726958746B5D
766B5F776B5D7C6F607A6D5D776F5E766F5F726D5F726E607772666F695D666154636255
5A5C53494C4342463943483B464C3F4853434D594C4E5A514C57525D6860696D635B5C4A
58543C2DAA1A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051AD19D19287
D9ADB4CBA4B1C88DA1B44E68AC1931B60C1AB7050FB7060FB108168C10393C15650A2089
02269501249401259602239203238C0726821B307D40477C635E7C6F62757D6C7A7F7078
84727889757B8E7A809181879085898D83868780857B72776C636364595662574D696050
7368547C6E597B6C597D6E5981725A84735C7F705D786F606D6B5F62655F555E5D485958
3A4F4D394C4849554E5D61556C695A7B78688D8A7BA7A497B3B2AAB4B3ADA7A5A29A9896
908B8F8781889187908A8187897F838881808A8180887F79847C737B7467695F516B5F4E
6C5E4D6C5C46746044755E417562487A725A6B6C5B4851453847404B59545B625B63675A
6E6F627D7E71858578807C6E76705D746E57747058736E55766B55776C53766D57756C55
766A54756953716753766E59776F5C78715E746C59756D5A756C5A746D5A756E5C746C5B
776B5E776D5E786E607E73657971607570607774667474676E6E63656156665D545C5A4E
4E4E424B4B3D4E4F40515445525848525C4B545F50525C52505C545D68616A7168676858
59553C2EAA1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C48370
B5838AECC1CFE19EB0A42132B60D17BB090FBA060ABF0F13AE0B1987123D3B1869091F88
02249201228E04268D072582182E79333F72525271685E6E74636C7D69707F6D727E6E70
807172857578847579817679756D6E6A6462605A5560564D695C4D796954806F5785765B
83765B7F73597E70577E6F5582735683735881715A776C5A686558595D56495350344441
33433C4553475B6354727466888579949187928D838A847C857C797F7976867E7B877F7C
87807C7F7C777F7D777F7E777F807A7A7D7478777271716B686C665C655D525A5350554C
515249514D3C6F6044856B4B7C5F3E7560426C624D686B5B464D443A464049554E556053
6367596A6C5E7070628481728784737C786477715E79705A756951796C547A6E59736B56
756A57736854746C57756E5A78715F776F5B706A54766F59766C5A76705B746E586D6652
756958766E5D756D5F7773617773637471647471667172686B6C6465655D5E5B51555045
5750445653435C5A48595B4B5E61525962535862575561575D675E6168616A6D656B6859
5E563C2CA71300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A96C4D
DBA8A9E0A6B6B54C61B71B27C71314C60E0EBE0A0CB40D1795102E5E19571E1C7907248E
02248B062581122B742E3A6E4746665F56676A5D666D5F62736565786969796E6D7A706D
796F6B756B686D6460675D5763594E695E4D72664F7E6F5686755A88765988755788755A
84745A8072597F70577F6F558474568272537E6E52776A536B63515555483D433940493E
5B64576A6F617274667E7B6F7A736A7A73697B756A7B776B7C776C828175808176797C73
777A72727A707079716B786F65716A646F67676D67656B64616A6359645C565D56545850
4D4F464B4A3C6D624B8671537E5F3F785B3974624477745C6265573F484037433F47544D
5961536367556B6B5D6F6C5D807E70878575817C6A7E7460786C54776B53776C57746D5A
766E5A766B57776D55746B54746C58746C59726A55756E57786D5A746A57716954746C57
796E5C78705E767160797766787468767468726F656D6F666869645A5A535352475B5649
60594A645D4D63604F67675964685D5C655A58635A5C665E5F655F5F645E696B636E6958
63573830A60F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0090A346
D39A97E092A1A62634C1181BCE1613CE1415BC121B95153261225D2423790A2989082A87
0D297724356B424765524C5B5E555A655A5D695C5F6D5E5F716362706661756C6570685F
665E535F5647675B4772634C7D6C518371558472548573558A785A8E7C5E8A76588B7556
87745881725A7F70597E6E558071528273517E6E4F776B4E71694F5D58435855446E6B5C
7774667571627672617972627774667473666E73677A82768C938A838E87717F7B677875
5F716D5C6C685C6B6557645C5A655B5A62556264586765566665546765536A66556B6558
6F685D726B5D84775F806B4D7D5E3B795A3679624174684B75726064675D4047423A453F
4C554B565E4E66685A6F6E5F7374647777667C7A677873607A725D7B715C776C58746C59
746955796C57796B53746A52746C58746D5A736B55776E56786C567C715D7F7463776E5C
7B6F617A72647975677777697674697372676E6D67656862565A5655564E5B584D655F50
6D6656716A5D6F6A5E6D6C6063675F5B635A5F69615F6A625F66605E645D65665C69614D
614E2840B11400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053AF19
C4796B95343EA61D24C41A17D11815C6171E9F1A3865296721257C0B2B8908297B1D326D
3B42634B4956554E516057576057555F5855645C596C625E6E645D6B6456665D4A665B43
6B5D417769497F6F4C847150867051856F508672548773558874568A775686734F88714E
86725383725A7E715B7C6E557D705387795A8374567C6D5074684B695F43766D537E755F
776E5A716853746E5C6A6A5D565E574F605B576D6B667D7B788B8D657B7E526A6F496062
485C5A505C575B5E566163536666536968526B6752706D557E7B648C877397918490897E
7E776C7C73617E6F577A6547796140836B48826B4A7B684873664E7673626A6C63454E46
444C44757B6F74766A6E6D60726F60726F5C706C586E6C57706B57746D5A7B735E807863
7B6F5C75665076634A76684D726951716953706650766B56786D5B82766880776B7A7366
7B73697771667370666B6C6167685F6868625F5F5C545753565B535F62556A675A716D5F
747162797669747367686C60636A63616C64636D67646F65636B6162655B655F516D5C41
76592627DD0D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D5226D6867CBE5051BD2221C31618AF203675336C292E800C2D84122F76293762454554
544C4D5A524D5C554E605852645C55666057686259625C4F645B476A5D4172613F7D6945
826D4B84704F8673528976568873548A73548972538872538B755687735384714E86734F
8673528573578072597F72587C6F547F70548371558270537361437E6D4F8473567B6A4F
796A50726751535041313832293B392E4946355254365359364E562E474D2D4346384945
4C554B5B5E4E656452706F5B7B7B68969684ADAFA0BCC1B5BFC0B8AEAAA59A908D837872
7B6D617B6A557F6B51877558806C4F7D67467A623D785D36745E3A7164497A7A686A7164
4E544B5D5E52706B5E756F5E756C59786D56766C55726A536E63506C614E706551756D58
8277657D6F5B77624874624473664B746952766C587B72617F74677B70647971647B7569
76746974756B72736A64675D575B53555853585B575F625B62655A686B5D6F6F63767669
7A7A6D7476686E71636A71636B74696C756D696F69686F63686B606561526E60486E5429
70932200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
23D003A6593DD47471AF2123B724328D386838348514368A1B336E3D415C50474B544A41
5F554A625A50635B50645D506E65576B634F695E486B5A4275603F79633B806840826A43
886F4D856E4F8573568A795F8373578473558573548B77588B7454887152846F4F887452
84714D83704E837051806F52807052816F50806B4D826D4F7C67498872537E69477C6846
807155655C454443333C413736413931443C2F443C2C403B2A3C392D3E3947534B656C5E
8284769E9F94B5B6ADBFC1B8BABCB7A6ABA58C918C7A7E7B716E6F74706E78716D7E756B
8275668878668B79658E7C63816B50745F3F785F3B795F34775D31705D36756A4E6C6C5A
7070675E5A4E706657756C55766A4F74654776644977664C77664F6B5C46756A53756E56
776E5B7E746082705977664A796C537971597C74607B7362746C5C716B596F67596F685C
6261555D6357575D53535A535159535A6259646B60686F616F766674776A7E7E737E7E73
76776C71746671746973776B72766D6C736A6B6E656A6B5F6C6B5B6A62496F5830678C1F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00807F1CA3321EA31A1BA134565A3C851E378D2036713F404F5B4D435D4D3A5A4D39
605843675E4C6D63536D62516B5F486D5E4075614078603E7A613B7B623A806845866D4C
886F4F87705289755888785B847558847657847655857252867154887356937E61897254
836B4B866E4D866E4C86704E806D4B7D6A4A7E6C4D816F53826D50856D4C7D663E7D6A44
827457787059716C5776705D7E7A69909382A5AA9CB4BAAFCBD2CCD7DCDACED1D0C9CAC7
B7B6B4A6A3A38A85897670706C68686D6E68787A71909389A8A7A29F9E9A84857F727268
716C5E8278678274649485729F907CB5AA9690826D7D6948796137735D30705E366F6446
6C68556A665471665075654775634077633E725D3C6F5A3F77654C76664C6C5F46787158
78725D79725F86776584745E7F705B776B567468536D614D675E49655F48605A485C594C
53574B4C594D525D5656625B5C686366716770776C727A6B797F717B7E757A7D74797B71
757770777A71787A7173766B6E71676F71676D6B616E685A756952735F37658C2000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009F390A91211E8545753B3D8A293A793F3C51594A3966513365503368563C
6F614772654C6E6049706046756345746340786542806B4A806C4A826E4C877352847251
8572538875568C7A5C8A795B87785A8B7C608473558370508670518D76568B7453866D4C
866E4A876F48867046836E44836F47816E4B7F6D4E7F6F5488775B8672508069417F6841
7C694B7B6C527B6D557F715980715B8C7F6D9A8E84ACA3A2BDB6BEB0A8B68F8894777277
7068686D645E786F647B7164756E6167685B929288BABCB2CBC9C4B5B0AC9B968F8F877D
7D73647D715E877A67877D6A8D8677BEBCB69D97958A7E718772547D66417761386F5B37
6C62457B745B70624677613D7B633A78603779603C745E3F6D5B3E76674873654B786E59
8076667D72628172607C6B5375644C71634B6C5F45655B41635E455F5E4A5B5E4F555C52
525F57586962596B656070696B7871737E76787F76787E73797F75797F76797E77767B74
797E78787D76777A707174676F6F63716F626E685974664F7B623A6A922400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ED608883825714C723F3F743B37505341366A53346D5631715A39776344
7766467164446D624277694A7B6A4B7C6C4B7C6C4B7F6F5083735684735784735786775C
89795F88755B8D795C88745593806088755886735486705188705088714C877049886F4A
836945846C43826B42826B41856D437F67417D68467D6D4C8070528A795A877150836B46
8068447D67457A6442755F3C77603F7D67497E6752816B607F6A667B6967766967706C67
82807B7C7B6F827C6B867A667C6E59837A648A816E8E8476968A7F968A7D9488778F8370
887A67827560877864857967857D6F847E77877F7A877C728E7F6A8E7B5E826D4B735B38
726142776A4F7564457C66437C633E79623A8068447A66466C5D3F77694C7667517A6D5C
8173667F71617F6D5977664C7162486A62466961476360486060515D64585F696057665D
59686261716E6A78776B7A7774807C78837B77817A7981797A81797B81797D807B7C7E77
777B7273776D74756B7371656F695C71685478684C7E633672962900FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0076892C6E4F524635424F3930644B2E7259327961397D65407B6643
786746685E3F6E674B766A4F7B6B4D7E6D4C7F6C4A7F6E4E81705484735A86755D82745D
82745B8A795E8B795C8D7A5C8D7A5D85745886745790795A876F4C846D44866E45866B45
846843876B44846B4285684084673E85693E7F663B7661367766408170509380628B7354
8B704F836845826741856A41856941856D44846C448269487E674C7A6A564B493E4B5552
838F8D868C88979589958B778C7C668A7B6491806992826B93836D94866E93846D8C7C65
8B7965897A638778628A7D6B877D6D867E728C82778E81728A7A68837358776343735E37
73613C7464457B6A4E8170537F6E4F806F508473567E7058796D557B6F587D705C7E7564
7E73637E715F7A6B577167516B66516A69566A6A5B666C5F6A716C6A75706B76736F7D79
6C79756D7B7772818072807F74817F79847F7A838178817C7F857F81867F80827B7C7C77
7D7C737B7A6E787569786F617B6B577E664789673650BB1B00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0F653C1B50341E5D412371552F7F633B8269407F67407E6A49
6F6247655E496A665075694F7C69497C67427F68428068447D6744836D4E837057817358
8274598475598B7C628C7C6084735585735585704F866F4C836A4482693F846B41846B45
876D48866E46826A3F836A3D83683B856A3C84693A7D6435775F3278633A846F4D90785C
8E7457917556896C4982663E856942846B41826A3D7F693C7E6943776A4D65685822322B
475654969B9BA8A29F978C80887A6A83725E86735B88775E8C7B648B7C65907E69907E69
8F7D698E816C897E6C857C6C857D708881748B82758B7F6F8B7A677E694E745E3B7C6A43
8776517C69487E6E537F735B817861897F69877E6A817A67827A67857C67857D697E7865
827C6B827D6D817C6E7A7A6C7C7D73757A72747D78707D78747F7A7F8A877F8989818C8D
7F8A897D88857785837383827A8888808C8B80888983888784868380827D7C7D787C7D77
807E787B756A7E72617E6C5084643C6E8F272ADE0F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00653D085B3B13674B227E6337856A407D663F6F5C3C63573D
6F6A585B5C4D6768556C634A7562427A633B7D633A7E623A7E633B7F66427A6748817156
8375597D705484765B87785E8775588771538169487F6841806A40836C42816A41846D47
846D4A826A44836C42856D41826A3C866E40836B3C876A3C8366377D63367D653F7F6A4D
8C775E8772558B7252876F497E643C7C61357C61327B63337B653B73674571715B828A7D
9EA49EEBE9E8AFA6A7877A7094826E9B83699C83649A846494816897826AA08770A28C73
95846F89806E8D86798E8B7F7F7B6F888478847D6F7E72617767517D6C508E7C5D948564
918363807152867860877E6B8A82708C85738B8676878371857B68887D678B826E8C8676
918E8190908492928B8A8B868B8F8D8A8E8F848C8E859191859190899495889294899294
83898B89939284908E7F8E8B808D8A828E8C83898C8285848385827A7C797979747A7871
7A756A7B6F5E7E65488A683650B91B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006B470F67481A7D5F3185693B80683D6959354C422B444030
5052445E64556269586F705C6F674D736344735F3C7A63417C66437D6A497A694B7C6E53
82745B80735986775C857458847154846F50816B467F6A407E6B407F6C44836F48836E4A
86714F856F4A867047886F45866C3E856C3C856B3A866A3A8569398367397C60387A6341
7A6648826F538D7A5B8C77548C724D8164397A5C2C795E2C795F3176643D72684B827D6E
8A878093908C8C827F8B7A68AF9375BC9B7AB99674BA9C7DAE967BAF977EBA9F84B89D84
9B8675877C6F888075857F737C7467756C5C74685482735A9282678F806386765B85775C
887C618E8769978F79938C7C90897A8B8475837E6E898370968E7AA79D8AB1A89AA9A397
A7A49BADACA5ADADA9A0A2A1969A9D9CA0A39A9EA1979EA1939A9D8C9596949E9F919C9D
92989A929B9A8E9797848F8D838E8D7D86867D85827D827D7C7E797777727A766C7E7461
7C6B4C846A3B72942700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0020D404704B157D5C2C89683884683B70613A59553A494839424438
3E4539445042576355656F626F7263706C5B746A55776B53786C517B6F557B6F567B6E56
7E705980735B82755A837157826D50816E4D806C46816B43867049866F4D846F4D857250
85735086714E89734E876D44866B3E84693B886D3F85693B896C3F85673A84683C7E663D
7B67407F6D4881714F8272518C77578F775181673C7E62347B613278633772613E766A52
80796A7F7C70847C6D9B8970C8A88AC8A485C7A489C2A68DB6A08AB09985B09682A98F7A
8D78677F70618174647C705B80715A83745B887D61887F648379628279618B806A958C76
99947C9390788C8777847D718B877A999789B0B0A2BEBFB1BDBDB0BBB8ADC2BCB5BFB9B5
B5B4B0BABAB8B5B5B5AEB2B2ADB1B4A4A8ABA7A8ADA1A5A8A4A8AB9CA4A7969FA399A4A6
97A0A28E989886908F838C8A7F87867D8383797E7A7B7D777C7A737C75667E6D5382683B
6F95272ADF0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA5067C531C89673388693B7A643E6A6248595C4B50574C4A5248
444E443F4B3E455245525D54676F6774776E7672687974647A776278745E76705B776E59
7B735D7A6F5A7E715B7F7057827055826F517D6A487F6B47856E4D856E4F8A76568C7859
88755387755387735287714C876F46866F44836C41876F44866D43876E45836B43836C44
836D4784714F8474538070518675589686679786648B78538470487C693E75623971613D
74654B776D567066507A6950987F669C816999816C94806D8574647F705E86736185735F
8373608779648578637F755E827861857C678C847096927E9C99859D9A8495907F8D8D7B
979985A0A591ACB1A4C0C3BBC5C7C3C8C9C5C8CCC7C2C6C1C5C7C4C3C3C1C4C3C2C7C5C4
C2C2C2BDBFC0B4B9BBAFB6B6ACB6B5ADB4B4B2B7BAA7ACB0ABAFB4A3ACAE979FA4919A9D
8B9396848D8E8088867C868078807E787C7978766F7E76677D6C558266426F942D28DE0E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA504875C218E6B3783683D72664868685660685C5C675D536056
535F554E5A4E49554948534A4D585260696380877F898F847B8173737668757466726E5E
75725F7B75627D745F796F5A776D567C6F567F715583725686735789775A8A785C87765A
87765A8574598574588675578674538876548877548979568979578979588B7C5D8C7F5F
8E7E618E7E628C7C6089795D85755B86775D8F80689589709B8F739A8F6F9488648E7F5B
9080608275567F7558807659887A608E7E6693836F95897598907DA59E88B6AC97BBB19C
B7AC98B2A994B1A997AEA898A8A394A19E919D9B8EA1A393ACAE9EBBBFAFC9CBC0D7DDD1
E0E7DCE0E7DDD7DDDACCD1D0CDD2D5C6CDCEC3CCCCBFC7C6C5CACCC3C6C8C7C9CCC3C5C8
C3C6C8BDC1C2BEC3C3BDC4C4BBC4C4B8BFC2ADB4B8A7AEB4A1A6AC969CA28E94998C9095
868A8E8183867878787579747979727972657A674E85673F7596302BDF1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0043A80593692A8E6D3A78633D79745E6B6F63687167657366606E63
616E645C695D55635655615855605956615C5A656263706C87948D8A938D7A7F78777B6F
797B6D8080707B79697A78667E7C69807B67867E68867D688A80698D836B8A80688E836A
8D846D8B836C8A836A8B83698E866B8E866C91896F90886D8C84698F876D938B71918B71
958E75988E769A8C7695887091846D8A7D67867863847961837860867E648A83698E876C
938A6F958E7299947B9C97809D9780A09783A49C8BA4A08CA2A18FA9A696B2ADA1BAB4AB
BFB7AFB8B1A8C1BEB6CFCFC8DDDDD7E9EAE3F2F3EDF9FBF6FCFDF9F6F8F4ECEFECE8EDEC
DFE6E6D9DFE0D3D7DBD2D4D9CCD0D4C6CFD1C5CED0C5CDCFC3CBCEC7D0D1D1D8DACED2D6
CBCED3C6CACEC6CECEB9C3C4B2BCBEABB6B9A4ADB19AA3A8979EA195999D8B8E92898A8E
8180837D78797F746E7B6D5C78634688693E4AB71D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AAF09956A2982613279674A82817170756E6A746C69766C6B796F
6D797069766D68746C68746F6A767163716C61706D60716E6471706A7674707C77858E88
8C948C8D938B888B82858A7E8B8F838C8D808889798786758785738987748A89778E8B7A
9591809493809595819A9A849D9B849B9884979681928F7A8D8A7289856D918C75939079
9B98819A978296907D9A947F9E98849F9B86A19D889F9B849E9B84A29F8498957B98967C
99937D98947E9A96819E9D89A3A38FB1B09FC3C1B4CDD0BFDEE0D3EBEBE2F5F5F0FAFAF8
FFFCFCFFFDFDFFFDFDFEFEFDFEFEFDFEFEFCFEFEFDFEFEFEFEFEFEF7F8FAEAEDEEE9ECEE
E0E4E6E3E8E8E0E2E5E2E3E6E2E4E6E1E7E8E1E7E7E3E8E8DEE3E6D5DCDFD7DEE1D1D8DE
CACED6BDC3C9BCC3C7B3BBBDACB3B8A3AEB1A0A8AA99A2A4969C9F8F9293858382807975
7C6F667968528265426D922E54BE2100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0029DA079C6C298564347F71537B7E6F7A857C6F7D766A79706A7972
717E7775807C767F7D7882817986847686847181807C8B8A7C87877C87837B8784778582
7C89867E8B8986928E97A29C9DA6A09EA49CA3A89FA6A99EAAAC9F9B9F929AA0939A9D92
9EA0959DA0929FA594B4B9A7C2C4B6BEC0B3BBBFB2BCBFB1B7B9A8B3B6A5ADAF9FB5B8A8
B9BDAEC2C5B6BCBEAFC1C3B4B9BAAAB7B7A7BEBFB0B9BCABBFC4B1C6CBB6C8CAB8CDCFBD
D5D4C8DFE0D3E9E8DEEEF0E5F4F5EDFDFEF8FEFEFAFDFFFBFEFFFBFEFEFCFEFEFDFEFEFC
FEFEFEFEFEFEFFFFFFFEFEFEFEFDFDFEFEFCFDFFFEFCFEFDFEFEFEFDFDFDFAFAFAFBFCFC
FCFDFDFDFEFEFEFEFEFEFEFEFDFEFDF8F9FBEEF0F3EBECF0E2E5EBDADDE2D3D6DDC8CFD5
C2C9D0BBC2C7B4B9BDACB1B7A9ADB2A2A8AB9FA3A69598998F8C8C857D767969587B6143
916D3F4EBA202BDF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF009E671F845F2C7D7151777B6A758076717E7874817D727F7D
7681807882827A8385818B8C838E8F8996968593938894958995968E9B99919D9B8B9996
92A1A091A1A28F9E9F9AA8A8A7B3B3AEB9B8B9C3C1C5CEC9CED4CEDCE3DBDAE0D8E1E6E0
E0E4DDD7DCD3D2DACFC9D2C7C6CEC5C4C9C4C3CCC5C7D0C9C6CEC5C5CCC3C7CEC5CAD1CA
CBD1C9D1D8CFD3D9D1D9DED6E0E3DAE2E6DDE7ECE5ECF1E9F2F5F0F6F9F1FBFCF5FDFEF9
FDFEFAFDFEFAFEFEFDFDFEFAFDFDFCFEFEFEFDFDFDFDFEFEFEFDFDFEFEFEFEFDFEFDFDFD
FEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFFFEFE
FEFEFFFEFEFEFDFEFEFEFEFCFBFBFBF5F5F8EBECF0E3E7EADEE1E7D7DADFD2D3D8C8CDD0
C1C6CABABEC1B6B8BCABADB1A5A7A9A3A3A296928C83796B79644C8B6D444BB8202CE011
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DB098F64287A63407F7D6B78817772807775857E778782
7B8987838F8F828D8C8A94938D98988E9B9C8D9C9C909E9E92A0A097A5A499A7A49FABAB
A0AEAF9BAAAE96A5A8A5B2B4B6C1C3B9C4C5C2CCCBCBD4D4CFD8D7DBE3E0DDE3E1E3E9E9
E5EBEAE8EFEBE7EEEBE3ECE9E6EDECE4ECE9E3ECE9E7F1EEE8F3EFE7F1ECE5ECE9EBF1F0
ECF1F1F4F9F6F0F4F4F2F6F4F5FAF9F3F5F3FAFCFCFBFDFBFEFEFEFEFEFDFFFDFDFEFEFD
FFFFFDFFFFFFFEFEFEFEFEFEFDFEFDFEFEFEFEFEFEFEFEFEFDFEFEFEFEFDFFFFFFFEFEFD
FEFEFEFDFDFDFFFDFEFDFDFDFBFBFBF8F8F8F9F9F9FAFAFAFBFBFBFCFCFCFEFEFEFFFFFF
FEFEFEFEFEFEFDFEFEF9FBFBF1F2F4EDF0F1E8ECEDE3E7E9E2E5E8DCDFE1D4D5D8CBD1D3
C2C6C9C3C4C5B9B4B49D9692877A6D846F578E6F49779A3558C12500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00748F1B8361307C6C527677686F7A6F79887E788881
7F8F8984939085929294A0A095A0A198A5A595A4A49AAAA99BAAA9A2AFADA6B1B0A9B3B4
ABB6B89DA9AB99A5A8A1ADAFB0BCBCBFCACAC6D1D1D1DCDDDCE6E6E0E8E9E2E8E9DFE8E7
E3ECEBE9F0F0E6EDEEEBF1F3E9EFF0E8EDEFECF1F3EDF3F4EBF4F3E9F1F3E9EFF1EDF3F4
F1F5F7F2F6F7F3F5F7F4F8F8F6F9FAF5F8F7F8F9FBF7FAFAF9F9FBFAFBFCFBFCFDFCFFFF
FBFBFCFAFCFCFBFCFDF9F9FAF9F9FBF9F9FAFAFAFCF7F8FAF8F8FAF9FAFCF6F7F9F5F6F8
F4F4F6F1F3F2F4F4F4F4F4F6F3F4F6F7F9F8F8F8F8FBFBF9FCFCFCFDFDFDFDFDFDFAFAFA
F9F9F9F7F8F8F5F6F8F2F3F5ECEDEFEDF0F1E9ECEDE7ECEDE1E6E8DFE0E1D7D2D6C6C0C2
ACA2A195847993775E9A764C4DBB242BE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00718D1E816135786C537A7D6D7D857C7A847F
828E8884938F8696948F9E9E98A6A69EACAC98A7A6A5B3B4AFBABCAEB9BBAFBABBBBC6C6
BFC9CABFC9CABAC5C2C0C9C9C6CFD0CDD7D8D6E0E2E2EBEDE5EDEFECF1F5E7ECF0E7EEF0
E4EEEFE7F1F3E6EEF2E5ECF1E7EFF2E8EFF3E9EEF3E5ECEEE8F1F3E5EEF1E5EDF0E5EEF0
E6EEF1E1E9EBE6EDF0E2EBEDE5ECEFE6ECEEE6E8ECE8ECEFEAEEF2E7ECEFECF0F4E4E8EC
DFE4E7E1E6E9E2E6EAE6E8EDE0E0E4E6E8ECE6E9ECE8ECEFEAEEF1EEF3F3F0F3F5F2F3F5
F9F9FBF7F7F7FAFAFAF5F5F5F9F9F9FCFCFEF5F5F5F8F8F8F6F6F6F7F7F7F6F6F8F7F7F9
F7F6F8F3F4F4F2F5F4F5F6F6F2F1F3F0EDF0F1EEF0E0DADDCDC7C5B5A8A1A1887E9A7A65
A47C5955C02B2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00708D1C8161337F71557D7C6B7F837A
8790898996928998968B999993A1A297A6A79AA8A9A5B0B3ABB5B9B4C0C3B6C4C6C6D0D3
C7CFD2C7CFD2C6CFD0C3CDCEC3CDCFC2CDCFC6D0D2C9D3D6CAD4D9CBD4DAC9D0D8CAD3DA
C8D5D9CAD7DDCCD7DDCED8DED0D9DECED7DCD1D9DCD1DCDED2DDE1D1DBE0D5DEE3D3DDE2
D0DCDDCFDADCD1DBDDD3DDDFD3DDDFD8DFE2D9DDE0DEE1E6D9DEE2D7DDE1E0E2E7E0E2E7
DAE0E3DDE5E7DCE1E4E2E7EAE3E7E9E4EAEAE6EBEEEBF0F3EAEFF2EFF5F5F2F6F7F3F4F6
F5F5F7F5F6F8F3F4F6F0F1F3F2F3F5F4F5F7F2F2F4F4F5F7F5F6F8F5F5F5F5F5F7F8F7FA
F8F7FAF8F5F6F7F2F3EFE6E8DCCED2C3B1B1B19A94A58778A9856684A5465BC32D30E215
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D90B88612B81674481755F
87847A8D938E7D8683848F8D8D9A9998A5A39EA9A8A2ACAD97A2A4B1BFC1B1BCC2B7C1C8
BEC8CBC0C9CDC4CCD1C1CBCEC1CCCFBFCACDC4D2D3C5D3D5BDCBCEC5D0D4C5CDD2C8CFD4
C6CFD4C5CFD5C6CFD4C5CFD2C6D0D1C1CBCCC7D2D3C9D5D5C9D6D7D0DADCD2DADDCDD7D8
D2DCDDD0DADBD5DDE0D7DFE1DBE3E5DEE4E7DCE1E4E0E5E9E1E6EAD9E0E2DFE3E6DEE3E6
DCE3E6DDE7E8E2E9E8E2E7E8E2E6E9E3E7E8E6EBECE8EEEEE8ECEFEAECF0ECEDF1EDEEF0
F0F1F3EEF1F0EDEEF0EBEDEFF2F3F5F4F4F6F3F3F5F8F9F8F6F5F6FCF7F9F8F1F3EBE1E4
D6CAC9C5B1ABB69A8FAC8879B3866EB889615DC53230E31700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B112876431
806C4C89806C8584767E8279858C8698A19C9FA8A5A2ABABA6B0B2ADB8BAADB8BBAFBABD
B3BEC0B6BFC2BBC5C9B5BFC3B7C1C4BDC7C9C3CED0C4CFD2C2CDD1C3CED2C5D0D2C9D2D4
C7D0D2CAD3D7C4D0D2C5D1D2CBD5D7C3CDCEC5CFD0CAD7D7CAD8D9CDD9DAD0D9DBCDD5D8
CCD5D8CCD5D8D0D6DAD2D7DAD2DADCD7DCE0D8DDE0D7DCDFD7DCDFD6DEDDDADEE1DBE1E3
D9E2E3D7E0DFDBE1E1DBE1E1DBE0E3E1E5E8E0E3E6E4E7E9E5E8EBE9EAEEE9EAECEDEEF0
EEEEF0EDEFF0F6F5F8F8F5F6FAF6F8F6F0F0EBE2E3DCCFCDCCBAB7BCA39AB69385B38A74
BA8D688FAB4A5FC52E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB517906B35866C4487785A897F6B918C7D9A9A90A4A49FA9ABA9A9AFB0B0B9B8ACB6B5
B2BCBCB1BCBBB6C1C2B7C5C6B3BFC0B9C4C5B9C4C6BCC6CABFC8CDC0CACDC4CDD0C1C9CE
C2CCCEC0CCCFBFCDD0BFCBCDC4CED0C0C9CBBDC6C9BEC8CABFCBCCC0CDCEC5CFD0C5CED0
C8D0D2C7CFD1C9D1D3C7CFD1CCD4D6CCD4D6D0D6D8D1D8DBD4D8DBD7D9DCDADBDCD7DAD9
D4D9D9D4DAD7D8DDDCD7DEDDD6D8DBD8D7DBDAD8DCDFDDDFE7E4E8EEEBEDF0EDEDF3EEED
EBE2E0DFD4D0D3C1BDC8B0A8C0A397B29380B59075B78D688BA9485EC63031E31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADF0E48B518906C358C6E448A7152907C66998A7BA79F93B0AEA4ACADA7
B0B3AEB4B9B5BCC1BFBAC1C0B3BCBBB3BBBBB6BCBDBFC5C7BEC6C8C3CBCDC1C7C9C0C4C6
C5CDCDBEC9CABBC8C8BDC8C8BEC8C8C0C8CABDC3C7BCC3C6BDC6C8C2CBCBC6CFCEC7CECE
C7CDD0C7CED1C9CDCFC9D1D0CDD2D4D1D6D5D1D4D3D4D8D7D6D8D8D7D8D9DADAD9DEDEDB
DFDEDCDCDBD7DFDCD8DEDAD7DFD6D4DACFCAD0C1BCC6B5B0C5B1AABCA498B29888B39582
B28D72B68C668BA9495EC73162C93031E31600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002BDF0F4DB61C47B31E95724390754F8C755A
907E689787759F9082AA9E94B3AAA1BCB4AEBBB4AFC4BEB9C0BDB9C9C6C6C8C4C4CBC8C6
CCCAC8C4C6C3C6C9C5C8CCC8CCCECBC6C9C7C4C5C6C6C4C5C9C7C6C9C7C5CCC9C7D1CFCD
D1CFCED8D4D4D7D2D1D5D1CDD2CFCBD5D2CCD7CECAD7CDC7CABFB7C4B9AFBFB1A9BAA89F
B8A195AE9584AA8E78A98C70AC8A6BB18B67B5885E88A7465DC6325FC82F61C82C31E416
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
56BF234FBA204AB61F47B4219D754A98754F95745293765695785F987B669C816D9F8470
A28977A08978A48E7BA48E7AA4907DA69280A5917FA8917FAA927EA78E7AA68D7AA38876
A38774A48771A98971A7866BA48568A0805FA3815FAB8660AE875981A33F55C02C59C32D
5EC62E2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 181.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000]B000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooolP003o000@00[f0`0W
f``09]/<05F^6P1bTR<0Li8T07NC901eTbH0VG8g09]d>`2JMCd0LiP`07JJ<P1hVc<0IJd^03g?7080
:MlC00D0:=hA01oV3000o`002_L401C^1`0Q003o0?oooooo;oooool000[ooooo7000o`00800VfP/0
QGdY09I[<02FKc<0Ug4h09M_>P2FKSX0V70l09mb@P2UMT80/7U80;EkCP2fOU<0]hAL0;Z3F`2kQEh0
/hML0;::H02bRF40/HQN0:n7GP2]QU`0ZH9D0:ImC02RNdX0WGY409ij@P1fVc40CK`N04bj701;^1/0
C[TL7000o`3ooooooboooooo000:oooooaD00?l002`05>d602KJ2`0VfP/0;=4>06FK8P1_TRL0L9L]
09Uf@P2LMTL0WgU=0:9jC`2PLD/0W6A409IF?02GCCH0YTLb0;Ho:@2j=R80^blN0;X[7P3?DTL0/R/L
0:lT5@2P;a`0VTHc07dZ6`25;b40S3DX090m;02A@Rd0TTPa0:U]E02PK4d0XWAD09mcC`2YO5@0XgmB
09mlC02KMdD0Vg@m08N5=01cUR/0@l4H01gT2QL00?l0JOoooolS003o000C02kQ4P0^h140;N0A05c1
8`1L`BD0S:@h09VM>P2mR4X0_8Q;0;f6C@2mQd`0^HE;0:f=AP2;XcH0RZ@f08^U=`2;YCP0RZHh04KB
7@0202oR4`0301Sa2P00o`000?l001h00?l0K?ooool000[ooooo4`00o`00<P0]d@`0FZ8J08mX<@2>
Jc@0TVlj09UfAP2KM4X0UVM308]H=`23@bT0PRhK07/M3P1l5@T0P@d708@81`2920T0S@L:08l5202M
1`P0/`h;0<PD403E5140e1D@0=<D3P3A50d0dAH?0;dC3`2U3@`0WQ/L09TR8`2;20X0T0X:08X82P2R
>C/0SB/Z0:Q=C01d4@`0RBHO07LP5027@c00aIf90;^RRP2[TG80XHIO0:21DP2JMSl0Nhh`06jB9@1D
[AX02_H34`00o`1Yoooooal00?l001D0@m0J06b]:@2]OT40[7e10:im@`2cOdH0/h550;:1B02ePDd0
/Wm;0;N0A`2hPDP0]X9<0;EoBP2hPdd0/gm:0;B2B`2fPTP0/h150;5n@P2aOdD00P2^O4<01`2ZN3X0
/7i00:mm?`2bPT@0/8=606ja;@0Fl0T07000o`1/ooooo`002_ooool@003o000g00Wf0`17]1<0NWTT
08YY<P2AKCl0TfE408MA=@1k?BH0Kb0A06X>1@1/1`80L0H307P30`2410@0RPD308l5102G1@H0V@D7
09h51`2Q1PX0W0H809L62@2G1`/0W`P;0;L?3`3B5a<0gQPD0>8K4`3P6140gaXB0=XG3`365Q00[B4O
09HH5P2Z7al0W@X<09/62@2G20L0U1/B0<ejJP259al0Vbh]09T/;02JCTT0d;Vc0<c3^`3Aak/0_:jK
0;BOQ@2/Tg00XHEM09emC02DL3D0H9HJ02?H1`0A003o06Wooooo6@00o`002`1=aah0E[dQ086L<P20
WSD0SIDk0;5nB`2cPD/0]hAB0;Z4E@2oQUL0b8IK0080chMO01`0dH=J0==oF`3EOU/0f7QG0=UfEP3F
M5@0eG=C0=IeE`3EMUT0eGYK0=9mF`3<OET0`GmI0;N3GP2eQUh0/XEH0:aoCP2^P4h0[Gi;0:Eh@@2U
Mcd0YgHk09eo=P1lUbX0OYX[08ZC;`1E_1/05^l75`00o`1/ooooo`002_ooool?003o000i01;/1028
Hb80RfXi09=]A@2JK4`0OCXW06`A201b2@D0M@H307T4101l0P<0O08407/11@250PL0S`@609<4102H
1PL0X0H80:X9302X1PP0[@P:0:T82`2U20`0WPH;09l:302S30`0/`l=0=0H5@3T71H0hB@L0>8l<`3N
6a40hQTA0=l`;02_7A`0VP@50:@82`2X2@T0X`L709TA3037JEd0Q1/D07h31@1k20H0[UA;0:MhK`3?
_kT0_k^d0<_6`P3:`kd0dlRm0<2dYP2iZ9D0X8Y[09IiB@2>JBl0=/L>01000?l0JOoooolE003o000_
00_g1019a1h0OYTa09io?P2aNdT0^GeC0<=nF039NEL0cFY=0=5PB@3EF480fDXk0=Q1<@3G=bP0fbhS
0=dZ7`3N9a/0hBDG0=hR4`3Q81D0hQdE0><N603T7aH0hadC0>@N503R7A@0gQ`C0=/M503D7A@0[18=
08XA402:61<0S24I08d]902A>Rh0U4Lg09QI@P2PJ4d0ZGIE0:YnE02VND`0YWU40:9d=`2SLS<0YG<c
06nN7`0Xg0/05@00o`1/ooooo`002_ooool=003o000m02_>201DWQH0PG4/08aS?@1oAC00M2HJ06lB
2P1g1`H0Q0H808L41@2610@0Q`@308l51`2=0`L0R`8709431P2L1@L0W`D60:<7202Y1`T0Z`L:0:d8
2@2a2@T0/PX;0:P72`2W2@`0[0`?0:`@3`2X3`/0/Ph;0<LI4P3OCTD0hUIA0>4R5P3V71<0hadF0=HM
602m4a80Y`d=09h92P2R2@T0W0P709`>3P2E2PL0R@<407T20`1j3P`0LQLC0;F4P@3Hc<X0c/g;0;ji
]P2n]k00][6Y0<G1^`3:`k`0_[2Q0:nKP02KPEP0GZPY00Wf100>003o06Wooooo4P00o`00<`0EkPP0
Dk/P07VI<P2SMTH0[gQ>0;]fD`37M5D0c6170<<l;@36:Ad0c20E0=DI4P3J5a80hAPC0>HH403Y6Q80
jATB0>`K4P3_7140lR0C0?0N4`3a7a80m20D0?DP5@3e7aH0lQhC0?DP503d81<0m1lC0?8M4P3`7140
jA`B0;d81`2T0PD0YP@809l31`2I0`P0T08608h52P1o1@P0MPL:06l=3@1g91h0Qd<f0:5ZD@2YNeH0
YgI809m_=`2JJBh0VVTV04nf4@0D003o06cooooo000:ooooo`/00?l00440<;l207AS4`24Gbl0OD`/
074_701Y4@P0L`L807`42@1n0`H0P@<308T3102<1080S@D30984102I1@H0V`D609T51P2M1PH0YPP9
0:X92P2Z1`T0Z`L80:h92@2c2P/0/`/:0;4;2P2]2`X0Z``;0:/>3P2Z40h0[Q8>0:lD402W6Q@0hjBL
0;YdJ`2M91`0Sa`D07TG401Y50l0Ga<=05@B3P1E3`d0J0l>07X?402H7Ah0VP/<09/7202<10<0P`82
08<51@236AT0c9>B0<o0_@36aL00e<o90;bf/@3=b/L0bl[80<6o_03=blP0c<S20;^^V`2BSE/0Ej@Z
01;]200<003o06Wooooo4000o`004`0;m`D0?/dJ07nK=P2bNU<0]fm?0;]K@P30?c00`bdS0<PO5`3?
5@l0ea8?0=hC3P3R4`l0iAHA0>DD403V5Q40jQTA0>`J4P3a7AD00P3b7Q<08`3f8QH0lb4E0?@Q503i
91T0o2HJ0?TT6@3k9QP0nBDE0?TS4`3g8A<0mR4C0?@O4P3/7A@0`@L70;H72@2c1PT0[0870:L32@2S
0PP0X08809X21`2C0`T0RP8:08042@1i10P0M0P;07LH5P20<BD0QTH`08mG=`2LJ3/0W6X_08Ej7`10
^@L09=D201400?l0K?ooool000[ooooo2@00o`00A00XbP80L6/@089J:01/?B00Ga@906X81P1`1PH0
M0D507P31@1o0`L0P`<608L3102>10H0T0D609<51P2G10H0VP@60:051`2R1`T0XPL60:X9202/2PT0
[@X;0:d:2@2_2`X0/PX:0;D<302d3P`0[`d;0:h@302[40d0Z1DA0:0M602:7QT0JQdH050b;P1XFDh0
Qg5V0::?Q@2iZ9d0a;BY0<6eZP2h[J40X9:707MUG@1B>S@0>QDC05`>3@2<3`h0V0/909P81`2R4`l0
WRDR0<IfMP2jTi00eLc70<c5`02k]:d0`kjh0<[:aP3:b/X0c<g>0<c>d03<c/d0b<K20;J/X02PSFl0
?L0M2`00o`1Yooooo``00?l003h02_L3052i6P1kVC00SI4j0;IaB`2gFSl0]D4^0:TK502l5A80bQ0=
0=@=3P3I3Q00g0h>0>0@3P3S4`l0gQ0>0=P;2`3G2PX0f0T;0=P:2P3Q40d0kQ/B0?LP5P3j8aP0nbDG
0?XT5`3l:A/0oB`K0?`Z6`3o;Q`0oRdK0?dZ6P3l9QH0o2@E0?XS5@3i8Q80mR0D0>PK4`3120D0`P/:
0<082`2f1@T0/0@90:h3202[0`P0Y`860:421P2G0@L0SP8908T11P290@L0R0880841202010T0N@H9
074?3@1i9AP0Q4D[09QT=@2=FR80Jf4;03:n1@l00?l0K?ooool000[ooooo2000o`00AP0AjP40OELE
07mH;`1L9a80E0L206L41@1`1@L0L@<607020`1h0PH0O`<808@41`2910D0R`8409021`2D0`L0U`@6
09L51@2M1@H0X`D70:P72@2]20X0Z`L90:X:302/2`T0[PX:0;@<302d30X0/0`90:h@3P2Y3`d0Xa<A
08XP6P1:5@`0A2XP099nM@3Lb/00i]K:0>[Le03^i>00k^OT0>[Wi03Vi>80jNGQ0>cVh03Xfm@0h]76
0<FfZ`0m;BH0A@X907hA3`2F2``0UPL809db<`3mblh0[XF70=2h]03Gc/P0`kji0=OCcP3>bL<0_[^h
0<S8a`37b/`0c];E0<_<c`2m_[h0alBm0:>AM`0caQL:003o06Wooooo2`00o`00@@0Ek`P0QY<a0;25
@032RD<0[T0P0;TH3`343`/0b0/:0<l;303C3@`0ePl:0=T?3@3N3a40i1<A0>XG403U4`/0e0L40=@7
203E2@X0fP/<0=`<2P3N3PX0hQ0:0?HP5`3h;Ql0lS<P0?<j:@3b@c40lDXf0?=6=@3l=2<0oS0M0?l_
703n:aX0oBPH0?dT5P3j91D0lBLF0=8E302k2@P0`@d=0;/:302_1PX0Z@D90:X4202Y0`P0Y`<90:H3
202Q0`P0V@8709411@2:0@D0R`8708@11P250`L0R0@80883201m0`T0NPD;078=2P1h9aP0Qd/X08EC
7`1ZG@T0>K0300d00?l0K?ooool000[ooooo1`00o`00B@0BjP40Lg8B07Xf5@1N4@H0D@D105@20@1W
0`@0K`@707441`1a0PH0M`8607/2102310L0R@D508h51@2B10D0UPH709L51P2G1@D0XPP70:P8202W
20L0ZP/90:88202N1PP0X`/90:T92`2^2P`0[`d:0:/>2@2R4@h0S1DB06XH501W@SL0ZYJ80=W;_@3W
g=40j^CP0>cWiP3Wi>@0j>KV0>KWi@3Vi^H0iNCW0>SVj03WiNL0iN?Q0>GQg@3TgmP0clBm06YFD@0k
30X0N18B098:302V=ST0UcPn084U9P2cOWX0dL:m0;:WX031^;40b<>l0<g=bP3Ddm<0c/k@0<g@d`3?
d=<0b<S=0<?5aP2i]Jh0ViQc05NS;P0V]PD02000o`1Yooooo`T00?l004@09ML208^18P2ZND80]hLh
0<RK7@3OVB80/R410<481`341`L0b`X90=D<303K40h0fa8>0=`N6`3C40h0ha<?0>`H3`3`7140iaH=
0=T:1P3I2`P0fPd:0=X=203O4@T0jaT>0?HV6`3GC3l0njbO0?nk[`3od<H0omO<0?k3^@3]?Bd0oc8N
0?d^603n:QX0oRPJ0?`V5@3X9aH0jfaI0;Da9P2a5A00_10?0:l93@2R1@X0V0@70:062@2U10H0X`86
0:H3202J0@D0U@8509@31`250@D0Q@0507`10`1g0080NP0207L1101f0@D0N`4507h2201l1@/0K0T5
07`j8@2HI3/0ND<@04>U0``00?l0K?ooool000[ooooo1P00o`00B`0CjP<0J7@>08PJ1`2I2@D0WPT8
09H82@281@D0QPH507h5101f0P<0MP8607d4202110L0Q`D908L41P2>1@H0U@H509P61P2J1`P0W`H7
0:H82@2T1`T0X0H80:@9202I0`H0V@L909`72@2S2@`0Y0X=0:4=2`2C5Q00G1`A075CA@2cXY@0h]K;
0>WPf`3XiN00inCQ0>OVi@3Xi^D0i^CT0>OViP3Vi^@0inKW0>GVj03WinT0i^OX0>?Th`3Rhn80h>7Q
0=oPg`3Lem40[Z2F05hh<P1g3a00TQHJ08`72`2D2PX0WdU:0=_8b02m]:d0eL[20<S0^P2m^;@0emOF
0=CGf03?dM40dM;E0<W;c`39cM00a<G70:JRWP2UUhP0RFe?02Jf1@07003o06Wooooo2000o`007P0M
h`L0RWh^0:EF=P2H=1@0`g`F0=6S1P3RWAP0]2@20<481`352@P0c`d90=L=303J3Pd0f@l?0</I5`3;
3P/0iQP@0>hK3`3a7A00ka`@0>dN4`3W7A80f1@;0=dK403^91H0n2TK0?P/7`2Y>cL0oN[W0?W_k080
mo;`02L0oNcY0>YIC@3l<Qh0oRhI0?l[603n:QP0mBXI0;<[7P3ddlP0n]G>0=bBR02mAT00Xb@N094F
40225a00PadD0:hh<@2N2@X0X`D;09`22@2?0PL0S04508P21@290PD0QP450842101o0@@0N04407@1
0`1i0@D0P0870803201m0`P0J@D5068H301i?240OTDD04b70P0Lh0<02P00o`1/ooooo`002_ooool5
003o001=02CC1P26>Q40OQ0309P51@2Y20P0[@T90:h<2P2f6a@0^1P@0;P>2P2a30/0W@T808`51P23
0PH0P`@608L41@2:1@H0S`@409H61`2M1`H0X@D60:87202O1PL0W`L909`6202J10H0W0D809`92`2I
2``0TQ4@06lB3@1^ASX0a;NX0>CLd@3WiN00iNGS0>?Th@3Rh]l0i>?Q0>CShP3UiN80iN;T0>KSi`3V
i>H0inCW0>?Ri03Ti>D0i>GT0>?RhP3RhN80h^;T0>CSh`3Shn<0i>3M0;Z_Y`1C61H0P`T<08h21@2Z
3Q00TPX>07L/;@2oWI80b[V^0;nbY`2m^:l0c/k90=7CdP3;c<h0dM7C0=?De`3?d=D0alO<0;bk_`2b
/:L0UHel08IXB@0CfP801P00o`1Yooooo`H00?l004404n`405nT7@29Fc40L2<E09/=2@2/4@<0bgHB
0=6U103KWQD0/RP20<<:1`3<2`T0dP/90=/?3@3L40`0ga<>0>8L5P3V6A40jaT>0>XK403H8QD0e40b
0>A]HP3^TXH0ljJJ0?N^XP3eY9L0lYB70>miK@2^CDD0bk:^0?Ocl03elo80m?;a0?Sal03]RXH0mS@U
0?d`7@3i;ad0hc<R0<A:>P3N[j@0mo?`0?Ccl`3fl_40mnOS0>O:`@3O_[40gKj`0=JaX`2^HUX0SPH:
09T22P2F0@T0T04808h11`2;0@H0R@4508/120270@H0P`4607l11P1o0PL0P@8708@2200208D22P07
06l10`1O0@40F`<1060J301h?1T0MDd901cO0P09003o06cooooo000:ooooo`D00?l004d0LE88074:
00260P40X@D70:/92P2_2`/0_24K0;@I3`327AD0_Ph90<4<2@343@`0^0h;0:P92@2C0`@0Q0<408P5
1P280@80TPD40:07202R1`D0X@L60:47202O1`T0W0<50:872P2S2PX0U`X908D@3@1H30T0Id<c0=30
/@3UgmX0hN3M0>;Sh03Rh^40h^7P0>?Rh03RhMl0hn;Q0>?Qh03Qh=l0hMoR0>?QhP3ThN<0h=oQ0>3P
hP3Ph><0h>3Q0>7Qh@3PhN40i>;S0>CRi03Og^40g][H07IFD01j5Q@0T1TH08`61`2;1@P0OaLF09]Q
F`3Kc<L0c/>l0<:f[@2h/:H0_kbe0<[;b`3Be]L0e=KJ0=;De`3AdM@0_[o10::SWP2LVY40SGIV01_>
2006003o00Wooooo8P00o`005P0SkAP0Ll1=08njH`2>]f80WLak0;NbS@31ZI80]Y^20:FcPP37]Z@0
^:bQ0:NJT01HEe@0RXEj09B<O`2E`HH0S<Mm08o1M@1ZcUH0Fli603SO:P0ZhadP003o00Sooooo1P00
o`00>P24OBL0L4/Y048?1P1H0P@0VPL90;4@103:Ka80eJT40>6T502l;`H0c0d90<l;2P3D30T0f`l;
0=/=3@3N4@l0ga<;0>DF303W5`d0d1hD0<ITFP3ndl`0o>[U0?S`j`3glNl0mO7_0?Sbl03gk^/0o>cY
0?cTg@3]gmT0lno[0??ak`3dl>h0l^o]0>nb[@3OA3L0i3la0=5<?P3OT8D0onCL0?WbkP3blo80loCd
0?;cl`3Xi^H0i]oL0>OJe`3H_K@0TEI>07X=3P2H0`X0W`@;09/3202G0PT0T`4808`2202>0PT208`1
200>08L11`1o0@H0N04407L10`1m0@H0P@490843201d0@<0I00006010@1H0P80D0H007Dg5P1=Q049
003o06cooooo000:ooooo`@00?l000d0<[D3078B0@1i0`40TP<30:@72`2N1@H0Z`d=0;DI4`2i8AD0
_Q/B0;d=2@3230T0a0`:0080a@d;0400_`d;0:L81`2>0`@0R0@308d5102J1@P0X0L609h71@2R2@X0
Y0T:0:D92`2S2PX0W@T:08L>301I71<0PVEB0<VfX`3Pfm80gM_J0=oNg03RhMl0hN?P0>7Rh03Rh^00
i>?P0>?Qh03Tgmh0hmcJ0>?Jf@3Odm40fLO70=_6a`3Ia<@0g/c=0>?If@3Tgml0hN3P0=oOh03Pg^40
f]_M0=WIf@2k[:L0J24L0:i9A`222@X0Q0D7098Y:`28@dL0`Z:T0<:d[`2n]:X0e<_10<2m]@32_k/0
alO70=7CeP3Ae=P0cLgA0<K9bP2l`;l0V9ZC09n@QP1<IAH07m071@00o`09oooooa/00?l002808^XC
03[O8@1YaSh0S[=F0<2NN`2nXX<0dKfT0;n]UP36^JH0b[j^0=?8_@38_K40`k^^0<_0]@37_[D0a<6l
0;>aZP2f]K80Z:RW0:ff^P1eRYX0HgZ<05=dR@2AZ;<0aloA0<c>cP3>c<d0c/g;0<_7`P32^k<0Y[^C
063IE@13fS@05?0>6`00o`08ooooo`D00?l004`0HZDP05`b5P0j2`<0>`@605D31`2?1@L0[0d20<UW
403GZ0@0i:TB0<8h1`3>30X0d@/;0=<;2`3H30`0fPh=0=`A3P3O4`d0i1D>0=dG4@2R<bd0mMOA0?K]
jP3cjNL0l]oM0>W?cP3TalH0iLW80>[BdP3ah=h0mNc[0?Kak`3clNh0l_7`0?7_k03clO40n>GR0??1
^@3gbl80o>;M0?[^j`3el?40mOCd0??cl`3clo80k>_Y0>KNfP3Rd</0cZRR0995?`1h2PT0Q`<709T2
202N0PP0VP4709H1202C0@P0S`4808`220280@L0RP8908<21P1g0@<0L00107<10P1h0@D0N`4707`2
101m0`H0M`@606d20`1R0@80F04105P;101e<P`0<kX32000o`08ooooob400?l001403?P602oR5`1Y
_SD0J[hh08fZC02;[E40[IQU0:>RI`2PQF/0YXe^0:J:K@2;^6H0]iYm0:B[LP2@^6L0=Nh[03;/:@0W
003o00_ooooo000:ooooo`<00?l005404nL1074V0@1c0P40P04209/41`2W1PT0Z@T90:lB402e71H0
]QTB0;/G402j30T0_``90<<;20363@X0b@h;0<T>2P3;3``0`@h;0;<;2P2P1PD0UP@509`8202P1`T0
X0H80:881`2M20T0S@H708@@3P1S:Al0]Z>A0=gCaP3Pg=@0g=[E0=[JeP3MgM/0h^7P0>7Qh03Qh>40
hn7P0>KOg03LbLH0`IBA0;1`K@2QD4d0Tc4a08hM8@2D6ah0UQ`L09HR902G>SP0X5aH0;nFT`3Pdm80
h=kO0=_Kg@3GemT0fmKE08E=AP1j2`X0R0H708X720231PX0M`@808<];P3:/:T0bL:j0<>k/@2f[j@0
a<?00<g>cP3<c=00cm7E0=7De`3:cM00][Zm0;2c/P2HU8`0ICha0:IjH`0^[0`01000o`09oooooaL0
0?l002T05o8>04KI:`1ZaT40YJQX0<6OOP35YXH0aj^90<V^S@3</YP0c[JN0<fhXP3<]Z@0bKVY0;>[
WP33^k<0bl>j0=;?a`31_[H0cl_50<W7`@3;blD0^[Za0:R/Z`2OYJL0QIFS0:Nlb01VQYh0Ki6U0:Nn
bP38dMD0b]7D0<[Be@3;d=<0bM7C0<W>d@33b/`0al[80<O0^P2aWI40KZeB03?67@0H003o00Sooooo
0`00o`00C`0Dk@H0UiE90<>/V00c4@l0=0D703X3201K10P0U0D80;4=2038EPd0eZH40>6Z3`32@@T0
b@/80<X8203>2@X0e@`:0=L=2`3I30`0ga0=0>4A3@3>5A80U5]J0?KNf@3HViH0bf=P0<8d=02m7Qd0
`A`L0;hL7P2l8b80^Bd[0<EFE`2eL780`k6_0??`l03_knd0l>k_0?;`l03el_40m_?b0?Kcl`3el_<0
m_;c0?KblP3fknl0n^g^0=Ni]@2cM6T0Vd0j08PD4P2?10P0TP8908l21`2H0PP0X@4;09l2302H0@L0
T`8808h11`2<0PH0R04608D11P1i0@<0KP4106l10@1e0P<0N`8407h21@1k0P<0MP8307X3201j10P0
K`8306P20`1L0P40F`d306hm100Ud`<01`00o`08oooooa`00?l002005o0<03[K7P1e^d<0SK1H0;NR
L`30WGd0dkNM0=>hY@3C]j@0dKRV0=31]03Aal<0YJ2V07f0T@2[]L@0QYFZ06Z1W`1jT:H0`<W?0=OE
dP3Fdm40dm3=0=;=b03@bL40Z=:N09_DS`2GcHL0SKmf05cCB`1IcDD0>=l[01C`3Qd00?l02oooool0
00[ooooo0`00o`00D@15U040P0L107X10P1j0000V@<60:P51P2]2@P0/A@A0:dC3P2k81X0]a8>0;T:
203030P0a0`:0<T<2`383PT0b0h60<`>303<3@/0c`h=0<LA3`2N10<0VPH709l6202R20P0X`X908h5
1`214Q40EaH>0;>OSP3Le/`0fmWD0=_KeP3LfmH0g]_H0=[Je`3Mg]`0h=oO0>KOg@3Wdm40a9NB08lk
=`2F7Qh0WA@F09lB4`2P3`l0X@/=0:@;3@2U30/0Y0`;09X;2P2C3`l0PQ<C0;QgL`3Uf=H0f][K0=WJ
fP3HemL0Y7ad074?20281`@0TQ4A08H<3`1l10L0T2<S09UUH039`Kd0d<_80<S2^`3Ad<h0`L;10=;B
d`3@dM@0blkA0<S<cP3BeML0YJFW0:FTWP1YBT80V7A[07=i?`04003o00Wooooo5000o`00;P0;n@L0
FL/f09F]G@2jX7`0_jF50<:YR@37[Y80c[BK0<jhXP3?_:D0cK^T0=BoZP3HaK00e<:[0=>oZP39]J@0
b/>i0<>m]032_[D0d<g40=GCc@3>bL<0b/Jo0<k:a03=b/@0c<c70:fg^@2KZKD0EG>B06j9Y@2H]<L0
U:no0<GEfP3:e=L0b=7C0<W@e038cmD0aLgB0<?=e@34c=00a<c>0<?7bP32`/80]ZfV08FBH00Pf18F
003o00Sooooo0`00o`00AP1^]ST0eLBc0<k5a00d6Q`0;PD803@21P1=0@<0S@@80:T92034B``0f:H6
0>2Z3P31A`T0a@/80<@720381`L0dP/90=@:2P3J3A00h10?0=l@303C5Q<0QcTf0=N9OP2f7QT0ba0=
0=D<303E30X0e`l:0=XA3@3K4Pd0iQXC0?DY803B<2`0T5YH0??]k03_k>/0k^g]0?;_l03ejnP0o^3Q
0?oOh`3oh><0omWM0?W=d03QYj/0_g9i08/U:@2@2PX0U`D709L31P2C0@<0T`450982202E0@T0WP4:
09h1302F0@L0TP4709021`2A0@L0R`4707d10`1b0040K00006h10@1_0@40M`8207`00P1k0@@207D1
1P0807L93@1]10L0I`4206020P1J0`40I1T208<l0`0DjP86003o00Sooooo6000o`009`0<n0H0>m/N
08BdAP2/YVH0cJR;0=>gX`3Nb[X0elBg0=_9_@3Mc/D0flk50=K9`@3Qe]40elc80=?;b03Ec//0cLcA
0<;2c`1HIhT0WJc406j5Y@2AZ/@0Q9^b0<kHgP3EemT0d=CF0=7CeP3>d=<0blo@0<_=cP3:b/d0a/K6
0<G3`P37a<<0cl_80<c3_@2Y^Y80G<i:00_h200J003o00_ooooo000:ooooo`800?l005<05>T107`j
0@291040R08308`20P2K0P@0Y`D70:T71`2V20L0/aTG0:lA3P2b2PL0^P/90;h;20322`T0a``;0<L;
2P393@/0b`h=0<`=2`3?3P/0d10<0<D>2`2f2PX0ZPL70:871P2H1`L0NPX;05XI4`2IOVh0fM?90=cM
fP3Kf]P0f][F0=_Ke`3OfmT0gMcJ0>;Og03Na/@0]GMf0:51@02Q92<0Y1DE0:LA402W3`l0YPlA0:L=
3P2V2Pd0Y0P;0:D:2@2Q20L0W@T909X;2`2A2@/0Ta/I0<jIUP3QfMP0f]WJ0=[If@33YIh0M1X@08@7
1@2710H0PP@807h61`2J<C40SDa90=K4`02m]Jd0/ZZN0;jk]03=c<`0clkB0<_<d03<c]40a/[=0<C9
c@2h_[h0W9jI07AOE`1_Ddd0Y92300[V0P03003o00Wooooo4@00o`00<P0FlPd0Fl/f08ZcEP2fWGP0
^Z>20;^UP`2oZXP0`jnA0<bgWP3=^jL0_k>S0;BYWP3?`:h0f/Jc0=g:]P3MbkH0g/^c0=g:]03Hak40
b[j^0<_2^P3AcL@0/:jV0<K5_03>bL<0eM7=0<O0^P3Abl@0b<Bn0<;5`P2m`/D0SJ2b08JO/`0ZCFh0
JXbT0:o9e03=f=T0bM?F0<SBeP39e=H0bm?H0<S@e`35cM<0`<W>0<C>dP31bLh0_lK:0<31a02WW9@0
BJ/`5@00o`08ooooo`800?l00540:Md@0<N`W03AcLd0dM3B03`Z;00]20X0>@<904d31`1j0`L0V`L7
0;e5303HYPL0f:H:0<9=2P322PL0^`830<T72@3@2@X0dP/;0=@<3@3C2`/0d`T80=0<2`2b6QH0cS@Z
0<d>2@3A2`P0d`d90=H@2@3E40P0eQD:0=PH2P3R8Q<0kc8Q0>Hm;`2B@c`0l^WU0?3^j`3`l>h0lo3`
0?g^k03MTi00i7el0>AlN03OLg40`eaK0;E9A`2`>cL0WR8I09hG302J3`D0U@X309870P2?10<0T@<6
09H11`2N0`/0V@8909H21P2E0PL0U@8809411@290PD0NP4307410@1^0@40K`4106h10@1b0P80M`82
07T2101g0@H0K`4408TY;@2L@DL0JP/>05`20P1H0P80F@T107<T0P0Qc@401P00o`08oooooaD00?l0
02d05o0;04KD901f_D<0^jAe0<nXS03F]9X0g[n[0=Rn[@3Mb[/0flZn0>OJd03LcLD0hMC>0>3Ec`3T
g=P0fm7@0>CJf`3MeM<0d/k;0<k9bP3:a//0]K_:06n5X@1fRZ80B6>40::gc02^`]40dmWL0=?Ff03B
e]T0dMGH0<oAe@3<cm<0b/kB0<W9cP33aLP0bLc?0=3Ce@3<d=<0blk@0<_9c033^KT0J[9R03Bj8`07
m0<05`00o`0;ooooo`002_ooool2003o001C05Qm0@2C4`H0RP<208d21@2K1@L0XP@80:D41`2V1@H0
Y`@60:T52@2[1PP0]@X90;X:2P2l2`/0_P/:0<<;2P373@T0b`h=0</=303>3`/0c`l:0=8@3@3C4Ph0
eA4>0=<D4@2j3@/0R0`:06L_902fXHd0fm;90=cJf03Mf]P0g=WH0=cJf@3Ofm/0h=OE0<ng]02dN7L0
YS0`0:hH5P2c5Q<0^1DD0;<B4@2]4@h0ZA4>0:D>3@2W3@d0Y@X;0:H;2`2Y2``0X`T809d92@2H20P0
T`L808d72@2><2d0eKB]0=[Fe03Ge]H0eKnl09Dk<`2?2`L0QPH4094O702B:2P0M`P;07DB502KJf80
`K:W0;jeZ`2o^[80_kbh0<o>c@38b/X0cLoC0<C8b`37c<h0]kbm09nTX@22M6`0Bc4/0;nf]@0/X140
0`00o`09ooooo`l00?l003H02oT704kA;`2WX6X0^j1n0;fRP`2jXXL0^ZB80<F_T03<]YT0c[^R0=>o
Y`3@_j`0fmO?0=;;a@3E`jh0g<Rc0=[;^03Md/D0gm2m0=k<]03Lc;P0e/Nd0=O9^@3Bak/0aL2l0;:a
Z03@c<D0c/W00=?CbP38aKd0d<k70;^j/`2RYZH0YZfc09N[^02>Y[T0OYng05]oU@37em`0bmCG0<WE
eP3:dmH0bM3H0<G>e031bM00_/K<0<39c`35c]<0`/_C0;_3bP2ma<X0PhF:03NA;007m0@C003o00So
oooo0P00o`00501fORh0dl[90<g=d@3Ad]D0F4]>02T62@0j0`P0B`4707L42P2E1@P0/CH<0=RR2P3G
X`L0`e<:0<@;1`371P`0aPH:0</8303:1`P0b@L70P340P80;@3;1PL0cP/:0<@>1P335PL0ab@@0</i
8P3?C340eEm40=iiG`3VSG@0lZVG0?[5^P3jcL@0mM_C0?7[i`3_k^/0kng/0?7_k`3cknh0mngY0?W[
i`3ijnH0nN[U0?[[iP3jjN<0nNCL0>_;_@3T^j@0gk6I0=RSS03<SGL0aWaW0:i<?`2@10P0VP<909L2
1`2E0PP0U@4809H11`2C0@T0P@8507@10@1a0@40J`400701000206l10@0<0741001d0@80M04406l1
101/1PT0WTI>0:ABFP1m:bd0EP8405@40@1/4`@0<ih01P00o`08oooooa800?l003408^TA04GC9@1d
^Sl0`YM`0<ZVQ03@[iD0dKFO0=BiY03K_:L0fKnY0=o:]P3Qd<40hM730>;Db03Zh=T0iM[F0>OOgP3U
g]/0i]kL0>?He`3Qf=D0in;O0=OCd02i^/00`lC:09VX^P2I[Kl0W:o405EdVP1WQ9l0c][T0=CGg03B
e]T0dmGH0=3Ce`3?dmH0c]7C0<c>d@39c]40b]7D0=3De`3?dmP0b/kC0<K;c`3:c=80LgN:06A/N@1g
SfD06^DB01H00?l02oooool000[ooooo05D00?l001;W0@267@00T@h808810@2@10L0V@@609T1102O
10L0X@D60:@4202V10X0ZPL80;<92@2h2`X0_0/:0;l;2`333@T0```90<L=2`393@`0c@l<0=0@2P3B
4@/0dA4;0=@A3@3G50d0aQLB07XZ8P34/JD0gMG@0=SFe@3Kf=H0gm_I0=gIe`3Nf=L0eL300:MWHP2:
8ad0XALE0;8D4`2f4a@0/Q8B0;0C4P2Z5140X1HC09@D4P2=5Q<0Ra<A08l?4@2L30h0Y0/;0:892@2P
2@T0V@H609431@2>0`D0PPP60:5ICP3Jb<00eMKG0=S8a`2UD4L0/B8G0:<V6P2K=c40V3ln07D72P1h
2@/0OCD`0=>g/P30/jh0]:RQ0;Rf[P3<cLX0b/_<0<O:c@39cM40bL_?0;:h^P2RZ:L0ShN4044T802G
S8X0EHLf00<00?l02Oooool=003o000[01Kb3P1^_4D0Z9iZ0;FLMP2iXX40^J260;nWSP34[YL0b;:I
0<ZeV`3=^9h0d;fV0=6mY`3E`Z`0fM730=S9^`3Ia:h0b;RT0<K1^03=cll0gMO<0=k<^03Mb[D0fLRa
0=O7]@3A`k@0eLZo0=39`@3Dd<L0a<2e0=;=a03=b<40d<[60<c:a@34aL40Wj>R05aaP`2:X;<0JHNQ
09B``@2/`lh0c=OI0<_Ff0020<gEf`0;0<_Bf032b/l0^lC70;W3aP2ja<P0`<[A0;k8c`2nb=40Yk>m
07Z7T@1/UE`04`00o`08ooooo`800?l00480N3`R0=;;b`3;c=00d]?G07I/K`0Z20`0=`8704P21P1a
0PL0S@<50;<c2`3HW`/0eJ470<5D2@2m20<0``H;0;421@2i10H0`0<40<8310330P80a0830<h92`38
2P`0XbHK0>:7J@3^ZXl0l/B`0?7?^`3^eL@0jm[@0>kTg03dkNP0l>g[0>_Yi`3`kN/0kng/0>o^k03`
k>`0lo3a0?3^l03al?40l>ob0?;alP3al?40lO3`0?3^kP3ZinL0jN7Q0>CIe03Rem40h=K@0>3Ec03T
e<X0d::I08<82P2D10X0S@4708l12@2B00P0U`8809D22@1o0@@0LP0007810@1^0@0207020@0=0782
0@1a0@00L04106h10@1]0@80K`T;09e4BP2UEf00QcXm06<C5P1;0@40I0d505=G0@06003o00Sooooo
4000o`00=00hfQd0LkTo0;:KJP32Vg/0aZB50<j^U03>/IX0c[>K0=JmY@3I_j/0hLRf0>3:^@3Td[h0
imO80>gNe@3[gM80k>7J0>[Rg03Xh=X0hMSC0>KPg03OfmP0hMcH0=_GdP3Pg=`0gMGE0;2`]@2IX;40
HWFB0:jjc01kU;40Sj[4082L]03Ae]d0dMKI0=3De`3@dmL0cm?H0<_@e03<d=@0bloB0<c@e03<dMH0
cmCH0<gCf03:cm<0bLkB0;NmaP1RLhP0K7b=08bFQ@0cab4E003o00_ooooo000:ooooo`1E003o000_
/P80LA<207P8101j0@80RP8408l00`2D0@80VP<509l4202O0`D0X`D70:L61P2b2@X0]`X:0;d;2P2n
30X0`@`90<@=2P363@/0aP/;0<X=2`3>40/0dA0;0=8A2`3F4`l0d1D@09@B3@2cTHH0hMSG0=cHf`3J
emX0gMWJ0=_HeP3Lf=H0g<O609I;BP2K61L0YQ4=0:/B3@2_4Pl0ZPl@0:TD502R71T0PAhK05<B3P0j
30L0:PT302T91P0g20X0Ga4B08P@4@2J2@T0W0P609H40`2B0@40T@8208T40P2081H0dK6W0=OGf03L
cL/0[E]A0;l_8`2T4@X0UadI07`91`1m1@H0QaLD080e<02kVYP0eLc>0<S3a02h/Jd0aL?10<O;c035
blh0`l[>0<;6b`32aLT0TYND09^CT@169R80R7Md06eoC@03003o00Wooooo2`00o`00>`0Fl@d0B/l]
0:>LJ@2cVWP0/Yej0;NPPP2mYH`0`JbF0<RcW@38/i`0b;6G0<NbV03;]9/0c;RO0<flX03C_ZH0e<2X
0=O0Y03H`JL0]jVG0=?;`032_[@0g<jn0=k;]@3MbK80fLJ]0=C2[03IbKT0cKf_0<o4]`3:`[D0f=G=
0<_6`03?clT0`k^f0<o9a@36`[l0`/?00;Bk_01cRYP0CVZ406B3W01aT:L0amKL0<cEf`3>emd0c]KM
0<cDg037dMD0`lgB0<37c02j`/H0][o50;O1a@2ka]00]/;?059UN@1CIFl0DJY301800?l02?ooool0
D`0<n0D0PiHg06LT5`2`Wid0c/g?0=?Bf02;QXT09@T:03@42@180`P0J0<808D41@2U9PL0fIl=0=BP
1P32E0T0_PP50<@62`2i1@P0^0440<031`300PD0`P840<L61P3>2PX0a`/=07@L603H]Z<0jMK;0>GH
d@3WfM00j=S@0?7Qg`3fiND0n>GU0?SPh03ifm/0l/c>0<Ri^P3^j^P0l^o`0?7^k`3bl?40mNg^0??9
cP3/^Kh0iKJl0>Fh_P3U^[h0gkVm0=bg^P3G/jl0eKB[0=Rl/`3MbL<0h]3>0>2l^0246AP0[3Hd0;A3
A02J82D0SP<:09<22@2C0PL0P04407L20P1e0P80L04106d1001]0@40LP8107<10P1d0P80K`4206/0
0P1d5AH0/6IZ08Q4C@2YIF/0PcM004`5201K2@H0IRP200H00?l02?ooool?003o000f072e>`2hT6X0
_YUh0<BQQ`37YH`0bZbB0<ncW03?]Yl0d[ZT0=W4[03Kak<0h<^i0>?>^`3YeL<0j][90>WGc@3_gmH0
jM[@0>GGcP3Uf=40jN7N0=gDcP3Le]00h]kK0>7Jf@3Kd]00d/O50=OCe@3DdmD0_<KC07F:W`1>IhX0
O9Fd09BY_@39emd0dmOK0=3De`3>d]@0c=;E0<gAe@3<dM@0bloA0<g?d`3;cm80cM7G0<c@e@3<cmL0
blgF0<?5c`1]NXl0K7jA09NOY`2cXI`03nX95000o`0;ooooo`002_ooool0E@00o`00=YH204<80P1l
?3/0K0@508H21P2?0P@0T@4309T31P2P10T0X@@80:@61`2X1PP0[`P:0;D92`2l2`/0`0`;0<<<2`33
2P/0aPd;0<P>2P3<3`X0ca0;0=4@303B4P`0cQDA0:/F4`2ACTL0g<o;0=_Ff03Kf=X0fMOI0=cJf`3P
e]H0a:FT09Q;B@2I5A@0Z0l@0:X?3P2W3Pd0YQ@B098H5@1_5Q@0Da/E05e3>@1mJel0UHAg0:2AP`2K
SGl0MVEI04`f;P1<3`d0TPl?09d:2@2I10D0U@8309420@2;0P40N``60<NHSP3Je]H0f/_90:aIC`2g
8aP0_bTN0:@P60233PX0Vb/[08LF4`1o81d0X6UY0=;0a02n_;d0^[Rd0<_<b`33b/X0`<O80<C;cP30
a/T0_[o30:Z][@2HUI<0CSPc085bL01oKed00`00o`09ooooo`X00?l003d0:N8I09bGH`2[U700/IUh
0;FMOP2gXHH0`:VA0<J`V033[iL0`jfD0<F/TP34[I@0ak>J0<ffV`3=]id0c[^Q0=2kX`3C_ZH0e[nT
0=ZnX`3B^j<0`k6N0=K3[P3Mb[@0flVb0=[6[`3Ha:X0dl2X0=>oZ@3C`K00clBg0<Bj[@3<aKX0al>j
0<k:a@3Cc/X0`K^d0;Vb[`2g]K40]KNf096O[02W^<80I82F06J5X@2T`=00bmCI0<kFg@3=eml0cMKN
0<_Df`36cML0a<cD0<SAf@32b]@0_l_A0;k8d@2`^/80QI2N06j3T@2AUiH0=LdW01400?l02?ooool0
E012dAl0YWiW05lJ4P2GMG80d/kB0=7CeP2VY:L08@X?03042P0o0PL0E`<707810P2K80H0fYh>0=FQ
1P33F@/0_`X70<H52`331@/0^`460;d21@310`L0aP@90<`82`3D30h0f10?0:TD4P3TShX0l[6/0=B8
OP3=MVT0cfiT0=abKP3QKfh0gfeZ0>5TH`3KBDP0fEA?0:eaJ`3bin<0lNk_0?7_k`3al?80m^_Z0=b:
R038B4H0/1hQ0;PN8@2Q82@0VS/k0:iOG@2bGeP0YU5509a7>`2E@c/0W4Y909Lo?P2?8240e7Ad0;iV
J02jGVD0Q@lG08d32P2=0PP0P04407L10@1f0@40LP8106l20P1_0@40L04107<20P1c0@80L04206h1
0P1W0`D0JaTO08DnAP2FD5X0Z69[05H?4`1H1@@0K1D5013U00D00?l02?ooool=003o000h04k;:@27
ZDX0^99^0;bJO031XhT0ajR?0<b]U@3A]j40dkfY0=Jo[@3Ka[<0gl^i0>;;^@3Qc;P0h/bh0>OC`@3W
eL@0j]S90>_Ib`3Zf<T0jM[>0>SKdP3Vf]D0h=C>0>KQf`3Kd/`0iMSF0>;He03Le=40dlk@0;F`]`36
_LL0UY:W0<_1d@1fP9`0KXRS09^eaP3@e]X0d=GH0<kCe@3>e=L0c=7E0<c@dP3<d=<0c]3D0<g?d`3<
d=@0blkC0<S=d`39bm@0alS?0828V@1TMhd0OXfI0:BTZ01YZE@D003o00_ooooo000:ooooo`1E003o
001:IPH0JeM@07IZK@130`@0Q@D809021`2C0@H0W`@809d31`2M10L0X@D70:H62@2^20T0]@/90;X<
2P2n2`X0`P`;0<@;2P3530T0b@h:0<d@2`3@3P/0dQ4<0=0B3P2T5A00Od<h0=O7_`3OgM`0emKF0=[G
f03Kf=P0gM3?0:=YI@2<8Ah0Wa@A0:X?3`2W3Q00Xa0>09<D4P1V5a40IdHi09Z7N03:^jh0hMG<0>;G
d@3TgMP0i>3K0>GNf@3Pell0fL_20:nAR01o61@0W@T:09/72P2E1@P0S@8308T20P1l1`80_XMh0=OC
c`39/Z/0W3LX0;DB2P317A@0]B0I08X4102:4QH0Ta`J08LK5`26<Bl0Nd920<Zk^034`;`0^[Vf0;Zl
^`34blh0a/oA0;o8bP30bL/0W:JW09RLVP1ICDP0RX:108MjK@03003o00Wooooo2@00o`00?P1K_CX0
V9=S0:RCM02`Vgh0]J260<:RRP38SWT0^gEO0<BTR02lZ8d0_jN<0<B[SP35[YD0ak:K0<RbV02o[iP0
WYJ509JBQ02j/9d0e<2W0=W0Y`3I`ZD0f<BY0=_7[P3Lb;00flVa0=W5[@3I`ZX0e[fV0=:kY03A_:P0
bkVY0=K=`@35^J`0blBh0;ffZP3=akl0aL2i0=7=bP2i]k40Z:RT09FKXP1`Q9<0JH:I09F`aP24X[@0
bMGJ0<kEf`3=emd0c=KN0<cEg`36d=H0a/oE0<C=e@2c_<D0`L[B0<3;dP2g`<L0UIbV06UlR`25UI`0
Q9]f4@00o`08ooooo`1D05K3;P2INfT0Ib@M0:j:S03CdML0cm;F0;jn`P0L3Q80:0<703T11`1C0PH0
MP@509XO1P3LXA40ej@50<AM3@2n2@D0a`H;0<H72P2m0@D0`P<80<X8303:20/0d0X<0=L=3P3M5@l0
fAhC0=PY903:;b`0[C0T0;aA@03KNfh0n:bR0?o1]P3odLP0nL6k09/^:P3=T8H0nnOP0?C_jP3aknh0
l^o_0>k^k`3_k^d0n>WS0?c@b02oEDl0Ya`K0959@P3cdLP0nNGM0?SQf@3delh0nMO>0?32^P3/]:`0
^V=N08`>4@3EKW40`Vic0<acN`2@7BH0S08;08`11`210@D0MP0107<10@1a0@40K@0106T00@1Z0@40
K`4107@10`1b0@<0K04106L10P1R0PD0F`D=07@R;@23=T40IADL06061P1/4P@07lT01@00o`08oooo
o`/00?l003/0=MTL09:SDP2hTVl0`9ek0<6OPP31Xh/0aZZD0=6cX03D]Z@0f[Z[0=^k[@3I`Zl0f/Jd
0=W6/@3QcKX0h/fl0>CA_@3Xe/H0i]6n0>[E``3Wd/40j]S90>SEa`3Zf/d0iMO<0=oDc03Mdld0h]WF
0>CHe@3Kc/X0fm3?0:JT/`21G840]4UP0<8nC`2j;CX0WU9W0:R`a01nV:l0bMKM0<S>f02EUJX0e<C>
0<o?d`3:cm<0b<oE0<[?e`3<d=@0c<oD0<_>e039c]80b/cC0<[;dP2NW:/0L7fC08^KZ@2]]kd0/jf_
07FPF00C003o00_ooooo000:ooooo`0^003o001MPbL0RhR506AXJ`0I0@40H@H808831`2>0PH0TP<8
09<2202H0PL0W@@80:@72@2^20/0]0/;0;T;2`2m2`T0_`/:0<<=2P373@X0b@d:0<`>303@3`h0dA4?
0;/E4@29A3d0elO00>;Og@3Lg=d0fMOH0=WEe@3I`;`0_UiD0:LG4P2N2`P0X@/<0:4=3P2E4Q@0MQLE
06<c;02]Vhh0gM?80>7Le03Rh=d0h^7P0>7Qh080h>3N02D0h>3O0=kOg`3KgM`0hMSE09iGC`2I2`X0
V`H709T6202C1PL0S@D6088>1@2oR7H0dlg70<2OV02@81<0/0T40<8;2`2n2Pd0[PT<08l31@231@P0
PAhO0>>WZP28De@0aJjZ0;Vb[@32_k/0b<W90<;:c032b/d0aLg@0;c5a`2W/[80SYRH07ejN01kM7D0
RGme00<00?l02Oooool7003o001101?`3027V5P0Whi`0:NGO02^WXH0/j>;0;ZRS@2cIE<0/2LG0;0^
6@39UgT0`JJ;0<>XS@34ZX`0aZ^?0<V_U@2gYI00P7i_09bGQ@2HThL0JVeV0;faV`3F_jH0fL6W0=W2
Y@3JaZ/0flN_0=c9/03HaJd0el:Y0=JoYP3C_JD0dK^U0<^hY038^ZD0bkf`0=3:_`3?cLL0_k^b0<W5
_@33_;@0a<6l0<O7aP2_/:d0RI>K07nBX@0jFWX0EWF?0;c@f@3>e]/0c]KN0<_Ef`3;eMd0bMCK0<G>
e`36cmP0_<?;0;O1a`31c]D0`LcE0:Jd`00jD640JH290:6UZ00YdQh04000o`08ooooo`1D07jS@`2S
SH40Jc8^0:N1R03>cM80c]7F0<?6b00N61X06@4303<31`1B0`L0M0@609LM1@3NX180eZH50<AP3@2n
2PL0a0H:0<H72`351@X0b`T>0<`9303>2@X0e0d:0=T?3@3N6a<0icP[0<8L4`2_@3L0j[^b0?OLe03f
i^00mN[X0??]j03dkN/0nNGR0:MUH@2CKV40l^_S0??bk`3cl_80m>g_0?CXj`3^jNX0l>g/0?C/j@3k
e=40V4=20:B9Q03/iN40j^WW0>g/j`3]jnX0j^OW0>cXi`3/iN80hKRg08hB5P2H4QT0/d==0;51BP2:
1`h0T@8809822@220@@0N@4207L10@1d0@40KP0106/10P1Z0@40K04207010P1a0@80K04306H1101Q
0@H0I04906T53P1c5Ql0LQPO06L6201]3`H07/P01@00o`08ooooo`T00?l003h02oP606bc?@2`SF/0
]iAe0;fJO`2oX8H0a:JB0<naW@3J/Z00fZNF0<F7N@3FRWl0dHEf0=ZiX`3G`:/0flFa0>C@`03Pc;/0
hLji0>SD``3Vc[d0j=6n0>S@_@3Zd/80j=710>OB``3Od<L0ako50<BFYP3GPhd0gWV00>B8TP3QTYP0
fZFc07Y4K02`?eh0_Q8O0<T:4P2j82h0Ie1a08>F/@2``]<0VYje070[C@2P8cT0_Fam0;B4UP2;Ih00
KDeU0;Vb^@3@d]L0c<kD0<S<d`37b]<0b<_C0:V/]P1=F6h0EfMi09^X/@2YZ:l0Y9>D03G991800?l0
2oooool000[ooooo05D00?l00::3GP1eNh00GFM[00d10@0a0P80F@8208431P210@80R`8609<10`2J
0PL0XP@90:`62P2b2@`0^0/<0;`<2`3130/0`P/90<L<2P3:30X0cA0>0<h?3P3=4@l0Ta<@0<6UWP3R
g]`0hN3R0=oOh@3Pg]h0g<K20;YSFP317A@0aa@@0;D@302P2`X0TA8A05XA3@1YCD80b[b^0>;Le@3N
g]X0g]kL0>3Pg`3PhN00hn?S0>3Ph03Ph=l0gmoO0=_Ng@3Mgmh0gmcL0;1oMP2E3``0V@<609`62@2J
1`T0U0L808PB2034Sgh0elo90:Z7OP1d1`40Y`H60;`82@302Pd0^@h@0:4=3`240`L0SQ/O07LD7@1d
9b`0el310<c8a@35a;l0^;Rg0<36bP36d=80][k10<G?d@2U/K<0UJ6R07QhM01]IfD0Rh5g00<00?l0
2Oooool6003o000e02;M5@1gVdl0W8ma0:>FO`2XVhD0[Yj60;6PQ@2iUg`0Xd4X0<QTAP2hLeD0`j:6
0<2UR@30YXL0`jN70<FXR033Z8X0Pga/08Z<NP2TWXX0XI^=06abJ`2NVhL0e;fS0=RnYP3K`jD0fLBY
0=_6[P3Jajl0f<B/0=O3ZP3F`JX0d[bU0<niXP3=^ZH0a[>O0<NgY`2m[j40c/Rn0<[8`@39a[l0^;2Y
0<:k]02n^K80/:j[0:^WZP2SV9h0[iVM0;RNW02_XJ@0blK90<kCf039e=X00P39d]X02`37c]P0a/gC
0;ZjYP34b/40`<_C0<3=e`2kamD0Jg^906n2S02OZJl0KKEQ01000?l02?ooool0E02D[6<0VXf:07E9
B@2=GfD0al;70<_>d`2m`<00?STi00d10@0X0PH0A`8806031`1n5`<0filC0=FU1P35H@`0_`/60<D8
2P3620/0b`T;0<h;3@3?2@`0d`/<0=P>3`3I3Pd0g1@>0<hG501V10<0bk2X0>o[j@3]jn`0k^g]0>c/
k03_kNd0lNWX0?[Uh@3U[9l0L3T[0>OGb`3Vh^00j>GT0?7De034HfP0XVIW0>oYj03[j^/0l^OW0<6=
S01jD500i=gK0>[Zj@3[jn/0jnc/0>SWj03Xi>@0j^CS0>oIf02L<c40X0H:09l42`2G0PX0U@8809@2
2@2?0@P0QP4507`10P1k0@80M`8307010@1_0@40K@4206/10@1/0@80L@830702101V0@D0G@4506@1
1`1[0`T0K@L=06d:3`1V1`T0I0X403^C0@D00?l02?ooool7003o001001;]2P1/Tcd0WheO0:j<L02b
TGL0^IQo0<BUSP3;Z9@0e::C0=B9O02oFD`0dVUD0<UZDP3BL5`0dG=Q0=fdWP3I`:X0g/Nd0>3:^@3Q
b[T0glVf0>O@_P3Sb[H0i<Ze0>K=]`3Yckh0jM2n0>GAaP2ASJP0ZDQ[0<dS:P3A8Ah0cB4Q0</R9P37
7BH0`Qh/0;dQ=03?;cd0bQDK0</83`312Q40]E]/07aWQ@1RBFl0RCIB0:T?7P2a0`h0[0@?0:H74P2G
5AP0YEeK0=G5a`3=bl<0c/_10<[=d038c=@0aLWC0;o1b`1XKWd0KW^708VCVP2RXjP0WiZM07BVHA80
0?l02oooool000[ooooo05D00?l00;BLP029V9d0D5eN01030P0Z0`D0:`4105T41@240`H0S@880901
1`2E0PL0X@<90:/72`2_30h0/Pl>0;X<30323@`0a0`;0<L=2`3;3P`0c10>0<d@3P325140TdHo0=kE
d@3Ph>40h^;U0>7Oh@3TbLP0`fUR0;lT703:4Pl0c1<?0<TE402/5Q80HaH?08ieI@3EbKX0h]gD0>;P
g@3Mg]/0gn3M0=oQgP3Ngmh0hN;S0>7Rh@3PhN40gmoN0=gNg`3Mg]h0g=WG0:MdJ`2H3`/0X`T:0:46
1`2M1PL0U0H608/L3P3:Wh/0fmKA09]aJP1d2@D0U0@40;P:2P302PX0^P`=0;TG6@2C0`H0R0H908P7
2`1k2@`0O3dl0<:d/P33`[l0bLW90<G6bP38cm80aLg@0;k7b`2ka/X0SibO096GU`1ZI6D0ShAl00<0
0?l02Oooool5003o001302WC6`26MUX0RWmU09^@N02SV800Z9b30:^KO@2_WGl0]Iio0;fEM`2lUgH0
^in10;^PPP2nX840`::00;nRP02oX7`0`:=o079[F`1/LfT0Ngid071gL@1KIV40/:VC0=70X`3D_jD0
fL:V0=c4ZP3JaZd0f/J/0=[6[@3H`Z/0e/2[0=:mY`3>^j<0b[JN0<NcW039^:D0`K:P0;b^W@33^jl0
`KZa0=;=b@36]K40_I:>0;1NF02W=380Z1`L0:hE5`2/4QD0YaDK0:P[<P2]GF40aJV]0<c@e03;e=`0
am7G0<K>d@2h]8`0_KN30<K;b`2haM00^/OB069`P@1KKgX0Pi:F09RASP0@003o00Sooooo04H0^IYl
09N>S@1nG5X0M3m10=34bP34a/X0/[Fe075/KP0?0P<0;@<904<22@1L0`P0OaH40=RN4`3FYPL0a5l=
0;h:1@3520P0a`X90<T82@3<2@T0c`/;0=<=2`3G3Ph0f@h=0=`@3P3D5A<0Q@`<0:5lN`3/jNP0knk^
0>k^kP3^kNd0k=kN0=^PWP3NJFP0g51808XP6@39]:D0j^GN0?Ccl@3hi^@0bVUX098^:`3Xf=D0k>_Z
0>gYjP3Wa<<0QR8S07ln@P3B`L<0jn_[0>[Zj@3ZjNP0fL?10;=gN@2hIfT0]Sho0:D62P2Y10X0WP87
09P11@2k82@0V@X>08`21P220@80OP4107/10P1h0P80M@820P1a0@40301a0P40LP430701101Z0@D0
G`4506411@1S0PH0IP@806L32P1Z20`0Ia8;03fH1`D00?l02?ooool5003o001300Wf1@1CXS40A4`o
04E4C@2VRWD0[Hmh0;2EP02kWh`0c:^H0;icI037Ie@0c6QB0=Q`G@36Ed80cEi80<UVB`3;NV<0h[:L
0=_0[@3L`k<0g/Jd0>39]`3Nb;80iLji0>?<]@3Tc;D0iljh0>W@_03Yck/0hlk506AIQ@2i<d@0hfmN
0>NRU@3HYj40b9bP0<RGY02bKh00WDUM09PhC@2X:C/0`P/C0<L63P2n3AT0/aDR0;0=6P2c1Ph0]08;
0;442`2Z2P/0Xb8N0<>8PP3EblT0cLoA0<S3Z@30[VP0clnk0<O=dP36b]@0alWE07MiR@1QK7P0SYZO
0:jc]P2a/;D0YIVH00Od100A003o00_ooooo000:ooooo`1E003o002dY8P0Ffeb055NG`0G10D0;`@7
01l20`0L0@40GP@608D2102:0@@0S`4709h52`2S1`d0WPhB0:8@4P2d3Ph0_0d=0<<<2`363@/0b@h<
0<X?30384Pd0VahE0<baZ03Rgml0g]kP0=kNgP3OaL<0`e=@0<TL5@3B5A00e1D@0=0H402i6Q<0N1`C
0:N@OP3MeL/0h=kJ0>3Pg03Oh=/0g]oO0>3Mg`3Qh=l0gm_H0>3Ad@3Sd]<0h]gJ0>3Qg`3Ogml0g]oO
0=cDd@2@A3`0WPd90:@82@2V1`T0X0H709<81`2I>2T0c:bK0=[Ad@2:DTd0P0X708X30`2Y2@T0^`X:
0;/:302g1`/0[0X:08`41@2B3Q80Q@P:09Ln>036[:X0bLG40;Zk^@2oa<@0cmSJ0<_Ce`35c]@0_<K<
09>QXP26SXl0GE]M09>9P@03003o00Wooooo1000o`00A@0VdAX0L7E?08ImJ@28PF`0V95l0:>JP`2W
W8@0ZY^10:jMP`2aWh80^:B50;VPPP2eW7/0/iaf0;RNNP2kW7P0_Yeh0;nML`2nWVh0TWiR05AID@1I
HU/0IFQO08Z3L@3<^Il0dknS0=BnYP3E`:L0fL>Y0=[5[03Kajl0f<J_0=S3[03E`JT0d;jV0<fkXP3:
]Ih0aK>J0<:]U`3?_Zd0aKBU0<FfZ033ZYl0_85h0:hk=P2^5A<0/`X<0;@82P2e20T0]PP90;L72@2d
1@T0]0L90:h93P2P5Ad0[fM/0<c7c@36dMP0aM3E0<C:aP2bZh40^;VH0;k6bP2g`l`0PI2Q05EWL`26
U9X0VibL01KQ3P0?003o00Sooooo05@0^Y^10:JNWP20IF<0Gb@Z0=:laP31`/L0[Jj`09:?S`0B10H0
:`<;03`1201E0PT0O1D60=NM4`3EYPD0`E/;0;h910372@P0a`P80<X82@3=2@X0d0X;0=4;2@3F3Ph0
f0h=0=X@3@3N50l0e1/I08LE6@38/kL0k^g^0>g_kP3]k>d0l^_X0?_Ac03>D4D0ebHJ0;<R7@2PPgL0
jN?J0>k^kP3cj^T0f9ZJ09D^:`3:/Jd0kn_Z0>gZj`3dg]`0Zc8a0:dJ8022=Sd0hmcL0>OVi@3Zj^T0
l>;N0=RLV02M9RD0ZP/@0:X4202Z0`P0Y0<:09P31@2]6R00U0H=09421`2<0@<0O`4107T10P1f0000
M`4207<0001a0@00L@4107810`1c0@D0K08505`10`1K0@<0H@8806<31`1V0PT0IPD;06HE4@1Ve4h5
003o00Sooooo1@00o`00@`1MNS`072<l00HJCP0Z=UT0Xhn30:fFP`2hWHh0^in=0<2PR@37Pg00`UQ6
0<YOB@35FdH0fI5g0=RSQ`3F[I<0d:F@0=VfW`3K`:h0g<>`0=c1[@3RbKL0gLJc0>;;]03Tc;@0iL^e
0>O;^P3Xck`0i]6j0>C>_P2GRI/0`hjB0>O5/@3Mc;/0f/Zn0>?He@3Jcl`0eLK60=G;cP2o_=40F4ei
0:TT?@382100a0D<0<4T6`2b<RX0YR`[0:/i=02_DTX0`8Em0=>n^`3>cLl0b/kA0<_@e@3>dLl0ak^A
0<>dN@3<cL80aL_A0<C9dP1oPi<0DEQY071mQ@2]/[L0/k:i0:^SZ@0Uc1/04@00o`0;ooooo`002_oo
ool0EP00o`00RX]O04YMG01BGel06@8302P20`0H0P801@4002010@1V10D0O@4408H21@2B0PP0X0H<
0:dJ7`2[61/0]B8T0:HE5@2f3@h0a0d=0<H>2@364@X0/a/C0:1QF03Rg=/0gmoQ0=[Jg03Hal<0]e16
0<<G4@3;4P`0cA8>0<lE402/6A80LbPM0;:HR`3PfM<0g=_J0=cMf`3Mg]/0g]kK0=kGe@3H`;l0_hb9
0:M?B`2N<Bd0UCPb0;BDRP3Ng]`0gMcN0>3Jf@2iTXl0RADF0:092`2W2P/0Y0P809d71`2<2`L0]FQE
0<^gZ@3Db<H0OS4[08X71P2?10H0T`830;892@2h2@P0]`T:0;D92`2E0`D0QP/>09LY:P256aX0RTa8
0;f_[03:c<d0bLoA0<K?dP3;e=X0bmGL0;W3b@2MZJh0S9FH05YKGP2@QX001_<10P00o`09ooooo`<0
0?l004H01oD505B??P2?ThD0][Nb08b:N02IU7l0XY^70:BKQ02YVh40[9f10;2PQP2cWX40/iUk0;BJ
MP2dVW<0]I]c0;VKK@2kVfh0_YU^0;jKJP2mWVh0YheV0:^FL`2kWgl0b:Z70<fdT`3C_Z<0dkjT0=Fo
YP3I`jX0fL>[0<^lZ02k[id0ak^W0=;2Z@3A_ZH0c[ZQ0<ZfWP38]9`0b;6K0<J/V038ZIL0aHem0;I3
?02d5A<0^@`<0;P:2`2e1`X0]@P:0;H:2P2g2`T0]`T;0;<62P2`1@L0/0H70:d52@2R2a00XDiC0<[4
b@34c]00^;^U0;jgMP2YX4L0a/Zf0;_4b`2@W:T0FFYh086DV`2NY:D0:]@P3`00o`08ooooo`100;^R
R02CTi<0T7in04dD6@30YZl0_;_00:jb/@2[[JT07A0@02X42`0o0`d0B04906L?0`3CW1<0eJL70<5J
302n2@D0aPP80<T82P3<2@X0c0P90<l92`3C2`/0ePd=0=X?3P3M4Pd0hA<>0><E4@3E6QX0Vbhd0:^2
RP3Ne]P0k>g]0>_[j`3`j^L0l<>h0=MYF@2n;BD0S5YB0>[Pf03ak^d0l>_/0?;Ee@3CUY80g<G10?3[
j`3^k>h0lNCS0;iFD`2n51D0ZQLK091GG03Hd<h0jNSV0>[Xi`3`hml0e9VD0:HI5`2Z10L0[@@80:L2
202V3Q@0bT]@08h:3P80TP460180QP4307T10@1i0@80N08107@10P1b0@40L@4107<10`1a0@<0JP83
05`10P1H0@<0F04505d21`1R0`L0H`D8064@301SdT`5003o00Sooooo1000o`00A01kXdX0LFI/00HG
BP025eh062UO09j?R`2`UhD0/iB10;JGO@2lWH80b8ii0<5D@033G4H0aWEL0<bGN`3>Zhl0cJbC0=:h
Y03MakT0f[n^0=VoZ`3K`Zh0glVc0=k5[P3Rb[<0i<^i0>?9]03UbkT0i/nk0>K?^P3Vc[/0hL^m0=k:
^03Ja[80hLJh0=o0]03Va/00i/C20>o7bP3IYZX0i:jf0:edSP2^<Th0a0PA0<862`30:Rd0UT==08iC
I@3<WjX0fkNm0=O1b03Fb<l0dL[@0<k;dP3;c=40bL[60=39Z@35/EP0c;ej0<_<`P36blh0XjF`069X
MP22SIL0WZ>]0:BV/02ZZ[80@kXk4@00o`0;ooooo`002_ooool0@P00o`00Fi8m04AFD`1LJ6L07@@4
02820`0=0@000@0101010@130@80L0D707`1102;0PL0X0H;0:/93P2Q1``0Y`lC09X82P2_30d0`0`<
0<D>2`3050d0SB4E0<JZY03Mfmh0gmoR0=_Dd`2lP7T0]Q/E0<<>303530T0a`l<0<4G501j9ah0^Z:C
0=oGcP3Lg=/0fm_K0=kMh03OgM`0i=OE0;B1OP2?<Rl0XR4N0:hG502P7QX0H1T>0:nKSP3LfmP0g=KE
0=:e/@2E?SL0V`d<0:89302R20P0X0H709T6202B60h0`hM`0<o2]`39^KD0NA/G09082@2A1@L0S@44
0:861`80]PL90180]0P60:D92@1m1@D0/eMK08/=401o7Ah0ekZj0<g;cP2g_;h0cMGI0<cEg@39dm`0
bM;J096NXP2BWJ00C4mA08j6O@0Ec0<2003o00Wooooo0P00o`00A`0Eh@d0HF]809>FS@2/^k`0`<S:
08b=P@2JV8D0Wi^90::LQ02WWHD0Z9Uj0:fKO@2_VW/0[YMe0;2GL`2cVGH0]iM`0;NEI`2iUF40_IMU
0<:NK@31X780`Yma0<>SN@36YWh0bZZ30<Z^RP3?]iX0d;nR0=FnY`3H`J`0]:RH09^GR02bZ9X0Qh=k
0;6[V`3?_jL0c[fS0<bgW`3:/id0cJfJ0<f7O02oE4/0]AlK0;l=3`2n2``0^`P;0;`8302f1PT0/PH8
0;@62P2e1`/0/`P90:l82`2^1`/0[`L:0:d6202Y10P0X0X=0:MMH03:cL`0_[nV0:jPA02UU@X0[ZLm
0;^nTP2/]k@0@5MU07B;U02EWZ80AK`h00l00?l02?ooool0E02kXXH0VIRI09J;R`144Q<0VGUl0;Zh
^P33b<X0cm?D038Y;@0Z1@`0?`D:04L11P1U3`D0cYDB0=BR2030E0`0_PX60<H81`3:2PT0c`X:0</6
1`3?2P/0dP/<0=H<3P3K3Pl0fa0<0=hC3`3P4a40iaPB0>4L5`2n9240PShl0=cDd@3/j^T0j^SX0>gW
i03df=00e75W07h]:@3Yf]L0k>[X0>c/k@3[jNP0l^WW0>kYj@3]jn/0kNc/0>kXj03BSH`0[Q`I0:4I
4`2KDDX0ZYB=0>KNf`3Xi^L0inKW0>gQh@32M740X14>0:T52@2X0`T0Y08909l32P2L0`P0T`4609P2
202D0PL0Q04307d10@1h0@40M`8207D20P1c0@40MP8307@1101[0P@0GP4405L10`1E0@<0F`860682
1`1T1@P0I@l<06KDCPD00?l02?ooool3003o001506RgA@2SU8@0O7Mo018UFP0266H03AiJ09b=R`2]
TH00/i=l0;REN`2kVX00^h5X0<AjG03>Vh40b:F<0<JYT@36ZI00bJbC0=_=_P3WgMX0dkf]0=[1[`3J
a:l0g<B`0=o7/@3Pb;<0hL^g0>7:]@3Sc;T0hlbk0>C>_P3Tc[X0hlbi0;^c[`2PR9@0ceUK0==1@`3A
=C/0cRT`0</P9P3961`0baTL0<HE60343a@0a0T>0<86302m10`0]0L?0:d94P2V2QP0X`dN0:4E9P2S
8S<0YCE40:Y8F02ZIG40ckb^0;n/H@2mXaH0_JDA0<2^BP32_8P0`;b/05]KHP1SJgH0UIfV0:6SZ`2W
Yjd0IJYK01400?l02oooool000[ooooo05H00?l00563:`1LJVL0DeiM01d4100F0@401@400040000C
0@80<04204h10P1_0`@0Q08509l52P2[20`0U@P;09XZ;0292P/0/0l>0<<?30333@X0/b0E099FAP3L
e<h0gN3S0>?Nh03AY:40/CH^0<0A3`353`h0a@h<0<@?3@2E5A00[X^00>3Hc`3Mg=P0fmcL0=cKg03P
g=/0dkfj0:ALFP2M92<0YQLF0:dF4`2M6QH0J2HK0:27N@3Jd<T0g]WI0<>XX@2A@c/0UaHB0:4:2`2S
2@`0X@L909/61`2@1@H0U2PL0;b?NP3Cb/40^9fI07dB3P2=10H0R`8408`31`2E0PD0/0P<0;L82P2e
1`T0/0P909/6202720`0R`L;08DF6031UI<0`;Zk0<?5b@2oaLT0aloG0<S@fP2ob]@0Y[Fl08:BU@1K
GV40QgQ_01G;0P800?l02Oooool2003o001704f8>028RX80[KRn06EkP@37d=@0SY::09BEQP2MVHL0
WiN40:JHQ@2VUg/0ZYUj0:^GMP2]VGH0/9]e0;2GM@2cU6d0]YAT0;RDG`2mUf<0`9m]0<BRM`32WgD0
a:Ak0<FWO`3<[8T0cJn>0<neUP3@^j00e;nW0=K1[@24OGD0Z:JL0;J`XP2BTX/0PhQn0<o0ZP3@_ZH0
ckZT0=F_WP3:JF00`20J0<@C3P353P`0`@X;0;/:2@2j2PX0^@P:0;<:2P2X3@h0XQlS09Hb>@24=dD0
NCY:07diA`2A=3d0VAHL0:D72`2X1@X0U@hD0;VHV@33c<l0_K^L0:JE5`2]W@P0ZidC0;F[C`1/LE<0
LhB7092HVP1TZ5803`00o`08ooooo`1D0;jTQP2HUi<0UH^:04lJ6P1iCe40`;^n0<_@d`3Cf=/0AT53
02X8300j10T0C`D:064=103@UQ@0e:080<1A30302@L0b@P<0<X;2`3?30`0d@/;0=4:303C30d0e0T:
0=P>3@3J4A40e10@0=0;1P3P5a00dB4G0;0c9`3?U8X0j^3L0>cYj03/j^T0k>OV0??PgP3SRXD0S1`I
0;bSX03[i^80j^[Y0>OSh@3N_Kl0TVa`0>?Lf@3^k>/0jnSW0=ne/P269B80Q4Q00?3Kd`3[hMh0jNGT
0>KUi`3ShN<0iMoR0=JYY@2:4Pl0V`@70:01202P00L0W`4609T11P2@0@@0T`0509D01P2<0@D0P@01
07/10`1j0@<0MP0107<00@1d0@@0L`4406`10`1Q0@<0F00405<0101B00D0GP8506<3201Q2`L0EkX`
1@00o`08ooooo`800?l004H0G[dk0:VMT`2VW9L0V9:H00hMCP045f001aI>08n1PP2ZS7d0/91l0;JE
O02jUh00`9f30<6NQ02fW8T0UXEg08QlL@2@QWP0_JRB0=:jZ03E_Zl0e[bW0=[1Z`3I`:/0f/>`0=o7
/03Oa[80h<Zf0>3;/`3PbK<0h/Zf0>;;]@3Sc;H0i<jh0=71_@1^GWd0_SDh0<lY6`3A=R@0eD<e0=IA
A03FG500dUmE0<iQE@2ZB4d0Wale0<074@300P/0_R8N0;E;@`2SAd<0XT4n0:Li=`2S:2X0XA`M09`D
6@2A4QT0`iNI0=7=`@2nZT/0_jD60;^P1P2bW@d0/ihO06YN:01SKWP0SIVP0;2c^@2RX:H0JimQ4@00
o`0;ooooo`002_ooool0EP00o`00GHdb06YfM01ZL7<07@H700h10@050P400@4101<20`0X0@40;`41
04L10P1j0PD0V`@:0:L6302O30h0ZDE60:HL6`2l30d0```:0<<@2`2Y@C@0eKnf0=oOh03Ogn80dJFT
0;0d;P2m5A00`Ph?0<TB40374@`0/AD?09IKC03Gd<H0fM[G0=_Kf`3LfmT0e]7;09Z=PP20>2l0XAPE
0:XF5P2T6A/0OaXF06Dj;@2n/:80h=[B0>7Kf037Xil0TBdW09L>3@2O2`h0X@X=09h82P2O20T0V`P9
09491P2OA3<0^Yj<0=K?bP2JKFL0PPX808l41`2>0PD0RP8508P20`2B0P<0[`T;0;<82P2d2@L0[@X7
09430`251`L0O0d>088j>`35[jh0^k^l0<75b@3;d=@0bM3F0<?<e02N[K80UZJZ05UMGP1mJe`05l`2
0P00o`09ooooo`19003o000PcQL0N7ea0:bg^P2f`lX0_<W@0<_Be`2GViH0U9:409bEQ`2OUH@0XI>0
0:>FO`2UUG/0ZiIi0:bDLP2[Ufd0[iQb0;6DL02bTV<0/iAN0;^GI02nWFd0a:=h0<FTO035Yh40aJIn
0<Z[Q`3;/Y80c[JI0=6iX03D_jH0el:]08N0N@1eNgP0Mh1j06AaJ`2DV8T0d/:^0=G1[P3L/Z80aeE@
0<HF5P3940h0b0h<0</@3P3530d0_0X<0;D<302]7Ql0TCa705a0F00h>ed0@4]]05MMN01ZM8d0CF:0
05UaT@22N8`0TCi:09h=4`2Q1`/0Uc`n0<C5bP33b[h0WI0j07=X302XW0X0Zi/707Ub8P1NK6d0U9jQ
076XI00?003o00Sooooo05@0_Z:509nLV@2ITI40F2LW05//<03;`lL0cmCI0=GJgP1GDeD0:`X>03X4
2`1F1`l0F``30=:J5@3GXPX0`4`:0<891`392@`0b@P:0<h;2`3A2``0d0T:0=<;3@3F30d0e`d=0=P>
403E3`h0f14<0<hF4`2RACl0k/[10?;Th@3[jNP0jNWW0>ORh@3`c/`0k9bN0=a:B@2`7QX0M4U60>_Q
g@3^kN`0l^_Z0=:IVP269bP0`ZNU0>_ViP3Zj>P0k]CB08Y2@P25GeX0jNGR0>SViP3ViNL0h]oP0=kE
e03H`[h0^gQc08T;2@2E0PD0UP4509T2202G0@H0UP4809411P2A0@@0U08608l21@260@@0O@4307P1
0P1e0040M@4207H11@1d0@@0K`8306810`1J0@@0EP4504l11@1E0@D0FP8505l70P13V@X5003o00So
oooo04P00?l002SO5P2eYIP0/:f]0:bXZ@2OV9h0;SIJ00<DEP045540PgIl0:R;N02^SgX0/YAk0;JG
O`2jW840^9n708anL02XUXD0Y9>5079/IP2HSH40d[RS0=BkY03G_ZL0f;fW0=RnY`3I_jX0g/J`0=_3
/03Qb[P0h/Zf0>?:]P3Qb[D0hL^f0>;;^03Ud;/0h<bk0<nh[P3K/Z@0eJVO0=f/W`3/]:P0m;fh0>6V
X`3HYj80/ijR0:Z@Y@2Q=e80_PTC0<452`2e6Ah0VTmP07MZQ@2=VJ/0ViFV0<NU[P3F/K80dJ^/0<RP
X030[[00blo@0<FiP`2mY@`0Xhh@07U`302^WPh0YiHS08B2J02FW9`0WjBW09fNX`2=Oh4A003o00_o
oooo000:ooooo`1F003o001XVD40O8Z@06ajP`0F1PL03P4100L10@010@404P4102`10P0_0080=P41
06`3202H1@X0Z0P=0:X:3P2W4Q@0^10?0<4<2`353P`0_A<=0;McIP3Pf]@0fmkN0=W@dP2[CDP0]a<A
0;lB3`324Q00aa0?0<DC3P2F7A@0e;Z]0=_Ie@3GemH0gMcM0=_Kf@3Of]<0akZ]07Ln<@2U7a/0U20M
05hF4P1D=BX0cKnb0>?Nf03OfmT0d[Fe09<a;@2R4Pl0Y0`>0:<:3P2O20`0W`T909X41P2M1`T0T`T6
0:ULBP3<]j/0eLk;0898@0231@D0RP4408d21`2:0P@0R08308L00@2P1PP0[@H70:l61P2_1`P0VP<3
08861@245QL0KaDF0:R3P@3:c<d0_<330<S;d@3;d]P0^lK>0;[6c@24TiP0Jfma07m]G`0Hc082003o
00Wooooo04T00?l005F4A`2T[k00]L?<0;k>e`2gbM00a]?H09fSX02?Sh<0Ui>70:2GRP2QTh80Xi=m
0:>DNP2XTWL0[I=d0:^DKP2]UFd0[I5U0;:BH02dUF<0^IUW0<6QLP37Z840aZN50<FYR039[H/0bk2C
0<^cUP3=^9`0d;ZP0=?0Y`3F`Z`0c;ZX09>>PP2IV8/0YZ6B0<k2/03E`k80fk:V0<YDCP3<61L0ca4B
0<h@4@3<3`l0cPlA0<D>3`2b7al0TTA?04Y3I00eA6P0KGR909fQY02i_/40/[Rn05]/OP1ZOiT0HX>M
0;[?f@37`//0XEQN09`<4@2>3Q<0WXZD0<;7^`2JSBl0P6lF06EQ2@2ES@X0X9<F07n3D`2FXIX0QY1f
00l00?l02?ooool0E02oXh<0WYjL09JAU@1S?Cd0AA8F0<Fi`03?em`0emcR06aZK@0Y2@d0=0<:04<1
201M3PD0eIhE0=^T3P2j@@X0``X70<H72@391PT0cPX:0<l82`3@2@/0dP/;0=D;303G30h0f@h>0=h@
3`3S5140`aDB08MLFP3/iN@0kNWZ0>[Xj03Wi^@0jn7O0=R@SP3??3L0iBLN0=PT801Q30X0cl6m0>g[
j@3`jnT0j/2o0:0a;@2LKfX0kNSU0>_[jP3ai>H0di>A07dV9@2nZJX0i^;S0>?Nh@3PfMX0e/>n0:]/
G`2?3`X0UP8209T20`2E0P<0TP4409811`2A0@T0S`470941102@0@D0R04408H00P2F2`h0XRPY07L6
1P1c0@<0MP8308072`1a0@@0H`4205`00`1G0@@0C04305811P1I0PL0G0D204NK3PD00?l02?ooool0
B@00o`00S:]W0:bZZ`2c]KT0Z:J[09R?U`1OH7X01A=<00@BC`1iKWH0XXId0:V<M`2_T7L0]IIm0;bK
P02WTWl0Q7]b0:>DQ`2DRX80L6e/0967O@3@]Z00eK^U0=BkY03F^Z@0f;bV0=VoZ@3Ma:l0flB^0>?:
]`3ObKP0h<^h0>;:]P3Sb[H0hLZe0>C?^P3Qb[T0f/Jj08R9VP2YIGX0bcU20=0V:`3>7B@0bQTL0;LM
7P30MX<0Hcm/0;<B8`361Pd0_PT;0:h94P2Z1aH0YCM605a?KP1k=E@0V@lN09XG902K8S00W3I40<2L
XP3:c]00`kMl0;fU2P2NRAL06QT505iM4P2<PQ<0Wi8M09R>>P2YXg@0YZFG09^DU00Cg@`04000o`0;
ooooo`002_ooool0EP00o`00K9i:08NFW`1gQY4030<400`10@070@800@4101L20P0c0P<0<`4203D1
0@1B0@@0SPH>0:@62`2]2@d0[`T<0;T;3@2m30d0```=0;LR6P3K]:P0gMkK0=cNg`3<ZJP0YR<L0:8B
401i3@/0P@d<0;dD4P2g81L0X5Q:0=cCc03HfMH0f]OF0=k?c`3Mb<@0hMSD0>;KeP30YYd0JRLO068h
:`2CP740clBh0>CNf@3Se]@0^YRF09E1?P2N5Q80YPh<0:H<3P2S2@d0X@X:0:48202P1PT0W@L:098;
1`2iO6T0fLk50<o5`@1g:b@0Q0@208T2102;0`H0RP8408T210250P80SP830:L61`2g5A@0[PL90:T;
2@2951<0ZeAF06dL7@2RM700]KBc0<36b@34bm00`l_D0<WCgP2c`LT0WZfd06Y`M023M6X05l`40P00
o`09ooooo`1:00o]2`2HWYT0]<;90;K5cP2P];d0UZbc0;72b02U[:h0SXn509NDR@2LUXT0WYB50:2D
P@2RUWl0YIEm0:ZDMP2^UG@0[99[0:b?I02bTV<0]IAS0;ZHJ@2oWg80`jN10<BYR`36[900bk>E0<^d
V03=^9h0cKRM0=:nX`3C_jD0el:]0=W6[`3Hak80f<Vh0=O8]P3Fa[D0g;V/0<UJDP3<6AD0d18@0<lB
4@3=40l0bPl=0<<G602Y@4/0ETU[03=<LP21SI`0_K^f0<6h]@38]KD0^9ZK0:^<RP2iYZH0Z:bc03iI
M`2Q_<d0b=CK0<Zn``2B<3H0U`T=07e8DP2oaKX0ZY/i0:NA3@1eJ@X0FeT;08n62P2PUA80V9=209^D
OP07m@@>003o00Sooooo05@0_::10::UY02DUIL0Gd9203d8302eYZ`0dMSM0=GLh01gN7/09`T?03H4
300l0@T0H1<60=RQ5`3LY100^3/90<8920361PT0b@L90<`92P3>2@`0d0X;0=8<2@3E3PX0f@h=0=`A
3@3Q4Pl0ha<@0=TF4`1k5AP0a:^`0>WTi`3Xi^L0inGU0>WWiP3fhMd0lZnT0=M:?03K9Ah0RaHG0:fB
SP3]jNP0kN[X0?;Mf@31NVh0]Hb00>cTgP3Yj>P0kn[Z0?S<b`2W;b`0OBH/0<N]/@3OemL0fmOG0>3F
e@3N^k40VS0U09@40P2F0@80T@4208h00P2@0@D0T@090982202A0@D0SP4508H11@2J0PL0[PH<0:PA
502Z9b`0LP0207H20`2>4AD0LP4406T2101S0P@0F`<604d10`1>00D0EP0705l50P18V`l5003o00So
oooo04T0<=DK0:RTX02_][T0/[Bh0:VVZ@2HSY80L6n600XGD0034dl0LVQb0:>6J`2[S6P0/Hm/0;FD
N02kVH00YX]m06m[J@1jMgH0KVi/06MVHP2`X8l0ckBN0=:hXP3D^j<0e;RR0=JkYP3H_ZT0f/B_0=[5
[03QbK@0h<Nc0>;9]`3SbKL0hlVf0>;:^03Rc[P0h<fi0=W8`P1DGH@0]DaN0=LG5`3L4a80f1LC0=Y8
>03?E440bgIZ06YKO@2P:dL0a0T?0<Ld<P2>AeX0S`/W0:d84P2;@5D0JcA<09h:502Y0P/0Y`8;0:08
302LA4T0dlk>0<:gQP2lYAT0[iLB040a2P1DCQh0:2D206YW5P2MSQ80[9/A0;>U@P2PTfh07=HB0100
0?l02oooool000[ooooo05H00?l0072SC`2DYZ/0L8>:00L310090@4010410080000I0P80=@4203L2
0@0j0P80AP8307L62P2N2@d0Z@P<0:d82P2f2P/0_Ph=0<4?2`30ACX0g/c50=kShP3Pg=d0[U]H07L@
3@1;7AP0I555085?A02T8A@0aFUE0<R`XP3If=H0flS70<F4P02nAd80]CD_0<:ARP3Rg=H0gmSC0:JI
RP3Fc[l0i>7K0>;Rh034b<H0NF1M05dV8`1G5Q<0GA<@078@402@4Q<0W0`<0:48202Q1`P0X0H909`6
2@2F6A80b9n@0=_Dd030[JT0NQLC08X310270@80Q`8308L210260@D0QP4308D20P2N1PP0[@H80;05
1`2Z2`d0ZSTn07hC502>92<0N2/Y0<Ji^@2l`L<0`<_=0<7<dP34d=T0^LOB09BT[@1`O880OGQb01G<
1@800?l02Oooool0BP13d3T0^/K=0;?4d@2J[k/0N9>M08FMX`2mbm80[[Fj08b>Q`2JV8`0W9J909jF
QP2RV8H0XYR40:2BN`2WUGT0[9=c0:f@JP2_TFD0/Y5T0;JDJ02jVFl0`:5k0<>WR034ZXl0aZjA0<Vc
V03:/iT0bkRK0<bhW@3C_ZD0e[jX0=K1Z`3H`jd0f/Na0=K6/P3Ga[40fL2^0==hK`3;7QL0e1H@0=8C
3`3;4Q00_A/J0;Tk@025E6h0<dIf06]hSP2UWIP0_jVO0;9lM02^C4X0[B@V0:HB502T3a80XQ`O0:MF
E`28PHl0SZFg0<OBfP3<d]T0ZWZ209<<4`1e:C<0ZkW10;ZkXP2VV2`0ZIP:08Ij2`1jL`/0ShD60:>H
3@2[W4d08MT?3P00o`08ooooo`1D0;nUQ02//;00TIFF075KF`0l2P/0Xi:E0<kDf@3EgN00PXF802<7
3`0f0`d0?04605T@0`3BWaL0fj<D0;He1P3120T0``@90<H6203:20T0cPX;0=0<2P3A30X0d``;0=L<
303L40`0fa0:0=lB3P3P4A40bQLH098J802TKWH0hMSL0>SWi`3[j^T0k>[Y0?;Wi@3d^kD0bS<^0:/O
802?I640kNWV0>c[j@3]j>D0lN;O0?3Uh03^j^L0k>_[0>_Wj03cf=L0_Ta:0:dC5`1l6Al0WWYl0=WD
d@3Kf=L0gmGC0<nOU02I<2P0T@D509411@2>0@<0SP4509411`2C0PT0T08508T2101k0@<0V`@90;83
1`2]0P@0Y0@808810`1j1PP0UAlR07011@1Z0@<0H@4205T10`1>0@@0B`4305<21@1N1080A9H:1@00
o`08ooooo`1904^o=02IWj@0/KRn0:BTZ@2^Zjd0UXn@06i/O@0<6Dd00Q1;06eRJ02aT4/0_iPa0<6J
BP2fU6/0_9V40;FGQP1[Hf80I69T07acJ`2PSgl0aZbG0<ncW03@]Il0d;BM0=6eX03C_:X0bkNV0=;1
[@3Nak80h<Re0=o5]03Tb[P0h/^j0>?:^P3RbkT0hljh0>;>^@3Ob;T0QXRR095]S0319BX0fQDC0<lJ
5@3gWXl0hK2K0=NdX@2BS9`0O3UQ0<0<5P2f5AT0[WV406D?=P2a1A<0ZCY405]6G@26:3H0X`<;0:<4
1`2]?SP0UV5K0<[6a`3=c/L0`;AU0;bU4@2[TAL0LUlH03P`2@1HFB80I5/?0::I6@2]Wa<0Yi</02?L
400@003o00_ooooo000:ooooo`1F003o001]XT`0RYfQ06UhP0080`@00`4100400@010@406@8103/2
0P0o0P80?`8304P1101R0PH0Q0D<09l73@2/1`/0/`X:0;`;2`2o40h0afIL0>;He`3Ph><0eKZi090X
8023EDP0`[FX0=;<``3Lb;h0Y5Y50<bKR03KdLP0fMKB09QYHP2@9b40QAXD05PD3@1VCd80clJk0>;O
fP3Ng=H0gmgK0<_>c@22RX@0B59906]TFP28O6l0Rgmb07]`I01DAS`0<a4>068>3`2I30d0X@T:0:87
1P2N20L0X3DU0<bbX@3Hd]40Zhb8084>2`2<10D0RP<408D10P250@<0Q04508@20`230@80S`<40:/8
202^1`P0[0H70:H93@2C4Q<0TA`K07hR8030Z:P0/;Bf0<O?d`33c]D0a<kG0;_5d02@X:P0M86607A`
JP0Fc@L2003o00Wooooo04X0C/e90;G2c@2Q]L@0JHB@04QVK02L/KL0_/kE0;Fo``2<SXP0UYF:09VD
R@2KTHD0X9F40:>FP`2QTW`0Y9=i0:ZBLP2[SfT0[hmT0;6AJP2dUV`0^9]b0;bNN`33Y8H0ajZ@0<J/
TP37/IP0c;JN0<^fWP3=^Z40dKjU0=>nYP3G`J`0e/:[0=S4[03Ib;40f/Rb0>2VU`34:B<0daPA0=DG
403=5A00^S@c07aHM00hAgD0A6680:2SY`2jYYH0_hAh0;4k>02`4A80^@X<0;T72P2b1@L0/@H70;46
202[2@`0WD9=04ACKP2nd=/0b=7J0<>a^@2;6R80PB<]08fKZ02kal`0^[VA0:ZK5P2WV0D0X94706mV
2026P@`0XI<?02OP20h00?l02?ooool0E02k[h<0Zjj^09VMX01dHf<0@0/=09^2QP3Fg>@0dMOO08jA
U`0V2140?@D>04l73@1Q4`@0dj0G0=bP5P2a:`D0_`L80<<72P341PT0b@P:0<d:2`3=2PX0d0/<0=<;
2`3F3@h0f0h<0=d@3P3P4Pl0hQ8@0>DD4P3R5aD0bQ/N098e>@2`Ti80in;N0>c/i`3/jnX0m>WW0==b
K`399240X3<`0?OHeP3cgn00m>7R0?COg`3fgn40mMkQ0?CNh@3_gMl0m]cM0=N2P@2n41<0^@dB08X=
4028Hf80d/_80=cFeP3PeMH0ek:]09<Z9`2A0PD0SP8408`10`2<0@80S`8708T01@250PD0J`4307h2
1P2U1@T0Z@820:T2102>0P@0N08607P21@1b0@@0JP4306410P1H0@<0CP4504H10P1:0080HP@304:B
1PD00?l02?ooool0B@1UYdd0UIfV0:Z]]P2]Zk40[JR[09ZBU02HTj0031E300<@B01^I5X0`9lU0<VU
3`2jUCX0/i5X0;JDO@2iV840XhQh09b8N`2dW8P0bjnH0<b`V@3>/Y`0ck>M0=2eW`3@]j80_JZI0<6/
W02iZIT0flFd0=o8]`3MbKH0h<bh0>7;^@3Rb[P0hl^g0>K@^`3Rck`0hL^j0=C4_P2:QYd0UF5h0<<d
>`3A5QP0d3<d0=MVH@3NVXh0cKg005a1K02`52<0^PX?0<5/M@1W8dX0[@HJ0:<C6P2dUI`0JTeR08/J
:02N1@d0YC<e0<na/P37b/d0b/kE0<c;^@2mZdH0_J<:0;NO3`1XEP`0EDlJ065I2P1oNR00N6l<0:^J
5`0af0/04000o`0;ooooo`002_ooool0@000o`00KZ9<08^NX`1AGVD02@840080000000000P000283
0`0k0P<0?@4103l10@1=0PH0H@8:06d01P2D1``0[0P<0;@82P2l2PX0_a4>0<UeK03Ug]h0h^7R0;fD
T@2=<240ckBW0=GAc03Ce]@0f<_60:EZF@3C/J80gMOC0=3;aP0j;B<07P`302PJ3`1nM6D0bKn_0=gG
c03Ng]T0g=cH09^QU`1HGU40Wj6C0<k7^@3Kcl@0h=G=0=kEcP3Md//0bkjb0:bNT`1:91l0Ra0D0:8;
3@2S2PL0WPX80:Q??@3<_K00eM3?0:=iMP2830`0S`<709052@270@@208810`0D084100240P@0R@43
0:<62@2Z10H0[0H60:h92`2D1`P0QPh>07DF5`3;[k<0`lG80;g6b@2iaLT0aM;I0;K6cP2S];/0MH>7
071]J00FcPP2003o00Wooooo04X0SI=_0;72c@1iTZ00?eeV05=`M`24W:@0Vk6f0;g9c029Sh/0UIF<
09VFR`2KUHL0WIJ50:6CP`2STgh0YYEk0:NCL`2XT6X0[8mU0;2AJP2dUg40^Iej0;ZNO`31YHP0aZb@
0<J^U035[iH0bkFN0<jfWP3?^J40d;jW0=;0Z@3F`Zd0e/>/0=W7/03JbK@0h<2a0<QDC03C7AH0eAL@
0<lI402mATP0EE5e04ESR029UJ@0^JnW0<RZW@2oJf40/AdJ0;`=3@2h20X0^@L;0;X62`2c1PT0/@H:
0;852@2`1@P0WaDK06QMN`2AZ[h0a=?K0<S7cP2<;cT0Qb8]07^8V02kbm<0`l_30;J_G@2ZVA40Y9@3
08Ij2P1?C@@0Rh@=04Zl1`h00?l02?ooool0E02Ib7L0`<?509fTY`1kKFh0?P/>095aN03Ef^40c]SN
09JJX@0U2Q<0=`8:04@12`1M5@<0eJ4E0=bP5`2]9080_PL60<062@3010P0``D90</92P3:1`T0c@P:
0=082@3C2``0eP`;0=/>3P3N3Pl0iA<A0>PF403X5a40iaLD0=LQ7P265aT0WH600>_Yi@3/j^/0lNOW
0=AgM`347QX0`T0j0<5VIP33HFT0cV9Y0<EGG034EU`0beeU0<EMI@2iGVH0aVa_0<iCDP2o40l0]`D:
0:/62`1V2`h0NF=O0=S>cP3JeMH0h];>09m?BP2?0PD0SP8408/10P2:0@40R04208H10`240@80JP43
05d10@1n0@<0V0<409`41`1m0@<0LP8607/11P1g0@H0J`4106400P1G0040C`8404L10P1;0040J`<4
06IM20D00?l02?ooool07@2>TWT0UJ6_0:6U[@2SXjT0Z:J/0:ZQY`2<Q90092eH00<AAP1gJSd0aJ@=
0<NV1P2oVCD0[hib0:nBO02gV840_if60<6PRP33Y8l0b:fI0<^^VP3:[YT0ck>M0=2dW`3;]:00`JbJ
0=FlZP2mZY`0f<Bb0080g/Rf02X0gLVh0>3;^@3Rc[/0hL^f0>?>^P3TdKl0i<jm0>3:]`3JakT0]j^b
07e`T02eDV@0c1DH0<l@4@367Ql0dH1k07Q^RP2F;dd0`0PA0;/F7`2/7S40/0HB0:`53P2ACEP0`L?<
06EAJP20:ch0U`XF09`b@03?^/40algB0<S=d`2o^iH0_j`c0;RQ1P2eW`T0X8T?07]Y301]HQl0Hed?
09F=6@1L_@l@003o00_ooooo000:ooooo`1F003o001UUT40GFa_055MH0040P800P41000000030000
8@8303@20`0a0@40=@4104X21@1N0`P0I@<808042@2[2@`0]`T:0;h;2`2l4@`0c81e0>?Qh@3RhnD0
RGad08YYG@3Pf=@0gMcM0=_If@3DZjX0]5]>0=^eZ03MfMD0f=?A0:JKT@2NU8H0^JfO0=;:`@3Lf]<0
g=gF0=gMfP3=akh0[JVF0=KDa03Ng=80g]_F0=kLfP3OgM`0g=[J0=gKg03MfMT0fM3;0:^FS`1i61H0
W0/;09d81`2H3@T0]G1M0=;:`P3GdM00U61L08d<302B10P0T@<608d31P250@@0QP8608<110260PD0
Q@8709T62@2/1`P0[`H70:d6202R20/0R`L:084>4@27@dD0^[Bd0<S?d`2nb<d0`LgE0;S7d02GZ:l0
O8Z?075^J@0GcPT2003o00Wooooo04X0WHmj09NY^@17IW@0BfYc065nQ02O/k/0PYVP0<C?e@2;TI00
TY>=09ZFS`2IThL0W9J509jCP02RU7`0XiEk0:JDMP2ZTG00/9A^0:nCK02fVGH0^Imo0;^SQP31ZHd0
aJbB0<J_U@36[I<0b;2H0<ZeW03?^:00dKbU0=6oY`3Ea:`0e/B`0=K6[`3Ja:l0fiF90<TU703E61<0
cAPC0;U:CP1;DWh0I7fJ0;ZcZ`33/J40bjRI0<9NEP2h4a80_0X=0;`8302g2@/0[`/<0:XJ7P2M;SD0
WBX`0:T93P2_1@T0XA4F05=7J01dUk80`]?L0<[;e@2@?4L0RR<^06mlT02jb]H0_lkE0<C:_02^XTD0
Y9@909nB102CQP`0NW4905^^2`h00?l02?ooool0@@2JbGT0^[k109fUZ024O7`0@14B08AQIP3Aem`0
d=[O09jTZP0P2A40=@<<04422P1R6PL0fZ@G0=nK6@2^7P40_PL80<052@321P/0a@D:0<X82P3:1`/0
c@T<0=092`3E3@`0fQ0=0=`@3@3Q40l0iQ<@0>HF3P3Z5a40iaH@0>8K5@2a7ad0UVMR0>kUh`3_hn@0
m/oC0<I3B0327A/0XdI40>fj]03PUI40fGMd0<INF032GUL0bFUT0<M`K036NWH0dX9m0<m/H@30?380
ZA<>0:D92P1_2@P0KTPl0=K5_`3Pe]H0gLS309Y9@P2B0P@0T04208h10P2=0@80R@810080QP410140
N@@405/5101S2`/0K0@606h11@1N0@<0K`8508411@200PH0LP4206X1101O0P<0D04304L10P1?0040
K`<4069H1005003o00Sooooo04T0XYfJ07B4U@2NYJ`0Zjbc0:FTZ@2SWZD0S8B?02H]DP0d<b/0[Y8K
0<BW1`39Z@<0`Y`V0:b:J@2ZSGP0]9En0;^KP`2oX8X0b[>S0=[=a03Kc<80b[:R0<faV`3A]9h0e;^W
0;VUU`2nZY`0ak>S0=[5/`3LakH0gLFc0=o9^@3Qc;d0glbi0>?>^P3Sd;/0i=;00>??_03QbkP0g<Vj
0;:/]02OPYh0_eM]0<dH6P3B3`/0ba0:0;Xl;`2hW:<0IcaT0;D>702l1P`0_3@i094;8P2]0a00WR<]
07YgTP1SD700Pc540:0E7`2Q1@d0XDaC0<k;d036c=L0alg?0<O4W@2o[3L0^:4=0;BL0`2^U`L0Yi4>
07i[3P2>P1X0=^0>01000?l02oooool000[ooooo00D00?l005:3:01aP7`0EFIV00420P0200410@0k
00<10@0J0P40;04203410@0g0P80?`4104X10`1D0080L08709h9302i2``0_``:0;hA3P39MFh0emCD
0=GGf@2d]:h0^[Nb0=CFeP3Idm@0cZVV0;0k=P2f8QX0c7E[0=o2_`3Me]H0gMKG0>3Ge`3Pdm40cl30
0;>^Y03FdLT0gmgJ0=cGdP3Uhmh0iNOS0>7Rh03Lg=/0gMgM0=gMg03Lf]X0gM[L0=_Jg03Fe]D0f]GA
0:5SG02D3P`0VPL909LE3`31T7d0f=;=0=O@b`2;CTD0S0P709H62@2C0PL0S`8608L20`250P<00P26
0P<04P230`L0R@840:H92P2/1PL0[PH90:T:302A2@`0W2TY088S8`33[k00^;o10;>n`P2nbm80^LSC
0:noa`1lSY<0Lg5^01S?2P800?l02Oooool0BP2JR740SZ6^03iNJ01;Jfh0KXZ@08fT[@2G[K@0`m7F
08ZBT@2BU8h0ViJ?09ZAR02LUXH0W9B20:2DOP2SUG`0Y99f0:ZCM`2`UgP0/YQg0;BLN02jY880_:J:
0;jYS`32[940aJfC0<V`U03;]9`0cKNN0<beWP3?_:L0d/2X0=;0Z@3D`Jh0e/B]0=g2[@3<I5P0eAhD
0=<G4031;R/0K5f004Y^U@2i];00a;:P0<Z_W036NFl0^aTG0<4<3P2k2@d0^@X<0:PA4@2N@4P0Jdm[
02H/EP1C>eL0X1LN0:l62P2O9BT0AT]^039IP02jd]h0b<cE08hkA`2;8c00K7N=0;G7d@31cmL0_/S;
0;2]Q02XWC`0WHl80::A1@2NT0/0I9873P00o`08ooooo`1D09g>OP33b<T0X:Z[08=oOP1=9BH0MdeC
0=GGh03?en00[K2g0209400b0`P0?`<706/S2P3JXa@0f8TG0;4H0`3220X0aPH<0<L72`381PP0b@L9
0<P72`3;20/0d0T:0=H<303H3P/0g10:0=hA2P3S50l0iaH@0>LD3P3Z5a80gQTE0<0b<P3^TY80iHZ@
0==RJ`3;>3d0dQTI0=<F502g6Qd0^7Ml0?;Lg@3dj>L0lNOS0??ZiP3`j>D0l>WX0>kYi`3]j>H0knOR
0>kDc`3P[ZL0^UmI09@W8@2hHEL0^Fm[0;E/JP2UBDH0TA4?09D10P2A0@40T08108l20P2;0@40Q`40
08L10@240`80T2LR09eDD02<Bd/0E`<506<1101l0PD0Q`@808X32@1l0P@0KP4206@10P1D0P<0A042
05810P1b0`@0HUD41@00o`08ooooo`190:^UX01UMHD0UIbU0:>SZP2QWJ@0X9^Q09nIX@0b=SL0YXlP
0:f?3@28L@X0ajD;0;NB902fTTd0[8]_0;JEP02jVhD0_Z>A0=g@bP31/J/0akF/0=:n/P3=[iX0dkJS
0=BkZ@3F_J`0fL2`0=[3/03IaK80flFb0=o9]`3Qbk/0h/fl0>7@_`3Qckl0iM:o0>CB`@3Ud;h0h/fk
0=K7``1GH8P0]T=G0=@E6P3B40h0`@l60=aKA`3O[9D0b[F]06EJNP2N9D00^0T@0=>0R0198U00W@PR
0:D7501M9TX0KS5;09X95@2V0`X0Y0T;09Dn>@3=alX0a<cF0<7;e038cll0`l:Q0<FkNP2dXRd0/j<?
0;FR202iY@X0ZIHD04S03P0@003o00_ooooo000:ooooo`1F003o001@Ob40Be]E04MGE`000@400P41
0041000200406@<102820@0/0P80?@8304010@1>0@@0G@4507@42@2;1@T0/Pd>0;h;2`323@/0_SLd
0=jh^03Mf=T0f]SG0=?<b`3:YjP0]V9Q0;4X9P2n40h0aA4@0;hG5@2o?S/0cWYh0<]mO@36K6/0^4m>
07Td;`2l[Z40hMcF0=kMf`3QhN40iNKW0>GVj03Rh^@0g=gM0=cMgP3NgMd0fm_K0=[If`3IfMX0fMSJ
0=SGf02iThd0TA8A09d<3P2N:al0bZ^L0=WDe03Jc</0Qd8k0909202F1PT0T08608h21@260@<0QP<3
08<20P240P<0Q@<508@1102D10D0Y`L60:`72`2/20`0Z0/?09P83@2A6aP0XG]h0;:f^02ka/T0^lS?
0;k=eP2EYZl0QIFJ07=^JP0Jd@/2003o00Wooooo04X0XhY[08ZIY01?Jg80IH:607fIX01mVJ40NiJM
0;_<d@2@VYP0TiB>09FCRP2GTH@0VIB409^DQ02PUhD0XIN20:BFO@2/V7h0/IUh0;2IN@2hX840_:F5
0;ZWR@31[I80aJfC0<F_U039/YH0ak:J0<ZdW@3<]Ih0c[ZT0<nlY@3B_jP0d/6Z0=O4[03R_JX0aCdf
0=LK5@3<81P0Wei^03AFQ02[/kT0a[JW0<n`XP3>Sh<0]BhY0<HB4@3130h0^@T;0;<W9@1lBEd0=3eW
049FNP2=TjT0WFM`0:D?4`2X2Pd0RD1?03Q>LP1cSjT0[/SH0<S9e02?=d80RR@b06EcR`2ebM80_LkE
0<3=e@2ob<P0]KVR09VD@02LT0l0Y9H;05bO1Ph00?l02?ooool0E02b_8D0_/G70:>]/@2@TY40C2h/
06Tk@@3Fe^00c]SQ0;6d_P0T2Q@0<P8903l21P1c:``0fj<E0<mg4P2b50D0`@H:0<D530381P`0b@H8
0<X82@381PX0b`P90=8<3@3C2P/0fPh<0>0B3@3S4`d0iQHA0>@D3`3U50l0jAPA0>TI503O7A/0gR<T
0=@I7`3A4aX0eaDF0=HC4`3E4a@0eaHI0;hQ:02Q?dP0gJF]0?OKh@3iiNT0m^?V0?SRi`3fh>D0m]cP
0?KLg`3VdmD0h]CC0>_?b`2XAT<0W0`?09d7302M1`/0VP<609P10`2G0@80T`0109<10P2=0@80R`82
08P20@270@<0Q`4408441`2?9bH0XdE309LW:0210`P0R04608h32P2@0`X0P`4607D10`1Y0@80EP42
04X10@1M0@80MP8306MH2@D00?l02?ooool09@2bY9P0HG2009BOZ@2NXZL0XZ:V09nHV`2CRHL0M6Le
0;bP501kHP/0U7P=0<JR3P2mVQX0`I`^0:f=JP2cTGl0_9b80;jUU@3Md</0_ZbR0<ji[@3?^:/0ckBN
0=:fXP3C^JH0e[b[0=RoZ`3G`:/0flFd0=S4/P3Lb[H0flVf0>3=_03NcK`0hm300>KB`@3Ud<400P3O
bk/08`3Kb[l0Q8NP09=VP`31:S80cQ0C0<`A4038:BD0e7ea0=FfZ@2FRI@0KBmE0;D;5P2h<SP0Z7^G
08T:;@2^10h0R2<g05=0H01l;T80U`dG09X?4P39Wi`0bLcA0<?:e031b]@0`lcF0<G>e@37c]<0/kR[
09nVN02`/FL0]Z`k0;^U6P2KUaP0=MX:00l00?l02oooool000[ooooo05H00?l005:0801YMG00B5MG
00010P020@400@4000800@0H0P406@0001l0000g0`D0@04105L11P1^1@X0N0<708@52@2U2@/0_0`;
0<4<2`2o4Ph0`e5@0>BZZ`3AYJ@0]gIc0:D/:@2c4a80_@h;0<8>2`3640d0aQ0<0<LD403561H0`ALH
0<<K6@2M6QH0REmA0=gEcP3Nf]X0h^7P0>?Si@3Vi^P0iNGW0>CTiP3NgMd0gM_J0=oJf03Nf]T0fmWI
0=_Ge`3Jf=L0fMKG0;VFTP2A5140U`X80:A2<@3;^:/0e=?D0=_=b@28?CL0T0L909432@2=0`P0RP84
08T30`280P<0Q`4208@00P240@<0Q04508P00P2T1`T0[@P90:l93@2^2Ph0V`P;08L?3P2RL700cL_=
0:Rc]@2mbm80]/K@0;S8dP1mSI<0MWAa02Jh3P800?l02Oooool0BP20[UP0TIfS06AnQ01dSYD0HX28
08NSZP28XJT0[Kg209RRX`2>TH/0TI2:09:?P`2ETX<0VYB409jHQP2RVHD0Z9V20:jHP02bW7d0/ij2
0;RQQ@2jXhP0^JJ70<:]TP35[I<0`jfA0<F`U036/9P0b;BL0<ZiWP3;^Z40c[bT0=2nY`3B`Jd0eL>[
0=ZNSP3991d0e1`E0;eBE`0lD7d0W:Ne0<fl/03:]ZD0bHQn0:dZ9`324a80aPl@0;`>402h2`h0/34d
06UCJ02<SiD0^jRS0;=`KP2S6aX0Y@d>08hmB@0T;e/0FGbO06R8X01/SjD0`l?>08X_=`259c80IWZ>
0;?4cP2mc=H0_LcE0;G3c02d_/L0VJNS09:LM02MV3@0Q8L?3P00o`08ooooo`0V0:nfP@38c=40X:f`
08:6Q`1aEUL0H34e0=KCg@3?e]l0/;Fm02494P0d0``0?`@906d`3P3JYAD0`f@@0;<A1P2o1PX0a0H<
0<H62`3:20X0b`T90<`:2@3@2P/0dPX;0=H<3P3M3a40h14=0>8A3@3U5A00ha8@0>TF4P3X5a00jAPB
0>PG4`3S5Q@0e0l?0=@@403E4Q<20=DC4`0/0=TE503J6AT0e1hP0<LV;@38@DT0eU]S0<eBGP3BE680
dE5N0<e;EP35@d/0/T=:0:19D@2/LWD0c8b7098@3@2T0`L0XP440:01102L0@@0V04409H10`2F0@D0
T@4308h110290@<0Q`4208L110260@H0P`8708H4202:0`T0S@<:09032P2E1@d0T`@:08H11P1i0@@0
J`4205X20@1C0@40J`8307d3101UEPT5003o00Sooooo04X0XlF;06EdQ@2?W:L0XJBY0:VUYP2]WH00
Y8Y20;VJ902ENP`0PF/C0;ZJ3`2aSRD0ZH]90:f>F`2ZRWH0[i1n0;NIQ`2oWhl0bKBX0=;0]03<]jP0
c;:M0<fbW03?]9l0d[NS0=>lZ@36]J<0eL6`0=_3/P3I`k40g<Nc0=[9/`3PcK`0h<fm0>CB``3VdlD0
i]C50>?B``3PcKh0g<Vj0=K6^@2YWjT0RFf30:e6D02h7b40aa<E0<8C4`39FeD0bZRO0619J`2W7300
]`T@0;8N;P2[21H0/0<;0:8K9`2^V:`0R8>J0751E`2@5200TahZ0<BS[@33bM00`<[D0<OAfP36c]L0
`lcF0:jha@1CH6H0Mgma096FO`2dZDT0_J`M06S75`l00?l02oooool000[ooooo04<00?l005:28@1B
HE/0BEQG00420@030P400@0000<10@0L0@80;`8303D10P110PD0D`<506P4201_2Pd0M0L;08862P2I
1`L0]`h;0<4=2P363``0a1HB0;TN702`8Ah0[QHC0;T?3P323`d0``h;0<D?303540d0a0l<0<HA3P37
4@h0_aDB09dF5@1_;RH0bKV`0=kJf@3Mg=d0i>CT0>CUi`3UiNL0in?V0>[Ng`3M^;L0`h>20;1YJ@2]
Kfl0dkbh0=WHeP3FeMH0fMGG0:b1O@2A4Ph0U`h;0:QC@P3>`[L0d]?C0=K:a`2:@c/0TPP909@42@2;
0PH0RP8708T210280PD0Q`440080QP850140Q@8608820`2K20P0[@P90:h8302_2Pl0[1XL08<;302A
DE80b<?40;O2``2mb]<0`<oJ0:>c_026UYd0Lfm_03BQ4`02003o00Wooooo04/0JKDl09FQX@1hSYT0
JhRB07fHWP1kUYl0Rj>[0<3>e02JXZ<0Q8N208^:P@2BTX@0UI>509bFQ`2PVHT0Xib90:VLR02_VhD0
/Yj50;BNQ02iXHP0^jB:0;VSQ`2nZHl0`JbC0<6]T@34[9D0a[2I0<NeW039^9l0cKZS0=2lY@3B_jL0
e/:[0=O3[P3AOFl0dB0H0<T^:01iH7l0PWVG0<UlNP3@RX00eJnQ0;E5@03161P0aa4A0;H_<@24AEL0
VT9;0:`F5P2a?SL0_h9d0:]3?@2Y4a40X1PG07PnD@0T=F00JX:O09n/]P2:XK80UkG70;^kb02792`0
P2Tf06Z0UP2jbM@0_/_F0;g=f02ga]00/;k909>U]01NKVd0RI9]09V@;00Rf`D03@00o`08ooooo`0S
09_8N@37bLh0XZb`08bAU01aG5l0Db4V0=;>e@36dML0/;Ro024=500f0`d0>P8507Hl3P3LXaD0/DL7
0;P?1@2n10P0``H;0<@52P371PX0b`T:0=0:2`3C30/0ePd:0=X?2`3L3`h0ga0>0=d?3P3Q4Q40iQ@A
0>HE4@3W5Q80j1LA0>LG4`3K4A400P3B3Ph02P3D4Q40e18B0=TF4`3N61D0gALE0=lI603O6QP0gATE
0=TG5P3B4A<20=DC5@0S0=<A4P3A4180_@T>0:l63@2O1`h0Vb<U0:@J6`2T0PL0X04309l1102O0@H0
W08809X11P2I0@H0U04409411@2>0@D0RP8308L10P250@<0Q`4408X1102A0@P0T@8:08l22P2F10d0
UPD=08P11`1n0P@0L@8205d10P1R0@80M`8307h2101Z@`D01@00o`08ooooo`0S093@L`1gPi@0PI2L
09nSZ02_Yhl0]ih]0;^M2@2]T0h0L5T90:f>3P30W0l0/H/i0:B4I02RPgL0Z8Yl0:f>P@2eUhD0_Yj;
0<BVTP38ZiL0bZjI0<V^V037[Y@0c;:K0=6eX@2oZi/0]jZL0<JcX@3I`Zl0f/Jc0=[9]03LbkP0g/bl
0=o=_@3Scl000P3UdL<09@3Wd/D0hlk10=g9^P3Ha[D0eLBf0<fm^@2EQI<0O6=h09]BH@305a/0_a<@
0=2:OP2JSIX0YV9^0;Pj=@2`=Rh0Zbl[0:LX:P2K8BT0Wg^70<[AfP2_/;l0KdYP08XD9@2>82l0a[Nn
0<?<e038d=X0aLgI0;o;eP2fa=80L8FL07f@WP2AWZ@0X:>;0;>bO@1jO4X03`00o`0;ooooo`002_oo
ool0EP00o`00B7HE03a:@`18EEL00P4100<20@0000001@4002820P0m0P@0BP8405D21@1V1@P0M`dA
0:Ld=`2151L0O0@909041P2Y20T0`0d;0<L>2@3940d0```:0;X:202g2PX0^P/:0;/<2P2k2@P0`@d:
0<8=3@323Pl0`a0?0<8B4P295@h0Kd4f0;j]Y03Lf=L0fm_L0=kNgP3ThnD0jnCV0>g7b03STiH0f5iN
0<HZ9@2o71T0Z18A09lI5`2WLVT0f=OD0=?FeP3Gc/h0TDM209T@3P2C40/0ZVMF0=7:a03@cm80f<g>
08Y;A02>20P0TP@808`21P2;0`T0R@8608P110270PD0Q`8608P31@220PD0PP@709041P2^2@d0[@P<
0;0:3P2/3@h0R@/<09IKE02c[JP0WZRY0;G4b`2lcMH0[[o:086AV@1hMGH0=Z<G0P00o`09ooooo`12
05?3;02HXIh0S::]06R6S`1YQXl0LhjE086MY@2S][`0XZR[07j0N`29RH40THj209^GR@2LV8X0Xib<
0:^RT`2`XYH0]Z>C0;NSS02gXHT0^j><0;RSR@2iY8/0_ZZ@0<BaV@32[9@0a:fF0<R`V`37/id0b[FP
0<fiXP3@_JL0dKn[0=?1[@3G`Jd0cFaP0=4N5`33DEH0V6Z20;``>@3<6QX0^BHS0<ZCU02/<300`a@C
0;lF5`25CV@0D5j00:Z?T02gAD40/``<0;<B4`2Y4a<0USDm04/hF00S?6<0V[?20:bh_P1eR9@0E6j5
06F5W02a[;X0R1TR07P[>01eSZ80^/_G0P30c=T01`2oc=T0/<7<09^b`P1ONhl0RinQ09bLLP0idA`0
3@00o`08ooooo`0g09W6L`36b<d0Zk>i08B9R`2;O7l0@QHI0<6m`02jalT0/k^n024>4`0d10X0?@D9
08=:403MX1L0YRl00;/<1`321`/0a0L:0<L62@3<2@/0c`/;0=8;3@3F30h0e``;0=T>303H30d0fPd?
0=`>403S4A80i18B0>@B4@3W5A80iQDC0=`@3`3F3Pl0e`lA0=D?403D4A80d14A0=DD503H5AD0fQHE
0=dH5`3M5aH0faHD0=/F5@3G51D0f1@D0=<@4@3A3Q00c`dB0;T5302^0@P0[0880:L22@020:D12@0K
0:82202Q0@L0WP8609/11P2K0PL0V@4609D11@2A0@D0T086090210280@40Q00208@10P290@D0T049
09822`2D1@d0U@@;09@42`290PP0O`4607H11@1X0@<0L`8307P10@1m0P<0Pa`900D00?l02?ooool0
B`1[gE<0PHVH07f9V02RXj40/9i?0;NJ2P2/SPd0JUD9095h3`33X0T0[8TZ09QiI02KNgD0Y85l0:R7
O@2/SH00/iF60;jNS035Yi80b:VD0<BWT@35ZI<0bK2H0<fbV`3B^:40cKJR0;n/V@3C`:/0el>_0=[5
/`3JbKD0f/Vh0=c;^@3OcK`0h/no0>?A``3Td/<0hm320>;@`@3Lb[T0fLNg0=K5]P3FaKD0dL6i0;Jb
`01KFGP0/d=60<0k:`3DXI<0Si2J09^EY031TXh0bZRW0<:^]02^UjD0LEeb07EdQP2iaLh0b];F0:BZ
_01M<4/0R0XF0:QkP034cM@0aLoK0<K?f@31cMH0_<OE069eSP1eRI/0T9jW0:6YZ@2TZZX0JFI`00cX
1`0>003o00_ooooo000:ooooo`1F003o0011KP`0E65H04eIF`040P801@8200<1000@0@40<08404L2
1@1;0@D0CP4405P31P222@/0W0P:08/92P1f1@L0SPD809T31P2c2PX0`Pd90<H?2`363``0`@h;0;T9
2@2i2`X0^0X80;`;2`313@/0`Ph=0<4>3@314100W1@B08MOD`3<a;T0g=SF0=[Jf`3LgMd0h]kM0>W=
c@3JOh<0dSLf0=LO7@3L7Q/0da/E0<dJ5P2h5a@0QAXE09N0M03Gf=D0dmCD0;JGU@2<71X0V@h;08`A
2P2aNFX0eM3<0=3@dP3FdM40SV9L08H;2P2@0PD0SP<508/31`2;0PH0Q@4308<10`220@D0Q@8508P3
1`280`P0R`870:P8302a20/0/`/>0;0<3@2=30`0YGUa09BDR`2:UI40^<G;0;C4c02hall0QYJM06m[
K00hYAT2003o00Wooooo04/0AlHN09NJT`20Uj80MI:N05IhO@1SP8<0SJF/08FIX@2W/[D0NGei08F5
OP2=S880WIR>0:FNU02/YIT0/ZNK0;BWVP2dY9D0/In=0;BOR@2hY8/0^ZJ<0;VTR`2lZ8l0_jZC0<6Y
T`34[YH0ak2I0<NbV`39]Z00ck^V0=2nZ03@_j/0dl:^0=K2Z`3<MfT0cb4K0=1FFP39D5H0dQXI0<`H
5@2aAT`0EUUg0;1RIP2`81l0_Q@E0;T_=P2gB4X0/S4/0;8E4P2h2`d0/B<P064e@`0^=f00FEej09b>
S@2bZ:@0^kbl0;G3bP2K/Kl0GGbE09^@W@264AP0LBXi086J/02jbm@0_<gI0;o>e`2od=/0//GC09jb
`01TP980RYnW09ROW01AZT<03@00o`08ooooo`0X09W4M035b<l0WjV^08F<SP24NG/0?A8D0:jVZP2f
_l80]Kc0028=5P0d0PX0>@8508YD4`3HV1<0YR<30;`;2`331`d0``D60<X:2P3:1`P0c``:0<l92`3F
30l0d`T<0=H;3@3K3Q00f`l>0=`@403Q4100hQ4@0>HC4`3Z5a<0ha@A0=P?403G4140f14C0=0<3`3@
4100dQ@C0<hA4080da@D02X0eAPD0=@O6`3=9Ad0cR@O0<dO7@3B6aX0e18C0=LA4P3C3a<0^`D<0:l2
202/0PP0Z@8;0:D1202S0@L0X@470:421`2P0PH0W04409X11@2H0@@0UP8409401@2?0@H0T04408T1
0@250040QP4208P01@2>0@T0TP8;09<22`2F1@d0U0D<08T1202100P0NP4707H010230@D0N00107P2
0P207``5003o00Sooooo04/0C=lf09nT[P1kQi80YIaZ0:nF402WS0T0Led807EN302bT`/0/Y4K09=f
F02DMg@0VgYi09mmNP2XQ7h0Zh^10;2AQ@2kVhX0`Z6>0<>ST@36ZiD0bK2J0<^fY03>]Z@0d[VS0=:l
Z03C_Zd0e[n]0=W3/`3JaK@0f/Fc0=[8^03Ob[T0glfm0=o>_`3Pd;l0hm;10>C?`@3Qc[l0g<bj0=W7
^03Ga[L0e/Bf0<fm]02OUiL0/JJW0=2^W@3A/9/0ajnR0<Ng/P25N8T0SE=S0:0e@`2T:SX0YB<c0:4M
;02K9SH0XDAF0;R1T@2ZX[80NFQg08M9B02_ViT0a<gD0<K?f@37cm/0a<gH0<?<f@1<GW`0G7B;07>1
S`2AVJ40U9bT06IZNP0W_Q`03P00o`0;ooooo`002_ooool0EP00o`00A7<C05aYH`19EeP00`4100L1
0@0:00007`4303l31P170@@0AP<404810`1:0P@0QPX@09D:3@1d1@L0J`<408/41P2B0PD0Y0D60;`<
2@302`T0a0d;0<8>2`2i2PP0^P`;0;/920333@h0``d<0<8=302o2`X0]Q4@07HW8039_[D0f=SF0=[J
f`3JfM/0hm[J0=nd/`3;Fe/0eRLU0=hO6P3E5@l0daHB0=0G50366AH0WAXG068^8`38`[P0e]KD0<Zl
_02@BDP0UQ0>09P<2P243`D0]XIg0=GBd03@dM<0dmCC08igL`1h3Q00T@@808l31@2:0P@0Q@420881
0`1n00<0OP4408<21P290`T0R`@:08T31`2Q1``0[PP;0;8:302d3@d0W@/>08i6@P2STh`0TYRE0:Rg
^P2nc=D0/;g608nPYP1fMWL0>ZPN0P00o`09ooooo`0D02KK3@2GTXD0Ujbf05YgP01OOH<0FgUn05]e
O@1jSI40/;Vl07IiM`21PGX0S8Uo09RDRP2TWiP0[:FM0;2UV02]XY80/:FC0;:SSP2aWXT20;RSRP0e
0;bVS@32ZY<0_jZD0<>[U032[9D0aK2I0<RaVP3:]Yl0b[VP0<fmX`3?_jH0e<6Y0=;2ZP3M/J40aT8h
0<`V8@3:8b00aRlX0;1IH@1<EWl0LH^T0<ZeZ@38UhT0^eeC0;Dg=@2^=CL0X4570:U?E02[4a<0/CDg
07<mD@2OAU<0YBT]0:4K7P2P9bh0XeQL09f>TP22UJ80MXjU09IoS02:3Q<0JR/k08jX^`2mcML0]l[F
0;S;eP2kcMX0^<WF0;G6e@15HWT0IGj>08bLXP1iLfd03@00o`08ooooo`0G09>oKP38bm80Yk:e07^2
P`2ARH/0>Q<G0:jVZ@30bL/0]l7301d<4`0`0`X0=`@508mO503BSaD0XaT20;d:2P331`X0aPL90<H6
1`3=2@`0c`/<0=4;303C2`d00P3E30d08@3J3Pl0f`l=0=X>303O4Ph0i1D@0>XG4P3Y5a80fQ0=0=4=
2`3B3`h0dQ0A0</<403<4140cQ8C0<P@40376AL0]R<O0;M2>@3;LV/0h:2J0?2b[@3a[:L0j92<0=13
@03>6aP0dQ8B0<@:3`2c10/0ZP<90:L11`2U0@D0Y0450:010`0209l11@0H09d11@2K0@@0U`4408P1
1@2;0`L0S`4508h10`290@40Q`4208P10`2;0PL0SP8909<22`2C10`0U0@<094430260@L0P04707X1
1@290PL0U@8608810@1i0P80P1d=1@00o`08ooooo`1;02kT7@2/Z:h0OXEk0:ND902aV@D0Ugh:095j
5@2bU0/0/iLA09AiA@2?Lfd0TgAe09QhMP2MOWL0YH=l0:Z7OP2`T8@0]ib;0<6TTP37ZYP0bZnL0;ZZ
W03;alL0g=CA0<jgY`3B^ZP0d[ZY0=S1/P3I`K<0f<>b0=O5]03Jb;T0f/Vi0=o=_@3NcKh0glnn0>;A
`P3SdL80h]6o0=o>_@3GakH0e/Jg0=?4]@3A`K<0d;na0=2n/@3=_:d0akJV0<NcYP34/jL0_[2W0;B[
/02PPHL0V5MH0:mEC`2^EE00[UaL09];D`2<?d`0UVId0<_9c@35b<`0a/kB0<C>eP35d=X0`m3J0<C<
e`31bmL0Qi^`07ZAY02>WJT0UInX09jX/`1]N8X0=k4b00h00?l02oooool000[ooooo05H00?l004=c
4P1FIV00B5EG00@10@0@0@406P4102T10P130PD0A`8503/10P0o0@80?P8505X62`1S1@P0C`430705
2@2=1@L0T`@609d4102i30/0`0/:0<<=2`3130T0_PX90<0=302o30`0_@`=0;d;302n30`0_A0>09DD
402SPWL0fMGB0=[If`3Kf]d0g]?E0<b6QP34?3X0dB4L0=PI503F6A40dAL@0=0F4`376QP0SATC060^
902]XI@0f]OC0<Jn_@24DU00RATI09T<3@2L3@l0RQL?0;bBQ@3Cd]40d=7C0=7Bd@2/Y:40EPh=08`7
2P2;0PD0R@8508H20`220P<0O@43080110240P@0Q@<508T41`2910D0U`D90:d8302c2@/0]0`<0:T=
3`1m3Q40HbDU09^ASP2]^[h0`LoG0;k<e`2:W:<0IVU[03ZY80800?l02Oooool0C00Ni0T0Wi>508ZN
ZP1TOhP0G7Un07VCV020V9d0Zk^o0;O0aP1iO7h0PX5k08^8O`2IThX0XIfE0:VVW02ZYIL0[Z>E0;>U
UP2fY9<0]:2:0;RTS02iY8`0^jN@0;nWT@31ZI80`:VA0<6/U034/9T0aK:L0<ZiX@3;^:80c[bU0<no
Z03Fa:`0eL>a0=S6]P3P_Zd0c8j609Q]MP1XJXL0C6^@08^M[P32_;H0aKV[0<FgZ034/Z@0VHf=06U/
P01IHWX0RfIc0:TB5@2d3a40[`hC0;873@2c1P/0/@D:0:d42P2W20`0VBdb08ElR`1RNXd0KdeK08h<
4`1U:C`0U:o10;c>e`2hb]H0^/cI0;c>f@2kc=L0]/[K07^H[`28XK00VJ^b08F4Q00:iP@<003o00So
oooo01X0U<5/0<O<d@2T/KH0Phf<08N3P`0n61X0^:ba0<gEf@2g`<<05``A02/42@0/0`80UfLG0<Un
5P2X50@0_PX:0<<72P371`/0b0P;0<h92P3>20T0d@X;0=@<3@3F30/0fPd>0=d?3P80hA<>03P0hA<?
0>HH4P3W5A40ga<@0=D?3@3D40d0ea@C0<l@4@3<3a40ba@E0;lJ5`2/8Qd0ZDU10=BUW`3bgMP0l>OT
0>g[j@3[jnX0k>WY0>kWi`3hdll0cFMR0<DO7@393180^0D=0:X22@2V0@P0XP4409l1102M0@@0W045
09d21@2I00<0V@0209T110270PD0O@4408d11`2?0@@0R`8208P10`2:0@@0S04508l11`2C0`X0T0@:
09863@2@1@d0Q@4707l11P1n0@<0VP<80:44202@0PD0NP8307XH2PD00?l02?ooool0B`00o`00`[BS
08f6C02bV`/0Vh870:J;4P2BM`D0/9DB05A<6@24L6`0Sg=b09AeL`2KMgH0WGah0:B3O02YRGh0/9>4
0;NKR`2nXXh0_j>?0;jXT`2ZXIH0^KZk0<_1^`3=]jD0dKRX0=:l[03F`;00el6`0=W5/P3E`kD0dL>g
0<Jl[`38_[<0f<nn0=[?_`3PdL40hM310=o>_`3Nc/00f<Nk0=G6]`3DaKH0dL:a0<o1/`3=_[40b[V/
0<VhZ@36]:H0`K:T0<Nk/02k/Z/0^k>/0<[7a@36a<H0YJ^c08VEY@0Y?ET0ZKK409:AW`2FXJ/0a/oF
0<G>eP32cML0a<oJ0<C@g033cMP0`lkI06f1V01LM8T0RYfY0:>^]`2SZ[<0M7n?04b6A`0>003o00_o
oooo000:ooooo`1F003o0012LaH0JGYg04MCE00B0P809P8302L10@0`0080A@8504h21P1>0@@0E086
04431P1=:b`0P5=C05D;30201PX0T0D909H41`2M1@H0[PP80;h;2P332``0`P`;0;l;2P2j2PL0]PP9
0;T:302l2Pd0_Ph@0;8Q702;Bd80em3;0=_Mg@3MgMh0emKF08E[J`1m7ah0^1dK0=HK5`3F6180daLB
0=@I5P346aT0N1LC07mWGP3<a;d0gmcJ0<_=b`18C4L08Pl:04/:2P2=3Q00VPh@08`O5`31VXh0dm;A
0<o@dP3AdMD0bLW804H^;01_2``0R0D608P30`280`@0P`4108010@1o0@<0O`4408811@240`L0R0@9
08h21@2]2``0/PT:0;<:3@2_30h0T18B068D4@2ORhX0]l?:0<3@f@2b`l/0UJF/05iRI00k[242003o
00Wooooo04`00?l009f:L`2=Wj/0JHJ?06n:S`1ROX<0GWao08ZRY`2ea<T0OX>40821N`2<Rh00ViJ;
0:BMU@2WXYX0ZJBH0:fUU`2dYYH0]jBD0;JORP2jXX`0^::;0;^USP2mYXl0_ZRA0<2[T`31[ID0aK6K
0<NcWP39]j40c;^W0<jmZ`3@_ZX0dl6/0=O5/`3GakT0eLRk0=C7_@30^[P0_K^l0<S1^`3:_k<0b;^]
0<>iZ`32^:T0`[R[0;jeY@2g[Ih0_:6E0:]5@@2c30d0]0P:0;<72@2e1PX0]PH:0;<72@2a1@P0[PD8
0:@6302EDf00V:Nh09=RJ`2C2a80HbXo09Rda`2lc]P0^lcH0;g>fP2kcM/0^lcI0;S;f`1PO9@0OiRU
08jOYP22Q8P05kl<3000o`08ooooo`1D096nJ039c]80Yk>i07R4Q@28RHT0@Q`N0;^]/@3<eM/0/;Ro
01/;4@0b1@d0<@@20:Me6P35L100/1860;h9303320/0`PH90<44203>2P/0c`T:0=<;3P3G3@d0f@d>
0=/?3`3O40l0i1@@0>DD403S4@l0iQDA0>DE4@3J4A00eA0@0=DB4@3E4a80d1@C0</J6@2d8A/0W48j
0=6RVP3`g=H0j^KU0>[YjP3Xj>T0i>CV0>OXj@3[jnd0k>c]0>gZj03be=00cF1N0<L@5@2l1`h0[PD<
0:H32@2S0PP0WP4409T00`2G0@H0V@4409P2102K0PD0V`4409D21P280@@0S`4508l10`2;0@80R`04
08/1102;0@H0T04709<22@2C0`X0T`H<09052`260@P0O`4608T11`2R0`/0X08708h1101j0@<0LA<7
1@00o`08ooooo`1;003o003;[740YY@L0:JA202FO@d0YX`=0;NH1`1fJ1L09b`l089^L`2ALWD0U7Eh
09YiNP2OP7d0Y8Eo0:Z9PP2aTXL0^Yf?0;fNS`31Xi40_jFA09>6N`2JSXH0^:NH0=2gY@3A^ZT0dKVY
0=>n[03G`K40f/Ff0;V]X`2RVY@0]JbQ0::IT`2SXIP0fM2o0>3@``3Qd<@0g/g00=c=_`3Ic;d0dlNg
0=;5]P3@`kL0cL2d0<c1/`3=_k<0bKRZ0<JdZ036]:/0a;BZ0<:f[P37`Kd0/[6^0;Bf^P2[/[X0WZ^j
0:2daP2=Z;d0a=CM0;_:d@36dMT0a/oH0<C?f033cMT0`/gI0<;>e`31c=P0P9:V05UcRP1^PY40TYjW
09:JX`1]NXX0I5aN00h00?l02oooool000[ooooo05H00?l004Uo9`1JKFl0Ce=G02T4100e0`@0:P41
02l10`130P<0C@4505021P1D0@@0G@/?07=4A@26D4l0O1/K08H51P2A1@P0V0@709`51P2T1@L0^``<
0<8<30313@/0^`/70;P:202j2`/0_0/;0;l<3@2d5a80_fUK0<2YWP3KfMT0gMkP0=;FeP1YLVh0GUiG
07]UG02?=2l0bR0K0=/K5`3?71X0ZQXI06PI5@2AOgD0fMC<0=kNfP3JfMP0alS20;:aYP2PVhl0IeM?
06/A4P2H3A00SR0I0<BOU03CdM80c]3C0<oBeP3?d]@0TI:<02P91`1R2@X0PP@608D20P210@80P042
07h10`200PH0R0L808D31P2610P0Q0450:@:2`2a2P/0/PX>0;4>3`2/<S00Q3Tg09anOP2a_<80_/cE
0<;?f@2CXjd0HV=T03NW70800?l02Oooool0C000o`00Z8i]09JW/P24WjX0I829055`M@1WQXP0KhZ>
0:bl`026Rhh0P81l08b<Q@2NVi<0XIfF0:RSWP2YXiT0[ZNK0;:UUP2fY9<0/j6=0;BRS02hXh`0^ZF=
0;bWS`2lYi40`:^E0;j/UP34[iT0b;>N0<bhY@3>^ZX0d;j]0<nnZ03C`Zh0e<>a0=K7^03Eb;T0dLRg
0=36^P3=`kL0b/:c0<Nn/P35_;00_kV/0;bhZP2k]:P0]jnQ0;fTVP2`De80[a0C0;L:2`2b20T0]@P;
0;492`2X30l0XQXL0:8E6`2Y1`/0Y`@808d[>`0a@V@0ReIP09H83`1X;3h0U[?50;K8dP2jc=H0^L_H
0;_=f02jbmL0]/SI06AmU@1YQ9@0PiFK08^DU`0UWQX<003o00Sooooo01/0SkYU0<C8c02[][`0NHJ7
0823Q0178bD0]J>Z0<cBf02d^/407``C02`32P0a1@<0]H@M0;YN3P2a3PL0^`H:0<0720311`X0`PH7
0<`:2`3A30d0e@`?0=L=3@3H3P`0fPl=0=dA3P3S4`l00P3U5A40>03S5Q40fQ8=0=<?3P3?4100caDC
0<HM5`2e=c00`VQP0<bHT03Zf=<0k>OU0>WWi`3YjNX0jn[/0>[Yj`3XjN/0jnc^0>g]l03[j^d0k>g^
0?3/k03X/[<0_Q`L0<8=3`2a1@/0Y`<90:D2202O0@H0V`4409P11@2I0@H0U`4409D1102H0@H0UP46
09@21@2C0@D0T08508/10`2<0@D0R04308P1102:00H0T08909H42`2F1P/0T`D<08L120240@H0UP<9
09/32`2D0PL0R`4307/10P1c4PL04ND11000o`08ooooo`1;003o001maQh0ZI@=06IH0P2@O140VX<=
0;FM;P1:B3P0<SIE08=_M02?LGH0UWIj09]iO02POGd0XhAo0:Z<QP2^SHH0]iZ=0;fQT@2oXXh0`:>B
0:F@P@2YV8P0`ZfM0;fZW03@^ZT0d[RY0=>l[03D_jl0f<Bj08f4P`2aZjH0`KVa0:nVY@23Pgh0f=2o
0=oA`P3Qd/D0g/o20=c;`@3Ib/00dlRl0=;5^P3?a;P0c<6h0<c1]P37_k80`kZ^0<2bY030/ZL0_K6W
0;^d[`2/Y:`0[Yj[0<^b^@2fY:T0GFUo09>T^01cSJ<0`m?M0;W5b`37dMX0aM7I0;o<eP2nbmH0`LgG
0;o<e@31c=L0UJNk07><XP29WJX0UjB/09NSZ`1lRIP0HfE[00h00?l02oooool000[ooooo05H00?l0
04f2;P20TID0H5mS0304100a0@<09@0103821@1810D0B@8304/1101A0@D0H08806/:4@1b2Pl0N`@8
08P51`2B1@L0V@<709d5202O10L0]``=0<<=3@3230`0_0/90;P;2@2k3@h0^@/:0;L:2`2d:b<0ai61
0=G9`P3Hf=X0e=7?06IYHP1lPWP0d/g60=oBc@3R[:D0`C8/0<lL6`2<5aL0?0`608]mL03Ke]40gn3O
0>7ShP3Ph>00g=cK0=CGdP3De<h0clFn08I2?@2C3Pl0SalH0<BOU@3AdM80cM7D0<kCe@3@e=H0b/[8
03di=@0L0@00I0L:08410`1o0@80O`0107l20`2210H0P@L807X1101o0`X0O0<609L62@2/20T0/@/<
0;4;3@2L3@l0O@l@09EOG`2Y/K<0_L[C0:fka`2Q/K/0GEmQ03NW7@800?l02Oooool0C000o`00QK=M
09BT[P2;Y;80EW9l02m;D01ON7`0Hgn40:Rh_02?U9H0O7ei08b;Q@2HVHl0WIfC0:RRVP2^YI`0[ZBJ
0;2SV@2eXiH0]J6>0;NRSP2gXXd0]jB=0;^VS`2mZ900_JZE0;j]U`31[iX0akZT0<Zl[03<^j/0cl2[
0<joZ@3A`k00dLBc0=;8^03Bb;T0dLRi0<g4^@3<`kT0al:c0<Ro]P36_;D0`KR`0;beZ`2i/ZH0_ZVO
0;1HE`2a4a@0^@/>0;H92`2]2PX0YA/L08/gA01J@Eh0>3iS065HK@2K;3@0X`@908/_?014FGT0QTiI
09L73`1a:3X0SjZn0;c<e`2jbmL0]/SF0;O9eP2dam@0^<WK07fD[@25WJd0UJR`09RSZ00oLbh<003o
00Sooooo03`0SkQQ0<G:cP2`_<@0QY2B0864QP169bd0ZYZP0<cCe`2`]k`06`/A02/32P0o3080aY<N
0:e32`2c2`T0_`L<0<<730341@X0a`P:0<`92`3?20X0d``>0<l>3P3P8b<0ePlA0=hA3`3L4`l0c1`E
0=]0>03A<RT0bBdV0<Tk<`3=Fe80dWab0>:/Y@3bhMd0k^OT0>[Xi`3ZinP0j^3U0>gLh03Y`l`0hjRb
0<9mR@2BMGh0hn;T0>_[k@3^kO40jnc_0>k^k`3ch^40_DA50<8@4P2h1``0ZP@;0:D22P2R0@T0W@85
09X10`2I0@D209811@0G0981102B0@H0TP4608h11@2<0@D0R`4608X010280@<0Q@4208X21P2?0PT0
U0@;09L63@2D1@`0SP4909/12`2Q0`/0P04508D=4@2710P0N@42078?1013U@@01000o`08ooooo`1<
003o0019g0L0UHD906]M0`2ZT`/0[iTK09:4@`0j?T`0>CiL08=`LP2BLgX0V7El09YgNP2LNgX0Y8J3
0:R9Q@2_SH@0_9b?0;VKR`30XHd0`:>?0<6ST`2nYID0`:VJ0:JFSP34[Yl0e;^[0=2mZP3E`[80eL:i
08ImOP2?SY40VINI08R8R`29R8<0g=2o0=o>`@3Pdl@0gM310=W;_P3Eb;h0dlJm0=?5_P3>a;/0cL>j
0<k1^03;_kD0`[N^0;fbZ@2i/J/0/Jb`08QjS`2>D6h0XBe50:8N;@2WA4`0g/C@092FX`2EZ;P0`M?N
0<SBfP34dMX0a<kH0<3=e@2mb]<0_lgG0;g9e030bML0HGF>04eYQP1RN8`0W:Nb0:Zc_P1RL8H0H6Mc
01O@3@d00?l02oooool000[ooooo05H00?l0066JBP2=X:P0JfQ`03X51P0f0P80:P4103<20`140`H0
?P4303l10`180@@0G`8807442P1g0`X0P0<908T52P2A10L0V0@809`31`2O1PL0[`T:0;h<302o2``0
^@X;0;@82@2f2@/0]@T90;H:2`2d?380^YB60=SAc`3Fe=D0UXF008=_I03>b<00fm_K0=oMg@3UbLT0
[DE307`F4`1M@3T0Yj:I0=KDc@3OhN40g>3R0=_Ph03MhN80fmgO0=GHf03AeMD0eMCD0:f2OP2<5140
RQXC0;jGS`3Bd=<0cm;E0<kAe03?d]D0cm7D09nMV@0j8Ql0H@T908420`220@<0OP4307d10`2:4180
PaDD07821@1Y0P@0QB0Q090:302^3@h0/@/;0;8<3@2U4100SQHG08@m?P2h^;/0]Ko80<;>e`2JZ[<0
KG1d03b/8`800?l02Oooool0C000o`00PJM809ZU[@1kUj<0>EMP05A/L@1UOhH0NiFJ09BVZP2GWj80
O7ij08F5OP2FV8d0XJ2F0:RTW02`YZ00/ZJN0:nSV@2cY9L0]::A0;:PRP2eXHX0^:::0;^USP2lZI00
_ZZD0;j]V02^YYH0_/6k0=CFe038_:h0c[jY0<_0Z@3>`K00cL:a0<k5]03AaKL0c/Ff0<_3^038_kP0
b;ng0<Ro^031^[80_KR^0;bg[02m/:L0]g5]0;0E6@2j30h0]P/?0:TG6@2;@4`0AdAY02a4K01NL8D0
T9RK0:ZMV`2I<C<0W`L;078jB01CJhD0QT]E09H63`1l8c00QIZ/0;_>e`2kbm@0^/gG0;W;f02``M00
//KD05ikT`1QPI40PiVR08:?V@13G3X<003o00Sooooo0180SKEO0<K;c`2__<80PXb?09:FVP15:S40
[IfT0<gEf@2Z/kP06`XB02X21P114`00d9/P0:/c2@2g20X0`@P=0<D82`341P/20<<830110<d;3@3A
3@h0_@`<0;XC4`3?30h0ga0=0=@A40270P80e9JA0?oDc03oe]00o^3G0?SVhP3dj^T0l>cZ0>_ZjP3Y
iND0k=kP0>Joa03VXJ`0cfUe0;P[>@338Bd0aQlV06L@5`3<`lP0j^[/0>c]k`3[k>h0i^OY0?;[k03=
Kg@0aaHJ0<<;402_0`T0YP8:0:811`2M0PD0U`4109P11@2=0@@0T08809<11P2B0PD0T00508`11@28
0080R04308P010270@D0P04108H1102<0PL0T`<:09P5402E1@h0W@8<0:T3302R0PT0NP4507P11P1h
0PL0N@X<06h=1013U`H01000o`08ooooo`12003o000_i`H0S7X809B02P2_U`D0/j0k08^3K`14Bf@0
A4ES08UcM`2@LWP0U7Ij09UlOP2MOWh0XhB20:N6PP2[S8<0]9J:0;ZLS@30Y8l0_jB>0<>WT`39ZiP0
a:bJ0;:OT@3=^JD0e;bX0=2oZP3D`k00e<6c0:BET01mN7X0PWj108R3P02i[J80g/jo0=k>`@3Lcl80
fLk10=O;`03Bb;h0d/Rm0=75_@3>`kd0c<:l0<_3^@37_[H0_kRb0;>][`2FQ9P0TeQe0:@aB`2`4R00
]PLB0;T63`2_1`l0Yblo07M7F`29SIl0`<oJ0<WCg037d]/0a<kH0;o;e02nb]<0_l_G0P32c=L02028
V:`0QYfd08^O[P2PZkL0VJB`05e/P`1EGVl08<TF3@00o`0;ooooo`002_ooool0;P00o`00RWYN0:Vl
b01[JG80?0D603d30`0Y0@808`4203H20`0c0P80<`4104010`1K0@H0LP<807`32@210PX0P`<808T4
1P2E10L0V0<509l7202W1PL0^0`<0;P;302M1@H0UPD60:h82`2b1`P0/PP80;50<`2mX980em?B0<c:
bP1[JE`0clJm0=ODe03FemP0c<g=08UmO0189b<0OW9Y0<[:``3IfMP0fM_K0=[Ng`3Jfmd20=WMgP0V
0=[Jg03HfM/0eMWK0=?Hf02kY:80QaPE08XF402kShL0dm?F0<gBe03?dmD0cm?F0<gBe03=cll0aKNb
09=AB@211P@0Q@8408@11@1o0@D0OP8507T2101d0@80I08308HC602F2a00X0X;0;8>3@2c3@`0YaPG
0=ekOP1_9bX0^:jb0;C1a`2lbM80Y[G006I/LP10/bd2003o00Wooooo04`00?l005K5<@2GWZ<0L8ZH
049OI`0kDeX0FG=g061lP@2<XZT0WjZ]07j3P02<ShP0UiV>0:2NV02ZXi`0[ZFO0;2UW@2]XYP0[j6D
0;>PT02eXH`0]:280;VTR`2jYHh0_JZA0;f[T`2fYiD0YjFH0<K9a@32`KX0a[ZY0<bmZP3<_ZX0c<6^
0<k2/P3>a;@0c/Bh0<k5^@3:a;P0blBj0<S2^035_[D0`;^b0;bf[`2n]jh0`IbG0:`U9@2l3Q40]@l@
0:P`<@1UAV409cm]06EjS`2HW9P0WYf?0:NQU02YLFd0WPlC09PL8@0h=EP0AfN208=<D@2F1Ph0R1DP
07j5V02ic]X0^LWF0;c;fP2kbML0]lSE0;?7e01hTJ@0LHjK08JKX@1nSYT0>3Xj3000o`08ooooo`0`
08^dG@2n`L<0/kg408^GV`23RXl0CS@j0:bKY03DfN40Z:nh01h;500a1@P0E2@60=BM9P2R7`@0]PP9
0;l83@2o1`/0]`L:0:d?4`2c8RD0[@L90<`>403=7b40h4120=DC4`3Q4@l0h1<@0<LC4`2I92T0`hjG
0>:oaP3ZcmD0kmKK0?KMh03cd=L0ikFk0=V=UP3HK7H0bSU00<HS:@3<6b80caDJ0=8F603A6AT0UATK
09F1PP3WjN/0jng_0P3/kNl0503_k>l0h9jR0;hN8@383Q40^@P<0:/22@2T0@L0WP4609T10`2G0@80
U@8709<12@2C0@P0TP4609411`2?0@L0SP8508d11@290@@0RP460P240@@03@2<0PL0T@<:09D43@2K
1@d0Z@D=0:X22P2N0PX0M04407T3201i10T0L0@806/80`12U0D01000o`08ooooo`800?l004X0SgH5
0:bF1`2_UPD0Y9A;0:BRX`0c>e`0DE1[08MaN02=KgD0TgEi09]jO`2OOGl0XX600:J5P@2[RH80/iB9
0;ZMS@2mXHd0`:F@0<BXU036ZiD0bZnJ0<ffX`3B_jd0dkn]0=2nZP3B_Zl0dL2_0=K4]037]JT0bKV/
0=G4]@3Jb;X0fl^m0=_<_P3Ibl80e/[30=O<a@3Ac<D0d<[20=;8`03>`kh0c<:n0<Bk_@2^XZ`0XX2F
09Y;H`2a:ch0^18L0;LA4P2a6AH0[2<U0:hA6P2g1@`0]0D=0:0E7P2OJgD0b=;I0<_Gg`35d]X0a=3I
0<7<e@2obM80`LcF0<?>f030cMT0RIjb03EBJ`22Vj`0Xk2k0:bg``1ZMi00AE=T03J_:Pd00?l02ooo
ool000[ooooo05H00?l008moI@1gSIX0IFI/03T5100k0`808@4101X10@0f0P<0;P42030000170@@0
F`4307421@1j00D0PP@:08D3202;10L0SP8309<31@2I10H0W`@60:h92`2c2PX0Y@T;0983102Y1`P0
/@P80;471P2^;BD0a9F:0=WAc`3@c/d0/ZjT0=GBc@3Ee]D0dMCC07R6P@0D8aP0N7U]0=3>a@3HfmX0
emcK0=KLf`3GgM`0emWJ0=KKfP3Gfm/0f][K0=SIg03Df=/0d]OG0;6AT02;4a<0T1@B0;=oM`3Ce=D0
cM7D0=3EeP3=d]@0cM;C0<_<c@2]V9P0Q3/g08@620280PH0Q`4408<21@1o0PD0NP8407L10`1W0@80
O@D80:493P2?0@<0ZPd>0;8<302/3A40VQ0G07@C5`34]KX0/Kc30<KCg@2EY[<0M7^3042b;0800?l0
2Oooool0C@00o`00E/4X0:2RXP1^Q9<0CVYd04IPI@1FLWT0NYFJ08VNXP2X]KX0QH^<09:CT02IVY@0
XZ6I0:JSV`2[Y9h0[ZBL0;6QU`2bX980/Ij?0;BOS@2cWXL0]J>;0;JUS`2iZ9<0_JZC0<2^VP2RV8/0
ZJBE0<NkZP3=_JX0cKf]0<bl[03=_jd0c<2`0<c2]P3<`kT0c/>k0<c3^@3;`KT0al2g0<Nn]@2o^k80
_;Va0<:g/02hL740^ADH0;L?4@2kA3d0/61S07m2E@2IQh`0X:2E0::QU@2TXI<0[hf609/S902P4180
LCiG02U4KP2T_LP0Qe]Q09@73P2?1Pl0O61`0;[=fP2ibMH0^<WG0;O8eP2gb=D0]<OF07jHZ`1/QYH0
RZ2W092RZP0lA4H02^H400/00?l02?ooool0<@29/UT0a<S90;O3b`27UYX0UijS050j?`2YVJ40dm[S
09fU[P0O2a80<0H907];5`3>TR<0WA460;H82`2j1a00[PH<09h1102h41P0^aXQ08d0002l2`d0d@d?
0=LA5@3L3a80h18?0>0C3`3I4A00c@h?0<DE70306b<0`B8Z0<L]=`3:<3/0bbL`0<XN903>6A`0eaXK
0=HH6@3B5Q@0e1TH0=LI6P3G61/0daDH0<0L7`1c>cd0hnKV0>S[j`3Zk>h00P3[k>h08P3_c]00[2db
0<HB4`2o2@`0]@L;0:X22P2P0@H0V@0309P20`2E0@@0T`4608P11@2=0PL0T@4608l11P2=0@D0S042
08h21@2;0@H0Q`4508H0102;0PL0TP8;0:094@2U1@`0[@D=0:D22@2L0PT0J`@706<3201l1@`0NPdB
07480`13T`D4003o00Sooooo0P00o`00BP2:X`H0[IX70;6Q=@2bZ880NWZ104Q@L01JFFh0Qg1g095a
N@2ELWX0V7Ij09ejNP2SP840YX>10:b7P02eUhh0_InC0<6RT@2oXhl0`JRE0<R/V03;/I`0c;BS0=:m
[03A_ZX0d[bZ0=>o[03A`:h0e/Bf0=?1/`3Hak/0g<bn0=[9^`3Ibkd0f<bm0=G8_`3Fbl@0eL_60:6Z
]02IY[d0_92J0<QiQ02lHg<0]DiS0;TgB@2j7b/0_1XH0;<V7P2jE4P0`7m`0;nIRP2IPXD0MD9J0:P9
5P2f0`/0/@@=09h/=@33`<L0c]WQ0<KDg@32cML0a<gG0<;:e@32cMD0a<oG0<C?fP28VZl0LH^Q082D
XP2<VJD0RiJS05MWOP0oD680Ahlh3@00o`0;ooooo`002_ooool01P00o`00N6M908FLY01]Jg80>0D5
03420P807@4104h0>08403L10P100`<0C@8405h3101a0PH0O08808831`250`L0R`<509451P2C10L0
V`D809T31P2S1@P0[PT90:h71`2Z1@H0[PL70;87202e20X0[Q0>0;MAB`3C[JX0f=;B0=SBd03Fc/h0
cKZk07]dLP10C440UYV=0<g=aP3JfmX0e][K0=OLg03Ifm`0f]gM0=[Kg03HfM/0emWJ0=WIg03Gem`0
d]OI0=;@d@2BE5<0U10A09@B402SI5d0d]3@0<oCeP3>dmH0cm;E0=3AdP2ZSHh0OR/Z08@<3@280`P0
P`4408@20`1o0@<0O04207X1101i0@<0I`8307X41P2P1`/0T0D709/;3@2b3@h0[`/>0:8<3`2;9RL0
/ZJX0;G1b02ncML0ZK[806]eN`1HP3<2003o00Wooooo04d00?l002[O4`2EUHl0T:Ne041LI@13G680
Af5U07B?T`1fSY<0]l;808F:SP2@T8h0VYRE0:6OVP2XXY/0[:>K0:jSV`2_XYP0/:6C0;6OSP2dXHd0
]:290;FSR`2jZ900_:RE0;n]VP33/Yl0a;:Q0<RgYP3:^JL0cKbY0<fo/039_Jh0b;n/0<[2/03:`[D0
b/>g0<_3^P3;`[T0b/>k0<K0^@32_;D0`;bc0;ji/032]:h0/EmQ0;XC5@2k;BL0^TI40:XA502[3Q80
U4e?08bCT02VXIT0[HN20:4/;`2W20/0ZbP[078lDP2=P8l0YJZ_085MIP2A20h0U`<:07hT<P2k_/X0
^lcF0;W9eP2gb]L0]lWE0;;6e01YPiL0IhBB06f3R@1eR8h0>dQ?01W23@0;003o00Sooooo03`0Kk]9
0<_=d02b_LH0UJ>W07AmPP1@>d80[9bT0=?Kh`2DVj@08PXA03871P2TM1h0`h4L09/:102a1@/0/PD<
09H21`2X1P`0`@L@0;L72`2<0000_@d>0<d82@3H3A40g0hA0=d@3P3N4a00d0`;0</=3@3>3@h0dQ0@
0=HD4`3D6AP0dadJ0=DM6P3D6AL0dADC0<dM6`38<RX0aCP]0<M2=`3=C4<0dT<o0<dL7P3=5a/0M1PK
0=??d03Zk>/0j>WY0>[[k@3Zjn/0lN;S0;IKH02n5AP0_`P;0;D52`2`10`0X`4709X1102F0@@20980
0P0G08/210290@<0S`4208/00`2>0@H0S@8408d11@2:0@L0S04408H00@2<0`L0V`H>0;084@2a20l0
ZP@:0:@12@2N0PP0V30f05/C5P1n10X0P@@:07840P14TPL01000o`08ooooo`800?l004X0L<050:ZL
;02VXh40XZ6M09fNZ@0c@5h0IFAf08E`M`2?LWP0U7=i09UeN@2ONW/0XWj10:R6Q@2ZRH@0]9J;0;^M
T`31XI@0`Z6C0<6TTP37Zi/0b:jK0<bdX03D_ZX0dKfZ0=6lZ`3C`:h0e<:a0=O4]@3C`[@0f<Jk0=[:
_P3Fb;X0fLZn0=S=`@3IcLD0fL_70=K;b03<bL`0R9:]091mU`2YH6l0/U9M0;m?E@37Ee<0b6QM0<Z3
M@3>XiD0`:^O0;6VV`2[XiP0][2`05ICL`2G8c@0]0@>0;82302T3aT0YHbJ0<gJh`3:eml0`m3I0<G?
f@34cMP0`loJ0<CAg@32d=X0T::g05QgT`1lVk40Pi^g086F]P18G8<0AeQZ04Z3?@d00?l02oooool0
00[ooooo01`00?l007m^D@2M/[l0K6Uc03@51`0U0@40704102<10@0e0P@0<08203@00@1:0P@0GP85
07<31`1n0`L0Q@D908H42@2:10H0S`<609D4202I0`H0U08509L21@2U1@P0[`H80;061`2b1@L0/PD8
0P2e1`/02`2c2`h0/2LW0;UIF`2fGf80YdY<06hZ:01SDTT0`Kng0=SHe@3Hf]/0fM_M0080f=[L02/0
gMSL0=c6b`32TIH0WFmc08EiN`3Adm@0emOK0=7Ee`2OSXh0PAdO09X=402J3Pl0VT4l0=77a@3=d]<0
c]?E0<oDe@39aLH0O3<b08/:2`2:1@L0Q08408810`200@40OP4307`20P1k0@<0M`4306L20`1f10H0
X`X>09H;3`261PT0[``A0;0<3`2V2`h0R1DH0::9S02`_/D0`=3K0:Fe_`1cOH40F8<e00800?l02Ooo
ool0C@00o`00:=/<09::NP21UZ00H7^403aDFP1AKgL0MI6G07jDV@34c]H0RHbA08j=S@2FUY80WY^G
0:NPWP2/Xid0[ZBK0:jQU`2[WI00/9f=0;6ORP2gXHT0^:6:0;ZVT02mZIL0_JZJ0;j]W@35/Z<0b;FU
0<ZiY`3;_:X0bl2`0<Zn/034_:d0akn`0<K1/P39`[L0b/6h0<S1^037`[T0aL6h0<6n]@2o_K@0_KR`
0<6d[`2iOGd0/QLJ0<4W9P2a5AP0/Pd@09lO901N@f<0H6^30:MbL02Q8B80Z`T;0:X4202X10T0XPH;
09PD6@2RJF/0W7eo08`;4`2J0`T0S`L@0:9^N030bM@0]LKA0;S;e`2fbMD0]<WI076=Y@15HGl0<d]X
03Q@I`0aB540:Z@K00/00?l02?ooool0E@1@`C80b/S60;g8c`2@WZ@0SYRN04ln@`2/WjP0e]kW08jD
W00S2Q40=0T40;f=9`2gK1H0X@X60;453@2Z1`l0QP840;4940331``0/@L908`000313@l0d`/=0=D>
3P3I3`h0fPl?0=H?4@392@/0b@`>0<d@4P375AD0_2TR0=YcJ@3VThT0j9680=e`J@3=BT<0RR0M0=FX
XP3`blD0lM?<0?SKeP3mc/d0a3/n0=4G6P2E5aP0Q6e_0>WZj@3[jnd0k>c^0>[[j`3]i^L0f9fO0;HN
8@2l20d0]0D;0;853@2Y0PX0X08709X11@2F0@@0UP4309420`2;0P<0S@4108d10P2@0@H0T@4608h1
1P2=0@L0R`4408X11@2?0@D0Z@L=0;H94P2c1Pl0[0@;0:L1202O0@P0SQ0H07HI802610d0Q@4707H4
0P1EMPL01000o`08ooooo`800?l004X0RK<=0:JPH`2UZjh0WZ:X08:6T@0e@Ed0Kf]j08A]MP2?LWT0
UW=i09]eO@2MN7/0XGen0:N3P02YQX00]YJ<0;^NTP2lX980^ijA0<:TTP3:ZiX0cK:R0<^eX@3A_:/0
e<6a0=6m[P3A_[40d[n`0=C3]03A`K<0e/Bg0=W8^`3Gak/0el^n0=K=``3GblD0dlW40=C9aP3BbLL0
dL[90<S5b02o_L00_kVj0<Bi^03>`KT0b;fd0<:h/02m]:l0^K2Y0;F^Y02b[:<0ZjNQ07AjT01`?E`0
Z0LB0;<23@2/1@l0]G5h0=7Ih03;fN<0amCM0<GBg036dM/0a<oK0<?@g02mc]d0NY6c031;O@0B:fT0
0QIN004CG@0255T0;d=P05mJC`d00?l02oooool000[ooooo01h00?l0085_EP2M/;d0KFQc02l51P0O
0@406`4102810@0Z0@807`4102X10@160P<0GP850782201k0PH0P`@808L5202>0`L0T`@709<31@2B
0`L0T08609@2202N0`L0[0H90;07202`1PP0/PH90;@72@2e2P`20;P<3@0f0;P?4`2P5AD0Ga4>071K
D@39b;h0emSI0=WJg03Gf]X0f]cL0=gDeP3D/[H0`gQn0:Tj@01[81h0ESXf0:^XXP3DfMT0cLg@0;Ff
]@1DCdX0HA4A09P>402L3100TQhO0<Ra[@3?e=D0d=?E0=?De`2i[:d0N1DE08`31P2;0`H0Q`8308H1
0@250P<0P@4307h10`1l0@<0M`4206T30`1D0@80N`L=07D62`1c1@L0ZPd@0;0;3P2Z2Pl0TP/?08aG
F@2Z/kX0a]?N0:Je_`1bNX00FH<g0P00o`09ooooo`0h003o000DkPD0XiN009JY]014H6X0EG5j03AF
F`1aRhh0NI2F0<?@f02=TiP0T96A09VIUP2MViL0Y:2L0:RSW`2ZXYT0ZYjD0:^KSP2`WXh0/In;0;:O
R@2hXX/0^:B@0;VZUP2lZYT0_jbJ0<>`X038]ZD0b;RV0<RiZ`3:_Jl0bl6b0<Nn/@34_K80aKne0<K2
]`37`KL0al2e0<S1^@35`;P0`;ng0<30^P30_;L0_[Vb0;n^Z@2_HF40Yb//0:@X;P2C@4h0F4Y]04e9
L@2E?dd0Z1<E0:d72@2/1`P20:P31`0C0:L3202[1@/0Tb8Y08]bOP246240V0<909D22`2431L0Z8B?
0;O7d02fbML0YKgC04eZUP088EX00A59004??P013SH06Ri303R5;00;003o00Sooooo05D0AK<Q0<_7
a02f`lX0U:F[07^6S@1@@4D0[9fV0=ONj01oQ8d09PTA04TJ1P3<Vb`0UTTB0:082`2`10`0W@L>07X2
1@2]20h0`0X?0:85202I0`@0bPd@0=D=3P3E30d0ePh<0=LA3P3=2Pd0b`X<0<d=3@2c4Q80KA/H0=bm
]P3ajnT0l>g/0>o/k03aj^X0l^;P0=;1_030^[P0i^CW0>OWj@3Zj>T0mNKW0<iaM03@61/0_AdQ04dB
5P3HeMH0kNk_0>[/k@3Xj>X0j^SZ0?7Fe`2Z=c/0]@T?0;D7402`10d0[0<:0:T32@2Q0PH0V0430981
102>0@40R@4108X10@2;0@40SP4309811`2B0@P0S@4508/10`2B0@<0X0870;053@2e1Ph0]@L>0:l5
2`2Z0`T0X`8809X32P2E3aL0R`4908D21P1d0`40Qb<800@00?l02?ooool2003o000A06C55`2MVg40
X:N]0:BV/026QYD0=SmJ07I`NP25KgT0S6ii09McN@2MM7X0X7Yl0::0P@2UPX40ZXJ40;6ARP2hVHl0
0P2jVXd0<`31XY40b:bK0<Z_X03;]:D0ckZZ0=G1/P3A_Jl0d;n`0=?0/P3C`;@0e<6d0=G3]P3Fb;`0
e/Vm0=C8_@3Db/40e<[20=;9a@3Db/D0d/W60=?;b03=b<@0b<W90;o5bP2g]Kd0ckNh0=6d/P38];<0
TI>S0:BGY@2mQXT0^h230<>/Z@2b]Kd0Cdid09TM;@2c10d0/0<=0:Da>`3KeMX0bmGR0<GCg@35dM`0
aM;N0<GBg@2ea]d0DffO00HMJ@0156D00A9Q004@F`02004AF@0300DCAP1DF5T04=/900`00?l02ooo
ool000[ooooo04400?l008MhH`2hbML0KfMb03041P0T0@807@0002810@0Z0@409`4103420P130@@0
E`4507431`1m1@P0PPD808P52@2?10H0T08508l2102?10H0T0<70983202C0PH0X`@70:l62P2a1`X0
/`L:0;@72P2e2@/0^@h>0;X>3`2b4A@0H0h=06]KCP32_[D0e]OE0=GHf@3FfMX0eM[K0=WBdP32Q8L0
ZcHk0:HV:`1G4100GU=:0;fn/`3Ff=<0eMWJ0=?De@3Cd<l0`;Zf07Dk=`2E3a80VPX?098@4@2gRhP0
c];B0=3De`3BeMP0]Z>U07PA4@2<0`D0SPD508P10P0208D10@0C08D2101n0P<0N`4207P10P1b0`@0
A@410546201@10P0G`<70:8=4`2[2`d0Z@X?09L:4@2=CU<0a<SA0<;>f`2`_LX0N82605F3>002003o
00Wooooo0P00o`00B`2[U780SIjX06AnRP0gF5d0E7=h05UeO@2<XJP0_L_B09FMX02?U9@0UYND09ZL
U`2OWYT0YYnJ0:VPUP2UVXh0[9^>0;2LS02_VhT0[ib50;BPQ`2fXhh0^jRB0;bXU02n[9P0_jfL0<:b
XP33]J<0`kZX0<Fk[038`;40a[jc0<:k/@32_;40al2d0<Nn]P36`;H0aL:i0<;1]`30`;T0_l2i0;jl
]P2m^k80_KN`0;^a[02NUYP0HFZ004=DN`1aDG80W2@_0;0=4@2`1``0[0H:0:X62`2X1@X0Y`D:0:L3
202V0`L0U2@]04]8HP27?DH0UPD:09@12@2B0P`0N1PR0:Zb_`2;Y/H06SM^004IG0025EP00A19004=
@00133D00Q8^03eL=P0;003o00Sooooo05D0B[PV0<O4`P2lbM40S9VQ09FQY01DA4L0/J:Z0=KNi`1d
MWh09PL>05X[403GYC@0R3@?0:062`2_1Ph0U0@;06h10`2B0`T0X@@:08X11@2N1PL0c@d@0=<<3@3B
30d0e@d>0<`8303820d0c@d=0<h=3P2B3@h0OemM0>kXiP3^k^l0j^_]0>g/kP3Uf^40h];L0>_Vj@3W
i^H0hn?U0>OXj03Wj>T0k>OX0>2RY@3:7B40c1/N06h>502bZ:/0jNg]0>OXj@3Xj>X0i>;U0>_Nh02b
FE/0/P`@0;042`2^1@h0Z`<;0:h22@2Y0`T0VP4609@0102A0@40S@4208X10P2;0@40S@4209011`2A
00P0T04509H11@2T0@H0ZP480:h22`2e1@l0]@H@0;053@2[10/0X`8709`22@2A0@T0R@4708@21P1a
0`00R24900@00?l02?ooool2003o001;06SLA@28T8h0XJRc09^NZ@2<SY`0>d1G07Y^N@26LGP0SW1g
09IbN02LMGX0WWMh0:=nOP2VPh80ZXF40;:>RP2jVY80_9^@0;bKSP2oXY00`jRH0<Z`W`3<]JH0c[Z[
0=70/`3=^jd0ckj^0=;1/P3B`;@0e<6f0=G3]P3FbKd0e<Rm0=;8_P3BbL40e<[30=;9aP3Ab/D0dl_4
0=?<a`3=bL@0PIJ_05m_VP2UHX40_b/h0;lW;`2n?dP0[Eme09iFL@2b5R80_a8K0;iTI@2d[jl0L7jJ
07lnF`2[2aT0/`@=0:<:5@39Y:d0bm?N0<OCg034d=X0`M3N0:^of00Z@h000AIT004BHP004Ul00QEK
00hPEP0D9Ul031eH00TFA`0h@e008/hK00`00?l02oooool000[ooooo05H00?l008IgH@2P//00JFA]
02`3100V0@407`0002<10@0`0P<0;`8203@20@150@@0F04606`21@1i0PH0O`<708D3202>10L0S`46
08l41P2>0`L0S0<608h41P2>0PD0W`D70:h8302`1PX0/@D70;@72@2h30d0^Ph=0;P>402>4Q@0LE99
0<:m/`3Fe=<0eMSJ0=GIf`3Hf]/0elS90;a`M02Q;Bh0NATK04TH5`1cK6<0alJn0=OIeP3IfmX0e]SI
0=OHfP3Ff=X0e]GF0:f7QP2=4aL0V0T>09P=3`2KEE00dM7<0<gDe@3?e=D0]ZJW07DA4P290`H0RP<4
08P20`260@80Q04108020@1l0@80NP4207P10P1h1`L0FA@D09a_K`1V=SL0DP<509/<3`2Z2`h0YPL<
09X;4@2JGV80]kg60<CAg`2a_l/0Nh::05J4>@800?l02Oooool2003o001<08NcGP2EY:`0BFMc059`
M@0kDeL0QIfS0::f`02iall0WZN]08^ATP2FUiH0ViVF09nMV@2TWYP0Y9^A0:BGS@2WUH/0ZYJ70:fL
R02^WHH0/Z280;>SR`2gYXh0^:RB0;^ZU@2mZYD0_JfH0;baWP2o]:40`[RV0<:l[038`K@0`[b`0<6m
/@35_[@0a[ni0<C1^P32`KP0`/6g0;o0]`2n`;P0^kbe0;Vg/@2j][80]kJ_0:j_Z@2`YjL0Yf=[0:LF
7P2d2Q00]@P?0;493P2V2Ph0W1XP08d_>P2C<3P0WPL<0:462@1m<DD0>Dme08m[M@2@2Q40UP4;0941
2P206BL0;cYY00`YJP015EX00QMJ00DMF00F;5@0;41K00XK>@0<8CH0<cLh00WU0`X00?l02?ooool0
E@16]B<0^KNe0;K3b@2FXjL0NXJ;0591AP2dY[00cmSQ06=SK@0Z1Pl0LT4E0=>M;`2570P0Z0H;0;85
3P2L1@h0IP4507L220200`X0O`440:L62P3;30d0d``<0=@<3P3B3@h0aPL<0<T93`3=2`d0cPd?08h?
4@2<MG<0k>[Z0>c/k`3[jnd0kNGX0;U^M`2R;c`0ZEaZ0=74b`3Wi^T0inSY0>GWj03Xj>T0jlG80<LY
;`3C6Q`0XQ`Q08iaMP3Uj>X0inSZ0>[Zk03Wi^T0j^GW0<>3Q`2]3aD0/`L?0;043@2]0``0[`8;0:h3
302O0PL0V04309@10P2@0P80R`4208T20@2;0P80T@4509@11`2I0PH0XP860:H21`2P0PH0Y0D:0;<7
3`2f20l0/0D;0:/32P2R0@L0TP8708T3202700@0Q04607820@1o6@D01000o`08ooooo`800?l004/0
J]a>09NQZ`2NYK<0WInX0827U00kAEP0O6ii08I_N02>KgD0U71g09adN@2QN7X0XWj00:F0P02ZPh80
/Xb80;NFSP2jW900_j6D0<:SU@36ZYd0b[2P0<beYP3B^jd0d[j`0<nkZ`3=^JX0d;j`0=72]03C`[T0
dL6i0<g2^`3@a[h0d/S10=7:`P3Dbl@0eLk70=C;aP3EblD0dl_70<g;b`1DL9P0ZJGB0;8hC@3@4QP0
bA<E0<iJF@2PAeX0YBm40<4C7P3931<0]BH[0<>TY02TZkH0D4Q[08PI;P2[1A40ZP@>0:]FH@3>dMT0
a]3K0<GAf`2_`]`08cj0004GI`0155l011YM03UDQ@1ZP9d0Sj2e02PmI@1HKH<0FfAf02@bA00iY300
3000o`0;ooooo`002_ooool0@`00o`00Sh=_0;o@h01RG6H0<0<502h20`0U0P80804102h20P0b0P<0
<`4104L2101O0`H0K@@707H32@1l0PT0PP<908h32@2A10T0T0D708/21@2:0`H0S@<709411P2L10L0
X0L90:l8302b1PP0/`T:0;D<302f3Ph0Y1<C074n>`38`kh0eMKF0=GGf03Hf=`0el_=0;n?TP2VBT`0
Ma`N04@T7`1XI5d0[ZnV0=GFdP3Ifm`0e][K0=OJg03EfMT0dmSJ0=;IfP3Af=T0^ZVY08HG6@2I2Pl0
V@X>08PL6P35[JX0c];C0<oBe@32/[@0MaPH08X41`2:0`H0Q`8208D10P220@800P1m0@<04@1j0@<0
M@4207420@21;b/0JSHg070a=01_1P/0V`P>09h6302Q20h0W@/A09E;D034`ld0`/oJ0;S8dP1iPhX0
F8Dl00800?l02Oooool2003o000C07:Z?`2EWZ40EG1k03aHG01WPXP0N96M06f6T02eaLd0Yjnf08^@
T@2=T8l0UiJ@09fLU`2PW9H0XYV?0:>ES02VUH`0ZYR;0:fJR@020;:NRP0g0;2NQ`2bXHX0]JB>0;JU
T@2gYXl0]JJ@0;>TT02dYI40]JZI0;ZdX`32_;00`K^a0;jl/031_K40`l2h0<C3_@32`[/0`<2i0;o2
^P2m`;T0^kff0;Vj]02j^;40][J_0;R_Z02^IFH0[1@J0;D:3`2e2@h0[0X>09hX;`1a@5X0>ce[02hh
I01k?4l0WPL>0:0?501c@ET0HWjM08>:VP2261l0U@8:08l22P1_5B/03AA@004EG00375L0=eN205Ag
U`1oWJh0IGjA01leB@1>HfD0;cPm017;200:003o00Sooooo05D0A;4S0;^i^@2obm@0SIbR08VCVP1C
@dP0]ZVc0=7Hh@1=CEL09PD<08YK7P2hNb@0R@h60:l62`2e1P`0[0L?06`21P2JAD`0_G1g08`;402n
2Ph0cP`<0=<<3P3D3140b0P<0<862`3:2Pl0cPX?0=8=402R4AD0HT540>STiP3Xj>X0iNGW0>[Rh`2i
FU`0`aLJ0<8H7`1`92h0a;o20>CTi03VinP0j>SZ0??Sh`2mB4`0cQXN0<0J7`1[;S80h>;T0>GYjP3X
j^`0i^WZ0>GUiP3E];H0WADK0:l7402^1@h0[@<<0:l4302[0P/0YP8:09h21`2E0@L0T04308l2102=
0@80S08209D10`2Q0@L0YP8:0:H11P2R0@D0U08608L21@2/2A40]`TA0;852`2/0`P0Y08809L12@25
0@H0R04708D21@1e0@80NQ@400@00?l02?ooool2003o001;06;A?`2RZ;80V:2]09bP[@11CfP0;cQB
07a[M@23K7D0S71g09IaN@2LMgd0WWQl0:=kP02VOh40ZH630:N2O`2eUXl0_9bE0;nOU032Y9@0a:RH
0<V^W`3:/j@0dK^[0<BYU@3D_J/0cKZZ0<o0/@3@_k<0c[nh0;>XX02l/Z`0/ZbX0=77`@3CbL<0dl_5
0=;=a`3Cc<D0eLg;0=C<bP3Abl`0M8Z^04YLT@2]Dfh0ca<J0<DF603IVYL0^;6f07aZQ@2J=E00`PhG
0;/=4`3:Oh40YZJX04mKN01hC6d0UP`M0:L33@2C4b00cko80<KBg02ncMl0=Dn<008JK`0476D0BFF@
05egU@1_Rj80Ni:U04IQQP0O=e`0KWn506ijO`0/>DD0Cha700`00?l02oooool000[ooooo00H00?l0
09^?O033d]l0F4mF02P20`0^0P<202810@1>02/10P0^0@40?`8304l21@1N0PD0J@<606l11@1l0`P0
Q@<608l4202<0PD0R@8408T21@2=0`L0SP4709831P2M1@P0W`@70:`62P2`1PT0]@/>0;H>3`2Z4Q40
MB0L0;^b[03De]H0emOI0=WGfP3C_/40WUMK07DT9`156QP0IfAM0;fo]`3Fe]00fMcI0=[Mh03Gfm`0
em_M0=GJg03DfMP0eMSK0=GIf`3Df=X0YX23090C5@2J2@h0V`X>09D;302LEU@0dLK50<oBdP39`<40
NBHU08T30`2:0P<0Q`4308<10P230P<0P@8507`10`1i0P80M`8207@10@1d1`T0PR0Q07hG5P2210P0
V`P=09T5302I10`0WPT@07dD6P2j[[L0_lcI0:job`22Ri@0EH@n0P00o`09ooooo`800?l004`0DKlZ
0:>YZ`1MMh80Gg^205IdNP1iTid0T:N`0<GBf`2]][d0NX2207]nN`2DTHd0WYRC0::JU02PUhh0Wi:8
0:BCR@2YUhX0ZYV70:ZJP`2]Vh<0[If40;6NQ`2aWhL0/9j50:bLP@2/VX00Zi^40:bNQP2]XXd0[JFC
0;>/WP31^Zh0_[^`0<6n]P2/[j/0^;^i0<73`02c]k<0]k^e0;jo^P2l_[/0^kbk0;Ng]02e];00]HB4
0:XH7P2h2a00/`X=0:HG7024AEX0<3e]03=<O01gJh<0TCY709`94`2W1@/0YP@:09H>5`2MKGD0TZ6b
085:EP2A1Ph0QP@A03@<?0045ed05S9[07^I^02/`]@0OIFV06b5V00C;Td0?EQS059TGP0mB4/04/l=
2P00o`08ooooo`1E04^h:02e/K00`/cE09NV[02;UY`0DT150;nb^@3Cf^@0=cU20245202TM2`0RSd=
09891`2]10T0]@L;0;H6302L20d0Y3a30:M=D@2i9RH0aP`=0<P82`3620`0a`L=0<862`352@d0b0T;
0<h<303?30h0^A<G04D72@3:`/@0inCW0>CTi`3WiNH0aXf90;4N80365AT0TQ<H05U2@`3LfmX0i^KW
0>WWjP3/i^P0c8V;0;PK7`314QL0N14H0<2k_@3VinT0j>SZ0>KWj@3UiNH0hM3B09lb=P2[2A00[@H>
0:`32`2/0``0Z@8:0:@2202N0`P0V`4809X11P2C0@<0T04309H10P2U0PL0ZP480:P1202U0@L0X@44
0:421P2F0PL0X`D<0;D93`2d1@h0/0@<0:@12P2K0@P0SP4508L10P240P@0N08307/B0`04003o00So
oooo0P00o`009P0aiQl0XInT09^S[`2DV:H07RI703a0FP1iJW@0Q6eg08]_N02DL7X0V7El0:5kP`2R
NGh0YWn10:Z3Q@2VPGh0]9:<0;VJT@2oWY<0`9nA0<FXU`38[Yh0b:fN0<ffY`3@^JT0d;^Z0<fjZP3?
_k00d<2d0<jo^@2h[JL0c<Bk0;B_Y`3@bL00dl_20=?;a03CcLP0d/_80P3CcL/08`3AbLT0/;S:02a<
N`22Ihl0`ATU0<dB6@3>Gf40a[B`0:^/]`1LEH@0ZQdb0<093P2^;C40_Zf/096KZP0/;eL0QBU40:D4
4@2N1A80]G^50<WAgP1]Q:h00Qi_00l_L01iU[D0/L?C06f4VP1fSj@0I7fP010YF`1bQYD0M7n307=l
O`0a@D/0GEeD00`00?l02oooool000[ooooo05H00?l009nBP02/[[/0=a`R02@10@0X0P807`4002D1
0@0[0P40<@4104L31@1?0@<0F`4406T1101e0`H0O08708@21`2;1@X0RP<708L210280`@0R`<408h3
1P2C10P0V`@70:/52@2`1`T0/0L:0;@:3@2c3a40W2@Q08=KE03Ge=80e=OF0=KHf03Eb<`0TEQM04XH
5`0U61@0PXEn0<_>a`3Kg=X0f]gL0=OMg03HgMd0fM[M0=SJg03GfM`0eMWI0=CHf@3FfM/0c/_>08Q0
AP2H3a<0W@/?09`<3P2H2@X0RAlO0;:=S@3Bd]40dLk>07Lk>P221@L0RP8308X31@2100D0O@0307h1
101k0@<0NP4307T10`1f0@<0M@4207821@1^0@@0O@8609L72P2F0`X0UP<<09T73`244AL0a:ng0<7;
e`30cMX0Q8bF05R8@P800?l02Oooool2003o001<05>o:02LWil0QYbZ055^M`1OO8D0LHbE0:>d_P35
d=/0]kk707=gO026R8P0UI:@09fFTP2JUHh0ViF<0:2AR02RT8@0YI>40:RGQ@2YV8<0ZiR20:^JP@2Z
Ug`0[i^00:fLP@2ZVW`0[9^00:^LPP2ZVX00[9n80:VPS@2]Y980[jZK0;^fZ`2f]Jl0WjFP09^PWP2[
[J`0[K2/0:B[Y`2T[:T0^kbh0;Rh]02g]k80_J^Z0:Dg?02e3A<0]@`A0:8T:`1QAfT08cme06i/R@2G
DE/0VALM0:H63@2U0`X0X`890:D32@2S10X0R2hk05=UOP2:QI40P1DK06X:8@0?55H06CUc09Rjd`2c
b=L0/L?E05UkVP0N>fH07caI06AmP@1FIUl0?T]:022n6`X00?l02?ooool0EP10[AT0a;fj0;k7d@2C
XZL0PY2D04Xn@@38_/D0e=kU02d/=@0R1@H0/Wl/07LN0@2F1@H0/@H>0;P73`2h10d0[P<:0;0E702a
7B40_@X?0<X:3@3310P0`PH<0;h42@301PT0a@L;0<X:303<30X0c`h>0<@B601W1``0WXj@0>KTiP3T
i>D0i>CT0=bl]`2O:bP0`1HF0;4H700i1PP0`;fl0>OWi`3WiNP0j^KW0>_2``2b:2/0`Q0F09HE6`2B
PhL0h]oR0>GTj03UiNT0hN7U0>?Kg@2ZEUP0YP/B0:h63`2^0`/0[08;0:P22P2X0`X0ZP@;0:L32`2Q
0@X0V@4409T00P2R0@@0ZP880:`12@2X0@P0Y0470:00102Q0@H0Y`<;0:T22@2a1P`0]@H>0:d12`2T
0PT0VP8808h11@2400@0PP4507/1101k3P808/P10`00o`08ooooo`800?l004`05_0;0<2j^@2MY[@0
XjRh02L^CP16Aeh0L69[085^M`29KgH0TVmh09QcNP2MNGl0XX2309UiO@2SOX80Z8600;6;R02gU8/0
_9b>0;fPT@2mXi40aZjM0<^aX`3>]ZL0cKVZ0<fk[03<^:X0ckf_0<fm[`3@`;@0_[:Z0;ZaZ`39`KP0
clS00=3:``3DclP0eLk70=?<b03<b<L0d<c;0<o8aP39b<X0XkC=05MYV02d?E40cA4I0<8O903DWi`0
^;Bb06ejW@2;@FH0_@dH0;0=502hOh00XJ6W06E]RP1O>U`0W0PH0:D33`2H<3`0b<OI01LeM00L?G/0
VKK>0;W;e@2faM80G7:?03A@NP0995L0IWZC07j8SP1dOX00JGMm02/nC@1KGeH01_<32`00o`0;oooo
o`002_ooool0:@00o`00XXQf05loA`0g1`X09@4202<20@0N0@409@4102h20P0j0P80B@8305D21@1S
0`L0J`<707<2201k0PT0OP4808<320240PH0Q@<408L10`2=0`H0SP460942202J10L0Z`L:0:l72@2^
20T0]0/=0:TI5P2^IU`0]ZRR0=GEe`3DemP0al;308EVJ@0n8200HV1G0:Z]Y03>clX0f]cI0080fMcM
02/0f=gN0=[Mg`3AeMP0]L330:F_[`3Ef=T0eMSK0=;Be02[S8l0QQXM09/=4@2O2a40W0/@09P9302;
30h0S3/k0<B_[P3Be=H0LeIH06l=40271@L0R08408410P1l0080O@4407/10`1i0@80N04307D10P1e
0@<0LP4507410`1m0PH0U`D909P5302D10/0U`L>08@@5@2`V9d0`L_E0;C1c`27SiT0GHY700800?l0
2Oooool2003o001<02SN4P2FUI00Q9bX05ajP`1ROhL0W;:k0<3@f`2nb]D0TI^R07YnPP2=SH`0TY2>
09VCTP2@RXH0UXn609j>Q`2OS840Y9:30:REP`2UTgd0YY9k0:RDN`2ZUgd0[9V00:JENP2XTgL0ZYIj
0:ZKP`2VVh<0Zj6>0:fQT@2YWhh0Yj:E0:2PU02l_;<0[:nV0;Zm]P2UYZ<0_;jk0;Bh]02OYZ80^KZf
0;Ne/`2d]:l0^YBE0:TH7@2g3A40YbL^05e9K013BWX0SE9W09hL9@2X2@h0ZPD<0:L52P2V1@X0Y@<:
0:P42P2T1P/0PC=6055/SP1=JXH0R5UV04T?=`0D5500>D=Y0:_9fP2eb]T0WkO@02I5L@0WBg00NYJP
06j0P@1EIEl0=DM702j_;0X00?l02?ooool0EP15[a`0]Zj]0<WBf`2GYZ`0R9BH0553B@38`l/0cMOO
01`M9@0W30D0/7/]06X:0@2L1`X0/`H=0;H5302i1@/0]`@90<893`332Pd0aPT:0<X92`382@`0_PD:
0;`42@2o1@/0a0L;0<P9303;3@`0c0h>0<8=4@2B4AL0OF9T0>KSi03Vi^H0iNGV0>KGeP2UE580^APL
0<0F701Z3A80Sh:30>CUh`3Th^40jNOX0?3Jg02gATP0`1<F0:XE6`1_D5<0gmgN0>?Rh`3Ph>80h=oR
0>7Mg`2hNgd0Xa8J0:h63`2`10d0[0<;0:T32P2W0``0YP8:0:L22`2Y0@/0[0<90:X21`2X0@H0Z@48
0:X1202X0@L0Y0460:00102R0@H0YP480:L11@2a1Pd0/`H?0:`23@2Q0@X0U@4708/11P220@D0OP45
07P1101g2`808LL10`00o`08ooooo`<00?l004/0aKVa09^W]`2GVj/0@DMS04e<G`1eJ6h0OVYa08E/
L@2@LGT0V79j0:5gO@2JLWX0UG9h09EgNP2YQHD0/H^70;F@R02mW980_Z6B0;nPT035ZYX0a:^I0<Zd
X`3:]ZP0c[V[0<^gZ`3?^jh0c[b_0<^n/@3>`[P0c<6k0=36`03>al80cl_40=CBcP3Dcl/0dL_:0<g:
b03>cLP0c<[60<g7aP39b<d0MX^[095UR0345R00bQ0G0<IGF@2m[ZX0Z[2m05A:N`2V52P0^@TB0:Xn
@`2^XZ@0U9RU04Y:K`2:73<0XP8@08l64`2POiH02bUV09>ac`2kcMP0^L_G09:ZbP0R?g@03bUH05=Z
QP1oSiH0KWUn06EcN00kCFL06BiB05MSI00LaQ402`00o`0;ooooo`002_ooool09`00o`00L4lX05D>
3P0g0P807`4101h10@0M0P409`4203@20P0k0P80B04305P20`1P0PD0H04406L11P1^0PH0M08607d2
1P2110L0Q0<708P31@2?0`P0T`<80982202J0`L0ZPP;0;472`2a20`0[`T;0:Pf;P2gUhd0dm3=0=;F
f02S[Jl0;STh03/n=`2KWIH0cm3>0=OJf`020=SKg00]0=SLg03Jg=d0g=OI0<>[/@1OEUT0C5]H0;Fm
^03Gf]/0cLK709U]KP289BH0U`d@09/93@2N2Q00V@P=09D82P2A20/0RP`?0999BP3?alT0VIBC03X8
1P1g1`P0QP8307l10`1l0080OP830802101k0P<0L`4207D10P1e0P<0L`4307@10`1m0PD0U@@;09D4
302A10/0T`T=09PX:`2/S980`/[D0;_8e`26SiP0GXa:00800?l02Oooool2003o001<01kT2P2IThH0
Ujjl05elQ@2BZ:l0/L3=0:Via`1lQY80NX2408B8R`2:RX/0TI2<09RASP2GT8T0Thb109^>Q`2MRh40
Y9640:>@OP2WTW/0ZIAl0:^EO@2WU7d0YI5e0:RGO02WUW/0Yi9e0:RGOP2YW8D0ZYn=0:VQS`2IUHD0
PH=k07R0NP2>VI<0_Knh0<C2^`2m_kT0YZZZ0:R^ZP2i^KH0^[Zg0;Rh]@2f][80^IBE0:/I7P2c4140
/UiV08M:HP2K8Bl0[@dB0:h7302/1PX0ZPD<0:88302M6aX0Ya`P0:L42P2H2a40F3aN0666Y`24Xk@0
[K?303`VDP0_4D@0CBQ509Fcd01YQjl05CIZ02Y8K`1VPY00Jh26061bL019GEd06Rlk04:7@PX00?l0
2?ooool0@`14[AX0]jbX0<K?e`2FYJ/0OhV>04Pk?`3;b=80[[[101DA60117`d0Y6LW07P9102C0`P0
Y`@:0;P83P2m20`0_`D:0<P:3@382`d0aPP;0<H72`2l10/0/`<:0;822P2i1Pd0^`@;0;l6303220/0
``T<0<<:3`2g51/0I2T/0=WHf03Sh^<0i>?V0>WRi03F[J`0]2h]0<PF6@2V6Al0HCTo0=gJg03Pgml0
h^CT0>[Ti032NG/0^ATL0;`E6@1M7b<0bLS:0>3RhP3Ogn40h>3Q0>3Og`3;ZZd0Sa`R0:h:4P2_1@d0
[@D=0:`5302U0``0Z@<>0:d33@2h0`d0^`D<0;H3302^0@X00P2[0PP04@2X0@P0Y0880:011P2P0PH0
X`480:D11`2^10`0/PH?0:P22P2O0@L0UP4608X11`210@L0O04607P2101d20408LL200<00?l02?oo
ool3003o001;0:g1V@29U:<0X:Fc01hW@P1DEFL0LfQ/07i[L@25Jg@0SVag09]eOP2RMgl0UFae0:1l
O`2fXj<0`JZ^0;2=S02bShP0]iR;0;fPT02oX980]Yf>0;^VU`32[ih0aK:S0<^dY`3;]:P0bkJ/0=2n
]@3=_[H0c/:i0<Nn]`3?al00c/No0=3;``3Bcl/0d/k;0=7>bP3=blL0bl_60<c=b03<b<@0cLS70:nf
b@1VK9T0/R<a0<d@5P2n92L0d:ZW0;Zi_@1MJI40VcQD0;`<502S4aX0b:^/0::R[01HHH00NC=B09/2
4P2J10l0OBm902]6N02dcN<0]<WL08fWc@0@;VP094=`07:8W@2AXJX0TZ6V07j<UP19GWD011A5000=
A00mC5h0:j@O00/00?l02oooool000[ooooo05H00?l005TZ1`1?10@0=@4201d10P0N0@80700102X1
0P0a0P80>@4204P2101<0@D0E`4606021P1U0@L0J@870702101k0@D0P@4608D31P280`@0R`450903
202>0PP0Q`<70:D82`2_20T0/PX;0:l;2`2V@CP0^Z>L0=KEe03=d=40J7=]08>:P02n`KP0e]KD0=KH
f@3Gf]`0em[M0=SLg@3Fc<h0bZ:V0:=RJ01C9bT0P7eg0<S=b03HfmX0dlK90:aIG02T7R00W10A09d<
4@2O2`l0X0P=09h93P2I20h0TP@:08h52P243@d0XW5a0<K2`P1:>cX0D`P:08431@240PH0PP440802
10210PH0O@8507810P1e0P@0MP8507@11P1e0@L0N@4709@53@2G10`0T`@:098630293aD0YGUn0;>j
a@2kbMD0QXjG06B2CP800?l02Oooool3003o000Y09b=O02DZ;P0QIjX0;C5d02KYkL0KUeY07=QI`1n
Oh<0PXN808Z:R@2AT8`0TY2909>?Q`2GShH0VXf309b9O`2OS800XhYk0:N?O02WTW/0YY=h0:BALP2S
Sfh0Y95`0:FAL`2XTW00ZIEf0:JHO@2WW840Yif508^8N01VLF`0H6i/07f;Q02m_kH0`l:k0<?3_P32
`[d0`L6m0;fl^@2j^kH00P2f^;<0802o[j`0YcHk0;P@4P2c5AX0[`hD0;493@2d2@h0[`P<0:<83@2E
7BD0McY908UEG`2H61l0X0T>08LlD00K<FL0DGfQ05QoV02ab]X0OGfF01`GBP0J5Td02bMQ02=2LP1Z
RZP0OIfc08JOZ`1jT9X0CFQg00lV@`014S40<ea02P00o`08ooooo`1F04jh902WViD0b]GL09JV[@2:
TYL0DTE90=3?e`2?VZH05@`D05Hf5P24Aad0P0/=09P4302V0`X0]0@<0;d73P2o1PX0b0/=0<T:2`36
1`T0``P<0;P42`2[0PX0W`480:L5302g10l0^`D=0;l83@2n1``0`@T>0;d?5P1S2`h0`Knn0>;Rh@3R
hN<0i^CT0>SDd`2iD540aQDH0;XG701I51`0clc?0>7PhP3QhN@0h^3P0=6SY@2U7B<0_Q<J06`>4`2U
W9l0gmkP0=kNh03Ng]l0g]gN0=[6b02D=c`0[@hD0;06302_1@h0ZP<;09H11@2U10`0]@L?0;/4302i
0PT0^@<;0;<3302Y0@H0Y`450:L1202T0@L0X@460:011P2E0@L0VP490:h63P2Z0`X0YP4809h11`2G
0PL0Q`4607d11P1f0@@0M04107D7000Qa`83003o00Sooooo0`00o`00B`2Hc8@0U9j/09^P[P0Q;4P0
=41N05]GI`1nJW40Qf]f08i/N02LMH40XGR1095[L`2WTY@0bl360=31b@2[S8l0/hn:0;VIS02iVh`0
/YR909N4N`2>P7P0/j>F0<B^X039/Z@0bK>V0<bh[@3A`;X0d<6j0<c2^@3;a;`0clNn0=39`@3?b/80
d/g80=??c@3AcL/0c<[60<k:b03=b/L0c<S40<[6``36b<h0E6bG0:M@I`384AP0`a4G0<amOP2l/K80
SYNa081>LP2f3ah0[@PB0;=aN02UXJX0O8>H05HgG02D21P0W@8=08LH:P0]=VL0H8>e049QU00A<VX0
=eF206b<Y@2L/Kl0Q9BP07F8U`0fBf`01QA9004:@P0234<09SME03>Q;P0;003o00_ooooo000:oooo
o`1F003o001K5P@0B@8403410@0Q00408P8202010@0X0@80:`4103T20P110@80@@0105411P1M0PL0
H`4806L1101^0@D0N`8708011@270PL0R@<308T10P2?0PD0S`<808821P2Q2P`0[`/90;082P2`2@/0
YS0Z0;VET03Fe=@0bLk>0;>e[`3Be<h0dmOD0=CGf03Ff=X0e][M0=KIg03Fb<d0/f]b098b>01=4a80
LVaV0=7BcP3HfMP0f]3C0;I]K`2c71d0]A8D0:8<402M3100W`T>0:483P2P2@h0VPH>09L73@2D20/0
S0D708HQ9@3=/k@0V9FC03H=3P1i1P/0P`8508@20`240PD0PP<707d11@1l0PH0NP4507H11@1h0@L0
N@4807/11P2B10/0U@<;0902202@1@X0R@L<09AMG`36bm80^LGA08R@VP1gG5@2003o00Wooooo0`00
o`00B`2UTgT0YkO40:ZnbP2N[k`0IT]G06`B6@1h=3L0P7j00865Q`2:Rh/0Shj<09:?RP2@S8D0UHb5
09V9P`2MQgl0WXUn0:2:NP2TSW/0Yi1k0:6:L02VSW80Xi1b0:>@L@2RT700YI9`0:NGN@2WVX@0Y9Z5
0:>KQ@2PW8L0Nh1e07n4N`2MWY80^;Va0<?0_034`l00`/2o0;jm^@2l_;P0^[Zg0;Ni]02e]k00^K:_
0:Y;C`2g3a40]`X=0;H:3@2d2A00[@`?09dQ9`1d?e@0A41U06A1G@295b<0UPhC084lC@0T=VP0HX>U
09fc`P20WkD0_M;N0<37d`1aC6@0DQ<d05]PO`2]amP0TJVj07B?Y01iT9l0A5]h008DA@0243h00@lf
02La@P0:003o00Sooooo02/0@JTC0;n`Z@39d]X0UJF]0829T01:>T00eMCM06]bOP0J2Q<0J4HO070[
4P221@/0WP@;0;44302g1@d0^PD;0;d52@372@d0b`T<0<D72`2g10P0[P880:H22@2H0PH0VP860;@6
2`2h10`0^`L>0;/73@302a40_@/D088=4P2JTi<0h^CS0>3RhP3Sh^80jN3Q0;ajNP2i8b40]b@Q07<P
802cZj/0hMoQ0080hN7R01X0gL;409L]<@2e4AT0Ra0H05M2A@3GemT0gmoP0=kNg`3Ngml0g]GE0:m^
L02T4QL0/`P>0;45302b1@`0ZPH;0:`42@2j1Ph0^`@;0;X52@2f0PP0/P<80:@1102N00@0Y0470:82
1`80X04500d0U`<708l11@2Z1`h0[0@<0:H2202K0@H0TP4508@1101f0@<0M08407820P1i40L08/T4
00<00?l02?ooool3003o001;08;FJ@2JX[00TiNY01dVC@0234<0<39H07UXLP22J780SVii09QaO@2L
LG`0W7Ak0;fX[@2USIL0_:BZ0:R=S@2YQh00/i:80;6AQ02RRGd0PWIc07YbL`2FRX40_ZVJ0<>]W@35
/:40bKNZ0<Zm/`3>`k/0c<6j0<_3^@3?akl0d<[50<o9``3Ac/T0dlo<0=3=b@3>c<T0c/S50<o9aP3<
al<0al?10<S6a`2CX[/0LVRA0;<M:P3;4AP0`bhe0<5VK`2jHg<0]E1S0;LC7P2e2140X3Hj0=32a@2L
YK80@TI[07lG:`2K0Pd0R@D@0:J8V`1^Oj80LHRX0:6eb02HZ;P0P9NY07F@X@27WZX0FVn8004@B`01
2T@00@/n00hNA00J;DT0AXM500/00?l02oooool000[ooooo05H00?l004dF0`120`<0<@4102810@0N
0@407`4102H20P0W0@40@08304`20`1?0`@0DP8405P1101O0@H0J04506l20`1j0P@0OP4408D21@27
0@<0S@8509<2202E0`T0V0D:0:<82`2/2@/0/0X;0;092P2T61@0ZfiW0<2k^03@eMD0d]GE0=CHeP3E
fMT0eMWK0=OGf@3JdmH0cJZ_0;=BF@2:7b00B1LD07=ZHP39bl<0fm[I0=[5b@32Mg/0]R8U0;lB502f
41<0Y@d@09h<402O2Pl0X@T=09l8302N20h0U`L<09@8302B1P/0SPX?09]BE@3D`<40Gcdn06d52022
0`L0P@8408<310241@L0N`4407T11@1g0@<0MP8407H11@1h00@0O@4509H6302D0`T0S@<908`32P28
1@/0QTQ<0:na]`2ob]D0RY:M07=ID@800?l02Oooool3003o001<09:PI`2X^LD0Z;K706iSK@1M;C00
OCm406/Z;`22NW`0OH2108J:R`2?Shd0TXn;09:<QP2DRhD0V8R409b6P02QRX00XH]k0:6=N@2UT7T0
XHib0:>>LP2QS6l0X8e_0:>DM@2STg@0Y9Ek0:BMR@2QVhD0XY^70:6LR02NVhX0XIjA0:>RUP2a/ZX0
`L2l0<;2_P32`Kl0_Kbi0;fm^P2h^[L0];Rc0;6f/@2f/k00YTeA0;D>4@2g2P`0[PXA09lO9P1j@EP0
=T1c03]=N`1j=4`0T0hI08XI8@1R?EP06C9V06N7Y`2CYK@0PIJZ05YfT02gd=l0`M7L0;Rc_`1e<3l0
FSU>0:[5eP2@ZL006CET045PP@0bBfT00A54008A?00B9cl09cY700gL2`T00?l02?ooool0EP11YPh0
]Z>H0<[Af`2CXZ/0QXnE05a>EP3Ef>40>45<01d:3@2<HBd0HPl609443@2/1@h0]PH<0;P62P2l20X0
_`P;0<P83P3;2Q00_0H;0:h22P2Z0@P0[P<;0:l32P2b1PT0]`L:0;@5302c1@d0]`H=0;/9402j2A<0
Ya4H06]8C03GemP0hN;S0>7RhP3Pgml0g<g:0=jh[`3R_kD0fl>l0=W@cP3Th=l0hN7O0=oPh@3Ue=H0
WDI;0;DD6`2W4aT0=@D70;bk_03Pg^80h=oS0=oNhP3QgN00dZfb0:<U;02j2@l0_`/>0;l83@2o20h0
^PD=0;/5302l10d0^P<;0;H42P2b1@/0Y`8809`00P2R0@L0YP470:L2202T0@L0X`890:<12P2/1@`0
[P@=0:H2302L0@L0S`8708021P1f0@@0L@8506P10`1_4`d09KX70`00o`08ooooo`<00?l004/0J=Y@
09jS/P1cNI000PL_0086?00R9U80MVMf08A/M@2?KWX0U6ih09Q]MP2OLg/0/YJK0<2Z[`2eVil0YhJ3
0:Z5O@2/Qgl0/8f00:f@P023L6X0P7=]0:>@Q02mYiP0`JbK0<FaXP38]ZL0bKfa0<o2^`3>a;`0blFj
0<k7`03=b<<0c<S40=CBc@3He]80e]?@0=C@c@3>b/T0cL[90<c8b039aLD0b<O50<G5b`21RjX0VfQk
0;i=C02oCDL0^59>0;UEE02kGUX0^EaJ0:mHE02TL6d0ViNI0:nia01FJHH0J35?09L44P2G0`l0XU]V
0<W>eP2oc=P0^L[E09j``P0fDW/00aeM01`iJP1ILXT00Q=;00XJA@0cA5H0DF1T02LiB01LGE`02`00
o`0;ooooo`002_ooool08P00o`00C1X303X20P0^0@807P4102020P0M0@409@4202l10P180@D0D@84
04`20`1=0@80E`4306410`1Z0@H0K`8507P10`1m0080Q04208/2102A10L0U`H809D32@2J10T0X`P9
0:d;2`2]2@X0[`X:0:8H502mPGT0a[fi0=CFe`3Df=T20=SIg00S0=SBeP36Uih0]E=H0;HX:`2l;b`0
[7M`0;Vg[P3DeM80g=7C0<N:S`2c>Cl0`1`Q0<@D5P2i4aD0Za@G098A5@2241<0NPdB07/=4@223Q40
S0hB094;3P2B2P`0U@P<09T83@2:2a80Sc]00:agM`1^2P`0P0<607h10`210PH0OP4407`21P1i0@<0
0P1f0@803@1i0@@0O04707l11`2E10`0UP@<08h22P2;0PT0R0D:07hh>`2e/;D0^lKA08N?V@1dGED0
0P00o`09ooooo`<00?l004`0PJmI0:Rb_P23N8H0H1TL06Y0@@1`GF<0HBH]07e`LP1iOX00QHN708f>
RP2ATHh0UI2<09F=R02JShL0VXV20:2=Q02PSGh0X8Yd0:68L@2OR6/0Wha[09n<JP2QSV`0XY9d0:RI
O`2TUX00Y9^80:6IQP2OVHH0WiZ709fKR@2NWXl0WYnC0;>dZ`2l_[P0`L2l0<71_@2l_[`0^Kjm0;Nl
_02e^[X0/;Jd0;>b/02[HVP0/A8G0:LO9026A5@0CDib02]:N@1VPId0VY6I07dM9@1i;d00>3EO01m0
KP1ZQIH0TJ2R0:bj`P2H/l<0LiFZ0:?2e02nd^00`<oL0:fS[`1H>T`0SJBf08nV_@0=9e`06S9P04IR
NP0=94H0<TaK04]QGP0jC4h06LTH2@00o`08ooooo`1004JY4P2hY9`0a]3H09n^]@1nQX/0ETM@0<gA
f`0J8Rd070X=09IY<01]1`@0V0H?0:d63P2h1P`0_0H:0<082`311`/0aPP?0<@83`2e0PP0[0490:h3
2`2^0PT0Z`460;43202c1@X0/P<=0;<33@2h1Pd0]`L>0;L74@2c3A@0Ia8K0:jJX`3QgN40h^3R0>CO
hP3ThN80iN;R0>;Oh@3Ug^00i=cO0>;JgP3Pf=/0gmCI0=bd_@2H9S00^0lG0;<=5@1E1@X0UHj@0>7Q
i03Sh^L0gmkQ0>3Nh03Rc=40[D=;0<<>4P393A00a0T?0;L6302T0PL0[`D>0;@33@80]@<=00h0/0<<
0:L2202O0@@0Y0870:P11`2/0`T0[`@:0:H11`2W0PP0[@D<0:/32`2V0@X0W@4808T11`80MP4700@0
KP4506D10P1Z3`d0;XL70`00o`08ooooo`<00?l004`0@>H^09jMZ013Af@00@D^0086>00Q9Dh0O6Ie
08QZMP2?K7L0U6ad09abN02NMG`0WWMl0:B0Q02QNWd0YWmj0:5lM02VPWD0/9230;2EQ02hWi40]in>
0;bRU02nYYH0`J^I0<F_X@39]jL0b;b`0<[0]`3>aKh0c<Fo0<_7`039a/00d<c70=KBcP3GeM80emCC
0=C@d@3<bl`0b/W80<[9aP38al<0a/C10<G2`P32`<80_kfn0<6h]@2n][80]K2/0;:/Z02a[:T0[JNU
0;>_[P2_[k40Yjfc08nIY@2:Vjl0B3eT08/:8@2K0Q00RaPT0=33c031c]T0^<WD08nT]01^Q:D00QIL
008FE01PNHh0<TIN05=UJ`1LJFD0Ef9T02Lh@`1/MWH03MX82P00o`0;ooooo`002_ooool05P00o`00
BaL303@10P0X0@406`8101h10@0N00009P4103/110150@@0BP4404L20`1;0@<0F04105h00P1U0P<0
K@4307d21@230@D0QP8308`11P2@0@L209L5200309T5202U2@X0[@X;0080[PX;02X0X1LE0;f4OP3<
a<@0eMKJ0=GHf`3Hf=`0f/oC0;b4RP2^:Rh0_ALG0<<E5P30BDH0dLBm0=_Lf@3LeMH0ahB<0;PU;030
5QX0_QLI0:PI6P1l5QT0C`/=02d41`0H10D04P@501<30P0M0`<0<`@705/>4P1j3Q80T0X@09X83P2F
2@l0S@/B098c=@216QX0P@@707l110210PD0N04207L10P1f0@8207@00P0=07T11P1l0PP0O04709@5
2`2F0PT0S`4708h220280`T0NBP/0:bQYP2obMD0OXNA071OF002003o00Wooooo0`00o`00C01T`d00
PhB705db=`1d9bT0H24V071EG01R9Rd0NfU/07AhNP24Q8D0SH^:09>?SP2ASHX0ThZ709^>R02NS8D0
X8f40:2>O`2NS7D0WhQ_09n6J02RRf`0Whe]09j;J`2TTgH0XiIn0:>IQ@2TWH/0Z::D09fEP`2NVXD0
WIf<0::RV02PX9@0];J/0<2o^`30_kh0_/2n0;c1`02i_kl0]/2l0;Bn^P2d_KX0/kJf0:b1Q02FBe<0
IEIa06e@J`2:EVD0VI^Q09RQXP2GVYT0RGn4024eG@16HX00OHb?08jIUP2HWZ00VIbU07n6T`2:TZ00
]/3>0<3?f`2od=`0_LkK09ZT/01_RI`0IH6C02m:K`0<:580EW9j05=ZK@1BJVP0CFAM03=6B`0XZBT9
003o00Sooooo01@0AZL@0;2FSP37d=L0Sj6X075lP@1PEUd0`LC?014D7`0M2@L0SE/]07P9202L1@d0
[0D;0;H4302n20d0`0P<0<492`2m1P/0^0D;0:d22@80[@8:00@0[0<70:`2202_0`T0/PD;0P2c10d0
>P2f1Ph0]PL>0;P:402g2a40Y10H08LM:02fKgX0c9NQ0<68U034QY<0]W5l0;IYM`2fI740]UeY0;ED
H@2cD5`0/TUH0;0b?@2b4a/0_0dB0;h@50203a@0NFQZ0>CUi`3Pgn<0h>7U0=kOh03Tg=d0^6Q[0<@B
5P342Ph0``P>0;L53@2T0PT0Y`890:d22P2/0@T0Z@480:P1202U0PL0X@460:H1202W0@L0[0880;@7
3@2Z0PH0ZP890:`32`2Y0`X0YP8809h11P2=0PP0O04807H11P1^0@D0H`420689200aR@P3003o00So
oooo0`00o`00C00]hQT0Y9nT020WAP072Rd0=31@02h^C@1lJGP0QFQf08MSLP2?JGH0W79m09ibO02Q
Lg/0YWMl0:5dM`2RMGH0XGIc0:Z5N02cTX@0]IR90;NKS02iX8d0_J>D0;nUUP32ZiT0aJnQ0<NdZ038
_[80bKnf0<c4_03=a[l0c<C10<c8a03Ddm00d]3>0=CBc`3Ee=@0dm3B0<g:b`3<b/X0b/W60<K5`034
aL<0_/;30<Fo`P32^;X0aKFh0<F_/P31Z:X0_j6W0;VHW@2hU9T0/i6E0:j<U@3</KT0_ZJb09Z=Y`1K
C700SB@i09T2402<1140/hJA0<7<eP2kbM@0NXbL07^>X@0jC7006c1I0723S`1]O7`0HVi]05eYIP1;
Ff806c1006AeM@0O^aT:003o00_ooooo000:ooooo`1F003o001?60<0<P8202D20@0L0@407@420281
000b0P<0@08404@20P160@80B04204l10P1H0@80G@8406@11@1`0@H0O`4708@11`280`@0R`8709<2
2`2F1@X0V@L:09/62@2V2@/0[PX<0;4:302b2`h0XaXI0;j7Q03=a/H0eMOJ0=OBe`3@]K`0]fec0;8W
:@325aP0bAHF0<LE5@2nBTT0elC30=c1a033Mgd0]RT^0:lI7@2<51H0H0lA02l:2`0[8Qh0>chi04UA
C01PIf<0Jg1/06U/IP1BETl0?40j01dH500P1PH0D`/?08/=4@2@1`X0T@H:08X93P2?51P0P`<60883
1P1o0@D0M`4207D10P1a0P40LP8307<10`1d0@@0M@4607X11P2D1P/0V@@:08l22@2<0`P0P`8907@P
9@2eYjT0[[S008VAV`1[GU`2003o00Wooooo0`00o`00C017`b40MVIR05`h>`1Y?3d0I20Q06`[<`1X
7R80MfQ[075gNP1oOH40RhN708Z6P`2=Ph80Sgmn09F2O`2LRH80W8Qo0:2<P`2OS7/0VhA[09b3IP2M
RF`0WHe^09j?L@2SUgh0XiV20:6JQ`2YXY@0ZjJK09fHQ@2KVH@0ViZ:0:FTVP2YZZ00Xj^T0:B]Z`2i
_[`0_l:n0;bo_P2j_[h0]kjm0;Fl_02f^k/0][Rh0;Nc/`2XQI40V3aA0:@B702N9Bl0G5md09>PX02J
X9`0SiJC08B=T02<RX/0T7Qg08eHF`2??TH0Tb`g09<P:P2>6bL0SR`j09INK02e[;P0_<gH0;G:e02L
]/D0Oif]082IZ01UOHd0HGEg05U^J`1BJF@0B61Q01lf@`0hWC/9003o00Sooooo02T0AZ@<08]WG03<
d=L0W:fa07b3Q01UFel0YZZe014<5`0i7Q40Nd<Q07X42`2O0`h0[@D;0;H53@2l1`h0`0P=0;l62@2n
2@`0/`D90:X22@2W0@H0Z0880:H2202S0PL0[0@90;833@2c10d0/@<<0;D53`2g1a40]@L>0;P;4@2k
31@0_A4H0;D@6@2a4ad0]1DN0;LF7P2g4aX0_AHN0;XD7@020;`C6`0[0;`D6P2g5AX0^A8F0;dE5@32
51H0bAHH0:`J701S>C`0fmgQ0>;SiP3Ti^T0hN7T0>;Oh@3AXjD0/aHH0<4=3`2m2@d0]0<;0:d12P2[
0PT0Z0450:P01`2U0@H0Y@870:411P2S0@L0Y`890:H1202[0`X0/PD=0;042`2_0`/0[P<;0:P22@2W
0PP0WP4709011`240@H0N04406h10`1U0P<0H@8202n40P03003o00Sooooo0`00o`00900Zg0l0[Z:P
00dE=00`<4<0FTmM048kD@1iIG80Of9`07mHJ@2@IG80Ufah09U]N`2NKg/0Wfmf09e^L02PMG80YW]f
0:V3N@2[RW/0/YB40;FJR02hWhl0_:6C0<2WV02nZY/0`ZjQ0<BdYP34^k00aknd0<_1^P3=a;d0a/2j
0<c9b03@d<h0d=7?0=7@d@80d=3A02H0bl_:0<S7a`36a/D0`L;10;2ia01`Q:@0/6Yj0<18E02h=T<0
^2Xi0;4R<02[6RD0Z1PS0:LE8@2S51`0XQ@N0:<F9@2O5RD0VQ<U09<C902I31/0V`<?09@2402B8SL0
Wf9l0:EoT`2SW:H0Pi>O082BV@1/O880KGQl075mO01UKg40BEUW00`I?@064cD0A5MP02f[:0X00?l0
2oooool000[ooooo05H00?l004dF0`0b0@807`4101T20@0N0@408`4103<20P150@@0@`4204810P17
0@80D@4305P10`1Q0P80J04307@210200PH0QPL:08D31P2<0@H0T`8:09L42`2L1PX0X0L<0:P93@2`
2P`0/PX=0;@<3P2T71`0`Xj:0<o8b03A`/L0VVQ`06PP:@2H7Al0`AHE0<DD5@385AD0aa@E0<Q2@`39
L7<0[C<i09hM8@1Q3a00<1@C040n>01VK6H0W:6O0;c0^`37b/D0c=3;0<oBd03?e=80dMGB0<_?bP33
bL80/KB_07]oN@0l>SL0>@T:07l;402=1`X0S@@808P31`200@<0O`4407h31@1g0@80M04207820@1a
0P80LP4307820P1b0@@0N@460986302F10/0S@4808X320210@H0LQXN0:FAU02U[;<0PX^D06QOG`80
0?l02Oooool3003o001<02KI301gHDh0F3di06Q?C01V>3P0G`dA07Xj?01^EU/0KGEe081oPP26P800
RX5o08MmN`25Mg@0S7Uf09B3N`2IQWl0WHUo09Z6L`2JQVd0WhYa09jAMP2PTGP0Wi5j0:BKQP2WXI00
Yj:D0:jXWP2/ZIh0Vib;0:>RT`2OX9@0[:^Q09VNU`2^]Jh0/[Vg09ZTXP2j_KT0^Kfk0;Rn^P2h_;`0
^kjm0;Bi]`2c]k@0^JZ/09XV<@2b3A@0[`P=09`C7`1?BV/0TZFZ09VNW02JS8d0U61U08`/<`2<3AD0
U@D?09X42`2N10/0W`<:09/2202F0``0S`@@088D8`2MNXX0^l[D09f__@1UOHd0O9BM07V>U01XNg/0
FFaZ04YTI@0D9ch011@b03UcAPT00?l02?ooool0EP18Y@`0XWY`0<W;dP2:Vj40Q8B;07=UKP2>Tih0
60`E05Th801]:1<0T0H>0:H3302/0PT0]PD<0;T5302n1Pd0_@H;0;H42@2Z0@L0ZP890:P21P2Y0`T0
YP880:<1202[0`X0]0@;0;<42`2b10d0]@D?0;P64@2e1`l0/@T=0;D@4@2g4A80]Q@D0;<F4`2`5a@0
/QdH0:lO6`2]8Ad0[BDP0:LX802Y:bD0YRhX0:<`:@2U<B`0ZcHa0:df;`2g=S80[3/f05lb;P3Ad]00
hNCS0>;Si03Qh>@0h=kS0=W0``2T7al0^0h=0;H;302_10`0Z@480:T2202W0@D0Y`070:D11P2S0@H0
X`470:D1202T0@L0Y@4:0:X22@2b1P`0/@<;0;43302/0PX0ZP8:0:T32`2Q0@X0S`4708821@1l0@<0
K`4206010@1N0P40=X`:0`00o`08ooooo`<00?l004`05Nd50:F=QP083BT0HeaX05U<EP1;A5D0MV9]
07YJI`23GF`0TVId08m[O@1DAFP0Nf9i09Y/LP2KJV/0XGIc0:IjMP2VOgD0ZHQg0;6AP@2`UHP0/9f@
0;JRU02lYYP0_ZRN0<6^XP31/ZD0`kV_0<No]038`;L0cLFn0<[5`03<b/L0c<_70<k>c03?cll0clk>
0<_=b`3:c<X0bLO50<O5a035a<@0_L78059[U@2VK800_DM80;mCCP2nG5T0^V9P0;MYI02bKVH0[fmY
0:mcJ`2WKFH0Zfm/0:EZI`2RIFH0WUmS09QCE`2HAd/0TCLm08`Y<`2472P0O14Q07LoB02QZJl0SYfQ
08:?T@1aNgd0KWYk05]XL`0;64800PTj0048=@0N<4H0<H<b2P00o`0;ooooo`002_ooool0EP00o`00
CQD203D30P0P0@40604101d10P0V0P40<`4204/21@150@80A04204L10`1>0@<0H08506T21@1/0@@0
LP8507@210293a<0NP<408/21`2D0`X0V@D;09d62`2Q20/0Y`T<0;0=3`2b30h0/``?0:HJ703ASXl0
]hjB06/h?@119bP0OFe/0;I/J`2n61T0aQ@F0<DB5@344aD0^aTM08LH6`1<30l0>28P06mbK@2e^[D0
a/g80=3Fd`3Gf]`0emWL0=GIg03Df=/0cm?G0=7Ff@3@e]P0d]OG0=7Fe`3Ae=L0cm;D0;c0`01QHUh0
@P/<07h:3P271PP0P`870801101m0@80NP4307@00@1d0@80LP8306P20`1`0P@0L`4307@01@1j0PH0
T0D;09D22`2>0@X0QP8808421`1f6Al0[I:F092EW025SI@0JV=Q0P00o`09ooooo`@00?l004/0Led`
060m=P1T?3/0J4a<05LW:01bA4P0K45407AeM@1iNWd0OWak08InO021N7D0OWA_08IgLP2BP7X0UX=l
09R4N`2JQgX0WHUe09^:LP2OSgP0XI=o0:BGQ02WWH/0Z::C0:^WVP2_ZJ00[:VN0:VWWP2`[ZD0Zk2V
0<;9a035c/h0_<G409nXY`2OZ:H0]k^j0;Jl_02e_[h0/kbj0;Jm^P2e^KX0[kFb0;j`/`2L92`0]@TA
0:d84@2D41/0Bd9R08jDW`2PJFh0UB8/09L8402H0`d0U08:09T22P2J0@T0WP<;09h22@2L0`P0U08:
09812P2@0P`0O@`G0:B6TP22VJP0JhVF06j9T01VOH<0GG1a05Y[K00R>4d00@dd004?=00X=dH02@00
o`08ooooo`1F04ZW302<HEH0blkG096OYP1eM7`0O71i07MlQP0H2Ph0KdTY05T@1@2>1@`0Y@D>0:H5
2`2`1`h0^PT@0;d73P2d0`/0[P8:0:H11`2Y0@P0Z0470:T22@2^0PP0/08;0:/32P2V0`L0/PH<0;<6
302e1@l0/@T?09d>402Y;bL0/DPl0;MIB`2oJ5/0b7a`0<J8N`3>Uhd0e:>K0=Z/YP3M/j`0hKjf0>72
^P3NaK`0glJo0>?;aP3Wc/X0j<k:0>[>b`3ZdL`0g=;<0=oNgP3Si>D0h^?T0>3Ph`3Ph>80gmKG0;=g
LP2iGEH0[DM109l[:@2I3Q00X`880:L1202X0@P0Y@460:D12@2V0@X0Y0080:H21`2V0PX0Y`<80;46
2@2d1@/0[`<:0:`32`2/0`d0Z04>0:422`2;0PL0M`4407/11@1c0@<0HP8205/30P0oUaD3003o00So
oooo1000o`00B`2XRgH05Q/d069GH`1CAe<0<cQA05M?H`1fFVH0QF1]08]SM@19>V406b1I03PdH02D
JW<0VV]]0:9cL`2WN7H0Ygef0:b8NP2bT840Y8^008f1N02WUhd0^:>G0;VVV@30[Z00`;6V0<6g[`36
_;D0akjg0<W3_@3=b<<0cLc70<o<b@3>blX0cLc=0<g=c@39b/P0blc;0<G5aP34`lD0_kk00<71``2`
]Kd0^;Rl0<>j^02n]k<0_KJf0;Bb/`2_[Zd0[:ZZ0:ZVY`2WY:D0VIjL0;Zn`02b^Kl0]lKG08JM/@36
e=h0b<oH0<O9dP31`LP0]k>g07mgQ01aKGL0RYFL07Z5S@1gPHH0IW=c069cL`0_?U/00P]30049>@04
3S@03Adi03iCA@0:003o00_ooooo000:ooooo`1F003o001@4`80>04102@10@0L0@806`0102@1000i
0@<0B`8504810P160@80B`8304T10P1F0@80J@8606`2101a0PH0H`8206@51P1V0@80R`8709D2202K
1@`0VPD909L62@2R20/0/0`@0;8<3`2e3140[aDH0<QGF`1^92T0<B4O0:RXX`3LemD0^Wmn0;`K7033
4aH0`a8F0;/I6`1g41@09P`;05aKF@2[[ZT0dMC?0=[KfP3Hg=d0eM[M0=CIg03Ef]d0eMSK0=CHg03?
eMP0dMCH0=;Ff@3Cf=X0dmKJ0<kDe`3>dmH0bm7D0;o3`013;bh0H`lA07l62P1o0PT0O04407P00P1g
0080M@4207L21@1c0`D0F`820642101b0PD0LP4607P11`2>0`T0T04908h13@270@T0PP4806`82P2A
Kfl0RXnC06mhO01^If@2003o00Wooooo1000o`00C01JJa<0LTI0060K701V=cT0ITmB06M8CP1Z=S/0
M6i`07AeMP1hMgH0OWYj07]eLP1lLg00PG9^08YeL@2GP7X0UhAk09b:O`2MRW`0X8mm0:>BP02TUHL0
YYV;0:RMSP2YXY<0ZjJJ0:^VW@2YZ:00[:ZS0:j`Y`2kaKh0[kJc0:fg]038eMH0Xjf]0;:g]02e^;P0
];Vh0;:k^`2d^kd0/[Zi0;Bi^02a][D0_K>e0:8h@@2Z3Q<0VRTa0716F`1QC6X0Sc500:@=5P2X1@`0
W`8:09X22P2G0PT0V08909T2202O0PX0W`8;09T22@2E0`T0T08908`22P260PT0MaXS092=U@1oVZD0
QinU07ZAU01LLW40DfAZ00HE>0013CD00Q4b01/^A@0;fPX8003o00Sooooo01/0C:L=07i=A033`//0
T9nU06e^L`28P8T0EeiV01P71@1gC2`0EPH308d43@2I0`/0T04809D11P2[10/0]`L>0:H12@2W0PX0
Z0890:`32@2X0PT0ZP880;032P2b0``0[0<;0:D22@2b1Pl00P2d1Ph09`2W3180A0820;RRW@3Xg=T0
i=oI0>CNf@3RgMd0h]kN0>;Oh03Sgn80h]cO0>?Lg`3Qg^00g=_N0=kKh03Og=l0gmkP0=kKg`3Ofn00
g]_O0=oNh03Ogn80h^3T0>;Qh`3ShN@0hn3U0>7Qi@3Ng^40hMoQ0>3KgP3OemT0g<[:0:Q[K02A20h0
Y`890:L1202V0@L0Y0480:@12P020:D12@0@09l22`2Q0P/0Z`<;0;043@2^0PX0/@D>0:h53P2X0PX0
X@4908`1201m0@D0O0860781101R0@80F04104Id40<00?l02?ooool4003o000P08:XF@0R8C80IU]R
048iB`0533T0;bm>07IMJ@23HW00N5ae03T_E@1RDgL0<BUE099TKP2LJf`0XG1^0:IiM@2VP7P0ZXIk
0;:CPP2RRW`0Sgmc09R8N`2`Wi<0]jFI0;^/W@2k/:D0_kJ^0<>j/`36_kT0b<?10<_7a@3<alL20<g9
a`0Z0<g;b`3<bld0b/_<0<W8b@36aL@0a/?40<;1`02n`;h0`<2o0;bn`02k_;/0^;Rg0;:d]P2b/kH0
[k2b0:Z[[P2Z[:l0XjFW0:jc]P2MXjT0WjVc07f?Y@2T_=40aMGO0<KCg`36dn00a=;M0<C@fP2O[[`0
UJJb09ZW/02@WJ@0LWj206MeM01RLgD03ae8008?@P0P=4`0AeUO01h^?`10Be001?822@00o`0;oooo
o`002_ooool02@00o`00DQ<203h20@0V0@407`8101l20P0S0P40<04204L31@0203h10P0Y04X20`1?
0P<0F@8506H1101Y0@80L084070?3`27;Rh0M`H808d21`2D0`P0U@<709L52@2C10P0X@X=0:l=4@2`
2`l0/``B0;0C5`2W=C<0L4@o0:JVX@3FemL0f]SI0;J1OP2h6AX0_QDI0:@F6P1T3Q00A3<`096ET03;
cL/0f=[H0=kQh03LgMl0fMgO0=KKgP3Df]d0eM_N0=CIf`3Ff]`00P3Be]T0803DemX0e=SK0=7Gf03@
emL0cmGE0<gBe@3<dM80TXn>048?3`1i2@`0P0<807d11@1k0@@0N@4407X2101h0@<0M@4306h31@1Q
0@<0M08607@01`1i0@H0T0@:09D1202@0PX0R@<808<11`1]2@`0WWam0864Q`1]M7P0L6QV0P00o`09
ooooo`@00?l00180AYDC0753?P1L5aH0JB0T06<c=@1YADX0Ic0b071YK01^KVl0LFm_07ejN@1lNWD0
NG5^081^K026KVX0Tgih09N2N`2LRGd20:>BP`0h0::DQ@2QU8@0XiN70:NMSP2WWY<0ZJ:I0:jYX@2/
Zj00[JfT0:n`Z@2ma<00/kRe0;Nn^`37dmH0[kNf0;:h]P2e^[X0]KZk0;6k^@2a^[T0/kZi0;>i]`2]
]K<0];Be09YMH@25CEh0BTae0716I02C5RH0Y0L@0:P6302X1@/0X@@;09`32@2J0PT0U@8809452`2?
3aP0Rb8^07`/>01c;3L0NR8]07h94P250P/0OP@=07=4C`1YOXT0K8>806b5QP1LLg40@eIR008@>@0<
83h0>UEM02]2C00AdQ<8003o00Sooooo01@0BjD;05/Y7P2c/KT0Xk2h04i?E02ASYD0>cm901/71@1a
ABT0DP@108`3302G0@P0T`070:@3302e1`l0]PH>0:L11`2[0P/0Z@470:h32@80Z@480400Z`480;04
2P2/0PX0/P@;0;<52`2b1@/0]0L>0;D<501W1`d0SGYl0>OQi03Of]d0fLoD0=33b03@`<D0a:jf0<JW
[`31WjT0aIbY0<BFX`2oS9`0a8fL0=JIZ03BTYl0eI>P0=NCXP3FU:@0d9:Q0=>KZ@3BX:h0eJZe0=^d
`03C/[`0e[g60=2na`3Bb=00dlkE0=[Df`3LdmX0]I6D08`B6@2W0PX0Y`4:0:@01P2T0@L0X`4:0:<1
2`2T0@`0WP8;09P02@2T0@T0[PD<0;853P2a1Pd0Z`@;0:L32P2O0@L0S04608011P1j0@L0L0440601
0@1G0@40Ce@=0`00o`08ooooo`@00?l004`0I[dl05A=EP1UG600<BXm00<7>00Z:4l0MUe/085QLP1;
?E`0K5Yh03dcGP15=Ul0U6=/09]XK02OKfh0XWMb0:AjM@2ZQG/0[i2109f8M`2[VHd0YY>70;2MS`2j
Z9/0^jfO0;^cZ031^K40a;Vg0<Bl^038`kh0cLW40<c8aP3:alH0b/O70<[9b`39b</0blS<0<W7bP35
aLL0_l300;o1`@2k_kd0`<?50;^n`@2i^[`0]KFi0:na]02^/K<0[K>d0:V]/02SYj/0WZ:T0:R_[`2c
_<00ZkO109BX^P1KNiT0`mKR0<CCgP34dn00aM;N0;G5d`1KLhT0OY6O08ZHX01fQhX0MXB606IdL01O
LGH01A90024cD`1EJFL0EFAQ02ThB00/@Dh01]D72@00o`0;ooooo`002_ooool0EP00o`00E14203h2
0P0W0@407`4101h20P0L0@409`4103P20P0d0P80=P4204d31@1B0@80G@8606810`1X0P<0L@4407`7
2@232``0Q`<709021`2C0`P0U0<809P42P2K1`/0UPL:09`82`2/3100/``@0:HI7@37SXX0a/6n0=OJ
f`3Hf]h0fMWJ0;J2P02Y7Qd0IA4@03TQ6`1eMG00a<W60=SLg03OhN40g^7T0=_Ph`3Kgn40f=cN0=KK
g@3EfMd0e=WL0=GJg@3EfM`0d=KH0=7HfP3Eem`0d]OJ0<kFf03@e]T0cmGG0<_Be03;d=<0b/c=08]c
KP1a4Q<0P@<707h01@1n0@D0O04407L11@1h0@@0M`4507@21P1c0@L0N`8907T11`1h0@@0SP<909@2
202?0`T0R08808L2201^10T0ReiS089nP`1SIFX0LVUX0P00o`09ooooo`@00?l004`0>Id:06m5?`1X
?c`0GR<U06lZ<01R5a`0JSho061OH01UIVL0JVQZ07IdMP1nNGL0O7A`07a^J@23L6/0U81i09V5O@2O
Rgl0XY220:>CPP2OSWl0WY:00:2HR02UW8l0Z9nD0:fUW@2`[J@0/;2V0:f^Y@2a]J`0ZZnZ0;S1`02o
aLP0/[^k0;Bi]`2e^[X0WJRZ09jXZ@2]^;@0[[Rf0:jg]P2_^;H0ZKBa0:bd/`2`[[00M7:;08E0G@2N
3QT0Y`H=0:X6302W0`T0Y@<;0:03302E10`0SA8K07X]?P1F>5H0>CYU028aH@0]?fP0DfB705m/R01a
G6l0NQHS0842301V6RL0R9JQ07N>T`1WOh00GGAb03aEH0056S`0?5UO04mVH@0fC5408JHX2000o`08
ooooo`1104ZU3@1E8aX0Z:FY082;TP1HEE/0WIZR01`O9P0Z5@X0ISPQ06<31`2C0``0W`4;0:@3302/
1Pl0XPD<0:H6302Y0`X0Z`8:0:l22`2`0PX0[@880:l32P2^0PT0[P<90:l32@2c10`0/`<=0;@63`2e
1Ph0]PPB0:0<5@2PADd0bX6<0;]WM02eE6<0/DEB0:PeA02T;CT0YRHa0:DT;P2W82d0Z1/Z0:TG9`2`
62H0_Q/Y0<DK9P397BH0aQ/W0<HJ:03162H0`A/X0;/M:P2h8B`0_2Pf0<@b@`33>4P0_d5C0;Y<G@2d
DV<0ZeUW0:e/N@2aKWH0VadU0:L22P2V0@T00P2T0@L04`2S0@X0X`4<0:<1302S0@X0X@8:0:811`2[
0`/0/PD>0;873@2Z0`/0Y@8:09h22P2>0@L0OP4507P11@1a0P<0H04205L1001?E0/00`00o`08oooo
o`@00?l004`0:M`E06iQJ01VGfX08Ahg00@;>@0/;4h0LEYV085TM@0g;dl0OV^9014CBP1[DVh0TEmV
09][K02NK700XW1`0:AgL@2ZPgP0[Xj10:jDQ@2KQg`0Yi>70;RST`2iYYT0^j^Q0;V_Y@32^[80`kRc
0<Bj]@38`Kd0bLC40<W5``3:b<L0alG30<O6b@39al`0a/G80<G4a`32`/@0_<2m0;Zo^`2j_K`0^[^o
0;Ri_02e][X0/kJj0;6d^02YZjl0SI:C0:B[[02QZ:/0Y:fd09BMY02V[KH0WZBb0;:oc@2^_<P0amKN
0<KCh032d]h0`m?M0:nnc02R]/@0UjNb082>U`1jRHd0Kgal06QgL`1TMGP02APn04eSK01IK6/0Cf1X
010M?`055CT01JL@2@00o`0;ooooo`002_ooool0@@00o`00E0`104D20P0a0@80904101`10P0K0@40
9`4203L10P0e0P80;P4104<20`1K0`P0H08606D20`1/0P@0L`8407X2101o0@@0R04608h21P2C0`P0
UP@:09T52P2K1PT0WPT:09d72@2^3@l0]@dA0:@K6`2oS8T0cLW80=KHg03If]h0f=KJ099hNP116AL0
MWE^0<?9`P3DemD0fMgO0=[Nh@3RhnL0g^7T0=[Ph@3Lgn00f=cN0=OMgP3DfM`0eMOK0=;?d`3>aL/0
`;6g0;VRZP2hW:L0^Z:Z0<Fl`@3AdmH0d=GG0<[Be03;dM@0b]3B0<:j^`1f;S40P0@90080OP4600<0
N`4506h20`1a0PD00P1h0PH03P1j0@H0NP4707`2201k0PD0T0@;09<22@2>0PT0Q`4808<3201_10P0
R5MK08>1Q01AEEX0KFIU0P00o`09ooooo`@00?l004`0?9h807M:A01V?cl0ICXk06082P1V;Rh0GeAF
05UKF`1RH680JfQW075/K`1jLW80PGMd085bK`28Lfh0Tgig09N4O02JR7d0WXio09f@O@2PTh80Vhmn
09nFQ@2UVXh0ZJ6G0:bWX02^[JD0/K2X0:RZX@2_/ZX0YZbX0:bb/02[[jh0[K:`0:ne/`2f^[`0U9nP
08nLV`2]^;H0[KNh0:ff^02^]KL0[;>b0:Za/02gYJX0Wd9<0:`>5`2]1`h0Z`L=0:/5302V10/0W`L?
08lG7`1/<dX0=3EU01TbI`11D7X0JU9]0890DP27<D00R3=007m;EP2TZk<0UG=n07`8501b4b00DUQV
07>;S01[Ph00GGAb049LI00P>Th0DFMW04mUI@0N=TP03VXV2000o`08ooooo`1F04bW3@1>5a00U8bB
07MoPP0/:S00WijV014;3P1]C3<0CQTA07L32@2K0P`0Y@8=0:X33@2L0`/0PP0408`22@2S0PX0Z087
0;02202e0`T0]0<90;H32`2g0`T0]@8:0;832@2b1@/0]@@>0;D43@2g1@h0^0L@0;L63`2h31D0^`dH
0;d<5`303AH0_``G0;X84P2o3QD0_0dE0;T<502h3aD0^PhB0<@?5@3<41H0da4F0=TC5P3L4aD0f14G
0=H?503F3a<0dPdD0<d;4`3<31@0b0TC0</;4`381`l0aPTB0<894P2m1a40]0HA0:T64@2S1Q40Y0<=
0:L22@2T0@L0Y@480:@1202Q0@L0Y08:0:812P2S0@/0X`8:0:411P2U0@L0[@<<0;863`2Y0`/0Y04:
09X11P2>0@H0O@4307D10P1_0P<0G`4105P10@1CE@h3003o00Sooooo1000o`00C00QiPh0Mf=Q06MR
K`0A4R`0<3IC04<oEP1bGFP0MV9c03LaD`19@f/061U>08EOM02BH6H0VVQ[09]VJP2NJ6T0XG5]0:^4
O02bT8D0]IF80;FKS@2fWi40]Z2@0;^VV02jZIh0^JfU0<2e[`30][00`k^d0<Jo_039aLD0b<K40<O5
`P36`l80aLC60<W7b@34`lD0`/;50<2oa02m`<80_;o00;Vl_@2h^[T0/kNm09FS]02BSj@0/8:D0:YU
M@2UKGL0^9NP0:^SZ01YN900Hf:409MHL@2WDfX0YE9W09ePM03>cMP0a=CP0<?Cg`33dmh0N96X07VA
X`2=WZT0UJ>Z092NX`1_O7h0J7If06YgNP0M;TP0CfQb03mDIP0?6d<00@Pg008;=@0@LQl9003o00_o
oooo000:ooooo`1H003o001E2P40B@8203T10@0[0@407`4101/10@0X0@40>P8203010P0O0@00:`42
04/11@1O0@<0IP4106h20`1`0@40MP4207d20`250@80S08509041`2G1@/0V0<809d52P2Q1`X0Z@T<
0;0;3@2c30l0Y1hL0<JDSP3>blT0f=OL0=;5b`29MG`09RDU07V2NP3;cl`0g=oP0=[Nh@3Lh>80gn7U
0>3Si`3Mh^@0g>7Q0=_Oh03Hf]l0gM_N0=K4c02kSIT0VeaV08LlA01m:3<0NB8]07XI9@226bL0PS8j
0;BFVP3Ad=@0bm7E0<WAd`3;d=80cl_>0814B0201@/0PP4808401@1n0@<0NP8407P21@1i0@D0M`45
07X21P1k0@L0O`@:0802202C0`/0T`4708h32@260@H0P04506d31`24DE80N7Ig05EGF`1WH5l07hd8
003o00Wooooo1000o`009`0k[PL0O4m306Ha<01V;bl0Fc4a05a@D`1@D5@0EEMH05mOH@1VIVP0LVa^
07MaK`21NGD0QgIe08afM02BO7L0UH=m09F6N`2LSGd0Xi>409nCPP2MTGh0XiV70:RMT02ZY9T0[JZQ
0:n]Y@2_/:P0YjRQ0:VXX`2ZZjP0[;2/0:Z_ZP2]/k40[kJd0;>g]`2Z/k<0Xjj_0:Ze]@020:Vd]00S
0:Vc]02Z/K@0]:>X0:@nB@2_3AD0/@T?0:`63`2Z10d0Z0D<09H?5@1l>4/0>3UX01TdJP12Fg`0O6Yi
08PZ=P2C2A<0V0<>09T3302>2Q@0HSMA06F7YP2WZ;T0LPhO07@C800i@E<0JHB606EkN@1NLg80E6]^
024lC017H6T083A<008C>`049C402000o`08ooooo`10042`2P174@L0SH>705mWJ00M6Ql0SHVA01H8
2029Gd80A@D407d32P2J0`/0Y08=0:P33@2=0PL0O`4708P22P2R2Q<0X@470:d22P2d0``0]P890;P4
2@2d10X0Z`<80:d32`2e10X0]08;0;X63`2m1Pl0`0T@0<093`2n20l0_@P@0;/9402k2a80^0XA0;/:
5@2n2a@0_``F0;d;502m2a<0a@lB0<lB5@3C41H0eQ4F0=XC5@3K51H0fQ8G0=P@5@3E3Q00dP/@0<d9
4P3<2A@0c@XC0<d:4@361Ph0``L@0;l73@2m1Pd0]@@=0:`32`2W0@P0Z@890:L12@80Y@4701@0X`48
0:012@2P0PP0X0480:@12P2S0@L0X@480:812@2W0@X0/@H@0:T22`2Q0@T0VP4708/11`1k0@H0L@42
06l20`1S0@80F`8104m?2@<00?l02?ooool5003o001;079GBP1^JGL02`/U04U4F@1FBed0LUaW06UG
K00k=ed06QiD03TaH@22Ffd0RUmX09UUJ`2LIFT0W6MY0:=cL02ZPgd0/Hn40;>DQP2bVHX0]Yn@0;RR
T`2kYYP0]ZNK0;^`YP2o]:d0`;Rb0<Bl^035_[/0a/:n0<S3a036a<@0`l700<;1`@36a/@0`/710<G3
aP2l_/00^kjm0;o1`@2j^[d0];Jk08nS^`1HHH`0Uc]K0:/A9P2h3Ah0/`lP0:DM<02jI7@0XX^U04M3
L@1k7CP0WPHH0:@5502C2Qd0bjji0<GBg`34d^00aM?P0:jmcP2Q]<<0V:Vd086>UP1iQXX0LGb006Yi
NP1XMgH0>TQL02<iFP023d000@Ll0046=@0133<09fXd00T00?l02oooool000[ooooo05P05^d605hI
3P1:0`80@@8202l20P0P0@406P4102L10@0n0P@0>@P:05TS:00e1@H0?P850602101Y0@<0K`840781
0`1g0@<0O`4408H10`2<0PD0T`@909D3202I1@T0W@L90:<8302]2Pl0/P/@0;D=4@2S7Qh0`Y>@0<o9
b@39/KL0LD]B034T8`1eO7L0bm7?0=oRi03Jg^40fn3S0>7RiP3Ngn<0g>3S0=kQi03ShnH0h=7H0=:Z
]031N840Z45;08HQ:01V5AT0BPlC034=4`0]20/0G@lA08PC5P2A41@0RRDZ0:MlP038alX0b];D0<_B
e03>d=80Pe1C080730230`L0PP4508021P210@P0P08807`11@1j0@H0NP4407l220211@/0O`<90987
302D0`P0T@<:08X2201o0@@0K0<507i:B`24Oh40BTa>065GEP0OS@L00?l02Oooool4003o001<02CD
1`20EDH0GAPG06@U9@1LCU40DdmD051=D@1DDeD0FEYM069RI@1`K6`0N7Aa081gM@25Lg<0RWEb091j
M@2BPWX0UHMm09f=P02QTH80Y9N70:FHQ`2TWXX0[:FF0:ZTV@2[Z9l0/:^U0:VYXP2JW9<0UYR?09NI
U@2Z[:L0Zjj[0;6g]@2^][H0];Nj0;>i^`2]];L0ZKFe0:^c]P2/];L0ZkBf0;6TZ@2TADl0[PhF0;@:
402`1`h0[@L=0:D83P2C9S40ET1U01LeK`16IXX0MXF@085MIP264ah0VP@<09`31`2K0PT0U0<;07L_
@P0L>VT0S[KB0::JZP1b3AT0L1/Y045AJ`1_RHd0I7Qg05mdL`1HKVh07cM<00PKA0013c`00@hi00HI
=`P00?l02?ooool0@`0c^0L0B@l707i`L@1OIFH0514C07IcN00M40h0ICdZ04D31@1j10/0T@890:02
302W0`d0R0050801201o0@P0U`L@09D11P2X0`X0[@8:0;82302g1@`0[`<909X10`2O0PD0^@H:0;L4
2@2i1@h0_`T>0<P:4@3:3180a`XA0<D<4P303A00^`X?0;P9402h1a80_PTC0<4:5@3131H0aPhF0<X?
4`3;3Q@0d10H0=HB5`3K51D0eQ4B0=TB5P3F3Q80ePh@0=P@4`3A2a80c0P@0=0<4`3<2A40a0H=0;`4
302h0`X0]`<;0;43302X0@X0Z08<0:H1202W0@L0Y@470:@11`2Q0@L00P2P0@P04@2N0PL0XP8:0:40
202N0@T0WP4:0:012@2Z0`d0Z08;0:822P2H0@T0RP4807X11@1V0000J`4206L10P1L0@40BTP400<0
0?l02?ooool5003o001;082:GP1VI7@05Q</04e1DP1MDf@0KUQT05i=I@0Z<F001Pm;05Q8JP1]Ced0
ID]F09=XK@2MIfX0W6QY0:EdM02/PWl0/8n30;FGQ`2dVHL0]Yf=0;JQT@2hYYP0]jRM0;^_Z02o]:h0
`kRe0<>j]`35_[X0bLC10<O4a033a<<0`/710<;2`P33`l@0`L;20<;2``2n_l40_Kjn0;Zk_02k^[h0
/KNo04AUT`2EEg/0]@hP0;l84P2n1a00_0H@0;P:5P2Y3Ql0WRU0074cE`2QCV@0VPPG0:L23P2O1A40
/G1l0<[Bg`36d^80^l[M06MnUP27VjX0U:Ja08ZHX01jQh`0LGf006UhN01WN7H0AEAW004;@0012440
0@Pm004<=00T>4h0<UXj00T00?l02oooool000[ooooo05P0:]T:06X_7P111080?`<202d10P0Q0P80
704102X10P0j0`<0;04204D310110`@0;04205/21P1U0@@0I`4206h10@1h0@<0OP8208D10P2;0P@0
T@<809P52@2F10P0W@H90:@8302]2@h0/`/?0;L<3`2Y6ad0fiFF0;n1Q`1_:bl0IeUH0<C7a03NhN40
gn?U0=cRi03Jgn80fmoR0=oPi03KgN00g]cP0>7<d`3>QY40^Se:0:HS;01k51X0>`X=02dU8@14BD<0
GFIP07f6P@2CThd0ZY><0:Y]J`2@6A`0S`/@07`Q8`2_Vi/0c=?E0<[Ce03>cm40O4=708872P261@H0
Q@@808<420200PP0OP8807X11P1i0PD0NP8607h21P1i1@T0K@84098>4P2G10/0UP<:08`21`210@L0
J`<707Y6A`1mMWP0DU1D05Q7A@0QS0H00?l02Oooool4003o001=02WH201lDc`0Gcdj06M@CP1LE5L0
BdQ<04Y9B`1EDeD0EUIK05eMH@1YJ6P0NG=c07meM025MG80RgQb091mN@2BP7T0UhEm09f<OP2PTH80
XiJ60:JIR@2VWH/0[ZFH0:bTV`2ZYIh0ZjNR0:>RV`2;SH80S8n208f>Q@2PXY/0YJ^Y0:Zd/@2Z/K80
[kBf0;:g^02/];L0Z;6c0:jc]`2`];L0]:fa0:QFG`2[3aL0/PTA0;083`2c2@l0Ya0D08HiCP0]=V`0
:4j206b;WP24U9P0QW1f080B7P2C0``0U`8809X32@2D0`/0Q1<O03/fH@1_W;d0]l_J08EFIP1m1a80
Fb<h02i5H01WOWl0HWUd05edL@1JKV`07c9:008>@0013Sh00a@g0319EP08f0P01`00o`08ooooo`0Q
01g;0@1;4@X0OVe^05MHF00U7al0HV5S02lP600c4@X0BP8808@43P2>0@T0WP8<0:43302;0@L0P`47
07D21P1e10P0QP450:L32`2Y0PP0X`050:/2202d1@/0/08:0;<52`2m1@`0_@H=0;P32P3120d0d@lC
0=@@5@3=3A<0``/A0080_@T@03<0_P/A0;/<4P2o2Q80a@dE0<L@5P394AD0c14D0<XB5@3:4AD0cA<G
0=8E5@3E5aH0eQLG0=LE5P3J51H0fa4E0=H=4`3=1a00b`PB0<T74@331@l0^`<<0;T22`2g0`d0/@<<
0:/22P2W0@T0Y`890:H21`2T0@P0XP480:411P2R0@P0WP4909H11P2L0@D0X@8909h1202L0@L0WP48
0:H3302Y10h0X08:09<12@2;0@T0O@8506l20P1^0@80JP8106010P1D9`800`00o`08ooooo`D00?l0
04/0OJUR04e=H`0S8SP0@C]=02X_E01NDVT0DT=S00P@C00F6U00LUac07MJI@1PBeH0OUeR09QVJ@2M
JV`0YGAf0:V2O`2]Rh40/IB40;6GQ02eW8`0]j6C0;VVV@2iYid0_k6/0;jd/P34^KL0`[Ve0<>l^036
`[l0`L700<;0`P32`<40`L300<73``30`L80`<;30;k0`P2l_Kl0^Kbn0;Vm_`2T//80@5^A0:@]A`30
1a@0`@LB0;d54@2d3A@0[TeB08=9F020=d/0Sale09`M;`2O21H0Y@<>0:423@2C82h0e<[E0<KDh02^
_m00TZVl09Z]^@28VJ<0PY2H07J1Q`1/O7h0K7al06QgN@1;FV/00@Xo004:@`086400<4EC055VJ010
BDL02@00o`0;ooooo`002_ooool0F00Yf@P0GRD@03`00@0n0`<0;P4202D10@0T0@40;`8203T30`0S
0@40?P@603D3100S0@80EP8505d10P1P0@<0JP4207@10P1i0@80P04208L2102?0`P0U08809D3202H
1PX0XPP;0:l:3`2h3A00_a0B0<0F6033<S<0N1/L07IWH`3Ef]P0hNGV0>CXj@3Oi>H0f]oR0=_OhP3L
gn80g]cQ0=2`]`2oKWL0_CM00;lN901k41<0>10B05E@C@2LXil0a<g90<kFe03Df=P0dmOH0<G0a@2D
Ifl0RR8Y09<73P2@20d0OAXJ09AoO@3=eMD0cMCF0;^c]P1e:bh0QPH:08D420230@H0PP<807h2201h
0`P0N@D;07T31`200`T0Q0<907d93@1d1`L0Xa8E09/93`2J1@/0T08908811`1^10P0NdA608AmO`15
@T40E48l026>1P00o`09ooooo`@00?l004d03?L307mF>@1TG5T0HUmN05YEF01;ADP0AdE805ABE`1@
E5L0FEeN06IVI`1gLW@0OWAe08IhM`2:NG@0Sgeg09>0N@2HQgd0W8ao09b>O`2QTh<0XYF50:JNSP2Y
Y9P0ZjNN0:RTW@2YYil0XjFM08^>PP29S7h0Rhn1096GS@2QZZH0Y[6a0:V`/`2_/kP0/[Nk0:V^/@2T
[Jl0ZZnc0;>_]@2^MX00YQ@M0;09402d2A40[`P>0:@D7@1h@f@06cMd04Q/TP20V:00QYRH08RATP1k
=Ch0SP@>08l42`253QL0NRTh06@eC01<?V@0:Teo0;;>h@2NS9`0OADS07L>6@0b9dP0EgN:06j4QP1T
N7D0GgMb05Y`L00]@5<00A4l00`R@`0dD5`0DVYY00g>3P07003o00Sooooo05H07LX004P;0`1gHV<0
DU1@04Ho@@19B4X0<24I01X1001;0PL0Q`8>09L2302M0P/0U`4;09412P2@0@X0S0L@0:@_=`2I1@`0
Z@8:0:h3202^0`L0[`<80;H52P2i10`0_0@;0;l63@301Pd0a0L>0=0>4`3@3Q40d0dB0=4@50323Q@0
^a@H0;HM6P2c:BD0/blY0;L[9`2j7Qd0`aXK0<LD5@2o4QP0P`/>0;aTH03?OWX0dX9m0=V7PP3KQX00
g85o0=]RH`385a`0e@dC0=D=5@3?2A80cPXA0<P84@2n10/0^P@=0;81302^0`/0ZP8<0:L12@2U0@T0
Y0090:@1202Q0@H0X@490:412`2M0@X0VP8809T11`2N0PX0W`4:09d12P2L0@/0W04:09`43@2F0``0
P04607d11`1g0PD0M@430741101/0@<0H`8205l90P<00?l02?ooool5003o001<076ZC@0m>Tl0=c54
02`X@`022T@0?CYN04@lG@032dL0BD5V06aGJ01UE640D4=?07eIG`2GHfL0XFm_0:=eM@2WOg/0[HV1
0;6DQ`2dV8P0]If;0;FPTP2eXiL0^jbR0;naZ`2m];80_KFc0;ji]@32_;T0a;nn0<?0_`30_kh0_/2o
0;k0``2k`<00_L740;k2a02n`/<0]kfo0;Bj_P2g_;l0YkG403MDSP2S=U40`0LE0;h53P2j0`h0[QhU
0;FKW@2QZZl0QHfN05aKN01S?e`0QRLk09D4402J0P/0U0DC0;^=V`39e>00MH^V07:?X@28WZT0V:J^
08ZEW01fPhH0Kgam06]iN`1VMgL0GFag00<@?@0P<E00DfM_05AWIP1=IF@0>da>017>30P00?l02ooo
ool000[ooooo01L0;=/;054D10110@00@P8302h10P0W0@408`0002l10P0h0`<06`4102L41P0M0@80
:08305/41P1F0040G04206X10`1d0@<0N04207h10`250@@0S`4809H42`0209L52P0o0:08302[2@h0
]`d?0;/=3`2l51H0R1DE05<f<`3;d/l0gnOW0>;Wi`3Tj>X0gN;T0=SNh@3Jg^80h]oS0=>W[`2`=Sl0
_aTO0<LG6`254Q@0?bhZ0:6WX@3?e=<0f]oO0=CKgP3Cf]`0e=SK0=7CeP2EJG00Q1TP09<9402C0``0
SPT>068B4`1hL6d0b]?B0<_Be02LR8T0M1PK08H42P220`P0P04708022@1m0@T0I@4305`00@1h1@X0
Q08808L42P1l10P0J`<409P@4`2710H0TPD;094220220@D0L@@807m5A@20MgP0CD]804Xj=00QS`H0
0?l000Wooooo1@00o`00C01YNcD0I5aK06ARH@1IEED0BTA404M5A`1DDUD0DU9E05UIFP1VI6@0M6i^
07abLP23MGH0RGId095mM`2DPW`0UHEm09R:O02ISW`0UX]i09R=N`2LUX<0XYb=0::PU@2XYYh0ZZVR
0:^YY@2FUXl0RHf008^>PP2=TXT0VjBO0:Na/02[/k<0/;Jg0:Zb]P2V[k80Yjnc0;B]/P2fQXh0XB<]
0;@<4@2a2A40/@X@0:0K8`1VAF/06Sil06F8Y@2=X:<0TJ2O08VIV02;S8/0NQTR09033@1m7b/0>C5K
01XcK`0M?gP0NIJk09ZWa02FLXD0OaXX07l:4`1I;dT08SaT06n;T`1RN7L0H7Id061eL`1JKfh0>e=J
02I1C`1:J6/0CfUW04iWI`0NXR87003o00Sooooo04P07//004/;0@1eGel0CDY805UBE@0c<C<0;A`H
01T0001900<0P`4:09D22`2I0@d0TP4:09012P2A0@X0TP4<09/53`2T0PP0ZP<80;442P2_0`L0/P@;
0;H32P2f0@X0^@<:0;d42P331`h0aPH>0=4>4@3@2Pd0d0dA0<LC5@2K6a/0Tchh0<fDR`3/b;l0j/W0
0>Jn^03FVY@0`6UR0;@f<@2c7Qh0A@8409NAU03Yi><0j^KU0>OSh`3Wh^40j^7R0?G<cP2k<3D0d0/A
0=D=4P3?2Pl0cP/@0<D63@2k10X0]P<<0;03302/0`X0Y`4:0:L1202V0@T0XP490:411`2Q0@P0XP89
0:012`2O0@X0V`4709T01`2J00H209`1200<09`12@2M0P/0UP<>08P22P1k0PH0O@8806`10`1c0@@0
K`4306/1101R0P80HPX30`00o`08ooooo`D00?l004`0Gle203L_?`1:@5405aHh008:A00h>5d08Am8
00dCAP1eH7P0KUQW04a3D`1JA540QE=K09]TJP2QKW40Y7Eg0:QmOP2/Qh40/Y:50;6FQ@2dVX/0/ij?
0;ZWW@31/ZT0_[6[0;nd/P31]k@0_kNb0;fh]P33`;l0`<2n0;nn_@2l_Kd0^K^n0;Zo_`2m`/D0_<32
0;g1`P2j_;l0^Kc00;Fg^`2a^l<0?V:F08eGN`2i2aT0`@D@0;`4402Z4Q`0]iFE09nVYP2NYj/0VZRd
0:6bc@12AW80Qb0g09/33P2M0`l0VCU:0=?@g@2?XKD0RYn^08jLYP27T9/0OHN=07J1Q@1aOWl0KGam
06QjN01UMWH0AUYQ05U/L01NLW40CfE^01T]B@0Q=TL09J@P2000o`0;ooooo`002_ooool0F00Yf0X0
BP/104010@100P80<08202H10@0T0@40;04103H20P0H0P801`410104100g0P@0FP4305D0001I0@40
J`8207H10`1j0@<0O`4208L10`2>0`P0TP@;09D52`2@1@X0UPL<0:H:3P2b2`l0^0lB08<@4P1>;2/0
[k6^0=kRh`3QiNP0hNGW0>?Uj03Qh^H0gn3T0=o@eP3HVJ80_cHm0<<F6`2o4QD0VA@F05`l>@2i`;T0
e]gI0=[Og`3Hg^00e=_M0=?If`3CemX0]YjS08TR:02E2`l0T`H<09862`1a30l0=QPG09nSX@3<dM80
^k:e07<i?01l3140P@8;07d12@1n0PP0P@<80882201o10X0KP<807841P2810X0R0<808H62P1/20X0
I0X=06d41`2=1@/0T@<808H11`1f10P0PTI808j7R019AdH0BCDb026=1@00o`09ooooo`D00?l004`0
Ihhk06YPG`1YIV40FUAD04]0@`1<@TD0EDi@055?D01GEUP0HUmN075[J`1iL700Q7Mh091nO`2BOgX0
TX5k09:0N@2@Og<0THAe0923LP2DQg<0ThQc09R@O`2GThP0Y:6J0:RVXP2XYjD0ZZRT09nPV`2HW9D0
VYjH0:6XY@2S/Jl0ZkJe0:N_/P2S[Zl0WZZY0:JY[@2^N8<0VB<]0;8A602`2@l0Z`T>09`L901LAG00
7DF407RE[@2FXJL0TYnQ092OX027UiL0RY2@07hY<02=1@d0J2]102`oK02T//`0OGZC09AXO@29:Sh0
R@/F07l?6@1Q=U404bMF06J4U`1eRXh0IGQi061fL`1OMW@0Eg5/05E/JP1?J6H0D6aY04=QI@0B;D80
8W`b1`00o`08ooooo`1F01k;001<2P40LE]M04Q6AP1nNGX07AXL02`I500V0@80E@8607X11@2A0PX0
U08<08h12@2@0P/0S`4=09<1302K0`/0X@460:L21`2Y0PT0X`050;042P2e0`X0]`8;0;`530321Pd0
`@L=0<<83@3>3@h0e10B0<<D5`2?7b00_Y^E0>GKe03Vh]l0jNGV0>KQhP3Vh^80i^7O0>GKf03R`[l0
b8J205XZ;01XJFh0hnGW0>KUi`3Wi^P0jNW[0>SVj03`gn40`UEK0=PD6@3D3A00c`XA0<D63P2m10/0
^`D=0;H3302a0`/0[08:0:X32`2W0PT0Y`490:81202Q0@L0WP4909l12@2Q0P/0X@4;09/11`2I0@H0
VP4709/11P2L0@T0W04709/1202D0`d0PP8808821`250PT0N@8807831`1/0@@0JP8506410P1X40T3
003o00Sooooo1@00o`00C01:fRh0CCe005=8F@0:2bh00P`n034gH@052C/0>CEJ081OKP2:H6l0M4]K
081?F`2=E5d0W6E[0:1/L@2RLW<0YWel0:b8P02`T840/YF80;:GRP2fWi@0_ZbS0;n_Z02n/Zd0_KB`
0;bb[P2n][80^kVf0;bk^02m^k`0^KVk0;Zj^`2f^KT0^Kbm0;Zo`@2k_l80^Kk00;>h^`2f^[`0]KRj
0;>h^P20U[D0FF2A0:HL;@2n1Pl0^`8>0;464@2aIV/0ZJb]0;S0b02KY;80SJ:h05M^U`1Y?V<0S@DA
09T23@2=2AP0_j:a06QoV02?X[40UjB]08>@V01lRHh0Lh21071oO`1^OX00J7Uh06EfL`1OLVl0Ffmc
03U@J00:6dd00@a001DV@@0`P2h8003o00_ooooo000:ooooo`1H02KD20151`40?@4103X20`0Y0@80
8`4202/20@0b0@80>@4202820P0l<C40FCe104l31`1F0@80E@4105h20`1/0@80M`8407`10`1o0P80
QP8208X21P290@H0SP8808l32@2E1P`0Y0T>0:/;3`284A@0Je9@0<K9b@3IgMh0g>3S0=kSiP3Mhn@0
h>GT0=gHg@37SIP0_T5:0<`R9`3E5aX0aQ@H09/H6@1bB4D0blk<0=[Og`3Igml0f=kO0=OLg`3DfM`0
eMWL0<c5b02==S/0W0`A09462@2:1@X0K`X?03XT8P2DVID0bLg=0<W8c@26E5/0N@dB08042P1n0PT0
O@8:07d12P1o0PP0PP8908<320200PT0OP<708D420260PT0QP<9094T9`20?Ch0I@D909@63@2@0PL0
Q@4707X42P27BD/0QGam05=<CP10;BX07h/4003o00Wooooo1@00o`00C01XRRh0KF5N06aXIP1QFU/0
Dce104TV:@1FB4`0De5E05EDEP1SGel0M6]]07e`LP2;Ng`0S7Uh08eiM`2BO7P0SGA^08egK02:NVX0
TXE`09N9M02FRWH0THYg09>?P02DTXP0XjBJ0:RYX`2/[:P0Z:^Y09jTX02PYJ80X:NU0:6ZZP2Z/k@0
YK:`0:F`[`2S[Zd0ZIZN09PX<P2/41H0[`/@0:X;4@2H6Al0Fd=X01e2O@21T:L0WWn909]OJP2LG6P0
VG]o092DU@2;UiL0Sf]b080>5`2841l0Q2Pi08HQ;`2431`0R`PC08T?5`1h;C`0@3=M00hWH01LO9P0
PYJL07f?T`1WNgT0HgId065gM@1GLF`0DfeW04iWJ00]BET01Q]0004C?00RDCh7003o00Sooooo00X0
7l`004d:001aFUX0?cXk092;SP0B3@d08`l=02l10`1L0PH0M`450P280@P0=@290@T0S04:0901302C
0P`0U`4:09/11P2U0`T0Y`880:@21`2]0`T0]P@<0;H2302l1@`0``P>0<883P2o1`/0b0X?0<4A5`1X
20T0XHV80>_Zj@3Qh^<0iNCV0>?Ri03Ui>H0hnCT0>?Rh`3Sh^80i>GV0>OWi`3NgM`0[k>b0>7Si03U
i>H0j^_/0>WZj`3XjNX0jNKX0=:AV03>5al0fQ0G0=4;4@331@/0_`D=0;d53P2i10d0]@8:0;822`2Z
0PT0Y`490:L12P2T0@P0X`480080X@4;01<0X`8;0:023@2G0PP0U`4609X1202N0@X0W@8909/1202G
0PP0V0<<08X2202:0PT0Q@8608021P1`0@D0IP4406H2101M0P80G@T300<00?l02?ooool5003o000m
03;U701kGeH0DTIF00H79`0c=eH062=B0087?@1DB640PEi]08AKJ@1oCU`0PD]H08mIH`2HHVL0W6UY
0:EcL`2UNGT0YhAl0:j>P@2_TH@0[iJ80;BOT@2kZIl0_jjX0;Z^Z`2k/:h0_;6_0;^d/@2i];@0^kFd
0;^i^P2i^[/0^;Ri0;Ni^@2i_Kh0^Kfo0;bo``2k_L80]kZm0;Vl_@2c]kX0/kZl0:fh`@0fE8/0U4i]
0;L94P2k0`l0]`<?0:T[<@2aXjD0UJ6X0;_8d@1eRih0V;C@03Y1L@2452T0U@4<09L43`2A>DH0T9VY
08FGX@0208NEW00=07J4QP1`Ogl0Kgio079oOP1[MgH0IgQi05=XM@0K;eP00@a9004:C@0234H06Ra;
031D=@08003o00_ooooo000:ooooo`1202?A1@141@00?04203410@0V00408@4002T10@0c0@40?041
03/41P0l5ah0AA<J05@21@1D0P<0D04205/30`1X0P@0M@4507X10`1n0080Q04208L1102;0@D0SP46
09D42`2H0PL0X`T<09P=4@1761T0^Kfl0=SJg03Ff]d0f=gP0=cQi03Kgn80gmoS0<FAW02f9S40dAXP
0=PI6P3F5QL0/aLI05`F5`2l]K@0f]gP0=WLh03Gfmh0emcO0=OKg@3FfMd0e]SM0;6;T`2D4AT0W0H=
08l72`1f3A009PP707j6P03Ae=@0cM3C0:^IW@1g6R00QPL>08<32P1o0@P0OP490P1o0PX050220@P0
P04807l220200PP0Q0<908P32@290`X0S0/@0:ho@@2H41D0W`H<09011P250@D0O0D:07dl@02ERhh0
E4m@03DS7`0NRP800?l02Oooool5003o001<06n68P1cHeh0KFUZ06A?DP1E8RD0BAdN05I6C01GEET0
DU9E065NH01eJVh0P7Ed08moOP2@O7T0SWUg08igL`29L6T0RFmU08aiJ@2>OVX0W8ae09R;MP2HTh40
TY22092AQ02JVI40Z:RS0:b/ZP2ZZZT0ZZf]0:B[ZP2RZZd0XJZ]0:Vc/`2X]K80WJZX0:J/[P2ZL7H0
Za8J0;<;4@2c2a00Y18I079<K00Y@h40Q65o09@Y=P2D3AL0TPdH090@6`2?41d0U5]S08FDU`2<UiT0
Q6ib07<c?01f7bl0O24`07D[>`1M=4`0@3QN02X`HP11>F@0ITmY08E^N`2;Q8X0LH6206QlO01TNGL0
HGId05Q_K`15HFX04b]9004@?P023d400A0l024c@`L00?l02?ooool0EP0Pc040B`X006]DDP1<AdT0
PWb101P>3`0L10@0<`0106021P1d0@D0O@4807/02@220@/0RP8:08/22@2?0@X0V@8;09/21P2Q0@P0
X04609/00`2X0PL0/`<=0;D2302l1P`0``P>0<883@362Pl0aPX@0:4;4@0f3Ph0eM7@0>OWj03Xj>P0
inSY0>7RhP3Oh>80i>?T0=c:d`37Z[T0eLCD0>7QjP3Ri^T0in[[0=oRhP3UinL0i^SX0>CXj03Uj>X0
inOY0>6l`P2l6b<0ea4I0=D>5@361`h0`@H@0;`23@2l0`h0]P4:0;D3302]0@X0YP490:D12P2V0@`0
YP4;0:@12`2S0@X0XP4;09l12@2G0PP0V08809X0202O00T0W`4:09d12@2K0P/0V0@:0:05302M10`0
TP<;08X2201g0PL0I08305/10P1F0P<0E@X40`00o`08ooooo`D00?l004`06_8<0:N2J`1;?dX06QP/
044jD@063d@0211305A8HP1nGFd0Qee/089CGP22CUP0SEMQ09ESIP2JJF`0XFia0:EeM`2WPGX0[Xb0
0;2@Q02aV8T0]9n@0;bZW@2k[:D0]jfY0;N^Z`2e[:T0^k>_0;Rc/02i]K@0^;Nh0;Vi^@2g^;T0^;bl
0;Zk_P2k_[h0`<;40;bo`P2i^kl0]kVm0;Nk_`2d^[/0/[Vl07::Z`1NG8d0Xa@V0;T4402h0`d0Z`XC
0;^6R`2[[kP0V:Rg09naa015JHl0BVFD06deEP2H1A<0V@8;08d:4`2<MGl0UJVc096PY`1mRY40M8:5
07>3PP1^Ng`0JWYk06IjP00kE6l02AU@008;CP012Th00Q5=020cF@1@Hf`0=3Tj2000o`0;ooooo`00
2_ooool0F00Rd0D0A`H103/10@0_0@80:P8202D10@0[0@40>04204020P160P@0B0P;04L31@1F0@@0
D`8404T20`1J61T0HADF06H2101g0P@0O@8308<20P260@80R@4308`1102B0PL0W0L:09d>3`1R30d0
NW9^0=OIfP3Ifmh0f=[M0=OLg`3IgN00fMCI0<NHX@2i<C/0baHK0=PH703J6AX0dQTI09L/:`2YTY40
fM[J0=_Mg`3Hg=h0e]WM0=SDfP3=]Kd0/H><0:IUL02N=3d0X``E090;4P1P2Pd0;@d=06=XI@33b/T0
dM?F0;je_@1n?4<0Q0TA08P32P260`/0O`8907l12@1n0@P0OP8808422@220@P0O`8808021`220`P0
Q@@:08T22@2I2@h0YPdA0:T<3`2R1`/0U0<808P21P1k1@P0Rda>08=gN`1NEUP0:ALB01f80P00o`09
ooooo`D00?l004d0Bk8M07a/J01aI6D0HBd_05LS901=>ST0DDM805aBF@1KEEX0I5iS07E[K@23NGT0
Rgem091lNP2@NWT0Qfm^089/IP26KF00RGAP08alI@2DQF/0UhU_09VCPP2CU8P0T9:909:BR`2@Thl0
YJVW0:^/[@2X[Zl0[;Be0:J/[`2QZZ`0Y:n^0:Ze/P2W/Zl0/Zf`0:<lB02e3A@0]PdC0:d=4`25>E@0
?dQo080gFP2N3Qh0U18K07PcB01=@FH0ETUX08DJ9`259S<0DfIl08bTZP22TiX0KH6?02LmJ00cCW/0
?E>003TmJ@1P=5@0OAda08D85`281100Q0D@07P>5`1oCe80MG]l06IhN01OM7P0=4]S00LIB@013D<0
0Pho004A?@0E;dX0@UML00KU1@06003o00Sooooo03l08<d104X:001aFeT0C4I505eGF`0L41006@42
0483101U0`D0LP8407H11`1i0@X0O`8;08@22`2100H0Q@4809T22`2M0PT0Y0890:/32`2T0@L0Z@88
0;<4302b10X0]PD:0;l73@2k1@X0_`L?0<<84@2>2a00@bl`0=_If`3Xj>/0inWZ0>OWj@3Ui>D0iNCV
0>?DfP2aC5X0/B4a0:/V>@2FBU`0Vh:@0<k<eP3RiNP0hnGU0>CVj03UinT0inSZ0>GUi`3WdmP0]Rli
0=4A603>3A@0a@L?0<<63P301@/0^P<:0;P22`2f0`/0/@8;0:X12@2W0PT00P2U0@X20:<12`0D0:41
2P2K0PT0P`8608X22P2I0@X0W@490:01302S0@`0X08<08l21P2X2100X`H?07h11@270`T0K0420682
101I0@<0F@8305X;1P0Ce042003o00Sooooo1P00o`007P2WN5@0C3a5034Z>`0d;DD010/o03<dG016
@5/0OV1_08IMJP25F680PU5I08eIHP2FI6H0Vf]]09eZL@2TM7H0Ygmk0:b:P@2^T880/IN90;>LSP2i
YIX0^JbS0;R^Z`2dZJP0]JfZ0;Na[P2g/k40^KFe0;Rf^080^KVk02`0^k^n0;^n`@2j_;h0_/320<31
a02n`<<0_;o10;Jl_P2c^K`0/KNj0:Ne``0cCXP0V4EP0;D64`2h0`d0/P@>0:Dh@P37`<P0TJ:d0:o6
e`1mVJ`0V[7>03lhJ@242al0V`8?09H33`2=ADh0WJF/09BRZ024Si@0NXV<06j0P@1^P880GgAo02@k
I0023e<00P]B008:C0044dT0?EA_061eN`1LKg40=T56013=2PL00?l02oooool000[ooooo05P08]05
04/60P0n0P80;P4102H10@0W0@40;P4203P20P110P80@04204810P180P80D0<404H20P1Z7200Nb0X
07/C6@1J0P@0H`<507T20`230@<0P`4108H10P2;0@D0TP8809<9401Q2Pd0GTa80<G:a`3HfM/0emSL
0=KHf`3EfM`0b[6h0:QFG`2]8RT0`QDF0<lE5@3D5AL0eQHH0<H];@3>YjH0f=OH0=_Nh@3Jg^40eloD
0<6JY02_E640ZB0[09l>5@2M3AD0UPhE06T:3`0[3Pl0?d<o08RBS039c/d0c<gA0;2KX`20>480Q0TA
08L52P2710T0R0@908811P220PH0P0<707h21`200PT0P0<807/11@1n0`L0P@8708<32P270@L0W0P=
0:`:3`2]2Q00XPH=09H220280@H0N@@80853A02@PhD0G55D01d;1`0KQ`800?l02Oooool5003o001=
05:k8`1nKfP0IdE406<b<01?>3X0BCi00595BP1MDUL0H5IN06UNI01hKG00QWYm08emOP2?OG`0S7Qf
089[JP1nIU`0PV]M08UeI@2:NfP0U8Qd09Z=N@2JTh<0Ti>709JFR`2@ShH0RXZ1092BS02UYj<0YJ^Z
0:^e]P2[/kH0Z;6b0:Vb/`2[/kD0Xjf_0;>NY@2M6bL0]P/D0;<<4`2N:CL0H5Al08hnFP2S41X0S2Pl
04M0LP0H?7P0BfZA089ZO@2941`0Q2Li0313JP1cT9X0Zl3907>@X020W;40Q9FY08aVM`1o5bL0SP@@
08l13@2?0@/0S04908P22@230PT0M`L?07YHG01NLGX08CUJ008BB@014D/00Pm4008A?P0O?e<0AVMW
04aRHP0<c0/01P00o`08ooooo`1G01o=0@152`00LeeN05iJG@0W8bD06P`;02420P160@80I04206d1
101a0@L0L`4707411P210P/0P`4608P11`2M10h0W`4:0:812@2X0PP0Y`870:T1202_0P/0]0D=0;D4
2`2i1P/0_@L>0<483`352A<0UP`C03TS9@3Kf=`0j>SZ0>KWj@3Xj>X0j>OY0>WWjP3G^kl0^R0X0=4@
5@3M5aT0daPM0;4E801k7c00QGb90=SLg`3Si^L0i>KX0>CWj03Ti^T0in;T0;QLI0324AP0b@`B0<H8
40361Ph0``L=0;X32`2g0`X0]@<:0;83302^0P/0ZP4:0:P22P2V0PP0Y@480:<12P2Q0@`0W04908T3
1`1j0PD0UP8909d21P2R0P`0Y@4;0:@22`2K0`X0X0@=09d630240`L0R08907X21P1^0P@0HP8305<1
0P1E1`<06<@100800?l02?ooool6003o001<04fd7P1=>cX0AC]702@P?00J7DH0DDaY03XgE`1jGVd0
QEm]08EFI028EEl0SeYS09APJ02HIFT0WVU_0:AcM`2VO7/0[XV00:f@P@2^UHD0/iZ;0;JQV@2iZJ80
]ZRW0;:YYP2_ZjH0[jbZ0:BVY02k_K/0cm7C0<g@e02j_;l0]KRk0;Vn`02j`<40_<;30;g0a02m`L<0
^ko10;Rk_`2d]k`0]KRl0;2g_@1NNJ@0J5Z90:<<7@2g0`h0/`8>0:@<602UOh/0VZZl02A;L@2D]/d0
bMWX041@O@1c;T`0T@<A09H230295Al0WI6D086?T`25TI80LH2106aoP@1ILH804bYO004?F@023540
0Pe<004;B00_AF80J7f106AiN@1LLG@0=dI;01bh5PL00?l02oooool000[ooooo01H08<l304X60@10
0@80<`4202`10@0^0@40;P4203D10P100@80@@8203d00@140P80@`8205L2101_0PH0NP8908@3201X
10L0B`0107831@200@80Q0420P270@<0;02=1@L0G`/>05E5@@2k_;T0e=CH0=CFf@3Fem`0fMKK0<FQ
Z02V;cP0]1DL0;TA5`2l41<0`a0A0<hC5@3@51H0cE]M0=C;c03LgMh0g=oQ0=32bP2WD5/0ZA`V0:lC
702N4AP0K`/A04L82`0V2P/0@D=209FQX031b//0dmWK0<G4b`2=GfH0Ob0X08<=502720l0Q@<:08P3
2@280`P0Q0<708421`1o0@P0O0870P1o0PT04P1m0PL0OP8808<320240PP0RP<809l93@2Z2100Z`T?
0:H63@2K10/0R04707T42@29BD`0TH:304m3@`0K1`D06HD1003o00Wooooo1@00o`00C@0ZgA40RF=J
06Le<`1WCdd0Bc/k04Tk@01AA4/0FU1G065GG`1WGV80NG1c08=iO@2:O7l0RgYl08afM@1nHf00OV=M
08A/H@27LV@0SWa]09N6M02LSWd0VI2209FER@2IV8d0V9R?08nAR02<ShL0U9VD0:Z`[@2/]K@0ZkJg
0:fe^02Y/;<0Z;2d09bUZP2TQXh0XA@M0;<=502W4aP0YeaX09@oE02Y4ah0S3Q@02XnN@0fHI@0P9NW
09EnQ`2<7R/0TPTC06@bE@0[C7d0RZBa08NNZ01WP9D0LX2H07PjBP252180T0<<09822P2A0@/0S08:
08L32P250P/0Q04807l22`1N93D05RYE004ED0014D`01AQ;00PLBP0@:DL0BVa[04eXI@1BJVH04=8A
00H00?l02?ooool0E`0Oc@40APX007QPH@1JEEL040X;01`=300[0@40D`8206T20`1]0@D0M08707D2
201c0@D0P04808801@290@T0UP4;09`12@2Q0@H0Y@450:D1202V0@T0[`8;0;D2302b0`X0Y`460;04
302e0`/0^P@=0:D>5P0Z1@L0b<K;0>SYj`3VinT0j>W[0>WZk03Vi^P0jLoC0;HQ:@3D4QH0gQLK0=D?
4`3B3a@0_aLN03P7402k_<00h^CT0>GUj03TiNL0iNGY0>CSiP34Qhh0]aLO0<T>4`331a00^`0;0;h5
3@301`d0^@<80;H32P2d0@/0/@4=0;41302Y0PT0YP480:<12@2P0@T0X00;09`12@2C0@H0S04509P1
202L0@P0X08;0:802`2P0@X0T04809d63P2N1P`0T`<;08T32@1i0`L0M08706/31@1I0@00E@H201S4
0@02003o00Sooooo1P00o`00800/gQ40DcX`05=5D@0B4C<0?3YF05iCK@0W9Tl0NEm`081LJ@26FVH0
RUYT08iKIP2BH6L0UfMZ09]WK02RLGD0Ygao0:j8P`2aTH@0[i>10;:JR`2fY9X0]JJP0;:WX`2_YJ40
[:JR09fJV02][Z/0`/K90;Zl``3>eMX0al_B0P2i_L00:P2h^kh0`<C60;k3aP2l`LD0^l330;jo``2h
_<00]KVl0:jc]`2MZ[l0=Dj609LeC02e1140]P<>0;44402F?Td0/Kc;07jJ/`28ZK`0b]WT08VK^`18
>6H0P`LJ09@12`2@10l0TUQO09bTZ020Si80HgMm04iZO`0?9V400A9O008BF00I;eX0:T1W00<BAP1E
KWX0JGen05E/N`0W@Ed0=DeJ01j>7PL00?l02oooool000[ooooo05P08<d304X40@0n0@40=04102l1
0@0_0P40;08203410@0m0@40?P4103`00@0n0P80?`4206@31P1b0@D0O04608<21`1X0`L0@@0006l4
20200@80Q@4108L20`2<0`D0Q@P<04/W9@2[ZjL0d]?E0=?Df@3Ee]T0f=OL0=>m``2P=Sh0]1<H0;T@
5@2i3aH0^PhC0<4?4P3941D0cADH0=1_L03He=H0gMkR0=WNg`29N7d0KadT06dA5P1B2@d0:@4200`7
1`0K9240KGUf0;2i]`3Bf=/0d]WN0;o;d`1RHfh0?A8H03`72@0m1@P0E0T>07D83`261@`0R@<:08<2
201o0PP0O`8907h21`1o0PD0P08907`22@200`T0P@8807l1202:10X0X0X<0:P83`2Z2@h0Z0P>09/3
2P290@L0N@@807De=`21LgD0Bcdn01T40`0YB@800?l02Oooool5003o001=027U2`27DSd0Ke1=05mB
DP1:>SP0BcXk0513A@1ICE80GeIK06UOI01oLWP0Q7Mm08IhNP2:NGX0RG=c07aQGP1jHEX0PfaP08Yb
I02<N6X0UhMg09jAP02JThD0UYJ;09RHT02GVI80T9R>096GS`2<Thh0XZ^Y0:Vb]@2/][T0ZkFf0:Vc
]@2X/kD0YK6c0:b7S`2X4a`0/@lD0:h/<031EUh0ZA@L09@kCP0V?7T0CWNP08jHX`2HJgH0SaXW09<9
4`1m<4P07c5X05]nW02O]l00MI2Q09bW^01^=DH0P@D?08`22@2@0@T0SP<:08@:501i9c@0H2i006XX
>01n1A80L@DD02@=>`024e<00AEC01HcFP10GW802R5502A2EP1@Kf`0Af=U03A>E`0QYbP01P00o`08
ooooo`1G023>0P182P00MUeN05]BEP090P805@H603<10P1L0`<0JP8406X11@1e0PP0M@0807L12@1l
0@P0Q08:08h22P2D0@X0WP8;0:<22@2S0@P0X`870:@12@2^0P/0/P4;0;<33@2]10/0^0H<0<473@37
20l0`Q@J04/31@2NUY`0i^OY0>KWj03XjN/0inW[0>GUiP3[f]/0_3Hn0=<B6@3E4QT0dPlF0=@@5P3=
4aT0I0P>0929SP3Ui^P0i^KX0>CUi`3UiNT0i>?V0=B`]@2U8bT0aQ4E0<<73P2o1@h0_@D>0;/43@2l
1@d0^PD<0;H33@2`0Pd0Z@@=0:843@2U0`/0X`890:@2202P0@T0W@8:09P11`2D0@H0VP8909/1202M
0@T0X04:0:022`2G0P/0T`8:0985302A1@`0P08906810`1[0P@0J@4306020P1L1`<06/H200800?l0
2?ooool7003o001;06a<>P1?AE8020/]05Y?H`1KDFd04QA507EOM020FfP0Qe]W08YHHP2=F6@0TUmV
09YWKP2MJFh0XFib0:MkO@2[RH40/8n30;6CQP2cW8l0]:6G0;>UW02`Yj80[JFQ0;2YYP2IUYD0/;:a
0;Vm`02_/kL0b]?F0<;6c02h_<40^Kc10;Vm`@2i`<80^l740;g2aP2m`LD0_;o30;Fi_@2d^[d0/[Jk
0:^c^P1=JYD0LU=j0:T96P2g10h0/`8<09`A8@1YH7d0ZLON0:k6e03:fN80`m?T03A1L01e83X0U04>
09@23P2<9300TX^>07j;T@16GGT01AYN008DI0076e`0>E=a05I_P00?9E006C1K05QbPP1AJgl03b9I
004@C@0S>UX07U0Q00L00?l02oooool000[ooooo04807ld304X50P0j0@40;04103020P0X0@409041
03020P0m0P80>`4003`10@0g0P80@@8406P21@1a0@H0M`4607T2201E0P@0?00006l41`230@@0R083
08X2102=10H0H@/;089kM@3=dM00c]?E0=?Ff03Fe=P0c[Rm0:YDFP2`5AT0^14D0;TA4`2j41@0_0lC
0<4@503641D0bQ@H0<MUIP3GdmD0g>3R0=WNg`1LI6L08AdO02<Q8@0a=380D5QE08>?S@2[][@0`l[;
0=?Ig02mb]80QiVS03Y>EP0E8bH09bd_02lf=`0Y;bh06ADD02T41P1S2A00P@D<08<22@200`P207l2
200D084220210`L0M`8407/11`240PT0P04908L12@2O2@d0Z@T>0:T73P2X20d0VP<708`21`1g10T0
SeEH081aLP0m;c005@<303T<0`00o`09ooooo`H00?l004`0Pe<e07AVI01MDe80CSDc04T]<01DADT0
Eda@065DG01/GFD0OW5h08AhOP26N7/0S7Ul08YeMP1iHEd0NEiD08E[H02=MfP0SWi^09F7M`2GS800
Ui:409JGR@2FVI00QXf80:Nd/`33c<h0Ri:?0:6[Y`2W/K40YkBd0:Ze]P2Z];H0ZKBf0:>`/@2`UiT0
Z1TO0;P>5P3282X0]aDN0:@/>P0o@7D0D6VH09QnR`2C>dH0UA0J08hA7P1^>EH07C9_049XTP2B[KP0
Mi6J08^QZP22G6X0QPTE08d22P2<0PT0S0D;07@Z=`10=ed05BUJ02i8L@1DDVX0K@lO03d7;0064UL0
1A]G039?JP1HMG/0:DAJ01hhF00R?e<0BFI^01<[B00253L08ghe1P00o`08ooooo`19027>0P1:2@00
Nf1P04Dk?P070@404@4204D30`1Q0`40H`8306@1101`0PH0M04807D1201h0@L0P`8:08/22P2C0@T0
V@4909`11`2N0PL0WP460:@12@2/0P/0[P<<0:T1202[0PX0]`@:0<d<4@3J41<0fADJ08h>4`1XEEX0
hnGW0>WZj`3Zjn`0jNW[0>SXjP3[hn<0^UUO0<HE6P3>4AL0d0hE0=<>4`3B4AD0Wa8I0655B`3Df=`0
inSZ0>GUj03Rh^D0hN7T0>GEfP2[E5X0^Q4H0<@740301Pl0_@D>0;P43@2e0P`0/P8;0:H4301n0@<0
R0`B0:h[=`2=0`/0XP<<0:<2202P0P`0W@4909P11`2>0@D0T@4709`22@0309h12@0;09h22`2D0PT0
U0D;09h6302>0P/0MP860741101Z0P<0GP4105d60P0Ia@800P00o`08ooooo`L00?l004/0HFD/04<j
B00E5S80Fe1P03TmG00:3d00Ge5]07iJI`25FFP0RUUU08YHH@2@GF<0VFI]09iZL02PKg<0YgUl0:^7
PP2`Sh@0/IB80;BJSP2`W9<0ZIbC0:ROV`2_YZ<0[jNU0:>NWP2OWYl0]kVl0<;6b`2j_lL0/K>j0;^k
`@2m_/<0^kk20;c1a02k_l<0^l340;_0a@2n`<D0][^n0;:k_02_]kT0[K>g092Q]P0mCH@0UbDl0;<3
4P2b0Pd0Z@DC09I@H`1iRYl0bMgW0<[Ii037en80L8:S05LfF`281A@0T`4<08/64@2CKFl0LH2>00`T
H`015FD04BMS05AZO`1UNWl0:d=T02HmH`0W>f<052UT00HJG`024U`00@i>010RC00X;SD01`00o`0;
ooooo`002_ooool0F00Nc080B0D203D10@0]0@80;`820241000U0P<0<P4203d20P0j0@40?0420342
0P0o0`D0L@<907T22P1g0`X0HP<804L10`1D0P<0N08408810`270PD0SP@908H7301C:RH0_l6m0<kB
e03?dmL0d=CG0<^`]P2I?d<0[ATL0;8A4`2L4aL0PQ4D07hC5P2J51P0_Q<J0<8>4`3441D0]SDk0=S1
aP3Jg^00fn3P0<39b02b_;P0ZKJ_0:bg/@34cL`0d]WL0=7Ig038d=P0Sj2X03eEG00bB4/0IgUf09NT
X02U/:l0ZKFd0:Ja/@2BWIH0ATY50283101/2100PP8:08@42@2310P0P047088120230`P0M04207`4
2@240PT0P`8908`3202O2@`0YPT=0:L8402S10`0V`<:08l2201d10T0PDe?07ARIP0d92H04`4103d<
1@00o`09ooooo`H00?l004`0R5dh06YFE01RDE80Ba`N04dN8P1D?TD0F4YD069FG`1^GVD0O6ig08=e
O024M7L0S7Mi08YaLP1kH5d0MU]E089XH02BOW40ThAe09V:N`2HSWl0UI2309ZIS@2?UHh0RIBA0;S6
b@2jaL`0PHN909NPWP2T[:h0ZK>b0:Nb]02X/kD0Y;:c09ZWZP2h[:h0WB0W0;T=602e2A80]a0H0;=E
HP1jF7/0TcmE09`H9@2O31T0RQLR06e;JP0?:fX0<EZ:07fGX`2L[KH0K8FE0;:lc01l:CH0T0@=0981
2`2@0P/0R0H>050ZB00B;V00GGjF07N7T@1kDU/0J@TJ01`;@00255d0<4ib05McM@1DL7L01Qm103YE
JP066d003bM<004?@0013ST06VLd1P00o`08ooooo`1G02;>0`1:2000PF=V03`c=P0?1@D05@0004H1
0@1O0P80G@4105l10P1]0@L0L04707811P1l0@L0QP4808T1202A0@T0U@0709P11P2I00L0W@490:81
2P2/0P`0[08;0:P12@2]0`X0`0P@0=0=4P3L4QH0ea0E0;<E6@1@:bh0gn7T0>[ZjP3YjN/0inSX0>OW
j@3Uh^80a8670;dI8@3;4QP0cPlF0=0=503C41D0_QDM050I7`31aLX0i>SZ0>GUi`3Oh>80gn3S0>GP
h`36TYL0[QPQ0<894@2o1@l0^`D<0;P5302f0Pd0]P<?09L4301X0040U@H@0:044@240PT0V@D=0:82
2P2P0Pd0W04:09L11`2?0PH0T04609/1202M0@P0W04909`22@2L0@X0VP4<09/43P2F10`0R@8907T2
1@1^0PD0J`8305l10@1M10406/@200800?l02?ooool7003o000P05Ul9P0i<4<0:BM304U0EP0Y;UH0
4QM903liG01mGF/0PEQU08EAH@2:Ef@0SUeT09IVJP2IJFh0WVaa0:IiNP2XPWh0/9250:nCQP2cVY00
[i^C0:VJT@2VWIT0ZInM0:bSX@2e[j`0][>`0:NVYP2RXJ@0ZZZ_0:R[[`2_/[H20;Zm`@0Z0;Vo`@2k
`<D0^/760;_2a`2k`L@0][^n0;2g^P2_][P0Z[>e0:B`_00^Bh80Rd][0;465@2c0Pl0[P4>09HZ>P2a
[Kd0c]cV0<_Ih`3:en00[koB03`hHP1m3280U08=09022`2<ATd0DF1o008JI`058Eh0D6Z106]oP01J
Kgl01ai<05Q]O`0lCf/00Q1K004=H00145`011E<00/K?`0b?4@03/T71P00o`0;ooooo`002_ooool0
F00Mb`80@P@102d00@0Z0@40:`8202<10@0V0@40>P8204020P0i0040?P420342100Y0@@0CP<805D2
2P1<0PT0@@8605d42@1o1P/0Q0@808@21`290PL0R`<806D=3`2@R8D0cM7B0=3BeP3@dmH0akJj09hk
@@2W5QT0TQ8F04`93@0Y6AT0>3Pg03dl?P0^6a`0QA4F0;`>50313Q<0_1<G0;Y=E`3CYZh0flcB0=gK
gP3Lfml0f][M0=SCe`35aLd0SYnZ05EZM@17GF<0Jg]n0:bg^030b<T0cMGD0=3Ge`3@e]T0cmGI0<oG
f03>emD0`<O5085kN@1R61`0P@<;08L32P260PP0Q@<708@21`250`L0PP8708012@200PT0Q08709H7
302R2@`0Y0L>0:D9402R1`d0V`<:08l2201a1@L0U6EU06YFFP0Q4Q@0508103h:0`00o`09ooooo`H0
0?l004`0Tf<l06Q8AP1TBT/0C@h>04hI6P1D@D<0EdY@069DGP1_GfH0O6]c085`N022LWD0QWEf08Qa
L@1nHUl0N5]F08=[I@2;N6d0U8Ae09J7M`2IS7l0Ui:409NGRP2;T8L0P8^80:B`]@2KYj/0R8j?09nU
Y02VZjl0Z[6d0:^e]`2W/k@0YK:b0:Rc]02`/K<0WD170;8?6`2e3AD0/`dD0:TQ;@2H6R`0YA<N0:8@
6P2A9CD0JTUZ01`dK`0ZDH<0MYFU0:Fi_`2FYk<0OYFV08f8V01l4ah0T08;08d430261Pl0QPD=07@U
=`1gPY@0TZR^08IfOP1e7BP0HPLN00d<B00265P0CFYj05efMP0fDVH032Q704]XL`0663h00A13004=
@0013cT06dTi1P00o`08ooooo`1902??0P1B3000MUYK034Y:P080@407`8205430`1M0P80FP4105`1
0P1Z0@H0K04507011@1m0@L0Q04808P1202>0@X0TP4809D1202I0@P0WP<;0:412P2W0PT0Z`8:0:T2
302[0P/0^0<90<d=4P3C3a40dPhC0<0B601=3A00_l?70>?Ui`3Ti>H0hN7Q0>7Rh`3Shn<0e:ja0:dS
:@3;4a/0dQ0G0=4?5`3@3QH0aa0H06<;4029Qhh0g>3T0>CVj03RhnH0h>7T0>7Rh`3H_/80XRXb0;`9
4P2k1Pl0^`H<0;D52`2d0``0]P@>08d52`1A0040R@L>09l33@1m10P0O@@909l43P2P0P/0W04809/1
202F0@L0V@8909`1200209d1200<09`12P2G0P/0TP4809P330260PP0P@8907<1101V0PD0H0840601
0P1P1@@0<hX50P00o`08ooooo`L00?l004`0EI/Y034Y?P0k=Dh0<be=01lUC`0P8dh07b1<07ANK`1m
EF80QUAR08eII`2?GfL0UfM_09i]M@2QLGD0YGYj0:V5P02`T8H0/9F;0;:KT@2^Vi80ZiVD0:^PWP2]
Y:40/j^W0;Ja[`2c/k80/[6`0:VVZ@2][k80XjJY0:V/[`2d^[d0/kZn0;Nn`02l`/H0^<340;Nn``2k
`L@0^;g00;>i_02a^;/0[;Bh0:Vc^@1KM9h0I5F30:<=7P2f0a40/@8@0:4@8`3ARIh0_i>Z0;J>YP2b
RJ<0[hBR06TfF0285bX0T@4>0942302482h0>cm^014[K01BKXT0Igb206InQ`0P=Ul09CeO06]oQ01Q
Lh802QaF004@F@097eP0?UE]02@eB00hAT/07iPE1P00o`0;ooooo`002_ooool04`0b^@L0=P<102<1
000U0P807`4102H10@0Z0@40>@4104010@100@00A@4103D2100H0@<0:@<603092`0a1PT0A@<807d6
40290PT00P2<10T0@`2>0`H0P`/;05DV902n`L00bm3C0<kBe@3Acm@0TEAJ09LH7P1b3aD0:@<403/o
?02Q[JP0/;bh0;6k]`2X[:/0Oc8c0;@C5@2n31<0_PdA0;XC6P2[7bX0/deI0<R3S@3;S9X0`WZ;0:5I
J`1:;Sh03B0X059WJ@2EXj00c]?D0=GIg03Ce]X0dMOI0=3Gf@3?e]P0d=KI0=3Ee`3<dmD0cmCG0=3A
dP1nBdh0NPD;08431`270`P0R@<808D31`220PH0OP4608432P1l0@P0PP4709T83P2P1P`0X`L<0:@9
3P2Q1``0V@@;08X1201_20X0UVUZ05<m?`0>10@0504103h:1000o`002Oooool6003o001=07Ik:`1_
BD@0Hc/h05D?3P1C:BT0EDA405];D01VEEd0LE5J06m0B@1hHVT0O6ea085`L@2:Lg<0PVIR07iQG025
KVP0SWY`0961LP2?PW40Th]l09VER02FU8T0UYF?07j3P023RHT0Qhb9092DT02W[J`0YJb]0:Va/`2Y
];@0ZK>e0:R_]02PZZ`0Yk>d0;>FVP2R6RH0]PdF0;<B5`2S8bd0UR/h08LnDP1N@fT0;D5e02]AP`1[
SJL0TjVb09:V[02J[K@0RYjY0::h`@1gGfl0Q@XE08D;4P1U<dX0@3IG06T]?01j2A<0W5iY08MEI01l
4b40O@H@04dC<`044e809TMZ061jOP15Gg0022A:03UJJ@1EL7007cI?004@@P0244003bI302@hA@03
lP<01@00o`08ooooo`0g02?@0`1>2P00ME]J02DO8@070040:@8205<20@1E0P40DP4105H10@1Y0PH0
KP4607411P1n0@X0Q@8<08P12P2=0@X0T00:09<12P2G0@P0W08:0:012P2W0PT0ZP8:0:T1202i1@h0
c@`@0=4<403;2Q00a`/B0;l;4`1a2Ph0PWn40=oQhP3Qh^<0hN;R0>7Qh@3Ri>@0i]GF0:]<DP365ad0
dPlF0=0=503?3AD0d10I09D=5P0d6b40b/kA0>GVj03RhnD0hN?T0=oRhP3Pg=/0XEEI0;8:4`020;L5
3`0N0;H43@2d0`h0/P<>09D63@160@40B08506@3201?0P@0J08909X44@2O0P`0W@8809X11`2A0@H0
U@4609/12@2N0@P0WP4909h2302J0@`0U`8:09H22`2>0P/0P`8:07`2201b0PH0I`8306810@1Q10<0
<hX60P00o`08ooooo`L00?l004`0@/0R02@N<01AAU`05QPj034bE00e<58010Pm04e6I01lF6@0PTmL
08UDH@2AH6P0UfQ_09Y^M@2ILGH0YWao0:V3P@2^SHP0[I>:0;2KS`2ZV900ZibE0:ZOW02aZ:@0[jZW
09ZJVP2GVId0/[:c0:ZZ[02c]KH0/K:c0:N/[P2`]KP0][Zo0;Zn`P2k`<@0^;o20;Ro`@2h`L<0^Ko2
0;Bk_P2`^kd0[KJi0:je^P2O[Kl0=Tf408llE`2_2AL0/0@@0;054`2Z1QT0X@PK09X86`2E1QX0T@DJ
08l45P2@0a00T@8<08l1302221H0?2aL03iKPP1/Phh0GgJ701`jJ00J=f40GgEn06n0O@1^OWh0E6Uf
03I>I`1DKWT0F71b02LlB010DeH0=6hW1P00o`0;ooooo`002_ooool0F018Y`h0<`@101`0000J0P80
3`4102<20@0[0040>P8204@10@1:0@40C@4204X3200N0P@0J5EG0:bKX01U@TH0MALL08P53P2<0`X0
S0@809462@2B2Pd0KQHD07ATGP3;d]40bm7C0=;Ce`2eVZ00Ob8U04l;3@0]71`0IVa[0;g7`P3FfMT0
fmgO0=[Mg`3Gg=/0^i2=0:DN7@2n3Q<0`0lC0<8?50334AL0_aDL0;TI8@2e6R@0YQ`X05d@600e;c80
Pi6@0;O2`@3?e]D0d]SK0=;Hg03@e]T0c]OH0<oDe`3@eMP0d]KI0<oFf@3<eML0c]KI0<oEf02AMWP0
M`P?07l21P2810X0R`D;08831`200PT0O@8907h3201l0`P0Q0<709T73@2M1``0X0L;0:@:3@2N1@T0
UP<:08L11`1`30l0XWYl058n@0090@406@81044:1000o`09ooooo`H00?l004d0HX/N07I:A`1O?3H0
E38[0550?P1A@dL0GDiF06]9D`1^:C80JQ4I07MDFP1bHVL0NfQ[07mVJP26K6/0OF9O08E/I`2;M6/0
T7ia08moL@2CRGh0V96809RFSP2HVI40V9fE09BHTP27RX<0U9ZF09RQXP2GX:40XZb]0:Rb/P2X/[D0
Y[:c0:6][P2KZ:X0[9FK0:<H8@2e31<0[3E504=;OP0mGH/0@6:@05IhV`1eU:L0RJ2V09N[[P2@XZD0
X[Jj08FMY028XK40Mi>T08IeP@243AL0Q1<P04HbEP1iPjH0T7F607dC7@261@l0P@H@07@C7@1A:Ch0
5Aa<00dXF`1ALhP0=e=`00LRC`0gEFX0FWAg05QaK`1@Ifh062m:020lD`16I6T0<TU>00k@3`05003o
00Sooooo05L08ll304h9001ZBTT06A4B00X10@0c0P80DP820581001B0@40F@4206H11@1Z00@0L043
07`22@210P/0QP8;08X12`2?00T0T`8909T1202L0@T0X@490:P2302[0@X0/@<<0<473P3<2a40a`T>
0<883P311`l0_`T?09X=501EA4P0b/kA0>;Ri03Rhn@0hn?T0>;Si03XhN<0dIfR0;TR:03@3aH0d0dE
0=4?5P3C3aH0_Q@K04L2202CTYL0h^GW0=oSi03OhnH0g^?U0=kPh02iT9D0Xa0K0;<63`2c10`0/`@>
0;424@2^0`h0Z0D<08L83@1^92H0Ncm104<10`1h10`0W0<=09/12@2K0@X0V@4:09811P2E0@H0VP48
09d12@2N0@X0W@4:09L230270@L0R@<:08/32P1V0@D0HP450702101]0`D0G@4105h30P0bR@D00P00
o`08ooooo`L00?l004d0:n0H01lG8`1ECf801@/_05E;H@1;?EL00PHm00d?@P1[D6D0P5AO08MEG`2C
I6`0UVY`095ZLP24JG80U7Mk0:N1P`2ZRHH0Zi670:^HS02ZVY80XiVA0::HU02SWYP0XZ6N0;c1`P2e
^[l0ZZ^`09fQX`2SYZT0YJR^0:6TZ@2Z[[@0/kNl0;Rn`P2m`/H0_/;70;Zn``2k`<D0^L330;Fl_`2b
_;h0^L?50;[5bP2X/k`0Qijj04]FQ@25B5l0UCQ70:51A02QAdH0X4a<09Q9C@2EBdl0S4Q<08=0B@1o
?4@0Q3Pj08Lc=`1k=cT0G5Ub01DaJ@0Q@78032MN02]5KP1WO8H0Jgin06n0O`1/OWl0K7am06ajN@1W
MWH0FFea01ddA`1=HFH0@T@m00Cb0P05003o00_ooooo000:ooooo`1104NV3P0c1040704101P20P0@
0@408P8102`10P0h0P40@08204P10P1B0080FP<705PS9`1D>D40J3e8074Q:`1m1@d0R08;08T32@2<
1@X0U0L;08TJ6@1?;2H0][Rd0<W@dP3>d=<0/YZO07<_=00g3@d0IVQW0:je/`3=dm@0f=?G0<BJX`2^
JWH0X86:0=KJg@3B_l00V2d^0;lD5`313Q80aA0F0<<>50374QH0`A<F08T@4P0k30`0FEYF0;K0_@3@
fMP0dMWI0=CIf`3BfM/0d=KJ0=7Gf@3=e]H0c]GH0<kCeP3=e=H0cMOH0<kFf@3>e]P0d=OI09IiO@1k
2a400`200PT0501n0PX0O08907/2201i0PL0O@<808X32@2H1@/0V`H;09d7302Q20/0W@D;09D42`26
0@P0NADI0:9jO@0a7b@0104101`10P152@<00?l02Oooool6003o001=04BT301^<2<0KDm:05M6@01A
@400ETE706=9C@1R8bT0Ja`P06TX;01WBE40K5UN07QUIP1jHfH0P6IY08=YJ@28KF/0R79[08]jK`2@
PgD0Uh]o09RBR@2IUXh0VIVB09BKU@2=Thh0Q8V207j7P01lQX40OXN7096KWP2OZZ/0Yk:c0:>a/@2T
/[@0XZb_0:AkP`2^51d0^`hE0:TW>011Ch40RZZl09RZ/02EYjX0Tj>X09NZ[02CZ:T0Y;Nl09F//P26
XJT0TZji04QWQ`2P[[`0NS<k08<84P1l2a/0NA0R07/:601o1Ph0P@@:078/>`0X:5004RUC03iMN00J
<eD01b1=014/EP0nGW<0GWUk06=iNP1KLg<0FG5b04mZJ@1FLFl0DFe[02M2B00MY2001@00o`08oooo
o`1702CA0`1B3000IdE000`71`070040;`4205D20P1C0P40E08205/00`1X0@D0KP450781101g0PP0
LP4707P22P260@/0RP4:09<22P2I0@L0V`0609h1202U00T0Z@890:h22`2h10T0a@T>0<4730301``0
_`T=0;h:3P2/3QD0?a`P0:J[[P3Oh>@0h^?T0>;RhP3Shn@0iN;S0>76a`2b=C/0cA4F0<h<503@3QH0
d0dE0<TA601h2a40J5]Q0=oRi@3QhnD0h>;U0=oQh`3Ngn40ckFh09PF8@2a2180/P<=0:h33@2]0`l0
ZP8<0:T22P2R1P`0[T9708Lk@P244QT0V`@>0:<1302L0@T0V`4909L1202C00L00P2H00P03P2L0@P0
W@8909/11`2;0PP0MP0507l22`200`P0JP<705X0101c0`H0J08305P1001L0`40=Hh90P00o`08oooo
o`L00?l004d08nT@03hZ:@19A5X05QTl06aKI`1UDF@01`Hi00P9?01^DVP0Oe5M08]LIP2KK7P0VF]f
091XLP1oI6h0TG9e0:R1P`2YQhH0ZHj70:^HS`2TUH`0X9J<09jFSP2HTXd0]KJd0<K:cP30`lX0[:b_
09nSY02OWj40VYbQ092FV`2V[K00];Zo0;^na@2m`LH0^/740;Nm`P2k`LH0^l?60;Rn`P2d_<00^L33
0;Bk`P2nbm80Z;O309^bb@2>ZlL0FGFE0<WIh03Af=`0dmSM0=3Fg@3=eMh0QIR`07F;X01iRYD0S9FG
0:6WZP29TY<0NXN<05e_Q01>I7`0H7J50724Q`1bPhD0KWmn06n0OP1]PH80Ef]c061dM01OLg@0@EE[
00/NAP13G6H0AE1;01C13@05003o00_ooooo000:ooooo`1H04JT3@0a0`408@0103HB4P0I0@406P41
02@00@0e0P80>@4104H10P1D0PD0F@4305T42@1L2A80H`D<07432@1o0PT0Q`8:08P32P2;10/0S`L;
074Y9@2NV9@0cM;C0<cBe@2aWj80I2/_03XH5`1nPX00c<o@0=GBf034YJl0ZDA@0:`K90285QX0MEIF
0=WKg@3;YJX0YBDY0<4D5P3241@0b14F0<XC5P334QH0R10B054m>`2PYZ<0b]?@0=GKg@3DfM`0d]WK
0=?If`3BfM`0d=KK0<G6b`2bZ:l0W82<09MmR@2a[[D0bm?G0=;FfP3BemX0c<_@07m9D@221Ph0P@<8
07d1201n0PT0P08907T2201d0@L0M04807@21P1n10P0T0<909T52@2L1@X0W`L=09/3302A0`X0Q@47
07HJ7@2HN7X06a0C00810@0K0P40@`P2003o00Wooooo1P00o`00C@14]`d0IBXG06m@C@1GB480ECLj
05lb>@1W>Sl0H3Dh06Q7C01VCeH0GTeE06A@E`1_Feh0N65U07iTI`27Jf`0RFe/08]fL02?OgL0ThIi
09V>P02IU8T0V9N@09NHTP23RH<0M7if075jL`1fP7X0Mh5n07N3P@23T900TZ6Q0::^/02V/;80X:b^
0:Nb]02RLGT0/A8J0;T:402_3QL0MD5U07FBZ`2M[K40VJV/09j//P2K[:l0Sj:W09na]@2FZk@0UK72
05n1V@1MOIL0MIVW0;:c^@1mEV80HBLj064W>`1G;T<0K3M707L7401Y=4X0?cAC06eMK@1RCE<0IEMK
05eVK@1HLWD0F7Eb05aiM@1SO7/0H7Qh05]cMP1<JFL0CVaW04m/K00P?4@0::8/00D00?l02?ooool0
E`0Td@D0C`d1060n?0090P803P4103<20P1B0P<0D@4105810@1I0P<0I`4606/11P1X0@@0MPX?09HZ
<@1_31<0OP8;08/12P2A0@T0V04709`1202P0@X0Y@480:T2202b10/0_@H<0<883@2m1P`0_@L?0;h8
402o2`l0]`lE04L:3P1iNgl0emSI0>;Ph@3Th^@0i>;U0>GSi03ZgMd0^5YN0<`E5`3@41D0dPhE0=8>
503=41H0Y1DL054_=P3FfMh0hn?U0>;SiP3QhN<0gmkQ0=_>dP2G<3P0/0XC0;<6402]10`0Z`8=0:T3
3@2U0P/0YP8>0:895`2P5bH0XPPD0:H1302T0P`0W08809/12@2F0@X0U@4809T1202K0@T0WP8:0:02
2P2N0@T0U08908T11`2@10l0O`4:07D31`1Q0@<0I@<506020P1L0@80F`8103>;1P02003o00Sooooo
2000o`00C01K?2X0>CA>03@aB`1`G5h0LEaW01HA>@0?3ch0LUEY089GHP2=HF`0UVMb09]/M`2HKgP0
VWEj0:=lO`2VOgh0YHB10:67P@2ST8L0XiJ=09fAR@2IShL0W9><09JBT02ZZJX0XZ>S0:2QX`2X[Jh0
Zjj`0:6SZ02AUYX0Yjj`0;Jl_`2k`LD0_<?70;c2aP2l`<H0_<770;W0a02g_/80`<K:0;c4bP2f_/@0
];o608bP]`2O^MD0A6^G0;;=g@3@h>P0d=cU0<oNi@3>fnD0bmWT09Z/`P2D[lH0RYf^08nO[@21T9L0
O8b>086?U01gQHP0M8B607B4Q@1aQ8@0LHB50722P01]Ogl0K7n002U0D`1CKWX0<4MR00HCA`002T<0
6Bi>04YMG`0OWAP5003o00_ooooo000:ooooo`1H04:S300`0`008`8305@a<P0M0P805`4102420@0a
0@40>00104L10`1<0080C`0205<00P1N00D0IP4506h11`1h0@T0PP8;08@1202:10X0Q`T<07UAC038
c</0cMCE0=3AdP1fDeL0:PP;06ATG`3:c/h0e<cB0;63S@2N<3T0^1DK09<C5P0n3Pl0[jb[0=gLg`2j
M7`0^1TP0<<A5@354AH0aa8F0<TC602[4QH0A1XJ0;2h]P3DgMX0eMcL0=CKg@3BfM/0e=[L0=;Jg03?
dMP0W8:B085:EP1f8bl0O1@Q06dJ9P1@?D@0^L740=7GfP3BeMT0Y9:J074N:0241@/0P@8807d2201m
0PL0O`<907L21`1a0@H0L`4707P31`1l0PD0SP@:09D42@2L1@/0W0@;09P52`2<0@P0Q047088];@28
KFd03@D70040000I0@00?PH1003o00Wooooo1P00o`00C@0Ve@L0IRlL06Xo?01RA400G1lQ068N901N
=S`0GdUA061=F01TD5T0FdYD061;D`1SC580KeIJ07eSI02<L700R6m^08MfK`2@OGL0UHIl09V@P@2J
UXX0THj407j0N01dNW80Lgae07AnN01iPW/0N89n07N3P@1jQXH0QYJF09bZ[@2Q[:l0WJR/0:Vb]P2X
Mgl0[A4J0;T<4`2j3Q@0XB8e061MP@2G[KP0VZV]09f]/@2FZ:T0[lC809F//P2?Yk80UZjj06Z9Y01`
Uk<0NZ:b0<3Eg`2jc]/0Q9Z`04eQPP0i>el0HRTo08453`2021@0M@DB07443P1/0`X0J@D<064J801W
FU/0G75`05mhM@1KMW<0GWYh04QSJ00_CU40AF=S024jC@076cD0<7hl00D00?l02?ooool0<@0UdPD0
CPd1050b;0070@40604104030`1=0@80CP4105@10@1H0@40H@4506P11`1J0@<0M@8:08`3301g0`X0
KP8808X12@2B0@T0U`4:09T1202M0@X0XP8:0:P22@2h1@`0``T>0;h63@2j1@d0_PPA0;h940322a00
_P`A070:3`0n=CX0aLK80>?QhP3PhN<0hnCU0>GTiP3Vhn<0bY:E0<<H7P3B4aX0da0I0=8@5`3@41H0
`A8J05T<502a];X00P3Rh^D0903Ph>@0h>3S0>;Nh@2UI6P0ZA4L0;<94P2^1Ph0Z@<;0:P22`2U0@X0
Y04<0:82302T0@d0Y`8;0:P33@2T0@d0X04;09`2202J0PT0V08909P12@2K0@P0WP490:812P2S0@`0
XP@=09D22`2>0``0S@<;07l2201f0@L0KP8606D2101R0P80G@8104IM1`800?l02?ooool8003o001<
05IZ9@0Z9Ch0D4QJ06]KH01XF6H0=Ba=00l@?01dFF`0QEaW08eTK@2EJg@0Vg1i09edO02MLg/0WgEh
0:=kO@2SOWl0WGml0:2=Q02RThX0V8j50:2HS@2QVI80UI6;09bJT`2LViH0UiZE0:R^[@2VZjh0YZR/
08nAUP2RZJ`0/[Zl0;W1a02k`/H0^/360:nf_@2^]kh0^l?80;c3a`2i`/D0]L340<CDfP2U^<<0Wk?9
09F_b01lW[T0_MKT0=7Oi`3@g>D0c]gV0<cLi@3;f^L0TJJm05EaR`2IZkL0YK>n08VHW`25TYL0NHN<
07N6Q`1dQ8@0M8>307>2PP1_PH@0LH6406enP01WNgh0<dMS014TE@012dH00@U5004=@@065S/0B5mS
02VL9@D00?l02oooool000[ooooo04H0@Z<<03H:1`1=<340FD=501<10@0F0@807P0103020P0k0@40
AP8404/10`1=0@<0EP4506<11P1Z0@D0LP8907X12P1m0PL0O`8808H42@2871d0SG]g0<[Cd`3=eMH0
]K2a03`U9P1LFeT0][^i0=3=d02YJgL0WB0/0;4C6@2L4AH0D1lP09^HU`3De]L0f/O=0:lh?`3551P0
aQ0D0<XB5`384AD0_QDJ06lA502BSX`0eMWI0=WMg`3Hg]h0e]_N0=?Jg@3Ae=T0_jjf099FH@257bX0
RA4J08P<501k31<0?@`@04E9BP2lalL0cmGH0;J^]@1c>D<0N`dF08022`220`/0O`8907/21P1i0@L0
LP450P1a0@H0401i0@H0QP8608`3202@0`P0U@<:09T42P2D0`X0S08908H22024=3D0N5aO00P21002
0@407P8103l50@00o`09ooooo`H00?l004d08N@9064Y2`1^?cT0HRHT06@F5P1R<CD0G4M?05Q8C`1O
C5<0GdQA05]6D@1MBE<0HDeA06QBE01jH6@0S79c08MaK`2<NW@0Sgid09B6O@2FSH80UY:7085nL`1o
OGL0LgYd061^J`1NKf`0FFa/07:0O`1ePX80NHB507R7Q`2=WIl0UjJX09VX[02KYjd0YH270:HB6P2g
2a40^@X@0;4<502<>E<0KH6M0:6c^`2K[K@0TJR]09V`]02Q^;l0WK[805=hU@1GNYT0FHBN0;cEg`31
dml0[[?408MZOP1a;3l0M0dJ084440270`X0QP8;07l12P1e0@T0LP4807011`1[0@P0GADJ06AYJ@1G
LW00EG=_05IcK`1?JV`06cI7014W?P013C<00@l_02M6=`05003o00Sooooo05L09m<605<@0`19;2P0
1P0001/00@120P<0BP4204d0001E0@00F04005l00P1S0PH0C04307D42P260PX0L@<806/21`2<0PT0
TP4:09H12@2G0@L0V`4:09l1202/10X0]`@:0;`6302k1Ph0^PD>0<0740302100_`P=0;l;4`2>31D0
8@L>0;2`]03QhN80h>?T0>7ViP3UiNL0i>?V0=fk`02g7bH0cQ0G0=<?6@3B3aP0c`lF0<XA6@1k31@0
Ph270>;Ui`3PhN<0h=oS0=oNh`3Ng^40^96F09@D7P2_2A<0[@H@0:L0302V0Pd0X@4:0:423@2O0Pd0
WP4:0:<12`2U0@T0XP4;0:012P2M0@T0V`4909X02P2I0@T0VP4809d12@2R0@d0Y`<>0:L7402G10h0
RP8908h12@260@T0P08807/21`1]0P@0G04105/10@1BEQ000P00o`08ooooo`P00?l004`0Hh@[01lI
;`1QE6<0;B]802d`CP1CBF402`dh07EML`2:I740T6Ma09Q^M`2ILGT0VW1i09mdO@2OMWX0X7Qk09ik
O02QR8@0WXj709j?R02LT8P0X9VB09^FT02GTX`0WibD09jNV`2IVYT0YJNX09BKW@2^[[80U9RL09bT
Y`2e_;l0^l;50;c2a`2h`LD0ZKBg0;Bk`@2h`/D0`<W=0;c5c02jb=00/Kk50:c3dP2W`MT0;UJ609Rf
c`3Ah>T0d=gV0=3Ni`3@gNH0cM_W0<[IjP1lTk@0UjK008nL[P20RYL0NhVA09VX[@22T9L0OXj@07>6
Q01bPh00LX630723Q@1fQXT0K7j504=JMP0864l00@U90049A@0444409CeG01P/A@0kE5l0?G8j1@00
o`0;ooooo`002_ooool0F00nX0/0@QPA04TZ:`0Y3a<05@4201P20P0L0@40;04203`20P130@80B`42
05410`1N0PH0I@4506X21`1Z10X0L@@;07h31`200PL0Q@@;08`k?02a[j`0cM?E0<cCeP1GEUH0JFaW
0<K<b`3@bm00WEeV0:0F6`2Z41H0SA4E040I6@2OYJ<0d][J0=_FfP2dH6X0`1LL0<P@4P3:4A@0cA8F
0<DI6`1k4A40R79`0=3Ie`3GgMl0e]cN0=SMg`3Dg=d0X:^d05i>G@1n9S@0Ua0G09P>4P2=3A40KPdB
02X:2P1>FeH0/Knl0=3Gf@31_l@0N3e307h;4`2310X0OP<807d12@1o0PX0O@8807X2201a0PD0KP43
0701101i0@@0P`4408<10`2:0PH0TP<909L42`2C0@T0T08:08D32@2GDeH0>b@X00H10P040@409P42
04440P00o`09ooooo`L00?l004d0Jc8<074m=`1V7a/0IS4_05i9CP1EADd0F4E>05]8DP1J@Th0GTIB
05a8DP1PC580JU9G07AKGP2:LG<0S7=a08mlN02DPW/0TXEk09:9P028P7T0JfiX06mfL@1JJ6L0Jg]i
06ilN@1CJ6T0GG9a079oO@1cOh00MHB4082AT025UYP0U:BW09:RYP2[Vj00WA/U0;P<5`2h2Q40]@T>
0:P@701oD6X0RZ6^092TZ02hcM40WkFl08BQ[@22WZT0PZ:k07RO_01XTZX0/Kc;095_P`239SP0PPPD
07h22`210PT0P04808D22P250@P0P@8907L22@1b0PP0L04606d11P1R10P0CSi705=`K`1CL6`0D6m^
02m:G00243L00@`c004:;`013bd07Rdd00Cc0`04003o00Sooooo05L09m@705@C0`109R<0204002`2
0`180`80BP4204h10P1H0P80G08206D21P1S0`X0?@8305@31P1Q0PP0C`4506X2202:0@P0TP4909L1
2P2J0@P0W`8;0:D22@2b1Ph0^0L>0;L43@2m2100_@P>0;d73`2o2A00_`P@0;l;5@2U3QP0>04:08V5
S@3ShnD0hN;V0>?Si@3Vi>H0iNGW0>KFf02b=3T0ca<J0=<B6@3B41H0dA0G0<lA6@2N4AT0HU5G0=OJ
gP3Qh^@0h>3R0=oOh03MgMh0c;Jj08HQ:P2[2Q<0[0D=0:P33@2V0`d0X@4;09h22@2N0P/0WP4<0:81
302T0``0X@4<09l12`2O0P`0W@4<09X1202I0@P0VP4809h12@2T0P/0Z@@>0:P5402T1A40V0<<08T2
2@270PX0NP4707D11P1Z0P@0H`8405l20P1?D``00P00o`08ooooo`P00?l004`0@:/K02@K:@1SEfD0
2Phe01/NA@1[FFX07a/o06IGL@2>JWT0TVQf09=XL`2AJ700VFmh09ibN`2NM7P0XWMi09iiM`2NPWl0
X8b60:6ARP2NTX`0WYB?09bFS`2FTXT0UI:=09RHU`2EUI<0XJ:R09bLX02b/k<0Y:RZ09bSY`2k`<@0
^l;50;No`P2f_l<0ZkFg0;c6b`2mb<l0_LK:0;_5b`36d]T0Y[[809Naa@27Y/40T:o;0:S2d`3Ch>H0
d]oX0=3OjP3=gNd0Y[KE07]aWP1P9EH0O1e008T]B02GG740RX2907j9TP1mRi80NHF:07R6Q`1gQhL0
LX>306j0O`1bQ8P0>4i^008DG0013ED00@U600lPA@13FF@0EfY]03Y;E`0fCeX0D5IA1@00o`0;oooo
o`002_ooool0F010Y0T0Aal@02440`0G0@805@4101`20P0O0@80:`4203/10@160@80DP8205P20P1O
0@H0I`8606D21P1;00@0C`8407d4202310L0P@@808eCD033a<<0c]?D0;c5a`0b@cd0]l2i0=7De@2]
R8l0UQTN09h@4`1i4AD0;0H608>:QP3?f=P0e]OL0<NJX`2b8BP0a1<F0<@@50383aD0bQ0E0:HO7`1O
>SP0dM?A0=KMg@3Gg]l0emcM0=WLg`3Bfm/0UJBV02LS:`1N4QT0U`lC08TB5P1J31007@@403i>A`2c
_kX0c=KF0<S>d`26HFT0P14H08H42`230`/0OP8807h120200PT0P@<:07`22`1`0@D0K0020781101l
0@D0PP45084010260PD0S`4609D22@2D0PT0S`4908@32@25A4T090hD00H10`070@40;04103l20000
o`09ooooo`L00?l004d0K4L>05hP5`1`>SD0JeEF05A6BP1C@T/0ET=<05U8D01IAD`0ESm:05U5C@1P
CE80JUAI07QQI02:LG<0SGAc091kM`2?PWd0TXJ008^2N@1mO700IViX07=jM@1;Fe`0Gg5d05]]L@1:
Gf80IGMd07B2O`1^O7l0Lh:307R8R020TY80Ri^M09>RY@2X[:l0VTA?0:TC7P2f2a<0]`/@0;8:4@2S
72/0Pff609F/^@2FZJl0XKO10:>oc01GNiX0DG:J04ITS02FQYX0Q31608P8602@0`h0R`8:08812@1o
0PT0P@4808L22P1k3Q@0LBLe05PY?@1@:C/0HaPR06T21P1Q10T0<R4e04i[KP1<JFT0635=004??`01
2CP00PXc00LJ<P0WAdd08SLg01;B3`04003o00Sooooo05L0:=D805@F200j92803@4103X20`1=0P80
C@4205810@1H0@40GP4206D1101S0PD0@08403P=3P1N:bh0A`<607/22@2<0@T0T@4:09D12@2G0PT0
V`490:P63@2M0`H0XPD;0;L5402l1a80_0L@0;/7402l2100_@TB0;d:4`2f3QL0L``D05U>D`3Lg^40
h^?X0>?Si`3Th^L0i>?W0>GQh`2gJFh0_R<W0<<P80328240`B8Q0<4T8`2_9RL0D2``0;fo``3Oh><0
gMoP0=oPh03Ogn00g=?F09UIHP2P3aX0[@D?0:X43@2X10d0X`8>0:833P2P0Pd0W@4;09`12P2O0``0
W@4<09X12@2L0@X0VP4909T1202J0@T0W04909l1202T0PX0Z0@?0:85402P1Q00X0@?08821`1o0PL0
M`4607H31`1R0P@0F04106820`19BP@00P00o`08ooooo`P00?l004d0?[XH02lS:P1?AED010Tf01`L
A01_EF@0ED9I04PnFP28IgH0TVMd099VL@2BIg80VFig09mgOP2KLWT0WWEh09UdM@2NPGl0WHJ009^9
P`2KShT0WIB?0:2HU02JThl0VYJC09VJV@2FV9H0Wj6S0::TY`2g^K/0ZK2c09jVZ@2e^kh0^;o10;[2
a@2h`L@0`<_<0;S4b@2ka/`0_/O=0<SEg02e`/`0]l[H0:O5e`0lIiL0N9bn0<WMj03@gn/0^LWT09>K
a01iHYD0OR]H098=:P2J0aD0UP8?09<13`2=0a@0SSI50:fV[P2<VIl0NhR>07b:R`1iR8X0N8N:07J6
R@1eQHX0>Daa004AG@045ET05BQC05=/K`1JL6X0F6eY0353D00nEV40EF1P00cH1`04003o00_ooooo
000:ooooo`1H04>Y3@0k5PT07@4101H10P0G0@406P4101X1000Z0P80?08204H10@1D0P<0F`450641
1P1X0@D0J08606L42P1R0`H0P@@:08T42P242Pd0TfQU0<[>c`3;d]D0QYBF07R6PP3?dm40]YfT08`c
>P2841D0C@T;02`K6`1eNgP0a/o<0=K@eP2oT9X0ZcHm0;hC602m3a40_PlA0<@>4P3151H0R3/l0;6_
[P3Gfm`0emcN0=KJg03DdMD0e<oF0=OJgP3@fmX0XZfZ04D_<01M4aL0;`P901lL6P1CHEX0[;Vc0<oF
e`30`lP0Rfmi07<G80251@`0R0@;08832@1o0PP0O`8907l120200`X0O04:07411P1Y0@40L04307`1
10220PL0NP4408421@2<0PL0U@<:09@32P2B0PT0P`@9091IG@0@0`H00`4100X1000f0`<0?`<100gB
0@Wooooo1`00o`00C@1CI@H0FBDH079NF@1VFeX0F4M9054W;`1F<cX0ETA=05Y5CP1F@4T0F4A<069>
E01/F5/0Mf=U08A/K`2<MG@0T7aj08n1O@2@Q7l0PWU`07ikK`1gNFl0Ngmg05YWIP13FE`0A5mP059X
I`1^O7X0Kgim06amO`1iR8/0PHn@08VHV029V9T0TJ>T0::_/@2`T9X0TRlj0:h?5`2d2Q80]@/B0:d:
4P2G8C00/ibV0:Jf^P26Xk80Oif/08nV^02HVJX0SU5T08d@7`2C0`l0S`4:0902302>0Pd0Q@@<07l;
4P2010/0N14L04PeFP0@9e`07c]U03=2GP1E82l0IP8605XE7P0G83/0C6Y`04mXJ`055S/00Pe0004;
=`0E;D@0=5QG03mOE`0W?cX07k4I00@00?l02?ooool02P0Xe@L0EAH7034F4`0G0@40@@<304l20P1?
0@80E04005/1101N0@8206810P0e05L31@1Y=cl0SV9Y06`D6`280P/0S@4909012@2A0@H0U00809/0
2P2Z1@d0ZPP>0:X5302h1A00^PHA0;X4402j1A00^@L@0;X63`2k2A<0_0dG09`F7@1292T0d]CI0=gQ
i@3Ri>P0h^;V0>7RiP3Qh^D0b[Fc0<bDT@3GViL0gJJP0=NQW03GXY`0ejRR0;nb/030`<<0g]kQ0=gQ
hP3Kgn00g]kR0>3Lg`2mVIl0UQLR0;043P2/0``0[@L@0:H33@2S0Pd0W`8<09h3302L0@`00P2L0@/0
502K0@X0V@4909P1202G0@L0V@4809`12`2S0P`0XP4:0:H33P2R1a40S`4909D53@250PL0N`<907<0
1P1]0PD0J@<506010P1S0@<0CD`70P00o`08ooooo`P00?l004d09=L>03/Y:00i<TL03aDo02DR@P1b
EF00M5MR058nE023HG40SfAa09MZM`2JKGT0VFeg09ieOP2LLgH0VFmc09E_L@2HO7L0VhAm09f;Q02J
SHH0WIFB09jIU@2FSX/0Ui:?096ASP2EUYH0VYnP09nSYP2^/kH0ZZfa0:N[/02b^Kd0^L330;g4b02l
`lL0_<C70<K@e02lal`0_LS>0;g;dP2Za=H0Y;[=07>@[02I]M00SJk>0:F^cP2=N:D0MS=T08HNA`2B
3RT0UPTG08l@6@2>9Bh0Pb8b08P7502C0Pd0S`<B08a6DP25RHd0PI2C07^;SP1jR8h0MhF:07R5R@1b
PXL0BEie01heH@1DK8<09C]F05]bM@1LL6`0Ffm^01L[?P1=IVl0EfQV01O54@04003o00_ooooo000:
ooooo`1H04:Z3`0Y1P406`4101H10@0L0P805P4201@1000[0P80?@8204X10P1H0@<0G@8506<11P1/
0PP0K`0807L12P1m0`X0Q0<908X42`212`h0X85o0<gBd`38dM<0MH>10<C;b`2YWZ<0IB/b04h?4P0R
3@h0Ef1L0:Rf/P3>eMD0dlC;0:]GI02Z6R40^a8D0;/?4P2l3a40_@h@0<4@402g;Bd0a:f/0=SLg03H
g=h0e]7F0;1gP@2L>T@0W3900:1SLP3=c=80eM_L09nUZ00^=cP0KWeh0:Fe[@37d/l0cLoD09j2R`1l
=Ch0NA4H07T3201n0`P0Q0D9088320200`X0OP8807d11`1n0PP0N`8:07@21P1^0@<0M08307h2101o
0@H0N`8407l11@290PL0T`<:09D32P2C0PT0P@T<0714A@0900400P4100l10@0g0P<0?@8001720@Wo
oooo1`00o`00C@1HJP/0GR`N06YAC01/Fe/0G3<g05@<4P1H92T0ED9;05U5CP1F?dL0FTE;06MCF01d
HFD0Nf=X08EZKP29Kg00RgAd0922O02>Qgh0PG]`07ajL01iNW00Oh9j07b1O@1]N7D0JGQc06mkMP1f
Pgl0]/C20;G2a@1lRH`0RibL09FUY@2>Wj00SInS096SYP2TZjh0/9JK09d]=P2d3Q@0/PTA0:l83`2[
21<0WRXg0:bEW02T]l00OIN/09b5V02<:Sh0TPHD09P33P2H0`d0S`8;08P43@1o6240OCi6084Y<`1e
2A80DBi=01PbI`1MNiH0KWAm06H_>@1W10`0I`d@03hY?00N>5@0CVa^05=/K`0>83h0325301D/AP0n
H6<0@f=L041NE`0R>c/0:9lW00@00?l02?ooool0@00XePP0GB8B03<N700M0@40B0<304h10P1?0@80
F@D605P31@1L0@<0H08406<10`1T0`L0LbDa07h]?01o2aL0S04<08l12P2A0PT0SP4609<2202N0P`0
[P@<0;853P2d1`l0^PL@0;`74`2k1a80^@LB0;P84@2h1Q40_0XE0;/:502a4Q`0B0`B0;bna@3Qi>L0
h>CV0>;RiP3Ti>H0i>?V0>?Ri03UhN40in7Q0>KQh@3Th>40h^3P0>KSi03Th^@0hN7S0>3Qi03Mh>80
g=oQ0=gNh03Pg^00dk^n09XX<@2]10h0[@@=0:T33@2X0`l0XP8=0:484P2M0Pd209d1300E09`1302L
0Pd0VP0;09`12P2K0@X0V`4909d22@2P0P/0Y08<0:P33@2Z20l0V0D>08T42`2=0`T0P08807P22@1W
0PH0H`4306L10`1W0P80DDl;00800?l02?ooool8003o001=023V3017<2/0:bQ203dkE@0h<400LEMN
07IGH01kGFP0Pem]091WM@2CIW80V6Ue09U/MP2LL7X0V6me09E[L02EK6`0UGIb09j6P02MR880Vhb8
09RAS02LUi<0THV709NAS@2<RXD0U9B@09:HV02RYjX0[;2c0:fa]@2V/;40Z[Bf0;k5b@2na<P0aLW>
0<37bP2oa//0`LS>0<SFg02fam<0CgZW08ZJ`02UOYP0S4i^08TgG@2;8T@0SQH^08hH9@2<9Bh0R3do
091VI@2PTIL0CeUb049@MP1Q9dT0S`<E09@13@273ad0TGj0086=S`1oSI00OH^=07^9R`1eQ8L0L8:3
0723QP1]PHL0K7j302i4F@1JLWP0Gg=a05]aK@0iD5@0E6]Z05U^J00UYR001000o`0;ooooo`002_oo
ool0B00kWP/0:P<101/10@0F0@805`8101<10@0B0@409P8204820`1<0@80E@4205/1101V0@P0K048
07812P1m0`/0Q0<=08H32`250`T0P``A0:R9RP3:d=80/kbn0:^d]032b/d0;cLj01dN700oAd@0Qi>@
0<K=cP3Fe=P0b:Zc0:8kAP2`4QL0]`lA0;H=3`2g3A40^`dB0;l?4P2n4180_eMH0=3:b`3Jfmd0fM[N
08a`N0217BL0OQ4G068=4@0b3AD0FfA]0<WDf03Af]/0^LC10<oHf03=dmH0]:V`08I?G01e5R00M`hE
07@:4@1c2@l0N0<907l42@1o0`P0O04707/21`1n0@L0P08907h32`1e0@L0M04407`21@80OP8400h0
P@44088110270PH0T08:09<22P2@0PP0PAPK05Pf>@070@400`8201P10P0m0P80?@8001720@Wooooo
1`00o`00C@0eU`@0FRDE0719A@1[=cT0GQ8D058D5`1G=3H0Dd1805Y5CP1G@dX0G4M?06YHG@1fIFL0
NfEX085VJ@27KFl0PfY[08YkMP2AQX00PGI`07YhL01dMVd0OGid0863O@1iPGh0N89n07J2O026Ui<0
a]SL0<CDg@1iS940OY2@08RJVP26UYX0Oi6E08^NXP2LZZh0XZ^_0:B4R@2K5al0/@/A0;493`2`20l0
[@/C09TW<`2TR9<0P5AX090D9@2L1A40V@8=09L33@2A10h0OQ4N05daD00n>VD0JBi907P9501R;4D0
421G06J1W`27MXT0KQd/07H43@1d0PL0KPD;05/F8`1GDEL0DfaY059ZJP0iEEX0AVEV03==EP0fEUd0
AfIP045NF`0E<C80<Wlc00@00?l02?ooool0;P0YePT0Fah@02H@3`0O0@40A0<204`20P1<0@80F`lC
05041P1D0`<0F0<605`21P1T0PD0KP4807/22`290Pl0S`8=09812`2@0PX0T@4609L2202Q0PX0/0D<
0:l32`2Y0`T0]PP@0;T64@2h1a40]@H>0;<64@2b1Ph0]0P@0;X:4@2m3QD0QPdF071KI`3Dd]/0h>;U
0>7Si@3ShnD0i>CW0>GSj03ThNH0i>3T0>;QiP3ThNH20>;Oh`0W0>7Oi03Mgn@0gMkS0=cMh@3LgN00
g]gP0>;Hg`39X:X0W1hY0;053`2]0Ph0[0<=0:D2302R0``0W`8=09h33P2N0P/0W04:09/1302K0@/0
V@4909X12P2J0@T0VP0909h2302R0Pd0Y08=0:P43P2V10d0Y@L@09T53@2=0`/0PP<706T1101H0@@0
G`8406D10`1X0P80G1`500800?l02?ooool9003o001<05Lg;@0M6cL0E4]L04PhA01bEU`0Ke5J07EF
H01mFVH0S6=a08mSL02EJ7@0UVaf09aaN02GKG@0TfU^09UaLP2KN7H0VWij09V4O`2NT8X0Uhf909VD
T02OW9L0WYZF09BAS@2JWIX0TYJG09fRYP2GW:@0WJJY0;Jm`@2a][X0^l760<76bP37c=40b];G0<37
cP39d=L0^lK<0<?Fh@2L]m80?5nG071aV`1jEW00RTiJ091IH02BKg00[YjM0;Bc]032bl/0bMSM08^P
/P2R^l`0Qj6k03<]G@1m2R80TP4>08d33P2=DUH0Q8Z<07b9RP1lRhd0O8Z=07>4Q@1cPhD0LX6307:1
PP1`Oh80F6ae05ifN01NLg80GG5]05U]K00lDe<0FFeZ03en=P@00?l02oooool000[ooooo05P0=YT7
02L2000I00005P4101P10@0E0@40300002000@110P<0C@4205H10P1J0@@0I@4706X11P1c0PT0N`8:
08012P250PX0QP@:08@;4P2UOh80bLoA0;[3a034bld0VjBW05QVHP24T8X0[kRd0<oDe@3<`LP0[Gb7
09/`?02`4AL0]`l?0;H=402e3Q00]0/>0;P>4@2f3@l0^0hA0;mOH`3Ad=<0em_N0<kCeP0c=cX05@L:
00l51P0A5AH0DF9Q09BUY@2obl/0e=gN0=?Lg`2d_/H0MW1j05@_>`1131H09`4601/00P0K0@80:@84
05<6301`10/0N`8907P21P1f0@D0NP4707d1201l0PT0N04807/11`1o0PH0O@4307l21@220PH0Q046
08P11`2<0@P0T08808`21`2?=CH0@B`]00<00@0200406`4104830`0n0@004L412Oooool7003o001=
03Z_201F8Pd0MCll06/L7@1W;Bd0DS4e054l@`1E@Td0Ed==05Q3C@1LAe40IE=J07ITJP1kIfd0NfAW
08UXK024IF40R7I_0926O`1lM6l0MgE`07IiL01dNW40MX1h07R2O01fOWX0MH5l07V9Q`2CYJX0Q9NL
0764Q`1mSY00PIBF07R>T@1lTID0O92E09RZ[@2?X:<0UZ2S09UUJP2M41P0/@XB0;084@2/2A00YR0V
0:Hf@@2E2aP0WP@>09`3302J10l0R0dI06X]AP0];F408S1_06@/D`1o21T0KRPn01XNF@0mA7@0Ld5E
07D;6P1m0P`0OP8:07L12@1a0@L0J@8605XE5`1JHV00CVMU04eYI019If80>eML02e<D@17IUh0A69L
02m=B011GCl01000o`08ooooo`1G02[G2P1U:1T09a<A02H10@1;10D0C@4105420P1O41@0D0<70401
0`1O8BD0C0P<05H1101c0@H0Q@4>08d13P2?0Pd0S`4908d1202@0@P0U@470:@32P2c0`h0]0@@0;85
3`2c1@h0]`LA0;L6402c10l0/PD>0;043@2c2100^@/B0;/:4@2g4A/0LP/M07LoEP32W[<0c;W60=W4
d03H_//0f[S80=Na_`3I[;/0fJVn0=>P]03AWZl0f:Bd0<nN/03;WK40_IBU0;jGZ039Y;@0c:>d0<62
T`2L;3d0[0/F0;433P2_1A00Z`8:0:H22P2T0`l0W`4;09d1302N0P`0W@8:09`12`2M0P/0V`4:09/1
2`2J0@L0VP480:042P2S0P`0XP8;0:@23@2S10h0Y@@?0:843@230@@0OP4607<21P1Y0@H0HP8505T0
0@1U0`@0JQD>00800?l02?ooool9003o001<051D9P0I63<0G4mM03H^A@1?@4h0K4eF07=?FP1jEF00
Qe]W091SKP2CI700UFYd09U`N02GKW@0UVab09]bM@2LNg/0WXB009R3OP2JSHH0T8N009:=QP2OW9L0
X9bH09FFTP2LX9l0RHjB08jFV@27SiD0TYbO0;Vn`@2g_L40/k^o0<K=dP2oall0`LcA0<C=dP35d]H0
_<cF09b`_`2`amP0U[GF05B2/P2`b]/0c]WP0=3Kh03>f^00c=_R0<SIhP36f^@0b=SS07B:Z@1TPJ00
L8JK04aKP`1Y8d<0T08A09422`258BP0S8N907n:S01mRh`0NXV=07N6R@1eQ8P0Lh6607B1Q@1bPH@0
LGn406YnP@1PM7D0GW9`05a`K`0^AT`0?EEL04iRBP@00?l02oooool000[ooooo00<0<iH602X50`0I
0@400P0H0@40700E0P80404202410P110P<0CP8205P1101N0@D0I@4506/11`1a0@P0NP<:08022P25
0`X0R`H;08T9402HGV@0b<[>0<S@dP3<d]@0Z[Bc0;W3`03;d]80cLkB0;^MY`2MAU00WQXS0:dA5`2c
3A420;<=400e0;8=3`2d3Q00/PdA0;L@4`2j4AD0^4aB0<o8c03Eg=h0d]_J08NGU@1[NgT0NhZ809f]
Z`2kb<L0cMSH0=;Lg@3Cg=h0XZjd02/mAP0=5QX04Q<E020T9P0_>CT0=D4o038n>`0R:BT050P:03/5
2@1Z1@/0N@4807T2201j0PT0N@8707`22@1m0PT0O`8807h1101m0@@0O@0307h110250@L0R04808/2
202=0PL0R@@808`m?P0/7Ah00`4200H10@0Z0`D0A0<404010@0B`P402Oooool7003o001=02?C1P1M
9A00J1dH07@]:P1W=cL0CQ/N05Hg?01E@dd0ED5;05]7C`1QBU<0I4iE07MSJ@1nJ6d0OUiT07lf?024
A480RGMc08b2O01lMVh0NGQ_07IjL@1]MVh0N7mk07N0O01ePG/0OXZ407Z7Q`20T8l0N8V907>6R01h
QhX0Pi>F08NJVP1iS8h0NHb?08JKW@2@YJD0WK2a09FMWP2IEeh0ZA8K0;0;4P2^9R`0[Rhg0:H;5P2U
10d0W@<<09<74021:d00@3ET024oNP1KJ9L0NSMC08X96@1h9cd092AN03d[G`1_6C40P@D@08422`1o
0P/0O04:07/22P1b0PL0J`4505d42011>T<0BVMV04]YI@19IV40AfAQ04ETH017I5h0B6=L03mID012
DdL01000o`08ooooo`0602[H2@1U:aH07@X702h20P1>0P<0B`420P1>0@<0C`1=0P<0J0lE08dY=`2;
9cD0G@8607T22P280Pd0S08>08/130290@P0S04908l22@2E0@H0ZP@;0;@43`2e1100]`D@0;T74@2g
1a00]@D=0;052`2a1`h0/PH?0;453P2k31@0_@/A0<0=5@2k4Ad0[a8S0:/M<P2i>Dd0`Ca@0<8gBP33
<480`2Xl0<8X>P3193P0_R4c0;dP<02m82h0^1h]0;@K;@2d7C00/ah`0;8P<@2b7c80/Q@U0;D95P2i
1Q00/P<<0:h33@2[0P`0YP8;0:D2302S0P`0WP8=09`23@2J0@`0W08;09`22P2J0@T0V@4809d22@2L
0@T0WP<<0:833@2S0Ph0X`8=0:T63`2X10l0X`<<09822P270`P0M@4407D21`1`0`H0GP430643101[
5Pl00P00o`08ooooo`T00?l004`0>fDI01hN=P1AB5H02Pda02LT@@1VBe@0L4]H07QBGP22EV80RemY
08mRK@2DJ7@0VW5j09Q`M@2BIV`0Vg5d09aiO02JPWh0VhV109Z;Q02DR8@0THV509::Q`2JUY80U9JB
09JLV`23RHX0PXF708V>T`2FWJ80_Kk20;Zo``2l`lL0_/G80;S0aP30bm40en7Y0;[5cP2gam40`M?N
06fD_`1[T[`0D7VS0<WOkP3:g>d0d=[X0=3Ih`3;f^D0Z;gF09Fbd`31`m/0RGjP07=eS`2ea]40Fg6B
04PZE0291QH0T`4;08H84@2CMgX0Ohb<07Z;S01kRXd0O8R<07F4R01cPXD0LGn207>1P`1_P880JWn0
06EiN`1KLW80Efe_045JH00nFF40FEmJ1000o`0;ooooo`002_ooool0F00`UP@0>AH?01@10@0D0@80
5`8200l10@0>0@408P4104810P1@0@<0E`0305h20`1T0@@0K@460782201h0PT0O`<;08@22P2910T0
RPH;08L/;`2aZZ/0a/g?0<cAe@3:b<d0`:jg0:Z0R@2IBE@0UAHP0:<<4@2]2a00/0/@0;8<402a3140
/@dA0;<>3`2b3Q40/`dC0;H=502i3QD0[aTR0<B7T`3Id=P0emcQ0=OMh03Dg=`0e=gL0=;Lg`33d=H0
UJR`09Z^/@3@g=d0U:BT05]]K@1hRHL0V:RU0:bj^@2g`l<0^lO40;_6a02Z^KD0NHN602h_<@1420/0
M`<907L11P1e0@P0MP4807/11P240PL0Q@8608421@230P@0OP4407d11@210PP0Q`4808T21P2:0@P0
PP<9099@D`0F1PT00@0100`10@0j0`D0C@8404<2000B`P49ooooo`L00?l004h0:]T:05`N1P1M71D0
Odm:05dN7`1H7R00ECXn05E2C01D@DX0GTU?0654CP1U?4P0K4A=07eRIP1oHfT0OSLk08<n>P27L6`0
QGYf07igL01fM6`0LWE^06acK@1bN7<0MGai07b5PP1lR8D0MhN607R8R01iRXT0J7em07b>T@2:Vil0
UjR[07V<T024V9/0QYZN09V^/@2M[k@0W[2b0;boa02REf00[BL/0;Te?P2Y2aD0/0XA0:/7402E4a/0
I3=C01dgL@1FOZ/0WJBo08LfCP2@2AD0ORPm02l/I01D>6D0M@`N08<22`250@P0Q@8907d42`1/1Pd0
KA8J06l:4P1_0PH0G0P<02HR=`16IfT0BVUU04]WI018IUl0B6MP04ITGP16HU/0@5iG02e7?P0Ad@d3
003o00Sooooo00D0:mT:07Dm8P0H1P@0>@<305830P0204`10P1@04H10`1C0P<0M08507l22P230@X0
MP<907<22`250Pd0R@8<08X22P2<00T0S04909811`2M0@P0[`H<0;@53@2g1a00]P@>0;P6402e1@h0
]PL?0;863`2_10l0[P<<0;D6402k2aD0`0dE0<<<50333QD0`Q0F0<8>5P394QT0bA0E0<`A603A4aX0
ca8F0=0B5`3D4aX0dQ4I0=4@5P3@3QH0b`hE0</?5P382A@0a`XC0<<94@322A40`0LC0;d54P2h10l0
[`<=0:X23P2W0Pl0Y0<?0:813@2T0@d0WP4=09d23P2K0Ph0V@8=09/12@2J0@P0V08:09P12@2I0@P0
W@8;0:412`2S0Pd0X`8<0:L63P2V2A00Y0L?09`22`2B0@L0Q@4707L11@1[0P@0IP8406L10`1W30L2
003o00Sooooo2@00o`00C@17K1X0;2Po04a2E@0212`081/j06M<E01_CU@0ME5J081DH02:FfL0S61/
099WLP2DJgH0UVaf09EWL02JLgH0WWan09j6PP2NSHL0VHZ609F;Q`2@RH@0ShV508f;QP2ATHd0SYBC
08R>T023QhT0UIZM0:F][`2k`<<0_<360;g5b031bL`0c=GJ0<39dP2mbM40a]7H0:g3e`2L]m80FX6^
09>if@2`c^D0OIW107QVT@2KEgP0XVB20;BD[P2YWl00=CQZ06TXCP1h4bd0LbXm0:2S[@1iSJ@0=SIR
07/@9P2D0Pd0U0@@091DF023RhP0O8b<07Z9S01iRX/0MhR;07F4Q@1bPX<0Kh6206j1P@1/PH00Igel
05eeL`1IKVh0DfQ[02Q3B`1MIfD04L`:00<00?l02oooool000[ooooo0480<i`403PK4@0B0@403`41
01410P0<0@003`4102L20P130P<0D@4505P0101L0@80IP4506`11P1c0PP0N0<:084430250P`0RP@<
08X63@29>c`0[[2^0<SBdP2QUY`0SCI209XL8`2O4AD0YP`B0:P8402Z2A00[`/?0;0;402a2a40/P/A
0;D>4@2e3A00]`h@0;P>4P2i3A80^a0C0;PA5P2Y62@0Z45A0;AbPP2oT9l0[H^G08R1R`1?GfX093Y3
04MNH@2`_l00emgO0<W@dP3Af]X0d][J0=?Kg@3AfM/0dMSK0<oHfP3?emX0cmGH0<_DeP2f`Kl0H410
07062`1d0PH207<11@0D07h31`290`P0R08508<21@250PP0PP4607h11P1o0@L0Q@0608X120290PP0
N@X<07Q>D@0<0`@0104201810@110P@0B@420441000B`P49ooooo`P00?l004d0HR47064X7`1c;2X0
IS0/05Tn?P1B?d@0DSm805@oB@1NA4l0HRdi06<A6`1P61h0MTI;07==D`1mEUL0QV5M08MaKP24N780
PGQb07aeK`1dMg00LGMa071hLP1eNWL0Mgmk07>0O01fQ8<0MXB407J6Q@1^P800NHb=08:EV02@XZL0
OI6F07F:T02<WjD0VJba0:g0a`2hbm40/<;80;be_@2Y@Tl0/PlJ0;<:4@2^2Pd0Zb0S09a2C`0bAGD0
S[GD0:NN]027:d80U`/G084X>`0^;fL0E3a]080=7`260@X0P`490883301d3A@0HBXj03/`C`0Y:e<0
GbXm06d32`1C72@04B4i045TI@18If40C6MU04YXH@18JF80AfIQ04ASG010Ge<0;4]101K95003003o
00Sooooo05L0:]T:06Ld5P0H0`40@`<305@20@1;0@80B@8203/10P1H0P@0N@8608411`230@`0L0<9
06X32@220Ph0R08?08`2302=0@T0TP8909<11`2L0@L0[P@<0;D53P2e10h0]`D?0;H5402f1100]@D@
0:l3302^0Pd0/@<=0;D6402k2QD0`a4J0<<<5@313QD0_0/E0;d=5`353aP0a`lF0<T@5`3@4aP0d18G
0=4A5@3C41D0e14F0=8?5@3D4AP0d0dF0<l=5@3<2a80aPT@0<<83`322A00_PL@0;/53P2h1@l0/`@=
0:d43@2U0Ph0XP8?0:@33P2U0Pd0WP4;09X12P2I0@/0V`4;09X22`2G0@P0U04909<22@2F0@/0V`8;
09d22`2O0P/0X`<<0:0I7033K6H0`Fa]09@G7`2B0`/0R@480802201_0@D0I`4306L20`1^3`X00P00
o`08ooooo`T00?l004d0<j0B04HiAP0n<dX00@<Z01hH=@1XCE80KDiD07ACG01mEEl0Q5QS08YOJ@2=
HV`0UFUc09MZL`2EIg00WgIk09ikOP2LPh40V8J309jET@3>cL`0VYNF08^5PP29Q840T8b:09RHUP27
QXP0RHR;09FIW02RZjd0^L;30;o4a`3;dM@0`<O>0<cEfP3Bfn40am7I0:o0cP2[_]00Y<CS07VJ`P0K
BhD0WKkN03m>P`2663@0W@TL09D=801o7380Ka/i07DR@`2<8CT0S@DC08864`2ROhT0Tj6]0393J@1S
:4H0T0<@09D23P2:82`0V8:607n9S01kRhh0MhV;07N8R@1dPh@0LX:40723Q@1^PX<0L8B306j1P01V
O7T0GW9a05Q[J`0eDEL0DVQY02>O6003003o00_ooooo000:ooooo`0e03NO1`0U2@403P0100/00@0?
0P403@4100h0000W0@40@@4204h20P1H0@80G04306<11P1[0@D0L04707H22P1n0`/0P04808P63023
1PX0RU9C0;[1`@37d=80RWn108PE6@2V2Ph0Y`/=0:P93@2]2A40Z`L>0;8=4`2`2Q40/@`A0;0:402`
2Pl0]0d@0;T>4@2l3A80_A0C0;/@4P2c3a<0[`dD0:/>5`2T4Qd0SadZ04L@700A2Q<062LZ08RGU`33
cld0dm_M0=OKgP3Gg=h00P3Eg=d20=?Kg@0A0=?Jg@3@f]`0c]OJ0<kFf@3:dmH0bM?E09:6QP1U20d0
M@<807811P1c00L0P`<908T21`250PD0P04607X41`230`P00P1n0@D030270PH0R@4708L21`1g4aH0
LEIF00L310040@406P8304H30`1:0P80@P8101;20@Wooooo2000o`00C@1a=0h0FadB06l`:01VBD<0
DTA104m0A01B?TL0GCE0068X<`1Q6R40IQhU068c=P1/DeD0KEUI07i[J`21KFd0RWIb08IkM@29P7/0
NWAZ07IgKP1cNG@0Mgai07MlM`1gOW/0Lgej06ekN01]OW`0Kh6007:3Q@1hQh/0QiRL082BU`2;WZ40
QijQ09V`]`2O]K/0SZ:Y0;[<dP2`_LD0/hBD0:lF9`2i2a@0/@`C0:lW:P2^;cD0T14P05YCMP2HRJ<0
RB0f09895`1m;4809c9]03U3O01i5Rl0S08>08P22P1h1Ph0I2Hg03DaF@0?95L0=D9Y05DaB`1Y2AL0
J`4805TF7P0n?TD0AVAO04QUH019If<0B6MQ04]ZI01:J680B6IM041OE00VA3d08ZTQ00<00?l02?oo
ool0E`0[fPX0Ld4P01d30@1=10@0E04104h20P120@80;P010583101g0@D0OP8807D32@1E0@@0I089
07l130250@h0S08>08d0202B0@T0U@4809h1202/0`/0]@D>0;<42`2f1`l0]0@>0;<33P2c10h0[`<=
0:d13@2`0@h0]0H@0;L84@2l3A@0`PhD0<8=5`2l31H0_PlG0<<?4`373a80ba4E0=<B5`3A3QH0da4E
0=8@5@3E4QH0dPlC0=<@5`3@3QL0c`lE0<X;4@392a80a`/A0<<93`2n1Pl0_0D?0;/43`2e1@`0[P@<
0:H33P2O0P`0W00809h12P2M0@X0W04:09`1302L0@d0V@4<09@12@2B00P0T`4809H02@2K0P/0V`49
09d22P2R1`h0[4]>0>2n``2CDF40Z4UB08HM7`1i1@/0OP8807H11@1^0@@0I@4206lB3@02003o00So
oooo2@00o`00C@0e`a<0Idm?02XR>P0?42d091db06U>DP1[CU@0LUAJ07UDG@20EF40R5YW08]NJ@2@
IVh0UfUc09AVKP2KLGL0X7an09n7P`2MRXD0WiJD0<K4b`2@RX`0RH1l08EnN`2<RhP0TI2?09:BTP28
RXd0RY6E0::[[@2i_/80_/?90<G=d03Gg^80a<gC0;;1b@39e=`0^L_L09ZjeP11K9X0OjG60:JoeP2^
aM`0>4Ak08PJ<P2R3Ql0RA8N0<>Y[P2JTJ@0GTEU06PF=P281AH0T@<B08@[=`35aL`0KWfE03`/E@23
2A`0U@8=08T54`2ADEX0QXN:07^:SP1iR8X0MHJ:07>4QP1fQ8D0M8:407F5QP1aQ8<0KX:306j1P@1S
MWP0F6e_0399D01;Hf<0<90W00<00?l02oooool000[ooooo05P0;iH401h20@0@00006@D501@20P0>
0@403`4102H10P110P80B`4205410@1J0@@0H`4506`21P1a0@L0N08;07d32P2110`0P`@:080:3P2@
IfH0`lc=0<SCd`2DV9T0IA0D0:H=4P2W2`h0Z@X>0:`9402^2100/@XA0;0:402a2`h0]0dA0;H?502h
3a@0_0dC0;d=502m3Q<0^a4F0;0>4`2/3a<0XQ@G07`?500f2@`0=cLj071nO@2^^kX0cmSH0=OMgP3E
fmh0eM[M0=GKg@3EgMl0eM_N0=KKgP3EgMl0dmcM0=?Kg@3Afm`0cmWJ0<cDf039d]D0YJ2S064<4P1d
0`P0M08807P21P280`T0R@8708H11@250PL0K08407H320200@H0P@4508H21P260@L0PP<7084X:@19
;2d00`4200@10@0L0P<0BP<504D10P0n0@004L412Oooool8003o001=05AY1P1G8a40J3/b0691>`1F
A4<0DCa0058W<@1H41P0HR@X06Hj?`1UATd0IdaE05]7C`1^GV<0OFU/08A/L@2<MgL0Rgek08Z2OP24
P7P0MgQa07EiLP1fNWT0MWah07=kNP1aOG`0L7em07:0OP1[OG/0J7an07F9R`26VYd0SZ:V08jQY@2?
XjT0QYVP0;W;d@2eb<`0[Kc30;:PZ`2N8c<0^0dG0;D>502d<3D0[RXe0:`<5@2H2A80UTQK08`G:@2A
3aT0LCAA01heL`1QR[P0MTmV08`65`2>0`d0O0`E05D`BP0A85<0;SmZ06U?I@1]6b/0LP@>07@12@1^
0@L0J@8605@M7@1;GeP0AFEN04]YH@19J680CFUU04]WI019IV80A65H02e:@`0/MR`00`00o`08oooo
o`1I02cJ2P1S;0`07`8104T20`1A0@80BP4203`20`0R0@40=@8205`21@1O0`T0C@4604000`1]0`/0
O`4<08H13P2=0Q00S@4;09412@2I0@P0Y0<;0;033@2c0`d0/P@=0;<53P2c10d0]0H<0:l3302^0`d0
[P8>0;433P2c1A00/`H?0;P<4`2o3QH0_@hG0;`?6@2k3A@0`@dB0<X@5@3<4A@0e14G0=@B5`3C4QH0
d18I0</G70305QX0_A`Q0<0R8P3171d0`a<H0<D<4`362a40``P@0<073`2m1@h0^P@?0;D43@2^10h0
Y`8>0:01302M0@P0V`4:09d22P2K0@P0V`8:09d2302H0@P0TP4709<11`2F0@T0V04:09/22P2K0@T0
W@4:0:053@2`G680g;O108HQ<02R?dT0]X660:QOI01h5AT0M`8607P11@1_0P<0K@d902f70@00o`00
2?ooool9003o001=02OJ3`1jFe405PlS04DkAP0c9C<0JTiB06e@EP1]CUH0Me5L085EH@26Ef40RE]V
095UKP2DIfh0U6Yc09]cN@2NN7T0WXF009j:RP2EQHD0S7im08UlMP27OGL0QGei08R3P02BTXl0Rhf>
08B6R`2:Si@0WJ:V0;[0``33b/d0aLoC0<[Ce`3<emT0`LoE0;34e02O]<T0S[CB0:31h@0mK:@0Z<KJ
0<kNk00iDHL0OCMH0:0=7P2=3R00`ZZe0<cJh@33dN00?D1[07LP>`2B11<0R@TH09ElPP2EY:l0<SUQ
074T?@2@0@d0T@8>07`?5`2?M7P0NXV<07F7R@1dQXT0LXF707B4QP1_PX@0L8>50723Q01bQ8H0L8J5
06MjOP1MKg00Efa[05MZI`14Lc/00`00o`0;ooooo`002_ooool0F00^U0409@D102/?3P1C>SX03P41
00T10@0=0@00:@8104<20P1<0P<0DP4205/1101U0@D0K08806`11P1e10T0P0H;08<530251@`0N`X@
09]oO@3:d]@0b=?C0;:o_P0n6Qd0Va0E0:L83@2W20h0[0X?0;0:3`2`2Ph0/P/@0;D:3P2h3A00]P`A
0;L=4P2m3a@0_PhD0<0@5P2f3A<0W`lD06`?4`0c20X0=2h^08JCT@36dM80e]kP0=KMg`3DgMh0e=gO
0=GKgP3Gfmh0dmWN0=?KgP3Fg>00e=WN0=?Gg03<d=D0bm?I0=3IgP3Af]`0cmSJ0<cCeP2FQh/0I`X@
07D21`1d0@H0O04608L21`290PP0RP8908`42@2510P0Q0@808`32P290@P0R@4608L2201l1PT0R451
04<X:`040@401`4202410P1?10@0A`8203/10@0?`@49ooooo`P00?l004d0F6d905/X6P1H4`l0Ic`f
05=2@@1B=cX0EB8Y05`/<@1SAdh0Ie5G06QAF@1YDU/0DSm906]JHP1mJfh0QFia08]iNP2:P7l0R8B1
08J5P@25QWl0LgE_079iMP1SLg80Jg]j06eiM@1`NWP0Jg]i06UnO01WNWd0MX^@086FUP1oU9L0SjFY
0:[0a@2J[;@0QiZQ0:Zl`P2V[;80T4=@0:lA6P2`41H0[T560:LW=02^2QD0/0P@09`84@2T<3`0R1LU
05lmI@0I=WH0Nj;90;G6e`1o>4X0TPDA08H;5@1J<e407R9D050hFP1]7S00N@DC07d22`1f0PP0L`48
06d11P1W0@<0D`lE02llA013I640B6MS04QWI019If<0BFIQ04QVH@14He/0<di802a/<@03003o00So
oooo0400;M/;05`V100S0@40C@<304d10@170@80@P8302L20@0U2@P0L4a903<83@0_00@0D08707X2
3@200@d0Q04=08/3302<0@/0T04909/12@2Y0`/0/0<:0;@53@2i2A@0/@<=0;843@2e10h0]0D@0;42
3`2^0Pd0Z`4;0;86402b2100]PdD0;P<5@2h2Q<0^0/E0;/=5@343aT0aPlE0<dC5`3=51X0aQPL0:`I
7@2Q>C`0/75a0<FNWP3M`;h0il_70=nl]`3@Thl0]CTj0;X@5@312A40_`L?0;`53`2j1100]P<>0:h2
302V0P`0X@4:09h12@2J0@T0V`8;0P2J0@T05`2M0P/0VP4:09P12@2H0@T0UP8809D11`2G0PT0V@49
09l22`2P10h0[DmF0>6f_P296RL0Tb8Z0:=`N@29D5P0]Xb>07li>`1]3@l0L0<506/91P0_Q`400?l0
00Sooooo2@00o`00C@0<m`@0MUM4014;6@1DADP0@bhg06a=D`1]CU@0L4eF07EAF`1mEF00PeMT08MI
IP2>HV/0TVI^09EZK`2HKg80WWQi09YmNP2LR8D0UXF10922O029OWH0R7eg08Z0O@25OWd0SXf<08J7
R`29Ri40Ri>F09nXZP2laLX0^l;70<kEfP38d]T0_LkE0;k>e@2aa=@0_=GZ05b1[01FPkH0L92b0<WK
j03BgnP0NY6f05Y;N02B4BD0V0TL09E<G03Ee]h0cM[R08BE/`1<:UX0S0HL09835029@Dd0Zk>j055P
O@1:;e@0Q0HD09<12`2=10h0RdM=0827RP1jQhd0M8J907>6R@1`PhL0Kh>506n2Q01^PH@0LX>806j5
Q@1`Ph@0IGMj061cL`1OLg40E5M@00<00?l02oooool000[ooooo04D0<IL303`F401O?cl0HDmA00X1
0@090@403P4002T20@140P<0C@4405H21@1L0PH0I@4606`22@1W0PL0L0@908073@241@/0QPD:07T=
4`2QRH`0c=;D0<O@d`37d]<0Ce1A06L>4P2R3140[0X@0:d93`2_2Pd0/PX=0;D;3P2h2`l0^`dA0;T<
402j3A00_0lA0<0?5@2h41H0TA0E03`92`15AT<0SIZE0<;<bP3Hg^00emkP0=KMg`3EgMl0e]kP0=GM
g`3FgMl0e=[M0<o>e@30[KX0[8VG09MTM@27@U@0MS];04HhA@29Uih0cm[L0=3If`2k^[l0KSPo07L5
2`1h0PL0OP<:08D32@2:0`P00P290PP04@2:0`T0SP@709042@2A0@X0T`<:09H52`2C20h0O1DG09MU
J00C10D00@4100T10P0Z0P<0C`8204D10@0g00003/0100Wooooo2000o`00C@13TPH0FAh>05TA2`1W
@CP0ESlk04d[;@1D:c80FDA:05e;DP1QCe@0JUEM06aCH01VD5/0Kf5W07i/K`25KG00QW=e08EjN025
P7d0RXR508b>R@1gNW@0Hfe^03MAE`17Gf80Kgai06ehMP1XNWX0J7am05A]N@1ROXP0UJRY08nQYP2J
[KH0PIBL0;S6cP2_`<L0[;c30:B7U02G5240ZQ0H08hkE01TFH40SaHX0:/63`2^2140VPhE08];G`0h
>6`0;5>=09^mfP2meN80^l[F07m;F@2<21D0Rb8]06D`B`1`6S00O0DC08<230200P`0N08706h21@1/
2@/0J`@806T21@1A5b0072hn049TH017IV40AfMP04YWH@19J5l0BVIO04IUF`0oGTl0?UA100<00?l0
2?ooool0F@0]g0`0EbH702H10@1>0P40D00204/10@190P80?P82040R9@38^/<0<a<K04@11`1/0P`0
O@4;07h02`220@`0RP4;08`02@2@0@/0V@090:X32`2d10d0]@@>0;@33P2c1@h0]@D>0;D53@2c0`d0
/@8<0:l33@2Z00/0[P@>0;<8402f31<0]@PA0;P<5@2k2aH0`PlK0<PA7@3841T0a1LL0:0K7`1o9RH0
Zh5o0>CHe`3ViN@0hN?U0>7SiP3Qi>H0hn?T0>7NgP3J][H0XSPm0;LA6P2o2180^`<>0;T33`2d0@`0
/08>0:T23@2P0@X0W@4;09L12P2F00X0V`8<09X02@2M0@/0W04909/12P2H0@P0U@0809H1202F0@L0
U04809/23@2O0Pl0WBPe0>ni`P2@:3@0S@lI0:a_N@1j@dd0^j>W0::9R`2YOH40KQ/P06l>2`0^QP00
0?l000Sooooo2P00o`00C@1XFcL07aDO054n?`1B>Cd0KDe@06e=D`1bCeL0MEEL07YFGP20FF80OEIP
08UOJ02@IW00SVE/09M_LP2LMgX0UgQh09b6Q02IQh@0UXZ308f4OP2:PG/0QX1j08F1O`2<RHT0RH^<
092FV`2CV9d0VZJX0:ji_03:e=P0`LO?0<[Cf@2nd=T0]/kL0;75f01DNZD0WkkL06:A``2E]ll0d^3X
0=?Pj032e>H0=Tb008XaB`2L2Q/0Q`hM0;>6TP3Ce]h0a=;T03]3M`1l6SP0U`8B08H>7P2TUYd0Wjno
030eG`1h5bd0U@4=09D230266200SX>507b7S01hR8/0LHB60764R01`PXH0LX>506n2Q01`PhP0KX>3
0764Q01XOG`0I7Ug06IlNP1NJfL02mP600800?l02oooool000[ooooo05P0:Hl104h/9@1UAdT08`lC
00T10@080@40404102P10@150P80C@4205@0101J0@L0IP4706l1201d0P/0M`<<08<73`251P/0Q@L;
07H;4@2SRXh0b];E0<OAd`38e=D0QI:?02l72@2B51X0ZP/A0:l:4P2c3A<0]0X?0;H93P2i30l0^P/@
0;X;3`2l3Q40_@dB0;8B6@234aX0;`@5059KFP2nb/T0fMoO0=_Nh@3Hg^40f=kP0=KKgP3Fg=l0eMcN
0=CLgP3Gf=d0aK:k09QMK0289SH0SaPT08hA701f41X0;`L<01dS9P2DY:<0cm_K0<C8cP1jFF80LA8I
07/3201l0PP0PP<808H21`2;0`T0R08808P1202>10X0SPD:09@63@2E0`/0U@<:09l73`2J3Q<0Y4e?
07E9C@0@0@<01`8100T0000]0P80F@@404P20P0j0@407h@22Oooool8003o001>04BU2@1D5@@0HRdS
0696>`1D?SH0Cc/j0551AP1EB4l0FTY?069@F01/Deh0LUQS06iJH@1ND5H0MfU]07mVJ`1lIVT0PgQf
08R3P02;RXH0SHf:08R:Q@1]MG40A5YK05ibL@1^NWT0KGUj06MgNP1QMh00=EQ/07fGW027WJ40PIFJ
0:Fh_@2U][l0XK>l0;G8c`2W/;P0W4mM0:@?6@28=4X0:cIe061ER02B5bL0Y@LA0:@84@2=7B`0:SEW
05f6/@2ed^H0_MGQ0;gCg`31dn00W8fJ07hA7P270`d0Q`@?08L12`260@X0P`4:07`2301Y2Q40Db4]
05dmA`1Q2A00I@@703hN<00Q>dd0AFAR04MSGP1=J6@0C6IR04QWG`15I5h0@f9K04=NEP11EdL03=`8
0P00o`08ooooo`1802gL301E90H0:P4105<20`1>0@40B@4204d10P1C10X0EAlW05`eA`1Q72P0JP@<
07H22@1o0@`0OP4908<12`2<0Ph0S@0909412`2I0@/0[@@?0;@43P2e1Q00^0XB0;443@2e1@h0/`D<
0;<53@2a10d0[@<;0:X22@2]10d0]0TB0;H;4@2j2a@0_0lH0<8A6@304QX0]1HM09dM7@2KA440^IND
0=gAcP3ShMl0hnCV0>CTj03Qh^D0h^CV0>?Ti`3RhnD0h>7S0>;Mg03@/;00YS<g0;d94`2n1A00^`<>
0;D33P2`0`l0Z@8=0:<2302L0@/0V@8;09T1302M0@d0W04;09X22P2H0@P0VP4:09H21`2D0@P0UP4:
0P2D0@X03`2I0@d0X@<>09X=6034LG`0YTeH09@H8P2RE5l0T5iW0;BJXP2LPhX0^IRQ08I5CP1X2`P0
;hL1003o0008ooooo`X00?l004d0AG4S02`R9P16<S40GdI706];C01/C540L51G07EBG@1iDe`0NU=N
06m>FP21FF@0SV9[091RJ@2BJ6`0VWEf09EhN02KQX@0V8N409R>R@2CRXH0THN408V4P028Q8<0QHB2
07V1S01hQHh0VJ6T0:Zf^P2Z];/0]Kk20<;:c`33d=D0[Ko:08:L/033fNX0O9_104ml/`1BNjP0YlKJ
0=?Pj@3DgnP0d]oX06=lXP1/Cg@0S`dN09P:6`235b/0b;2k0<[Hh`1bQZX0F31K08h45`2?0`l0R4aG
09ZW/@1=Gh00Gc9C08l55@2E0@h0S0D?08iTJ01lR8/0MXV:07:5Q@1dQHL0LhF806j2P`1_PX<0KX:6
0725Q@1^Q880Igml069iMP1YPWl0KGik01G23P02003o00_ooooo000:ooooo`1H03V<101C<2P0;QHG
00/10P050P801@4200`1000X0P80A@8204l10P1C0@<0EP4406@11P1]0PL0L`8:07H32`1o1Pl0O@<:
08042`1d1`l0WhB80<_Be@38d]@0b=?E0;S5``0]:RX0B`/=09L@502^2Q40/0X?0;89302g2Ph0^@`>
0;`=4P2k3100^`hB0:PB601F2`l0;A`L06YbL@32cLd0f=oR0=WNh@3Jg^40fMkQ0=[OhP3Gg^00f=kQ
0=SMh03;`/L0UV5[09D`?02H4ah0V0dC090?5@1[3A<0:P`>049=B@2?WY`0am7B0<CAe@1SJg<0@QPQ
07<:4@1k0PL0Q0D908L3202<1@T0R`@808`32P2=0`/0SP@;08<11@2:0PP0U@<:09P42`2N2140UQ`P
0=>EV01_Ad/07@<601420P0L0P<0@P4205d20`180@80>@4001n30@Wooooo2000o`00AP0/a`H0EQ/7
05/K4@1M:b@0FT8n04e0@01DA4X0F4I?069;E01/BU40Iblg07UGGP1_GV@0HU=J07=TJ@1fGF40KeQK
08=gM`24OW/0Ph1k08F4P@23QHD0LWMe0869QP2EWY`0OXV:06elO@1VN7`0<51[04a`P`1jTI80O96D
0;?5b`1oTi`0Y;Nn08ZLY`2fbm<0_Ko709Tb?`2W9c80NEAa07doH@2J;3l0WA0L0:895@2J2180NBa4
02Q8NP2genD0`MGM0<7Dg@2od]h0`M?M08elR`1n3Qd0Q`8;08D12P250@P0P0<:07D<5@1P9cL0=Ba:
030ZBP1I6B`0J0@:05LM9P0C63T0=EQS04QVH`19IV8204YXH`0604UXH@17IEd0AV=M04APF00lF4H0
5/PA0P00o`08ooooo`1I02kM3P1J:@`0=@8205D20`1<0@40A`4105010P1J0P<0HPD>06X:5`1f0`h0
MP0707H1201j0PT0O04708<1302=0Pd0S`0909D12`2M0@X0[@@>0;@43P2c10h0/@<<0;443P2c1@h0
^0XB0;452`2/10/0YPD<0:H8302^2A40/0/C0:`<4@2]4AD0YQTI09hZ9@2TEU00^IF?0=O;a03Sh=`0
hnCT0>CTj03ThnL0h^3U0=oKh@3Bd=P0f]gR0>7TiP3Ri>L0h>;U0>3Qh`3Rgn40_8N=0;<?6P2n1Q00
^P<=0;H3302]0@X0Z08;0:@13P2O0@`0W@4:09`13@2M0@/0W@4=09/12P2L0PT0W08:09P32@2C0PL0
T`8909812@2B0@P0UP4;09h23@2Q10h0V0`G0:`oC02kIFl0OQ0N09<X>P2ACE/0R65Y0;B8T01^9Rd0
J@T603:70P00o`002?ooool:003o001=04R1800n;BX0B3<`05]7BP1I?TH0JdaB06m>EP1fD5`0N4mL
081GH`1hD5/0PeQQ091QJP2>H6T0TfY^09eiNP2HO7`0U7ik09B4OP2HTXT0Uhn;08Z0O@2<QX@0SHN8
07n1Q`1@HgT0RIBM0:^b]P2>UY`0a]3E0;6l`02oc=40^/_C0<OIi@2W_mD0AVnL08jbe01]UL@0RZ[8
0=3Qj03Ch>P0d^3W0=7OiP2fb=`0<T5e07`L=@2E1AD0U0TG09iCH@3?eMh0[/3E03@iJ01i5B`0T@8?
07lJ9P2JUId0Q9BW03/fGP1n3B40T@4?08h23@25<c`0PHN907R:S@1eRH/0MHR807:4Q`1aQ8H0Kh>5
0722Q@1`PX<0KX:306UnO`1VNg/0J7im07>3Q@0WY1l00P00o`0;ooooo`002_ooool0:P1AOP`0=1<<
01P30P0G2PX0104100P20@0;0@009@4204H20`1=0@40DP0205T11@1T0@P0K@8907412P1g0`/0O0@<
07d42P200`/0N0L=091YK@3<dM@0bM;D0<[CeP3;e=D0RiFC01<A401B2Ph0YP`A0;4:3P2c2Pd0]P/>
0;P;3P2j3A40]@lC094B5@0l4140KgIe0;W5a@3Bfm`0fMoR0=SNh@80fMoR02`0e]kP0=;Jg@31b/h0
dm_M0=KCf02KEEl0VaHN0:4=4@2D3a@0G@/?02X72@0W:BH0KX5k0;[7a03?fMX0bmGI09NV[P1BHfD0
8b@V04D83@1j0`X0Q@<808/42@2>1@P0R`<808X2202>0PL0SP<908@11P2=0`L0V0@909T62`2K3140
[EMI09UbM`1B;c@0>@d@02020`0]0P<0G@@606T2101;0@80>P0001n30@Wooooo2000o`00CP0Xe`X0
FR<:05DK401V?3<0FD<m05A3A@1IAT`0H3m806H`>P1g=Sd0MbL^07mGGP1cHVT0KV1U06mPI@1eGf<0
M5eQ07e`K`1iL6h0N7=^07ioM`25Qh@0OXR40;c7b@2KZ:l0[K^o075oPP1CJgX05S]P07B>V02@YJL0
Oi:G096UZP2W^;l0Vk2j09J]]P2:XZP0/K[109U:E@2T5b40VA/W09LX<P2]C5L0U`dJ09L64@2<2aL0
DcQP05AlY@2me]l0_]CM0;kEg@2odm`0_M7J09:=V`1g3al0QP8>08@22`1h2A<0IbLj03TaEP0F9E<0
@be=06DA8@1Y1@h0EB4]01TM?P0O?ED0BFUX04]YI017If80AfMQ04YYI019J680A6AN04ITG@13HEH0
?eY:02>X7@800?l02?ooool0F@0^g`l0CAX403T20@1C0P80BP0104`20P1A0@80FP4106010P1Y00D0
N@4907D0201g00T0NP4907T11`220@d0S`4<09@02`2I0@/0WP490:`53P2d1@d0/@8<0:l12P2`10d0
/`@>0;@43P2^0`/0XP<:08TK7@2E?c/0Tb`X09<V8@2A;BL0UdI10;V8OP3MbL00i>3J0>7Th`3Pi>@0
h>CU0>7SiP3Kf=l0gLkG0>:lb`3CTZD0IBY107]bO`3MhnD0gn?U0>3Qi@3Ph>@0gMkQ0=2g^P2T5b40
_0L@0;/53P2e0`l0Z`0;0:L13@2T0@d0X00:09d11`2K0@P0W04809l32`2M0@/0W04;09T02@2I0PX0
U`4809D12@2C0@P0U08709L12@2M0P`0X@<=0:864@2K1Q<0R`HH08d3402:0Ph0TcM009i]N02FIFl0
OT9906T=2`1;C@D00?l000Sooooo2P00o`00C@0_V``0CcH/06E9?`0n:Bh0ET1606]=DP1^D5D0KdmF
089XKP2gXZL0RFIc08AGI@2;HFX0T6I_099[L`2JMW`0UGAf08mcL@2DPgd0Vi6:09N@SP2;Ph40RhJ3
08^6Q@1HIGX0Gg>9092HW@2V[k80][g30:Rb^P2j`lX0^lW@0:JiaP2:Z;/0a=gY09>bcP1RSkl0?6FN
0626/`3@hNX0dMoW0=?Ni`3BgND0c]kV059YT@1N>5d0R0HG09P64`2;3Ql0`INX09^7X@1hFGh0Qb]3
09823`261A40UG=j0;K4cP0kBg40L2Y708`34@2@0@`0O@XD08]gNP1jRhd0NH^=07J6RP1fQh`0M8B7
07>5Q`1aQ8D0LH>406^0O`1ZOgh0JWem06UmO`1hRH`0>HTd00800?l02oooool000[ooooo03/0FW<=
03PE3P0H0@404`8200L000050@002P4002T20`140040D08205@00@1I0PD0H@8806X11P1_0PX0L@8;
07H32P1n10X0PP@<07l63P2;EET0a/W<0<cAeP3;e=L0cMCG0<;;bP1SKV/06PH808`?502^2@h0[PP<
0;893@2g30l0[A0D08<>5P0^1`L0MH1k0=;Kg03Ih><0e]kP0=SOh@3Ggn80emkQ0=KOhP38e]X0XK6e
0<G?d@3FgN00]i^S09<J902P2a40TA8E04L82`0C4A80CUmL08JIU036e=40c]SI0<cFf0020<cGfP0K
0<;?cP2;UiD0AR@W07`73P270PP0Q`4608P21P2:0`T0Q`8508`31P2?10P0T0@:09<42P2D1@X0U@H<
098>4P2lOh40RfQ^06I;C`0I0PH0:0/<03D31@1M10@0K08305820`0o0@407X8100Wooooo2000o`00
CP0GkPH0GB<505dd901PB3`0G4M005a5A`1S>D40HAHO06dW;P1g?D<0LT1507YPIP1`H6P0Kf9W075U
J@1lJfh0O6QZ07e^KP1cJVL0NGE_07n2O027SHT0VjNW0:6//`1fP840TInQ06UhQ00L>V40=5Qe07bA
U`1dR8/0]l_?08VMY02EZ[80QibT0<GIh02`aLl0OYb]0;:f_@2@KG`0Fdef03e;NP20@U`0S`XE08/6
3P1i8SP0735Y09Vne`32e]l0`MKO0;kDg@2ndm`0_=?K09^NZ`1X5RD0LPPC06PV>00n<UT062iQ041O
QP1nT:@0F1TW06DF8016:T8041i90253GP19JF`0CFUU04]XI01:JV@0BfYV04UWH`15If40A6IP045S
F`13HUP0@5e?02n69P800?l02?ooool0?`0_h100Cad703P20@1D0P80DP8204h10@1A0@80F@410601
0P1/0@H0M`4907@1201h0@X0N`8:07L01`230@`0TP8<09T12`2N0P/0WP8:0:@12@2^10/0[`8;0;43
3P2a0`d0/08:0;843@2/0PX0X`@:05h82`1XBe00_:V]0=[7a03Pcl/0i=_G0>CRh@3Ti>@0hN;T0=gL
hP3Kd]/0fl;?0=:K[@3<MX/0adiS0<8Y?@326BP0/1/U05DS:@3Ff]`0h^GW0>3Qi03Nh>40gN7R0=SB
dP2S=3l0^0TC0;T53@2c0`d0[`8>0:/23`2U0@`0X@8;09d12P0209`12@0H09`12P2N0P`0V`4:09P2
2@2I0PT0U`4909D12`2D0@T0V04809/12P2N0@`0X0<?09P32`2A0``0R08;09022`2<0@X0T2H_090j
B@1e7B/0V5=L06D;2P1R4`P00?l02?ooool:003o001=02Rf201N?c40K4i104Xd=`0m<3T0JTiB06a;
D@1`CUH0RWR10<Fka@2;JW`0QeMX08]OKP2<HVd0SfYa09UbN@2@Jfl0TGEc09>1P@2GRhT0ThV608^4
O`29QX40RHZ@02a1I021SYX0/;Rn09bU[02g`LL0Y[:l0;2ma`2<W:L0c=gV07nK^P1COZ/0Nj3604A_
Y02</]L0UKG;0=?Qj03Ch>L0dmoX0=;Ni@3?g^D0//?F03e9L@1Z8SX0QA4N08P>6`215BL0OaTa08@P
=@287bX0R24W07lS:`2?MWh0RIFO086CZP1<=E/0O0TN0942402;0`h0R4aA07f9R`1kS8h0MXV<07V9
S`1gQhX0LhB806f1P@1^Ph<0L8:306emO@1[Ogl0JGeo07>7R019KDP00P00o`0;ooooo`002_ooool0
F01BK@d0CR/T01P1000B0@402P8100H1000900009`8204/3101D0P80EP4105T1101Q0@@0J04606D2
1P1H0`P0GP@807X4302110`0P@D=08Lh?P2h]KX0bm?F0<_De`3=dmL0c]KF0;Jo_`0n@T<0C`/>0:H?
4`2_2Pl0/P`?0:/?501V3140;aDI06mfM`3;eMD0f^3R0=SOh@3Gg^00emoQ0=WOhP3Dem`0Yk:k05mf
OP2da<H0e]kP0<o6b`2C?TX0UQ<J07@=4@0i2@X0<SLd08FETP2b`;/0bMGC0<kIf@3=e]T0cMOI0<gF
f03=e]T0bmGG0<WAd`2;Mg/0N@/C08L32@250PH0QP8708/32@2;10P0S0D708h3202C10X0T08808h2
202@1@T0RalQ0:V0PP2PPHH0;Q/P01H52`0T1@T0>0430644101[0`<0D@4103l10@0QP`89ooooo`T0
0?l004d0JCH>05m2;01OBCT0I4E1064]<P1Z82L0IAHK06ho@P1dEEd0LEiU07EUJ`1eI6X0M69X07AT
J@21If`0P59G07iMG@1hLFX0OWah08Z;QP23RHL0S9VK0:jo``2:VYT0TJ2U03mGL@0::Eh0EWJ408ZP
Y02BY:/0O96H0:2a]`2O]K`0Wk>k08nS[02dbM00VkO60:G4f`1YR[003Sj908V<[`2?7Bh0UP`E08LE
8P16=5l0BG6M0;cGh`31eMl0`]KN0;kDg02oe=d0_M7M0:Ja_P1N@dl0>Bi=00dSE`0OA6h0G86H06n=
V@2BZ[40IF5/02</C00?:eD0>Ua`04a_K`1>K6X0BfUU04mZI`1<JVD0CfaY04a[I@16If40AfIO04ET
GP12HET0@eiE03F2=@02003o00Sooooo05T06?0804`H10110P80F`8205P10@1>0@80D`8205h20P1T
0P<0KP8607L11P1g00H0N@4907h12`1o0@L0R@8:09D2302J0@/0W@8:09d12P2Q0PP0[0@;0;033@2a
0`d0/08<0:d22P2^0`P0[P<;0:`22`2S1@h0R@PD07HJ;@2?DVT0W6^10;F;W03?XK40c9BU0<J1T`35
G740aD1G0<4U>03;62H0ca<O0=DB7@3@31D0d@hB0</A5P1c2Q40YjJ[0>7Ti`3Qh^H0g^7T0=cPhP3N
gn40ZV9Z0:d>5`2f1@h0]08=0;02302Z0PT0Y@8<0:013@2M0@/0V`8809d12`2M0@d0WP8;09d12`2H
0@P0U`4809L12P2B0@P0U@4909H1202H0@P0V`4:09h23@2F0P`0R@<;07h32P220`X0L04406l32025
0`h0P@8;07<62`1Y0`<0HPh5003o0008ooooo`X00?l004d07m46060o;01[C3d0FChm02lS;01XCE00
J4M<06]8DP1`BeP0NeIV07iEH`25F6D0OeYZ07QKI@2;Ifh0VG9f099/K@2DMgH0Th2109Z=R`2GSHT0
TXV508n;RP1MKHT0@5b00::[[`2@Uih0`<WB09jZ]02Q[[P0/L380;C4c`1cSjD0Uk3806>3Z@2;[]L0
EWna01U>T@2nf^`0d^7X0=?Qj03Ah>L0d]oW0=7Ni@3Ag>@0_LkJ09bW/@2_YJP0[YjP0;BVZ02f/;H0
KgR<09FKY@1lQI80/KW00:2a_@2IZKH0T:6a03]2J@1Z9TD0RPDF090230217BD0QhF607b<T01lSY00
NHb?07R:SP1cQXX0M8N90765Q`1bQ8D0L8:306b2P@1/PH00LXF705aOF`02003o00_ooooo000:oooo
o`1H05Ud3`117aP06`0101<20P090@40208100L10@0U0P80BP8405810P1D0@<0G08406@11@1X0@T0
H04505L31`160PD0L0@;07l42P2210P0Qa@I0:V>TP3;dmH0bm?E0<cCeP3=e=L0c]GH0:Ve/`0T7A`0
M`lD0:L;4@2N3aD0D@T>055AD02b_[`0d]WK0=WOh@3Hg^00fMkP0=SOh@3Hf=d0]9>P06m<F`0g>Cl0
X[6a0=OLg`3;_/H0V4mJ088F7P0j30`0<2l]06emN@2c`/40cmWJ0=3IfP3Af=X0c]OI0<gHf@3;eMH0
cMKH0<[Ce`3<eML0bM;E0;Rb]@1f61l0R`D:08L31`260PH0RP<808T41P2:0PD0T`@:09D42P2?0@T0
SP8808l83@2dL6l0TWYm0:JFV@0K2Pl060<602`21P1@10P0J`@606X30`1@0@80@@4002:40PWooooo
2@00o`00C@1/DA00G48/0655=`1T:2D0IaXN06@U:@1Y@DD0IE5G06]KI01^GfT0N6I]07]UKP1jFf@0
N4A<07he>P20:2T0PeED07icL020OW/0RXf708bBS@2?UYD0QXfB07f7S01QL7/05RmP01dlJ`22W:@0
GgIj09>XZ`2:Wj@0ZKc407^AV@2icmD0XKS10:S1c@2[`mD09UB609g3h@25UK80VD]O0:0?6@2;4A`0
G3UK02=2N02^cMl0`mKL0<;FgP34e]h0`mGM0<3Cf`2md]d0]l[D0;G6cP1ON9L05cm[07BL/P11Ig/0
S:^g07NCW@1bRi80HGf;06R6T01UPX@0CVa[051^KP1<JVT0BfQU04i]J01?KFd0CVaY04UWI016I5l0
AF9N04IRFP15H5D0AeQ900800?l02?ooool0@000o`00DQ`704H20P1N0@80FP0105810@1C0@40GP43
06810`1X00<0NP4707X1201k0PT0P08:08<0202;0Pd0U04;09`32`2N0PX0UP0809P0202Z0P`0[`<<
0:d22P2]0P/0ZP880:/21`2Y0@P0Z`8:0:`22P2_1@l0Z0@>0:d?7@2a5bP0/QT]0;PJ;P2n62d0aAHW
0<`C7@3=3QT0dQ0H0=8?5`3C41P0d0hE0=0=4`3A3A00c@`@09`@5P1oLWH0h>GW0=oRi03Ogn<0h>3T
0=gNhP2eRXl0Wa8N0;@44@2e0Pd0[@0:0:T12@2R0@T0W04:09d12`2L0PT209`12@0309l2302J0P`0
U0880080U@890180TP0809<12P2E0@P0UP0709P11`2O0@/0W@<>08l32P1j0@D0NP8906`31P1P0@@0
O@<:0803201e0P<0J@81064;0`00o`08ooooo`X00?l004P05Nd7060l801]C3h0I4A002`J901VBDd0
JTM=06Y3CP1aB5@0NTiK085DH@1eDEl0Je5O05m@G01cG6L0TfYc09=[LP2?MGP0UHB209J;QP2FSh/0
V9:?09:CW@0L>6h0Mh^U0:ff^02X/;P0VjR`09n[/`2lbm<0RYZV0;k;e`2H[/T0Nio308Z^d`0UDhl0
S;SQ05N3/@38h>d0d^7X0=;Qi`3BgnH0d]oW0<oNi@3>g>H0bm_R0<cJh@3>fN00cMSN0<WIh037e>00
DFN>06InX`1kRjD0Wj^l08jIZP2h`<`0Y:Zh06mfUP1I?F@0Q0hU09D13P271A00Sf]a086?T@1nSi40
O8f=07^?T01cQXT0MHN807J9RP1aQHH206b2PP050766R@1eR8X0I6e[013<2@00o`002oooool000[o
oooo0480DVh=01`20@0H0@804P8200T10@090P402@4002H10`180P@0E@8605T1101L0P@0H@4506T1
201`0@/0L@8:06h22@1h0`X0OP8808L4202E2Q00TT=;0;F[/@3;d]H0bmCH0<cEe`3<dmL0bmCD07Am
N`1C41<0QADJ04D<3P1RJ6H0b]CD0=ONg`3Gg=l0f=kQ0=WNh@3Ifn40bKG109UAHP1J6b@0ASho0::^
[03GgMh0`jRa08Hf@P1]5Ql0=1dM07V7P`2b`Kl0bmOG0=7Jg03@fM/0d]WL0=3Ff@3>e]T0c]OI0<cF
f03;eMP0b]CF0<[Ce`36d=<0]Zne07PG8@2:10X208X42@0D08h62`2@1P/0T`D;09H42`2A0PT0T`<;
09832`2771`0bZV/091lP01TEET0;aXO02442P0f0`L0E08507821@1^0P<0CP4204000@0QP`49oooo
o`T00?l004l0FWT?05m1:@1N:Al0I1D>068Y901WC540H5=J065CF`1YFfH0KemY07MDGP1nAe<0Nb/h
07DM8P1l<2l0NCXi07IBD@1jLVh0NW]e08Z=Q`2=U8h0T9VA08J=Q`1bNWT0AeUa00@PH011I800MX^=
09BVZ@29WJ@0UJV_0:Vk`P2]_lP0SZB]0:>ja`1RQ9L0[<WG08b/bP1CNjT0ZGjB0:DF9@2G5R<0GCQK
01`nLP2J_]D0_mSP0<;IgP33f=l0`]KN0<;DgP2me=`0^m?L0;kBf`2ld]X0/L[E04i]R`19L8X0MINV
07:CW`21WZP0VkO007RAV@1XOXD0HGQm05IbL@1@Kfh0D6iZ04]ZIP1<K6X0BF]W04e/J@19IfD0AfAQ
04MVH@18I5d0B6=H04UKCP08i`H00?l000Sooooo05T00?l004lI101A10@0H`8205X10@1E0@40D@41
05`1101T0@@0J@4407T2201h0@L0N`4908@1302500X0S@8?09H13P2I0P/0V`4909<02@2E0@T0Y08;
0:h42`2`1@d0Z`<:0:X22@2X0@P0Z@890:T12@2X0PT0ZP<:0;073P2i3QD0^a4H0;lD6`3261d0`APL
0<HG6@3<4QT0a14D0;/N7P31;Bd0`c0c0<@d=@3<>SP0bQhQ0<h;4P2f4AL0H3m30=?FfP3Qh>D0h=kS
0=kNhP3Lg^80b;6d08`O:@2`2180/`8=0:l23@2[0@`0Y@8<09l13@2M0P/0W08909X12@2K0@X0T`<<
08H<4P2=6b00Q0D;09<22@2C0@H0T`4909<1202E0@L0V@4809d2302M0P/0V`<<08l430240PP0OP<7
06`21@1Y0PD0JP8306/10P1V0P40H`d5003o0008ooooo`/00?l004h0JD4M06m@?P1S@CT0DcHg06Y8
B01ZATX0KD==06m7DP1iCe/0Ne5N06E;EP1iGVX0KUiY06=DH@2=J780PEmZ07aUK`2CPX<0V8f909F=
R02ETH`0NH>G010aJP2X^L@0YZ^`09^U[02X];`0^<G?09FU/037dm`0Vjfo07ZC]00fHiD0`^So08nc
e`0lL:d0Ghfd0<gRj`3DhNP0dn3X0=?Oi`3Ag^H0cmoW0<?Kk`3@fNL0e]?S0=C8g@3=_=D0a:_80;jI
^02?I8d0ODed08aBL02>Cf`0SU5`09ECL`2:AFH0QdAS08a1G`2B4RT0UP8?09433`2C@4X0U8::08Z7
SP1oRh`0OHnA07J:S01iSXd0MX^;07>9RP1]QXD0JH6106QlO`1gRH`0IWEe01Zf4P00o`0;ooooo`00
2_ooool0F01;I@h05`4001@00@0F10@01`0000H100080@00:@8304P10`1D0@@0G0050642201P0@@0
I`4607022`1f0P`0NP8<07d12P1n0@P0R0<909d93P2<5Ah0[H:90<O9c038d]@0bmCF0<cBe@3?eML0
^;fl05HW:@0^1@H0B4Y70<C>c03Eg=h0emcP0=GLgP3Hg^00f]CM0;F=W02E>4L0MAPQ04<j=P2O[j`0
dmcM0=?8d02BA540IaLO02TB502<VIP0b]CF0=?LgP3Afm/0cm_K0<oJf`3@fM/0d=SL0<kFfP3>e]/0
c=OL0<WEeP39dmD0bM?G0<K?e02QS9D0O@hJ08/42P2?1@/0RP8908/32P2=0`T0U0H<09432P2<0`P0
S@<808/62P2KC4d0VXF;0;2PYP1NDUP0;ALJ02L5300l0`P0H@D907/41@1^0P80C`4304@10@0QPP49
ooooo`T00?l004l0C8h:05lj801K60d0IbDL06U;A@1PDE<0GUAL06=DGP1^DUd0MCm;07@c>`1e<CH0
PCe207e@D`22JFT0NVMX07a/J`1nMg@0Q8N008^=Q`2>Thh0Ti^C08^BT01`NG`07C=P00HSG@20WJT0
Kh6708NIW`1mT9H0/lW@08VMY`2R]K`0Ujbc0;S=e@2bb=H0Gh>R092cdP22Oj80Wb/m0:@[?01L@Fl0
84Eo09^me`34fN<0aMSQ0<?Hh034f>40`]KP0<7Fg`2meMd0^MCL0;SDg02fdm`0]M3L06R7XP0H>F80
O:6f04i`P`1fTZ00KX^E07:>T`2C[:l0N8nE061iN`1DLFl0DW1/04]YIP18JFD0B6QS04aZJ@1:JFL0
BFIQ04MUH017IV00Af9L04QOD`0Gb1800?l000Sooooo03<00?l005<F101P10@0H`4205d10@1H0@40
F04206<31`1U0P@0K@4508422@270@/0Q@4;08@22P270@T0SP8=09T33@2L0@`0U`890941202?00P0
W@8;0:/4202^10X0[@<;0:P1202W0@H0Y`470:T12@2/10`0[@<<0;894@2N4QL0QR4P0:iVH@3>WIH0
cIfH0<B2O`2mF5H0SR`Z071;B@3Od</0h<o>0>?Cd03Ydm00bFec0<LD7P3941T0Ea0D0;:a^03Oh>@0
0P3Ngn<04`3Lgn80e]3C09AAFP2U31L0]08>0;013@2^0P/0YP4<0:013@2M0@/0W04909T22@2A0``0
N@8708P53`2J62<0RA0F09032P2D0@L00P2D0@P01@2E0@T0UP4809d2302L0@T0T`<:0080S`@;00P0
L`8407/31`1d0PD0H04205P10@1T0`80I0l6003o00Sooooo2`00o`00CP1UGAX0Kdhl06a;?@1YACd0
JTU406Q7B@1[ADd0LD]D07YAG01kE5h0GDQC079NJ@1SFfD0Ge=N08YVK`29JG00QVid09F0P`2GRXP0
Uhn:09>AT@16FH40;dn40:F`]`2Y[k<0a<gC09ZV[`2e`LP0Z;K10:nnbP1XPiX0`=O]076H``1FQ[X0
Ii?301aBV`2_e>l0d^7Y0=GQj@3Eh>P0dmoU0=;Oi@3;g>P0?f6B081XS`2B=UL0SRE508`M>P275C80
R18_08H=:@272b80R`XQ08X9802:2B80R`TQ08`97`2;2A`0S@TJ09<65`2A1100T0@?08X95`286R`0
Q2Pj08EOIP1nSHl0N8b?07R;S@1fRXd0MHZ<06n4Q@1aQ8@0LHB607:7R@1_P8409J8N003o00_ooooo
000:ooooo`1H03mL2`0N0@40;P`=04HU9`0=0P401`4000X0000/0P@0BP830581101K0@L0HP8806<1
1`1X0@L0L0<:07L32P1g0PT0NP8907l2202=0`X0W`P?09T;4`2B=Sh0^jJ[0<_De`39eMD0b]GF0<gE
e`2`_;l09bl_04QCD@2__KX0d][J0=GKgP3Dg=h0emgP0=?4c@2/HW00W2@a08HH7`109BD0WJbW0=7M
f`3He]X0XVUd05hJ8@0l;Bl0RI>D0<[De@3Dg=h0dm_M0=7Kg03@fm`0cmWK0=7Hg@3;c]H0/JFa09J1
TP1aM880X:jb0<cEe`3;eMT0_kk80817D@262100R@<:08X12@2<0PX0R`<:08/3202?10T0S`<808`3
1`281@P0O0l?0;R;S021L7L0[:>Y02XT;01[Gf<08`H:03l4201X10P0P@<506l20`1@0@40AP4102:2
0@Wooooo2@00o`00A@11YPL0GR`?06HZ7@1Y;RD0HSHa06A@DP1SDUT0I4AA06TiA@1_<S`0Md5707aN
H`1oIV`0NVab089fO01oKW80Nf]/07aeLP26QX80Rhf:08nCS`2?VI<0R9FB05m_P@037V008dYg06J0
Q02CYZP0SJ>W08>JWP1nUi`0]LS?0:Ri`@2W^lD0TZbi0<CKi`2D[l<0]KS809M<G`2ECfd0@Db903eV
WP2[bn40a=[Q0<KIhP35fN00a]_R0<OHhP36f>40`MKN0<3Gg@2me]h0^]GM0;SDgP2jdml0CW6=05Uo
VP1HNi40L92O08n__01mVJ@0O9FO06f9T01bRXl0Mi2C05]gMP1FLW40Cfe[04YZJ00204YYIP0804YY
I`1;JF@0BVMS04UWG`16I5X0AV1C02FY8000o`08ooooo`19003o001D4`80HP<106810@1L0P40E@40
05T10@1N0@80HP4207811P220PX0RP8>08@12`200@P0RP8=08h12`2H0P`0VP0;09H11`2A0@L0S`47
09X11`2Y1@P0[PT=0:`42`2[0PT0Y`480:X1202]0PX0Z`<:0;<84@2Z2QD0Da@G0;2SWP3OgMP0h>7O
0>;Qh03Rh=h0hm_E0<^n^01gN7L0f=kN0>3Rh`3Qi>@0hn?S0<jHWP2e6B80c18I07H;4@1aJW00em_O
0=kOhP3Mh><0g=oR0=[Jg02`RI40VQ@P0;<4402^0@/0Z`890:D12@2P00d0WP4;09/1202H0@T0P089
0744202D0P/0UP4;08P220290PP0U04909D22@0209@12@0>09L1202J0@T0W04:09832`210PP0Q0<9
05D0001Y0@<0Q0@906P00P1I0@00H08106<@1`0F``08ooooo`/00?l004h0GgTF07A??`1]C3`0JdLl
06M6@P1VB4P0J4Q<06i;D`1dCeL0Me5M05A3D@1DD5d0D4mJ07=KI`2;Hf/0PV9X08I^L@2EOX<0V8V9
09VBT021QiL03bUY05abVP2_/KH0_/C<09ZT[P35d=P0Xk6k0:Vh`P2U]l80[<7?06b<[01jWLP0:5RJ
07FTe@1RSL<0JYC10=;Rj`3ChNT0dn7W0=;Pi`3BgnH0cmoY06n</P1IFGl0QcY60990AP2AB4d0TUEL
09MTJP2HK780W7Qn085SM02JNX40QFM]08MVJP2?KW40T6a`09egN@2BJFd0QeeQ08UGF`25BT/0Q3`n
08@`=P1f@4D0PHb=07b?T@1fRX`0LhJ907J9S01^PXH0Kh>407>8R@1cRH`0MXb?03V9=@00o`0;oooo
o`002_ooool0F00lF@X0@Q/N068e>`1K=CX04@4100T10@0>0@40:08304D20`1@0@<0G08506021@1U
0@T0JP4907042@1c0PT0MP4907P220210@T0U0D>09X6302N1`h0V0dE09eEG@37b</0b]GF0<SEe@2b
`lL0;4=9061eL@30c//0cmWJ0=;Hf`3Dg=h0f=SM0<:Q[@2J<d40XALO070?4P12:2P0X[2/0=GNgP3D
c=<0XfQe05`I801THf<0^<G50=7Lg03Dg]l0dmcN0=CMg@3Afm`0dMOK0<6c_@2NLH40RSmA06LJ:00`
41P0;CDg09FTX`3;eMH0YkJn04=4D01J4QT0R@D;08`32`2<0`d0R`8;08/42@290PP0R`8708h3202=
0`T0Q0T<09A@CP3:][T0L5QL09VAU`0c7BL0=1`R01X41`0f0P<0KPD908D31`1^0@80C`4204<10@0P
P@49ooooo`T00?l004l0=;`705lX401Y<240IQhD06Xn=@1UC4`0J3<j06LR:`1P:2l0KE9G06iIG@1f
IV`0NVUa07AXKP1nLgX0Pg=i07e]L01nM7@0PGn008Z=R@2=Thl0TYZG08nJV`0gCG@00QYW055`T02?
XjH0WK6g06b3R02gcM00UZR_0:Nj`02S]Kd0`mGM0:Bmc029ZK/0ZKo:0:f_]P2`[L4094nI03Ud^`2k
gN/0a]cS0<WJhP37fN40a=WP0<?Li036fn80`mSR0<;HhP33en40_]GN0;kDh02jdml0_M?N05QfU@1@
NYd09DY_07fN[`1UQI80RjRa09Ze_@1nVJ80PY^T06b7R`1NNg`0Eg=c059]L01=JF/0CF]Y04]ZIP19
J6@0Bf]T04i/I`1:If00B6IM04MQF@0]UR/00?l000Sooooo05T00?l005@C0@1U10<0HP4105P10@1E
0@80F@4205/1001W0P<0M04408821`290@X0QP8;08D12`2<0@`0U08>09/33@2H0@T0UP4708l1202<
00H0U0850:831`2W0PP0ZP890:`22P2[0PT0Z`490:d32P2/0`X0/`TA09@;501LAdT0fM[I0>3QhP3Q
h^@0hN7S0=kNhP3IeM`0h>7T0=[Ng`3Gg=`0gn?S0=kSi03Ph^<0g;o20:4Y<@3651T0U0lE034I7`36
bm00g=kQ0=kPh`3Lg^80g=cO0<:^/02E9c<0[`DC0:h23@2Z0@X0YP8:0:<13@2Q0@d0W@4:09T22`1j
1@/0G`<508d33@2C0@X0PP8708021`2C0@L0U@4808`220220PL0S`<809/12`2M0@`0W08<08/32@28
0`X0M@@:06L1102510X0L`8306X30`1O0@40IaH?01G20@08ooooo`/00?l004h0?J@<079??01^C3l0
KD/o06M6?`1TATH0I4M:06a9DP1cBeH0N4mM06e?G01GBE@0LV5[08i^N@2?JG80T6e_09AfM`2EP7l0
UHV609FDV`0^?Vd01R=^08BDZ`2`][X0^;k30;:l``2S[kT0Y[Bn0<?Af`26W:`0Zl;C072A/P2F^]/0
Nj;=0115T@1[Vl/0X[kE0=;Rj@3Dh^P0e=oU0=CPj@3BhNH0d^7W0<?Fh`2/`/l0`lc@0<G>d@39e=T0
b]WM0<cJh02Z_=40HHFa049TT02H//D0UJZb0;?5b`2R/kd0XkBm09j^]P2P[K@0Wjfb08nNX`2=VYh0
S9RJ08RAU@22S8h0NHb>07V=T01gS8l0MHR=07>9S01`Q8P0JGeo0765Q`1dRHd0MH^?04mQCP00o`0;
ooooo`002_ooool0F011G0X0Jd9504hS:`0c51T0308100L1000=0@40;08304X21@1?0@@0E`4305d2
1@1R0PP0J@4806l21`1a0`T0L`8907T11`280`T0U0@;09X52`2O1``0X@T?09@H7P2`U9L0b=CF0;G5
b`0lDUP0GG1`0<C@c@3>emP0cmWJ0=;Jg@33[kL0W59Q09XN:P2L51`0C@dA04a9B@2P[J`0eMcL0<2V
[`2D@4h0KA/R06]VIP36dm<0eMoP0=GMg`3DgMl0d]WL0=GIg`3;`<X0WfUh08LT<01k51h0C@XA02HM
7@1QLVl0Y;>a0<WCd`33c]00RifR05]YK@0o8R@0P@T>08h42`2;0``0RP<<08X3202<0`X0RP4908/2
2@290`T0RBh^0=Fk_02>P8@0TH:408J3R@0T5Ah07@L<02P;3P1710P0M0@808821@1a0P80CP4204L1
0P0SP@49ooooo`T00?l004l09MD7064X3@1W8QD0IR@J06i6@@1X<CD0KBH/06Lg?@1ZDe/0IEUO06]J
H`1gIVh0NVYb07i_MP1oL7L0P6a`07i[KP1nLW40PWik08Z<R@2=Thl0UYfJ08fIY@0?:fd02Rac05Ie
SP1mTIL0SZ:X0:Rla020V:00Yk_00::f_02^_/L0[Kg70:K0cP1WS:40/LkK09Nje`0oPKd0B8C305:=
b031h>/0b=kT0<_Lh`38f^40a][R0<WMi@39g><0a]_S0<CKhP32fN80`]WP0<;Gh@2ne^00_]CO08BS
_014LiL0N9ni07jT^`1bTjH0RZNf072;U`1jUI`0QJ6V07J@T`1[QXX0GGYl059_L01>KV/0CV]X04]Z
IP1;JfH0CF]V04i/I`19J6<0A65K04APE`0ePC@00?l000Sooooo02X00?l005hH0@1[10<0H`8105T1
0@1C0@80E04106H2101/0PD0L`4508812@270PX0M`8907D22P2;0P`0U@8=09X1302K0@X0U@8808/1
1P280@@0S`440:01202Y0PX0Z@890:`32P2a0`d0/`D>0;442`2`1@d0/PLA08T94`1QEUX0g=oQ0=kQ
h`3MhN<0hN7V0<BQ[P2I;TL0S3aE0:><WP3LgnD20=oSiP0C0>7UiP3Rg=h0[VI]0;TH7P2d4QP0@`87
09>CV@3Kgn<0g=gP0=cNh@3LgMl0f]GG09U?F@2V1a@0Z@8=0:P22`2V0Pd0X@4=09h2300209/1300H
08@53@150@<0G08906d32P1J0`H0LP8909422P2D0PT0T0<:07T31P1n0PH0V@8;09`23@2J0Ph0Q088
08@3202;0`X0O0<607`41`1U0@40H`4206@20P1U4@/05/<12?ooool;003o001>04B[3@1cDSH0Ke11
06i<@P1[Bd<0J4Q706Q8CP1ZAe80LdUG07]@H@21EVH0RFM_091`M`2ELWh0UW9k09MdNP2INGh0VXF4
09bAS`1iO9801AeW01<dO02DWjd0a<_?0:JY/P2g_lL0Z[Nm0;70b`2Q/Kd0`=7N082K/`1oW[h0<V6I
0;KPo@1hX=40>Ff_0;gJkP3Dh^T0eN?Z0=CQj03Eh^T0e>;Y0=CRj03Ah>L0cmoV0<kOiP3@gnL0cmkW
0=7Pi`3@gnL0`mKX06fF``2Tan<0JiFi0:2mc`2X^LP0ZKC00;W6c`2a_LT0_L[F09na^P2J[;<0UZN_
092QZ@27VJ00RI^P07R;T01jSY80OI2E07:5R`1^Q8H0KH6506UlP01OLgP0JX2407>7S01OIf@01?82
2oooool000[ooooo01h0BfL>05lj>`0X1`X0600200T10@080@403P0002d10P190P<0C04305@10@1G
0@<0F@0506L11`1]0@L0K`<807D32@1i0@H0SPD:09X62`2M1P`0W@L=09l52`2P3A40UdiD0;W0aP16
FF<0:D140;K4a03<eML20<kFf@0h0<Via02==4<0X1@N0:0B601I30l0EEAD0:Vf]P3Bfmd0d<C<094h
B02>7RP0Ec4a0;o;b@3DgMl0e]kP0=GLgP3Cfmh0e=GJ0;ZQ/P2@AUT0RaPU05`?500N0@@06b0P07R;
Q`2kb/D0b=?C0<[Ee@38eMD0amCE0<OCe02<O7h0N`hD08l52`2;0`X0RP<908T1202<0PP0SP8:08/2
2@221@P0YFe[0<W1``1ZF5`0XIZJ06eZK`0K2a00:``B05/h>`1=10P0M`<708@11P1d0P@0D00104@0
000/H`49ooooo`T00?l004l08N@706<U1P1U8aT0Kcdc06`a;P1Y:RX0JD=506MEG@1YGFL0K65Z071Q
JP1hHf/0PF1Z0818E01kATl0NUMJ07]MGP21MG<0QX9o08F6Q028SH`0TIVI069cT@0287@03S9d06J3
T@2X_<<0KXF@09:]/`2E[KD0VkFn09B//@2od]H0^/cC0<cMiP32hO00H9k709;5j01d[MH0co;o08Fn
g`3:io80dN;X0=7Qj039g>@0a]gR0<_Ni@3:gN@0amgU0<OLi037g><0a=[R0<7Gh`30e^80_]KR096_
c`0=?h<0GXjd05^3W`2<ZKT0V;6m09>/]`2N][l0PIjU07:<T@1/R8`0HWj005QhM@1BLfl0D71/04a[
J01?KFP0C6YV04e[I`1<JVD0A6AN04=SF@16EdD00?l000Sooooo02/00?l006`P1P1c1P80I04105X1
0@1E0@40E`4206@2101Y0@@0LP4408@12`2:0`d0M@<:06X11`2;0P`0V@8=09`22`2L0P`0TP8808T1
1`2<0PH0S@8409/2202X0PX0Z`890;443@2e10l0^@LB0;@43P2c1a00[@<>09P<5@1>>Sl0cm?F0=cP
hP3Nh^<0h>3S0<JIX02k5R80a1@N08dC9025NhP0gn?W0080gn?U02`0h^;T0=Ne^P2`9bl0``lE08H@
5@1OCU80emkP0=SLgP3KgN00f]gN0=[Jg@2]QX`0V`/H0:P43P2W0@d0Y@8:0:41302M0@`0VP8:09`2
2P2D10d0G@L:07I8C00Y10L0<00207X22P2B0@X0TP4609D11P2B0@H0TP4709P12@2L0Pd0V`8=08X2
2@250PH0P`8307h2101o10L0M08206`20P1W0P80H``701K20@Sooooo2`00o`00;@0Qe0H0LDl_06mC
?`1_DD<0L5=:06mCDP1ZCU80K4]B06m:E01hD5d0PeUW08iWL`2AK7P0UW9m09YfOP2NOH80Wh240:6<
S`2MTiL0A561004MN@0_BHH0]kk60:F[[`2na</0[;O00:Vg_`2caLd0X;:o0:6c``1[QZD0[/[U06fE
aP0fL;@0LZCG04Ei]`2jg?<0e^C/0=WUk03Ji^`0f^O]0=SVk@3GiNd0e^;Z0=GRj`020=CQjP0O0=GQ
j@3EhNX0dMgY0<gNk`0iKK80Mj_J08jfe`2fd^<0/lOD0<;Bg02kb]D0`/gI0;k:eP2Q/K`0Z[_50:2_
^`2IZ;80Tj:Z08jMY@1mSiH0M8R=07>9S@1WOH40JWn206QmPP1YOX80CVE/065hN`1[PXD0IW9b017=
2`0;ooooo`002_ooool0F01GLaH0@R0O01h10@0L0`80304200H10@0;0@00;08304D10`160@80C`42
05L31@1O0PP0J@4706X11P1/0@D0L`8907h31`2E1`d0WPH=09/53@2M1`d0W@L<09l93P2=7BD0K5mV
01da=028VIX0am?D0<_Ee`3=f=`0`;K109M2D@2O51d0W10H06L<4P13>C/0/;Zj0=CKg@3Cc=80XUAR
09LM:01B5AP0UiNF0=KNg`3EgN00e]kP0=GLgP3BcM@0Y6in08L/>`1e5B80?`T?02HQ8P1?Gf00S9fM
0<3<b@3:eMD0b=?E0<KCe@37d]D0am?D0<OBe02m^[d0LA/R08X62P270PL0R`@808X22@2=10X0S`D8
08h7301l4A<0`JNY0;N`]P1OBDh0/K6a096CUP0^8bH07PL=02`<4P1<10L0M`<808H32@1d0P@0D041
04<10@0dA089ooooo`X00?l004h0IbX706Xe:@1R8aX0KCT_06Y=B`1TEed0HEIN06IKH`1_GVP0MUMQ
07Hd@0249C40PQHS08</=01iEUT0RGAe07ebL01hMG40QHN708V?T02=VYd0<Dal00<UO@0ZChX0SJNb
06Z4RP2/`l/0Rj>]09B]]P2^aL/0bmcO0>;[k@3Nk?80`M[W0=K/m`37i?@0k?co0>Wfn@3Ainl0dNch
0=g/m@3KjNl0eNO/0=;Sj03?hNP0c^3W0<[NiP3:gNL0a]_V0<GIi@32fN@0aMST0<7FhP2oe^80[/SL
05b:_02<^=X0H8^/0:>od@2?Z[X0SJJb09Zd^`2BZ[40T:V`08FNY@1_R8/0LHf>05mkN`1IMg<0EGAb
055`K01>JfL0CF]W04mZI`1<J6<0B6IK04IMCP08i`D8ooooo`1I003o001S6`80MPH306H10@1J0040
E04105L10@1Q0@80I`4207H10`230@L0S@8=08P12P240P/0T08>09X23P2L0@/0V@4:08l12@280@D0
RP0208l11`2G00P0YP890:l33@2c10h0^0@>0;L63`2d0`h0/P@?0;D;502T3AD0@QhT0;W0a03Mh^@0
gN7S0=_Nh`3E_<40]AhY0<dB6`2j5B00Dbhk0=OLh`3PhnH0h>GW0>;TiP3Ue]L0]4M?0<D=5@2/4QX0
DBH[0=7Ff@3Ig^40em_N0=OLg`3Ff]/0`Zfb094A7`2S0@h0Y04:0:812`2M00/0W@8:09X11`2H00T0
V08<09LU;P1oBE80@PlE05/21P2<0PX0TP4809011`2E0@H0UP4509L01@2I0@T0V`0<09/1302=0PT0
O`8507`2101l0PL0M08407420P1[0P40IP4006L?2@0F`P002?ooool;003o001>01C/101eC2P0KeA1
06mC@@1aDdT0Ke9C06]ADP1]CUD0KTaE07QBG@23FVL0SVIc09=]NP2FLW`0Vg^10::3R02TQX/0XHbA
09ZCXP0G;7P012F604mZVP2Z/kH0][c10;6i``2T/[X0`M3H08RHXP2nc]H0Z;[709b`bP1BMjT0Uk[R
082_f`2TeNl0XMG/0;;GkP3XkoD0lOGh0>odm`3UkO@0h>_a0=cWk`3JiN`0en?/0=STj`3Fh^/0e>;[
0=CRj@3AgnP0cmoZ09o5j@1fZm/0Q:_=09Zmf02X_Lh0]/OF0;K7e@32d^40[;c=0:k3d@2eb=40Z[S3
0:Be_P2M[KP0TJ6[08>FW01dR8`0L8B706j3QP1`Q8@0Jgj206IkO`1KM7L0GGEh06AkNP1WN7P08j0K
2oooool000[ooooo03X0CFT@02420@0N0P80504200l20P040@401@4002L30`1:20/0B0<604h11@1O
2Q00I0<806P11@1Y0@@0J00407822P291@/0U`H=09P42`2G1@`0U`@;09H42P2H1`d0L@dE03lh>02O
[Z/0am7B0<SBe034d=H0Oi6K04lmB02D61l0RA4G04483@1>B4/0]<720=KJg@3;/[d0XDYI0:LJ802=
ADL0V9VF0=3Jf`3Ign40eMcN0=WMh@3=^/D0TDUJ06DE800g2`h09b0P05i]K02Y^;L0`lkA0<kGf@3>
eMP0c=CI0`39d]H06`38d]@0am;D0<G7c01`92/0Q`D;08D21`270`L0R`D:098;202F4@`0P`D609AD
E032_L80FTM>07QSIP2DVYd0B4E;020@5`0P1Pd08P8705842P1g0`P0Q@<707T30`1D0@40@P4003A4
0`09ooooo`X00?l00240IT4>05`U5P1S:AX0Je9606MIF`1QEE/0GU9I069BFP1^B540L2Td07`U;P24
8RT0QCHj08YGF`21KG00Q7Mh089jNP1oOG`0PXF408VAS`29UZ402bYa00L/S00dGI40WkBk09b_^02S
^LD0Z[o80<WIg`3RkO00jo7d0??gn@3]l_@00P3hool0903[n?d0]=[W0>OgnP3fno`0iNkd0=gXl@3G
iN`0enK[0=GTj@3?hNP0bmoW0<[MiP39fnD0aMWV0<?Hi031f>@0`mOS0<;DhP30dn40^<kQ02]ER`1?
OjT0Nj:l09bkbP2I//40Y[o;08n/]`24WJH0SZ>/09R[/P2?Y:H0P9NJ06b7R01PNg/0FgQi05=bK`80
DG1Z00D0DFiZ04m[H`1;J5d0Af5B01G74@08ooooo`1I003o001]80@0N@H206P10@1M0@40E`4105T1
0@1S0@80J042078210220@P0S08<08/12P290@X0T04<09/23P2P0Pl0W08<09<22P2<0@H0RP050901
2@2F0@P0X`<<0:h43P2c10h0^@D;0;H52`2b0P/0/`D?0;<43`2Z2140APXC09BHWP3Jg^40g>3R0=cQ
i03Pe]T0]Ci60<`C6`3951`0FA8L0;Rj`@3Nh^H0hNCW0>3Rh`3UhN80]fU_0<HB6P2n4QX0E@dE0;Zm
`P3Kgn80fMcO0=SLg`3Ff]`0clK:08dT<02T1100Y08<0:032`2M0@X0W`8;09`12@2I0@/0V@4<09D6
4`2H9S@0RaHS08`43P2C0@X0TP0609<1202D0@H0UP4909T12@2I0P/0VP4;09X22`2<0PP0N@8507L1
0P200PL0NP8706810P1T0P80I@8106D<1`0G``402?ooool<003o001=07Y>8P1_DT00Le9607ACBP1^
D500KU1C06]?E@1[CUT0LU9L081GI@2=Hg40Tfmk09MgP@2MP8P0XH>;0::3R`2ORHh0P82L00@QO@03
9880NY6f0:R^/`2j`<@0]Kg40:nja02W]Kd0b=;I0<cHh02lcn00^M7U0;k?h03AkOX0cOCo07[0i02a
h_D0hO7i0>ccn@3^l_H0i^gc0>3YlP3Oj?00fNK]0=GTj`3Fi>/0e^?[0=ORj`3DhNX0d^7Z0=3Nj03A
hN`0ZLGU04R0`@2_eO00XL7M0;O>h@2Z_ll0XkC60;?4d`2X^/L0^<[F09nb_@2KZkD0WZbd09^Y/`21
Ti`0P9>J07R<TP1aQhX0MHf?07R;S@1nSi<0Kh:705idMP1LLG<0I7Qj06=fMP0dQ2d02oooool000[o
oooo01@0=UH702020@0M0P80404100l20P040@40200002/210180P@0DP4305D10`1N0PL0H`8706D1
1P1X0PD0J04506l11P2<10/0T`<:09H52`80T`@:02L0U0@:08@:400g6Q/0YK6_0<_Ee@3;eMH0_/g@
055YLP0lDeT0W9nP06<Z;P0h8B<0JgMg0;_7b03Fe]`0/G^909`U<P2_51X0ZBX/0<B`/@3CgM`0fMoQ
0=WOhP3Df=`0[iRT06lgA`0b3aL0@4E606j0O`2W^KH0am?B0=3GfP3?e]X0d=OK0<kGf@39e=L0bM?F
0<[De@38d]D00P36d]<06@2`Zk00M1@P08X430260PP0QP<;08T71`2I6A00P`<507LA4P2oZjX0VYBJ
03/P9`2SVil0XZ^_04m0A@0R1`d0;0XA02L4201A0PH0O@@;08H2201n0P@0FP4104H10@0fA0802Ooo
ool:003o001>05IX2@1B70/0JdXl06YLE@1VG5/0IU9H06@mAP1V@DT0LTI=06dR:P1i>d00PdaC08Q?
F026@4d0PfE/08ImOP24Ng/0QHB208F:RP2=UYL0SijY00haN@01;YD0Hhjl0:nka02lall0c=SO0=OR
j@3`moX0h>S^0>gcmP3`m?L0o?ko0>3]m@33f^D0hO7g0>_mo`3Il_`0go;h0<oZl`3Gj?<0e>?/0<gP
jP39g^P0amcX0<KKi`34fnD0`=SS0;oGh`2oen80_MCQ0<;Eh030d]h0_=7O0;K?g@1iWKP0AVnF05n;
ZP1MQj80M9FU096^]P2?[;H0SZZe09Vb_@2<Xj`0R9bQ08:GW01^R8/0I82105ejN`1GM780FW=`05Qd
L@1DLFh0EFeZ059ZI01:IEP08JLM2?ooool01`00o`00L1h407l60P1[0@40GP4005`10@1Q0P800P1Y
0P<0>`1^0@D0P@8908/1302;0@/0SP4=09<02`2L0Pd0WP8>09L02`2A0@T0S@4808d11`2B0@T0U08;
09T1302Y1@d0]@D?0;L33@2d0`/0/`@=0;463@2`1@h0Z`DA06P84@10>d@0a/gA0=cQh`3Kh><0hN;S
0<9kP@347B<0cQ@I08PA5P1HBE80e]gP0=oTi@3Oh^@0hN;U0=6W[P2k6R<0aa4F07`<502=RXl0fn3S
0=_Nh03Ff]h0f=_O0=OHf`2CC5H0X0XG0:@6402R0`h0XP8>09l12`2K0@X0V@8;09T12@2I0@X0U@4:
0080U@4;01<0U@4909<1202D0@P0S08608D11@2E0@T0V04709L12@2H0@/0TP8908011@1o0`L0JP84
06d31@1R0P<0G`4206P20P1S20<0;8D100Sooooo3000o`00C@1TKaT0LDhj07EBA@1cDd`0JTi>06a?
D@1ZC580IDMB06M;F020FfT0RfA^099`N02GNH@0VWj9095gP@2PPhT0XhbC05YRS00698P02Bj607b@
/02f^kl0`lO<0;Zma03=dML0e=SN0=[Pj03Rk?80hN[c0>[ho@39iOT0IJ[G0;?Tn03Onol0Zm[]0<_X
m`3Zl_P0mOSk0?;gn`3Wk_D0h>[b0=WWkP3Fi>`0d^7Z0=?RjP3ChNX0e>7Z0=7Oj03@h>P0dn7Z0<7C
h`1iWm00JYW;06Z=/P2_aMP0]<KD0<3BgP2^_ld0YKK50:>d`02Q/k`0X[6h09BRZ02BX:L0QYVP07J:
T01_Q8T0JX:607V>T@1eS8l0L8N90768R@1RNG`0IWYk06AfMP1PLg80A7Dm00_ooooo000:ooooo`0l
031A100P0@407`8101P10P0=00001@4100P0000]0P<0A@4204l20`1C0080G@4705011@1D0PH0I045
06L11@1`0@H0R`<808l21P2C1@T0S`880903202>1@X0FPP=061UI037d]80b=;C0<WEf01bRY40C6M[
0;C4``37dM80=ci108FEUP32d=40f=_N0;RAWP2N7BX0^1HL0;TC602cA4T0b/C70=WRhP3Gh>40en3T
09jY/P0_9c405a<F05Q[J@2/_;`0b=GF0=3Lg03Bf]`0d]SK0=7Gf`3@f=/0c]SJ0<WFf036e=P0aM;G
0P38dmD06P37d=@0SFii07d;5@2;10d0R`<:08D31`2I7Q<0Q@X507h52P28@T00`L?2071PIP1^DUH0
YJRY08F@TP0b:Rd07@P>02<5300c1@/0H@H:07X11@250PH0O`4306800@1>0@40=T@22Oooool:003o
001>05Ek2P1E:Q@0JE=306]NEP1aGEd0HBX`06hE701_<ST0KdeE07MBF01oCUL0O2Ha08h]=@266B80
QUAJ08^2Q@29Q8D0Rhj=08nFV02NXZ@0YJZb03IJV@04@Z`0N:;?0=GMi03Dg>D0f^?[0=kVk`3Oinh0
kO?e0?Kko03Vk_40jo7e0?;gn`3^n?h0]m?Z0:;@l@1NY]L0b>co09K1g`38gn`0b]gV0<GLh`33fn@0
`mWT0<GJi@2oen40_mKR0;kEh@30e>40_m?O0;kBg`2ld]l0^m7K0;S@g01SQZ009del06F@Y`1fVZ`0
Vkc:07^KY`1`SIT0NiNS07fJY022WjL0P9ZQ06n7S01VP8@0H7en05IeMP1ELg<0FWEf05agM01KMg80
FGA_055ZH`1?JUh0:iDZ2?ooool0;@00o`00Mal208460P1/0000H`4205`10@1K0@40I@4306D00@1]
0@<0P04708L0202>0@`0T@8<09<02P2N0P`0V`8<09<02P2@0PT0SP8908/01@2A0PT0UP4909H2302M
0@T0/P@=0;@22`2d10/0/`@>0;863@2/0@X0[0<>07l73`0N20d0/KJm0=cPhP3MhN@0h>;U0=F_/P2c
92T0dA@L0;4F7P0a1A00a<S>0=oTi0020>3Si00Z0=k;cP2a9c00ba8I09h?601YFf40f>3S0=_Nh@3I
g>00em_N0=WLg`2NKGL0U`dM0:<54@2R0`l0X@4>09h12P2J0@T0V@4;09X22`2H0PX0U04909@12`2D
0PX0U04709@11@2B0@D0S`8608H11@2B0@P0U`4809H11`2H0@X0T`4807`1101b0@D0JPD805`20`1Z
0`H0IP8306P10P1V2`H0;hL22?ooool<003o001=061m5P1^CCD0Le=307AECP1/CTh0J4Y=06M:D@1Q
Ae00JDaH089OK@29I740Sfig09IfP@2BMh80Pfmk08]dOP2RS9X0>4N4008SS@08<8@0X:c50=;:c`3;
aL`0gmkS0=KHgP3KgNL0g>?/0>;YlP3ZlOT0^M3V0<oWm03Fm?d0SlSY08[9k02Yh_D0`^Gg0=cXl@3K
iNl0fNC]0=OTj`3Ei>X0e^C/0=CRj@3AhNT0d>7X0<kPj03=gnP0c]kW0<kMi`3@gnT0b]WV08j[c021
Z=@0[lgX08NXa`2P]<L0Z;W60:Via030d=`0Z[_609j`_02BXjd0UJJ/08FEW@1nTIL0NXjE06ImP@1Q
NWd0N8^?07F;S`1^QHT0KXJ807:7S01ZO7l0I7Mf065hM@1BF4`02oooool000[ooooo05P0<4l20282
0@0L0@405@4200`10@060@40204002/20`160P<0D04305L10`1M0PL0D08704d1101Q0@H0J@4607D1
202>0`T0T08609432@2@0@X0T`H=07l?50107al0Z[Je0<OAd`38e=@0[/72055/KP2a`/40cmWI0<[E
e`2?XJ<0a=7A0=SLh03?[KL0Z30l0<0E6`344QL0a1@H0<5AE@3Ac<l0fn;S0=_Sh`3:em`0=4eE04QN
H02@Xj40`M;A0=;Mg@3Dgn00eMoP0=;Kg@3@f]/0dMWL0=3Gg03;d]P0V:Nb05I^NP1nTi`0bMKH0<[C
e`2_YZl0Nblk08D73@2910/0R`<:08`=202I8180P@D6070:302^R8H0_/74050b>02COgh0Xj^[0:>_
/@1CD5@06@T?02/A600c10X0F`<507T11@210PD0OP8406L10P1B0@40>4<22Oooool:003o000Y03^P
1@1J>AT0IE9106aFC`1a@d40Ia<F06dK7@1`?d<0NDIA07dmB026>D@0OA`U08Pl@P28Ad`0TVQ`09J6
S02JVYd0VY^O0:>TZ02d/kD0aL;707ZE_`09DK@0NJ_H0=WSj03Nind0dMkU0=SVk@3Eh>P0e^7[0<[K
iP37fN80cMo^09Nac@32foD0PJcB0:7=k@1l[]T0@hK7082be@36gNH00P38f^802P37f^@0a=WS0<?I
i031f>@0`=KR0<3Gh`30eN<0_]?P0;gEhP2ld^420;OAg`0G09>ca01/U;P0B7:L03UQO`1]TJ80LXnL
08n]^02F][h0NiNQ06j9T01SPHH0IX:606V6Q`1ROh00DW5^055_K`1BL6l0F7Eb06B1O01SOG/0EVm[
051[H@0iQCP02?ooool0F@00o`00NB4408@70P1a0@40J08206010P1Q0@80J04406/20`1_0@<0Q08:
08/13@2?0Pd0T08<09<02`2K0`d0V08<09802P2B0@X0T@4:0942202D0@T0W0<<09`33`2L0`/0[0@=
0;832`2b0``0/0@=0:/32`2W0@P0Z0<:09D94@0a0@H0P86<0=cQh`3PhnH0g^7R0>;@d@2aATh0caTP
0<dK7`1T2A40WIJL0>7Vi`3RiNH0hNCU0>GNh02hBU@0caHO0;`E7P1L>400bmCH0=cQi03IgN00em_N
0=SLg`2hVJ00RQDS0:H6502U0`l0Y0@?09d12@2L0@/0U`4:09@12P2G0@X0UP4:09<02P2C00P0TP07
09401P2B0@H0T@4709011`2B0PT0T`4809@2202H0PT0U04708H31@1d0@@0N@<706@10P1U0P<0K@84
06`20P1W2`L0<HT500Sooooo3000o`00@`1BTa40Kd`e07=FA01dF4`0JTm;06I;C01ZD5@0Nf=Y07MI
H@23HV`0Qf9`091_N@2DM7d0UWR307]QK02?M7h0YYJS02Q0R`02:Y/02SF:0:bhd@3Dbll0g]gQ0=OH
g@3IgN80h>?Z0>GZl03Sj_80f^;[0>K_n02`cnX0TlG]04nGd`1k_>T0[mO_09g3g`3Fhn`0eN;[0=CR
jP3ChNP0dN;Y0=GSjP3Ch^X0d>7X0<oRj@3>h>P0c^7X0<kPjP3>h>/0c>3/0<kRl02/c>L0;6Ba08:a
hP2=/m80`=_^0;;;h02fcND0XkgC0:2gaP2/_ll0Zko;08nS[02=WJL0QINM07J;T@1WP8@00P1VOGl0
201aRH`0KH>80767S01fRXl0M8R:06MmN`1SN7P0De]A2oooool000[ooooo05P0;dd202820@0L0@40
5P4200h10P040P401`4102L30P150@80C`8405H10`1N0@H0H`8706021P1W0@H0J`4607d2202C0`X0
T`8909L42`2I1@`0RP`?04092P21QH<0am;C0<WAe02Y[K<0UZFX0;[:b@3>fMP0dM[K0<oJg02ob/`0
hm;I0=>8V039=d@0hB4T0>XV8`3_;BX0kBlZ0>IRH03cj^/0j>g^0>W]kP3Pi^L0dM[K0>3Zj`3QjNX0
hnWY0>;Xj03Oi^H0h>KW0=cQh`3GgN00f=ON0<F/^@1^Cf80:38m06f5RP2ib<X0c=GI0;6NZ`1m:c/0
R`/E08`42P2:1@T0RP`50:H_6P231`D0MPT;09MPG@36`<40X9RL06A3A02]ZZT0VZZY0:6`/@0O8BH0
50X>01X7300/0`L0H`@:07X11`1o0PH0MP4306<10P1C0@40>4822Oooool:003o001>04J/2P1K?AT0
H4Xh05l[9@1_8b80K2PZ06di?P1W8b/0M1HQ08@[=01m?4@0PDmE08aEH02@DUh0ST=>0:j4R02[Yj`0
ZJ^^0;Jj_`2n`LD0`L;90:jid@0?CJP0K9gA0=;Lh`3AfnD0`]7K0<7Cf`2eb]H0ZL3?09Ra_@2^am<0
[/WH09fkd02WaMT0Z/[S02MYYP2?`nD0N;GM0:cJlP39gnX0b=o]0<CRk`2ohO80/]gd0:CFm@2Dco@0
Q/?b07bil01d[nX0JZGR06FPg`1PV=T0G9;D05R<d014N<407EB[01E8W@1JSL@0G8Vg0627/@1PRJd0
JI:]07NK[P2;ZkX0OIZT061mP`1ROh40Ih:605AbL@1?K6X0CVaZ05EcK`1HMG80JXJ5082GUP1HLV/0
?HY02?ooool0F@00o`00NR@408P90`1i0P<0J`4106@10P1T0@<0J04406l31P1b0@H0O`4:08D13027
0P/0S@4;09812`2F0P`0TP8:09812@2C0@X0T`8:09<32@2C0P/0VP8<09`2302M0P`0X`8;0;843P2d
1@l0[0<<0:L32P2T0@L0Z`<;0:T84P1/2140DTUB0=SMhP3Nh^<0gnCT0>GQh@3U[[<0cS0e0>HT:02k
92l0PeYS0>?ViP3Ti^L0i^OY0>GVi`3@RI00e2H]0=XJ801S51/0blkC0=kTiP3Jh>40f]kQ0=WNh03C
b<d0SCQ40:X<602/0a00Y@4=0:<13@2M0@X0VP4:09T12P2K0@/0V04:09H12`2D0PX0T`4809811`2A
0@L0T046090120270PL0RP8809P22`2G0@X0TP8807/2101g0P@0Q08707D2101V0P<0J08206d20P1U
0`40<HH300Sooooo3000o`00C@14Z0`0M50d07AEAP1dEDX0Ke9:06U@D01mKg40_[Nm07YQK022HF`0
RVMc095^N02FMX40VGV40:5kQ@2gSYT0[Ij]01hhR`04<Z/013BG09jbe@3Edm`0dmCK0=WNi03Oi>X0
f^7Z0=OSk03@g>P0dn3/0:k3g02;[mP0S;WS0:kKo@19Pl@0FiSF0;?@iP3Eh^/0e^;[0=KRjP3Ehn`0
d^C^0<cTl@32h_<0]]oh0:CFmP2Jd?@0SLSe082jlP1a[nl0I:;Y05RIi@0jO]X04e[@03QheP0nMm00
?WG@02iQ_P0cHkd0?6c204=__P1>N<40@FZ/04ecZ`1HO:`0I8JZ06V9XP1SOXh0JXJ<06j9S01dRhl0
L8B;0767S01_PhP0MHZ=0725Q`1UNGX0F5mG00_ooooo000:ooooo`1H04@n200P0P407@8101T20P0>
0P40108000@0000V0P80@P4304h1101C0@<0G04605l11@1S0PH0K@8807<32@2710/0U@@909T42P2O
1`/0XPT?07HB4`1EAdH0_<G50<WDe035^/40K41<0;>X[@3Bfm`0d]cM0=GOh03GhN80hn;T0>6?VP3M
>440mS8d0?hj=@3m@SP0oda10?iCA03fM6/0onSZ0?gno@3nooh0o_kn0?[ko@3^l_@0l_Cf0?3cl`3[
k^l0jNg^0>K[j`3Ri^L0lMgX0=VEZ@2>?U40;QLQ08nSY033eML0d=SM0<g6d02E@E@0VP`J09/53`2D
0`/0SPT50;A08@2E7@X0Q0@707`Y:03?_kh0_/C907YUJP25K6`0TYZK09j`/@2X]KL09R0U05]:C00J
1@X0<P/?05@11P1_0@@0N`4507<10P1Q0@40D@0003Y20@Wooooo2P00o`00CP0Re@D0H3hJ058c8P1B
7Q80HbLN06Lf>01S7R@0IA0G078[<@1mCUD0PeEO08LiA`2?9SL0VcI209mCG02QKW<0/[:g0;W3aP2g
_<80^;Nm0;Za]02cZkD0:4fF05B1_02aam<0/<C=0;32c02hbmH0SJB_0;77c`2N]<40^m3J0;gAf033
gN/0S;750<cVl@3=k?L0a^kj0:CPkP2Ui_T0Tm_i06g<n@17^oL0;Z_e01VBkP0@P>h02X3c00I^k00P
F=00>TVd03m1Y`15>Yh0AcJF04D_S00m9h40=b1e03@QMP0_8WX0:b9h02<OM00M8W@05B5d01<WNP0C
;Wl06S^60252O`0^D7`0@65m05IgRP1LO840D71_04m]J`1?KVT0EGAb07BBT029XZ@0F79`04]HB`So
oooo01<00?l0088X2@2;1`@0O@4306l10P1V0@<0G`4206410@1[0@@0K@0407X120200@`0P@4908/1
302B0P`0T@4<08d12`2@00T0T@090080T@8800P0TP4:09P13@2G00T0X08>0:@1302]0`d0/`H@0:h4
3080Z0480280[@8;0;854P2K41/0BB@`0<oDf`3Ri^L0h^OW0>GUiP3fh^<0efma0>AGF03LHVX0[Gf4
0>g^k`3Xjn`0in_/0>OXj`3cc=00gDE;0?4/;P2?5AX0[Z:Z0>3Vj@3MhnD0g>3S0=_OhP3LfM`0[Fmi
0:`B7P2i1Q80]@DA0:`33P2T0Ph0W`4;0P2K00X0102K0@X0V@8;09L12@2E0@T30981200?09411`2?
0PP0T04:09`12`2I0@T0S`0508821`1i0@<0P08506/10P1Y0`<0K04206`10@1V1@80=H/700Sooooo
3000o`00C@0Re0H0MU4c07AEAP1eEDT0LU9;06Y@C@1[F5/0SW^607ULJ@23HFh0RVId09IcO`2LNhP0
ZHRC0:V4T02URYD0]K3001XjSP03<:/02CjW096Zd`3>cMH0c]7H0<kCg@3;d=`0emgY0;W5d@37dmd0
`LoN09N^aP2^bN<0:e^J04El]@2C`^L0KKKV0:cNm`38j?D0f_3g0=oen@2iioT0N/oh04Jfm@0YY_L0
5YGc01Qnj`0fLN80@V7E04iBa`1MA[@0I3VS06TcV`1a;i40MRV507PUNP1j9GT0NBEh07@NL01]7Fd0
Ia]^06@KKP1M76l0Daid04TQO00i8gh0:2>401TSOP0E9WH07SUl03EER@1CM9D0IH:G06n:U@1[Q8T0
Jh:50727R@1fSI40I6QV00_ooooo000:ooooo`1H05T[400P0P40704101H10P0:0@40108000T1000Z
0`80@P8204h10P1G0@<0G04506421`1[0`T0LP4907L12P2?1@h0V@@:09l62P2T20d0XPdA06l_;`2T
Z:P0bmCF0=7DeP2`LW/0R2Xf0<^a]P3HgN00fN3S0=WRi@3Si^X0lkW20>a6D@3k=CX0oSLg0?i1?03l
B440nde40?aEA`3dLVP0oNCT0?oooP3no_h0n__j0?Win`3cm?L0l_?f0>k`l`3_lO@0k>g`0?3/l03b
amL0cG2708@[?01D<ST0Z[>e0=3MhP3EgN80fm;N0;U[O02`6B<0/P/A0:h:402Q20X0[C0D0:P]4`2A
2@D0Q`X<0:UiN035a//0`/?<05Lb>P2[W9/0R9FG092RY026T9<071@H01T:3P0E0PD0<@h@04h2101]
0P<0M`4307420`1K0@80D@4103]30PWooooo2P00o`004@0Yf`X0HS<=04dQ401F;1T0HR0F06TO8@1[
9BT0JBhd07A<E@1iHf/0NdMA08DK9@2B:c40SCe109moPP2[V9`0[jbb0080Zjb`03/0ZZZ`09jOX`2:
TIL0=eJ:03mUU`2V^L<0]LS?0;76d02`a<h0`]WQ0<KNjP2mg>h0[Mge08C;l`29dO@0O<[`07O=m@15
]?<08Z7^01fNj00OX>@06Z3W01NXl00AZoP02ZGl00VLo008S_X01h?i01ebk02K>hP0cB140<TJ>@37
5S@0`A<]0;H@9P2Y3B<0XP`Q0987702@2200R`PP08<K<020<4P0KPl`078;;`1Y3SX0E0do040?A@0Y
3T/06QAE010KGP0F;fX0:Tef049TNP1DM7L0EWAc06F5Q@2<YZX0DVa]04=nA008ooooo`1I003o0024
:0H0S@P207d20P1^0@80IP8205h10@1R0P<0J08406`11@1j0PX0O@4;07d020270@X0SP8;08l13@2<
0@/0R`8:08l22`2@0PX0S`8:09812P2G0P/0V`4<0:423@2S0@d0Y`@<0:l53@2g20h0_0T?0<094038
3AD0b0lF0<TM901g7BT0fMKL0>CXj`3Xjnd0jn_^0>o]kP3jjNT0onc/0?obl`3onOT0no_l0?Kgn03c
m?H0l_?e0?[Zk@3/MWP0nTU20;l[;P2?JgL0j>_^0>?Vj03Pi>D0h>?V0>7Pi03K[KH0]b0^0<T95`33
1a<0_0H@0;433@2W0@`0X`4;09h12P2L0@X0W@8<09/12`2J0@T0V@4809H12`2B0@P0T@4709@12@2J
0P`0W@8?09/12`2F0@L0R`8808811@200PD0K08306H20P1a0P80K04106030@0kO`X02?ooool<003o
001=02GF1P1eCb/0LeM307IFA`1aDdX0JDm>06E<C`1eEel0NEUV08QQKP2AJWP0WGV60:>2S@2[SIH0
]IRQ0<Fe_02l^<X09DBF008_Z`03<jD0KH^l0<O:e@32a]00a<_C0<cCg@2f_/T0]L790<kKi02O/;/0
[<GK08VZa`2len`0d_Co0;OZoP0n]O00>k[g05k6m`1oeOP0Ak3[01VIj008U^l00Hkb006:mP03PoH0
EekC0;dfS03F;Vh0gBUH0=hPAP3M6C`0eA4f0=4?;@395bh0_1P_0;XE;@2f93h0[a4Y0:TI;P2X2R@0
[`@M0:D<8`2H4c40UA8e08l@=`273400NPm8064AE01156806aAY00/LKP099W009dZ005YgT@1QNGl0
I7Ul07R=T`1POUl02oooool000[ooooo05P0ERXA01d10@0K0@405P8200H10@020@40200002/20P18
0@80D04205P1101P0PL0IP4607422P1h0``0P@8=09/63`2S1Pd0Z0L?0:`93P2S5QT0XGn00<kDeP3A
emP0d[Zo07LY<@0^1``0][Rj0=GLg`3Ig^80f=kR0>[PiP3ICeT0o2d_0?d^;P3m=300oChi0?m<B03n
CdT0oU9;0?UmM@3ol_40o_kn0?gnoP3moOh0nOWk0?Kgn@3bm?H0kNoa0?O]mP3ldn40l8fM0<e4E@1^
=d40W9ZL0=CNh03Hh>@0h=_T0=J/_P2kDVL0aAXV0<LB5`313QD0^PhA0<0b4P2j<A80YP/90:093P2H
?S`0clO60<G:d@2VTi`0FRT]0;Bc]P2>WZ<0Z[Rl0:6Z[@0D3a<03`<701D31@0a0`D0G0<607D31P1h
0@@0K@4205L10@1?0@40?4812Oooool;003o001=06HX1`1O:AT0H24F06PA3@1W7ah0JCe006hh@01Z
5b<0PUIN08UYL01k@4L0TVM[09b;T@2KU9X0XYVN0:RPYP2RXJH0VYbQ09RMX`2@VI`0Q9BG04]XS@19
LZ40[/GD0;[?hP2Yc>`0Q[GW066SjP0lT^`07H3Y00mok`04ROL01Y7g00:@l`08WOP05J_g03Jmm@1X
d?P0P=Kh05S4m00]ZoH05YCa00Ukj@0:K><03E_F01A8``0X?:`0UAeF0;L<7P2_21P0Y`DE09d95@2C
72D0R1DU08L85`1k41T0KP/F06`:5@2^NH80UGV709]VM01k1a<0O`<=07h23@1l0`h0M`<@07<5601V
22H0C`/f034DB`0F75/05S9W03iQN`1[RY00NYJI04mZI`0kU3/02?ooool01P00o`00RBT:08d80`1g
0P80JP4106D10@80HP430540I@4207410`1j0PP0NP4:07`12P260@`0S08<08`23P2:0PT0R@4908X1
2@2?0PX0T04909H1202S0``0Z0<<0:l33@2e10d0]@@<0;d7403?3aH0iA/N0>XK7`3a8RH0mR/_0?Tf
>P3S?4L0ei>X0?K/m03al?<0l_;e0?;cm@3clo@0n?Si0?[jo03jno/0nocm0?Wjn@3hn?P0m_Gg0?_E
f`3]HfP0ndPo0=hf=P1d=440hn?Y0>;Vj03RiNP0h>?U0>3QiP3_e=d0_SQ60=0>6P3>31H0c0/E0<<8
4@2i1@l0]0HA0:/2302T0@/0Y04<0:D2302S0`d0W`8<09/22`2D0@T0TP4909L12`2L0@`0W@8>09`1
2`2I0@T0S`8807T21@1Y0P<0K@<406<10P1]0@80K04105d10@19CPT02?ooool<003o001=00[f0P1h
CRP0MeI307QGB@1dETl0K59?06Y@D`1`DUP0NeUT08YRK`2ILgl0WWf90:F6T`2YSi/0/Y^X0<N`_02m
Z[d0:cn?008TVP05:YX0KH^o0;Jh``32a</0_L;80<35c`2naL`0aLgG0;?5e02Uamh0Z=Ge097:k@1`
^o40C:oe02JCk@0DU?8038o^016RkP0`[>T0Ekc/06K5lP18`oP08[;i00bLnP0@RoT0QE2f0>TSC@3]
6Bl0ia@U0=X?7@3F31`0b`HJ0<H6603;B5<0ijR`0:I7FP3GVjX0^FUk0>blaP2T;TH0ZP@D0;YAF`3B
ZKD0bij/0<6:VP2VAe`0U`DL094:7`244Rh0L@`e05X@A`134E@09aEN01@SI@0`CW80FWMo06UmPP1=
RTP02oooool000[ooooo05P0CbD=01d10@0L0@005P8200`20@070@402@0003<30`1D0@@0F08505h1
101U0@H0L@<908@;4P2>41H0V0/A0:d:3`2c20h0]@X=0;`=402e:bh0g<340=GFf03Fe]P0SX>303ll
?P2JY:D0cMOK0=;Kg`3Ggn40emgP0>?6c@3=<3L0jB0S0>dR8P3^92<0kbLV0?<];@3d;c40lbla0>U7
C03jfml0kNoa0>W]k`3Xjnl0i^[]0>CVjP3^hnX0ijfl0=aJL@3Q>4T0fDA:0=JXZ03AeMT0f^;V0=KK
h@3Ga=80_fEg0;LS<P355b40b18G0<4A502g40l0_C0A0<4l4`2a3P/0[PT>0:0Q8`3B/k<0algA0<W1
bP1^>T@0ZXB50;c5aP2AY:H0Xk>f08jHW00C2`l050D801D31@0W0P<0F@`?06h21P1f0@@0K08205d2
0P1?0@40>4812Oooool;003o001=06`Z3@1Y8aT0I`l<06XQ701[Ad@0HcTj07HS:`1b4QT0PTiF08Uk
Q@26Mh00RWj608n7S`2ARY80ThZA09:;T`2BT9H0TYBI09BLX@2EX:H0RZ2^05^0]@0MD:X0<FNm02i_
cP0@C<401DK900AMi@03Ko@01WOi00Mnn`07QO/028Oh00N7m`08PO802g[Y01Eah@0UJmX0>6;B04IF
`@1FB[40ISfK078aQ@1j;Gd0ORM`084TJ@1o7f40W1M20;<:7@2b2QP0Y`TF0;UGH03>YkD0`J:b08=K
I@3:/;L0Zi>O0:bFX02<KW`0Y9FT0:RLZ@28HFT0Sf9V07Lh?P1g9Bd0K08907811P1g0PT0N@8;07X3
4@1]2B80AP`e020GCP0]Ch80LiV^05E^K00XZR<02?ooool0F@00o`00RbL908X70@1b0@40J04006@1
0@1W0@<0I@4106X10P1c0@H0N`4:07D1201e0@T0Q`4=08/230280@/0R`4808h02@2C0@/0V@4<09h3
302T0@P0/@<80;l830382`h0dPlC0=4=5@3C41T0fA4K0>`M903e82@0oBLY0?dY;P3l<C@0nS8i0>8l
D`3YRJ80on_g0?odo@3ol_/0oo3i0?o`m`3oloL0o_cm0?ghnP3nko40o^GV0?cCe`3aPH@0o5QA0?a9
?03^?CX0L1/V0=CDfP3Oi>L0gn;V0=gQh`3Oh^D0hm?L0;Q4E03?4Qh0b@`C0<L<50302180^PDA0;L6
4P2b1100Z@8=0:P13P2Y0@h0ZP8=0:D13P2P0@`0VP4<09H02@2H0@X0X08>0:81302R0`h0WP8<09<2
201o0PL0I`4406`3101U0@40L@4206d10P1L0@00ATX400Sooooo3@00o`00C01kDRH0MUI207UJBP1j
FeD0LeID07AHF`1lGV@0OemW08]XM@2EMWl0VX>=0:29UP2WSY`0/96Q0<:HZ@37WK80:Rij008HP@03
7X<0CVBG0<34bP2m_lL0^/?=0<?Di@2/a^L0MjOQ04fCiP0ILN802V_Y00UVi`04P?L00XWk00FBo00<
X_`0:K_k02ninP1=]O<0Gjc]03n:h`0WLn40<F3H04ACbP1H@kH0W2Mj0=@@<`3G31`0c@PE0<H55@37
1QD0aPHD0<@550306bh0hjZg0:IfR`3I]lP0^H^P0=BcaP2H6S/0Z08D0:Y;F`2]TjL0SEQg08iTO`2g
TJ@0R`PP0:55C`2URi40ZXJ>09eIJP202R@0P`HR068;=P0I4U4052mQ04mYMP0cXbl;ooooo`002_oo
ool0F0198Pd0704102<20@0I0P403@4100P2000>0@40=@8305L1101L0@<0I@4506h2201k1@d0T18H
090=4P2M2Q00/0T=0;P:3P2k2`l0`@hC0;Pa=P3MaLT0dmGJ0<_Ae01BGUd0Y[Jf0<WDe@32c=80cmWK
0=;Lg@3Bf=/0aIRP0;XK8P3;4aL0ba8E0<XB5@3:51T0d1<H0=DF603I6A/0dBD/0>Rk`P3QiNT0hNCX
0=oSiP3ThnP0jLgI0<YcQ@35:CT0cQTS0<XG6`33C540c<W>0=;KgP3Ffn00a;Fn09e5F02]4b@0]0`F
0;@<502a2A80[0/<0:8K0@38FAl0WA040:L7302M3Q80]fi^0<c;d03:b]40RfIc064T:02bYjP0]lC9
0:Ne_@2X]k`0V:>V04He>P0X31007@8503441`1D1@X0KP8707810`1Z0@40G04104h10@0e@@09oooo
o`/00?l004d0G5X>05l@1`1Y81P0MClh0717@P1X@Ch0Ib4Q07mEEP1lJG00O7=k07ibN`1mLG/0P7N0
08ElQ@2>PhX0V8jD09ZIW`2IXZl0PYVd05Uk[`0REJT02DFc004YX`01::P0253C00=1cP04AmH01Uo/
00EVk@07Fmd044g;0216^`0e@:`0Bd2U060mV`20>i<0USZ90:<oR@2Q?hT0VDjE07YDU`1[Gj<0Ef6^
04=[_00bK/80:F_:02=Sc@1LCZ/0cB=20=DI8`385R40]bDf09`kCP2cSi`0YiBP0<Vb`@1]9d40^jNd
0;BW]P1N;4@0/YfZ0:JBX@1lJgT0Rgj:0:1oSP1T1A40J@4406X:3@26<cX0N0H?07P4301m1100N@TQ
04/FB00X?7X0FGF601?C4@08ooooo`1I003o002090H0Q`L107810@1X0@40J04206H10P1R0@40JP84
07@11`1n0@/0MP4507L11`2:0@`0S`4>08`12@2B0@T0VP8>09l23P2Y0`d0/0@=0;L4303420h0c@/@
0=D@403G4100b`H>0<T53`3>2A<0e`dF0>`I7`3f7b80oR//0?da;@3n=C@0ncPm0?=4D@3dJ7/0mGN:
0?EfQP3dNXD0n8ZD0?VP[`3l_M40o;[=0?REWP3jPX<0nW=a0?iPFP3nCTH0odDo0?Hk?@205R@0bl7:
0>3Uj@3NhnH0gN7T0=_NhP3Ug><0]eAS0<LA7P383aP0aPhG0;h7502h1A80]0<@0;843P2Z0@/0Z04=
0:`13`2]0Ph0Z04<0:@12P2J0@/0S04609D2202Q0@d0YP8?0:T54@2V1a00U08808H11@1g0PD0K@84
07421@1h0P<0KP420681001:BP@02?ooool=003o001<06Yi8P1cESd0Nea<07eNE01lGE/0OV5T081U
J022Ifd0RFmj09=nR@2HQY00VhNC0:F<VP2YSI/0[hjL0;BCYP0Q96d00AEl008KP01AIYl0Y:o408nZ
e@1QTmX09VS>00QCc@03EM/00ecX00=XmP06Lo/027gk00Mmn007NOD02gOa01Icj@0IClD0>d^o06Y6
]@27?:80UcJC09haRP2K<8H0S3:707TlU01m>Hl0_25M0><F:P3T51/0gPlJ0=d=5`3M3QT0f@/G0=@>
7P3DI7D0bZ^h0=o1d030UJX0cIfd0:@C<@2c11<0[3510<NW]P30[Kd0`kS60;bN/P2A2RD0US0m0;^k
`02/][l0YiJT074G;@270a80Q@<B03T=?`034eL05BaA02N[:P_ooooo000:ooooo`1H04PO300O0@40
9@8201X20P0;0@40204100d0000f0`D0G@4506L21@1_0`P0OPhD08D?50251`d0RP@=09h7402a2@l0
]P/>0;P:3`2l3A80[2PZ0<^h^P3>eMH0_LW:0:Bc/`31cLl0aM;G0:nm``3>f=T0d=WJ0=;De`2RGFL0
]a@J0;`@4`2o41D0_a0F0<0C5P3951H0dAPJ0=@G703<8bP0ikZo0>7Vj@3Si^P0kMkS0>:EY@3<AUL0
e2Ha0=LJ7P3?5QT0c1PJ0;i8CP3Bc]<0d/_C0;jEXP2R@E00ZA<N0:P84P2U1`l0Y0L=0:86302P70L0
c6TV0:0^2`2E1PP0UPT>08X/;03?^KP0a/cB0:nKY@1K6R<0Vfe^0;Jj_@2Y][/0V:N^09BTZP20QXd0
=b0Y03lO9P0g51X0<08505P21@1`0@H0L@4306T10P1L0P40D04104T30PWooooo2`00o`00C@1MK@`0
GQ/:074d9P1d9Ad0KRhU07QNEP1iJVL0MFec06mYL01cJg80MFQa079VL01kLWX0QWn709:<V@2<Sj/0
G7NZ02EBX@09?:000SFR00<aX`04=k8013Ff00@b^@07AL`01dcD00Dh_@0=<J`0B2jB06/TL`1j8fL0
OBa^07XlP@1fAX/0JEVQ05Ye_`1?SM80GZ_P07_1h`1od_<0DLCf03Bon`0LZOT02YKi00N>n004NO@0
0f[Z02U<_@2b7TT0a`lN0<0>6P2i?TL0gKJo0;1kT`2:=e00fZRi08@V>`37WJ`0]iVZ091]N`2gVjP0
SUe_09Z6TP2=OHX0YHJD06`95P1b0@D0H0dB09]_N01m;c`0QT==07lX<@213QP0S``I05lMC@0O=680
5LPH00Sooooo05T00?l008<V1@262080M@4206X10@1U0@40HP4206<10@1]0@D0N`4608H22@260@P0
R04:09D53`2T4Q`0W@H@0:843@2V0``0ZP<<0;433@2b0`/0/`880;d32@3720d0c0P:0=<A403820l0
b0TA0<L74@3=2aD0fQ0L0>dK9`3f9BT0nRXZ0?/];@3l;B`0o2l`0?Xc=`3h=S`0mSDk0?Pk?P3d>d40
kca60>a1D03/?dl0kCa30?0l?P3/>3H0kC@e0>P/;P3X:Rd0ebL]080H9`25NXP0g>;V0=gPh`3Kgn80
fMcP0=gJh02MDV00/`lL0;H:5@2i2aP0/@@C0:h34@2/0`d0[0<>0:X23P2V0@`0ZP8=0:`13@2W0@/0
Y04:09X22`220@<0T@4:0:022`2U0@h0Z`HE0;4B7@2M1Pd0R`8807l21`1Z0P<0K`4307L20`1/0@80
H@4104]<1P08ooooo`d00?l000`0JXLT085NB022HDh0QVEG08IUH026JFT0PFQY08M`M02:Lgd0TWZ8
09MkS02IO8d209n1T00n0;6?W02hU:X08BYh00<TT`04:Y`0546Y01M=^007BLP00dS>00ADgP05En80
15OT00MFi@0:Cmd06TcB03A0^`1B=ZH0IC6H07LaT02>;hH0KAi`06HaQ@1aBIX0OVR^08J>`P1RWML0
;ICY01F>l@0@R?D06gK`07m;]03O8DL0jAHN0>0@6@3J2QP0e0XF0=885@3?2AL0_ba10>38d`3E`<l0
dZVo0;1UQ@2Z32L0/`8@0;PmB`3G^<D0a[K40<Bja`2gP9P0W@LQ09PY=`3>a<`0Zj^g0:jHY`1i6SH0
RP<F07d230152S402A9D00<DA00IW24;ooooo`002_ooool0F01870X07`4101h10@0F0@805`820182
0@0B0@40>@<506H21P1`0`L0L`8708lC702=31<0O@<:08X7402L2A40[`/C0:`93P2Y1``0[0X>09dA
5`2dSiH0b];D0<KCe038c]<0[ZB`05AIIP2O[[<0c=OG0=?Hf`3?[kH0Y2Ta0<TD5`3D5aT0fQ/M0=dN
7P3U9bD0l2dY0?0/:03e=Bl0jde50?cPh@3fmoT0mnc_0>JBUP3^DD`0n4@m0?Y1=P3f=RX0lBlT0>/[
9@3RJV`0kL7<0<aDIP3:8Bh0c1HN0<4>5@2e2a80Z0L<0:D82P2L4@D0aVPM09Xb1`2>2@H0S@@;08<K
7`3@[Zl0al_=0<K:d@1eAU00HalS0;JUY`2`_l80[;c00;O8c02K[:h0If=Z03HL:00R51d0MF9Y0405
2P1]10T0N@8607@10`1X0@80F`8104h10@170`89ooooo`/00?l004d0?XX406dh801/81<0MQL=08YB
@@1bGUL0MVib07I^N01UGVH0K6=[079WK`1eJ780N7F4069aT`0bDY402cJB00<_W002<:@00S>X00@j
[`04;j803S>V01XYV@0V57H0@Q=T030MMP026H003Qam050eR017Aid0;f6l01afe`0JVO8059ce01RZ
o@0HZ?X069kg01JAl@0DQNX03h?]00Aek@01Lnh00Fc[005Vi`01I^T00EgQ009Mh@0JC<D0XBAL0=0B
7P3<4AX0ceMS0=:^^`3EVJX0^DYQ0;X/@@2]4bP0]R]30:TY@@2eDVX0YD9J09i1E02dMhL0RdQK0<2J
YP26=4<0N`89070N8@2]Uih0NE5K07mHI02WRYH0U69^09TlA`1f7dD052=L01>X6P08ooooo`1I003o
00239@@0P`H107@10@1W0@40H04106<10@1W0040L`8508411`280@T0R04;08h22`2X4ad0_bLa0:`=
6P2[1@d0Z`8<0:T1202`0PX0]08<0;D32@2o1`d0a0L=0;h42P2^0@<0[0470:/22@2[00T0/0<?0;83
3@3121H0fAHO0=`K8@3O82D0hbTZ0=l/:`3J<S<0eSTj0=Hn>`3GAd@0fe9=0=YJD`3LIeh0h71[0>=f
LP3UNgL0f79/0<eWH`3LMW<0bFMW0:eDE@25C580MW9h0=OLh03Hg=l0f=cP0=KJgP3Jg>40SF5[09DG
8@2I3Q@0W`dE0:854`2P0@h0WP0=09l13@2N0@d0W`4;0:L2302X0Pl0XP4>09l02`2O0P`0TP4709T1
2@2S0@X0X`090:H1402S0Q40U@D>08H53P1h0`L0N`8507P1101k0P<0K@4205l1001:B`D02?ooool=
003o001<052T6@23HDT0QfEC08i]G`2>L6T0QVi[085XJ`1nHfl0RFmm08Y^OP2<K7d0Sfal09]lR@2T
RIL0ZY:W08Ao[@0E=ID00bjX008`[P01<kD013g300E4cP06BM802DC<01Di_@0a<:/0DRNC070SO@21
8Fl0NRE`05/_O`1>?Y40?U2[02a^c`0KQNP069;_03b_mP1T^_@0E:O_01V4l004M_@00Fkb001UkP05
FN@0<cff0;DJE03I2QX0e0PD0=H95@3B21<0d0HC0</@702l@4`0h/[D0;nR]@3;V:l0[5Eb0:dC:`2`
1140a6Mc0<2Z^036^/P0_JZk0;AROP2V1ad0[U9K0<Jna`2l_<T0c;k>08@VA`2B11T0QP8806<45P0d
3cT02a<l01:B5`_ooooo000:ooooo`1H04DK2@0R0@40908201l10@0Q0P806`4201L10P0a0P@0HP85
06l21P1`0@P0M0/?08HU:@1^10`0O`D<09873`2P2a@0W0L@09h6302P1P/0X`P@09lY=@2bK7d0/gj=
0:UGI`1h8c00C3a30<?=c`3@f]`0gm7G0;MFH03D8bL0kbHR0?X^:03h;2P0oCD_0?i0>03oBd40oU=8
0?iJBP3lN6`0omKN0?_Fh`3jc]`0nJfd0?^2M`3nKUl0oF5A0?YFAP3hL6<0mW5/0>mMI03`BE@0nC0c
0?TW:P3c9BH0iQhN0=LG6`3:4Q@0^aD=0<aQ5@2dB@h0WPd60:06302?2Pd0Z71_0<c<c034c]00_;:h
05DD7P2?JFT0_l?30;C2aP2IZjh0TjNY08fPXP1dKgL09@PD020:5`0m:SD0MSDl07H32@210PL0NP83
06P10P1N0P<0D04204L40PWooooo2`00o`00C@0h[@D0KS`L07Lg8@21?2T0SG1S07M]IP1`J6T0LFU`
05I>E@1/IFl0KVYj04iJN@0M=gH012b6008]T`01:ID00RbK00<_WP0>;i`08bN<03hGIP1I4dh0HaI?
04h=B@0h4ed09S:D00@^ZP05?<002UcP00U]k007M_000f_W00=/j@00J>P00F[Z005XjP01K^h00W;]
00=kl@08PO003HW_01:Gl`0AWO@03Ycg00RKn`05T_/01h_j01Agl02QA8h0jb4^0>DM8`3I7b`0eD9J
0<dnF`345bh0aa0L0;h;5P2m2aL0^0`F0;L<602Z1a@0W@DB09L6502@1180RP`M08D95`240`X0UDeA
08UPL@2GJWP0SgN20;6Q[02/WZX0YWB407XRAP0L8EH01lP=00Sooooo03P00?l008<T1@201P80L`81
06T10`1O0@40HP8106/10`1h0@@0Q@4808P11`2900L0T`<=0:/;602[2aH0Y@<?0:T33P2a1100/`@?
0;@33@2h10h0]PD=0;032`2a0`/0YP8809/11@2H0@H0U`8509@11`2H0@/0V`0;0:433`2F2A@0W3]0
0<emO03VX9`0k[6^0>no_P3ddM00m]KB0?GHe`3dg=T0l]kJ0?7Qg@3bhn40l^GU0?7Sh`3_h^00jmoL
0>cOh03YgMh0h]WH0=_Fe@3CemP0f]oR0=cQi080fMgQ01l0f]cO0;Za/@2^RXT0ZWYi0:MZK@2I>D00
V0@?09/1302H0@X0UP4;09P1302M0P`0W`8>09d1302K0@/0V`4:09X12P2N0@X0Y@4;0:H13P2W0Q40
W04>08021`1i0`X0L`@807D41`1a0P@0OP<507820P1R0040C3L200Sooooo3@00o`00C019/1<0Qf56
091ZE@2GMV80UWmb08iiMP20JVd0O6=/07QNJ@1oHVl0QVId08m^O02<NY40HfVI02I3U`07;id013Bb
00@g^`05>/000bnc00Xb[`0L;:<0B2ZD06`JM02266<0MQUR05LSM00g=Y<07U:l015Vg@0=M_4037of
00Z3n@07O_L00W;f009ZlP01J?400VSa00=]l@03K_4017;a00AjlP03OoD017of021ai@2Z?8X0lAdY
0?<L803b6Ah0jQ<K0>TC7`3L<C`0mkk<0>70e@3R_]H0hKgC0?2hdP2i;d`0_0HH0<=9H03L`m@0b;g>
0=35eP2aG7X0X`TN0;]kPP2n_<H0^[S60<6I]02J63d0Y@HH09D22P1D1R4060Ta024G;P08ePL;oooo
o`002_ooool0F01460P08`4102H10@0X0@40:@8302810P0J0@809`0105X31@1/0`D0JP4506LD5`1b
=CX0I`@<07H11@2>1@`0TPD@08P5302H1P/0XPL<0:P93`2a31D0[a8O0:lF802l51`0La0E0:>NX03?
f=X0e=cN0>:ma@33=Sh0jBHV0?DU903k:RH0oBXV0?/]:@3j<b`0mSPb0?M2>`3hAcl0kdi:0>=[M03P
MX00hGR10>MXJP3_GU80l4m20?A<@03`JF00lJJW0>bUZP3cQh/0lS<g0?//:`3i9bT0lR8Q0>HK6`3M
6AX0e1/H0<Xl303SQQh0]1l70;H<3`2c2a80U1PH0<ni]`35cm00a/k@09n2R@1Q6R40Sg]n0:6]/@2V
]K/0[[g30;;3b@2HYZh0<2@_040Q9P0e4a`0;0HA064:501o0PH0P`0507d2101^0P80H@4304`10P14
0`49ooooo`/00?l004d09mH606h[2025E3P0RVeH081aIP1aHeh0FTi?06eUJP1[J7<0CUMf01/_K@04
87<00b:1008TRP039Y001b:901XMN@126VH0IaMA06dHC@1A75L0:2Ab018`U`069YT012bT00Y4_`02
<kD00Rnb00=2aP01AlT00e?E009Mg002JNP00G;^00=nm008So@09JWf05C4m@24fOH0W^Gk09[YoP1^
f?/0?<Ci01b^nP08Vo`018kl00=ln005Jo00GDNZ0<LK?03<42@0b18S0;l?8`2l3B<0]@/O0;8;7@2^
2AT0Z`TG0:X85@2Z1a@0X0DA09L33P2<0PT0Q@4708811`1o0@L0O0<:09E<E02fRIP0ORPm09M>H`37
WZl0]Yf]0;V9V02=7CD0=dH/00?a0`08ooooo`1I003o001o9@H0N`D107<10P1[0@<0E`4105d10P1_
0@<0O@4508P11`2<0@H0T04809X33P2X1Q00ZPP@0:L94P2Z1Q80Z`@@0:/33P2[10d0Y08:09h42`2I
0PT0V`4709<1202B0@P0T04708d1102;00H0V08=0:033`2T1100R`/J03hN;@3HfMl0jnc^0>c]k`3]
ko40k^oa0?7bl`3emOL0n?Wj0?Shn@3fmoL0m_Kh0?Ofm`3hnOT0l_?d0?3`lP3_ko80ko3b0>[/k`3V
j^/0hnOZ0=oUj03KhNH0gN7U0=cQi@3Kgn80fmkQ0=WMg`3Ffm`0e=SJ0;>GW@2F2aX0Y04>09d22`2F
0@T0V@4;09/2302J0@`0V04<09P12`2E0@T0UP4909`12`2X1140/`/J0;<?6`2M0P`0P`870781101h
0`L0I@@60580001h0`H0M`4206H1001O2`<02?ooool=003o001<02CG202:Hd00UGAJ09f3K`2WUHX0
SGUg081WJ@1eG640M5UT07iUK`1nJgd0EE9o01T^O004:9@00RVR008YY005:j/03BVS01hPSP0i5GD0
Ha9N07XBE01_6V40D2n902@fWP0@A;X02ECB00QNh`04GN@00ekW005Ij000F^H00F;[005Ul@02LOD0
17ce016;l`0lYo00J<3d07cAn01ZeOT0@L[g01nio00?Z?h04I7j07UM_@3Y9440k1PU0><B8`3K42D0
eA4V0<T@;@327TT0^1Y>0;8GB`2]64T0ZaA40:/<<02/1R40Z0XX0:<WD@2X?VX0[d9/0:8;;02P11H0
`6j20;jM]03>_Ll0/6F30:L=:02]1a80VP@?04H=>`054e806APe003o00_ooooo000:ooooo`1H04HH
2@0X0@40;P4103020P0Z0@40908101l10P0V0P80D0<706L31P1T0@D0K18H07HU;@1]0`X0O@8:09l@
6@2Q3QD0UPL<0:D:3`2/2Q00]@`D0;lA4`364a<0c1DC0=8O7@1`8bD0b/_=0=?Ig03Gem`0c7f90=8W
:`3[9200mR@R0?/X9@3m;BX0oC8^0?hk<`3n@ST0oDa30?iEB`3lIUh0nXJ90?ZV[`3l]l@0o9fR0?en
L`3mJUX0nV5E0?VSW`3_^;d0jJV_0?>T[@3Y@DL0nRd^0?HV:P3b92<0j1lO0=TL5@36;PH0gWdF0<5:
2`2l40l0^`XD0;H?502eFeX0d/o@0<OCd`3<cm00OdQ@08eAE02]ZJX0[;^m0:2_/`26V9h0SJ2V096O
Y@0]7bP0@1`S03T@6@1E4A/0M@D>08L22@250@H0O@430781101V0P<0D`4204D30PWooooo2`00o`00
C@0Gk@D0MRh708=I?`22KU`0OFiT07QWG`1ZFeT0I5i_02/hI`046VD00QQc008KNP035G802AA/020C
H@1;3dP0IQ9005PLD00b9Fh04RR900L`W006=ZX01CRd008ZY@016iL013:a008d^@02;K800dC;00IY
j`06P?L01i3k00ZNo@06X_h03Z[n01ffnP0d_?T0?KGg03:Vl`0OT^d048Wa00F3m@04OoD00G3^009X
j@02INT00UgO009Fe`0@B/<0A3B>05D/N@1<;GP0ARYf04@WM@129W@0@BA`04<PJ0198V<0DB1K05LI
D01Q6D/0JaU206DC<01Q2Al0I0DB06@32@1V0PL0LP@?07L;6`241A40T`HE09@@902ZCV40/EIZ088E
<00D]Pl00?l000Sooooo03400?l007`S1P1h0`40M04107@20`1V0P80KP4307/110220@H0R`8808h2
202D0PX0UP8:0:884P2X3QH0/A`T0:4=602L0Pl0V`<=09412@2=0@P0RP4709411`2J00L0X@890:D3
2P2W0PX0Y@480:`33@2e1Q00_@/E0<@=603462<0LPdQ0=_0dP3gj_P0o?3l0?o`o03oko/0onki0?o[
m@3oj?00o>G_0?[Qk03feN80m/oM0?G8e`3ea=@0m/;E0080mK_A02H0m;S=0?>cb`3c///0jj_60>:Y
b03JZlT0e[C=0=Fld03E`=@0d/?D0=;7eP3BbmX0c:jm09l@8@2b0`l0Z`@>0:@22`2T0@d0X`8>09l2
3@2L0@d0V@4;09L12@2H0@X0V`4;0:D54`2c4b00/aHP09`540240`X0O08907P3201`0`D0K0020882
1P1n0@80K@4106D:0PSooooo3@00o`00C00;mP<0SF@f09]oI02RSWl0[J:M09F4P`1mI6@0O6=U07US
K`1IE7<072QY00<IMP028H`00R:G00DPU@0I6hP0BQIc07HAEP1i2T40I@m:03/GI`0L:8`033>[00Q4
bP04C=P00TOB0058d`02B]P00E?P009Pj`01J_400gOh00F5nP06V?d03:Sn02JknP1Gd?/0K/_f05nl
m00nZ_804i;c00J9m`03P_`00WGi00=/mP0JGN80J3fO07TbP@1Z<X@0Fc2<050dU`15=9/0?cFO03Pb
XP0b;id0;RjH02dYTP0^9X/0;b21038LM`0g5f`0@aIY054FH@1M4E40J`do07T<>@243cT0WS1F0:DP
?`2[21d0Z`D@0906600`4e0011QX00lJA000o`0;ooooo`002_ooool0F01<6@X0;P4103D20P0d0P80
:P4202`20`0T0@807@8203D21@1@0080F@4206@11@1a0@T0OP@<09<<5P2_5ah0/0hC0;0:3`2d2Q00
]`XB0;l=50384A<0cQ@B0=4D4`2o71h0M4eA0=GKgP3Cf=`0dl360;8f?@3:6ah0eaTL0><M7P3/7A`0
l20O0?<Q8@3e9RD0kR<S0?8Y:@3a:BL0lRd^0>h]=`3Z;ch0j2m20>L/?03V9c00jBP/0=lY;03POXD0
f:2/0<R;U`3SVZD0]R@]0</H703<51`0c14G0<LC4P34>0/0hHdF0<Q/4@2e5``0_0lD0;P?502X:BP0
fl2n0<cBe@39d=<0^IjW078I802VRH`0UZ6Y0;G3bP2lb<d0[ko30:Ri_P2BXjP0:APP04/C700]1@h0
@0X@07863P2:0PX0S`<:08`5201i0P<0K@8205/30P180`89ooooo``00?l004`0Ke/A081SA01dHdd0
MFAF075PE@1GEF004B5D008GI0035f`00QAY00PDI00W3Dd0CP`i05D>>@0i4e8061me00P]TP03;ih0
0RnS004ZW@006H/00RRL00<c/@01:[4013o:00IEh@05B=T01UKU00EfnP05P?/00g_g009in001N?D0
0W_f009hm@01MoD00G;c009cm002L?000VWY009Ti@02H>400UWI005Fd`02EM<00U?=00=>a`02BL<0
14Jl00<o]@04?k8013na00@n/@04>J`01CVZ00@eY`04<Z8013:M00@^V006;IH01bZ=00XXQ@0@9Gd0
6B5/01/BA`0T2Rh0BP`[06@780201Q80S`@>09d84@2N2180V`hJ06`RB@0DAcD00?l02?ooool02`00
o`00NR0407P30@1k0P40P@8307T20P1g0@<0OP4408@0102<0PL0RP470080R`4804`0T@8?09D34P2I
1aL0U@<D09<23@2B0@X0S`4908h1202H0@/0X`480:l32P2h1`/0c1HE0<H<4@311a00`PPB0<06402o
1a40_PDB0<<<602a3b<0]SeS0;Y<N`3AEhL0fUf80>=ZR`3SKHL0i7B40>>4R@3QSYH0i:6`0>>LZ`3W
RI00jgAh0>eVJ@3aF6<0l4eK0?5<F@3a@U40l3a?0>hgB`3W;dL0g2U50=4UA@3194@0^BQ90;<[CP2/
=5@0Zd1O0:mBM@32Hh80Z@PI0;@1302_0P`0Z`4:0:T12@2X0P/0YP8=0:81302P0@/0W04:09/0302J
0@`0X@<A0:/;6@2Y31T0U`8>07D11`1[0`P0MP4707T21@1k0@<0R@8408410P1b0@00J@T32?ooool>
003o001;081i;02ENEl0UhIn0;J^[P2=NgT0R7Aa07]aN`0d>VP011AR008FMP0267h011Ml01TALP1@
3ed0N0e806d?CP0i3eh05aIe00XPS@04:j801Bj_00@g^`04A]400TOB0058d`03FnH00VKb00Ihn`05
POd01HGn00B7o@05S_h00h_l00:7o003QOX00h3j00=mnP03M?X00W7j009_n@02JOD00FOb009Qk001
FN@00UWQ00IEe`06Cll01d_<00E6aP05A<401TG000M3_007@[X01d:g00Hn/@06>JX01CBS00HaV`05
;IH01BZC00DZU0059i<01RF@00POQ`0=78006QUc03<EH01K4dX0O0he094;901l2B@06a=H00<PL`0=
7U000?l000_ooooo000:ooooo`1H058O2`0d0`80<`4203T20`0a0@80:`<401X10P0<0@40:@830542
0`1L0@40J`8407T32P231@d0T`P@0:/<4@2_20d0/@P=0;@93`2h2A40_@/B0<4>4P333a80_Q0C06d;
3`28R8/0b]KI0<k?e@2KDUd0XA8H0:T=4`2c3A80`0hA0=HF603E4A@0g1DJ0=XD5P3Q6AX0iA/L0>HK
6`3V7ad0i24Q0>HT903W92L0iB<X0>LT9`3]9bT0iR@V0=Di@@3TPi80hHJG0<YGI02h5a`0^14D0;8;
402h3Q80[Qd70=:6503<RAP0UAl409X32@2I10T0TQ0B0;=jN03;d=80a/oD0<g9c`1o@d`0R4530<G4
a02Y]KX0]l;70;6oa02GYjh0U:F]09JSZP0b6B00>PTA02`53`112Q<0KPL>07T10`1o0@@0Q@8607l2
101b0@80G04104d30@Wooooo3000o`00C01VNa00NUlh06]L@P1[FT<0HUQC010N@0025eT00aAU008B
HP0;3E80<PLh05`;;P123Sl051=O00@PPP02:I400BZG004/WP02;ZH00RnX000YWP02?;H01Tk@00A1
c004B=D036O_0050d002@=000egX009Sj`01HNT00F3X005Rj002I>T0063T005Ph@01GMl00f?S009P
g`01G=P00UgG00=Le001E/T00U?500MFaP07Dkd0252b00]?Z@0=C:003dVF01A<U@0HC9@05TZA01A6
S@0EAhd04T>900loR00:>8D01C>500HeR004<8H00bb:008[S`02:8`00b9o00@LL00;6FP08aQH050D
?`1h2b@0W@dH0:<93@2F2aX0BbER01<RB@00o`08ooooo`1I003o001g8@<0M`@108410@2;0@<0RP42
08010P200@@0Q`8608P21`270@L0P`8807d11P1n0@/0O04<09D<6@2R3Q/0VPDA09P2302J0@T0Y0<<
0:h33P2e10h0^PH>0;/62`333@`0_PD90;P2202g0P`0]P8<0;/33`3121@0b0`F0<l@7@3J72h0gb8g
0>DX@03`?E80nU5L0?YJGP3mKVP0nh9i0?R@T@3gX:h0mYf^0?N5R@3jJfD0neYB0?a9AP3l@T40o40m
0?Pd=03g;S00mBT[0?4Q9`3Y6b80i1PR0=XE8P3F5RL0d18T0<L?802o3Ah0^@dS0;8:8@2g1A@0]P@?
0:h1302[0@/0Z@090:X12`2X0P`0Y`4=0:H12P2P0@X0WP4;09d1302P0Q00Y`PE0:/?7@2L1A40M`88
05D10P1T0PD0L@8608021@290P@0P`4207L10@1]2`<02?ooool>003o001;04fd6@2@Ke80U7md0:^P
W@2GShh0M7J9024dK`0377P00QIf00<BK`0C3V00>0U205T9=01=2dL08aMb00/PS`0489D00b2G004M
V0018Yh00S2a0095c@05G>H0163/00AWl`05Lod016ok009_nP02L?X00V_i005Yn002IoH00V_f00=^
n001J_D00F_e009Wm003HNh00eoY00IQi@07H]d0367E01EOb@0MH/<0:6Jk03A[/`0kJj`0AFbV04aa
X01CM9l0FGZL06=lV01WOiT0IWnJ06=mUP1PNY40F7:805MaR01GKhL0CFN004ASP00oGh40=e=n02U6
O00L>WX05S9m00PVO@078h403Amk028OL00c6Ed02AY/00@XOP0E9eL00?l000_ooooo000:ooooo`1H
05HQ300i0P40>P@403`3100`0P<0804201400@0:0@80;@<405X20`1U0P80K0430781101j0@H0R@46
0:P83@2a2@h0/0T=0:d8302^20`0/0P=0;89402^2@l0WP`C03L?4P2]^[`0bM?E0;fS[@2D6b@0Z`lC
0;0?502g3Q<0aQ4E0=<E5`3G51H0h1TH0>HP7@3]8b40lbTS0?</9P3f>2h0lT8e0?1;A03/CT`0kTe9
0?54?P3gACh0mClj0?0f=@3T=cl0hcQ30>0/<P3D71d0bQLJ0<<B5@2i3``0`E@<0=BH4@2S@@H0V``8
09X32`2A10X0M1@G0<fh^@34cm40aLgA0;bZ/P1L5Ah0OeEK09RW[@2^_<00`Lk@0<3>d02mbLh0TZ6U
09JUZ01]JV`07`L>02<1301@4b00L0D=07L10`1c0080MP4407P20`1g0`@0H@41058300Wooooo3000
o`00C011^@T0O5d`06]J?`1ZFT/08BDf00<FA`035UP00`mF01D9A00j1b/0A0X/02L?B0095VX00b>1
00<YT002:IP00RVL004^XP02=:h00cnl00A5`P04C<`01E?G008k``03=;h01TkE004e`@02>LD015?J
009Hg@02F=/00USJ005Hf@02F]X00U[I00=Jd`04F/d01U[600eK`00DG[T07VJe02][/00dKJ<0?VnO
04IaVP1?N9T0EgjI05V2U01PQ9D0IXNG076AW@1eTj00MI:N076>VP1`SIT0O9VU07^HY@1bTYd0IhFG
05UkSP1@LHP0@fF2035GOP0NAWH04SQa00T]L@02974012=d00dRK`0Y7f80GQU1098?7`2J4bL0>B]_
00UJ?@00o`08ooooo`1I003o001h:@P0NP@008`20P2B0@80V@8409D31P260@<0O`8507h21`1o0@H0
O04607l11`2410`0Q@PB090>6P2L2QH0V@<?09/23P2S0PX0ZP490;422P2b0`/0]@8<0;L4302n3@d0
_0`?0;<53@2a1A00[P@>0:h33`2[0`h0/PD@0;T64P2m2AD0_0TG0;L85`2i2aP0cAPU0>4S;`3^:cD0
n3Ll0?Tn?@3k@480mcTl0?Xj>03j>CD0nc4_0?XZ:@3m;B`0m2<U0>dO8P3U6Qd0h1TO0=HC7@3=3aP0
b@hH0;h;5`2g1a@0]`PC0;<54@2^0Q00[08?0:T12`2[0`d0Z@8>0:<22`2R0@/0XP4:0:H33`2W0@d0
Y@4<0:822P2K0PT0W@8809h12@2Q0@d0XP8A0:444`2J0Pl0T08<07`3201/0P@0J`8407/210240P<0
P04207T20@1`3`402?ooool>003o001;00_g102DKT@0RfmP09jDT@1TKY@071mR02/JJP0<67X03A=`
02l8A01A22h0=@@]018<E00678<00bNO008YY002::D00RVV008^/@04>;X00d3300A=e@04E>400UKS
009Lj`01G>d00eg[009KjP03Gnh00UcY005IiP01F^L00ekV00AOh@09Hmh04VKC029/c00iM<D0BgZj
05Z3/`1]Rjh0NYBY08FKZ@2<WjH0T:2U09:PY02CX:@0TIfO09>QXP2GYZT0TZ6S09JRX`2HY:H0Uj:U
09^VZ@2LZ:H0UZ2R09FRY02FXJ@0SYVK08RHV023U9<0R9VJ08JHV`1mSY<0LX>;069gQ`13GGT0;Taf
01i0OP09<XT00bjA00@/Q@0J@dH00?l000_ooooo000:ooooo`1H060[3P0l1@80=0<20384100P0P80
608201@20@0?0@40=@D606431@1T0@80J@8307421@1i0@H0R@<80:H;3`2_41@0Z0`@0:D82P2U1`X0
Z0H=0:`83`2T20h0L@/?04A1@P35d=80cl?;09U7E@2/4aT0^10C0<@E603?5aT0gA/M0>`S8`3d:BL0
nC4[0?`i<03m@CX0nd8m0?i?AP3oI5T0oXEl0?bYZP3m^lD0oJV/0?f3P03oKf/0ofUR0?mHE03oE5@0
oTY<0?a2A@3h>C`0kb/_0>PV9P3E=100hYLG0=1o4`2[7@D0/P/=0:T53@2D2`l0Zfe^0=7=c`35d=40
c<gB085LI@1K3AH0Sgj008fQY02M[k00WJfb0:Jg_@2fa<`0X[6i09VU[@1KDe`0;P`D02`12@1610`0
K`@:07/21P1c0@<0K04306030`1_1@L0I@4205L50@Wooooo3000o`00C00;m`<0KWdN06]D>P0a<CP0
0a8k004DCP074Dh09PPb04H99`0W2C80215D008KM@039XX00RJ<004YT`02;j000cN]008j/P03?[T0
0T?100A3``02?K`00d32008^/@029ZX01d7400=7b004CL/00do=009Ab`05DlL025Bo011H_00GG[@0
9fF[03aaY`1>NIl0GX>J06V:V@1]RY80M8nC07N@T`21UYH0QifM08nQXP2EZJT0WK2`0:Fi]`2Z_;/0
[/720;K:b@2mc/l0_Lo@0;k@dP2jb/d0^/W=0;30``2S]kX0T:R[082IW`1dT9<0IhB505ijO`1@L740
AFEW03YLH@0]DU`08dIM01<hG`08;F/032aj03PZL01`8eH092ig00mK>000o`08ooooo`1I003o001k
:Pd0PPD209810P2E0@40W0D609P520270PD0M@0207P10`1l0@H0P04808P22P2?0``0T`H?08T12`2:
0PX0S@0809D1202Y0`X0/0880;H62`2e1Ph0/@H>0:<12@2N00L0V00709801`2B0@P0T@0809@02`2G
0@d0WP4>0:@3402Z1180/PPG0;D85@2j31L0a14N0=HJ9P3]:c80nD4o0?Q=@`3fCdH0mE590?E=@P3i
CT40m3T_0?`g<@3k=300nS0_0?@W:@3Y6b00iA/T0=/H8@3?4Q/0bA0I0;h;4`2h2A<0/PDA0:/33P2V
0@/0YP8<0:812`2Q0@d0V`0;09T02@2H0@P0U`0709/12`2O0Pl0W04<09T12P2=0@D0V04909`12@2M
0@T0W00;09`23@2E0@T0T@4608D11P1g0@80M@0307X0101j0@80N@4207<20@1^4`402?ooool?003o
001:08NT@02;K5T0JVV003/RG`224cl0V@/[05T<BP1G2d80B@Pa01P:B`033f@00aj3008WV@01:Z<0
0Rj[00<d]`04>[h00c_200=0a@02?L000SZm0090a@02A/h00eCM00=Dg`02E=d00UGI00EFe@0<F/`0
5Eg602EWaP0nM;`0F8Bd07ZI]P2BYkD0XK2h0:6]]02]]kD0/KRi0;:j^P2nalD0a<_=0<?:b`35blX0
alW90<O8b034aL80_l300;Zg_02d/;P0/:R^0:ZSY`2[X:D0YijO09nIV02PV9/0ViFG09^FV02QVid0
X9^L09jLW02OX:00XJBS0:6TXP2PYjD0UZ6P08:BT01hR8P0JWj204YTM`0QA7D0331/01J58P00o`0;
ooooo`002_ooool0F01:CPL0@@L202h10@0Q0@404@4101<10@0O0P<06@4102X30`1K20T0H0@508h^
<`1b2@l0M08708D22P2R2a40Y`hC09l;402S2a00Y@H<0:P7302Z2`l0S`hC03TA4@2MYZL0e<790:Y>
F`2g6b40cQXK0=HL703Q8R40ib8R0?8T9@3j:2@0nR`U0?he;P3l=Bl0nC<]0?/e<03j>cD0nT8k0?A2
@03bATh0ldaI0?53C@3f?T<0mSDh0?Ld=`3b;300k2T/0>TW;P3Q7bT0gB4Z0=XM8P3@:Q40hWdD0>2U
5034@0X0c1XD0<PB503041@0/D920>38b@3;dm<0a]7B0<:b^P1U6280K1dT092AV@2L[kH0]/K:0;K3
b02]^l40X[:i09FV[P1WJgL0:`lL03`?6@141P`0G@D908XY;P1d0PP0LP0206@20P1E2``0KaLH0644
0`1H2@49ooooo`d00?l004/0;/l;05E19@0752T00QDo00XB?P0c2bP0=PLO018;@00355l00Qmd008U
Q@02:8h00RVC00<_V`02<JD00S>Y004eZP02>Jl00CRa008i/P02=:X00SVb00<a[P029:000cF_00Q;
^00ADZ`09V2V03m/W`1GNid0HX>F06V6U01]R8d0MHf>07b?T021UYD0RinL09JXY`2W^;H0]/O60<7>
d03<dmL0aLoD0<S=d@2l_L80]KBj0:RZ[`2QXJ@0V9RJ08j?T02:RH`0QhB5081kN`1mNWP0N7Ee07Eb
K`1`KfX0JVeU06IZIP1OJVD0EfEO05ARH@1<HEh0B69L03mMF00kFU<0>UMA03MED@0`DU<08TAG00de
JP0C=hD03S=i00Z]6000o`002?ooool02P00o`00QSHE08D70P2J0`@0V`<508d71P295aT0N@8507@1
0P1i0@@207l11`1=08811P290@P0RP4:08T120280PL0S@4709P22@2X0Pd0/0D>0:T43P2I0@X0U049
08h1202?0@T0S04908X01`2;0@P0S`4909D12@2N0PX0Z`<?0;45402k2QH0bQ4K0=XM903S9R/0jBhg
0>hk@03iEeH0o8Mj0?^MSP3i/jd0n[^j0?Z/Y@3mVHP0oWMU0?mID@3oD4T0oTI30?ho@03l=CP0nRhd
0?@Y;P3]9BX0i1lU0=/I8@3@4A/0b0dH0;X74`2f1100]@D?0:`23P2T0@h0W`4<09d12@2J0@P0UP06
09H12@2I0@`0V@4;09H12@2B0@T0U`4<09P12P2I0@X0U@4:09<12P2>0@@0S04308/21@240@D0O@45
07X10`1e0@80L`8206h30@1^60<02?ooool?003o000g02GZ3`29JeH0>RIA08hC<`2a2AD0/@H@0984
7@0i2C`02@iG00<IM0015gX00R>@008YX004<Z`00S6`004c]P02<KH00SJl008h^`02>KP00SJe004k
^P03ALD01Dg800]FaP0TI;d0Bg^l072C_02>Y;X0VJVi09n[^02Z/kP0[;Ff0;o5aP3>dm80g=oO0=cL
h03NgN00eM7I0<?0b@2b[kT0WY^S096<U`23OXT0O7Ej07]_L01fK6X0MF]V07AZH`1dJF@0MVUR07U_
HP1gJed0NF]P07EZF`0207M[GP0A07A[G01bJE/0KFII06MSE@1XHUD0J61G06YSF`1^J6<0LfiW07Ui
L01mOWD0MGad06UeKP1EIf@0>4i=00no3000o`002oooool000[ooooo05P0Agl904L<0P0/0@409041
02H20P0W0@40<08202@10@0K0@80@`8206`31P1n10/0N08906l11P2610/0X@`B0:X?502Z31<0Z0L>
0:/63@2c2`l0[PdB07/62`2LLG@0fLo@0<9SK@377RD0cADG0=@H6P3E61/0eaLI0>0I6P3`7ah0nBLQ
0?/Z8`3j;RL0nTA00?Tk<@3lA3H0nTPh0?QD@P3gJUP0lg=Y0?AhL`3fMFd0nfAI0?U@A03mCD<0ndLo
0?To>`3d=C@0l2l^0>XV9@3F<A00iH8K0>6Y4`3AL@l0`AP:0<4=402o3180[1HI0=6SX@3?dM<0bm;D
0<kAeP2LIg@0NQ4I0:1YJ`2LZK00TjJ]09^_]02AXjP0VJZa09Z[/`2Q/[X0UiVQ05Xh@P0e3AL0>`@;
06/93`272@l0P@<807<10`1O0P<0D@8305`4101H1@40ER032Oooool=003o001;00_g0`1=>Ad011L_
00H?;`0^2Ah0;0HI00P<>`036FL00R5j008TP@039XL012N>008WTP01:9800RRH008YVP02<J000SBU
008fY`03>Jd00SZ/00@kY`0@?i/09dV<045QS@1HNI40KHNA07>:S01dRHX0NHn@08:HU@2<Wid0X[Fa
0;K5`P2nc<d0`<S<0;^oa@2a/kP0YjBY09NAV026Oh40P7Mb07adK@1jL6<0NV]M07e]FP1kKEH0NVUB
07AUBP1dJ4/0L6E;07AZD@1eJU80M6]E079ZD`1aJ4l0L6E;06mTBP1dJDl0L6Q=071VC01/ID`0JV96
06ERAP1LH4L0Dee704eKB`12ETX0>eE<03YHC@0ZBD@05Se@014j@`03lP<00?l000Sooooo03`00?l0
06]b3`203`80W`H709H410242P/0R10F06l10P200PD0O04308011@1n00@0O`4408811`230@T0S0L?
09`J8P2L6200U`PD09X23`2H0@d0TP4:08/01`2A0P/0T`8:09d22@2V1@X0Y`@:0:`53P2_1Pl0/@H>
0;L740393aT0cQ0I0=LG7`3P7BD0hb4Z0>HT;`3V9cH0jBhk0?@nB03fDUP0n69V0?MYM@3cH780le=R
0?M<D@3f?Sd0nC@b0?X`;@3k<C00mbP/0?TX;@3e8bT0kb0U0>PK8@3Q62<0f1<N0=<@7@3>3QX20<H:
600K0<<8502l1A40]@<@0;823`2^0Pd0Y`490:411`2Q0PT0X@8=09`12`2I0@T0TP4:07l11`2>1100
W`HI09P55@2B0P/0RP4408T11@2>0PD0S@8508410`1m0@80O@4307<20@1g4@L0GSL200Sooooo4000
o`006`1]LdT0Faa30;4A702^3A80[``C09@77P0N4U@00aif008SPP017hH00RNH00<[YP02::H00BVX
004`/P01;kH00cFk008f^@02>;H00c^f00E1]P0<AZ`0=fJY07jN`02X^L@0_L?60<75aP020<C9b00/
0<[?d03Ae]@0in[Z0?;am@3MfnD0^;3009>8W025Nh`0OWF307AaO01_LGH0Kg=a06U_KP1SJVX0IV]Q
07IbI@1fLV40Mg=Q07UbH01iL600NFiP07]cH@1hL5h0Ng9P07Q`G01dKEP0MFmI07A^F`1fKUd0M6mK
06i[F`1/JU/0KFYJ06eWF01VH580J5i=061JB`1NFDT0HV1B06][GP1PIe/0BUa=02^=8@00o`0;oooo
o`002_ooool0F00c^`T0@Pd102d10@0Y0@80;`4104@50`1=1`P0<08301D10@0f0P<0K0<807`11P1l
0PL0M04708/6302V3A80Z0X@0:X9402_2Ph0/`P>0;/<4P2]20d0TQ@H0<ZIW@3=W:@0^QlZ0<`A5`3<
4A80eaDG0=hH6P3V6Qd0l20N0?d^8`3n=bX0oc/_0?/j<@3oE500o4m60?mRE03oLf40oi>30?o:a@3o
in`0oncf0?oQi@3oZ:H0ogad0?m]H03oJeh0oeM?0?i7A03oAD80o3/a0?5^7@3W[1`0iJhK0=532@3J
6QP0d1<E0<lD602k@T<0g=3@0<_Ae039dM<0dL[@07/V<P1h3aH0ZhfC0:Ng`02b`/L0_Lc>0;S7a`2`
_/00UZJ^07^>U`1PIgD0:aDT04`h@@1>:c80HPH>094630290`L0N@8505T20P1?0P<0D@4205090`10
C`89ooooo`h00?l004X0@5`@00XF8@0R2AT09`HF00D<;`025eT00R1g004SQ00288800R2100<TS001
8H/00B:9008TS0029Y400RfJ008cW005>IL05TND03ENU01DM900KhJB07B9RP1bQXH0O92?08jQX@2S
/[<0ZkZm0:^j_P2V/;@0YJR/09FEU`23OG/0MVmX07I/G`1eJEX0N6iK07YbG01jLEd0KVQA075^E@1[
JDl0JfM<06QUBP1YIDT0JfM:06IRA01WHdD0HV5206=QA01RH4@0I65806=SCP1WJ5@0IfME06QXDP1S
IDh0IfYD069VD@1OHD`0GF5905aJ?@1IEcH0F5Dc05YF=01HECP0DeLo051GA013ED<0=Dho02Q8>@0T
Fb`00o<2003o00Sooooo05T00?l004n_2P2==aP0T0D308T20`1i0P80QP<606h0002:0PD0R`0308/2
1@2D10X0R`@907h11@210@X0T@TH0:4M;@2L6RP0T`XH08l1302B0@X0U08909X22P2Q0PX0[0@<0;/;
4@355QL0^`dA0;463P2T0PP0Y00809l11`2X0Pd0[`@?0;43402f1140^PDB0<885P392aL0f1<M0>PK
8P3g:Bh0mRla0?Ti>P3g>C/0n3Hf0?Pe<@3j<b`0nblV0?/[8P3k;BP0n2HU0?PS903c7Ql0jQHJ0>HE
6@3J3aD0c0XD0<L;5P3221@0^08?0;H1302d0@`0/P4;0;81302c0@`0/@4;0:d22P2Z0@X0Z@4:0:P2
3P2U0@/0XP8;09H22P1o0PL0R08>09d46@2K11L0V08?08h120260@D0Q@8308T110260@80P`8207l1
0P1f1040MQL:04aD0008oooooa000?l004T0PWU?07hI=02^6Qd0hHB70;M2C02X2Q/0DaMB00PTQ`02
:9800RZG008XVP029Z000RJQ008ZYP02;Jh00S2c004a/003=:h02CVW02UDY`1PPKH0VZg50<?<d03?
e=40eMOC0=cNg03Ph^80gMgQ0=;?f@36`lh0[J^d092>V@21OXP0PGn808B4R`2;Si<0Qhj@07f4QP1T
LG40H6m_05i_K`1MK6l0Gfa]05iXG`1UJEd0Lg=T07QbG`1gLEd0MVeM07I_FP1gL5/0NVmO07Q`G`1f
Ke`0MFmL075[E@1cKUT0Mg5P07I_H01dKF00LFYK06iWEP1_JeT0JfIE06USCP1WIE<0EeY:04U=@P17
BT00FUi=05YOC`19F3L01O<200_ooooo000:ooooo`1H00[f0`1D80H0<@8103420P141@@0F`P705D7
2@0^0P803P4102`10`1[10L0P08708041`1d0PD0SPD;0:D83@2[1`d0ZPH<0:/52`2`1PT0]PH:0;4:
3P2T<cD0j;:h0;i8D@3F7200fa/K0=dK6`3Q6a/0jR0N0?8S7`3l:b@0oSDW0?hj:P3l>2h0nC@_0?i5
?`3f>CD0o4I10?]@B`3iF5H0mVQ_0?EeP`3gNhd0m71i0?QOI03mDUH0ndU80?e:A@3n@Ch0oC/i0?/f
=@3^?Ah0ki`S0>6d6@3KTQT0cbP>0=/J703F5QT0cQ`O0=>5Q`3Ad]D0bm?E0<WAd`2oXJT0QAPR09M8
BP2bZZl0Vj^c09j^]P2T/[X0/Kc00;O4aP2X]k/0/;o3079bNP0Z41X0>2<_040N:@1K1P`0R@D<0842
1@1h1@L0E`P904`51P180P40Da0603iA0@Wooooo3P00o`00BP0_[PT091P>02T:4`0:3B@00AI800<O
KP0287X00R:3008PP`016G/00Q^0004NQ`028XX00RB600@[Q@0C?8@0>5j905]jS`1bRY40OI2C086C
U02;WI/0WK2]0:Ff]`2P[;00U9VJ07amN`1/J600IfAC06eWD`1/HTd0J5i106YS@P1/I4L0J5m306iX
CP1/JTd0LW5B06i[D01]KTl0KV]@06UTA@1WHT80IVA606ISA01ZIDP0J6A706MTA01SHT@0IF=7065M
@@1PGD@0GEe006=QB01UITh0HVE<06AWC`1UJ5D0IFQG065UD`1NHe00G61:05UM@`1GFch0EeXn05IK
@P19Dcl0B54m03m9<`12Dc/0>4lk02e8<`0E^A400?l02?ooool0F@00o`005nl607@/2P231P80O`42
07@10P2410H0KP010985202Z1PX0X@<809/42@2:0PL0O`8708823@2?1QD0X1TV09lH9@2B1Q80S`8:
09P2302L0PT0X@870:D32@2W0PT0X`<:09X21P2B0@<0T00608h1102B0@@0U@470:82302Z0`h0]PD@
0<<84@3;2a<0gAPN0>HN8P3b;Rd0nCdg0?U?A`3fG5D0m6iX0?N5P`3gP7d0nG=Z0?aSEP3kDT<0oU50
0?i:?`3m@CH0oSdb0?dg;P3k;2T0n2DT0?8O7P3R4aP0ePlH0=0>6@362Q@0``XB0;`63`2h10h0/P8<
0;012`2/0@P0ZP490:T12P2X0@/0Z@8<0:`23@2X0@/0X04909P12@2G0P`0W@<C09X24P2H0Pl0S`4:
07X21@1]0@<0O`4508L110290@80QP8307T70`1Y4P80;Yd000Sooooo4000o`00B@1_X2D0U1hJ0;UM
G@3EYZl0chbI0:LA7P2K2RP0=aa_00@VU@029YT00RNK008VX002:J800RRN00@[X00:<9d0842I04iU
V`27TZ/0ZJjf0<71a@3=b/`0d<oA0<[9c`2g/[X0XIFO08IkQ01bK780JFM]06Q[K`1XL6l0LGYg06Yc
KP1ZKVP0JV]Q06UZG@1/JUh0L6aN06e/GP1ZIe/0FUeG04=?C014DE00D5eK05eXG@1/K600LfeN07=_
G01gKel0MFiJ07E_F@1fKeX0MfmM07E^FP1dKEL0MfeI07E]F`1dKUl0NWIW07I]H01`IeL0KVUH071Y
EP1]IeL0JVE@06QXF@1CE4h0<c/f02hk<@15CSh0EUM505]J@`0Fd``02oooool000[ooooo05P00?l0
04iX3P0j2@80>`@105X:1`1Q2PT0APD602410P090@407`4206D52P220`T0N@<506X10`270PL0X@D9
0:P3202[10T0[PD<0;<63@2n2`l0^1DH0>Z1R@37E5d0aQLJ0<hE5`3>5AP0cQDI0<hB603I5QX0jQ`J
0?XV7`3n;R80oBhR0?PW8`3R7A`0ibd^0=LM7P3c=380ncP`0?dm=@3m?CH0nS/e0?i2>`3m?cP0o3Xa
0?/]:@3l;b`0oC8Z0?d_:@3l;RL0mS0O0>I]5`3JZPh0d:4:0;eG3P2j5100_`hE0;/<4P2Y8b@0f/;3
0<SBe035d]80bLoB09YMI`237280`9nS0:bi_`32dML0cM[M0;[5b02ja/P0^/C70:^h_02U/[D0KVQ]
03/G7@0`1@d0B0@=06P6301l10X0M08506<72@1jA4L0?P@405T7101D3`40;8h02Oooool>003o001:
00_g0`19A`P06a8E008F<`0386000R9g00<TP00288000Qn3008MP0017h400R:100L[N`0YBWh0F7B;
07B<T@22UI<0Q9RF09BVY02T/[<0WJR[08nEUP1iNgT0LFiX07=^H`1eKed0MVmH079]E@1aKeL0LW1H
079_E`1dKeH0LFmF075^F@1`KUP0LFmI06m^E01]Ke<0KFiF06IWBP1WHdL0If5206IP?01QGSd0HEi0
069L?P1TGT40I652061P?P1QH400Gf12061O@P1PGd00HF53065QB01RHdd0HFA=06=SCP1QIDh0GVA=
05]SB`1IHDT0Fem:05MLAP1EFT80DeU104iMB`0bACP0:cl]041?>@17Dc`0?Dhh02Uc8P00o`08oooo
o`800?l00440DXH:07T:0@250P80N@<207051@1R0000U0P90:/31`2[10/0W08908@21P1f0PP0P@<=
08P4402;2180R@8:08X11`2<0@T0S`4709H11`2U0PT0ZP880:h3202Y0PP0Y0D60:T8202/1PT0Z`@;
0;DA5`2i2Q40c0dE0=PA603T61h0lR4T0?TZ:P3m;bh0od0k0?e=A@3nGET0oGAf0?^=U03kZKL0nJo2
0?RT]03lU9X0o7Ia0?iSF`3nFU00oU=80?e;?P3nACX0oSdc0?d`:P3m:BD0nB<O0?<N7P3V5ah0gQ@O
0=@?6`3@3QT0bP`F0<88502n1a<0^@@>0;@22P020;41300D0;42302a0PX0]P@;0;012P2T0@H0XP46
0:01202K0@T0U`4909<12@2<0PH0PP8607D10P1n0@@0QP4408/1102<0P<0O`P406hG0008lP48oooo
oa400?l004P0NFdC0<J8R03R`l`0gkG30:/Z?02b1Q@0PA1001<MQ@029YT00RNL008UV@0499<06SB8
04M@Q@1]JHP0R7^=09>7S`2LU9L0XYnT0:BNXP2?R8X0NFmb06mSI01fJ600PWMZ07AbJ@1QJfP0F6UY
059QHP1NHUX0IVMJ07IdI`2?SGl0Zj^O0<K3``32_[l0/ZRT09f=Q@2FPW@0RWQY07ibH@1_J5P0DeQ;
04iJDP1UJ600MgI[07EbI01gKeh0M6eH079/E@1eJeL0MVUG07EZEP1eK5D0MF]H07M^FP1bJUL0M6aM
07Q]H01jKEh0MVmO079/G@1bJel0IfAE05MID012A3X0?dHj04AA@P1<F4l0H6MJ05UH@@0Ge@h;oooo
o`002_ooool0F000o`00@7l803l70@1>1`@0H0`905P:200b0@40700100`1000B0@40A`4506/2101W
0P80HP4107l00`2R1@X0ZP@90;062`2c1`X0^0X=0;/:3P2n72<0`C<k0;HC6P303Q80_`dB0;l>5@2n
3QD0``hE0=TF6@3/7A/0nRPS0?`/8P3m:b@0nR/U0>8_;@3UI6L0b1`O0?@_;`3l=2`0o3T/0?`h:`3k
=RX0nSH[0?/g;P3m=b/0o2hU0?`a:03l<RL0nR/R0?PY703Y<`h0mZdZ0=Rb3@3FW1D0Zb/30;482`2]
1Ph0X0H<0:13A03>cLl0`LkA0;o?d03<cm80OC0j088`=P2SW:80Rj6Y0:c0b@3<gN@0c=[Q0<_Gg03D
gN80bmSL0;G1a026NWh0G38i04063@1[2Q<0R18I088;4@1]0@@0F@<505LE6@1P1`L0J0H305PB0`0_
T@09ooooo`l00?l004T0;;X801lJ6@0274L00b9Z008SM`039X<00RB300<SQP027gh02RYd03MGO`1_
Qi80RYZJ096RX@2GZZL0WZf]08jJVP1kP7d0J6=N075^H`29R7X0WinF0;:b/03<b<X0^;Bi0:RVY`2F
V9<0Rhn408R9O027R7L0Q8=a07n2K@1kNf`0MgUZ079gI`1/M680KgAR06edH`1YLEl0IfeI06=YD`1O
HdP0GV58061QAP1NGdD0GF1505YPA@1GGT80F5dm05QL@P1JGD@0GEe405YLA@1KGd/0FV1>05eTD@1N
Hd/0Ff5705aUC@1PIe80GF9<05]PBP1GG4L0D5E1059LB@11DdD0;T@e03mC@01>Gdh0D69@051H@@0o
B2X00?l000Sooooo0P00o`00E`0Xe@L0NQ<1090710261@@0M1hM05`6102J2`/0YP860:L1202X1Ph0
Q04505`00@1d0PT0P0L=08D73`2200D0PP4508@11P2500@0V`480;L43P300`/0b`XA0</=4P343A00
b10B0<<:3`2n2180/`<<0;l94P3:2Q80d0T@0=/C6@3L4AX0lB4W0?HT9@3n=Rl0oCXc0?i0?`3k>d80
mce80?M2D@3e@E00mcm;0?U1AP3nB4P0o4A20?e5@`3l?S`0oCXe0?`d;P3m<2X0o2PV0?HO7@3d7Q`0
jQHI0=X=5P3A31L0b0XH0;d85@2_21@0[PHC0;P4402f0Ph0]P<?0;X43`2m10d0``LB0<X;4`3A3aH0
`PL@0:P11`2U0@L0X04509X11@2G00D0U04508l10`290@@0QP4508H110240@@0Q00308T41P1m2P<0
KaX0003o0008oooooa400?l004P05N/70<VBSP3L/l00`FMk0;D?7@2j2@l0W@hZ02<LN00299<012F>
01H^O`16BWH0LFAd07m^M@22LWD0R7Ml08IkOP1hLG40KF9M071RE01iKEL0OW1I081aF022LU/0LV]M
05MMF@0kC4T0?e1805eTF021OW40UI2509^GTP2DSh`0R8>308N1PP23P7d0OgYf075aJ01NG500GeM6
079PA01kHdD0LVQA04aDB@1;EU00HfQK07QhJ`21OF`0Mg9M07I]EP1hKEH0MF]F07AYE01eK5P0N71N
07A]F@1fKU/0LfaI07M/G@1iLF80Mg9R07EcI`1YJ5l0GUU?059?@P1EED@0Ee];05IPDP1FHEL0IFaT
06=OB`0Ge0/;ooooo`002_ooool0F000o`00=9T604D90@1D30L0D@T504@71@0Z00008@4101<10@0?
0P40:`4204l21@1G0P<0I04508011@2R1@X0[PL;0:l9302`2``0/`T<0;@9302a2`l0[`XA0;D:3`2l
3A00`0hA0<8>4P3:4a@0fATH0>XU8@3_:R40l30V0>lf;@3/?C<0iShf0=eVI03PX:D0aU9@0=A<@P3B
CT<0cU=60<]CA@3<ETL0c5M80<MCA03:EdH0ae520<Q@@`38C3h0c4Tj0=58=P3:FBl0eJ]10=2b=03@
TC00^3@E0;hO702T4A80Ta8D0:mcM037c]40`<oB0<GBe@36`LH0KAPP080oA02c^;`0W[>i0<7BfP34
eMd0_loF0<[FgP3:fN<0a=KP0<??e`29MGl0EQ0I05h73@1W10X0PPP>08L42@1/0@80EP4206892`1j
2PL0J0P205HE0@0[XP49ooooo`l00?l004T05Nh703<W60047D`012Ug004VO`03;8`00RV:00DWNP0Z
AgD0JWj;08jLW02DXJ40UjBT08^EUP1cNgL0IVML06YSC`1]I4X0LfY>07McFP1fLV40NGI]08V5P`2N
Uid0T8Z>08F1P@1mNg@0NWY^07UjJP1eNF<0M7IT071dH`1_M6H0KgMY071iK01ePG80Lh9e06UjK`1R
Mfh0GG9Z05AZI01<I5X0C65G04ePEP1;Ge@0Bf1H04UNE@17G580B5a?04QJD018FTl0Ae]>04IFC`19
G5L0CV9K05=SE`1IHeD0HfQI06A]G01SKUd0IfiN05]TD@1BG4P0D5U604YJCP0fC400?5A1051TE01F
IeT0FFaQ05]WE00kKRH00?l000Sooooo0P00o`00E`0<m`@0P20509HB1P2F20H0V3a006h?4@2J1`X0
Y@870:L21`2a1Pd0XPD:07d21@1f0@D0O@4408821P250@H0RP8708/11P2A0@L0Y0<;0;P53P3:2Q80
c@XB0<463P2^0`X0Z0890:D1202P0PX0W@4:0:L7402b0`l0^`H@0<H94P3:1a80ia/O0?@P803k:BD0
nBPR0?/Y8`3j9RD0nBTX0?/]:`3l;bX0nbh[0?DU9P3d:2/0ncDc0?df<`3l<S00nbl`0?`^:P3f9R@0
l1hO0>hK7P3_7Al0jaPL0=X@5P3821<0]PHD09X2302`7bd0Xa@Q0:T23P2/0``0[`8<0;/43`332140
b@XB0=8>4`3C3Q80b0XB0:d22P2R0@L0W@8509T1102G0@@0U@8508l21@2B0PD0S`4408/10P250@@0
OP0308031@1l4@D0AW80003o0008oooooa800?l004L0^YEe0>2L[02e:SH0ba<C0;4@7@1N75L03RF6
00lZO00e?VT0Fe=Q06aNHP1cIVD0MVeX071WG`1ZHEH0Kf9A07UZDP25M5P0RWQJ08QeF@20LET0PG5E
081aDP1cJE40DU93061SEP1`L680N7EW07QdJ01hNFd0Q8Mm07EmM`1YMFh0I71Y061ZH@1VJEl0HVMJ
061QE@1OG500NFeE085WA`1hGch0LFeH04M?B01:E4/0HfMG07EcI01oOF`0NW9M07Q]F01eKET0N6aG
07I/E01dKET0MFeF07Q^F@1gKU/0NW1P07QeIP1fM6T0KFeU05aME`1LF4`0JF9C06UUE`1WJEh0G6EL
05mWH01SIel0Iea201cF2@0;ooooo`002_ooool0F000o`00:<H704lD00162P@0<`8102d10P0[0@40
:P8202420@0B0@406P4004XN7`1g?d80IP<908411P2M1P/0[0`@0;@C4P2d4A00]@h?0;/>3@2m40l0
`1@D0<@K5`369Qh0`C0X0<0m=@2mBCd0`ee@0;m^G@2gMVD0]7i`0;27NP2^SX40ZY>90:2GT@2IW9/0
UI><09JAQ`2CTHP0SXj708b<P`2;S8<0QhV008J:P025RGl0PhV10866O020Q7T0PhAh08:2LP1nOVh0
NWiZ07QnH`1nN5l0Qg9Q08MXF@1nGTl0NUY>08EjMP2AVYd0VjR[0:Fa]@2SUiX0NR4R09mdN02/^l80
[<7=0;G8e034e^00c=_V0=;Nj03>fnD0c=cU0<cEh01PAeD0J0lF08@F5`263a80YA4E0:082`1n0`@0
I04106D20`1b1@<0IPl305dM0@0Kc009oooooa000?l004P0@FdC00/O?P04<7l00cVM00@gUP0A=WH0
C65g07N6Q@23Sh`0QY:?07AnNP1TIed0JVE?071[D01]K4l0KVY@071XC@1bJD/0KVM406eS@P1aID@0
NF]=07]]D`20LEX0OgAL07]dF`1lMEd0MG5H07=dFP1^LE`0K7AS069_I@1DIf80A5aI03ICD00`CDT0
<e9>03ADC`0mFUH0<U1<02]8@`0WA3h09d4l02@n>00S?3P07SXe01/j=P0P?CT0:T4k03Q7?@0hB3X0
:T4f01Ld<@0V@c`0AEU:05UUE`1PJU/0GfQH061YE`1RJUT0F69A04mOCP19Fe00?eI904]QD`1GJU/0
GFaR05i]HP1KJel0GfMD02ZY6000o`08ooooo`<00?l005H0RCT>09LO2`2I2@@0TAPE08d?2P2G0`80
X0430:/2202i1P/0^PH;0;L83@2Z1PX0U`8609@2202G0@P0VP8:09H2202H0PP0W@890:/42`2l1Ph0
a0P?0<@:4P2`1`/0X`8609X01`2C0@L0SP0609P2202`1P/0bA4C0=`L603U8Q`0jRPQ0>X[903U<BT0
i3L]0=/f;03E?cD0cT8h0=A:@@3=Bd40cdm60<M:@P33BD00`Da10<YBB036C4<0^T0l0;Pn>@2d>3@0
/C4`0;@`;`2d:2H0^b<S0;TM7@2g61X0ZQ<H080:3@2V<SX0T0L@0:d:402e20h0_0T@0<4940322@l0
a0L@0=0=503A3a<0a`/B0:X22`2L0@L0U`4609D11`2G0@L0U@8707h10`2D0PT0T04408`10P280@80
P@4407X4101f6PL07<T0003o00Sooooo4P00o`00A`1^Wb/0]UeM0;X[;0336R40JBYS01<[P00U=VP0
CT]E05eED`1SFeH0IemH06YQC`1_HDD0MfE6085_CP27Le<0R79C08UdE@27M580Qg=A089cFP1nL5H0
PgAG07YZC@1iJdl0NfiF079XDP1IF4`0@55=04YTI@1AIf`0@EIH051KD`1UIEH0NGQU096AO`2NW8d0
TXV107eaH@1oKE@0OfY<07mXAP1gHd80Lg1N055HC`1^Kf<0LfiN07A]F01`JED0LfYF07ecH01iJeH0
MVA907=YD@1fK5P0OW9T07adJ01hM6T0KViT05mQFP1KGET0H6AH075_HP1gMVT0LG9U06Q_I01WL6T0
IVeS06MRDP1aIbd02_L400_ooooo000:ooooo`09003o000;m`@0Fd/603l;0@0/0P80;04203<10P0_
0@80<08100808@4204d0F2d`0898C@1_1PX0P`<70:D>40328R<0`bXX0;h[9`2e:RD0[C8Y09m3>02J
DdT0UV=I08mjKP2=RX00TYB:09NLT`2QZIl0Yk>Y0;G2^@2f`;T0`<O10;k4_`2d_KP0^<C10;O4``2i
`l00`<O50;c5a02l`lD0_/G60;o8a`2ka/D0^<;10;Bo_`2]^[X0YkFf0:Ff/P2HZ:@0Tj>O08^LV023
UY@0NXj907F;Q01cQh00Kh=k06YmM`1/OgT0Jgaf06UjL`1VN7D0HgI`06QcJ@1cJUd0L7=a07^:T@27
Uj00V:^f0;35d@2icmX0]lcG0<3Cg@2od]h0aM;L08aeOP1K7b@0/hF807PP9P2T3a<0[0d>09@6201m
0P<0K`8106T50P1T60<0Kbl2023@0@09oooooa000?l004P09MX<03La;008=h0014:T01LkMP1;F5l0
KG1/07=iMP1VK6D0GV5>06aVB`1_IDH0L6M906eVC@1/J4h0KFU<06mZC01`J4P0MFQ807U[B`1fJ4<0
MVM4079U@@1bHd80MVM:07M/DP1aJE@0IFME06EZFP1TKV<0DVAL02Lo?00P?SX0BfUP08FLU@2ial<0
b]?D0<?8b02RXid0PH5h075cH01_KET0K6QD06mXE@1ZJ500K6aI06IXF@1RIED0HFEB06ETD@1TI500
FEi904aF@`0kCSh0>d`l05iZF`1MIeP0GVEB061SCP1LHE40E5mC04]NE`1@I5d0GG5W06AeJ`1WMFd0
I7A/069cJ@1PKF00HV9501SD2000o`08ooooo`<00?l005@0GFD208LJ0`2@2@<0QP4109870`2I0@80
Y@450;431`343@l0`0L<0<X=403<3Pl0]@H909h11`2H00P0T`070941202A00P0W`8:0;T94`3131@0
`@X@0<893`323A40`a8D0;8<402R3@l0Wa8A0:dO6P2m;RH0`CX]0<M7>@36EdL0afMG0<EaHP34PgL0
`H]n0<BIR`2oXY80`:VL0<:ZW`37/jL0a;BW0;j_X@2l[Z00]:^O0:bSV02^Y9P0Y9V?09fCR@2LT8H0
VXV109B0M`2IOW@0U7=X08mXFP2DHU80SeA607]>A02HMG40JBDP08lN5`2L5Q<0Z1DD0;<A4P304a@0
aPlB0<h>5@3>3Q@0b0dD0:h43@2L00/0V04;09@12@2G0@L0U@4608d11P2D0PP0SP4408d10`280@80
P00107L60P1^7`D2003o00Sooooo4P00o`00?`09m040Tf`]0;<i=02@<eh08cJ403e1F01GBd00HeY;
06UPDP1]HT`0LEm207UR?022JTH0R6m>08MbE027Me/0QGEF08UdE@2:MEH0Qg5@08E_C`22L500Ofe=
085/C`23K4X0Ofi>06mVC`1JFDP0GVEH06ejL@1oRXL0TINA0:2OV@2NW9P0Si2<08B8P@2<RHL0NgQ`
081eI@27MfD0TH1Y08ekH01jHST0Lf4k06iZE`1[He<0MVQ;07ES@`1eHdX0LF=;07Q`FP1lLf00PG5J
07Y^F01fK5T0KFEB06MQD`1HGE40EEiF05aVGP1/LfH0MW]^07anL`0207EgK@06079fJ`1]L6H0KfYJ
06eZ=00Jh`P00?l02oooool000[ooooo0P00o`00EP1>/a@0A18003P50`0n10<0@`<403L10@0j0P80
:P4102<10@1@3a<0QbDZ08462`2=20h0/1/L0;4[:P2Q@D00Te5<08QQE`20LfP0NWmf07R3O@1gRH40
Mhj907^ETP22VIL0Sj:Q09n_[P2__[h0]LG40<CAdP3Ag>00f^;V0>7Wk03Sj_80gN?[0=oRj`3Ig>@0
e=GP0<k=f@3>cmT0c/oH0<_<f037am@0bLSE0<_;eP3:bmH0cm7G0=OHf`3Mg]l0fmkQ0=SNh@3AfMT0
bM;B0;[8aP2P/Jl0SZ2N082DT@1eRhD0K89m06EmNP1PNWD0H7Ub06=iL01PM700GW=`05icKP1MKfh0
HW9h07>6SP2K[[T0`=KR0:_2c`2W_ld0VZ:_03`?702CHg80JQ0K0:@G702^4Q<0W0L708/31P1k0P80
K@P106@P0@21A0@00?l02OoooolA003o001704RC700R>5d06Sia04Q?D@1NH580HVAF05eMBP1XH440
KV@o06mUAP1_ITP0JVM906eYC01/ITX0KfY;06iXB@1_Hch0K6<n06aUAP1^ID@0LFI306mS?P1`ICh0
LFI306iVB01YITd0H6EF04aGCP0R>C@0948l065kM@2@XId0TYbI08b=R`2>R8H0ThZ30963MP1mKeP0
P79F07AXB01^HD00LV@n07mX@024K400Pfe7085/CP1lJdd0OVi=07e^D`1hKUH0LFU?075[C`1XI4X0
GfIC05UPD@1SIU80HFMB05mXG@1LKFP0GW9_069hL@1^OW/0LX9o06j0N01`P7/0K7]f06QdK@1VJ5P0
KFX^01;]1P00o`002?ooool3003o001D04fI201l9`@0O`L208l50`2I1`<0XP<20:`41P2b0`@0bA4A
0<072P3:3@h0c@d<0<T=3P2c1`X0X`<:09T73`2M2a80X@L@0:X7402a2A00[@/@0:X@402S6QL0X2/U
0:<l<02RB3d0WeU<09iWF@2QL6<0Xgib09n7N`2PSX40XIJ<0::IT@2UX9T0ZZRS0;6c[@2j_kP0alc3
0=3BbP3Hf=40f=WB0=SId`3Ce<d0d=C=0<W>b02maKh0^;nh0:fd/02U[j`0WJJT09>KVP2?UY80Ri2;
08F;Q@24R8<0OX1g07enL@1gO6l0MGU^07]cIP20K5d0OV9D08=JC@25Ac/0UD0e09da:P2X8Al0/1PH
0;HD5P2b31@0/@TE0:D54P2H0@d0V04909L2202D0@L0TP450941102B0`@0RP4308@20`1i2P@0B6@1
0P00o`08oooooa@00?l004<0NU/F05a4NP0n?5D0IU8e06iI>`1cIDP0LF=707QXA`1mJdX0Pg5A08Id
EP27MUT0RgQK08]jF`28MUT0QW1A08YcD026KDX0QFi508A^A01oJdP0PG5D08IbC`20JTH0O6Y<07]Y
C021KU@0TX5f09Z=T@1lM7L0Mg9]07mfI`1gL5l0VIF80:bTW02DRWd0PWES08MiIP28Ofh0VYB@08Yk
J@22K4T0L5ln07IYCP1kI3h0Nf<m079O@@1fId`0OG9Q07ibHP1mKEL0LF=:06QOAP1PH4h0FV=H05YY
H`1TM6l0Lgmh07V0M`1jP7P0NWih07MlM01fN6h0LG1S079ZE`1hLC/06n@900800?l02oooool000[o
oooo0`00o`00E@1E<`T0A0L205h<201P2@L0B`8204P20`0h0`@0<P<605H7302641<0MQ4A07HT9@1o
?C`0OU]E07MbJ`1aNW80Lh1i07F5O`1gRH<0MhV407J:QP1mSh`0P9:A082DTP27V9L0Qi>F08RAU@29
TI<0Qhj?07n5QP1kP7h0OX2007AgN@1bMGH0M7=c079bL`1bLW80Lg5]07IdK`1gLVl0MWAa079bKP1h
Mg@0OGai07ejM`1oOWX0NgYe07elM`1nOg`0R8J50:FTY02o_<40`lC80;:g^P2PXIl0WijI0:6QV`2G
X9T0TijJ08bKV@24V9H0NY2<06b5P01SOGL0HG]d05efL@1NMW40GWE`05acL@1WO8<0PiNR09>X]`1S
IWD0>@dH05`E8P1l41T0Y1dO0:H?3`2N30/0R`@408<6101f2`80KBh203:m0`00o`002OoooolA003o
001500_g101?CBL0A48e05UG@P1MGT<0GEhn05QE<`1TEb`0IU``06MO=P1`I440KVM706iZD01YI4L0
JfE206iVA@1bId@0LVM307EYA`1eJDP0LVI806]SA01]Hch0Jf<o06]T@P1YIT/0AU5308JES`1<HEX0
FfeQ07=eJ@1dLV80NWES071^FP20QG@0W9nB08b<OP1/LV@0FVIQ03Q<A`0Y@SH0?Thg06eYBP1gJDL0
MVe?06e^F@1MIeH0EV=E05UUF@1IJ5X0Ef1@06m]E`1cKeT0LG1N06I/F`1WLf@0L85i07R:R01hS8/0
PiFD07nDT@20TI00OY6=07R>R@1dQXD0KGYf06AXF@1[K3<06^<800800?l02?ooool3003o001D01G]
1P24B1L0N10309/8102T1040[PL60;861@2m2PX0_@X<0;/52@3830h0c0l>0=4@4P3@4QH0bQPJ0;0K
7@2T9bP0W2DV098^:`2CAd80S5U?08m^HP2BOW80T8Ij08f9O@2<Rgh0Shj408f<QP2AThd0UINF09RN
W@2PZJH0[KJc0;W2`035c<d0e=[L0>7Wj@3YkO00l_;f0?Gcn03fm?P0m?7f0?7_m03^jo40k>W^0>SV
jP3PgN80h]cP0=_Ee`3>bl`0b/_80<32_P2n_[X0_k^g0;Nd/02_/:`0Z:RU09^MV@2GVI<0T8n:08N9
P01nQ7X0O85i07MnM@1hOW80N7Y^07MeJ@1kKfH0OFML081FC`28?ST0WC0_0:LP902Y3aL0YPP@09T2
1`2@0PH0R@4208l1102A0P<0S04308@20P1l3`@05]H00P00o`08oooooa@00?l00480:=T?05/n=01Q
Abd0O68j07iW@`1^HTH0LFU?07eZB@20JdP0PVi@08AdF`22M5X0RGUN08]iG026LeD0R75>08A/@`26
JdH0QFa308AY?P24JC`0NF<h08EaC`2>M5H0RVm>08EY@`25Jd<0PVY207aYC@18CdD0NXB209^DR029
NFD0SGaT0920JP2@OfT0SGeX08QkI`27OFh0RX5e08amK@1lJ4T0NfQ207]ZC020LeP0QWQO07meG`21
Mf80OgQV081gIP1jLf40LW9S06eeJ`1bO7P0Mh>107J2O`1dPh80NXN507j6Q022QH00OGmi07ekL@1k
M6D0OV]B06R?;@0DkPL3003o00_ooooo000:ooooo`<00?l005<0A5h604l<0`1`4P`0LA4<068:1`1O
2@P0B`P703@71`0j5140F3L`065LD`1QJf<0IWIa06n0O01dQh00N8Z707V9Q`1gQX00Mh5j07=iL`1c
MFh0LG5U06m_H@1`L600LW9Q07QdIP1kMfL0Og]W07agI01gMV80M7IQ07=fI01fMfH0MgEQ07AbG`1d
M6<0MGIU07IeH`1fN6D0NgYZ07akJP1hNfH0N7YY07IkK01gOFh0Oh5c08B6N025RG`0T9>;09RKV02P
Y:L0ZZV`0:>TZP22QhH0Mga^07IgIP1jNFD0O7YW081hJ020N6X0OgU]08N2M@2@Sh<0SY6508bCR@26
U8h0NXj:06j6P@1RNgL0GgMf05ieM@1EJf/0DeeL04Tm>@1D8RH0Ma4F094D5P2]>SX0WQHE08l91P2=
30L0NA0305=A0P02003o00Wooooo4P00o`00@`1MC0h0GDh^06MM?`1BDC@0ATld04mC<`1OERP0JETY
06IH9`1ZFR`0Kele071V@@1`JDP0KFQ506mYBP1aJdd0KVE406eP>P1/GC<0LV<i07EU?01bHCH0Kf<c
07IX?`1/ID@0IVIA08Z9O01WIED0KG=Q07QeHP1cM6<0DEiC04=HC`11DdT0?Dm603=7@`0bAd@09d10
02m:A015G500IViM07E^D`1fM5`0NhEh06]nM01OMF`0GFiT05eZH01DHE<0Kg=N07QhI@1nPG<0QY26
09JRW02GYJD0Xk6b09^YZP2AX:40TZ6Q08nPW`2@X:40R9RH07j?S01dPG/0KFeO07E`=00aeA000`00
o`08ooooo`@00?l00580NXXN08LS1`2Z40D0^0h80;l?2P2o3PT0_@`90;@61P2o2@/0bPhA0<TA4P33
5QH0/B@R0:Hl=`2HFE40S7=/08eoM`27QGT0RXZ108^=Q02;SH80Si2709BESP2GVYD0W:2K0::WX`2T
ZJD0YZ^Y0:NZ[02TZ:/0YZR/0:FVZP2UY:T0X9fP09VCV02BS980Ui2D09>9R`2EQh`0UHJ909V;SP2K
Si80W8n@09B5PP2GRH@0U8Am09J4O02BPGP0UHIm09R@QP2KTHP0UXUo0961N02?Og<0Sh5c09:3MP2G
Qg`0WXb00:2<P@2OS7l0WY:309jDQP2PUXT0Vi>709F@Q02?SX@0Q8R307j5O01jOWH0NGYd07I`J`1i
HUh0ODQ308<f;`277A/0R@X<09041`290040QP4208L20@201040N1830`00o`08oooooaD00?l003l0
ID8B07YN<P1kICd0FDhf05mOD01ZJUD0MFA407YR?@1nId<0OFa@08=eFP22MEX0QWEI08A]C@1oJT40
PVe408E_B`25KTH0QVe008E/?@26JCX0Of@j081[C@25LE@0RgEC089W?P1kH300N6@l07YiI@2ZZZD0
U8N00:N=LP2[Sfl0XXec0:fDN`2@PW40Rh=g08AoLP1nMVH0PgAM08QhF`2=Of40Rh1V08f6M@2:Q7<0
RhAa09^AO`2LUh/0WijE09^LU`2BUYL0SiNI08bFU`2>V9X0SIBE08JBT021S8/0P8J407enNP1kMfd0
OVmD07Qm>00gb1D01@00o`0;ooooo`002_ooool3003o001C04J2201F4@<0KQ<;06/A2P1N30P0B`d6
04PV7@15@3T0C5UA05AXG`1QLf`0J7Ye06^0N`1/P7/0J7I`06MbI`1YL5l0Kg1K07=`FP1iMF00O7IP
07efH@1lN640NgYQ07UgH@1kMV80NgEQ07YcG`1jMF40MgEP07IgH01fMUl0MgEN07IdG`1fLel0N7ER
07MfHP1hNF@0M7MV075gJ01`MfP0LWY[07YlK@20Ofl0QhId08J5L`1mOfh0O81_07UmL@1eNW00Mg]a
07amM@1oOG@0PX5]081kIP20O6H0NgUT07AbG@1`KEP0L6eF06eXD@1bKEL0OGIR07mgHP1nM5h0PWIP
08AlJ`29QWP0RHYn08:<QP1gRhL0IWil05]dL`1GJfT0E5iK05A2?01/9RH0TalU09dA3`2A2P@0VAD:
07<B1@0fL@000P00o`09oooooa400?l004<09MP606A8501[FcD0FE8e02`k9P0T>bX0@E9105IL@@1M
FC<0I5he06IN>@1[H3`0JF0j06iT@01^JDH0Lfe@07A^E01eKe<0N75D07A[CP1aJDP0M6]9071W@@1`
JD40LFa:07I_D@1bI400Lf0h06mV@P1dMF00P7aW06]_G@0nDTT0>55703iEC01LL6D0ZKFc0<k>d`2N
X:80Oh1_07IeG01RIE80GVQH06imL@2S[j/0Wj^Y07^<R01^NW40MWib08nFPP2Z/:80_/Jo0<WAc`33
c<X0`L[<0;c5b02la<L0]/320:fh^`2/]kT0XJn`09>QXP2:V9T0NWmj07I/DP1[Tbd02oL400@00?l0
2?ooool4003o000V02kL2`1m9P80ZQH60<8E203<6a40bQLA0;l>30376AT0_Pd<0;@A3`2S7Q/0VT0h
09]gK@2=Pg`0Q8Mn08J<P`25S7l0RY25092CR`2@TX/0TYB=09NIU02IVYP0U9JD08f>S028RXP0V9VD
08j<Q@2CSHD0Thf309J@Q02KU8L0VI:409ZAP`2JT840VY1o09N<NP2@Q6h209N9L`0Z0925LP2KSgl0
UHUg09N:M@2HS7L0W91j09Z=M`2ISgX0XYF509nGQP2JTGd0UHMa08ilI@2;NUl0RgYN08]iGP2=NV40
SGQO08egG@2;LUL0Rg1H08]aFP2=Leh0SgUX09F4M@2NSH80XIB;09^CQ@2BSX00PXAl07UkN@1eMgD0
L71Z06YWH01YDT`0JbLS094C4P2;0`@0P@4108010@1n1P40F4h40`00o`08oooooa@00?l003h06=h3
07eI9@24J3`0Hei204Y>@P12C400EF5D06mbI@1gKeh0NW9J07U_F@1mLU/0Og9K089`E@21KD/0Pfe8
08MaD028ME@0R7=A08M^A@26KD00Qfe108E[@020JT<0PVm<089bD@2>NeX0RG9:07eX?01dI480Ng9O
08=eH02aU7P0[Y=l09^8M@2IPg00QWIT08=fI020M5h0QgeU0929L`2@RG@0UI9m09^LRP2UY9/0]kN^
0<73^P31_kX0`;fk0;bm_02b][H0Zk6c0:V]/02TZZh0UYnS08fGV022RhP0O8:007]jLP1nLE`0IY8c
02OM3PL00?l02oooool000[ooooo0`00o`00D`14Y`d0EQ@206dF2`1X4`X0Ea8:04D_7`1=Dd<0DEaC
051SF`1HKVH0IGUa06EfK`1NKF40Hf]K06mdG@1dN5l0MWQM07UdF`1jM5h0NGEM07egG`1jMEh0NWIN
07]fGP1lNF40N7IN07UdH@1kMF80NWAP07YhH01gME`0MWEK07MfGP1fM5h0NgIR07]hI@1dM640K75O
075hJP1^MfL0L7MV07MjJ`1hNf/0MWUV07UkJ@1fMfH0LWMS071dH@1cM6L0MGEW081oK@23OF/0P7UT
089iG@27Med0Q7AK08QkH@22N600LfaE07=ZDP1aJE80MVmH07A`G@1kNFD0MWAN07UdF`1lME/0OGEN
07acFP1mM5d0Pgi^08:6O@1jRXH0HgQh05E^KP1CJF<0F5MB06HV8P2?5Q80R`P309LI3P1P40@09hX1
00800?l02OoooolA003o001102;F0`1dF1l0Ie`c049=>00eBcX0<4Pg0316>00mCcd0EEi:05mTC@1S
IDh0IVM?06UYCP1]JDh0KfYA07=]EP1cKUH0Lfi@071XB@1fJdd0M6a?07A_DP1fM5D0N7IH07MdFP1i
LUX0OG5D081aC01hJT<0Mfe=07YcE`20Me`0RgmM091oFP2AOU`0TGeJ08aeE`27MEd0QGaT07iaD@1l
LDh0IfUB06ebF`2<QW00Z9nC0;2[Y`30_[P0fm[C0>oajP3fnO@0k>o`0>?WjP3LhND0emgP0=_OhP3M
hnD0eMcP0<;;d02b_<00Z;>f09j[[02:U980NgQW07J1>`0ceQ@01P00o`08ooooo`D00?l00540PcX9
09lN2@379QT0`adC0<DF402h4@d0[B4M09hW7P2?C3l0Q6IJ08QmM@26R840PX^308NBR@2=V8l0SYJ<
08^@R@26R7l0PX9i08N7OP29R7l0SHMm09>>P02DT840VIF:09^HS02GTX@0Ui5n09^CP02JTh00VY:0
09F>N@2HTGd0WIN40:2IQ`2MU8@0Vi=o09Z@N`2GSGP0Vi9m09^@OP2GRGL0Vhmk09fCP@2MUX80WiR5
0:6IQP2QVHT0XY^;09V?NP2AP6L0SgaT08alH02?OF40S7]O08UiG`27NF00QWMN08AbF@25L5T0R79I
08ehG02IQVl0WHil09F8MP2@P6d0SGeX0921K@2>Q7<0SXQl08N3NP1mO7D0LG5]06QZI@1RETl0JSD/
07TJ50202@T0O@<107l@101=C@<00`00o`08oooooa@00?l001008M<308iX<01jJTP0IfeP05iZH01H
IEX0Ce]A05IQF`1bNgD0P8Qn07MhJ`1gMfH0OGUW07]eH021Mel0QgUP0P2;OF<0:P28O680RWeP08ao
H@2<P640SX9U0966JP2CQV`0TH=Y08YlH`2<OfP0T8IZ08n5IP2?Q6H0SHI/09F:L`2MTgl0XYj;0;R`
X02h/:40^KBW0<6n/`37a[`0dM?90=[Me03Pi^00fMoM0<kBe@35c/l0`l_<0<W>d038bll0`/K80;o7
a`2e_/00YJfb09VOY02<Si@0PX:507YeKP1mKUL0Dj4[02WM4@T00?l02oooool000[ooooo0`00o`00
5P0Cj`@0I24406`I3P1N6a00Dc4S04Y@>`1<FdX0E69F05e]HP1OKf80HfeJ06U^F@1aLe`0NWIL07Uf
FP1iMed0NWUP07eiHP1mNF40NgMO081fG`20N60207YfG00E07IcF`1hMUd0OGQS07ehH`1iMed0OGUQ
07agH01hM5h0MgEO07IdH01cMF40KgES06]bH@1YLF40L7EW06edHP1bMfH0MgUY07EgI`1eMVH0LWIT
0080KWAR02@0LGAS07AdI01iMF40NG=M07E[DP1eK500MFmA07YaE`1jLUX0N6mD07I[C01jL5D0LFU?
079[D01cKED0N7EP07YgH@1fLe/0N7AN07YcG01kM5h0LW1D07IcEP1kL5D0OG1I07adH@1kOG80Kh1k
061gM01HKVT0FUaF06DX8P256Q@0Qa`@04d<0@0UR`42003o00Wooooo4@00o`00?`0Xf`L0NUhQ05UH
>013ETH0?UM804AJC@10EdP0?eA004ED@@1BFTP0FEe<05UQC`1PIE80KW5M06icGP1_LUd0Lg9O07=c
G@1bLUd0N7IQ07UjH`1hN680MgMP07EfHP1mP6d0NgeY07]jI01nOFL0R8Q`08b<M@28RW80SHeb096C
MP2FV7d0W9^209nMP`2TXXT0ZZ^F0:jaW`2`/ih0^kbX0<C6]03EeLD0k^_N0?gkm@3oo_/0o_km0?ko
oP3no_h0nocm0?7bmP3Si^d0emoV0<oJh@3?fN40bmCJ0<?=d@2g`/H0ZkNh09bTX@2:PW00II@h03_=
6008003o00Sooooo1@00o`00D@1DWa00WDH`0:4U8038ATL0[1lH09@f:P27H5<0Mf]M079gJP1nPWT0
RHZ408R;P`27RH80QHMn08B6N028QWP0SX]k09:>N`2CSGP0V95o09ZCPP2FT7d0VYF109J?O02GT7l0
Thak09J@OP2IU840W9F209bDPP2KUH80Ui=n09fGP`2NUX@0X9^909nHQ`2OUX@0Y9^:0:2KR@2QWH`0
X9^;0:FNS@2QVhT0Y9n>09bJR02PVh`0WIV<09bKSP2LW8h0V9F709::N@2@RWH0SX]h09BGPP2CUXD0
Rhf208F;P@21R800Qh^308^<PP2>SWl0TXmm09F>N`2JSW/0W8mj09f?N@2JSG@0VH]b0920J@2;NF80
RWYU08f2K`2:PW80Pgmc06m_J01OGEH0FT]005h[8P1h4PT0LQL902Z60@03003o00Sooooo5000o`00
900Ue`D0S6H^07idGP1]MFd0JWQ^06]hK`1XM6h0IgA_065aKP1WM780NhF008bDS02;ShL0R8f108Z;
O@27QW@0RXQf09:>O@2EU840W9^409VGP`2@SGH0SHUa09NDO@2JUh80V99n09nJQ@2PW8H0X9f409RF
O02IU7h0W9Z50:ZZU`38bKX0iNKK0?Shm080oogm0P3no_d04P3no_h0lO?d0>GXjP3RiNL0h^CV0>7W
j03Qi^L0e]gP0<kCfP2m`lT0^;o20:Ra]@2MYJL0TiNI08=nO01kK5`0N7`h02[O4@/00?l02oooool0
00[ooooo1000o`003@1<P`H0IS<I05Y6<01=C3D0DEa505UWE01LIUH0H6ID06i_F01dLEH0MG=J07Qf
GP1eLUX00P1nN5h00`20Nf40OWUL07ihG@0207]fG@0n081gH01mMeh0OWQM07agG@1lMEd0NgEM07]e
GP1iMeh0OWYX07]eH`1lN6D0N7MU07EiJ@1]MVT0J7AU06UfIP1aNfd0MX9d07b9NP20Rgh0OHQl07^8
NP1fPW<0K7IX06IbH`1ZMVL0JG=U06ecI01dLel0LVaB07E]C`1bJT/0MFa@07E`E`1bLE/0LVmF071Z
B01jLeL0Mg5F07A_E01mNF80OgeW07AaF01gMEh0O7MN07YbF01iLUP0N7EK07AaF01dKe<0L6]?06aU
B01TGT80KfUD07AeI01[MVX0FfaY05QLF@1?;240DQL903h>0@0Aa002003o00Wooooo4P00o`00:@1k
K200DU8c04YOC`15Ge80BV9G059YG@1IKUh0FVMJ05iXEP1MIDl0EV1=05APD01HIEL0GVYO06AbIP1X
LFD0JgEX06mkK01bO6h0MX1b07QoK`1lQ7<0P8Ul08:<OP21SG`0QI1o08VEP`2;UXD0TiZ=09FMSP2N
Z9L0Y[>R0;S2]039c/D0fmkF0>c^j03cmO40moWg0?cmn`3no_`0o_on0080o_kn0140o_ko0?_ko@3c
m?L0j>g`0=gUjP3Hh>@0eMcR0=?Jh@3@fn00b]GJ0<KAe`32cM00^L?40:BXX`2AQVh0JiTh02WO4@0:
003o00Sooooo1@00o`00D@0ciAP0XFYE0:M9A@2Y:B@0UCl`07UUE01`KV80L7IX07^1L`25QgX0Q8=h
07eiK026OVl0U8]j09>?N@2ETG`0Ui5n09^DP@2HT7`0VI9o09VCO@2HTWl0VYF209ZCP02ITX00UXml
09ZBP02LUX<0VY>009^DPP2IUH80VYR609^HQP2GUH<0UYJ309^HR02OVh`0X9Z=09bJS02JVh`0WYnB
09ZLSP2PWi<0ZJRM0:ZZW`2^[Z@0[[6X0:b`Z02X/:L0YjnX0:2ZY@2IYId0VJBL09RSVP2EWI<0PX^2
07^4O@1eP7d0MX:207^7Q@1gPgh0PhMn096;NP2LT7h0WY5l09f@N@2LTGX0WY9k09f@NP2IRG80V8Qb
09B4K`2CQ700P7ET08R2L`1hM6T0GeeC05I;?P1J91<0D0h001?30@03003o00Sooooo5000o`008`0;
mP80TFHZ07agH01dPGP0Kgeh07J1OP1kQ8@0Ohb<07n=S@24T8l0Q96>08NET`2:UiL0WZVV0:Zc[@2i
_[H0^l6g0;o2^@2j_k<0`/Rk0<36_031a[X0^l2c0<76^`3:cl<0blo30<g?`P3Cel/0g>3C0>CUf@3/
k>@0mOG_0?cln03nood0o_km0080o_kn01@0oooo0?knoP3nooh0o_ko0?gmo@3mo_h0o_kn0?gno@3b
loH0i>O[0=KIgP35bm00^l340;6d^@2UZ:/0U9:>08IgI@1KVC<0><XH00_g10`00?l02oooool000[o
oooo1000o`006@0Wf`/0Gd`S04m;;P1JGT80HfE>05YNB01DFDH0HFAB075_E`1hME/0NgUR07eiG`1l
N5`0OGEJ07YdFP1kMed0NgIK07afG@1mN5h0PWYQ07efG01lMUX0NgII07afF`1lMU`00P1jMU`0:P1j
Mel0NWYX07YlJ`1iO6/0MGU[06efK01ZNW40HgI]05M^IP1CJV<0CfUT04YVH@1:HV40B69O04YTG`1?
If<0DVUU061eK`1[O7H0IgMb06MfK@1[Lf@0Kg5L07=aF01dLEH0LW1G06i_F01^K5@0MFeA07UcE@1k
MUd0NWUS07elI`1oO6T0MGAO07QgH@1iMUd0NWEJ07]fFP1hLe`0Mg=L07E`EP80MG5H00X0LfiE065O
AP1EF4<0Addi05MIA@1_KE`0FVEI05EMD00j9QD0>R410`00o`09oooooa800?l002<0B[@@06EH:01<
FTL0CFEF05AZG`1GKFD0GW=Y06IhKP1_OG80Kga/06YhI`1VMVD0IWAU06AbIP1VMVd0JGQ_06anM@1/
OgP0N8Z607R;Q`1nUHd0Qi^E092RW`2FZJH0WK6[0;34^`2ibkl0c=[?0>7ZhP3dmo80n_gi0?goo03n
ooh0o_kn0?kno@030?knoP0D0?kno`3jo?d0mOSi0>obm@3Xk?00h>GY0=_PiP3IgnD0dmgP0=7Mh03A
f]h0bmKK0<WEf036dM<0`lg?0;Fh]P2VVXd0RI=I04no:00Fl0T<003o00Sooooo1P00o`00D02KMdP0
Q2lQ09@o<01hGTh0KFiO07AgIP1kOfd0Ogm^08EoK@29PFd0UH]h09J;MP2FRWL0UHmi096=M@2ITWl0
VYB309fFQP2OVHL0Wi^90:2KS02NVX`0Wib>0:2MSP2NVhl0WibA0::QUP2VXiL0[ZZP0:NTVP2KW980
XJ:F09VKT02KWY@0Vj2I09jVW`2U[JH0]K^c0;Fl]@2`^;80Z[BZ0:je[P2//jh0[KF^0:RaZ`2FWIX0
T9RF08F?S01ePWd0KG]f07J2N@2?UH/0XZBI0:f/X02HUXL0QX1`07YeI01bJE`0GUeC05IOE@1ZLV/0
QH=f09B9N02MTWd0X99k09jAO02NTG/0V8]c09Z=MP2OTG/0V8]e09F<N`1iM6D0HV9C07=^G@20N6H0
JF1@05Lo;0164P@04/<10`00o`08oooooaD00?l00140C;@D07m/C01dOG80N8R0086?S02:UID0TYjO
09>RXP2JZ:L0XZj]0:Jb]02JZ:/0ZkRi0<3;b`3Bg=`0gnKU0>?[jP020>S_kP090>O^k@3Zlo40j?3_
0>kcl`3cn?L0loKf0?Gin03io?`0o?gm0080oOkn01L0oOgm0?clo03lo?d0o?cm0?_ko03hnOT0n_Wi
0?SinP3inOT0o?ck0?knoP3moOd0n__k0??dm@3[k^l0i>SZ0=[Jg030_l00[:BO0:6>O01QXSl0@/8P
01K`2P0?003o00_ooooo000:ooooo`@00?l00100=<D=05I:7@1VHSd0IfM7055A>01MGdH0Eee805eV
E01_L5T0LW5D07MfFP1lN5h0OGUL07]dF@1kMU`0NgIN0P1nN5h0?`1oN5h0OWIJ07aeF@1kM5L0NgEJ
07]fG@1jME`0MgIO07IhH@1hNVL0LWQU06U`H@1TKV40DF9I05]cK@0lF5@0940m02M4@016HU/0HWmd
06f7O01lTHL0KXIk05MbI`0_CD807S`d01D_;00I<340;TM704eTH01PK6<0JVeN071`GP1UIE00K6mH
07QdFP1mM5L0Ng=E07aeE`1jM5`0PX1[07emJ@1cLeh0MgIN07YdG01jLeT0N79H07]dG@1mMf80N79K
079/C`1fL5D0MW1H079]E`1NHD`0B5E302U0<P0V>Rh0EELo06Y[DP1HI540@chY02i?0@03003o00Wo
oooo4`00o`00;@1DWQ<0GUPc04YMC01GK600Gg=Z06=fKP1YNW40JWac0720M`1cPGL0MXEj07B5O01i
RX80NXj708BGTP29VYH0TjFT09JYZ@2L[jh0Zkfn0:no`@2kc<d0_LoA0<[JfP3GiND0h>_/0>cbl`3l
oOh0oooo0?gooP3no_l0o_kn0?clo@3ino/0m_Oi0??em`3_lo<0j>o_0>3Wj@3Qj>X0h>[Z0=gVj03L
i>P0gN;W0=CJh0020<cEf0070<[BeP39c]00]kRb0:nQSP23X5P0DL0/027X3`0?003o00Sooooo1P00
o`00C`1]`CH0LD`^075MA`1fJeX0OWUV07]hI01_K5/0QGm/09B:M02GRg@0Uhei09^CP02ITWl0WIB2
09jHQ@2LUhL0W9R=09bHSP2PW980XYnD0:NRU`2VXiD0Z:BH0:VVVP2YYYl0[JVR0;Fa[P35`L00e<gA
0;nl_`2TYZH0TIZK08:=T01nSHl0O8^>07V;R`1jRhP0SYZE09fUXP2X[Z/0[KB^0;2d/02g_;P0a/_6
0<O<b037c<`0b/o>0<35``2d]K@0[:bW09^MU`2d[k40a;k40<>k`02]XIP0UH=_09V0IP2GMUH0R6]:
07UUA`1VFdL0LVYF0964K`2NTGX0Wi9i09f?N@2LT7T0Vi1k09Z?N02JSgT0UH]h08^8O@1TJ680?DXo
04E;?01QFdH0P7AL06eLA01F<ad01000o`08oooooaH00?l002D0FIlL07e_DP1mPgT0QY:=08^JV@2I
YjL0Wjf^0:nk_@2jaLL0`lc>0<;;c034cLh0bmGG0=OPh`3JhNH0f>;U0=WTj03KhnP0g>CX0=cVj03L
i^X0g>KX0=SRi03Li>L0g^KX0>;Uj@3Qi^T0i>O/0=kTi`3Ri^X0i>OY0>S/k`3]l_<0l_Gf0?Ogn@3g
moP0mOGf0080m_Oh00X0m_Kg0?SgnP3fmOD0kNOY0=K:bP2o[:40SZMU05bf=@0[h1H03?P64P00o`0;
ooooo`002_ooool4003o001A042M201YG2l0JVLo05MJ>`13BS80CeDm05YRC@1IIE@0JG1I079bEP1g
MU/0N7EK07ajG@1mN5`0O7MJ07afF`1lMEP0NWEF07egF01nMUT0OWEI07agF@1kN5/0NGUQ075dH@1_
M6<0J7=P06A_G`1AHE<0?59702m7@00[ASd0<Tm5059XGP1QLVH0MX=i086>QP2DXIh0[KFe0;k2a@33
a/X0a<W;0;:l/P2GX9@0SIJ;065cJP0dCd/0Fg=b02`o>01EGDd0Lg1M07YcF`1mN5X0OGII07eeF@1j
ME/0NgUQ07elI@1dMEl0LgEM07IeG`1lMeh0OWEJ07idF@1jM5X0OGAM07mfH01lME`0NG=I07IbE`1a
L5L0KG1M05AOC`0cBS/08T0b02E0<00gB3@0IVI906eVC01FB38088d100<00?l02OoooolD003o000b
03jn4`1WJC00G6A=06=bIP1XNW00K7id06f2N01fQGl0NXR307b>R024UI00QiZG08nSX@2DYjL0W;2^
0:Bg]P2a`/<0^LS:0<3>c`3>g=l0g>WY0>_clP3dnOT0m?Sh0?OjnP3fnOX0loOh0?;fm`3_l_<0l?Ge
0>calP3[l_40k??c0>W`l@3]lo@0jO7b0>C]kP3Qj^X0fn;T0=ORhP3DgMh0dM[L0=GJg03?dMD0`[jk
0;BZW02OVW80IK<o04_;9P0<n0DB003o00Sooooo1P00o`00C`0ocQX0KUL`079TA@22MEd0L6MB06YT
D@1XIUH0P7e]08j6M02ISgX0T8Yd09B>NP2HU800U8]k09B;NP2ITGl0VHf009jDR02OVhd0WYR;09jF
R02NV8H0W9J509VDPP2ITX40Vi2109V?PP2JT8L0U8b408:1P`1QJFd0EFE/04]KG`1>Ged0FfIS08B<
Q`2V[ZL0alo80=gShP3Xk>h0jNWa0>GTj`3@bm@0^;>i0:BNX`2>R8`0OWIh07a^JP1mJ5h0PfaL08Md
GP2AP6/0VhQi0:6?P02QSgL0X8m^09f8IP2CNeX0TWA?09QfC@2?L4X0P6U408afE`2TUGd0WY9m0:2C
O`2JSWX0WiF009N;MP2HS7X0TXj206Y]J`16DTh0AEA604aDA@1CEDH0MG9K08=bE@1ZC2d01000o`08
oooooaL00?l001@0;<h>07Em>P28PG00PHN0096KV02QZjX0Yk>e0;6l`@2i`lH0_/O;0;c6bP31cLl0
`loB0<G?d`38dM@0am7E0<OBd`34cm00b]OG0=3Jg080c]SJ01H0e=_N0=WPh`3Kh><0f^3S0=gRi@3K
i>D0gnGU0>7Ui`3UjN/0jN_^0>c]l03_l?40l_;d0?Ccm@3bko00i]kM0=[8``3</J<0Vjm]05S4>P16
dbD03?P65P00o`0;ooooo`002_ooool4003o001A05j54P1dIc/0Kg1A05MSC017Ed<0AUE304YIB01@
GTl0HVaK06Y^E`1bM5/0N7IN07ijH@1jLeL0OGQI081jG01oN5X0NgED07YbDP1kLeL0O7UP07AiH`1Z
M640FfYI04eOE@13ETh0<Ta202=0=P0]BCh0?5=4059RC`1OJ5<0JfY@079XC01dIdP0MfY607Y[AP1e
K4l0OWY[09ZISP2NWi<0Q7i`08EgG@2=N5H0TWaN09J>N01`LV<0Qhb106E/F@1DEch0MVa>085eEP1o
N5X0O7QP07ekI@1jNfD0MgIR07EdGP1fME`0OGQM07efG`1lM5X0OG9I07idG01jLe/0OgUS07YeH@1i
M5h0LW1J06]_F@1TK5X0EfAG03=;@00/Acd0<T`n03M??`0oF4T0GfYE071UA01aFc<08;4100<00?l0
2OoooolE003o000]00[g0`13]AT0JG/g06]ZC`1^MfH0Lh5e07V7O`1lRH<0OXf:08FFT`26VYP0Sj>S
09FVZ02P/[<0/;no0;g<b`34d]D0cMgN0=SVj03Vl?40jo?c0>gem@3`m_H0l?Ce0?;em`3_m?@0kOCd
0>odm@3/l_<0jO7`0>O`k`3Uk^d0i>g/0>?Zk03Ji>D0g^GV0=oTh`3Hg=T0bLS00<:i[@2jZY<0Q[AQ
06Vd@012db<05o4:01H00?l02?ooool6003o001?04jU501kGcL0Q7AA06YQA@1=BcH0De=205iQE01n
OW40R89`09R?N`2?RWD0VYB108^5LP2BQW80TH9[09B5K`2BPV/0UHQe09B=N@2DSG`0UHil09J>N`2H
SgX0Uhmk09Z?O02LTh00Vi9o09N?O02>RWX0HfQS04=<BP11CTP0I6aQ07=dI`2@RWd0W9F=0:RPW02/
Y:H0XiZL09>7Q`28NGP0QWE]08mhJ@2ANF80VH5Y09n8K`2RRFd0Wh=O09]lDP2<LTh0SGiT09F9K`2J
SGD0XYR30::JQP2HTh80TXin07imK`1hJe@0W7Y?0:1iB@2GMDH0PfM40::?MP2MRg@0VXMb09>1JP26
MEX0Q7AK07meIP1YKf`0BUMF04YGD01?G4l0EV1A05eXF@23RW/0RWeR08AS?@04003o00Sooooo6@00
o`009@0gb1@0H9la08ijF@2FRgX0YJ6J0:jc[P2a^;D0][jm0;K1`@2g`<40_lO:0<?;c@33b/`0_/_=
0<3;c02oalX0_/S90<C>cP37cm00aloA0<W@d@3>e=H0d]OH0=KIf`3Kg=/0fMcI0=cMfP3JeMH0e<_:
0=K:aP3B`kX0cKBR0:neP`2B^FT0Il93057=;00TjQ806`00o`0;ooooo`002_ooool4003o001A06:9
6@1aJD40MWiW061aG@1CIE<0CV1>04mOD01DHUH0Gf]P06I_GP1WL5X0KW9L07QfG`1mN5/0NWEF07eh
F@1nMeT0OWUM07mjGP28Q6T0O7iW06QcH@1<HE@0=4m702=1>@0K=b`09Chc045GB@1KJ5D0JfeA075/
B@1gIcl0QFdn089^@01hJ480MVI208UhD020MUD0PX5]0:JSU`2g]jd0Ti5n089gF02AOEP0U7eG099k
F02@OEX0OVe;07EV?`1iKdh0OgAL08Z4K@26Pf/0OGaW07UjH`1eMUh0NgMM07ihG01mN5/0OWUM07mh
G`1nMed0O7EM07efG`1lMf80NgMT07McH01eLEd0JViK06E`H01BGe80@553039>?`0gDd@0?5I7049M
C@1=IET0HW1P06EQ@01hIBl07mH400<00?l02OoooolH003o000U01cU2P14]Q`0HI@e07QnC@1oN640
P7m^08:9O`22T8X0RYZH08nNW@2I[:/0Y;Rg0;72`@2ib<X0aMGF0<_Lg@3Fhn<0g^SW0>7/k03Uk^h0
iNc]0>S^kP3Xl>l0ino^0>W/k`3Yk>h0jN[X0>GThP3Lem80e/g50<k1]037]J00T/1c07fhE`1EaSD0
=]XN02?Z4@0K003o00Sooooo1P00o`002P1ZSB80T7==07e_D@1@CcL0C4lj04m@?`1?DD<0IFIL08:0
M@2?R7P209VBP00:09^AO@2ERG80Th=Z09^<LP2?OfH0TWiU09b;L@2JS740UHM[09F4I@80V8AV03L0
V8=W09^9L@2MSWT0W8ei09J;M`1`JUD0LfYF07Q^E02:Neh0TgmO09ImG@2QQVD0Y8Y[09>1J02TUh@0
`KBV0:ZMS@2CQVd0VXMW09J8I`23P6/0QH=d08ElJ02MR6D0Vg]=08ahE@1VIUP0Ogmd08N5N@2LV8h0
YZ6F08n;P@1mNFd0K6]I085_C@2UPe00YWe809mjB@2FOEL0TGaP08ehG02?OEl0SGmR08=kIP1cLVD0
G6EM051OE@1AGU<0FFAG05eVF`1UL6@0LWec086:P@2ISWT0UW5300@00?l02?oooolL003o000L01oU
2`0hbAT0AkX[07>OAP1dXTh0TIeY0:VEP02/VhX0/Z:H0;JXWP2dZYl0]jjS0;J]Y02i[:80^J^Q0;Z/
XP2n[Z<0_jfO0;^ZV02oZID0/:V008ZhJ@1m^5P0ELLj05S5=@1@c2T0<>@I02G[4B400?l02oooool0
00[ooooo1000o`00D@1TS1/0LVa807IoKP1]NVh0HW=V05i_H@1OKV80HViV071lM01mR7d0MX=b06A_
FP1VJDl0KFY<071[A`1dKDP0NG1@07egG@1nNf80Og]R07UjH01UL5T0>Dlm024k;P0hCcd0DUm7065X
C01]K4`0O71:08]hB@2;MCh0SG4g08if@@1OES80EE8d065K?P1VHTD0KVmG07UjI`22P6l0O7a]06ib
H01YJeP0EUY804I>>P1aJD`0Q7=>08YfCP29LD00Q6`n089aD`21O6D0NgaT07]iH01nNel0P7aM07mk
G@1nNU`0OgUL07mjG@1nNE`0P7YP07ihG`1jM5X0M71I06e[E@1WI500HVE?05UUE@1<Gdh0AEM604QJ
BP14GD`0BFAE051WG@1=IU/0E6aS065^HP1SHT<0OfT]01kU1`03003o00Wooooo7000o`006`0Gl0T0
:=lA03W;6`16^BD0FJXe06bNAP1YXTh0K:MG09>JLP2RV7l0[:6>0;2VU02i[IP0_[6M0<6aW`34/ih0
`:nH0;FeT02K_Wd0S;m`08jjJ01m^UL0F<Xk05W9=P0ig280;nDJ00ci1P0Q003o00Sooooo1P00o`00
C`2NM3L0TgMB081hHP1?E4@0CeA304mDA@1CETP0DeM:05IIDP1gN6l0RhUj09N@O`2HT7`0XYJ40924
KP2FR6h0WHed08ajH02JRW40Y9Qm09Z=L`2ISFh0Vhi`09f<L02KR6X0VhY`09^;LP2MSW@0Wi1g08Uf
EP29KdH0UGQ:0;JHKP2eUg00[I1Y0:b=K02]TG00Z95f09jAO`2LU8<0V95o09ZEOP2BSWP0U9F10::V
V02KWI40M6]J09V1G`2SP500XXAJ06]OBP1fKEd0QgIP09:7L@2ZYI@0S8Mi07egJP22O6D0UGaC09em
B@2LNd/0ZiEb0:RKP@2YWHT0[jNG0::NSP2;Rgh0IfaU05aUH01MJF40Gf]K05iYFP1QKUl0IW9X06ij
L01fPGT0Q8^509B5K@2OMC`01000o`1/ooooo`002_ooool4003o001@05RR601_IT00N7i[07R3M`1h
Qgd0LhAk07:2N@1fQW/0NHUm082@Q`1lSH80NHYm06]gI01XL5L0JfmA06i/C01cKe<0N7QO07YmIP1n
P6/0PHA]06a[CP1WI3l0KfU407Y^BP1kLD`0P7EA08UkEP2:N4`0SgU9099iA`2?M3h0SgM607eaC@1e
L580MG9H06ieG@1NKf40M81j07j9Q01AHE`0:40e02Y0<P0bBc/0A5]706U[CP2<Ne<0T7Q:08]dA@2@
OU<0QWYJ089lHP22O640QX1Q08AoH025OV00PgiR085lH01mN5P0OGIH07M^D@1cJTd0LFM<06YUB@1Q
HdL0FV1;059QC019GTd0Bf5D05AWF01KK5/0Ff]O05U^I01GKfD0FFmY05ibJ`1LKfP0IFiN06mT?@1R
Vb04003o06Wooooo1P00o`00C`1fVBd0SgQC089nK@1PIUX0EEa=055IB@1EGDh0EUe?05IMD01MHeX0
O7ig096?Q02ETH80X9Z;0:2LRP2NUX<0XYV80:ZRT02PV8D0Yj2?0:>KRP2PVXL0WiV60:2FQ@2OU840
W99n09ZBO02ITg/0W9=n09Z4IP2INTd0/99U0:Z@J@2^SfT0/Y1Y09n6IP2IPFH0XHM]08AlK`2HVXl0
ZjfP0;FeZ@2j^Jh0Z:FI08^7N01nMf40TWaM0:F8G@2VPDh0YH1?09Z1G@2KQf/0[95e0;NUT`3<a<40
SXMo07a^GP2<NU`0X8YU0:^HM02`XXL0/:VI0:VUVP2SXIX0QXR307MkL`1ZLFH0IVeU06U`J@1WLFT0
Jg=Y06agK@1WMF`0K7Yd07AnN`20R880SH^209=hD`1C_1/01000o`1/ooooo`002_ooool4003o001@
01kU201nIc40Q85V08B=OP23T8T0Oi6;08:ET028ViD0QIJ?07nAR`1oTXT0Nhj607J5O01gPWP0N8Ak
07N3N01eOfh0LgiY07AjI`1fNFP0NG]X07a^A@2<L3L0Tg@m07m[@`1^KUD0LGQW07IlK@1hOVX0MG]U
07YnIP24PfH0SHIU08f0G`2>P5d0UX5R0::?M@2XWXh0ZZFL0:NSX02@SH40QGYP08QfDP21M4h0P7=9
08UhB`2AOU<0TH1H08n5HP2<QFX0S8E/08R2J022O680OWUL07afEP1jLU@0Mg5D07=^D01aK4d0K6]=
06]XCP1WJ580H6AB05YUDP1BIE@0DVUL05=ZG`1GKf<0GgI[06MjK`1XNG40IWQc065fLP1ON7<0GgM_
06EkL01UMFX0JfI707Ej:00DkPH4003o06Wooooo1P00o`00?`1W[2H0WhQS08B1KP1/LfP0GfML05]Q
F01FH5@0FV9F05aUF01NJUX0I6MO06IXHP1cMFh0SXf609^HT@2OWI@0ViV=09bHR`2NVh`0WYZ;0:>M
SP2SWXd0Z::A0:jUV@2[XID0Zj>D0:ZWU`2YY9D0Z:6B0:>GQ02BNU`0UgiH09j7H@2TRFH0^9Ed091l
H`2ANfH0Wh=/09N5M`34_[/0/k2/0:fUX@2QTh`0TH9`08mmH02IOUH0XHEJ0:jFK`2ZT6/0Z8mX0:ZE
KP2VTg<0YI9e0:FEO@2XV8@0Z9Mm0:JFOP2fZIP0/ZZM0:ZWW@2MWYP0Rhj90825OP0207EjL`0=07El
LP1lQ7T0PXR007V2N`1cP7X0L7mh07:1NP1]P7X0NHJ208J9P`2;R7`0RGMN05be:005003o06cooooo
000:ooooo`D00?l004h0EJ4H07e]AP2<TH00RYVB086FT@26ViP0RIfK08BHU@23UY@0S9fH08FHU021
Thh0QI:=08:AS01kS8<0NH]n07f;O01oS7d0Nh=e07YnK@1oMUD0QFhm095d>`2>M4@0K6=306=RB`1Z
JEP0Nga[0869NP23T800RiR809>OS`2GX8l0W9n;0::PR02BQFL0U7mE09Z3EP2LQ5h0Vh1J09UoD02D
Md40UG]50:6@H@2OUW00VI=c09BAM@2BSWD0T8ae08f6L024O6@0OWQQ07QcF01eLE40MW9A07AaE01d
M5L0LW=I079eHP1^LfH0H6aQ05MXH@1MKfP0F6iT065fK01WO780Jh1g06QnM01YOgL0JX1i06MmM`1V
OWL0HGad06ElL`1/Og@0Jg1N085Z=00/h0l5003o06Wooooo1P00o`00A00Yg@d0U7I709>:L`1aMVP0
J7=X06=^I@1NJUl0GFMN069/H01WL6<0JW5W06MZHP1XKVD0JFaT06U[I01dMVl0THn809jKTP2SXIL0
Z:BK09nOSP2NWHX0VIF409fFR@2KUHT0U92209F@P`2LU8H0VHn209VAO02FS6l0VhaX09N4GP2HQ600
VHAU08amHP2:Meh0TgeR09N5J`2NSg`0XY9n0:RGP02^VH40]j>40;ZXQP30/900_[2B0;fcV`2cZYD0
^:nK0;N`W@2f[ih0/j^L0;2XU`2l[Id0^J^J0;N[X02YY9d0VIFA08Z:QP26RX@0PHF10864PP22R800
PhR008B;P@2=UHd0Q8^80P1fPWh01`1jQX80OHV207b:Q@26T8X0QXAi08MgG`28Qch01P00o`1/oooo
o`002_ooool5003o001=01C^1P1YSb@0Q7IG08nGSP27ViH0QI^G08^QW`2;X9h0PYRE08NKUP2;WY`0
R9fJ08^NW@2;Wih0Q9VB08>FSP26UX`0Pi>:08NBS029ThL0R8mn08R:K`2<QEl0SgiC08QdB`27LDX0
Qg1;08]fD`1mMEd0OH1^08nGQ`2_^;80Z;>a07V;Q@1HJEh0FUm:08AdB02CNT@0UWa90:F?H@2gYGX0
`k>:0<2bS@2ZXX80UiEg08nBM02ATgX0U9F2096EQ028RWL0PhA`07n2KP1nQ6l0OhI_0864K`2:RGD0
Vi>008^7M`22PWP0Mgad071kL`1[NWD0JG]d06QnM@1eRGl0LhIo07N:Q@1aQX40KXIn06j8P01_Qh00
K8El06YoMP1^Nfh0KW9O07YY?`0jcAD01P00o`1Yooooo`L00?l004`0IZXT09IlE`1jMfH0NWmf075j
M01YM6d0Hg1X06EbJ01YM6X0KgQ_06idJ@1bNF/0LWU/079fJ@1`M6T0LWI_07EfK`1jNW<0QhJ108nB
RP2KWID0XJ2F0:VWWP2/ZJ00[jfR0;2_XP2^ZYd0/JZL0:ZUT@2]ZI<0/JbI0;J]V02l]9d0_kJP0<>n
Y@34_:<0clF]0=G=]P3MeL40hMW60>3Ha03Dc;T0clJd0<o8]`39aK@0bLRf0<C2]032`KD0`L2g0;^k
]02h^:l0^;B]0;Z`YP2lZj40[inH0:>JU02IUI00W9^F09BGTP2EVI@0U9JD09:FT`2=U8d0S9><08R@
RP27Thl0PXn>07n?RP20ShP0QY2;08^BS02>U8l0THn7095kG01OYb`08^P>1P00o`1/ooooo`002_oo
ool7003o000:03S95@1nNTP0PH5e08jKU@2@Xj00Sj>Q08jRX02@Y:80TJFT092TXP80T:BT03h0T:BR
08fPW`2FY:40Tj>N08nPV`2<W9H0UjFN096PW02HYIl0WJJL09VNSP2MVhP0WYQo09nBL`2MSF/0V8UW
0968K02<Qgh0PH5i075fH`1iO640TXi/0;2XPP3<`j80jN?:0?cij`3elnP0k>[O0>7Pe@3De<H0b<^k
0;k5]02e_jl0/[b`0:bk/@2T]:/0Xk6[09f/Y`2EYj40Tj>M09RPU`2TWi<0]:>E0:NHR02HTh<0SY26
08>=Q`1nSHD0OXn707R>Q`1mUHl0N96<07R@S@1eRhP0MXb60725OP1_P7P0Kgec06YaG01_J4H0K8T^
01gV2PL00?l0JOooool8003o001903k>5`2?Qe@0UI:308J;Q01oR880Lgmh075mM01`NWD0M85i07J2
MP1gOg<0OH9h0865O026Rh80OX=k07EiLP1eNg<0M7ed07EnN@1fOGX0Ngmk07Z0P01oQXP0Ph^;09>M
W@2KY:<0Xj^W0:R^Z02`]k00][^f0<35^P39cl@0d=K;0=cQe03Vimh0kNkV0?SglP3lnoP0o?ci0?ck
n@3gmo80loC_0>oak@3Xj^H0g^?M0=CMf03=e]@0cMGF0<C:c02n`L00a/O30<S5_P32_KP0_[jg0;bm
^02b]:l0[K2/0:FZZ@2QZJP0W::R09^RX02DWY`0U9jM08bGUP2=VIH0SibH096LV@2?VID0T9B?09NE
R`2DQG80LY/m027X3P08003o06cooooo000:ooooo`P00?l002<05Nl805VV:028MDh0QX9^09FPV`2K
ZjT0W:j/09Z^[@2K[jh0VJf[09nb/@2L[Zl0Vjf]09f^[P2IZjX0UjVV0:6c/02Q/[00W[6^09R[Z@2J
[:`0VZf]09Z/Z`2U][D0[K^h0;c4`P31bL@0`lo70=;NeP3Jhm/0gnOO0>W_i`3gnO<0oook0?kno003
0?knoP0Q0?gmo@3no_h0o_kn0?kno@3fn?L0inc[0=KRh@38eMD0_/_<0;O4a@2[^KT0X[Bb0:Fg/@2V
/J/0YZ^U0:j]Y02][J00Z:RM0:2VX@2BXYh0RIfI08RMV024ViL0Q9^H07nGT`1oUI80MXZ606j0MP1/
N6`0K7=P07A/BP1AY2D0:=l@00T00?l0JOooool9003o000X01C_201jY4<0WX]^09^EQ@2>U8T0Qi:8
07n:Q01oSHL0Q8n:07j8P`20RHH0QI2:08VDS@2<U8h0RHj908V?R@28TX`0TijJ08VCT@2>UY@0OHN7
082;S@2=VYT0SibK08jLV`2EXZ40YJj^0;2h^@2ka/D0am?@0=7Jf03Ni^D0j_3_0?cmoP3no_h0oOgn
0?knoP3moOd0o_km0?gnoP80o_kn01`0n?Wi0>gblP3Xk^h0hNWY0=kUiP3Fg]l0e]gM0=SLg@3EemL0
d]CB0<c@cP31a/D0^;no0;:j^@2X/;00Yk2_0:F^[02QZj/0WZVY09bWYP2MYZ@0UifL096CT02>SHD0
RX1]07n<C@19^RL0:n0C2P00o`1/ooooo`002_ooool;003o000O07JL;`26N5P0UIR=0:2[Z@2Q/K00
XK>a0::e]02R];@0XK>c09jb/P2Q][H0X;>d0:6c/P2Z^[T0Y;Fc0;;3`P2X^kT0XKBd0:2d/`2U^;L0
X[Bd0:Vk^`2ja/P0b=KG0<?Cd`3;g=/0cmcM0=gWj@3Vk_00loOg0?gmo@030?knoP@0oOgm01`0o_gm
0?knoP3inOX0hNSY0=KRh@3>f]X0a]CD0;[;b@2hbLH0_/c90<;>bP2d`[h0]/:j0;O1^P2c^[<0ZKBa
09ZZZ@2AY:40Rj2M08^OV`28ViP0PYRD07N<R01VMFh0J71L06aTA`25KC`0:MlA2`00o`1Yooooo`/0
0?l00200;N4C08V9@P2MSgD0ViZ:092BQ`2=UHd0SiNC092JV029U980QY6<092KV@2@ViX0S9JE09NO
W@2IXZ40WjVX08nJVP2KY:80QI>>08jMV@2O[:T0[;Jd0;O3_`2f_kl0_LG40<;7bP3Cf]`0fN7R0=_Q
h@3UjN/0k?3a0?[ko@80o_kn1@3moOh06P3moOd0l_;c0?7cm@3Zknl0i^c/0>[_l03MhnD0hNKX0=cP
hP3Gg=`0bm3@0<W>c`35bLX0^/310;Rm_P2e^[X0/[Ng0:Z_/@2Y/K80Y:f^09bSY02GUiL0SXEo08ef
H@2JN500E<0V3@00o`1/ooooo`002_ooool<003o000R02SO4P1M[3<0PY5E09N?N@2TYid0Z;>a0:Fd
]02/_Kd0ZK^l0:Rm_02X^kd0[;jo0:fo_`2U]kL0ZK^j0:^m_P2^_/00[l;00;?3``2ca/D0^lg;0;o=
c@34d]80bm[G0<gLfP3HiND0fN?T0=[TiP3Tj^`0kO3a0?;em03mo_d0o_kn0?gno@<0oOgm0P3noOd0
6@3no_l0n?Wi0>kem03LinL0fNKV0=OUi@3@gMd0e=kN0<cGf032d<l0_<W70;O3`02d_kd0ZKBc09n^
[02IZJH0TJBP08VLU`1lR8@0L7Y`06Y^FP1aMd@0DJDX03[>6@0Gl@X03000o`1Yooooo`d00?l001h0
?<hL04Zn;02;UEP0W8eh09jGR`2KVY<0Ui^H09RMV`2HX9h0U:2O086;S02IY:<0XJb/0:>][01oRhP0
T9bJ0:Nd[`2P[JT0[kZi0<39b`38d]<0bm?E0=GMgP3Ff]d0gN;S0=gSi@3Vk>`0k>oa0?7cm03jn_`3
0?knoP030?gnoP3no_h0oOgn0080oOgm01L0nOWi0??fmP3am?D0j^o`0>W^k`3Pi^L0h>CW0=WOh03C
fMT0cmKD0<_@d@36bld0`LO60;c0`P2f^[d0];Vi0:^/[02PWih0V92:09V7L@1_W4T0Ek@a02[O500?
003o06cooooo000:ooooo`l00?l001805_4:04C78@1ZZdD0Xhib0:FKR`2/[JL0/kjk0;2n_P2``L80
/lK70;73``2Z_[d0Zkno0;31`@2hc<X0^lg<0;g?cP38e]H20<kJfP0;0=?Og`3Dh>00fnKW0=_Ri03L
i^L0hng]0>W_kP3cn?P0n__k0?[ln`3moOd00P3no_h00`3mo_d0o_kn0?kmo@020?knoP0C0?_mo@3_
m_H0jO;c0=[Wj03Gh^@0c]WL0<cGfP34cm@0^<C70;>m_`2^];L0XJNW08jBS01oPGD0MGMQ07ElCP1I
W380AKTQ03?H5`0@003o06Wooooo4000o`007@0]hA@0D[hW06B_>02KT6@0WhQ`0:2@O`2ZWY@0[:JN
0:f[YP2_/K00/KFb0:jd[P2c^KD0]ko00;Nn`@2la<L0_lO:0<G=c`3:dM@0d]cM0=GLgP3Ni^H0hn_[
0>W^kP3bmOD0n_[j0?kmo@3oool0o_km0080o_gm0P3no_h05P3no_d0o_ko0?knoP3inoX0moSi0>oa
l`3Xk>d0iNW[0=oSi@3JgN00f=cM0<kBdP38bLP0_;fk0:nZY`2VVY00Yi:108JSH@1c[TH0D[l/02_Q
5`0=n@LB003o06cooooo000:oooooa<00?l001/06?8<03?H701c[TD0Nj]B08nRJ@2]XXd0[:ZL0:na
ZP2i_;P0`<S50<SCd03:e]@0amGE0<OFeP3<f]/0e>3Q0=WTi@3OjNT0gNSW0>?]j`3Sj^P0iNg/0>ge
m03cmoL0m_Wj0?Sjn@3loOd00`3no_h04`3nool0o_on0?gmoP3gn?X0jo3d0>7YkP3Jh>D0b=CE0;g8
b@2]][D0YZ^Y09VHT02@RGL0Sh=Z07Z:DP1LWSH0AkPR02?K400QjQ005000o`1YoooooaD00?l001L0
@m8N07bN>`2ROUT0XhIZ0:nKR02kZId0`kFZ0<Vk^036_kl0`Kbo0;nm`036alH0bL_90=7Ee@3Eg=X0
fmoP0>?Xj03Xk^d0l_Cc0?Sin@3lo?`0oOgm0?kooP030?kmo@030?knoP3oooh0oOkm0080oOgn00d0
o?cn0?OgnP3`l?@0jnW]0>CQi@3Fd]D0b/?20;fbZ`2_WI00XX]d0:N8I01]]3/0ILhd01P00?l0K?oo
ool000[ooooo6000o`005P0ej1X0Gl/_05?2;01kXdD0XXQU0:FBN`2`XY<0^[JZ0<S8`P3Ef]H0f=oL
0=kTh`3UinT0i^c]0>gal`3/k_40k?3c0>ocmP3fnO`0nocm0?[lo@3lo_l20?kno`0>0?cmo`3emOP0
kNg_0>7Qh`3Bd=80^[Vi0:RXY02IU8`0S89b08aiG`2CNeH0WH1C052o:@18f28J003o06Wooooo6000
o`005@0Hl@/0A=<Q04[89P1a]cl0T;1H08Z`G`2=]FH0T;a`0;NcSP33[i/0a[BW0<bn/`3Aa/40dLW4
0=O>c03OemD0jN3N0>_Rh03[i><0jn?S0>gTh`020>oUh`0@0>_Qg`3VfMP0gm;=0=g>aP3Ha[/0eL2c
0<ngY02^^8H0TKe_08jgI@2=/eT0L[]505c8<`0_iA/0=>PL01_d3AX00?l0K?ooool000[ooooo7000
o`007P0=nPL0<^LK02kS6P0ffal0E/Db07ZeB`27/EH0R;=N08^gI@2H]W<0aZV=0;V`RP35[YD0aK2F
0<JaUP33/9L0`ZnG0<2/T`2nZ8h0/jj608FhJ`20/El0P:iH07j/D`1b[TL0Cl8`0572;@0ndB40;><H
01Wc3Ah00?l0ooooool_ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {180.75, 0}} -> {-0.106847, -0.0454574, \
0.0105606, 0.0105606}, {{10.0625, 98.1875}, {176.438, 4.25}} -> {-17.4879, \
-6.49014, 1.7365, 1.7365}, {{107, 195.062}, {176.438, 4.25}} -> {-211.421, \
-31.6328, 1.97589, 1.97589}, {{203.875, 291.938}, {176.438, 4.25}} -> \
{-344.957, -8.96734, 1.692, 1.692}, {{300.75, 388.875}, {176.438, 4.25}} -> \
{-580.177, -33.4024, 1.9291, 1.9291}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extract RGB data", "Subsection"],

Cell[BoxData[{
    \(\(data1 = ExtractRGB[obj1];\)\), "\[IndentingNewLine]", 
    \(\(data2 = ExtractRGB[obj2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize RGB data", "Subsection"],

Cell[CellGroupData[{

Cell["3d distribution in RGB cube", "Subsubsection"],

Cell[BoxData[{
    \(\(gobj1\  = \ 
        PlotRepresentativeSample3D[data1, \ 2000, pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample3D[data2, \ 2000, pointStyle2];\)\), "\n", 
    \(\(gdist1 = 
        Show[{gobj1, gobj2}, nS, \ ImageSize \[Rule] 288];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RG plane", "Subsubsection"],

Cell[BoxData[{
    \(\(which = {1, 2};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\n", 
    \(\(gdist2 = 
        Show[{gobj1, gobj2}, nS, FrameTicks \[Rule] False, \ 
          FrameLabel \[Rule] None, ImageSize \[Rule] 288];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RB plane", "Subsubsection"],

Cell[BoxData[{
    \(\(which = {1, 3};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\n", 
    \(\(gdist3 = 
        Show[{gobj1, gobj2}, nS, FrameTicks \[Rule] False, \ 
          FrameLabel \[Rule] None, ImageSize \[Rule] 288];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GB plane", "Subsubsection"],

Cell[BoxData[{
    \(\(which = {2, 3};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\n", 
    \(\(gdist4 = 
        Show[{gobj1, gobj2}, nS, FrameTicks \[Rule] False, \ 
          FrameLabel \[Rule] None, ImageSize \[Rule] 288];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show all", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{gdist1, gdist2}, {gdist3, gdist4}}], \ 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0258451 0.47619 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0258451 0.477324 0.518133 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.15686 .04706 Mdot
.30196 .09412 Mdot
.63922 .29804 Mdot
.58824 .22745 Mdot
.6902 .36471 Mdot
.30588 .10588 Mdot
.75294 .27843 Mdot
.66667 .31765 Mdot
.29412 .10588 Mdot
.5451 .17255 Mdot
.44706 .03137 Mdot
.61569 .31373 Mdot
.63529 .32157 Mdot
.81176 .0549 Mdot
.63137 .24314 Mdot
.58039 .19216 Mdot
.41569 .01569 Mdot
.84706 .05882 Mdot
.49804 .07059 Mdot
.57255 .2 Mdot
.43922 .00392 Mdot
.79608 .07059 Mdot
.57255 .02745 Mdot
.61961 .32941 Mdot
.40392 0 Mdot
.62745 .04706 Mdot
.52549 .02353 Mdot
.8549 .8 Mdot
.59216 .28235 Mdot
.61176 .02353 Mdot
.87059 .13725 Mdot
.49804 .01569 Mdot
.58431 .25882 Mdot
.54118 .02353 Mdot
.64706 .04314 Mdot
.69412 .03529 Mdot
.81176 .79216 Mdot
.57255 .27059 Mdot
.59608 .02353 Mdot
.65882 .03922 Mdot
.61569 .03137 Mdot
.67451 .61961 Mdot
.39216 .02745 Mdot
.63922 .03529 Mdot
.68235 .0549 Mdot
.55686 .04314 Mdot
.76078 .72157 Mdot
.4 .02353 Mdot
.60784 .01961 Mdot
.67059 .05098 Mdot
.24314 .03529 Mdot
.84314 .80392 Mdot
.38824 .08627 Mdot
.61176 .02353 Mdot
.69412 .05098 Mdot
.55686 .46275 Mdot
.83529 .71373 Mdot
.12941 .04706 Mdot
.55294 .02353 Mdot
.68627 .03529 Mdot
.81569 .69412 Mdot
.58431 .01961 Mdot
.79608 .82353 Mdot
.43922 .02353 Mdot
.6549 .03529 Mdot
.48627 .09412 Mdot
.91373 .84706 Mdot
.87451 .82353 Mdot
.51765 .06275 Mdot
.54902 .01569 Mdot
.68627 .05098 Mdot
.92549 .89804 Mdot
.47843 .06275 Mdot
.83137 .84706 Mdot
.3098 0 Mdot
.59216 .02353 Mdot
.63529 .05098 Mdot
.90196 .90588 Mdot
.49412 .07843 Mdot
.80784 .82745 Mdot
.43922 .01176 Mdot
.63529 .02353 Mdot
.83137 .70196 Mdot
.90196 .90588 Mdot
.89412 .83529 Mdot
.65882 .59216 Mdot
.4549 .01176 Mdot
.62745 .03137 Mdot
.9098 .87843 Mdot
.88235 .88235 Mdot
.72157 .65098 Mdot
.66275 .51765 Mdot
.56078 .01961 Mdot
.62745 .03529 Mdot
.88627 .87843 Mdot
.8902 .88627 Mdot
.76078 .62353 Mdot
.57647 .48627 Mdot
.73725 .05098 Mdot
.61176 .02745 Mdot
.89804 .89412 Mdot
.88235 .88235 Mdot
.41569 .10196 Mdot
.75294 .72549 Mdot
.7451 .03529 Mdot
.62745 .02745 Mdot
.88627 .87843 Mdot
.87451 .88627 Mdot
.52549 .03137 Mdot
.81569 .83137 Mdot
.70196 .03922 Mdot
.63137 .02745 Mdot
.87059 .86667 Mdot
.89804 .88235 Mdot
.48627 .04314 Mdot
.8 .82745 Mdot
.60392 .00784 Mdot
.53333 .01176 Mdot
.82353 .67059 Mdot
.8902 .81961 Mdot
.87451 .84706 Mdot
.8 .77255 Mdot
.5098 .01176 Mdot
.79216 .04706 Mdot
.56078 .06667 Mdot
.88627 .86275 Mdot
.87059 .86667 Mdot
.78824 .71373 Mdot
.3451 .08235 Mdot
.72549 .03137 Mdot
.63529 .03922 Mdot
.88235 .87843 Mdot
.61569 .06667 Mdot
.56863 .06667 Mdot
.81569 .84314 Mdot
.67843 .03529 Mdot
.80392 .04314 Mdot
.85882 .83137 Mdot
.62353 .07843 Mdot
.84706 .8549 Mdot
.81961 .79608 Mdot
.53333 0 Mdot
.76078 .03529 Mdot
.59608 .03137 Mdot
.88627 .78431 Mdot
.61569 .04314 Mdot
.49412 .03137 Mdot
.75294 .78431 Mdot
.65098 .02353 Mdot
.81176 .03922 Mdot
.84706 .83529 Mdot
.65098 .05882 Mdot
.84706 .84706 Mdot
.71765 .67059 Mdot
.55294 .00784 Mdot
.73333 .04314 Mdot
.58039 .02353 Mdot
.61961 .18824 Mdot
.61569 .03137 Mdot
.51373 .03922 Mdot
.8 .83137 Mdot
.64706 .03137 Mdot
.8 .03922 Mdot
.87059 .84706 Mdot
.65882 .05882 Mdot
.87059 .80392 Mdot
.76078 .69412 Mdot
.35686 .18824 Mdot
.72157 .03922 Mdot
.83922 .05882 Mdot
.64706 .0902 Mdot
.6549 .04314 Mdot
.64706 .1451 Mdot
.8 .82745 Mdot
.58039 .01569 Mdot
.77647 .04314 Mdot
.84314 .83922 Mdot
.6549 .06667 Mdot
.55294 .00784 Mdot
.66667 .32549 Mdot
.54118 .47059 Mdot
.63529 .02353 Mdot
.81961 .04314 Mdot
.64706 .41961 Mdot
.16078 .02353 Mdot
.8549 .84314 Mdot
.64706 .60784 Mdot
.43922 .13333 Mdot
.7451 .04314 Mdot
.83529 .7098 Mdot
.66275 .05882 Mdot
.61569 .03137 Mdot
.65098 .13333 Mdot
.73333 .76471 Mdot
.56863 .01176 Mdot
.78824 .03922 Mdot
.86275 .8549 Mdot
.72157 .60784 Mdot
.53333 .00392 Mdot
.43529 .18431 Mdot
.36863 .27451 Mdot
.63137 .02745 Mdot
.82745 .05098 Mdot
.66275 .05882 Mdot
.89412 .8 Mdot
.76078 .58431 Mdot
.66275 .64314 Mdot
.62745 .63529 Mdot
.73333 .03529 Mdot
.8902 .88627 Mdot
.23529 .03922 Mdot
.61176 .04314 Mdot
.68235 .0549 Mdot
.73725 .78039 Mdot
.55686 .02353 Mdot
.78039 .03529 Mdot
.83922 .62353 Mdot
.8902 .87451 Mdot
.54902 .01569 Mdot
.5451 .21176 Mdot
.47059 .44314 Mdot
.60392 .02745 Mdot
.81176 .0549 Mdot
.62745 .0549 Mdot
.87843 .88235 Mdot
.83529 .75686 Mdot
.69412 .64314 Mdot
.45882 .50196 Mdot
.71373 .04314 Mdot
.88627 .89412 Mdot
.88235 .81569 Mdot
.51765 .19608 Mdot
.75294 .04706 Mdot
.77255 .81961 Mdot
.20392 .00392 Mdot
.78039 .03922 Mdot
.74902 .09412 Mdot
.87059 .86667 Mdot
.60392 .02745 Mdot
.51373 .02745 Mdot
.56078 .61569 Mdot
.56078 .02745 Mdot
.78431 .05882 Mdot
.62353 .09412 Mdot
.87059 .87059 Mdot
.86275 .83137 Mdot
.80392 .67451 Mdot
.76471 .72549 Mdot
.63922 .06275 Mdot
.87843 .8902 Mdot
.87843 .86275 Mdot
.68627 .48627 Mdot
.72549 .04706 Mdot
.80392 .84314 Mdot
.16863 .01961 Mdot
.76078 .04706 Mdot
.81961 .05882 Mdot
.89412 .87843 Mdot
.63922 .02353 Mdot
.67451 .05098 Mdot
.52549 .58039 Mdot
.47843 .01176 Mdot
.73725 .06275 Mdot
.44706 .20784 Mdot
.8549 .77647 Mdot
.83529 .80392 Mdot
.58039 .21961 Mdot
.50588 .27059 Mdot
.64314 .0549 Mdot
.85882 .86667 Mdot
.86667 .86275 Mdot
.51765 .21961 Mdot
.54118 .00392 Mdot
.79608 .83529 Mdot
.1451 .01569 Mdot
.63137 .07059 Mdot
.77255 .04706 Mdot
.56078 .18431 Mdot
.62745 .02353 Mdot
.70588 .02745 Mdot
.79608 .86667 Mdot
.03529 0 Mdot
.76471 .03529 Mdot
.43529 .1451 Mdot
.34902 .03922 Mdot
.75686 .47451 Mdot
.50588 .05098 Mdot
.21569 .22353 Mdot
.44314 .01176 Mdot
.86275 .8902 Mdot
.85098 .85098 Mdot
.80392 .68627 Mdot
.53725 .03529 Mdot
.81176 .61176 Mdot
.32157 .35686 Mdot
.63922 .04706 Mdot
.74902 .04314 Mdot
.59216 .08627 Mdot
.63922 .05098 Mdot
.52549 .01176 Mdot
.8 .83529 Mdot
.05098 .00784 Mdot
.74902 .04706 Mdot
.75294 .06667 Mdot
.29804 .03922 Mdot
.58431 .02353 Mdot
.6902 .02745 Mdot
.69412 .76863 Mdot
.16078 .00392 Mdot
.6902 .49412 Mdot
.84314 .83922 Mdot
.88235 .82353 Mdot
.83529 .79216 Mdot
.52157 .01569 Mdot
.43922 .24706 Mdot
.41176 .02353 Mdot
.61569 .2 Mdot
.87843 .83922 Mdot
.65098 .0549 Mdot
.53725 .01961 Mdot
.73333 .61569 Mdot
.24314 .31373 Mdot
.68235 .04314 Mdot
.46275 .04314 Mdot
.28235 .11373 Mdot
.63529 .03529 Mdot
.52549 .01176 Mdot
.73725 .80392 Mdot
.00392 0 Mdot
.76471 .04706 Mdot
.85882 .82745 Mdot
.86667 .85098 Mdot
.76863 .44314 Mdot
.68235 .03529 Mdot
.49804 .6 Mdot
.21176 0 Mdot
.87059 .8902 Mdot
.76471 .11373 Mdot
.18824 .03137 Mdot
.51373 .03137 Mdot
.47843 .04314 Mdot
.30196 .14118 Mdot
.43137 .01961 Mdot
.68235 .55686 Mdot
.88627 .84706 Mdot
.55294 .07843 Mdot
.51765 .01176 Mdot
.64706 .60392 Mdot
.03922 .00392 Mdot
.6902 .03922 Mdot
.66667 .31373 Mdot
.7098 .72157 Mdot
.63137 .02745 Mdot
.51373 .01176 Mdot
.78824 .8549 Mdot
.08235 .00392 Mdot
.88235 .65098 Mdot
.32941 .24706 Mdot
.86275 .77647 Mdot
.83529 .81176 Mdot
.67059 .02353 Mdot
.48627 .5451 Mdot
.23137 .00392 Mdot
.36471 .08235 Mdot
.80392 .71765 Mdot
.87059 .85098 Mdot
.56078 .02353 Mdot
.53725 .03922 Mdot
.31765 .37647 Mdot
.43137 .03137 Mdot
.86275 .83922 Mdot
.84706 .79216 Mdot
.51765 .06275 Mdot
.53725 .03137 Mdot
.6549 .65882 Mdot
.00392 .00392 Mdot
.75294 .04314 Mdot
.89412 .78431 Mdot
.86667 .86275 Mdot
.7451 .36863 Mdot
.50196 .01961 Mdot
.72941 .82745 Mdot
.15294 .00392 Mdot
.79216 .80784 Mdot
.88627 .85098 Mdot
.86667 .85882 Mdot
.44314 .06275 Mdot
.67451 .02353 Mdot
.63529 .56078 Mdot
.24706 0 Mdot
.83137 .81569 Mdot
.81569 .72157 Mdot
.85098 .8549 Mdot
.56078 .01961 Mdot
.59216 .07451 Mdot
.08235 .11765 Mdot
.50588 .03137 Mdot
.75294 .04314 Mdot
.90196 .9098 Mdot
.60392 .0549 Mdot
.51373 .00784 Mdot
.6549 .70588 Mdot
0 0 Mdot
.76078 .03922 Mdot
.76863 .07451 Mdot
.86275 .85882 Mdot
.83137 .82745 Mdot
.51373 .01961 Mdot
.72157 .82353 Mdot
.17647 .00392 Mdot
.65882 .18039 Mdot
.32549 .05098 Mdot
.86275 .78824 Mdot
.58039 .02745 Mdot
.67451 .03922 Mdot
.26275 .05882 Mdot
.41176 .02745 Mdot
.76471 .04706 Mdot
.8902 .8902 Mdot
.85098 .83137 Mdot
.53333 .01961 Mdot
.50196 .04706 Mdot
.00392 0 Mdot
.54118 .01961 Mdot
.75686 .0549 Mdot
.94902 .79216 Mdot
.58039 .1451 Mdot
.52549 .01569 Mdot
.72941 .81569 Mdot
.09804 .00392 Mdot
.78431 .03529 Mdot
.56863 .06667 Mdot
.75294 .08235 Mdot
.84706 .81176 Mdot
.52549 .01569 Mdot
.43529 .52549 Mdot
.34118 .01569 Mdot
.72157 .03137 Mdot
.84706 .8549 Mdot
.84706 .81961 Mdot
.56471 .01961 Mdot
.69412 .04706 Mdot
.34902 .36471 Mdot
.59216 .03922 Mdot
.74902 .04706 Mdot
.80392 .4 Mdot
.59216 .05882 Mdot
.52157 .01176 Mdot
.6549 .51765 Mdot
.02745 .00392 Mdot
.57255 .01961 Mdot
.73725 .04314 Mdot
.82353 .07059 Mdot
.84706 .80392 Mdot
.51765 .02353 Mdot
.76863 .85882 Mdot
.28235 .01961 Mdot
.75686 .03529 Mdot
.8549 .8549 Mdot
.39216 .22353 Mdot
.4549 .35686 Mdot
.56078 .02353 Mdot
.42745 .39608 Mdot
.19608 .01176 Mdot
.76471 .04314 Mdot
.71765 .23529 Mdot
.43529 .18824 Mdot
.53333 .01176 Mdot
.70196 .05098 Mdot
.05882 .08627 Mdot
.45098 .04706 Mdot
.74118 .04706 Mdot
.81961 .0549 Mdot
.59608 .0549 Mdot
.49804 .00784 Mdot
.56863 .40392 Mdot
.16863 .00392 Mdot
.61569 .01569 Mdot
.85882 .80392 Mdot
.24706 .04706 Mdot
.80784 .82353 Mdot
.50588 .01569 Mdot
.68627 .78039 Mdot
.31373 .01961 Mdot
.76471 .04706 Mdot
.32941 .35686 Mdot
.77255 .75686 Mdot
.23529 .19608 Mdot
.63137 .04706 Mdot
.23922 .07451 Mdot
.59216 .36863 Mdot
.73725 .05098 Mdot
.72157 .12941 Mdot
.50196 .38824 Mdot
.51765 .01176 Mdot
.6902 .06275 Mdot
.2 .00392 Mdot
.55686 .01961 Mdot
.70588 .21176 Mdot
.23529 .02353 Mdot
.7451 .47059 Mdot
.49804 .01569 Mdot
.62353 .63529 Mdot
.27451 .02745 Mdot
.62353 .02353 Mdot
.82353 .77255 Mdot
.86275 .87843 Mdot
.80392 .82745 Mdot
.44706 .02353 Mdot
.58431 .67843 Mdot
.27843 .00784 Mdot
.72549 .03922 Mdot
.84314 .85098 Mdot
.83529 .85098 Mdot
.66275 .62353 Mdot
.67451 .05098 Mdot
.63529 .74902 Mdot
.50196 .04314 Mdot
.69412 .01961 Mdot
.20392 .06275 Mdot
.64314 .47059 Mdot
.51373 .01176 Mdot
.65098 .15686 Mdot
.22745 .01569 Mdot
.57647 .02745 Mdot
.85882 .81176 Mdot
.84314 .86275 Mdot
.84314 .83529 Mdot
.4902 .01569 Mdot
.61569 .68235 Mdot
.19216 .00784 Mdot
.63529 .02745 Mdot
.83529 .80392 Mdot
.83922 .8549 Mdot
.8 .83137 Mdot
.40784 .00784 Mdot
.33333 .3451 Mdot
.38431 .01176 Mdot
.65098 .01961 Mdot
.10196 .11765 Mdot
.82353 .85098 Mdot
.47451 .08627 Mdot
.67843 .07451 Mdot
.66275 .74902 Mdot
.51373 .01961 Mdot
.71373 .04314 Mdot
.85882 .86667 Mdot
.58039 .07059 Mdot
.49804 .00392 Mdot
.63529 .0549 Mdot
.14118 .00392 Mdot
.55686 .01961 Mdot
.65882 .13333 Mdot
.85098 .8549 Mdot
.82745 .74902 Mdot
.47843 .00784 Mdot
.63922 .7098 Mdot
.18824 .00784 Mdot
.57255 .01569 Mdot
.64706 .17255 Mdot
.47059 .24314 Mdot
.81569 .83529 Mdot
.36078 .00392 Mdot
.45098 .53725 Mdot
.30588 .01176 Mdot
.66275 .02353 Mdot
.80392 .76078 Mdot
.83922 .86275 Mdot
.50196 .03529 Mdot
.50588 .04706 Mdot
.44314 .43137 Mdot
.48627 .02353 Mdot
.70196 .03922 Mdot
.83529 .85098 Mdot
.21176 .03137 Mdot
.52157 .00392 Mdot
.6902 .05882 Mdot
.17255 .00784 Mdot
.55686 .02745 Mdot
.70588 .03922 Mdot
.67059 .23137 Mdot
.6 .05882 Mdot
.51765 .01569 Mdot
.42353 .0902 Mdot
.14902 .00392 Mdot
.56078 .03137 Mdot
.56863 .0902 Mdot
.66275 .61569 Mdot
.80784 .82353 Mdot
.47451 .00784 Mdot
.71765 .82353 Mdot
.2 .00392 Mdot
.56078 .02745 Mdot
.83137 .84706 Mdot
.84314 .84706 Mdot
.62353 .5098 Mdot
.85098 .70196 Mdot
.18039 .0549 Mdot
.40784 .01569 Mdot
.67843 .05882 Mdot
.83922 .75686 Mdot
.81961 .84706 Mdot
.53725 .01176 Mdot
.57647 .0549 Mdot
.16471 .1098 Mdot
.50196 .03922 Mdot
.70196 .04314 Mdot
.14902 .06667 Mdot
.58431 .07843 Mdot
.50588 .00392 Mdot
.63137 .06275 Mdot
.13333 .00392 Mdot
.54118 .01961 Mdot
.3451 .04706 Mdot
.85882 .87451 Mdot
.55294 .05882 Mdot
.46667 .00392 Mdot
.74118 .80392 Mdot
.15686 0 Mdot
.55686 .02745 Mdot
.84314 .85098 Mdot
.83529 .86275 Mdot
.79608 .81569 Mdot
.45098 .00784 Mdot
.4902 .53333 Mdot
.3451 .02353 Mdot
.61961 .02745 Mdot
.37255 .12941 Mdot
.82353 .84314 Mdot
.5098 .02745 Mdot
.4549 .01176 Mdot
.42745 .4 Mdot
.47451 .03529 Mdot
.68235 .03137 Mdot
.85098 .83529 Mdot
.54118 .09804 Mdot
.51765 .01569 Mdot
.58824 .04314 Mdot
.13333 0 Mdot
.50588 .03529 Mdot
.73333 .46667 Mdot
.84706 .87059 Mdot
.60784 .06275 Mdot
.4902 .01176 Mdot
.47451 .09412 Mdot
.18431 .00392 Mdot
.52941 .01569 Mdot
.81569 .8549 Mdot
.36471 .39608 Mdot
.52941 .06667 Mdot
.45882 .00784 Mdot
.75686 .87059 Mdot
.32549 .01176 Mdot
.57255 .03137 Mdot
.67059 .64706 Mdot
.83529 .85882 Mdot
.80392 .81176 Mdot
.45098 .01176 Mdot
.34118 .05098 Mdot
.38431 .02353 Mdot
.6902 .04314 Mdot
.84314 .86275 Mdot
.60784 .07059 Mdot
.50588 .01176 Mdot
.59608 .05098 Mdot
.12157 .00392 Mdot
.44314 .00784 Mdot
.58431 .04314 Mdot
.81569 .69804 Mdot
.62353 .05098 Mdot
.50588 .01176 Mdot
.57255 .05098 Mdot
.13725 .00392 Mdot
.53725 .02745 Mdot
.81176 .83922 Mdot
.61569 .58824 Mdot
.59608 .05882 Mdot
.4902 .01961 Mdot
.77647 .82353 Mdot
.26275 .00784 Mdot
.56471 .02745 Mdot
.83137 .84314 Mdot
.74902 .51373 Mdot
.56078 .05098 Mdot
.4549 .01961 Mdot
.47451 .42353 Mdot
.32157 .01176 Mdot
.62353 .03529 Mdot
.85098 .85098 Mdot
.71373 .07451 Mdot
.63922 .55686 Mdot
.5098 .02353 Mdot
.21176 .00784 Mdot
.42353 .02353 Mdot
.68627 .03529 Mdot
.70196 .12941 Mdot
.58824 .06667 Mdot
.49412 .01569 Mdot
.55294 .03922 Mdot
.12549 .00784 Mdot
.4902 .00784 Mdot
.75294 .67843 Mdot
.8549 .8549 Mdot
.48235 .08235 Mdot
.47451 .00784 Mdot
.42745 .0549 Mdot
.24314 .01569 Mdot
.55686 .02353 Mdot
.83922 .86275 Mdot
.75294 .10196 Mdot
.53333 .0549 Mdot
.45098 .00392 Mdot
.47451 .56863 Mdot
.27843 .00784 Mdot
.59608 .02745 Mdot
.67451 .15686 Mdot
.15294 .02353 Mdot
.57255 .04314 Mdot
.46275 .02353 Mdot
.21176 0 Mdot
.36078 .01569 Mdot
.69412 .04706 Mdot
.78039 .0902 Mdot
.56863 .57255 Mdot
.52549 .03529 Mdot
.61176 .03922 Mdot
.10588 .00784 Mdot
.4902 .01569 Mdot
.59608 .13725 Mdot
.67451 .28627 Mdot
.78824 .77647 Mdot
.4902 .01569 Mdot
.51765 .02353 Mdot
.21961 .01176 Mdot
.54118 .01961 Mdot
.71373 .59608 Mdot
.08235 .04706 Mdot
.76078 .75294 Mdot
.44706 .00392 Mdot
.56078 .59216 Mdot
.26275 .00392 Mdot
.60392 .04314 Mdot
.65882 .21569 Mdot
.84314 .85882 Mdot
.09412 .05098 Mdot
.45098 .01176 Mdot
.33725 .26667 Mdot
.35686 .01569 Mdot
.66667 .05882 Mdot
.77255 .08627 Mdot
.82353 .8549 Mdot
.52157 .02745 Mdot
.53725 .03137 Mdot
.11765 0 Mdot
.43922 .01961 Mdot
.71373 .06667 Mdot
.16863 .01176 Mdot
.81961 .84706 Mdot
.47059 .00784 Mdot
.53725 .03529 Mdot
.13725 .00392 Mdot
.37255 .00784 Mdot
.18431 .04314 Mdot
.87059 .86667 Mdot
.81176 .83922 Mdot
.46667 .01176 Mdot
.36863 .05098 Mdot
.23922 .00784 Mdot
.57647 .02745 Mdot
.84706 .8549 Mdot
.83922 .87059 Mdot
.8 .82745 Mdot
.37647 .00392 Mdot
.47059 .49804 Mdot
.30196 .00392 Mdot
.59608 .03922 Mdot
.65098 .11765 Mdot
.83529 .86667 Mdot
.46275 .32941 Mdot
.4549 .01176 Mdot
.23922 .00784 Mdot
.4 .00784 Mdot
.67843 .05098 Mdot
.80784 .81961 Mdot
.80392 .84314 Mdot
.49412 .01569 Mdot
.56863 .02745 Mdot
.11765 .00784 Mdot
.4902 .01569 Mdot
.74902 .54118 Mdot
.87451 .8902 Mdot
.82745 .84314 Mdot
.44314 .01176 Mdot
.51373 .02745 Mdot
.2 .00392 Mdot
.55294 .02353 Mdot
.85098 .86275 Mdot
.85882 .87843 Mdot
.81569 .84314 Mdot
.45882 .01569 Mdot
.51765 .54902 Mdot
.13725 0 Mdot
.6 .03137 Mdot
.3098 .31765 Mdot
.81961 .76471 Mdot
.79216 .82745 Mdot
.48627 .03137 Mdot
.12157 .03137 Mdot
.36471 .01569 Mdot
.64314 .04706 Mdot
.8549 .88235 Mdot
.47451 .13725 Mdot
.40784 .11373 Mdot
.56863 .05098 Mdot
.28627 .00784 Mdot
.42745 .01961 Mdot
.70588 .06667 Mdot
.88627 .90588 Mdot
.04706 .05098 Mdot
.5098 .01961 Mdot
.57647 .02745 Mdot
.17647 0 Mdot
.44706 .00392 Mdot
.68235 .07059 Mdot
.85098 .87843 Mdot
.51373 .33725 Mdot
.52157 .03922 Mdot
.53333 .02745 Mdot
.12549 .00392 Mdot
.4902 .00784 Mdot
.80784 .52157 Mdot
.86275 .70588 Mdot
.52549 .1098 Mdot
.4902 .02745 Mdot
.45882 .01569 Mdot
.20392 .00784 Mdot
.52549 .00784 Mdot
.41961 .36078 Mdot
.72157 .13333 Mdot
.55294 .04706 Mdot
.4902 .04314 Mdot
.61961 .56863 Mdot
.12941 .00392 Mdot
.56863 .02745 Mdot
.88627 .90588 Mdot
.41961 .41961 Mdot
.63922 .63137 Mdot
.50196 .03137 Mdot
.14902 .11765 Mdot
.14902 .01569 Mdot
.58824 .03529 Mdot
.87059 .89804 Mdot
.84706 .87059 Mdot
.79608 .83137 Mdot
.52941 .03922 Mdot
.12941 .02353 Mdot
.2549 .01569 Mdot
.59608 .0549 Mdot
.86667 .89412 Mdot
.82353 .85882 Mdot
.44706 .09804 Mdot
.35686 .00392 Mdot
.24314 .00392 Mdot
.32941 0 Mdot
.67059 .0549 Mdot
.73333 .31765 Mdot
.75686 .7098 Mdot
.49804 .04314 Mdot
.32157 .01176 Mdot
.22353 .00784 Mdot
.40392 .00392 Mdot
.58039 .10588 Mdot
.8 .09412 Mdot
.60392 .0549 Mdot
.48627 .03529 Mdot
.58431 .03529 Mdot
.12549 .00392 Mdot
.47451 .01569 Mdot
.83529 .85098 Mdot
.32549 .14118 Mdot
.52549 .05098 Mdot
.51373 .04314 Mdot
.51373 .02745 Mdot
.18431 .00392 Mdot
.50196 .00784 Mdot
.83922 .87059 Mdot
.8549 .87843 Mdot
.34902 .34902 Mdot
.49804 .03137 Mdot
.4902 .25098 Mdot
.24706 .00784 Mdot
.52157 .00392 Mdot
.85882 .88235 Mdot
.83529 .86275 Mdot
.81569 .84314 Mdot
.49804 .02745 Mdot
.41569 .40784 Mdot
.27451 .01176 Mdot
.53725 .00784 Mdot
.64314 .31373 Mdot
.78824 .6902 Mdot
.47843 .10196 Mdot
.5098 .04314 Mdot
.15294 .01961 Mdot
.32549 .01176 Mdot
.58039 .03922 Mdot
.80784 .08235 Mdot
.60784 .09412 Mdot
.53333 .03922 Mdot
.58039 .04314 Mdot
.30588 0 Mdot
.27843 .01176 Mdot
.27843 .02353 Mdot
.83529 .08627 Mdot
.50588 .09412 Mdot
.51373 .01961 Mdot
.67843 .06275 Mdot
.21176 .00392 Mdot
.47059 .02353 Mdot
.83137 .83922 Mdot
.84706 .5098 Mdot
.34118 .38039 Mdot
.49804 .01961 Mdot
.64706 .05098 Mdot
.17647 .00392 Mdot
.4902 .04706 Mdot
.83529 .8549 Mdot
.86275 .87059 Mdot
.82745 .86275 Mdot
.47451 .01961 Mdot
.54902 .03137 Mdot
.17255 .00784 Mdot
.38431 .03137 Mdot
.78039 .67059 Mdot
.71765 .72549 Mdot
.26275 .27451 Mdot
.5098 .03137 Mdot
.44706 .03922 Mdot
.24314 .01176 Mdot
.51765 .01176 Mdot
.71373 .08235 Mdot
.0902 .03137 Mdot
.03137 .03529 Mdot
.48627 .02745 Mdot
.38824 .35294 Mdot
.22745 0 Mdot
.54118 .01569 Mdot
.72157 .08235 Mdot
.39608 .42353 Mdot
.18039 .20784 Mdot
.51373 .03137 Mdot
.03922 .00392 Mdot
.16863 .00392 Mdot
.32941 .03137 Mdot
.72941 .10196 Mdot
.80392 .84314 Mdot
.03529 .01176 Mdot
.5451 .03137 Mdot
.22745 .01176 Mdot
.41569 .03922 Mdot
.81176 .81961 Mdot
.75294 .07451 Mdot
.78431 .8549 Mdot
.47059 .05882 Mdot
.64314 .04706 Mdot
.18431 .00392 Mdot
.36471 .03922 Mdot
.81176 .83922 Mdot
.73725 .07451 Mdot
.33333 .41961 Mdot
.52157 .03529 Mdot
.6549 .06667 Mdot
.16471 .00784 Mdot
.23529 .00784 Mdot
.57647 .21569 Mdot
.68627 .27059 Mdot
.83137 .85882 Mdot
.52157 .02353 Mdot
.59608 .03529 Mdot
.15686 .00392 Mdot
.53725 .03529 Mdot
.23137 .02353 Mdot
.72157 .41176 Mdot
.81569 .85098 Mdot
.51765 .02745 Mdot
.47451 .01961 Mdot
.24314 .00784 Mdot
.55294 .02745 Mdot
.72549 .73333 Mdot
.67059 .17647 Mdot
.80784 .84314 Mdot
.48627 .02745 Mdot
.45882 .38824 Mdot
.2902 .00392 Mdot
.54902 .06667 Mdot
.86667 .88235 Mdot
.35294 .05098 Mdot
.80392 .84706 Mdot
.48235 .03137 Mdot
.01569 0 Mdot
.35294 .02353 Mdot
.78824 .79608 Mdot
.84314 .87059 Mdot
.68627 .71765 Mdot
.80784 .8549 Mdot
.56078 .03922 Mdot
.27059 .01569 Mdot
.47843 .3098 Mdot
.8 .82745 Mdot
.8 .66667 Mdot
.81961 .8549 Mdot
.71373 .6902 Mdot
.60784 .04314 Mdot
.15294 .00392 Mdot
.37647 .06275 Mdot
.36863 .11765 Mdot
.76078 .07451 Mdot
.81961 .85882 Mdot
.52941 .05098 Mdot
.61569 .03529 Mdot
.26275 .11373 Mdot
.47059 .02745 Mdot
.73725 .75686 Mdot
.78039 .08627 Mdot
.80392 .83922 Mdot
.48627 .02745 Mdot
.57255 .03529 Mdot
.08627 .00392 Mdot
.51373 .04314 Mdot
.69412 .55294 Mdot
.73333 .07843 Mdot
.46667 .15686 Mdot
.49804 .03529 Mdot
.50196 .02353 Mdot
.16863 .00784 Mdot
.54118 .03529 Mdot
.71373 .07843 Mdot
.61569 .61961 Mdot
.43529 .09804 Mdot
.43922 .01569 Mdot
.56078 .46275 Mdot
.23922 .00392 Mdot
.42745 .30196 Mdot
.39216 .36078 Mdot
.8549 .87843 Mdot
.71765 .76078 Mdot
.43137 .01569 Mdot
.00392 .00392 Mdot
.28627 .00784 Mdot
.8 .83922 Mdot
.87451 .87843 Mdot
.83529 .87059 Mdot
.78824 .81569 Mdot
.51373 .01569 Mdot
.18431 .00784 Mdot
.36078 .01961 Mdot
.06667 .07059 Mdot
.75686 .10588 Mdot
.36471 .45882 Mdot
.51373 .0549 Mdot
.52157 .01569 Mdot
.29804 .03137 Mdot
.41176 .02353 Mdot
.81961 .83529 Mdot
.78431 .08627 Mdot
.49804 .12157 Mdot
.49412 .02745 Mdot
.57255 .03137 Mdot
.08627 .00392 Mdot
.35294 .04314 Mdot
.59608 .09412 Mdot
.76471 .0902 Mdot
.39608 .07451 Mdot
.50196 .03529 Mdot
.57255 .03137 Mdot
.08627 0 Mdot
.43137 .02353 Mdot
.22353 .01961 Mdot
.40784 .3098 Mdot
.15294 .18824 Mdot
.48627 .02745 Mdot
.57255 .03529 Mdot
.0902 .00392 Mdot
.52941 .03529 Mdot
.56471 .61176 Mdot
.83922 .86667 Mdot
.79608 .82745 Mdot
.49412 .04314 Mdot
.46667 .03922 Mdot
.07451 0 Mdot
.52941 .03922 Mdot
.84314 .86275 Mdot
.86275 .87451 Mdot
.7451 .75294 Mdot
.45882 .02353 Mdot
.20784 .11373 Mdot
.2 .00784 Mdot
.62745 .42353 Mdot
.58824 .24314 Mdot
.55686 .2 Mdot
.4902 .10588 Mdot
.44314 .00784 Mdot
.00392 0 Mdot
.27059 .01176 Mdot
.78824 .81961 Mdot
.71765 .06275 Mdot
.36078 .07451 Mdot
.4 .07843 Mdot
.49412 .01569 Mdot
.04706 .00392 Mdot
.31373 .00784 Mdot
.72941 .76863 Mdot
.71373 .06667 Mdot
.08627 .12549 Mdot
.12941 .00784 Mdot
.48627 .01176 Mdot
.2549 .01569 Mdot
.36078 .01569 Mdot
.8 .83529 Mdot
.70588 .05882 Mdot
.67843 .73333 Mdot
.06275 .00784 Mdot
.4902 .01176 Mdot
.25098 .00392 Mdot
.38431 .01961 Mdot
.76471 .79216 Mdot
.68235 .0549 Mdot
.81961 .87059 Mdot
.13333 .01569 Mdot
.50588 .02353 Mdot
.37255 .03137 Mdot
.41176 .01961 Mdot
.81569 .83529 Mdot
.71373 .07843 Mdot
.79216 .84706 Mdot
.39608 .05098 Mdot
.52941 .03137 Mdot
.11373 0 Mdot
.45098 .03137 Mdot
.55294 .20392 Mdot
.72549 .07451 Mdot
.68235 .7451 Mdot
.47843 .03529 Mdot
.53333 .02353 Mdot
.05882 0 Mdot
.48235 .03922 Mdot
.65098 .06667 Mdot
.71373 .09804 Mdot
.78039 .82353 Mdot
.44706 .01569 Mdot
.53725 .03137 Mdot
.05098 0 Mdot
.50588 .04314 Mdot
.65882 .05882 Mdot
.66667 .11765 Mdot
.82353 .8549 Mdot
.44314 .01569 Mdot
.44706 .09412 Mdot
.0549 .00392 Mdot
.50588 .02745 Mdot
.69804 .07451 Mdot
.65098 .10196 Mdot
.82353 .86275 Mdot
.4902 .02745 Mdot
.13333 .08235 Mdot
.06275 .00392 Mdot
.5098 .03137 Mdot
.6902 .06275 Mdot
.43137 .08235 Mdot
.82745 .86667 Mdot
.5451 .02745 Mdot
.00392 .00392 Mdot
.19216 .01176 Mdot
.54902 .3098 Mdot
.70196 .05882 Mdot
.20392 .2549 Mdot
.82745 .86667 Mdot
.52941 .02353 Mdot
.05882 .00392 Mdot
.26275 .00392 Mdot
.8 .83137 Mdot
.71373 .06667 Mdot
.83137 .87059 Mdot
.81569 .86275 Mdot
.5451 .03137 Mdot
.27843 .01961 Mdot
.3098 .01176 Mdot
.78431 .82745 Mdot
.71373 .07059 Mdot
.83922 .87451 Mdot
.81961 .86275 Mdot
.54118 .03529 Mdot
.30196 .00784 Mdot
.35686 .01569 Mdot
.76078 .80392 Mdot
.73725 .07059 Mdot
.83922 .87843 Mdot
.81569 .86275 Mdot
.55294 .03137 Mdot
.21176 0 Mdot
.38039 .01961 Mdot
.14118 .14118 Mdot
.74118 .06667 Mdot
.83922 .87843 Mdot
.66667 .66275 Mdot
.58431 .04314 Mdot
.32157 .00784 Mdot
.43137 .02745 Mdot
.30196 .0549 Mdot
.51373 .10196 Mdot
.80392 .79608 Mdot
.47451 .06667 Mdot
.61569 .0549 Mdot
.36078 .22353 Mdot
.4549 .03922 Mdot
.59216 .07843 Mdot
.36078 .39608 Mdot
.54902 .16471 Mdot
.47843 .02745 Mdot
.63137 .07843 Mdot
.09804 .01176 Mdot
.45882 .03922 Mdot
.62745 .07451 Mdot
.82353 .86275 Mdot
.62353 .07451 Mdot
.50588 .02745 Mdot
.58431 .22745 Mdot
.1098 .05098 Mdot
.47451 .04314 Mdot
.64314 .0549 Mdot
.8549 .8902 Mdot
.56078 .08235 Mdot
.52549 .02745 Mdot
.64706 .49804 Mdot
.04314 .00392 Mdot
.47843 .04706 Mdot
.67843 .06275 Mdot
.83922 .87843 Mdot
.13725 .01176 Mdot
.53725 .02745 Mdot
.47059 .35686 Mdot
.03137 0 Mdot
.46275 .03529 Mdot
.67843 .0549 Mdot
.84314 .88235 Mdot
.30588 .36078 Mdot
.52941 .01961 Mdot
.4 .32157 Mdot
.03137 .00392 Mdot
.47451 .03922 Mdot
.67843 .05882 Mdot
.84314 .88235 Mdot
.72549 .76863 Mdot
.53725 .03529 Mdot
.07451 .03529 Mdot
.02353 0 Mdot
.47843 .03922 Mdot
.68627 .05882 Mdot
.67451 .72549 Mdot
.81176 .85098 Mdot
.5451 .03529 Mdot
.09412 .04706 Mdot
.02353 0 Mdot
.49804 .04314 Mdot
.66667 .05882 Mdot
.06275 .13725 Mdot
.8 .84314 Mdot
.54118 .03137 Mdot
.11765 .02353 Mdot
.02745 .00392 Mdot
.50588 .02745 Mdot
.51765 .09412 Mdot
.66275 .71373 Mdot
.80392 .84706 Mdot
.5451 .03137 Mdot
.22353 .01569 Mdot
.08627 0 Mdot
.54118 .02745 Mdot
.1098 .06667 Mdot
.84314 .87451 Mdot
.80392 .84706 Mdot
.56863 .03922 Mdot
.33725 .02745 Mdot
.20392 .01569 Mdot
.59216 .05098 Mdot
.67451 .71373 Mdot
.81569 .76078 Mdot
.80392 .84706 Mdot
.58039 .04706 Mdot
.41569 .00784 Mdot
.27451 .01176 Mdot
.61569 .05098 Mdot
.83529 .87059 Mdot
.53333 .21961 Mdot
.8 .86275 Mdot
.57647 .04314 Mdot
.49804 .01569 Mdot
.29804 .01176 Mdot
.61569 .05882 Mdot
.83922 .87451 Mdot
.15294 .03529 Mdot
.67059 .74902 Mdot
.55686 .03529 Mdot
.47451 .01176 Mdot
.30196 .00784 Mdot
.60392 .07843 Mdot
.83137 .87059 Mdot
.6 .65882 Mdot
.69804 .76078 Mdot
.55294 .02353 Mdot
.4 .00784 Mdot
.32549 .01176 Mdot
.57647 .0902 Mdot
.85098 .87059 Mdot
.83529 .87843 Mdot
.8 .83922 Mdot
.54902 .02745 Mdot
.32941 .00392 Mdot
.36078 .01961 Mdot
.53333 .12157 Mdot
.59608 .37255 Mdot
.83529 .87451 Mdot
.79608 .84706 Mdot
.52941 .03137 Mdot
.2902 .00784 Mdot
.35294 .00784 Mdot
.54118 .20784 Mdot
.63529 .1098 Mdot
.83137 .87451 Mdot
.4902 .59216 Mdot
.4902 .16471 Mdot
.27451 .00392 Mdot
.36078 .01961 Mdot
.60392 .36078 Mdot
.51765 .10588 Mdot
.81569 .8549 Mdot
.60784 .68235 Mdot
.83137 .76863 Mdot
.27843 .00392 Mdot
.33333 .01176 Mdot
.64314 .49412 Mdot
.15294 .11373 Mdot
.83529 .85098 Mdot
.78039 .83137 Mdot
.55686 .52941 Mdot
.07059 .00392 Mdot
.34902 .01961 Mdot
.55294 .27843 Mdot
.52941 .56863 Mdot
.6549 .5451 Mdot
.78039 .83137 Mdot
.33333 .2902 Mdot
.13725 .00392 Mdot
.35686 .02353 Mdot
.49804 .12941 Mdot
.6902 .73725 Mdot
.51765 .21569 Mdot
.78039 .83137 Mdot
.20392 .14118 Mdot
.14118 .00392 Mdot
.38824 .05098 Mdot
.43922 .09804 Mdot
.81961 .86667 Mdot
.4902 .14902 Mdot
.78039 .83137 Mdot
.24314 .1451 Mdot
.14902 .01569 Mdot
.38039 .02353 Mdot
.24706 .03922 Mdot
.83529 .87451 Mdot
.19216 .03137 Mdot
.78039 .83137 Mdot
.43137 .33725 Mdot
.1451 .01176 Mdot
.39216 .01961 Mdot
.1098 .04314 Mdot
.83922 .83137 Mdot
.07451 .09412 Mdot
.77255 .82745 Mdot
.62745 .56471 Mdot
.15294 .01176 Mdot
.38431 .02745 Mdot
.2902 .3098 Mdot
.64706 .49412 Mdot
.54118 .61176 Mdot
.77647 .82745 Mdot
.72549 .68627 Mdot
.14118 .00392 Mdot
.33333 .02353 Mdot
.56863 .61961 Mdot
.58039 .20392 Mdot
.72157 .77647 Mdot
.78039 .83137 Mdot
.78431 .76078 Mdot
.1451 .00784 Mdot
.30588 .01961 Mdot
.7451 .79608 Mdot
.69412 .12941 Mdot
.81961 .86667 Mdot
.76078 .79608 Mdot
.76078 .75294 Mdot
.14118 .00784 Mdot
.34902 .03137 Mdot
.77255 .81569 Mdot
.78824 .10196 Mdot
.84314 .88235 Mdot
.61176 .57647 Mdot
.72157 .7451 Mdot
.1451 .00392 Mdot
.39216 .03137 Mdot
.77647 .82353 Mdot
.87059 .11373 Mdot
.87059 .89804 Mdot
.47059 .30196 Mdot
.69412 .74118 Mdot
.14118 .00392 Mdot
.38431 .01961 Mdot
.77647 .82353 Mdot
.95686 .15686 Mdot
.89804 .92157 Mdot
.5098 .16078 Mdot
.70588 .76471 Mdot
.14902 .00784 Mdot
.37255 .02353 Mdot
.78824 .83529 Mdot
.99216 .21569 Mdot
.92157 .93725 Mdot
.60392 .10196 Mdot
.68235 .75294 Mdot
.15294 .00784 Mdot
.36863 .02353 Mdot
.80392 .83529 Mdot
1 .25098 Mdot
.94118 .95686 Mdot
.66667 .06667 Mdot
.63529 .71765 Mdot
.15294 .00784 Mdot
.37647 .02745 Mdot
.85098 .82353 Mdot
.97647 .23137 Mdot
.93333 .95294 Mdot
.72549 .06667 Mdot
.67059 .7451 Mdot
.15686 .00784 Mdot
.38431 .02745 Mdot
.8549 .74118 Mdot
.99216 .27451 Mdot
.9451 .95686 Mdot
.76078 .08235 Mdot
.69412 .76471 Mdot
.15686 .00392 Mdot
.39608 .01961 Mdot
.71373 .56471 Mdot
.99608 .25882 Mdot
1 .95294 Mdot
.74902 .07843 Mdot
.60784 .6902 Mdot
.15686 .00392 Mdot
.41176 .02353 Mdot
.40392 .3098 Mdot
.98431 .19608 Mdot
.87059 .5098 Mdot
.74118 .07451 Mdot
.51765 .6 Mdot
.1451 0 Mdot
.43137 .03137 Mdot
.17647 .17647 Mdot
.9098 .12941 Mdot
.83137 .21961 Mdot
.6902 .03922 Mdot
.70588 .77647 Mdot
.13725 0 Mdot
.47059 .04706 Mdot
.24314 .29412 Mdot
.80784 .0902 Mdot
.8 .11373 Mdot
.63529 .00392 Mdot
.73333 .81569 Mdot
.13725 0 Mdot
.47843 .04706 Mdot
.62353 .6902 Mdot
.75686 .07843 Mdot
.79216 .09804 Mdot
.76078 .1098 Mdot
.61569 .70196 Mdot
.27843 .00392 Mdot
.59216 .15686 Mdot
.73725 .79216 Mdot
.79608 .08235 Mdot
.83137 .09804 Mdot
.83922 .18431 Mdot
.66667 .7451 Mdot
.28235 .00392 Mdot
.6 .13333 Mdot
.78431 .82745 Mdot
.90196 .13333 Mdot
.91373 .11373 Mdot
.65882 .04706 Mdot
.61176 .6902 Mdot
.27843 .00784 Mdot
.57255 .07059 Mdot
.78431 .80392 Mdot
.96863 .18039 Mdot
.97647 .16471 Mdot
.5451 .00392 Mdot
.57255 .65882 Mdot
.26275 .00392 Mdot
.50196 .0549 Mdot
.65882 .50196 Mdot
1 .23922 Mdot
.96078 .26275 Mdot
.58431 .01176 Mdot
.51765 .61569 Mdot
.27059 0 Mdot
.70196 .39608 Mdot
.63529 .18824 Mdot
1 .25098 Mdot
.97647 .58039 Mdot
.6549 .03529 Mdot
.5098 .6 Mdot
.28627 .00784 Mdot
.48235 .27451 Mdot
.74118 .10588 Mdot
.97255 .18824 Mdot
.9098 .64706 Mdot
.71373 .05882 Mdot
.52941 .61961 Mdot
.27059 .00392 Mdot
.56863 .33725 Mdot
.8 .1098 Mdot
.99216 .20784 Mdot
.90588 .67059 Mdot
.73333 .07843 Mdot
.51765 .60784 Mdot
.27059 .00392 Mdot
.40392 .07843 Mdot
.81176 .13725 Mdot
.99608 .21569 Mdot
.9451 .77647 Mdot
.72941 .07451 Mdot
.48235 .57647 Mdot
.26275 .00392 Mdot
.41569 .02745 Mdot
.73725 .12941 Mdot
.95294 .14902 Mdot
.91373 .75294 Mdot
.73725 .07451 Mdot
.49412 .58431 Mdot
.26275 .00392 Mdot
.44314 .03137 Mdot
.61961 .12549 Mdot
.9098 .11373 Mdot
.73725 .55294 Mdot
.70588 .07843 Mdot
.58431 .67451 Mdot
.28235 .00784 Mdot
.46275 .03529 Mdot
.38431 .0549 Mdot
.88235 .1098 Mdot
.84314 .63529 Mdot
.61569 .06667 Mdot
.60392 .69412 Mdot
.2902 .00392 Mdot
.46667 .03922 Mdot
.16078 .00784 Mdot
.8902 .1098 Mdot
.91373 .52941 Mdot
.52941 .07059 Mdot
.54118 .63529 Mdot
.29412 .00392 Mdot
.43529 .01176 Mdot
.15294 .11765 Mdot
.92941 .13725 Mdot
.8902 .25882 Mdot
.4549 .0902 Mdot
.60392 .68235 Mdot
.31373 0 Mdot
.43529 .01176 Mdot
.3098 .3451 Mdot
.98039 .19216 Mdot
.99608 .31373 Mdot
.55294 .27451 Mdot
.74902 .82353 Mdot
.32941 .00784 Mdot
.42353 .02353 Mdot
.53725 .59608 Mdot
1 .2549 Mdot
1 .32549 Mdot
.78824 .58824 Mdot
.6902 .78824 Mdot
.3098 0 Mdot
.41176 .03922 Mdot
.71765 .77255 Mdot
.98431 .21569 Mdot
.9451 .21176 Mdot
.90196 .77255 Mdot
.58824 .68627 Mdot
.33333 .00392 Mdot
.51373 .13333 Mdot
.78431 .81961 Mdot
.97647 .15294 Mdot
.8902 .12941 Mdot
.8549 .8 Mdot
.60784 .67451 Mdot
.34118 .00392 Mdot
.48235 .05098 Mdot
.84706 .83529 Mdot
.96863 .16078 Mdot
.94118 .18039 Mdot
.82353 .82353 Mdot
.65098 .71373 Mdot
.34902 .00392 Mdot
.4549 .02353 Mdot
.7098 .41176 Mdot
.99608 .22745 Mdot
.98431 .23529 Mdot
.79216 .82745 Mdot
.55686 .58431 Mdot
.39608 .06667 Mdot
.43922 .02353 Mdot
.77647 .12549 Mdot
1 .32941 Mdot
.99608 .26275 Mdot
.78431 .82353 Mdot
.10588 .09804 Mdot
.33333 .00392 Mdot
.47451 .02745 Mdot
.83529 .0902 Mdot
.97647 .30196 Mdot
.99608 .23529 Mdot
.81961 .82745 Mdot
.1098 .06275 Mdot
.19216 .00392 Mdot
.62745 .04314 Mdot
.87843 .11373 Mdot
.98431 .28627 Mdot
.86667 .04314 Mdot
.52941 .13725 Mdot
.18824 .14118 Mdot
.21176 0 Mdot
.65098 .02745 Mdot
.83137 .09804 Mdot
.99216 .23529 Mdot
.84706 .05098 Mdot
.77647 .61569 Mdot
.31765 .03137 Mdot
.39608 .03529 Mdot
.68235 .03529 Mdot
.91765 .10588 Mdot
.99216 .2 Mdot
.64706 .01176 Mdot
.76471 .86667 Mdot
.4902 .03922 Mdot
.12549 0 Mdot
.72941 .0549 Mdot
.98039 .12549 Mdot
.98431 .17647 Mdot
.68627 .0549 Mdot
.81569 .90588 Mdot
.34902 .01961 Mdot
.04706 .00392 Mdot
.70588 .09412 Mdot
.96078 .16863 Mdot
.88627 .2 Mdot
.83529 .67843 Mdot
.85098 .93725 Mdot
.49804 .03529 Mdot
.29804 .01569 Mdot
.73725 .05098 Mdot
.85098 .6902 Mdot
.68627 .27843 Mdot
.75294 .81961 Mdot
.77647 .85882 Mdot
.2902 .00392 Mdot
.42745 .02745 Mdot
.8 .12549 Mdot
.60784 .49412 Mdot
.51765 .37255 Mdot
.40784 .10588 Mdot
.5098 .10588 Mdot
.22745 .00784 Mdot
.66275 .0549 Mdot
.72157 .45882 Mdot
.53333 .55294 Mdot
.45882 .4549 Mdot
.71765 .81569 Mdot
.63137 .07059 Mdot
.18431 .00784 Mdot
.75294 .1098 Mdot
.69412 .69804 Mdot
.60392 .64706 Mdot
.43922 .47451 Mdot
.69412 .82745 Mdot
.6 .03922 Mdot
.19216 .00392 Mdot
.57255 .2902 Mdot
.78039 .79608 Mdot
.81176 .85882 Mdot
.40784 .47451 Mdot
.74902 .87451 Mdot
.40784 0 Mdot
.40784 .12549 Mdot
.47059 .52941 Mdot
.87451 .92549 Mdot
.83137 .85098 Mdot
.39608 .47843 Mdot
.6549 .80392 Mdot
.44706 .07059 Mdot
.5451 .15294 Mdot
.58039 .65882 Mdot
.4549 .46275 Mdot
.54118 .53333 Mdot
.37647 .46275 Mdot
.46667 .10196 Mdot
.3451 .01176 Mdot
.45882 .50588 Mdot
.43137 .41569 Mdot
.43922 .38824 Mdot
.56863 .55686 Mdot
.36078 .43922 Mdot
.53725 .00784 Mdot
.21961 .02353 Mdot
.4902 .49804 Mdot
.4549 .37647 Mdot
.4549 .41569 Mdot
.52157 .43137 Mdot
.35686 .44706 Mdot
.27059 .06275 Mdot
.41176 .47843 Mdot
.4902 .39216 Mdot
.46275 .38824 Mdot
.58039 .60392 Mdot
.52549 .42745 Mdot
.41961 .07843 Mdot
.35294 .01961 Mdot
.37255 .33725 Mdot
.4549 .36471 Mdot
.46667 .42353 Mdot
.45098 .38039 Mdot
.56471 .5451 Mdot
.61176 .05098 Mdot
.35294 .40392 Mdot
.47451 .36471 Mdot
.46667 .36863 Mdot
.44706 .39216 Mdot
.40392 .28627 Mdot
.36078 .45882 Mdot
.43137 .04314 Mdot
.4549 .37255 Mdot
.47451 .37255 Mdot
.44314 .4 Mdot
.50196 .36471 Mdot
.47059 .34902 Mdot
.5451 .07843 Mdot
.35686 .39216 Mdot
.5098 .38431 Mdot
.45882 .36863 Mdot
.43529 .38431 Mdot
.46275 .32549 Mdot
.50588 .38039 Mdot
.41569 .04314 Mdot
.46667 .34902 Mdot
.49412 .38824 Mdot
.43922 .4 Mdot
.45098 .30588 Mdot
.48235 .38824 Mdot
.34118 .36078 Mdot
.37255 .3451 Mdot
.50588 .38039 Mdot
.44706 .39608 Mdot
.43137 .40392 Mdot
.48235 .3451 Mdot
.43137 .2902 Mdot
.42745 .21569 Mdot
.4902 .36471 Mdot
.47843 .36471 Mdot
.53333 .55294 Mdot
.4549 .3098 Mdot
.48235 .34902 Mdot
.32941 .38824 Mdot
.45098 .33725 Mdot
.48627 .35686 Mdot
.42745 .43529 Mdot
.40784 .43137 Mdot
.46667 .37647 Mdot
.43529 .30588 Mdot
.38824 .29804 Mdot
.47059 .35294 Mdot
.47451 .41569 Mdot
.11765 .21961 Mdot
.42353 .33333 Mdot
.47059 .37255 Mdot
.29412 .21961 Mdot
.48627 .37255 Mdot
.4902 .37255 Mdot
.24314 .32941 Mdot
.38824 .38039 Mdot
.4549 .36471 Mdot
.25098 .24706 Mdot
.36471 .27843 Mdot
.4902 .35294 Mdot
.19608 .25882 Mdot
.51373 .5451 Mdot
.47843 .35294 Mdot
.47451 .3451 Mdot
.39608 .02745 Mdot
.48627 .36078 Mdot
.39608 .36863 Mdot
.54118 .56863 Mdot
.4902 .34902 Mdot
.4902 .3451 Mdot
.19608 .21569 Mdot
.38039 .36078 Mdot
.48235 .35686 Mdot
.40784 .32941 Mdot
.57647 .54118 Mdot
.43922 .34902 Mdot
.4 .37255 Mdot
.36863 .32941 Mdot
.4902 .34902 Mdot
.19216 .2549 Mdot
.67451 .62353 Mdot
.47843 .38039 Mdot
.47843 .38824 Mdot
.41961 .25098 Mdot
.40392 .35294 Mdot
.23137 .2902 Mdot
.46667 .25882 Mdot
.46667 .2549 Mdot
.50196 .37255 Mdot
.2 .25098 Mdot
.3451 .35294 Mdot
.51373 .4 Mdot
.51373 .23922 Mdot
.51373 .38431 Mdot
.50196 .37255 Mdot
.39216 .3451 Mdot
.27843 .04706 Mdot
.37255 .27451 Mdot
.36863 .29412 Mdot
.37255 .32941 Mdot
.50588 .30196 Mdot
.47059 .33725 Mdot
.3098 .36863 Mdot
.43137 .44706 Mdot
.50588 .41569 Mdot
.55686 .30196 Mdot
.30588 .27451 Mdot
.52157 .38824 Mdot
.32549 .32157 Mdot
.47451 .47843 Mdot
.43922 .33725 Mdot
.51373 .3098 Mdot
.23529 .28627 Mdot
.52941 .38431 Mdot
.29804 .30588 Mdot
.55686 .17255 Mdot
.46275 .48627 Mdot
.46667 .27451 Mdot
.6902 .63529 Mdot
.53333 .39608 Mdot
.38039 .28627 Mdot
.38039 .42745 Mdot
.5098 .57255 Mdot
.51765 .23922 Mdot
.53333 .34902 Mdot
.58039 .38431 Mdot
.40784 .3098 Mdot
.39608 .45882 Mdot
.52941 .6 Mdot
.47843 .44706 Mdot
.56863 .55294 Mdot
.63529 .40784 Mdot
.45098 .33725 Mdot
.40784 .46275 Mdot
.53725 .59216 Mdot
.50196 .52157 Mdot
.43922 .41961 Mdot
.73725 .47843 Mdot
.47843 .38039 Mdot
.44706 .50196 Mdot
.57255 .57647 Mdot
.53725 .57647 Mdot
.52941 .38431 Mdot
.82745 .65098 Mdot
.53725 .50588 Mdot
.45882 .52941 Mdot
.51765 .50196 Mdot
.56863 .60784 Mdot
.56863 .35294 Mdot
.85098 .77647 Mdot
.58431 .56078 Mdot
.45098 .52549 Mdot
.58039 .64314 Mdot
.55294 .60784 Mdot
.56863 .50196 Mdot
.87451 .83922 Mdot
.7098 .58824 Mdot
.43137 .47843 Mdot
.60784 .68235 Mdot
.61569 .67843 Mdot
.98824 .95294 Mdot
.78039 .83137 Mdot
.54118 .59216 Mdot
.31373 .12157 Mdot
.61569 .6902 Mdot
.75294 .80392 Mdot
.99216 .99216 Mdot
.67059 .6902 Mdot
.46667 .53333 Mdot
.64314 .71373 Mdot
.64706 .71765 Mdot
.99608 .99608 Mdot
.75294 .81176 Mdot
.5451 .61176 Mdot
.66667 .6902 Mdot
.66275 .73725 Mdot
.9451 .96078 Mdot
.88627 .92157 Mdot
.59608 .65098 Mdot
.65882 .64706 Mdot
.69412 .76078 Mdot
.92549 .93725 Mdot
.88235 .92549 Mdot
.54118 .6 Mdot
.69412 .76471 Mdot
.78431 .83922 Mdot
.99216 .99216 Mdot
.8 .8549 Mdot
.17647 .08235 Mdot
.72941 .8 Mdot
.93333 .95686 Mdot
.92157 .95294 Mdot
.4549 .26275 Mdot
.75294 .81569 Mdot
.91373 .94118 Mdot
.91373 .95294 Mdot
.32549 .15294 Mdot
.76471 .82745 Mdot
.98824 .98824 Mdot
.70196 .72157 Mdot
.67059 .52157 Mdot
.96471 .98824 Mdot
.61176 .57255 Mdot
.64706 .44706 Mdot
.75686 .70196 Mdot
.40784 .21176 Mdot
.628 .126 .941 r
.34902 .20392 Mdot
.47451 .38824 Mdot
.8 .68235 Mdot
.74118 .73333 Mdot
.71373 .54118 Mdot
.43137 .44314 Mdot
.77255 .68235 Mdot
.76078 .63529 Mdot
.73725 .75686 Mdot
.79216 .78431 Mdot
.81176 .62745 Mdot
.83922 .80784 Mdot
.79216 .83137 Mdot
.72941 .43922 Mdot
.76863 .61176 Mdot
.61569 .63922 Mdot
.78039 .82745 Mdot
.7451 .51373 Mdot
.72549 .60392 Mdot
.71765 .75294 Mdot
.76078 .80784 Mdot
.71765 .48235 Mdot
.84314 .66667 Mdot
.83922 .81569 Mdot
.78431 .83137 Mdot
.11765 .05098 Mdot
.65098 .5451 Mdot
.76863 .72941 Mdot
.16863 .43137 Mdot
.75686 .81176 Mdot
.71765 .51373 Mdot
.87451 .72549 Mdot
.73725 .68627 Mdot
.79216 .83922 Mdot
.74118 .77255 Mdot
.80392 .63137 Mdot
.87059 .72941 Mdot
.73333 .70588 Mdot
.77647 .82353 Mdot
.33333 .21569 Mdot
.82745 .64706 Mdot
.84706 .70588 Mdot
.72157 .72549 Mdot
.78824 .8549 Mdot
.10196 .05098 Mdot
.82353 .66275 Mdot
.86667 .7098 Mdot
.83922 .81176 Mdot
.79608 .84706 Mdot
.44314 .54118 Mdot
.8 .61961 Mdot
.80784 .81961 Mdot
.83529 .76863 Mdot
.78824 .85098 Mdot
.75294 .81569 Mdot
.7451 .57647 Mdot
.84706 .64706 Mdot
.81176 .71765 Mdot
.66275 .77255 Mdot
.75294 .80392 Mdot
.6902 .45882 Mdot
.79608 .61569 Mdot
.87059 .70196 Mdot
.7451 .67843 Mdot
.80392 .86667 Mdot
.72157 .81569 Mdot
.76863 .6 Mdot
.83922 .63137 Mdot
.83137 .68627 Mdot
.38824 .52157 Mdot
.76471 .82353 Mdot
.6549 .41176 Mdot
.76078 .58431 Mdot
.84706 .67451 Mdot
.86667 .81176 Mdot
.08627 .36863 Mdot
.77255 .83922 Mdot
.69804 .49804 Mdot
.79216 .60392 Mdot
.85882 .69412 Mdot
.80784 .74902 Mdot
.80392 .8549 Mdot
.70588 .76078 Mdot
.84314 .5098 Mdot
.44314 .39608 Mdot
.85098 .66667 Mdot
.79608 .75686 Mdot
.79216 .85882 Mdot
.50588 .62353 Mdot
.70196 .09412 Mdot
.60392 .53333 Mdot
.83922 .6549 Mdot
.8 .74118 Mdot
.78824 .8549 Mdot
.2549 .4 Mdot
.69412 .08235 Mdot
.65098 .54118 Mdot
.83922 .66667 Mdot
.71765 .67059 Mdot
.8 .86667 Mdot
.18431 .3451 Mdot
.61176 .17647 Mdot
.61961 .53725 Mdot
.85098 .68235 Mdot
.82745 .8 Mdot
.80392 .84706 Mdot
.7451 .84314 Mdot
.68235 .51373 Mdot
.77255 .53333 Mdot
.85098 .65882 Mdot
.76471 .64314 Mdot
.72941 .48627 Mdot
.74902 .75294 Mdot
.61569 .47843 Mdot
.75686 .5098 Mdot
.82353 .63922 Mdot
.78431 .61569 Mdot
.67059 .37255 Mdot
.77255 .83529 Mdot
.50588 .32941 Mdot
.72157 .50196 Mdot
.36471 .4 Mdot
.83529 .65882 Mdot
.7098 .61569 Mdot
.78431 .66667 Mdot
.39608 .5098 Mdot
.67843 .50196 Mdot
.7451 .43922 Mdot
.8549 .67059 Mdot
.82353 .6902 Mdot
.71765 .03922 Mdot
.73725 .58431 Mdot
.5451 .44314 Mdot
.70588 .46667 Mdot
.81176 .61961 Mdot
.80392 .63529 Mdot
.71373 .04314 Mdot
.80392 .82745 Mdot
.51765 .55686 Mdot
.68627 .51765 Mdot
.72941 .43922 Mdot
.85098 .68235 Mdot
.76078 .57255 Mdot
.6902 .02353 Mdot
.78039 .71765 Mdot
.56863 .48627 Mdot
.70196 .44314 Mdot
.8 .57647 Mdot
.81176 .63137 Mdot
.7098 .03137 Mdot
.57647 .25882 Mdot
.61176 .68235 Mdot
.64314 .47451 Mdot
.7451 .41569 Mdot
.83529 .68627 Mdot
.83137 .57255 Mdot
.70196 .02745 Mdot
.66275 .03922 Mdot
.66275 .75686 Mdot
.68235 .4549 Mdot
.78039 .50196 Mdot
.46275 .43137 Mdot
.72941 .03922 Mdot
.67059 .03137 Mdot
.20784 .31765 Mdot
.60392 .53333 Mdot
.7098 .37647 Mdot
.8 .60392 Mdot
.80392 .63137 Mdot
.67843 .03922 Mdot
.74902 .59216 Mdot
.10588 .05098 Mdot
.63922 .48235 Mdot
.75686 .43922 Mdot
.53725 .45882 Mdot
.78039 .0549 Mdot
.4 .40392 Mdot
.65098 .19608 Mdot
.73725 .80784 Mdot
.68627 .47843 Mdot
.77255 .49412 Mdot
.51373 .51373 Mdot
.76078 .05098 Mdot
.21961 .42353 Mdot
.68627 .01176 Mdot
.8 .83529 Mdot
.67451 .43137 Mdot
.79608 .54902 Mdot
.81961 .68235 Mdot
.65098 .11765 Mdot
.58431 .33725 Mdot
.41176 .38824 Mdot
.57647 .51765 Mdot
.69412 .37647 Mdot
.80784 .61961 Mdot
.88627 .57647 Mdot
.15294 .38431 Mdot
.63137 .03922 Mdot
.53333 .52941 Mdot
.62745 .53725 Mdot
.71765 .40392 Mdot
.82745 .66275 Mdot
.81176 .06667 Mdot
.80784 .82353 Mdot
.66667 .71373 Mdot
.69804 .76471 Mdot
.62353 .48627 Mdot
.75294 .47451 Mdot
.86667 .70196 Mdot
.8 .05098 Mdot
.70196 .68627 Mdot
.66667 .08235 Mdot
.70588 .81569 Mdot
.64706 .50588 Mdot
.76863 .55686 Mdot
.85098 .72157 Mdot
.7098 .39216 Mdot
.72157 .79216 Mdot
.57255 .02353 Mdot
.47451 .60784 Mdot
.64706 .47451 Mdot
.78431 .57647 Mdot
.83529 .69804 Mdot
.12941 .41961 Mdot
.21176 .38431 Mdot
.51373 .03922 Mdot
.57255 .67843 Mdot
.67059 .46275 Mdot
.78039 .59216 Mdot
.84706 .68235 Mdot
.67843 .58039 Mdot
.69412 .85882 Mdot
.43137 .01569 Mdot
.77255 .84706 Mdot
.67059 .42353 Mdot
.8 .61176 Mdot
.72157 .23137 Mdot
.7451 .41961 Mdot
.77255 .8549 Mdot
.4902 .04706 Mdot
.65882 .70196 Mdot
.67843 .38824 Mdot
.78824 .61176 Mdot
.82353 .06667 Mdot
.7098 .05098 Mdot
.78431 .85882 Mdot
.38039 .02745 Mdot
.52157 .54118 Mdot
.67843 .39608 Mdot
.80784 .62745 Mdot
.83922 .05882 Mdot
.71765 .04314 Mdot
.79216 .8549 Mdot
.29412 .00392 Mdot
.54902 .54118 Mdot
.69804 .41569 Mdot
.80392 .62745 Mdot
.81569 .05882 Mdot
.71373 .03529 Mdot
.77647 .77255 Mdot
.39216 .01569 Mdot
.56471 .54902 Mdot
.67843 .41176 Mdot
.81569 .64314 Mdot
.75686 .29804 Mdot
.70588 .03529 Mdot
.59216 .42353 Mdot
.54902 .05882 Mdot
.58431 .56078 Mdot
.70588 .4549 Mdot
.82353 .65882 Mdot
.19608 .46275 Mdot
.63137 .12549 Mdot
.52549 .12157 Mdot
.56078 .06275 Mdot
.58431 .56078 Mdot
.69804 .46275 Mdot
.80784 .6549 Mdot
.12941 .49804 Mdot
.51373 .43922 Mdot
.51765 .11373 Mdot
.52549 .02353 Mdot
.58824 .56078 Mdot
.71765 .49804 Mdot
.81176 .64706 Mdot
.46667 .69804 Mdot
.08235 .36471 Mdot
.52157 .1098 Mdot
.5451 .02353 Mdot
.58431 .55686 Mdot
.71373 .50588 Mdot
.80392 .64706 Mdot
.71373 .76471 Mdot
.32549 .53333 Mdot
.52549 .10196 Mdot
.49804 .00784 Mdot
.59216 .56863 Mdot
.70588 .5098 Mdot
.8 .63529 Mdot
.78039 .7098 Mdot
.77647 .78039 Mdot
.52549 .08627 Mdot
.52157 .03137 Mdot
.5451 .53333 Mdot
.71373 .52549 Mdot
.79608 .63137 Mdot
.80784 .67451 Mdot
.7098 .58431 Mdot
.53725 .09804 Mdot
.59216 .08235 Mdot
.52549 .51373 Mdot
.71765 .52549 Mdot
.80392 .63529 Mdot
.85882 .62353 Mdot
.72941 .45882 Mdot
.5451 .09804 Mdot
.58431 .15686 Mdot
.52549 .50196 Mdot
.73725 .54118 Mdot
.80392 .64314 Mdot
.71373 .24314 Mdot
.63529 .15294 Mdot
.54902 .08235 Mdot
.58824 .2902 Mdot
.50196 .47843 Mdot
.73725 .55294 Mdot
.8 .63529 Mdot
.75686 .10196 Mdot
.68235 .06275 Mdot
.56471 .08235 Mdot
.65098 .50588 Mdot
.50196 .48235 Mdot
.72549 .54902 Mdot
.80392 .63137 Mdot
.78039 .08235 Mdot
.66275 .05098 Mdot
.57647 .08235 Mdot
.60392 .58039 Mdot
.4902 .47451 Mdot
.72157 .5451 Mdot
.81569 .65098 Mdot
.73725 .0902 Mdot
.60784 .21176 Mdot
.56863 .06667 Mdot
.5098 .53333 Mdot
.48235 .46667 Mdot
.72157 .54118 Mdot
.80392 .64314 Mdot
.70588 .23529 Mdot
.32941 .25882 Mdot
.56078 .06275 Mdot
.68235 .73725 Mdot
.44314 .46275 Mdot
.69804 .52941 Mdot
.78431 .62745 Mdot
.73725 .3098 Mdot
.66275 .34118 Mdot
.49804 .0902 Mdot
.47843 .60784 Mdot
.65882 .70196 Mdot
.68235 .54118 Mdot
.78431 .61569 Mdot
.73725 .50196 Mdot
.63922 .04314 Mdot
.52941 .34118 Mdot
.3098 .50196 Mdot
.72941 .78039 Mdot
.69804 .56078 Mdot
.79216 .63137 Mdot
.50588 .56863 Mdot
.69412 .05882 Mdot
.35294 .42745 Mdot
.62745 .81176 Mdot
.70588 .78431 Mdot
.71765 .58039 Mdot
.76863 .60784 Mdot
.20784 .45882 Mdot
.63137 .07843 Mdot
.37647 .52549 Mdot
.35686 .58039 Mdot
.54902 .66667 Mdot
.7098 .58431 Mdot
.78039 .61961 Mdot
.6549 .70588 Mdot
.61569 .16471 Mdot
.56471 .6902 Mdot
.7098 .87451 Mdot
.40392 .52549 Mdot
.70196 .59216 Mdot
.77255 .61569 Mdot
.81569 .72549 Mdot
.6549 .25882 Mdot
.58039 .49412 Mdot
.72549 .84706 Mdot
.38431 .51765 Mdot
.67451 .6 Mdot
.76078 .59608 Mdot
.81176 .7098 Mdot
.67451 .30588 Mdot
.54902 .07843 Mdot
.70588 .83137 Mdot
.33333 .47059 Mdot
.68235 .60784 Mdot
.7451 .58824 Mdot
.81569 .71373 Mdot
.66275 .30196 Mdot
.63922 .02745 Mdot
.73333 .84314 Mdot
.31765 .45098 Mdot
.68627 .61569 Mdot
.74118 .58824 Mdot
.81961 .72157 Mdot
.6549 .30588 Mdot
.65882 .03529 Mdot
.72157 .83922 Mdot
.34902 .50588 Mdot
.66667 .60784 Mdot
.74118 .57647 Mdot
.82353 .72157 Mdot
.77255 .6 Mdot
.63922 .42353 Mdot
.72157 .85098 Mdot
.56078 .7098 Mdot
.63137 .59216 Mdot
.73333 .56078 Mdot
.8 .69412 Mdot
.73333 .64706 Mdot
.62353 .66275 Mdot
.72549 .82353 Mdot
.53725 .55294 Mdot
.60784 .56471 Mdot
.73725 .55294 Mdot
.80392 .6902 Mdot
.73725 .67451 Mdot
.61961 .60392 Mdot
.72941 .83137 Mdot
.68627 .40784 Mdot
.55686 .52549 Mdot
.72941 .54902 Mdot
.79608 .67059 Mdot
.72941 .67059 Mdot
.61176 .54902 Mdot
.71765 .8549 Mdot
.31373 .21961 Mdot
.55686 .53725 Mdot
.71765 .54118 Mdot
.8 .66667 Mdot
.73725 .69412 Mdot
.61961 .56078 Mdot
.63922 .80784 Mdot
.1098 .21176 Mdot
.56078 .55294 Mdot
.69412 .52157 Mdot
.80392 .67843 Mdot
.7451 .69804 Mdot
.62745 .56863 Mdot
.43922 .32549 Mdot
.52549 .63137 Mdot
.5451 .56078 Mdot
.70196 .52941 Mdot
.8 .67843 Mdot
.75294 .69412 Mdot
.64706 .59608 Mdot
.5451 .05882 Mdot
.56471 .65882 Mdot
.65882 .71373 Mdot
.70196 .54902 Mdot
.79608 .66275 Mdot
.75686 .69804 Mdot
.61569 .57647 Mdot
.59216 .02745 Mdot
.40784 .51373 Mdot
.33333 .44706 Mdot
.68627 .56078 Mdot
.79608 .6549 Mdot
.77647 .73333 Mdot
.56471 .1451 Mdot
.50588 .29804 Mdot
.4 .60784 Mdot
.55294 .67451 Mdot
.66275 .55686 Mdot
.77647 .63922 Mdot
.78824 .72941 Mdot
.67451 .06275 Mdot
.65098 .59608 Mdot
.67451 .83529 Mdot
.16863 .33333 Mdot
.67059 .58824 Mdot
.77255 .63922 Mdot
.78039 .71373 Mdot
.70196 .05882 Mdot
.61176 .05098 Mdot
.7098 .84706 Mdot
.3451 .49804 Mdot
.67059 .61176 Mdot
.74902 .60392 Mdot
.78039 .71373 Mdot
.69804 .09412 Mdot
.66275 .03137 Mdot
.69804 .83529 Mdot
.44706 .59216 Mdot
.63922 .6 Mdot
.73333 .59216 Mdot
.76471 .70588 Mdot
.62353 .27451 Mdot
.6549 .02353 Mdot
.72157 .84314 Mdot
.49804 .63137 Mdot
.61961 .59608 Mdot
.74118 .57647 Mdot
.76471 .69804 Mdot
.73333 .66667 Mdot
.66275 .03922 Mdot
.7098 .7098 Mdot
.69804 .60392 Mdot
.59608 .58039 Mdot
.71373 .56078 Mdot
.75686 .68627 Mdot
.75294 .69804 Mdot
.65098 .03529 Mdot
.52157 .06275 Mdot
.27451 .12941 Mdot
.58039 .58431 Mdot
.7098 .53725 Mdot
.77255 .6902 Mdot
.72941 .69804 Mdot
.66667 .04706 Mdot
.57647 .04314 Mdot
.01569 .18431 Mdot
.52549 .56471 Mdot
.69804 .53333 Mdot
.75294 .66275 Mdot
.7451 .72549 Mdot
.68627 .0549 Mdot
.59216 .04706 Mdot
.02353 .2 Mdot
.76471 .8549 Mdot
.68235 .54118 Mdot
.74118 .61176 Mdot
.75294 .72941 Mdot
.70196 .05098 Mdot
.53725 .49412 Mdot
.57647 .70196 Mdot
.25098 .38824 Mdot
.64314 .54118 Mdot
.69412 .55686 Mdot
.76078 .73333 Mdot
.7098 .04706 Mdot
.41569 .53333 Mdot
.16471 .40392 Mdot
.58431 .72549 Mdot
.61569 .52549 Mdot
.68627 .51765 Mdot
.76471 .75294 Mdot
.72157 .0549 Mdot
.58039 .07843 Mdot
.68627 .85098 Mdot
.23137 .37255 Mdot
.62353 .55294 Mdot
.66275 .49412 Mdot
.56863 .58824 Mdot
.7098 .07451 Mdot
.6549 .03529 Mdot
.67059 .84314 Mdot
.37255 .52157 Mdot
.60392 .5451 Mdot
.68627 .50588 Mdot
.66275 .64706 Mdot
.60784 .14118 Mdot
.63922 .03137 Mdot
.65098 .86275 Mdot
.66667 .78824 Mdot
.60784 .56863 Mdot
.6902 .50196 Mdot
.72549 .67059 Mdot
.78039 .63529 Mdot
.64706 .03529 Mdot
.29412 .62353 Mdot
.63922 .53725 Mdot
.57647 .55294 Mdot
.67059 .48235 Mdot
.66667 .58431 Mdot
.70588 .68235 Mdot
.64706 .03529 Mdot
.03529 .32549 Mdot
.33725 .30588 Mdot
.56471 .55294 Mdot
.66275 .48235 Mdot
.66275 .56471 Mdot
.7098 .69804 Mdot
.67843 .05098 Mdot
.15294 .25882 Mdot
.22353 .29804 Mdot
.52549 .55294 Mdot
.66667 .4902 Mdot
.66667 .57255 Mdot
.73333 .71373 Mdot
.67843 .03529 Mdot
.57255 .5451 Mdot
.32941 .37647 Mdot
.47059 .50196 Mdot
.64314 .48627 Mdot
.64706 .51765 Mdot
.7451 .73725 Mdot
.69412 .04314 Mdot
.60392 .79216 Mdot
.41176 .4902 Mdot
.43137 .43922 Mdot
.63137 .50196 Mdot
.64706 .48627 Mdot
.76078 .74118 Mdot
.68627 .04706 Mdot
.36863 .7451 Mdot
.64706 .76863 Mdot
.42745 .38824 Mdot
.61569 .49412 Mdot
.65882 .44314 Mdot
.77255 .75294 Mdot
.69804 .04706 Mdot
.04706 .37647 Mdot
.27451 .49412 Mdot
.44314 .51765 Mdot
.6 .50588 Mdot
.64314 .43529 Mdot
.76863 .73725 Mdot
.71765 .05882 Mdot
.38431 .45098 Mdot
.28627 .47843 Mdot
.65882 .78824 Mdot
.59608 .53725 Mdot
.63137 .44706 Mdot
.73725 .71765 Mdot
.71373 .04314 Mdot
.56471 .37647 Mdot
.69412 .83529 Mdot
.68627 .82353 Mdot
.56078 .5098 Mdot
.63137 .43529 Mdot
.63529 .58431 Mdot
.60784 .13333 Mdot
.51765 .18039 Mdot
.36078 .4549 Mdot
.67451 .58431 Mdot
.56863 .54902 Mdot
.62353 .42745 Mdot
.62353 .55294 Mdot
.70588 .70588 Mdot
.57647 .06667 Mdot
.56471 .47451 Mdot
.17647 .27451 Mdot
.52941 .53333 Mdot
.61961 .41961 Mdot
.62353 .53333 Mdot
.7098 .72549 Mdot
.46667 .14118 Mdot
.74118 .86275 Mdot
.25882 .36471 Mdot
.4549 .4902 Mdot
.63137 .45098 Mdot
.61569 .51765 Mdot
.7098 .73725 Mdot
.56863 .6549 Mdot
.4902 .73333 Mdot
.1451 .34118 Mdot
.37647 .14902 Mdot
.61961 .49804 Mdot
.66275 .57255 Mdot
.72549 .74118 Mdot
.57255 .62745 Mdot
.20392 .40392 Mdot
.31373 .49804 Mdot
.4549 .36471 Mdot
.63529 .52941 Mdot
.61961 .50588 Mdot
.74118 .7451 Mdot
.51765 .16863 Mdot
.58824 .58431 Mdot
.01569 .29804 Mdot
.43922 .18431 Mdot
.62353 .52157 Mdot
.63137 .50196 Mdot
.7451 .74902 Mdot
.57647 .18039 Mdot
.58039 .40392 Mdot
.5451 .68235 Mdot
.31373 .12157 Mdot
.56863 .48627 Mdot
.63922 .50196 Mdot
.53725 .57647 Mdot
.58824 .21176 Mdot
.51373 .17255 Mdot
.3098 .52157 Mdot
.32157 .21569 Mdot
.54118 .4902 Mdot
.61569 .45882 Mdot
.53725 .53725 Mdot
.7451 .66667 Mdot
.50196 .12941 Mdot
.70588 .83137 Mdot
.30196 .08235 Mdot
.54902 .50196 Mdot
.61569 .46667 Mdot
.66275 .62353 Mdot
.6902 .70196 Mdot
.53725 .18431 Mdot
.44706 .18039 Mdot
.00392 .18824 Mdot
.4902 .48627 Mdot
.61176 .45098 Mdot
.66275 .62745 Mdot
.71373 .73333 Mdot
.53725 .16863 Mdot
.58039 .04706 Mdot
.00392 .19608 Mdot
.47451 .4902 Mdot
.61961 .4549 Mdot
.69412 .65882 Mdot
.69412 .72157 Mdot
.56863 .18431 Mdot
.56863 .03137 Mdot
.00784 .20784 Mdot
.46667 .43922 Mdot
.60392 .48235 Mdot
.66667 .63529 Mdot
.7098 .74902 Mdot
.55294 .2549 Mdot
.59608 .02745 Mdot
.32549 .42745 Mdot
.38824 .23529 Mdot
.58431 .47059 Mdot
.66275 .61176 Mdot
.70588 .71765 Mdot
.43137 .47451 Mdot
.61569 .04706 Mdot
.36863 .45882 Mdot
.32941 .09804 Mdot
.53333 .41569 Mdot
.66275 .6 Mdot
.69412 .7098 Mdot
.21176 .39216 Mdot
.59608 .04314 Mdot
.37647 .48235 Mdot
.47451 .22745 Mdot
.50196 .41569 Mdot
.64706 .56471 Mdot
.69804 .71373 Mdot
.27059 .43137 Mdot
.55686 .04314 Mdot
.35686 .48627 Mdot
.38039 .18039 Mdot
.47451 .41961 Mdot
.65098 .56078 Mdot
.6902 .72941 Mdot
.70196 .68627 Mdot
.52941 .06667 Mdot
.33333 .22745 Mdot
.46667 .26275 Mdot
.50196 .46275 Mdot
.61961 .52549 Mdot
.68235 .71765 Mdot
.68627 .70588 Mdot
.51765 .10196 Mdot
.49804 .03529 Mdot
.26667 .33725 Mdot
.43922 .43529 Mdot
.6 .48627 Mdot
.68627 .7098 Mdot
.65098 .67843 Mdot
.50588 .10588 Mdot
.44706 .20392 Mdot
.24706 .37255 Mdot
.40784 .4 Mdot
.61569 .49412 Mdot
.65098 .65098 Mdot
.68235 .72157 Mdot
.57647 .05882 Mdot
.53333 .53725 Mdot
.32941 .4 Mdot
.3451 .35686 Mdot
.60392 .48627 Mdot
.68235 .6549 Mdot
.66667 .7098 Mdot
.63529 .03922 Mdot
.55294 .07451 Mdot
.00784 .18431 Mdot
.30196 .32157 Mdot
.58431 .50196 Mdot
.6902 .66667 Mdot
.65098 .69412 Mdot
.67059 .05098 Mdot
.60784 .04314 Mdot
.36471 .43922 Mdot
.33725 .31765 Mdot
.55294 .43922 Mdot
.67843 .63529 Mdot
.7098 .73333 Mdot
.65882 .03529 Mdot
.61176 .02745 Mdot
.39608 .47451 Mdot
.39608 .11373 Mdot
.51373 .43137 Mdot
.67059 .59608 Mdot
.69412 .72157 Mdot
.70588 .05882 Mdot
.59608 .03529 Mdot
.48235 .6902 Mdot
.47451 .31765 Mdot
.4902 .44706 Mdot
.6549 .55294 Mdot
.66667 .6902 Mdot
.69412 .06667 Mdot
.50588 .08627 Mdot
.41569 .09412 Mdot
.19216 .32157 Mdot
.38431 .38824 Mdot
.65098 .53725 Mdot
.58431 .56078 Mdot
.65098 .38431 Mdot
.51765 .57647 Mdot
.55686 .49804 Mdot
.00392 .23529 Mdot
.31373 .33333 Mdot
.61569 .50196 Mdot
.53333 .49412 Mdot
.66275 .69804 Mdot
.49804 .62353 Mdot
.63137 .90588 Mdot
.01569 .20392 Mdot
.27843 .29412 Mdot
.59608 .49412 Mdot
.61176 .58824 Mdot
.63137 .67451 Mdot
.34118 .62353 Mdot
.10196 .4 Mdot
.35294 .43529 Mdot
.29804 .27451 Mdot
.58039 .47451 Mdot
.66667 .62745 Mdot
.67059 .72157 Mdot
.03529 .46275 Mdot
.02353 .39216 Mdot
.39608 .46667 Mdot
.39608 .38824 Mdot
.5098 .43529 Mdot
.62353 .57647 Mdot
.68235 .70588 Mdot
.42745 .48627 Mdot
.02353 .36471 Mdot
.40784 .4902 Mdot
.43137 .37647 Mdot
.48235 .43922 Mdot
.60392 .50196 Mdot
.63922 .69804 Mdot
.60392 .0902 Mdot
.52941 .22745 Mdot
.62353 .80784 Mdot
.20784 .3098 Mdot
.40392 .38039 Mdot
.56863 .43529 Mdot
.61176 .60392 Mdot
.66667 .04706 Mdot
.5098 .34902 Mdot
.1451 .3451 Mdot
.28627 .42353 Mdot
.30588 .3098 Mdot
.52157 .4 Mdot
.63529 .64314 Mdot
.65882 .09412 Mdot
.54118 .58039 Mdot
.47843 .13725 Mdot
.32157 .39608 Mdot
.29412 .14118 Mdot
.55294 .43137 Mdot
.65098 .63137 Mdot
.66667 .66275 Mdot
.54902 .19608 Mdot
.52941 .0549 Mdot
.34902 .43137 Mdot
.35686 .29412 Mdot
.53333 .44314 Mdot
.54902 .49804 Mdot
.60784 .6549 Mdot
.55294 .12941 Mdot
.51765 .07059 Mdot
.38431 .46275 Mdot
.41569 .38824 Mdot
.54902 .4902 Mdot
.58431 .5098 Mdot
.64706 .69412 Mdot
.57255 .51765 Mdot
.40784 .32157 Mdot
.46275 .48627 Mdot
.19608 .27451 Mdot
.45882 .42353 Mdot
.5451 .37647 Mdot
.63137 .66275 Mdot
.12157 .48235 Mdot
.61961 .69412 Mdot
.47843 .07843 Mdot
0 .23529 Mdot
.37647 .37255 Mdot
.54902 .39608 Mdot
.67843 .71765 Mdot
.58431 .33333 Mdot
.3451 .58431 Mdot
.55686 .03922 Mdot
.00392 .23529 Mdot
.36078 .33725 Mdot
.52941 .38039 Mdot
.66275 .65882 Mdot
.72157 .07843 Mdot
.56078 .08627 Mdot
.55294 .05882 Mdot
.00392 .2902 Mdot
.26667 .23137 Mdot
.4902 .38824 Mdot
.54118 .50196 Mdot
.68235 .5451 Mdot
.50196 .63922 Mdot
.50196 .09412 Mdot
.00784 .28627 Mdot
.45882 .30196 Mdot
.54902 .47843 Mdot
.58431 .53333 Mdot
.65882 .70588 Mdot
.13333 .54118 Mdot
.4902 .48627 Mdot
.41961 .36078 Mdot
.56863 .31373 Mdot
.51373 .48627 Mdot
.60784 .50588 Mdot
.67843 .72157 Mdot
.40784 .50588 Mdot
.69804 .84314 Mdot
.52549 .03529 Mdot
.3098 .39216 Mdot
.41569 .38824 Mdot
.6 .47059 Mdot
.65882 .70588 Mdot
.67843 .08627 Mdot
.53725 .66667 Mdot
.44314 .13725 Mdot
.29412 .41569 Mdot
.35294 .32549 Mdot
.53333 .38824 Mdot
.55686 .57647 Mdot
.72549 .22745 Mdot
.06275 .39216 Mdot
.46667 .13725 Mdot
.01569 .23137 Mdot
.32157 .27059 Mdot
.47843 .33333 Mdot
.78824 .82353 Mdot
.71765 .0902 Mdot
.52941 .35686 Mdot
.48235 .04706 Mdot
.33333 .47059 Mdot
.32549 .21569 Mdot
.53333 .44706 Mdot
.48235 .4902 Mdot
.60392 .66275 Mdot
.59608 .07451 Mdot
.54902 .03137 Mdot
.06275 .3451 Mdot
.38824 .28235 Mdot
.52549 .47059 Mdot
.60392 .54118 Mdot
.65882 .71373 Mdot
.62353 .12157 Mdot
.55686 .0549 Mdot
.04314 .31373 Mdot
.1098 .27451 Mdot
.49804 .46667 Mdot
.58039 .47059 Mdot
.65098 .6902 Mdot
.54902 .19216 Mdot
.57647 .71765 Mdot
.43137 .10588 Mdot
.00784 .25882 Mdot
.39608 .37647 Mdot
.57255 .45098 Mdot
.63922 .66667 Mdot
.6902 .06667 Mdot
.42745 .54902 Mdot
.67059 .73725 Mdot
.05098 .23922 Mdot
.33333 .27843 Mdot
.51373 .4 Mdot
.5098 .52941 Mdot
.57255 .12941 Mdot
.63137 .73725 Mdot
.45098 .07843 Mdot
.06275 .30196 Mdot
.32941 .08235 Mdot
.52157 .40784 Mdot
.52941 .52941 Mdot
.65098 .71373 Mdot
.53725 .72549 Mdot
.07059 .31373 Mdot
.31765 .4902 Mdot
.47059 .27843 Mdot
.44706 .4 Mdot
.58824 .5451 Mdot
.66275 .71373 Mdot
.19216 .53333 Mdot
.52157 .05882 Mdot
.07451 .37647 Mdot
.17255 .30588 Mdot
.43137 .06667 Mdot
.56863 .45882 Mdot
.59216 .63529 Mdot
.25098 .62745 Mdot
.46275 .59608 Mdot
.31373 .31373 Mdot
.1098 .28235 Mdot
.34118 .17255 Mdot
.53333 .42353 Mdot
.50196 .52549 Mdot
.67059 .1098 Mdot
.48627 .62745 Mdot
.47451 .07451 Mdot
.3451 .43529 Mdot
.32941 .25882 Mdot
.51373 .41176 Mdot
.48627 .48235 Mdot
.58431 .32941 Mdot
.52549 .62353 Mdot
.48627 .0549 Mdot
.38039 .47843 Mdot
.33725 .26275 Mdot
.48627 .40392 Mdot
.53725 .53725 Mdot
.63529 .69804 Mdot
.64314 .73333 Mdot
.40784 .07843 Mdot
.32941 .46275 Mdot
.36863 .01569 Mdot
.38824 .32941 Mdot
.59608 .55294 Mdot
.65098 .70588 Mdot
.6 .67451 Mdot
.65098 .67059 Mdot
.41569 .30588 Mdot
.01569 .17647 Mdot
.39608 .35686 Mdot
.57255 .47451 Mdot
.46667 .5098 Mdot
.24706 .39608 Mdot
.5098 .7451 Mdot
.42745 .07451 Mdot
.25098 .37255 Mdot
.37647 .28627 Mdot
.51765 .42353 Mdot
.46275 .47843 Mdot
.72157 .07059 Mdot
.53725 .68235 Mdot
.52549 .03529 Mdot
.36471 .46275 Mdot
.38039 .06667 Mdot
.51765 .42353 Mdot
.43137 .4549 Mdot
.62745 .68627 Mdot
.57255 .67843 Mdot
.4 .17647 Mdot
.35686 .43137 Mdot
.30196 .01569 Mdot
.36471 .3098 Mdot
.49804 .4549 Mdot
.58824 .66275 Mdot
.57647 .67059 Mdot
.58039 .59216 Mdot
.43137 .02745 Mdot
.00392 .17255 Mdot
.37255 .31765 Mdot
.58431 .51765 Mdot
.44706 .50588 Mdot
.55686 .46667 Mdot
.74118 .8549 Mdot
.4549 .03137 Mdot
.00392 .2 Mdot
.36078 .32157 Mdot
.57647 .47843 Mdot
.43529 .48235 Mdot
.71373 .05098 Mdot
.46667 .77255 Mdot
.5098 .02745 Mdot
.02745 .24706 Mdot
.32549 .2902 Mdot
.54118 .43922 Mdot
.36471 .43922 Mdot
.60392 .35686 Mdot
.60784 .81961 Mdot
.50588 .03137 Mdot
.31765 .41176 Mdot
.43529 .19216 Mdot
.41961 .34902 Mdot
.28627 .33333 Mdot
.57647 .64706 Mdot
.60392 .70196 Mdot
.51765 .03137 Mdot
.3451 .0549 Mdot
.1451 .12157 Mdot
.32941 .28235 Mdot
.4902 .44314 Mdot
.51373 .57255 Mdot
.56863 .13333 Mdot
.55686 .03529 Mdot
.32941 .34118 Mdot
.21176 .34118 Mdot
.34118 .3098 Mdot
.56078 .49412 Mdot
.42745 .48235 Mdot
.70196 .07059 Mdot
.56078 .08235 Mdot
.08235 .40784 Mdot
0 .21961 Mdot
.34118 .13333 Mdot
.5451 .45098 Mdot
.40784 .45098 Mdot
.67843 .67451 Mdot
.67451 .68627 Mdot
.42745 .16863 Mdot
.32941 .45098 Mdot
.48235 .38824 Mdot
.48235 .41569 Mdot
.4902 .4902 Mdot
.50588 .59608 Mdot
.61176 .68235 Mdot
.56471 .44706 Mdot
.05098 .25882 Mdot
.05882 .03529 Mdot
.35686 .30588 Mdot
.44706 .41961 Mdot
.49412 .56471 Mdot
.69412 .06275 Mdot
.44314 .12157 Mdot
.44706 .02353 Mdot
.2549 .35294 Mdot
.35686 .30588 Mdot
.57255 .50588 Mdot
.76863 .87451 Mdot
.68235 .07451 Mdot
.58039 .04706 Mdot
.41961 .12941 Mdot
.11373 .26275 Mdot
.3098 .20784 Mdot
.51373 .40392 Mdot
.44706 .47451 Mdot
.55686 .63529 Mdot
.61176 .03922 Mdot
.28235 .52941 Mdot
.30196 .39216 Mdot
.45098 .13725 Mdot
.47451 .41961 Mdot
.47059 .48627 Mdot
.48235 .58039 Mdot
.59216 .11373 Mdot
.45882 .23922 Mdot
.31373 .07059 Mdot
.2549 .03137 Mdot
.37647 .31765 Mdot
.45098 .43137 Mdot
.53333 .60392 Mdot
.66275 .07451 Mdot
.44706 .31373 Mdot
.44706 .03137 Mdot
.28627 .35686 Mdot
.32549 .28235 Mdot
.49412 .43529 Mdot
.46667 .53333 Mdot
.53333 .29412 Mdot
.04314 .43529 Mdot
.4902 .04706 Mdot
.28627 .38039 Mdot
.31373 .17255 Mdot
.56078 .32157 Mdot
.47843 .52941 Mdot
.67451 .76863 Mdot
.47451 .36078 Mdot
.51765 .03137 Mdot
.28627 .39216 Mdot
.51373 .30588 Mdot
.48235 .4 Mdot
.4549 .46275 Mdot
.45882 .55294 Mdot
.69804 .06667 Mdot
.41961 .48627 Mdot
.32157 .09804 Mdot
.13333 .1098 Mdot
.33725 .0902 Mdot
.43529 .42745 Mdot
.50196 .58824 Mdot
.68627 .14118 Mdot
.49412 .18824 Mdot
.41569 .37647 Mdot
.25098 .3451 Mdot
.33725 .2902 Mdot
.53725 .47451 Mdot
.44314 .50588 Mdot
.70588 .79216 Mdot
.5098 .22353 Mdot
.28627 .36078 Mdot
.28235 .38039 Mdot
.30588 .2549 Mdot
.51373 .41961 Mdot
.44706 .48235 Mdot
.54118 .65098 Mdot
.32941 .61176 Mdot
.42353 .05098 Mdot
.29412 .39216 Mdot
.46275 .23922 Mdot
.4 .34118 Mdot
.46667 .46667 Mdot
.6902 .78431 Mdot
.62353 .16471 Mdot
.54902 .04314 Mdot
.31373 .20392 Mdot
.24314 .00784 Mdot
.37647 .27843 Mdot
.46667 .45098 Mdot
.52549 .62353 Mdot
.72157 .08627 Mdot
.50588 .65882 Mdot
.44706 .02745 Mdot
.27059 .36078 Mdot
.33725 .06275 Mdot
.54902 .50196 Mdot
.38824 .46275 Mdot
.63922 .47451 Mdot
.51765 .40392 Mdot
.41961 .18824 Mdot
.29804 .4 Mdot
.32549 .26275 Mdot
.51373 .43529 Mdot
.41569 .45098 Mdot
.55686 .66667 Mdot
.73725 .34118 Mdot
.02353 .3098 Mdot
.25098 .37255 Mdot
.37255 .12157 Mdot
.35686 .31765 Mdot
.42353 .45882 Mdot
.70196 .78824 Mdot
.67059 .07059 Mdot
.56863 .04314 Mdot
.41176 .01176 Mdot
.20392 .28627 Mdot
.37647 .32157 Mdot
.55294 .53333 Mdot
.27059 .43922 Mdot
.62353 .11765 Mdot
.74118 .87843 Mdot
.44314 .01569 Mdot
.28235 .36471 Mdot
.34118 .2549 Mdot
.51765 .46275 Mdot
.40392 .48235 Mdot
.54902 .3451 Mdot
.11373 .52157 Mdot
.51373 .03529 Mdot
.27843 .37647 Mdot
.32941 .19608 Mdot
.47451 .42745 Mdot
.42353 .47451 Mdot
.74118 .84314 Mdot
.53333 .21961 Mdot
.52549 .0549 Mdot
.2 .37647 Mdot
.32941 0 Mdot
.44314 .38824 Mdot
.47059 .45882 Mdot
.50588 .60392 Mdot
.63137 .10196 Mdot
.48627 .21569 Mdot
.40784 .02745 Mdot
.27059 .36078 Mdot
.37255 .32157 Mdot
.52941 .50196 Mdot
.37255 .55686 Mdot
.2 .38431 Mdot
.74902 .87059 Mdot
.26667 .31373 Mdot
.28235 .38039 Mdot
.30588 .2549 Mdot
.40392 .31373 Mdot
.42745 .4902 Mdot
.73333 .72549 Mdot
.71373 .91765 Mdot
.47843 .05098 Mdot
.2902 .39608 Mdot
.34902 .05098 Mdot
.42745 .38824 Mdot
.78039 .83137 Mdot
.70196 .80392 Mdot
.59608 .07059 Mdot
.51765 .04314 Mdot
.00784 .23529 Mdot
.23922 .26667 Mdot
.44314 .14902 Mdot
.54118 .5098 Mdot
.44706 .54118 Mdot
.73333 .52157 Mdot
.74118 .85098 Mdot
.42745 .04706 Mdot
.2549 .35686 Mdot
.36863 .16471 Mdot
.47451 .42353 Mdot
.04314 .35294 Mdot
.56863 .33725 Mdot
.7451 .87059 Mdot
.48627 .72941 Mdot
.28627 .39608 Mdot
.36863 .2549 Mdot
.44706 .41961 Mdot
.41176 .45882 Mdot
.77647 .88627 Mdot
.05882 .44314 Mdot
.15686 .35686 Mdot
.29412 .38824 Mdot
.48235 .0549 Mdot
.46275 .43137 Mdot
.44706 .50588 Mdot
.49412 .58824 Mdot
.6 .09412 Mdot
.32941 .24706 Mdot
.23137 .4549 Mdot
.24706 .3451 Mdot
.40784 .30196 Mdot
.49804 .47451 Mdot
.64706 .74902 Mdot
.10588 .55294 Mdot
.7451 .86275 Mdot
.4902 .59216 Mdot
.27843 .38039 Mdot
.39216 .10196 Mdot
.50196 .18431 Mdot
.01176 .32941 Mdot
.59216 .79608 Mdot
.76078 .86667 Mdot
.44314 .65882 Mdot
.2902 .38824 Mdot
.36863 .19608 Mdot
.47843 .38824 Mdot
.45098 .48235 Mdot
.73333 .84706 Mdot
.03137 .4 Mdot
.49804 .72941 Mdot
.3098 .42353 Mdot
.26667 .32941 Mdot
.42353 .41569 Mdot
.55294 .5451 Mdot
.60784 .71373 Mdot
.64706 .0902 Mdot
.73333 .85882 Mdot
.48235 .60392 Mdot
.26667 .36471 Mdot
.38039 .36471 Mdot
.48235 .38431 Mdot
.4 .4902 Mdot
.03922 .47843 Mdot
.75686 .87451 Mdot
.63137 .79608 Mdot
.2902 .39608 Mdot
.34902 .01176 Mdot
.48627 .24314 Mdot
.41961 .47451 Mdot
.77255 .88235 Mdot
.76863 .87843 Mdot
.53333 .76078 Mdot
.31765 .42353 Mdot
.29412 .30588 Mdot
.43529 .18431 Mdot
.54902 .55294 Mdot
.52157 .64706 Mdot
.03922 .47059 Mdot
.71373 .86667 Mdot
.39608 .51765 Mdot
.27843 .37255 Mdot
.38824 .35686 Mdot
.47843 .44314 Mdot
.48627 .58431 Mdot
.59216 .2 Mdot
.7451 .86275 Mdot
.51765 .66275 Mdot
.2902 .40784 Mdot
.43529 .18039 Mdot
.52157 .49804 Mdot
.05882 .44314 Mdot
.76863 .8902 Mdot
.77255 .88627 Mdot
.23137 .48235 Mdot
.30196 .41569 Mdot
.36078 .02745 Mdot
.47059 .43137 Mdot
.57647 .61176 Mdot
.59608 .69412 Mdot
.78431 .88627 Mdot
.72549 .85882 Mdot
.43137 .55294 Mdot
.27843 .36078 Mdot
.36078 .21176 Mdot
.52941 .52549 Mdot
.76471 .86275 Mdot
.49804 .91373 Mdot
.74902 .87059 Mdot
.68235 .82353 Mdot
.2902 .38824 Mdot
.40392 .26667 Mdot
.50196 .45098 Mdot
.49804 .61176 Mdot
.7451 .87843 Mdot
.77647 .88235 Mdot
.41961 .63137 Mdot
.3098 .41176 Mdot
.38039 .07451 Mdot
.47059 .43922 Mdot
.46275 .63922 Mdot
.62353 .73333 Mdot
.78431 .88627 Mdot
.7451 .87451 Mdot
.44706 .57647 Mdot
.25098 .3451 Mdot
.40784 .40392 Mdot
.50588 .49412 Mdot
.5098 .63529 Mdot
.50196 .8549 Mdot
.76471 .88235 Mdot
.56078 .69412 Mdot
.2902 .39216 Mdot
.38824 .12157 Mdot
.47843 .3451 Mdot
.52941 .64706 Mdot
.56863 .9098 Mdot
.78039 .88627 Mdot
.38824 .64706 Mdot
.32549 .43529 Mdot
.36471 .0902 Mdot
.55294 .25098 Mdot
.00784 .46667 Mdot
.91373 1 Mdot
.80392 .90196 Mdot
.74902 .90196 Mdot
.48235 .61176 Mdot
.27843 .35686 Mdot
.4549 .4 Mdot
.55294 .57255 Mdot
.76471 .86667 Mdot
.87451 .9451 Mdot
.76471 .89804 Mdot
.69804 .81961 Mdot
.2902 .39216 Mdot
.37647 .35294 Mdot
.50588 .45098 Mdot
.67843 .81569 Mdot
.82353 .9451 Mdot
.79216 .89804 Mdot
.52157 .72157 Mdot
.36078 .46667 Mdot
.3451 .06275 Mdot
.55686 .30588 Mdot
0 .52157 Mdot
.98039 1 Mdot
.81569 .91373 Mdot
.67843 .86275 Mdot
.60784 .69804 Mdot
.29412 .36471 Mdot
.50196 .32941 Mdot
.52157 .56078 Mdot
.92549 .96471 Mdot
.85882 .95294 Mdot
.76078 .88235 Mdot
.65098 .8 Mdot
.33333 .42745 Mdot
.4 .34118 Mdot
.54118 .50588 Mdot
.83529 .89804 Mdot
.75294 .98824 Mdot
.74118 .88627 Mdot
.17255 .4902 Mdot
.38039 .49412 Mdot
.3451 .11765 Mdot
.53725 .22353 Mdot
.00784 .63922 Mdot
.92941 .95686 Mdot
.76078 .8902 Mdot
.71373 .87059 Mdot
.52549 .64706 Mdot
.32941 .38824 Mdot
.42745 .34118 Mdot
.63137 .6549 Mdot
.98039 1 Mdot
.79216 .9098 Mdot
.7451 .87451 Mdot
.37647 .52941 Mdot
.36471 .46275 Mdot
.38824 .12157 Mdot
.59216 .59216 Mdot
.84314 .91373 Mdot
.74118 .98824 Mdot
.74902 .87843 Mdot
.28627 .54902 Mdot
.35294 .46667 Mdot
.34118 .12549 Mdot
.50196 .23922 Mdot
.00784 .69804 Mdot
.39216 .6549 Mdot
.77255 .8902 Mdot
.71765 .8902 Mdot
.41961 .5451 Mdot
.34902 .42745 Mdot
.44706 .1098 Mdot
.76078 .77647 Mdot
.68235 .82745 Mdot
.79216 .90196 Mdot
.64706 .97647 Mdot
.42745 .6549 Mdot
.32157 .43137 Mdot
.42745 .18039 Mdot
.76078 .65098 Mdot
.75294 .85098 Mdot
.61176 .92549 Mdot
.32157 .92941 Mdot
.12157 .63529 Mdot
.40392 .52157 Mdot
.33725 .12941 Mdot
.49804 .22353 Mdot
.02353 .61176 Mdot
.74118 .89412 Mdot
.19608 .9098 Mdot
.07843 .60392 Mdot
.2 .5451 Mdot
.51765 .61961 Mdot
.43137 .25098 Mdot
.70196 .72157 Mdot
.78039 .88627 Mdot
.32941 .9451 Mdot
.43137 .5098 Mdot
.13725 .41176 Mdot
.30588 .40784 Mdot
.39608 .13333 Mdot
.71373 .6549 Mdot
.76863 .87843 Mdot
.28627 .94118 Mdot
.14902 .91373 Mdot
.55686 .18039 Mdot
.03137 .38824 Mdot
.32549 .02745 Mdot
.62745 .25882 Mdot
.02353 .41176 Mdot
.31373 .93725 Mdot
.06667 1 Mdot
.63922 .08627 Mdot
.38824 .18039 Mdot
.50588 .62353 Mdot
.55686 .41569 Mdot
.60392 .65098 Mdot
.23137 .87843 Mdot
.35686 1 Mdot
.68627 .09412 Mdot
.5098 .08235 Mdot
.19608 .47059 Mdot
.41569 .26275 Mdot
.62353 .62745 Mdot
.36078 .86275 Mdot
.4 .99216 Mdot
.65882 .20392 Mdot
.56471 .38039 Mdot
.39608 .16078 Mdot
.36471 .03137 Mdot
.56078 .57255 Mdot
.33725 .78824 Mdot
.04706 .99608 Mdot
.41569 .48235 Mdot
.72941 .55686 Mdot
.44314 .02353 Mdot
.34118 .32549 Mdot
.51765 .5098 Mdot
.50588 .74118 Mdot
.02353 .98039 Mdot
.62353 .44706 Mdot
.6 .52157 Mdot
.70588 .59608 Mdot
.06667 .45882 Mdot
.47451 .28235 Mdot
.6 .67843 Mdot
.01569 .97255 Mdot
.68627 .47843 Mdot
.76863 .10588 Mdot
.60784 .62745 Mdot
.48235 .05882 Mdot
.33333 .17647 Mdot
.61569 .60392 Mdot
.01176 .84314 Mdot
.69804 .52549 Mdot
.4549 .67843 Mdot
.63137 .64706 Mdot
.43529 .17647 Mdot
.44314 .17647 Mdot
.50588 .50196 Mdot
.01176 .73333 Mdot
.56863 .54118 Mdot
.03137 .99608 Mdot
.75686 .67059 Mdot
.43922 .01176 Mdot
.32549 .07451 Mdot
.4549 .43922 Mdot
.02745 .69412 Mdot
.43529 .4902 Mdot
.02745 .94902 Mdot
.59216 .4549 Mdot
.4 .36863 Mdot
.52941 .18039 Mdot
.40392 .40392 Mdot
.00784 .65882 Mdot
.47059 .45098 Mdot
.03529 .93333 Mdot
.75686 .09804 Mdot
.51373 .2902 Mdot
.70196 .63137 Mdot
.46667 .43529 Mdot
.00392 .61176 Mdot
.00784 .52157 Mdot
.00784 .93333 Mdot
.76471 .26667 Mdot
.65098 .20392 Mdot
.5451 .45882 Mdot
.57255 .33333 Mdot
.00784 .58039 Mdot
.32157 .45882 Mdot
0 .92157 Mdot
.00392 .95294 Mdot
.74902 .09804 Mdot
.67843 .4902 Mdot
.52549 .21176 Mdot
.00392 .47451 Mdot
.21961 .30588 Mdot
0 .8902 Mdot
.03529 .99608 Mdot
.77647 .1098 Mdot
.52549 .04706 Mdot
.04706 .0902 Mdot
.09804 .38824 Mdot
.32941 .33725 Mdot
0 .83529 Mdot
.33725 1 Mdot
.78039 .12549 Mdot
.53333 .03137 Mdot
.59216 .23922 Mdot
.39216 .47843 Mdot
.42745 .29804 Mdot
0 .79216 Mdot
.5451 .98039 Mdot
.7451 .14902 Mdot
.6 .06275 Mdot
.58824 .50196 Mdot
.43529 .40392 Mdot
.44314 .25882 Mdot
0 .7098 Mdot
.24706 .89412 Mdot
.47059 .38824 Mdot
.50588 .18824 Mdot
.56078 .10588 Mdot
.43529 .39608 Mdot
.28235 .34902 Mdot
.01961 .76863 Mdot
.03137 .96078 Mdot
.0902 .68627 Mdot
.2 .41176 Mdot
.58039 .06275 Mdot
.43137 .36863 Mdot
.11373 .43529 Mdot
.00392 .79216 Mdot
.00784 .97255 Mdot
.00392 .76078 Mdot
.02353 .58431 Mdot
.55294 .05882 Mdot
.43922 .3098 Mdot
.07451 .41961 Mdot
.0549 .95294 Mdot
0 .93333 Mdot
.01176 .76863 Mdot
.00784 .62353 Mdot
.35294 .14118 Mdot
.41176 .25882 Mdot
.0549 .41961 Mdot
.01961 .81961 Mdot
.00392 .88627 Mdot
.01961 .72549 Mdot
.05882 .53333 Mdot
.05882 .40392 Mdot
.41176 .24706 Mdot
.01176 .45098 Mdot
.01176 .78039 Mdot
.00392 .86667 Mdot
.16863 .61176 Mdot
.35294 .57647 Mdot
.00392 .47451 Mdot
.41961 .23137 Mdot
.00392 .4902 Mdot
0 .74902 Mdot
.00392 .83137 Mdot
.40784 .57647 Mdot
.61961 .7098 Mdot
.03529 .39608 Mdot
.47843 .17255 Mdot
.01176 .51765 Mdot
.01176 .78431 Mdot
.02745 .76863 Mdot
.51373 .60392 Mdot
.70588 .77255 Mdot
.21961 .4 Mdot
.49804 .12157 Mdot
.00784 .5451 Mdot
.00784 .73333 Mdot
.18039 .62745 Mdot
.60784 .67451 Mdot
.72157 .80784 Mdot
.25882 .37255 Mdot
.35294 .07451 Mdot
.00392 .55686 Mdot
.01569 .71373 Mdot
.43922 .57255 Mdot
.85098 .88235 Mdot
.46275 .52549 Mdot
.23529 .34902 Mdot
.03137 .12941 Mdot
.00392 .58039 Mdot
.00392 .61569 Mdot
.51765 .59216 Mdot
.58824 .58824 Mdot
.47059 .37647 Mdot
.23922 .31765 Mdot
.00784 .21569 Mdot
.00392 .58824 Mdot
.07843 .51765 Mdot
.74118 .78824 Mdot
.52157 .40392 Mdot
.46275 .2902 Mdot
.2549 .29804 Mdot
.24706 .0902 Mdot
.00392 .59216 Mdot
.43137 .53333 Mdot
.56078 .58039 Mdot
.4549 .30588 Mdot
.40392 .28627 Mdot
.2549 .28627 Mdot
.00784 .36863 Mdot
0 .62353 Mdot
.53725 .6 Mdot
.48235 .37255 Mdot
.37647 .24314 Mdot
.38431 .3098 Mdot
.20392 .25098 Mdot
.00392 .52157 Mdot
.10588 .52549 Mdot
.56863 .63137 Mdot
.40392 .2902 Mdot
.37647 .25882 Mdot
.36471 .28627 Mdot
.1451 .20392 Mdot
.00392 .47843 Mdot
.4902 .57647 Mdot
.41176 .27843 Mdot
.40392 .26275 Mdot
.36471 .2549 Mdot
.35294 .25882 Mdot
.22745 .03529 Mdot
.00392 .53333 Mdot
.69412 .74902 Mdot
.42353 .28627 Mdot
.37647 .25098 Mdot
.39608 .29412 Mdot
.33725 .25098 Mdot
.01961 .15686 Mdot
.03922 .43137 Mdot
.41569 .38039 Mdot
.43137 .31765 Mdot
.38824 .25098 Mdot
.37255 .2902 Mdot
.28235 .27843 Mdot
.00392 .45098 Mdot
.4902 .56471 Mdot
.48235 .38431 Mdot
.43137 .33333 Mdot
.38039 .25098 Mdot
.36078 .27451 Mdot
.19608 .2 Mdot
0 .49412 Mdot
.63922 .69412 Mdot
.50588 .46275 Mdot
.40784 .32941 Mdot
.3451 .23529 Mdot
.39216 .33333 Mdot
.30196 .24314 Mdot
.02353 .42353 Mdot
.52549 .4549 Mdot
.55686 .49412 Mdot
.35686 .31373 Mdot
.34902 .27451 Mdot
.3451 .28627 Mdot
.23529 .02745 Mdot
.60784 .64314 Mdot
.58039 .59608 Mdot
.43529 .39608 Mdot
.34902 .34902 Mdot
.35686 .38039 Mdot
.28235 .30588 Mdot
0 .52549 Mdot
.3451 .31373 Mdot
.44314 .39216 Mdot
.45098 .48235 Mdot
.24314 .32157 Mdot
.34902 .32157 Mdot
.34902 .36471 Mdot
.12941 .43137 Mdot
.42745 .28627 Mdot
.43137 .31765 Mdot
.1098 .21569 Mdot
.19216 .24314 Mdot
.40784 .38431 Mdot
.35686 .29804 Mdot
.5098 .54902 Mdot
.43529 .2549 Mdot
.42353 .41961 Mdot
.23137 .30588 Mdot
.12549 .18039 Mdot
.26667 .30588 Mdot
.03529 .61961 Mdot
.43922 .3098 Mdot
.46667 .2902 Mdot
.32549 .4 Mdot
.3451 .33333 Mdot
.36471 .36078 Mdot
.38431 .40784 Mdot
.44706 .42745 Mdot
.43922 .27451 Mdot
.36863 .33333 Mdot
.56078 .47059 Mdot
.4902 .33333 Mdot
.34118 .32157 Mdot
.18824 .04706 Mdot
.44706 .28627 Mdot
.4549 .25882 Mdot
.61961 .69412 Mdot
.52941 .26667 Mdot
.38824 .30588 Mdot
.43529 .46667 Mdot
.37647 .31765 Mdot
.43137 .2902 Mdot
.40784 .31373 Mdot
.54118 .43922 Mdot
.42353 .26275 Mdot
.36078 .4 Mdot
.43922 .17647 Mdot
.4549 .28235 Mdot
.42353 .27451 Mdot
.45882 .39216 Mdot
.38039 .25098 Mdot
.43922 .32549 Mdot
.46275 .52549 Mdot
.30196 .16863 Mdot
.44314 .27059 Mdot
.73333 .76471 Mdot
.27843 .33333 Mdot
.37255 .38039 Mdot
.52549 .59216 Mdot
.35294 .18824 Mdot
.43529 .29804 Mdot
.45098 .21961 Mdot
.42353 .40392 Mdot
.42353 .43922 Mdot
.54902 .61569 Mdot
.40784 .27843 Mdot
.4 .1451 Mdot
.42353 .19608 Mdot
.47059 .38824 Mdot
.44314 .37255 Mdot
.50196 .46667 Mdot
.52941 .59608 Mdot
.31765 .27843 Mdot
.46275 .33725 Mdot
.42353 .23529 Mdot
.59608 .64314 Mdot
.45882 .41176 Mdot
.67059 .71765 Mdot
.18431 .16471 Mdot
.43137 .28627 Mdot
.48235 .36078 Mdot
.57255 .57255 Mdot
.49412 .52157 Mdot
.75294 .79608 Mdot
.43922 .19216 Mdot
.41569 .29412 Mdot
.45882 .32157 Mdot
.59608 .42353 Mdot
.67843 .63922 Mdot
.87059 .89412 Mdot
.46667 .07843 Mdot
.4 .32941 Mdot
.46667 .3451 Mdot
.54118 .29804 Mdot
.65098 .48627 Mdot
.90196 .93725 Mdot
.4902 .0902 Mdot
.38039 .33333 Mdot
.47059 .36863 Mdot
.57647 .42745 Mdot
.91765 .81569 Mdot
.81961 .8902 Mdot
.36471 .19608 Mdot
.35686 .32157 Mdot
.45098 .37647 Mdot
.60784 .55294 Mdot
.99608 .98824 Mdot
.78039 .84706 Mdot
.24706 .30196 Mdot
.43922 .43922 Mdot
.4902 .45098 Mdot
.87059 .84706 Mdot
.98431 .99608 Mdot
.69804 .74118 Mdot
.37255 .38824 Mdot
.42745 .42745 Mdot
.57647 .56078 Mdot
.99216 .99216 Mdot
.83529 .89412 Mdot
.42353 .16471 Mdot
.36471 .36078 Mdot
.50588 .55294 Mdot
.99608 .99216 Mdot
.87843 .9098 Mdot
.75294 .78039 Mdot
.40392 .43137 Mdot
.52157 .58431 Mdot
.99216 .99216 Mdot
.95294 .98039 Mdot
.77255 .82745 Mdot
.36863 .41569 Mdot
.51765 .55294 Mdot
.86667 .92157 Mdot
.97255 .98039 Mdot
.79608 .84314 Mdot
.35294 .38824 Mdot
.52941 .59216 Mdot
.85882 .90588 Mdot
.90588 .92941 Mdot
.8 .84706 Mdot
.4 .43137 Mdot
.6 .66275 Mdot
.98039 .99216 Mdot
.89412 .92941 Mdot
.60784 .44314 Mdot
.47843 .51373 Mdot
.84314 .90588 Mdot
.93333 .96078 Mdot
.81569 .8549 Mdot
.42353 .43922 Mdot
.68627 .7451 Mdot
.94118 .96471 Mdot
.8549 .8902 Mdot
.41961 .2549 Mdot
.65882 .72549 Mdot
.91373 .93725 Mdot
.89804 .9098 Mdot
.46667 .41569 Mdot
.77647 .83922 Mdot
.89804 .92941 Mdot
.34118 .18824 Mdot
.61176 .68627 Mdot
.9098 .94118 Mdot
.36078 .20784 Mdot
.67059 .67451 Mdot
.74118 .59608 Mdot
.60392 .32157 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0258451 0.97619 0.518133 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.86275 .04706 Mdot
.71765 .09412 Mdot
.4902 .29804 Mdot
.43137 .22745 Mdot
.52549 .36471 Mdot
.72157 .10588 Mdot
.40784 .27843 Mdot
.42745 .31765 Mdot
.72157 .10588 Mdot
.25098 .17255 Mdot
.05098 .03137 Mdot
.48235 .31373 Mdot
.49412 .32157 Mdot
.07451 .0549 Mdot
.24706 .24314 Mdot
.42745 .19216 Mdot
.07059 .01569 Mdot
.08235 .05882 Mdot
.06275 .07059 Mdot
.43137 .2 Mdot
.01569 .00392 Mdot
.08235 .07059 Mdot
.02745 .02745 Mdot
.49804 .32941 Mdot
.01569 0 Mdot
.03529 .04706 Mdot
.02745 .02353 Mdot
.83137 .8 Mdot
.39216 .28235 Mdot
.01569 .02353 Mdot
.16863 .13725 Mdot
.01176 .01569 Mdot
.45882 .25882 Mdot
.01961 .02353 Mdot
.02745 .04314 Mdot
.03529 .03529 Mdot
.80392 .79216 Mdot
.40392 .27059 Mdot
.00784 .02353 Mdot
.0549 .03922 Mdot
.03529 .03137 Mdot
.65098 .61961 Mdot
.06667 .02745 Mdot
.02745 .03529 Mdot
.07059 .0549 Mdot
.04314 .04314 Mdot
.74118 .72157 Mdot
.0549 .02353 Mdot
.01569 .01961 Mdot
.06667 .05098 Mdot
.03922 .03529 Mdot
.82353 .80392 Mdot
.18039 .08627 Mdot
.01569 .02353 Mdot
.06275 .05098 Mdot
.51373 .46275 Mdot
.73725 .71373 Mdot
.84706 .04706 Mdot
.01569 .02353 Mdot
.03922 .03529 Mdot
.7451 .69412 Mdot
.02353 .01961 Mdot
.81176 .82353 Mdot
.01176 .02353 Mdot
.02745 .03529 Mdot
.11765 .09412 Mdot
.87451 .84706 Mdot
.84314 .82353 Mdot
.32941 .06275 Mdot
.01961 .01569 Mdot
.03922 .05098 Mdot
.90196 .89804 Mdot
.06275 .06275 Mdot
.83529 .84706 Mdot
0 0 Mdot
.02353 .02353 Mdot
.07059 .05098 Mdot
.89804 .90588 Mdot
.05882 .07843 Mdot
.81176 .82745 Mdot
.00784 .01176 Mdot
.01569 .02353 Mdot
.76078 .70196 Mdot
.90196 .90588 Mdot
.83137 .83529 Mdot
.62353 .59216 Mdot
0 .01176 Mdot
.02353 .03137 Mdot
.8902 .87843 Mdot
.88235 .88235 Mdot
.68235 .65098 Mdot
.6 .51765 Mdot
.01961 .01961 Mdot
.02745 .03529 Mdot
.8902 .87843 Mdot
.88235 .88627 Mdot
.67059 .62353 Mdot
.54902 .48627 Mdot
.05098 .05098 Mdot
.02353 .02745 Mdot
.89804 .89412 Mdot
.88235 .88235 Mdot
.11373 .10196 Mdot
.75686 .72549 Mdot
.0549 .03529 Mdot
.02353 .02745 Mdot
.8902 .87843 Mdot
.87451 .88627 Mdot
.01961 .03137 Mdot
.81569 .83137 Mdot
.08627 .03922 Mdot
.02353 .02745 Mdot
.86667 .86667 Mdot
.87843 .88235 Mdot
.04314 .04314 Mdot
.81569 .82745 Mdot
.00784 .00784 Mdot
.01176 .01176 Mdot
.75294 .67059 Mdot
.82745 .81961 Mdot
.85098 .84706 Mdot
.78431 .77255 Mdot
.00392 .01176 Mdot
.0549 .04706 Mdot
.07059 .06667 Mdot
.87451 .86275 Mdot
.86667 .86667 Mdot
.75294 .71373 Mdot
.14902 .08235 Mdot
.04314 .03137 Mdot
.02745 .03922 Mdot
.88627 .87843 Mdot
.05882 .06667 Mdot
.06275 .06667 Mdot
.83137 .84314 Mdot
.03529 .03529 Mdot
.05098 .04314 Mdot
.85098 .83137 Mdot
.07451 .07843 Mdot
.8549 .8549 Mdot
.80784 .79608 Mdot
.09412 0 Mdot
.04314 .03529 Mdot
.02745 .03137 Mdot
.78824 .78431 Mdot
.03922 .04314 Mdot
.02745 .03137 Mdot
.77255 .78431 Mdot
.02353 .02353 Mdot
.0549 .03922 Mdot
.84314 .83529 Mdot
.05098 .05882 Mdot
.84706 .84706 Mdot
.70196 .67059 Mdot
.1098 .00784 Mdot
.04314 .04314 Mdot
.02745 .02353 Mdot
.18824 .18824 Mdot
.03529 .03137 Mdot
.03922 .03922 Mdot
.81961 .83137 Mdot
.02353 .03137 Mdot
.05098 .03922 Mdot
.85098 .84706 Mdot
.07059 .05882 Mdot
.82745 .80392 Mdot
.72941 .69412 Mdot
.28627 .18824 Mdot
.03922 .03922 Mdot
.07843 .05882 Mdot
.0902 .0902 Mdot
.03922 .04314 Mdot
.19216 .1451 Mdot
.81569 .82745 Mdot
.00784 .01569 Mdot
.05098 .04314 Mdot
.83922 .83922 Mdot
.07843 .06667 Mdot
.00392 .00784 Mdot
.33725 .32549 Mdot
.47843 .47059 Mdot
.01569 .02353 Mdot
.06275 .04314 Mdot
.41961 .41961 Mdot
.03137 .02353 Mdot
.84314 .84314 Mdot
.62353 .60784 Mdot
.14118 .13333 Mdot
.04706 .04314 Mdot
.74118 .7098 Mdot
.07059 .05882 Mdot
.03922 .03137 Mdot
.15686 .13333 Mdot
.75294 .76471 Mdot
.00392 .01176 Mdot
.05882 .03922 Mdot
.85098 .8549 Mdot
.66275 .60784 Mdot
.00784 .00392 Mdot
.17647 .18431 Mdot
.29412 .27451 Mdot
.01176 .02745 Mdot
.07059 .05098 Mdot
.0549 .05882 Mdot
.84706 .8 Mdot
.61961 .58431 Mdot
.65882 .64314 Mdot
.62745 .63529 Mdot
.04314 .03529 Mdot
.88627 .88627 Mdot
.08235 .03922 Mdot
.04314 .04314 Mdot
.06667 .0549 Mdot
.77255 .78039 Mdot
.00784 .02353 Mdot
.04706 .03529 Mdot
.6549 .62353 Mdot
.88627 .87451 Mdot
.00784 .01569 Mdot
.22353 .21176 Mdot
.45098 .44314 Mdot
.00784 .02745 Mdot
.07059 .0549 Mdot
.05098 .0549 Mdot
.87843 .88235 Mdot
.77647 .75686 Mdot
.66275 .64314 Mdot
.48235 .50196 Mdot
.03922 .04314 Mdot
.88235 .89412 Mdot
.85098 .81569 Mdot
.23922 .19608 Mdot
.03529 .04706 Mdot
.80784 .81961 Mdot
.00392 .00392 Mdot
.04706 .03922 Mdot
.12157 .09412 Mdot
.87843 .86667 Mdot
.02353 .02745 Mdot
.01569 .02745 Mdot
.60784 .61569 Mdot
.00392 .02745 Mdot
.07451 .05882 Mdot
.11373 .09412 Mdot
.87451 .87059 Mdot
.83529 .83137 Mdot
.68627 .67451 Mdot
.75294 .72549 Mdot
.04706 .06275 Mdot
.88235 .8902 Mdot
.88235 .86275 Mdot
.52941 .48627 Mdot
.04706 .04706 Mdot
.83529 .84314 Mdot
.00784 .01961 Mdot
.04706 .04706 Mdot
.07843 .05882 Mdot
.88235 .87843 Mdot
.02353 .02353 Mdot
.04706 .05098 Mdot
.57647 .58039 Mdot
.00784 .01176 Mdot
.0902 .06275 Mdot
.25882 .20784 Mdot
.80784 .77647 Mdot
.81176 .80392 Mdot
.23137 .21961 Mdot
.6549 .27059 Mdot
.03137 .0549 Mdot
.85882 .86667 Mdot
.86667 .86275 Mdot
.23529 .21961 Mdot
0 .00392 Mdot
.82353 .83529 Mdot
.01176 .01569 Mdot
.05882 .07059 Mdot
.05882 .04706 Mdot
.19608 .18431 Mdot
.02353 .02353 Mdot
.02353 .02745 Mdot
.83137 .86667 Mdot
0 0 Mdot
.05098 .03529 Mdot
.17647 .1451 Mdot
.08235 .03922 Mdot
.55686 .47451 Mdot
.03529 .05098 Mdot
.21176 .22353 Mdot
.01176 .01176 Mdot
.87843 .8902 Mdot
.85098 .85098 Mdot
.71373 .68627 Mdot
.03922 .03529 Mdot
.61961 .61176 Mdot
.36863 .35686 Mdot
.03529 .04706 Mdot
.06275 .04314 Mdot
.10588 .08627 Mdot
.03922 .05098 Mdot
0 .01176 Mdot
.81961 .83529 Mdot
.01176 .00784 Mdot
.04314 .04706 Mdot
.08627 .06667 Mdot
.07059 .03922 Mdot
.03137 .02353 Mdot
.02353 .02745 Mdot
.7451 .76863 Mdot
.00392 .00392 Mdot
.5451 .49412 Mdot
.84314 .83922 Mdot
.82353 .82353 Mdot
.80392 .79216 Mdot
.01961 .01569 Mdot
.34118 .24706 Mdot
.00784 .02353 Mdot
.22353 .2 Mdot
.85882 .83922 Mdot
.04706 .0549 Mdot
.00392 .01961 Mdot
.63137 .61569 Mdot
.28627 .31373 Mdot
.03137 .04314 Mdot
.04314 .04314 Mdot
.17255 .11373 Mdot
.02745 .03529 Mdot
.00784 .01176 Mdot
.77255 .80392 Mdot
0 0 Mdot
.06275 .04706 Mdot
.84314 .82745 Mdot
.86275 .85098 Mdot
.50588 .44314 Mdot
.03137 .03529 Mdot
.56471 .6 Mdot
.00392 0 Mdot
.87843 .8902 Mdot
.14118 .11373 Mdot
.04314 .03137 Mdot
.03137 .03137 Mdot
.03529 .04314 Mdot
.73725 .14118 Mdot
0 .01961 Mdot
.61569 .55686 Mdot
.87059 .84706 Mdot
.07451 .07843 Mdot
.00392 .01176 Mdot
.60392 .60392 Mdot
.00392 .00392 Mdot
.03529 .03922 Mdot
.4 .31373 Mdot
.73333 .72157 Mdot
.03137 .02745 Mdot
.00392 .01176 Mdot
.83137 .8549 Mdot
.00392 .00392 Mdot
.68235 .65098 Mdot
.2902 .24706 Mdot
.81569 .77647 Mdot
.81569 .81176 Mdot
.01961 .02353 Mdot
.53333 .5451 Mdot
.00392 .00392 Mdot
.13333 .08235 Mdot
.76471 .71765 Mdot
.8549 .85098 Mdot
.00784 .02353 Mdot
.02745 .03922 Mdot
.36863 .37647 Mdot
.01176 .03137 Mdot
.84314 .83922 Mdot
.82353 .79216 Mdot
.07843 .06275 Mdot
.01569 .03137 Mdot
.6549 .65882 Mdot
.00392 .00392 Mdot
.05098 .04314 Mdot
.80392 .78431 Mdot
.86667 .86275 Mdot
.45098 .36863 Mdot
.00392 .01961 Mdot
.78431 .82745 Mdot
.00392 .00392 Mdot
.8 .80784 Mdot
.84314 .85098 Mdot
.85882 .85882 Mdot
.09412 .06275 Mdot
.01569 .02353 Mdot
.59216 .56078 Mdot
0 0 Mdot
.80784 .81569 Mdot
.78431 .72157 Mdot
.85098 .8549 Mdot
.00784 .01961 Mdot
.0549 .07451 Mdot
.11765 .11765 Mdot
.01176 .03137 Mdot
.04706 .04314 Mdot
.90196 .9098 Mdot
.05098 .0549 Mdot
.00392 .00784 Mdot
.69804 .70588 Mdot
0 0 Mdot
.04706 .03922 Mdot
.08627 .07451 Mdot
.86275 .85882 Mdot
.82745 .82745 Mdot
0 .01961 Mdot
.78431 .82353 Mdot
0 .00392 Mdot
.18824 .18039 Mdot
.08235 .05098 Mdot
.8 .78824 Mdot
.01961 .02745 Mdot
.02353 .03922 Mdot
.68627 .05882 Mdot
.01569 .02745 Mdot
.05882 .04706 Mdot
.8902 .8902 Mdot
.82745 .83137 Mdot
.00784 .01961 Mdot
.04314 .04706 Mdot
0 0 Mdot
.01176 .01961 Mdot
.05098 .0549 Mdot
.77647 .79216 Mdot
.20392 .1451 Mdot
.00392 .01569 Mdot
.78431 .81569 Mdot
.00392 .00392 Mdot
.05882 .03529 Mdot
.08235 .06667 Mdot
.09412 .08235 Mdot
.80392 .81176 Mdot
.00392 .01569 Mdot
.49412 .52549 Mdot
.00392 .01569 Mdot
.03137 .03137 Mdot
.8549 .8549 Mdot
.84314 .81961 Mdot
.00784 .01961 Mdot
.03529 .04706 Mdot
.4 .36471 Mdot
.03922 .03922 Mdot
.04706 .04706 Mdot
.38431 .4 Mdot
.06667 .05882 Mdot
.00392 .01176 Mdot
.55294 .51765 Mdot
0 .00392 Mdot
.00784 .01961 Mdot
.05098 .04314 Mdot
.08235 .07059 Mdot
.82353 .80392 Mdot
.00784 .02353 Mdot
.82745 .85882 Mdot
.00392 .01961 Mdot
.04314 .03529 Mdot
.85098 .8549 Mdot
.27451 .22353 Mdot
.37647 .35686 Mdot
.00784 .02353 Mdot
.4 .39608 Mdot
0 .01176 Mdot
.05098 .04314 Mdot
.23922 .23529 Mdot
.19608 .18824 Mdot
.00392 .01176 Mdot
.04706 .05098 Mdot
.08627 .08627 Mdot
.03137 .04706 Mdot
.03922 .04706 Mdot
.08235 .0549 Mdot
.0549 .0549 Mdot
.00392 .00784 Mdot
.41961 .40392 Mdot
0 .00392 Mdot
.01176 .01569 Mdot
.82745 .80392 Mdot
.07451 .04706 Mdot
.81176 .82353 Mdot
0 .01569 Mdot
.74902 .78039 Mdot
.00392 .01961 Mdot
.0549 .04706 Mdot
.36078 .35686 Mdot
.77255 .75686 Mdot
.22745 .19608 Mdot
.03922 .04706 Mdot
.67843 .07451 Mdot
.36471 .36863 Mdot
.04706 .05098 Mdot
.15294 .12941 Mdot
.42353 .38824 Mdot
.00392 .01176 Mdot
.05882 .06275 Mdot
.00784 .00392 Mdot
.01569 .01961 Mdot
.25882 .21176 Mdot
.04706 .02353 Mdot
.51373 .47059 Mdot
.00392 .01569 Mdot
.63137 .63529 Mdot
.01176 .02745 Mdot
.01961 .02353 Mdot
.77647 .77255 Mdot
.87843 .87843 Mdot
.81961 .82745 Mdot
.00784 .02353 Mdot
.64706 .67843 Mdot
0 .00784 Mdot
.03529 .03922 Mdot
.84706 .85098 Mdot
.84706 .85098 Mdot
.63922 .62353 Mdot
.05098 .05098 Mdot
.70588 .74902 Mdot
.01176 .04314 Mdot
.01569 .01961 Mdot
.08235 .06275 Mdot
.47843 .47059 Mdot
.00392 .01176 Mdot
.16078 .15686 Mdot
.01176 .01569 Mdot
.01569 .02745 Mdot
.83529 .81176 Mdot
.85882 .86275 Mdot
.83529 .83529 Mdot
.00392 .01569 Mdot
.66275 .68235 Mdot
.00392 .00784 Mdot
.01569 .02745 Mdot
.82353 .80392 Mdot
.85882 .8549 Mdot
.81961 .83137 Mdot
.00392 .00784 Mdot
.33333 .3451 Mdot
.00784 .01176 Mdot
.01961 .01961 Mdot
.16863 .11765 Mdot
.84706 .85098 Mdot
.0902 .08627 Mdot
.06667 .07451 Mdot
.7098 .74902 Mdot
.01569 .01961 Mdot
.03137 .04314 Mdot
.86275 .86667 Mdot
.07059 .07059 Mdot
0 .00392 Mdot
.04706 .0549 Mdot
.00392 .00392 Mdot
.01176 .01961 Mdot
.13333 .13333 Mdot
.84706 .8549 Mdot
.76471 .74902 Mdot
.00392 .00784 Mdot
.6902 .7098 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.16078 .17255 Mdot
.22745 .24314 Mdot
.83137 .83529 Mdot
.00392 .00392 Mdot
.51373 .53725 Mdot
.00392 .01176 Mdot
.01569 .02353 Mdot
.79216 .76078 Mdot
.84706 .86275 Mdot
.04314 .03529 Mdot
.02353 .04706 Mdot
.45098 .43137 Mdot
.01176 .02353 Mdot
.02353 .03922 Mdot
.85098 .85098 Mdot
.04314 .03137 Mdot
.00392 .00392 Mdot
.04706 .05882 Mdot
.00392 .00784 Mdot
.01961 .02745 Mdot
.03529 .03922 Mdot
.21176 .23137 Mdot
.04314 .05882 Mdot
.01176 .01569 Mdot
.07451 .0902 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.08235 .0902 Mdot
.65882 .61569 Mdot
.82353 .82353 Mdot
.00392 .00784 Mdot
.76863 .82353 Mdot
.00392 .00392 Mdot
.01569 .02745 Mdot
.83529 .84706 Mdot
.84706 .84706 Mdot
.5098 .5098 Mdot
.70196 .70196 Mdot
.60784 .0549 Mdot
.00784 .01569 Mdot
.03529 .05882 Mdot
.7451 .75686 Mdot
.84706 .84706 Mdot
.00392 .01176 Mdot
.03137 .0549 Mdot
.08235 .1098 Mdot
.01176 .03922 Mdot
.03529 .04314 Mdot
.09804 .06667 Mdot
.07059 .07843 Mdot
0 .00392 Mdot
.03529 .06275 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.06275 .04706 Mdot
.86667 .87451 Mdot
.05882 .05882 Mdot
.00392 .00392 Mdot
.76471 .80392 Mdot
0 0 Mdot
.00784 .02745 Mdot
.84314 .85098 Mdot
.85098 .86275 Mdot
.81569 .81569 Mdot
.00392 .00784 Mdot
.50588 .53333 Mdot
.00784 .02353 Mdot
.01569 .02745 Mdot
.12941 .12941 Mdot
.83529 .84314 Mdot
.01961 .02745 Mdot
0 .01176 Mdot
.36078 .4 Mdot
.00784 .03529 Mdot
.02745 .03137 Mdot
.8549 .83529 Mdot
.07843 .09804 Mdot
.00784 .01569 Mdot
.01569 .04314 Mdot
.00392 0 Mdot
.01176 .03529 Mdot
.51373 .46667 Mdot
.86667 .87059 Mdot
.04314 .06275 Mdot
.00392 .01176 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .01569 Mdot
.84314 .8549 Mdot
.37647 .39608 Mdot
.05882 .06667 Mdot
.00392 .00784 Mdot
.81569 .87059 Mdot
.00784 .01176 Mdot
.00784 .03137 Mdot
.67843 .64706 Mdot
.85098 .85882 Mdot
.81176 .81176 Mdot
0 .01176 Mdot
.41176 .05098 Mdot
.00784 .02353 Mdot
.03529 .04314 Mdot
.8549 .86275 Mdot
.06667 .07059 Mdot
.00392 .01176 Mdot
.01569 .05098 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.06667 .04314 Mdot
.68235 .69804 Mdot
.03137 .05098 Mdot
.00392 .01176 Mdot
.02745 .05098 Mdot
0 .00392 Mdot
.01176 .02745 Mdot
.83137 .83922 Mdot
.61176 .58824 Mdot
.02745 .05882 Mdot
.00392 .01961 Mdot
.79608 .82353 Mdot
.00784 .00784 Mdot
.00392 .02745 Mdot
.84706 .84314 Mdot
.49412 .51373 Mdot
.03529 .05098 Mdot
.00392 .01961 Mdot
.41961 .42353 Mdot
0 .01176 Mdot
.02353 .03529 Mdot
.83922 .85098 Mdot
.06275 .07451 Mdot
.55294 .55686 Mdot
.00392 .02353 Mdot
.00784 .00784 Mdot
.00392 .02353 Mdot
.03922 .03529 Mdot
.14118 .12941 Mdot
.04706 .06667 Mdot
.00392 .01569 Mdot
.00784 .03922 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.69804 .67843 Mdot
.85882 .8549 Mdot
.07059 .08235 Mdot
.00392 .00784 Mdot
.03922 .0549 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.84706 .86275 Mdot
.08627 .10196 Mdot
.03529 .0549 Mdot
0 .00392 Mdot
.52157 .56863 Mdot
.00392 .00784 Mdot
.02353 .02745 Mdot
.14118 .15686 Mdot
.02353 .02353 Mdot
.02745 .04314 Mdot
0 .02353 Mdot
.01176 0 Mdot
.00392 .01569 Mdot
.03922 .04706 Mdot
.08627 .0902 Mdot
.6 .57255 Mdot
.01569 .03529 Mdot
.01961 .03922 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.15294 .13725 Mdot
.25882 .28627 Mdot
.79608 .77647 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.00392 .01176 Mdot
.00392 .01961 Mdot
.56471 .59608 Mdot
.0549 .04706 Mdot
.76471 .75294 Mdot
.00392 .00392 Mdot
.56863 .59216 Mdot
.00392 .00392 Mdot
.02745 .04314 Mdot
.21961 .21569 Mdot
.85098 .85882 Mdot
.06275 .05098 Mdot
.00392 .01176 Mdot
.28235 .26667 Mdot
.00784 .01569 Mdot
.04314 .05882 Mdot
.07059 .08627 Mdot
.83922 .8549 Mdot
.01176 .02745 Mdot
.01176 .03137 Mdot
.00392 0 Mdot
.00392 .01961 Mdot
.04706 .06667 Mdot
.01176 .01176 Mdot
.83137 .84706 Mdot
0 .00784 Mdot
.00392 .03529 Mdot
.00784 .00392 Mdot
.00392 .00784 Mdot
.05882 .04314 Mdot
.87843 .86667 Mdot
.83922 .83922 Mdot
0 .01176 Mdot
.04706 .05098 Mdot
.00392 .00784 Mdot
.00784 .02745 Mdot
.84706 .8549 Mdot
.85882 .87059 Mdot
.81569 .82745 Mdot
0 .00392 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.02353 .03922 Mdot
.10588 .11765 Mdot
.8549 .86667 Mdot
.34902 .32941 Mdot
0 .01176 Mdot
.00392 .00784 Mdot
.00392 .00784 Mdot
.04314 .05098 Mdot
.82745 .81961 Mdot
.83529 .84314 Mdot
0 .01569 Mdot
.00392 .02745 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.54902 .54118 Mdot
.87843 .8902 Mdot
.82353 .84314 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.00392 .00392 Mdot
.00784 .02353 Mdot
.85098 .86275 Mdot
.87451 .87843 Mdot
.83137 .84314 Mdot
.00392 .01569 Mdot
.53725 .54902 Mdot
0 0 Mdot
.01176 .03137 Mdot
.34902 .31765 Mdot
.72941 .76471 Mdot
.81961 .82745 Mdot
.00392 .03137 Mdot
.55294 .03137 Mdot
.00392 .01569 Mdot
.03137 .04706 Mdot
.87059 .88235 Mdot
.11765 .13725 Mdot
.10588 .11373 Mdot
.02353 .05098 Mdot
.01569 .00784 Mdot
.00784 .01961 Mdot
.04314 .06667 Mdot
.8902 .90588 Mdot
.03137 .05098 Mdot
.01176 .01961 Mdot
.00392 .02745 Mdot
0 0 Mdot
.00784 .00392 Mdot
.0549 .07059 Mdot
.86667 .87843 Mdot
.36863 .33725 Mdot
.02353 .03922 Mdot
.00392 .02745 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.50196 .52157 Mdot
.66275 .70588 Mdot
.09412 .1098 Mdot
.00392 .02745 Mdot
0 .01569 Mdot
.01176 .00784 Mdot
.00392 .00784 Mdot
.38039 .36078 Mdot
.11373 .13333 Mdot
.03529 .04706 Mdot
.01176 .04314 Mdot
.56078 .56863 Mdot
0 .00392 Mdot
.00784 .02745 Mdot
.90196 .90588 Mdot
.42745 .41961 Mdot
.64314 .63137 Mdot
.00784 .03137 Mdot
.12549 .11765 Mdot
.00784 .01569 Mdot
.01961 .03529 Mdot
.8902 .89804 Mdot
.87059 .87059 Mdot
.83137 .83137 Mdot
.01961 .03922 Mdot
.56078 .02353 Mdot
.00392 .01569 Mdot
.03137 .0549 Mdot
.88235 .89412 Mdot
.85098 .85882 Mdot
.08235 .09804 Mdot
0 .00392 Mdot
.00784 .00392 Mdot
0 0 Mdot
.03529 .0549 Mdot
.27451 .31765 Mdot
.6902 .7098 Mdot
.00784 .04314 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.0902 .10588 Mdot
.07451 .09412 Mdot
.03922 .0549 Mdot
.00392 .03529 Mdot
.01176 .03529 Mdot
0 .00392 Mdot
.00784 .01569 Mdot
.84706 .85098 Mdot
.14902 .14118 Mdot
.03137 .05098 Mdot
.00784 .04314 Mdot
.00392 .02745 Mdot
0 .00392 Mdot
0 .00784 Mdot
.85882 .87059 Mdot
.86275 .87843 Mdot
.37647 .34902 Mdot
.00392 .03137 Mdot
.23529 .25098 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.87451 .88235 Mdot
.85098 .86275 Mdot
.81961 .84314 Mdot
.00392 .02745 Mdot
.4 .40784 Mdot
.00392 .01176 Mdot
0 .00784 Mdot
.27059 .31373 Mdot
.64706 .6902 Mdot
.07451 .10196 Mdot
.01569 .04314 Mdot
.05098 .01961 Mdot
.00784 .01176 Mdot
.00784 .03922 Mdot
.08235 .08235 Mdot
.05882 .09412 Mdot
.01569 .03922 Mdot
.02353 .04314 Mdot
.03529 0 Mdot
.00392 .01176 Mdot
.01961 .02353 Mdot
.07843 .08627 Mdot
.06667 .09412 Mdot
0 .01961 Mdot
.03922 .06275 Mdot
.00392 .00392 Mdot
0 .02353 Mdot
.83137 .83922 Mdot
.50196 .5098 Mdot
.38824 .38039 Mdot
.00392 .01961 Mdot
.02353 .05098 Mdot
.00392 .00392 Mdot
.02745 .04706 Mdot
.83922 .8549 Mdot
.86667 .87059 Mdot
.85098 .86275 Mdot
.00392 .01961 Mdot
.00392 .03137 Mdot
.00784 .00784 Mdot
.01569 .03137 Mdot
.64314 .67059 Mdot
.7098 .72549 Mdot
.22745 .27451 Mdot
.00784 .03137 Mdot
.02353 .03922 Mdot
.01176 .01176 Mdot
.00392 .01176 Mdot
.06667 .08235 Mdot
.01569 .03137 Mdot
.02353 .03529 Mdot
.00784 .02745 Mdot
.34902 .35294 Mdot
0 0 Mdot
.00392 .01569 Mdot
.07059 .08235 Mdot
.44314 .42353 Mdot
.21961 .20784 Mdot
.00392 .03137 Mdot
.00392 .00392 Mdot
.00392 .00392 Mdot
.03137 .03137 Mdot
.08235 .10196 Mdot
.83529 .84314 Mdot
.01569 .01176 Mdot
.01176 .03137 Mdot
.59216 .01176 Mdot
.01176 .03922 Mdot
.81961 .81961 Mdot
.04706 .07451 Mdot
.82353 .8549 Mdot
.02745 .05882 Mdot
.03529 .04706 Mdot
0 .00392 Mdot
.00784 .03922 Mdot
.82745 .83922 Mdot
.05882 .07451 Mdot
.40784 .41961 Mdot
.00392 .03529 Mdot
.04314 .06667 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18824 .21569 Mdot
.22353 .27059 Mdot
.85098 .85882 Mdot
.00392 .02353 Mdot
.00392 .03529 Mdot
.00392 .00392 Mdot
.00784 .03529 Mdot
.01176 .02353 Mdot
.36471 .41176 Mdot
.84706 .85098 Mdot
.01176 .02745 Mdot
.00784 .01961 Mdot
.01176 .00784 Mdot
.01569 .02745 Mdot
.76471 .73333 Mdot
.12157 .17647 Mdot
.83137 .84314 Mdot
.00392 .02745 Mdot
.38431 .38824 Mdot
.00392 .00392 Mdot
.06275 .06667 Mdot
.86275 .88235 Mdot
.03137 .05098 Mdot
.83922 .84706 Mdot
.01176 .03137 Mdot
0 0 Mdot
.00784 .02353 Mdot
.80784 .79608 Mdot
.8549 .87059 Mdot
.72941 .71765 Mdot
.84314 .8549 Mdot
.01569 .03922 Mdot
.03922 .01569 Mdot
.28627 .3098 Mdot
.81961 .82745 Mdot
.6549 .66667 Mdot
.85098 .8549 Mdot
.67059 .6902 Mdot
.01961 .04314 Mdot
.00392 .00392 Mdot
.03529 .06275 Mdot
.11373 .11765 Mdot
.06667 .07451 Mdot
.85098 .85882 Mdot
.01961 .05098 Mdot
.01961 .03529 Mdot
.1098 .11373 Mdot
.00392 .02745 Mdot
.76078 .75686 Mdot
.06667 .08627 Mdot
.80784 .83922 Mdot
0 .02745 Mdot
.00784 .03529 Mdot
.00392 .00392 Mdot
.01176 .04314 Mdot
.51373 .55294 Mdot
.06275 .07843 Mdot
.1098 .15686 Mdot
.01176 .03529 Mdot
0 .02353 Mdot
.00392 .00784 Mdot
.01961 .03529 Mdot
.05882 .07843 Mdot
.62745 .61961 Mdot
.06667 .09804 Mdot
0 .01569 Mdot
.45098 .46275 Mdot
0 .00392 Mdot
.31765 .30196 Mdot
.36863 .36078 Mdot
.87059 .87843 Mdot
.76471 .76078 Mdot
0 .01569 Mdot
.00392 .00392 Mdot
0 .00784 Mdot
.83137 .83922 Mdot
.86275 .87843 Mdot
.86667 .87059 Mdot
.79608 .81569 Mdot
.00392 .01569 Mdot
0 .00784 Mdot
.00392 .01961 Mdot
.08627 .07059 Mdot
.08627 .10588 Mdot
.40784 .45882 Mdot
.03137 .0549 Mdot
.00392 .01569 Mdot
.12157 .03137 Mdot
.00784 .02353 Mdot
.83137 .83529 Mdot
.06275 .08627 Mdot
.09412 .12157 Mdot
.00784 .02745 Mdot
.00784 .03137 Mdot
.00392 .00392 Mdot
.02353 .04314 Mdot
.07059 .09412 Mdot
.07843 .0902 Mdot
.06275 .07451 Mdot
.00784 .03529 Mdot
.00392 .03137 Mdot
.00392 0 Mdot
.00784 .02353 Mdot
.01176 .01961 Mdot
.3098 .3098 Mdot
.20784 .18824 Mdot
.00392 .02745 Mdot
.00784 .03529 Mdot
0 .00392 Mdot
.01176 .03529 Mdot
.62745 .61176 Mdot
.85882 .86667 Mdot
.84314 .82745 Mdot
.00784 .04314 Mdot
.03137 .03922 Mdot
0 0 Mdot
.01961 .03922 Mdot
.85098 .86275 Mdot
.8549 .87451 Mdot
.7098 .75294 Mdot
.00392 .02353 Mdot
.10196 .11373 Mdot
.00784 .00784 Mdot
.41569 .42353 Mdot
.19608 .24314 Mdot
.14902 .2 Mdot
.06667 .10588 Mdot
0 .00784 Mdot
0 0 Mdot
.00392 .01176 Mdot
.81569 .81961 Mdot
.0549 .06275 Mdot
.05098 .07451 Mdot
.05098 .07843 Mdot
0 .01569 Mdot
0 .00392 Mdot
.00392 .00784 Mdot
.76471 .76863 Mdot
.0549 .06667 Mdot
.12157 .12549 Mdot
0 .00784 Mdot
.00392 .01176 Mdot
.01569 .01569 Mdot
.00392 .01569 Mdot
.82745 .83529 Mdot
.0549 .05882 Mdot
.73725 .73333 Mdot
0 .00784 Mdot
0 .01176 Mdot
.00392 .00392 Mdot
.00392 .01961 Mdot
.80392 .79216 Mdot
.03529 .0549 Mdot
.86667 .87059 Mdot
.00392 .01569 Mdot
.00392 .02353 Mdot
.16078 .03137 Mdot
0 .01961 Mdot
.81176 .83529 Mdot
.0549 .07843 Mdot
.84314 .84706 Mdot
.03137 .05098 Mdot
.00392 .03137 Mdot
.00784 0 Mdot
.00784 .03137 Mdot
.16471 .20392 Mdot
.0549 .07451 Mdot
.74118 .7451 Mdot
.01176 .03529 Mdot
.00392 .02353 Mdot
.00392 0 Mdot
.01176 .03922 Mdot
.03529 .06667 Mdot
.06667 .09804 Mdot
.82353 .82353 Mdot
0 .01569 Mdot
.00392 .03137 Mdot
0 0 Mdot
.01176 .04314 Mdot
.03137 .05882 Mdot
.07059 .11765 Mdot
.85098 .8549 Mdot
0 .01569 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .02745 Mdot
.05098 .07451 Mdot
.05882 .10196 Mdot
.8549 .86275 Mdot
.00392 .02745 Mdot
.07843 .08235 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.04314 .06275 Mdot
.06275 .08235 Mdot
.85882 .86667 Mdot
.00784 .02745 Mdot
0 .00392 Mdot
.00784 .01176 Mdot
.31373 .3098 Mdot
.04706 .05882 Mdot
.24706 .2549 Mdot
.85882 .86667 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
0 .00392 Mdot
.83137 .83137 Mdot
.04706 .06667 Mdot
.86667 .87059 Mdot
.8549 .86275 Mdot
.01176 .03137 Mdot
.01176 .01961 Mdot
.00392 .01176 Mdot
.82353 .82745 Mdot
.05098 .07059 Mdot
.87059 .87451 Mdot
.8549 .86275 Mdot
.01569 .03529 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.80392 .80392 Mdot
.05882 .07059 Mdot
.87059 .87843 Mdot
.8549 .86275 Mdot
.00784 .03137 Mdot
0 0 Mdot
0 .01961 Mdot
.14118 .14118 Mdot
.05098 .06667 Mdot
.87059 .87843 Mdot
.63922 .66275 Mdot
.01176 .04314 Mdot
.12157 .00784 Mdot
.00392 .02745 Mdot
.03922 .0549 Mdot
.07451 .10196 Mdot
.76471 .79608 Mdot
.03922 .06667 Mdot
.02745 .0549 Mdot
.23529 .22353 Mdot
.00392 .03922 Mdot
.05882 .07843 Mdot
.4 .39608 Mdot
.11373 .16471 Mdot
.01176 .02745 Mdot
.05882 .07843 Mdot
.01176 .01176 Mdot
.00784 .03922 Mdot
.0549 .07451 Mdot
.85882 .86275 Mdot
.04706 .07451 Mdot
.01569 .02745 Mdot
.21961 .22745 Mdot
.0549 .05098 Mdot
.00784 .04314 Mdot
.03922 .0549 Mdot
.87451 .8902 Mdot
.07059 .08235 Mdot
.00784 .02745 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.01569 .04706 Mdot
.04706 .06275 Mdot
.86667 .87843 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.33333 .35686 Mdot
0 0 Mdot
.00784 .03529 Mdot
.03922 .0549 Mdot
.87451 .88235 Mdot
.37255 .36078 Mdot
.00392 .01961 Mdot
.30588 .32157 Mdot
.00784 .00392 Mdot
.01176 .03922 Mdot
.04314 .05882 Mdot
.87059 .88235 Mdot
.78431 .76863 Mdot
.00784 .03529 Mdot
.01176 .03529 Mdot
0 0 Mdot
.00784 .03922 Mdot
.04314 .05882 Mdot
.6902 .72549 Mdot
.85098 .85098 Mdot
.01176 .03529 Mdot
.01961 .04706 Mdot
0 0 Mdot
.01961 .04314 Mdot
.03922 .05882 Mdot
.11373 .13725 Mdot
.83529 .84314 Mdot
.00784 .03137 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
.01176 .02745 Mdot
.06275 .09412 Mdot
.72157 .71373 Mdot
.83922 .84706 Mdot
.01961 .03137 Mdot
.00392 .01569 Mdot
0 0 Mdot
.01176 .02745 Mdot
.06275 .06667 Mdot
.86667 .87451 Mdot
.83922 .84706 Mdot
.02353 .03922 Mdot
.01176 .02745 Mdot
.00784 .01569 Mdot
.02353 .05098 Mdot
.72549 .71373 Mdot
.72549 .76078 Mdot
.83922 .84706 Mdot
.01961 .04706 Mdot
.00392 .00784 Mdot
.00392 .01176 Mdot
.03137 .05098 Mdot
.86275 .87059 Mdot
.17255 .21961 Mdot
.84314 .86275 Mdot
.01176 .04314 Mdot
.01176 .01569 Mdot
.00392 .01176 Mdot
.02745 .05882 Mdot
.85882 .87451 Mdot
.01961 .03529 Mdot
.72941 .74902 Mdot
.00784 .03529 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.04314 .07843 Mdot
.86275 .87059 Mdot
.65882 .65882 Mdot
.75294 .76078 Mdot
.00392 .02353 Mdot
.00392 .00784 Mdot
0 .01176 Mdot
.05882 .0902 Mdot
.84706 .87059 Mdot
.87843 .87843 Mdot
.83529 .83922 Mdot
.00784 .02745 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.08627 .12157 Mdot
.30588 .37255 Mdot
.87059 .87451 Mdot
.83922 .84706 Mdot
.01569 .03137 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18039 .20784 Mdot
.06275 .1098 Mdot
.86667 .87451 Mdot
.56078 .59216 Mdot
.16078 .16471 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.34902 .36078 Mdot
.08235 .10588 Mdot
.84706 .8549 Mdot
.67059 .68235 Mdot
.76471 .76863 Mdot
.01569 .00392 Mdot
0 .01176 Mdot
.47059 .49412 Mdot
.11373 .11373 Mdot
.82353 .85098 Mdot
.82745 .83137 Mdot
.5098 .52941 Mdot
.76078 .00392 Mdot
.00392 .01961 Mdot
.24314 .27843 Mdot
.56863 .56863 Mdot
.4902 .5451 Mdot
.82353 .83137 Mdot
.25882 .2902 Mdot
.52157 .00392 Mdot
.00392 .02353 Mdot
.09412 .12941 Mdot
.74118 .73725 Mdot
.14902 .21569 Mdot
.81961 .83137 Mdot
.11373 .14118 Mdot
.51765 .00392 Mdot
.03137 .05098 Mdot
.06667 .09804 Mdot
.86275 .86667 Mdot
.10196 .14902 Mdot
.81961 .83137 Mdot
.12941 .1451 Mdot
.52549 .01569 Mdot
.00784 .02353 Mdot
.01961 .03922 Mdot
.85882 .87451 Mdot
.01569 .03137 Mdot
.82353 .83137 Mdot
.32157 .33725 Mdot
.52157 .01176 Mdot
.00784 .01961 Mdot
.04314 .04314 Mdot
.79608 .83137 Mdot
.0902 .09412 Mdot
.82353 .82745 Mdot
.5451 .56471 Mdot
.52157 .01176 Mdot
.00784 .02745 Mdot
.31373 .3098 Mdot
.43137 .49412 Mdot
.61176 .61176 Mdot
.82353 .82745 Mdot
.67059 .68627 Mdot
.51765 .00392 Mdot
.00392 .02353 Mdot
.62353 .61961 Mdot
.1451 .20392 Mdot
.77647 .77647 Mdot
.81569 .83137 Mdot
.75686 .76078 Mdot
.52549 .00784 Mdot
0 .01961 Mdot
.79608 .79608 Mdot
.0902 .12941 Mdot
.86275 .86667 Mdot
.76471 .79608 Mdot
.75686 .75294 Mdot
.52157 .00784 Mdot
.00392 .03137 Mdot
.81569 .81569 Mdot
.08235 .10196 Mdot
.87843 .88235 Mdot
.53333 .57647 Mdot
.7451 .7451 Mdot
.51373 .00392 Mdot
.00784 .03137 Mdot
.81961 .82353 Mdot
.1098 .11373 Mdot
.89804 .89804 Mdot
.23922 .30196 Mdot
.74118 .74118 Mdot
.50588 .00392 Mdot
.00392 .01961 Mdot
.81961 .82353 Mdot
.17647 .15686 Mdot
.91765 .92157 Mdot
.09412 .16078 Mdot
.76078 .76471 Mdot
.5098 .00784 Mdot
.00392 .02353 Mdot
.83137 .83529 Mdot
.25098 .21569 Mdot
.93333 .93725 Mdot
.04706 .10196 Mdot
.74902 .75294 Mdot
.51765 .00784 Mdot
.00392 .02353 Mdot
.82745 .83529 Mdot
.28627 .25098 Mdot
.94902 .95686 Mdot
.03529 .06667 Mdot
.7098 .71765 Mdot
.51373 .00784 Mdot
.00392 .02745 Mdot
.80784 .82353 Mdot
.2549 .23137 Mdot
.93725 .95294 Mdot
.05098 .06667 Mdot
.73725 .7451 Mdot
.51765 .00784 Mdot
.00392 .02745 Mdot
.71765 .74118 Mdot
.29412 .27451 Mdot
.93725 .95686 Mdot
.05882 .08235 Mdot
.74902 .76471 Mdot
.5098 .00392 Mdot
.00392 .01961 Mdot
.53333 .56471 Mdot
.27451 .25882 Mdot
.89412 .95294 Mdot
.05098 .07843 Mdot
.67059 .6902 Mdot
.5098 .00392 Mdot
.00392 .02353 Mdot
.30196 .3098 Mdot
.21176 .19608 Mdot
.40392 .5098 Mdot
.05882 .07451 Mdot
.59216 .6 Mdot
.5098 0 Mdot
.00784 .03137 Mdot
.18431 .17647 Mdot
.12549 .12941 Mdot
.1451 .21961 Mdot
.06667 .03922 Mdot
.76471 .77647 Mdot
.50196 0 Mdot
.01569 .04706 Mdot
.30196 .29412 Mdot
.07059 .0902 Mdot
.08627 .11373 Mdot
.10588 .00392 Mdot
.79216 .81569 Mdot
.50588 0 Mdot
.01961 .04706 Mdot
.6902 .6902 Mdot
.06275 .07843 Mdot
.08235 .09804 Mdot
.34118 .1098 Mdot
.67059 .70196 Mdot
.01569 .00392 Mdot
.14118 .15686 Mdot
.78824 .79216 Mdot
.08235 .08235 Mdot
.09804 .09804 Mdot
.47843 .18431 Mdot
.72941 .7451 Mdot
.01961 .00392 Mdot
.10588 .13333 Mdot
.82353 .82745 Mdot
.14118 .13333 Mdot
.14118 .11373 Mdot
.28627 .04706 Mdot
.68235 .6902 Mdot
.01961 .00784 Mdot
.03529 .07059 Mdot
.76471 .80392 Mdot
.20784 .18039 Mdot
.22353 .16471 Mdot
.10588 .00392 Mdot
.64706 .65882 Mdot
.01569 .00392 Mdot
.03529 .0549 Mdot
.43529 .50196 Mdot
.28627 .23922 Mdot
.32941 .26275 Mdot
.0549 .01176 Mdot
.60784 .61569 Mdot
.01569 0 Mdot
.39216 .39608 Mdot
.12157 .18824 Mdot
.28627 .25098 Mdot
.60392 .58039 Mdot
.04314 .03529 Mdot
.58824 .6 Mdot
.02745 .00784 Mdot
.25882 .27451 Mdot
.07843 .10588 Mdot
.21569 .18824 Mdot
.63137 .64706 Mdot
.04706 .05882 Mdot
.59608 .61961 Mdot
.01961 .00392 Mdot
.3098 .33725 Mdot
.1098 .1098 Mdot
.24706 .20784 Mdot
.64706 .67059 Mdot
.04314 .07843 Mdot
.58039 .60784 Mdot
.01961 .00392 Mdot
.05098 .07843 Mdot
.14902 .13725 Mdot
.24706 .21569 Mdot
.75294 .77647 Mdot
.03529 .07451 Mdot
.55294 .57647 Mdot
.01569 .00392 Mdot
0 .02745 Mdot
.12549 .12941 Mdot
.15294 .14902 Mdot
.70588 .75294 Mdot
.05098 .07451 Mdot
.56863 .58431 Mdot
.01569 .00392 Mdot
.00784 .03137 Mdot
.10588 .12549 Mdot
.10196 .11373 Mdot
.49804 .55294 Mdot
.06667 .07843 Mdot
.6549 .67451 Mdot
.02353 .00784 Mdot
.00784 .03529 Mdot
.03529 .0549 Mdot
.09804 .1098 Mdot
.58039 .63529 Mdot
.05882 .06667 Mdot
.66667 .69412 Mdot
.01569 .00392 Mdot
.01176 .03922 Mdot
.00392 .00784 Mdot
.1098 .1098 Mdot
.45882 .52941 Mdot
.06275 .07059 Mdot
.60784 .63529 Mdot
.01176 .00392 Mdot
0 .01176 Mdot
.1098 .11765 Mdot
.14118 .13725 Mdot
.21961 .25882 Mdot
.07843 .0902 Mdot
.66667 .68235 Mdot
.01961 0 Mdot
.00784 .01176 Mdot
.33725 .3451 Mdot
.21569 .19216 Mdot
.31373 .31373 Mdot
.26667 .27451 Mdot
.80784 .82353 Mdot
.03137 .00784 Mdot
.00392 .02353 Mdot
.59216 .59608 Mdot
.2902 .2549 Mdot
.31765 .32549 Mdot
.58431 .58824 Mdot
.7451 .78824 Mdot
.01961 0 Mdot
.01961 .03922 Mdot
.76863 .77255 Mdot
.23529 .21569 Mdot
.19216 .21176 Mdot
.77255 .77255 Mdot
.63529 .68627 Mdot
.04314 .00392 Mdot
.10588 .13333 Mdot
.81569 .81961 Mdot
.18039 .15294 Mdot
.12157 .12941 Mdot
.79608 .8 Mdot
.65098 .67451 Mdot
.0549 .00392 Mdot
.01961 .05098 Mdot
.82353 .83529 Mdot
.18824 .16078 Mdot
.18824 .18039 Mdot
.81569 .82353 Mdot
.6902 .71373 Mdot
.06667 .00392 Mdot
0 .02353 Mdot
.37255 .41176 Mdot
.28235 .22745 Mdot
.24706 .23529 Mdot
.81961 .82745 Mdot
.53725 .58431 Mdot
.46275 .06667 Mdot
.00392 .02353 Mdot
.08627 .12549 Mdot
.38431 .32941 Mdot
.27451 .26275 Mdot
.81569 .82353 Mdot
.03529 .09804 Mdot
.12157 .00392 Mdot
.00392 .02745 Mdot
.08627 .0902 Mdot
.33725 .30196 Mdot
.23922 .23529 Mdot
.80784 .82745 Mdot
.02353 .06275 Mdot
.01176 .00392 Mdot
.02353 .04314 Mdot
.11373 .11373 Mdot
.29412 .28627 Mdot
.28627 .04314 Mdot
.0902 .13725 Mdot
.08627 .14118 Mdot
0 0 Mdot
.00784 .02745 Mdot
.07451 .09804 Mdot
.2549 .23529 Mdot
.67843 .05098 Mdot
.60392 .61569 Mdot
.00392 .03137 Mdot
.03922 .03529 Mdot
.01569 .03529 Mdot
.11373 .10588 Mdot
.23529 .2 Mdot
.12549 .01176 Mdot
.83529 .86667 Mdot
.01176 .03922 Mdot
0 0 Mdot
.04314 .0549 Mdot
.16078 .12549 Mdot
.21176 .17647 Mdot
.02353 .0549 Mdot
.87843 .90588 Mdot
.01176 .01961 Mdot
.00784 .00392 Mdot
.07451 .09412 Mdot
.19216 .16863 Mdot
.24706 .2 Mdot
.68235 .67843 Mdot
.90196 .93725 Mdot
.04706 .03529 Mdot
.00392 .01569 Mdot
.04706 .05098 Mdot
.67059 .6902 Mdot
.34902 .27843 Mdot
.80784 .81961 Mdot
.81961 .85882 Mdot
.37647 .00392 Mdot
.00392 .02745 Mdot
.1451 .12549 Mdot
.53725 .49412 Mdot
.46667 .37255 Mdot
.07843 .10588 Mdot
.07843 .10588 Mdot
.01569 .00784 Mdot
.03922 .0549 Mdot
.52157 .45882 Mdot
.57647 .55294 Mdot
.5098 .4549 Mdot
.78039 .81569 Mdot
.05882 .07059 Mdot
.00392 .00784 Mdot
.12549 .1098 Mdot
.73333 .69804 Mdot
.65882 .64706 Mdot
.5098 .47451 Mdot
.77647 .82745 Mdot
.02745 .03922 Mdot
.00392 .00392 Mdot
.34118 .2902 Mdot
.80784 .79608 Mdot
.84706 .85882 Mdot
.4902 .47451 Mdot
.83137 .87451 Mdot
.00392 0 Mdot
.10588 .12549 Mdot
.55294 .52941 Mdot
.89412 .92549 Mdot
.83529 .85098 Mdot
.4902 .47843 Mdot
.74902 .80392 Mdot
.23922 .07059 Mdot
.16471 .15294 Mdot
.64706 .65882 Mdot
.44314 .46275 Mdot
.52941 .53333 Mdot
.47843 .46275 Mdot
.05882 .10196 Mdot
.01569 .01176 Mdot
.52157 .50588 Mdot
.43137 .41569 Mdot
.43922 .38824 Mdot
.56471 .55686 Mdot
.46275 .43922 Mdot
.01569 .00784 Mdot
.01961 .02353 Mdot
.51373 .49804 Mdot
.45098 .37647 Mdot
.47059 .41569 Mdot
.4902 .43137 Mdot
.43922 .44706 Mdot
.67059 .06275 Mdot
.4902 .47843 Mdot
.46667 .39216 Mdot
.46667 .38824 Mdot
.59608 .60392 Mdot
.4902 .42745 Mdot
.06667 .07843 Mdot
.03529 .01961 Mdot
.4 .33725 Mdot
.4549 .36471 Mdot
.47843 .42353 Mdot
.4549 .38039 Mdot
.58039 .5451 Mdot
.08627 .05098 Mdot
.43529 .40392 Mdot
.45098 .36471 Mdot
.44706 .36863 Mdot
.46275 .39216 Mdot
.38431 .28627 Mdot
.45882 .45882 Mdot
.08627 .04314 Mdot
.47059 .37255 Mdot
.44706 .37255 Mdot
.46275 .4 Mdot
.47059 .36471 Mdot
.44706 .34902 Mdot
.09412 .07843 Mdot
.43137 .39216 Mdot
.48235 .38431 Mdot
.45098 .36863 Mdot
.45882 .38431 Mdot
.42353 .32549 Mdot
.45882 .38039 Mdot
.09412 .04314 Mdot
.45098 .34902 Mdot
.47451 .38824 Mdot
.46667 .4 Mdot
.41961 .30588 Mdot
.47059 .38824 Mdot
.38039 .36078 Mdot
.40392 .3451 Mdot
.46667 .38039 Mdot
.45882 .39608 Mdot
.47059 .40392 Mdot
.45098 .3451 Mdot
.40392 .2902 Mdot
.31765 .21569 Mdot
.46667 .36471 Mdot
.46667 .36471 Mdot
.58824 .55294 Mdot
.42353 .3098 Mdot
.45882 .34902 Mdot
.38824 .38824 Mdot
.43922 .33725 Mdot
.45882 .35686 Mdot
.47843 .43529 Mdot
.46275 .43137 Mdot
.46667 .37647 Mdot
.41569 .30588 Mdot
.41176 .29804 Mdot
.45098 .35294 Mdot
.48627 .41569 Mdot
.23922 .21961 Mdot
.42745 .33333 Mdot
.4549 .37255 Mdot
.28627 .21961 Mdot
.47451 .37255 Mdot
.47059 .37255 Mdot
.35294 .32941 Mdot
.42353 .38039 Mdot
.4549 .36471 Mdot
.31765 .24706 Mdot
.38039 .27843 Mdot
.46667 .35294 Mdot
.2902 .25882 Mdot
.58824 .5451 Mdot
.46275 .35294 Mdot
.45098 .3451 Mdot
.27059 .02745 Mdot
.46667 .36078 Mdot
.42745 .36863 Mdot
.55294 .56863 Mdot
.44706 .34902 Mdot
.45098 .3451 Mdot
.2902 .21569 Mdot
.42745 .36078 Mdot
.46275 .35686 Mdot
.40392 .32941 Mdot
.59608 .54118 Mdot
.44314 .34902 Mdot
.43137 .37255 Mdot
.42353 .32941 Mdot
.47059 .34902 Mdot
.30196 .2549 Mdot
.68235 .62353 Mdot
.47451 .38039 Mdot
.46667 .38824 Mdot
.38824 .25098 Mdot
.43922 .35294 Mdot
.32941 .2902 Mdot
.40392 .25882 Mdot
.40392 .2549 Mdot
.46667 .37255 Mdot
.31373 .25098 Mdot
.41569 .35294 Mdot
.49804 .4 Mdot
.44314 .23922 Mdot
.48235 .38431 Mdot
.48627 .37255 Mdot
.41961 .3451 Mdot
.69804 .04706 Mdot
.38431 .27451 Mdot
.40392 .29412 Mdot
.4 .32941 Mdot
.43529 .30196 Mdot
.43922 .33725 Mdot
.40784 .36863 Mdot
.4902 .44706 Mdot
.51373 .41569 Mdot
.47843 .30196 Mdot
.36471 .27451 Mdot
.50196 .38824 Mdot
.39216 .32157 Mdot
.52157 .47843 Mdot
.43529 .33725 Mdot
.47059 .3098 Mdot
.32157 .28627 Mdot
.5098 .38431 Mdot
.37647 .30588 Mdot
.42353 .17255 Mdot
.52549 .48627 Mdot
.41176 .27451 Mdot
.67843 .63529 Mdot
.50196 .39608 Mdot
.37255 .28627 Mdot
.46667 .42745 Mdot
.58431 .57255 Mdot
.43137 .23922 Mdot
.48627 .34902 Mdot
.52941 .38431 Mdot
.41569 .3098 Mdot
.47451 .45882 Mdot
.60784 .6 Mdot
.50196 .44706 Mdot
.61961 .55294 Mdot
.58039 .40784 Mdot
.45098 .33725 Mdot
.49412 .46275 Mdot
.61176 .59216 Mdot
.56471 .52157 Mdot
.47843 .41961 Mdot
.65882 .47843 Mdot
.47843 .38039 Mdot
.52549 .50196 Mdot
.60392 .57647 Mdot
.60392 .57647 Mdot
.48235 .38431 Mdot
.78431 .65098 Mdot
.56471 .50588 Mdot
.53333 .52941 Mdot
.52941 .50196 Mdot
.63137 .60784 Mdot
.49804 .35294 Mdot
.83922 .77647 Mdot
.6 .56078 Mdot
.53725 .52549 Mdot
.65098 .64314 Mdot
.62745 .60784 Mdot
.56078 .50196 Mdot
.88235 .83922 Mdot
.64706 .58824 Mdot
.50588 .47843 Mdot
.68627 .68235 Mdot
.67843 .67843 Mdot
.99608 .95294 Mdot
.83137 .83137 Mdot
.60784 .59216 Mdot
.74902 .12157 Mdot
.6902 .6902 Mdot
.8 .80392 Mdot
.99216 .99216 Mdot
.7098 .6902 Mdot
.54118 .53333 Mdot
.72157 .71373 Mdot
.72157 .71765 Mdot
.99608 .99608 Mdot
.81176 .81176 Mdot
.62745 .61176 Mdot
.69804 .6902 Mdot
.73725 .73725 Mdot
.95294 .96078 Mdot
.92549 .92157 Mdot
.65882 .65098 Mdot
.67059 .64706 Mdot
.76863 .76078 Mdot
.94118 .93725 Mdot
.92549 .92549 Mdot
.61569 .6 Mdot
.76863 .76471 Mdot
.83922 .83922 Mdot
.99216 .99216 Mdot
.84314 .8549 Mdot
.88627 .08235 Mdot
.80392 .8 Mdot
.95294 .95686 Mdot
.94902 .95294 Mdot
.41176 .26275 Mdot
.81569 .81569 Mdot
.9451 .94118 Mdot
.94118 .95294 Mdot
.76078 .15294 Mdot
.82353 .82745 Mdot
.99216 .98824 Mdot
.72549 .72157 Mdot
.6 .52157 Mdot
.97647 .98824 Mdot
.6 .57255 Mdot
.56078 .44706 Mdot
.72549 .70196 Mdot
.81961 .21176 Mdot
.628 .126 .941 r
.78431 .20392 Mdot
.43529 .38824 Mdot
.7451 .68235 Mdot
.75686 .73333 Mdot
.63529 .54118 Mdot
.43137 .44314 Mdot
.72157 .68235 Mdot
.7098 .63529 Mdot
.75294 .75686 Mdot
.79216 .78431 Mdot
.71765 .62745 Mdot
.83137 .80784 Mdot
.81569 .83137 Mdot
.58824 .43922 Mdot
.68627 .61176 Mdot
.63137 .63922 Mdot
.81961 .82745 Mdot
.63529 .51373 Mdot
.66275 .60392 Mdot
.74902 .75294 Mdot
.8 .80784 Mdot
.62353 .48235 Mdot
.76471 .66667 Mdot
.83137 .81569 Mdot
.81176 .83137 Mdot
.83529 .05098 Mdot
.60392 .5451 Mdot
.75686 .72941 Mdot
.30588 .43137 Mdot
.79608 .81176 Mdot
.63922 .51373 Mdot
.80784 .72549 Mdot
.7098 .68627 Mdot
.83137 .83922 Mdot
.74902 .77255 Mdot
.73333 .63137 Mdot
.80784 .72941 Mdot
.73333 .70588 Mdot
.81569 .82353 Mdot
.52549 .21569 Mdot
.73725 .64706 Mdot
.78431 .70588 Mdot
.72941 .72549 Mdot
.81569 .8549 Mdot
.82745 .05098 Mdot
.7451 .66275 Mdot
.79216 .7098 Mdot
.83137 .81176 Mdot
.82353 .84706 Mdot
.49804 .54118 Mdot
.71765 .61961 Mdot
.81569 .81961 Mdot
.80784 .76863 Mdot
.83922 .85098 Mdot
.79608 .81569 Mdot
.65882 .57647 Mdot
.75686 .64706 Mdot
.76471 .71765 Mdot
.73725 .77255 Mdot
.78039 .80392 Mdot
.59216 .45882 Mdot
.7098 .61569 Mdot
.79608 .70196 Mdot
.70588 .67843 Mdot
.83922 .86667 Mdot
.75686 .81569 Mdot
.68627 .6 Mdot
.7451 .63137 Mdot
.75686 .68627 Mdot
.44706 .52157 Mdot
.79216 .82353 Mdot
.56078 .41176 Mdot
.67843 .58431 Mdot
.76471 .67451 Mdot
.84706 .81176 Mdot
.22353 .36863 Mdot
.81176 .83922 Mdot
.61176 .49804 Mdot
.7098 .60392 Mdot
.78824 .69412 Mdot
.77647 .74902 Mdot
.83137 .8549 Mdot
.73725 .76078 Mdot
.58039 .5098 Mdot
.43922 .39608 Mdot
.76078 .66667 Mdot
.77647 .75686 Mdot
.83529 .85882 Mdot
.57647 .62353 Mdot
.14118 .09412 Mdot
.57647 .53333 Mdot
.75294 .6549 Mdot
.76863 .74118 Mdot
.83137 .8549 Mdot
.34902 .4 Mdot
.15294 .08235 Mdot
.62353 .54118 Mdot
.76471 .66667 Mdot
.69412 .67059 Mdot
.83529 .86667 Mdot
.26275 .3451 Mdot
.26275 .17647 Mdot
.61176 .53725 Mdot
.77647 .68235 Mdot
.82353 .8 Mdot
.83922 .84706 Mdot
.79216 .84314 Mdot
.61569 .51373 Mdot
.65882 .53333 Mdot
.76078 .65882 Mdot
.70588 .64314 Mdot
.5098 .48627 Mdot
.77647 .75294 Mdot
.56863 .47843 Mdot
.63922 .5098 Mdot
.7451 .63922 Mdot
.70588 .61569 Mdot
.38824 .37255 Mdot
.81176 .83529 Mdot
.44314 .32941 Mdot
.61961 .50196 Mdot
.41569 .4 Mdot
.74902 .65882 Mdot
.64314 .61569 Mdot
.64314 .66667 Mdot
.46667 .5098 Mdot
.61176 .50196 Mdot
.61569 .43922 Mdot
.76863 .67059 Mdot
.75686 .6902 Mdot
.02745 .03922 Mdot
.72941 .58431 Mdot
.51765 .44314 Mdot
.61569 .46667 Mdot
.72549 .61961 Mdot
.73725 .63529 Mdot
.03529 .04314 Mdot
.80392 .82745 Mdot
.5451 .55686 Mdot
.62353 .51765 Mdot
.61176 .43922 Mdot
.76863 .68235 Mdot
.64314 .57255 Mdot
.01961 .02353 Mdot
.79216 .71765 Mdot
.56471 .48627 Mdot
.6 .44314 Mdot
.7098 .57647 Mdot
.73333 .63137 Mdot
.01961 .03137 Mdot
.24314 .25882 Mdot
.66275 .68235 Mdot
.58824 .47451 Mdot
.61176 .41569 Mdot
.76078 .68627 Mdot
.61961 .57255 Mdot
.01961 .02745 Mdot
.59608 .03922 Mdot
.73333 .75686 Mdot
.59608 .4549 Mdot
.6549 .50196 Mdot
.46667 .43137 Mdot
.02745 .03922 Mdot
.02353 .03137 Mdot
.27843 .31765 Mdot
.59608 .53333 Mdot
.57255 .37647 Mdot
.72157 .60392 Mdot
.71765 .63137 Mdot
.03137 .03922 Mdot
.58824 .59216 Mdot
.82745 .05098 Mdot
.58039 .48235 Mdot
.62745 .43922 Mdot
.49412 .45882 Mdot
.07451 .0549 Mdot
.30588 .40392 Mdot
.59216 .19608 Mdot
.77647 .80784 Mdot
.6 .47843 Mdot
.65098 .49412 Mdot
.5451 .51373 Mdot
.04314 .05098 Mdot
.28627 .42353 Mdot
.62745 .01176 Mdot
.82353 .83529 Mdot
.58824 .43137 Mdot
.68235 .54902 Mdot
.76471 .68235 Mdot
.11373 .11765 Mdot
.28235 .33725 Mdot
.43922 .38824 Mdot
.56863 .51765 Mdot
.56863 .37647 Mdot
.72549 .61961 Mdot
.61176 .57647 Mdot
.23529 .38431 Mdot
.02353 .03922 Mdot
.53725 .52941 Mdot
.58824 .53725 Mdot
.59216 .40392 Mdot
.76078 .66275 Mdot
.06667 .06667 Mdot
.81961 .82353 Mdot
.67059 .71373 Mdot
.7451 .76471 Mdot
.57255 .48627 Mdot
.63529 .47451 Mdot
.78824 .70196 Mdot
.05882 .05098 Mdot
.68235 .68627 Mdot
.59216 .08235 Mdot
.77255 .81569 Mdot
.59608 .50588 Mdot
.66667 .55686 Mdot
.78824 .72157 Mdot
.34118 .39216 Mdot
.74902 .79216 Mdot
.50196 .02353 Mdot
.57647 .60784 Mdot
.58039 .47451 Mdot
.6902 .57647 Mdot
.77647 .69804 Mdot
.24314 .41961 Mdot
.27843 .38431 Mdot
.46275 .03922 Mdot
.66275 .67843 Mdot
.57647 .46275 Mdot
.69804 .59216 Mdot
.76078 .68235 Mdot
.61961 .58039 Mdot
.79608 .85882 Mdot
.39216 .01569 Mdot
.81569 .84706 Mdot
.56471 .42353 Mdot
.70588 .61176 Mdot
.25882 .23137 Mdot
.4549 .41961 Mdot
.81961 .8549 Mdot
.43922 .04706 Mdot
.69412 .70196 Mdot
.56471 .38824 Mdot
.7098 .61176 Mdot
.08235 .06667 Mdot
.04314 .05098 Mdot
.82353 .85882 Mdot
.37255 .02745 Mdot
.55294 .54118 Mdot
.55686 .39608 Mdot
.72157 .62745 Mdot
.0902 .05882 Mdot
.02353 .04314 Mdot
.82745 .8549 Mdot
.30196 .00392 Mdot
.56471 .54118 Mdot
.56863 .41569 Mdot
.71373 .62745 Mdot
.09412 .05882 Mdot
.02353 .03529 Mdot
.74118 .77255 Mdot
.38431 .01569 Mdot
.56863 .54902 Mdot
.56471 .41176 Mdot
.72941 .64314 Mdot
.30196 .29804 Mdot
.02745 .03529 Mdot
.37647 .42353 Mdot
.51765 .05882 Mdot
.58431 .56078 Mdot
.59216 .4549 Mdot
.74118 .65882 Mdot
.27059 .46275 Mdot
.11765 .12549 Mdot
.07843 .12157 Mdot
.49412 .06275 Mdot
.58431 .56078 Mdot
.6 .46275 Mdot
.73725 .6549 Mdot
.30196 .49804 Mdot
.34902 .43922 Mdot
.07059 .11373 Mdot
.44706 .02353 Mdot
.59216 .56078 Mdot
.62353 .49804 Mdot
.72941 .64706 Mdot
.58431 .69804 Mdot
.16863 .36471 Mdot
.06275 .1098 Mdot
.47451 .02353 Mdot
.58431 .55686 Mdot
.62745 .50588 Mdot
.72549 .64706 Mdot
.74118 .76471 Mdot
.41176 .53333 Mdot
.07059 .10196 Mdot
.43137 .00784 Mdot
.58824 .56863 Mdot
.61961 .5098 Mdot
.72941 .63529 Mdot
.7451 .7098 Mdot
.77255 .78039 Mdot
.06667 .08627 Mdot
.47451 .03137 Mdot
.54902 .53333 Mdot
.63529 .52549 Mdot
.72549 .63137 Mdot
.72941 .67451 Mdot
.62353 .58431 Mdot
.07451 .09804 Mdot
.55686 .08235 Mdot
.53333 .51373 Mdot
.62745 .52549 Mdot
.72157 .63529 Mdot
.67451 .62353 Mdot
.50196 .45882 Mdot
.06667 .09804 Mdot
.57255 .15686 Mdot
.52941 .50196 Mdot
.63922 .54118 Mdot
.73333 .64314 Mdot
.26275 .24314 Mdot
.16863 .15294 Mdot
.0549 .08235 Mdot
.58039 .2902 Mdot
.50588 .47843 Mdot
.63922 .55294 Mdot
.72549 .63529 Mdot
.11765 .10196 Mdot
.0549 .06275 Mdot
.0549 .08235 Mdot
.65882 .50588 Mdot
.50588 .48235 Mdot
.63922 .54902 Mdot
.72549 .63137 Mdot
.10196 .08235 Mdot
.05882 .05098 Mdot
.0549 .08235 Mdot
.63529 .58039 Mdot
.49804 .47451 Mdot
.64314 .5451 Mdot
.73333 .65098 Mdot
.1098 .0902 Mdot
.22353 .21176 Mdot
.04706 .06667 Mdot
.5451 .53333 Mdot
.48627 .46667 Mdot
.63529 .54118 Mdot
.73333 .64314 Mdot
.23529 .23529 Mdot
.18824 .25882 Mdot
.03922 .06275 Mdot
.72549 .73725 Mdot
.46275 .46275 Mdot
.61569 .52941 Mdot
.72157 .62745 Mdot
.30588 .3098 Mdot
.31373 .34118 Mdot
.06667 .0902 Mdot
.56863 .60784 Mdot
.69412 .70196 Mdot
.61569 .54118 Mdot
.7098 .61569 Mdot
.47059 .50196 Mdot
.04706 .04314 Mdot
.31373 .34118 Mdot
.41961 .50196 Mdot
.76471 .78039 Mdot
.62745 .56078 Mdot
.71765 .63137 Mdot
.47059 .56863 Mdot
.04706 .05882 Mdot
.35686 .42745 Mdot
.73333 .81176 Mdot
.76078 .78431 Mdot
.65098 .58039 Mdot
.70196 .60784 Mdot
.3098 .45882 Mdot
.07843 .07843 Mdot
.4549 .52549 Mdot
.47451 .58039 Mdot
.65098 .66667 Mdot
.64706 .58431 Mdot
.70196 .61961 Mdot
.66275 .70588 Mdot
.17647 .16471 Mdot
.63137 .6902 Mdot
.79608 .87451 Mdot
.51765 .52549 Mdot
.6549 .59216 Mdot
.6902 .61569 Mdot
.77255 .72549 Mdot
.27451 .25882 Mdot
.41961 .49412 Mdot
.79216 .84706 Mdot
.5098 .51765 Mdot
.64314 .6 Mdot
.68235 .59608 Mdot
.78039 .7098 Mdot
.3098 .30588 Mdot
.03922 .07843 Mdot
.77647 .83137 Mdot
.45882 .47059 Mdot
.6549 .60784 Mdot
.67451 .58824 Mdot
.78039 .71373 Mdot
.30196 .30196 Mdot
.01176 .02745 Mdot
.80392 .84314 Mdot
.42353 .45098 Mdot
.65098 .61569 Mdot
.67843 .58824 Mdot
.78431 .72157 Mdot
.30196 .30588 Mdot
.01569 .03529 Mdot
.79216 .83922 Mdot
.46275 .50588 Mdot
.63922 .60784 Mdot
.66275 .57647 Mdot
.78824 .72157 Mdot
.62353 .6 Mdot
.38824 .42353 Mdot
.79608 .85098 Mdot
.6549 .7098 Mdot
.63137 .59216 Mdot
.6549 .56078 Mdot
.76078 .69412 Mdot
.68627 .64706 Mdot
.65098 .66275 Mdot
.79216 .82353 Mdot
.54902 .55294 Mdot
.61176 .56471 Mdot
.64314 .55294 Mdot
.75686 .6902 Mdot
.72549 .67451 Mdot
.63137 .60392 Mdot
.79608 .83137 Mdot
.56078 .40784 Mdot
.56863 .52549 Mdot
.64314 .54902 Mdot
.75294 .67059 Mdot
.7098 .67059 Mdot
.60392 .54902 Mdot
.80392 .8549 Mdot
.26667 .21961 Mdot
.56471 .53725 Mdot
.63922 .54118 Mdot
.74118 .66667 Mdot
.71765 .69412 Mdot
.61176 .56078 Mdot
.7451 .80784 Mdot
.16863 .21176 Mdot
.56471 .55294 Mdot
.61569 .52157 Mdot
.73725 .67843 Mdot
.73333 .69804 Mdot
.61961 .56863 Mdot
.2549 .32549 Mdot
.59216 .63137 Mdot
.56078 .56078 Mdot
.61569 .52941 Mdot
.73725 .67843 Mdot
.72941 .69412 Mdot
.63529 .59608 Mdot
.02353 .05882 Mdot
.63922 .65882 Mdot
.69412 .71373 Mdot
.62745 .54902 Mdot
.73725 .66275 Mdot
.72941 .69804 Mdot
.61176 .57647 Mdot
.00784 .02745 Mdot
.48627 .51373 Mdot
.42745 .44706 Mdot
.62353 .56078 Mdot
.72549 .6549 Mdot
.75686 .73333 Mdot
.12941 .1451 Mdot
.26667 .29804 Mdot
.52941 .60784 Mdot
.65098 .67451 Mdot
.60784 .55686 Mdot
.70196 .63922 Mdot
.76471 .72941 Mdot
.0549 .06275 Mdot
.59216 .59608 Mdot
.76863 .83529 Mdot
.30196 .33333 Mdot
.62353 .58824 Mdot
.69804 .63922 Mdot
.74902 .71373 Mdot
.04706 .05882 Mdot
.04314 .05098 Mdot
.78824 .84706 Mdot
.45098 .49804 Mdot
.64314 .61176 Mdot
.67451 .60392 Mdot
.75686 .71373 Mdot
.07843 .09412 Mdot
.01569 .03137 Mdot
.77647 .83529 Mdot
.55686 .59216 Mdot
.61176 .6 Mdot
.65882 .59216 Mdot
.74902 .70588 Mdot
.28235 .27451 Mdot
.00784 .02353 Mdot
.79216 .84314 Mdot
.58039 .63137 Mdot
.61961 .59608 Mdot
.65882 .57647 Mdot
.73725 .69804 Mdot
.68627 .66667 Mdot
.01569 .03922 Mdot
.69412 .7098 Mdot
.66275 .60392 Mdot
.6 .58039 Mdot
.64706 .56078 Mdot
.72941 .68627 Mdot
.72549 .69804 Mdot
.01569 .03529 Mdot
.01961 .06275 Mdot
.21176 .12941 Mdot
.58824 .58431 Mdot
.63529 .53725 Mdot
.7451 .6902 Mdot
.72941 .69804 Mdot
.02353 .04706 Mdot
.00392 .04314 Mdot
.08235 .18431 Mdot
.55686 .56471 Mdot
.61961 .53333 Mdot
.72941 .66275 Mdot
.75294 .72549 Mdot
.03922 .0549 Mdot
.00392 .04706 Mdot
.1098 .2 Mdot
.81961 .8549 Mdot
.60784 .54118 Mdot
.68627 .61176 Mdot
.75686 .72941 Mdot
.02745 .05098 Mdot
.44706 .49412 Mdot
.65882 .70196 Mdot
.35294 .38824 Mdot
.58039 .54118 Mdot
.63922 .55686 Mdot
.76078 .73333 Mdot
.03137 .04706 Mdot
.43529 .53333 Mdot
.29804 .40392 Mdot
.6902 .72549 Mdot
.56078 .52549 Mdot
.61961 .51765 Mdot
.76863 .75294 Mdot
.04314 .0549 Mdot
.03529 .07843 Mdot
.78039 .85098 Mdot
.34902 .37255 Mdot
.59216 .55294 Mdot
.59608 .49412 Mdot
.59216 .58824 Mdot
.05098 .07451 Mdot
.01569 .03529 Mdot
.77255 .84314 Mdot
.48627 .52157 Mdot
.58431 .5451 Mdot
.61176 .50588 Mdot
.66667 .64706 Mdot
.11373 .14118 Mdot
.00784 .03137 Mdot
.77647 .86275 Mdot
.73725 .78824 Mdot
.58824 .56863 Mdot
.60784 .50196 Mdot
.71373 .67059 Mdot
.62745 .63529 Mdot
.00392 .03529 Mdot
.4549 .62353 Mdot
.59216 .53725 Mdot
.55686 .55294 Mdot
.59608 .48235 Mdot
.63922 .58431 Mdot
.70588 .68235 Mdot
.01176 .03529 Mdot
.08235 .32549 Mdot
.32941 .30588 Mdot
.56863 .55294 Mdot
.57255 .48235 Mdot
.62353 .56471 Mdot
.70588 .69804 Mdot
.03137 .05098 Mdot
.04706 .25882 Mdot
.30196 .29804 Mdot
.54118 .55294 Mdot
.58431 .4902 Mdot
.63922 .57255 Mdot
.72941 .71373 Mdot
.02745 .03529 Mdot
.47843 .5451 Mdot
.39216 .37647 Mdot
.48627 .50196 Mdot
.55686 .48627 Mdot
.60392 .51765 Mdot
.75686 .73725 Mdot
.02745 .04314 Mdot
.72941 .79216 Mdot
.48627 .4902 Mdot
.40392 .43922 Mdot
.55294 .50196 Mdot
.58824 .48627 Mdot
.75686 .74118 Mdot
.03529 .04706 Mdot
.56078 .7451 Mdot
.73725 .76863 Mdot
.33333 .38824 Mdot
.53725 .49412 Mdot
.57647 .44314 Mdot
.77647 .75294 Mdot
.03137 .04706 Mdot
.1451 .37647 Mdot
.40392 .49412 Mdot
.45882 .51765 Mdot
.53333 .50588 Mdot
.56471 .43529 Mdot
.75294 .73725 Mdot
.04706 .05882 Mdot
.31765 .45098 Mdot
.39608 .47843 Mdot
.73725 .78824 Mdot
.55294 .53725 Mdot
.56471 .44706 Mdot
.74118 .71765 Mdot
.03529 .04314 Mdot
.3098 .37647 Mdot
.78039 .83529 Mdot
.75686 .82353 Mdot
.53725 .5098 Mdot
.54902 .43529 Mdot
.63137 .58431 Mdot
.1098 .13333 Mdot
.1451 .18039 Mdot
.37255 .4549 Mdot
.64706 .58431 Mdot
.56471 .54902 Mdot
.54118 .42745 Mdot
.61176 .55294 Mdot
.72157 .70588 Mdot
.03922 .06667 Mdot
.42745 .47451 Mdot
.23922 .27451 Mdot
.53725 .53333 Mdot
.52941 .41961 Mdot
.60392 .53333 Mdot
.72549 .72549 Mdot
.10588 .14118 Mdot
.81176 .86275 Mdot
.36078 .36471 Mdot
.47843 .4902 Mdot
.54118 .45098 Mdot
.59216 .51765 Mdot
.73725 .73725 Mdot
.62745 .6549 Mdot
.64314 .73333 Mdot
.2549 .34118 Mdot
.12157 .14902 Mdot
.54902 .49804 Mdot
.63137 .57255 Mdot
.7451 .74118 Mdot
.58431 .62745 Mdot
.31373 .40392 Mdot
.43529 .49804 Mdot
.33333 .36471 Mdot
.55686 .52941 Mdot
.58824 .50588 Mdot
.74902 .7451 Mdot
.12941 .16863 Mdot
.56078 .58431 Mdot
.12549 .29804 Mdot
.18431 .18431 Mdot
.54118 .52157 Mdot
.59216 .50196 Mdot
.74902 .74902 Mdot
.12157 .18039 Mdot
.37647 .40392 Mdot
.63529 .68235 Mdot
.11373 .12157 Mdot
.49412 .48627 Mdot
.6 .50196 Mdot
.58039 .57647 Mdot
.1451 .21176 Mdot
.13333 .17255 Mdot
.43922 .52157 Mdot
.22353 .21569 Mdot
.49804 .4902 Mdot
.55294 .45882 Mdot
.56471 .53725 Mdot
.64706 .66667 Mdot
.10588 .12941 Mdot
.78824 .83137 Mdot
.70588 .08235 Mdot
.5098 .50196 Mdot
.56863 .46667 Mdot
.66667 .62353 Mdot
.71373 .70196 Mdot
.14902 .18431 Mdot
.11373 .18039 Mdot
.07059 .18824 Mdot
.48235 .48627 Mdot
.54902 .45098 Mdot
.67059 .62745 Mdot
.72941 .73333 Mdot
.12549 .16863 Mdot
.00784 .04706 Mdot
.04706 .19608 Mdot
.47451 .4902 Mdot
.54118 .4549 Mdot
.68627 .65882 Mdot
.73333 .72157 Mdot
.15294 .18431 Mdot
.00392 .03137 Mdot
.07843 .20784 Mdot
.43137 .43922 Mdot
.52941 .48235 Mdot
.65882 .63529 Mdot
.7451 .74902 Mdot
.20392 .2549 Mdot
.00784 .02745 Mdot
.39608 .42745 Mdot
.21176 .23529 Mdot
.50588 .47059 Mdot
.64706 .61176 Mdot
.72157 .71765 Mdot
.35686 .47451 Mdot
.00784 .04706 Mdot
.46275 .45882 Mdot
.08627 .09804 Mdot
.43922 .41569 Mdot
.63922 .6 Mdot
.71765 .7098 Mdot
.23922 .39216 Mdot
.00784 .04314 Mdot
.47059 .48235 Mdot
.20784 .22745 Mdot
.42745 .41569 Mdot
.61176 .56471 Mdot
.71765 .71373 Mdot
.28627 .43137 Mdot
.02353 .04314 Mdot
.44706 .48627 Mdot
.19608 .18039 Mdot
.44314 .41961 Mdot
.61176 .56078 Mdot
.72157 .72941 Mdot
.67451 .68627 Mdot
.04314 .06667 Mdot
.18039 .22745 Mdot
.31373 .26275 Mdot
.47451 .46275 Mdot
.59216 .52549 Mdot
.70588 .71765 Mdot
.71373 .70588 Mdot
.06275 .10196 Mdot
.00392 .03529 Mdot
.31373 .33725 Mdot
.42353 .43529 Mdot
.54902 .48627 Mdot
.7098 .7098 Mdot
.6902 .67843 Mdot
.07059 .10588 Mdot
.16078 .20392 Mdot
.34118 .37255 Mdot
.40392 .4 Mdot
.56863 .49412 Mdot
.67059 .65098 Mdot
.71373 .72157 Mdot
.03137 .05882 Mdot
.5098 .53725 Mdot
.40392 .4 Mdot
.34902 .35686 Mdot
.54902 .48627 Mdot
.68627 .6549 Mdot
.7098 .7098 Mdot
.01961 .03922 Mdot
.03137 .07451 Mdot
.1098 .18431 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.69412 .66667 Mdot
.68627 .69412 Mdot
.02353 .05098 Mdot
.00392 .04314 Mdot
.44314 .43922 Mdot
.30196 .31765 Mdot
.4549 .43922 Mdot
.66275 .63529 Mdot
.72941 .73333 Mdot
.00784 .03529 Mdot
.00392 .02745 Mdot
.47843 .47451 Mdot
.12157 .11373 Mdot
.43922 .43137 Mdot
.63922 .59608 Mdot
.71373 .72157 Mdot
.03529 .05882 Mdot
.00784 .03529 Mdot
.6 .6902 Mdot
.3451 .31765 Mdot
.4549 .44706 Mdot
.61961 .55294 Mdot
.70196 .6902 Mdot
.03922 .06667 Mdot
.04314 .08627 Mdot
.04706 .09412 Mdot
.27843 .32157 Mdot
.38431 .38824 Mdot
.6 .53725 Mdot
.58824 .56078 Mdot
.34902 .38431 Mdot
.56471 .57647 Mdot
.42745 .49804 Mdot
.0549 .23529 Mdot
.31765 .33333 Mdot
.55294 .50196 Mdot
.54902 .49412 Mdot
.68235 .69804 Mdot
.59216 .62353 Mdot
.80392 .90588 Mdot
.08627 .20392 Mdot
.27451 .29412 Mdot
.52549 .49412 Mdot
.61569 .58824 Mdot
.66275 .67451 Mdot
.4902 .62353 Mdot
.18824 .4 Mdot
.43922 .43529 Mdot
.27451 .27451 Mdot
.50196 .47451 Mdot
.66275 .62745 Mdot
.69804 .72157 Mdot
.18824 .46275 Mdot
.12941 .39216 Mdot
.47451 .46667 Mdot
.39608 .38824 Mdot
.44314 .43529 Mdot
.61961 .57647 Mdot
.70588 .70588 Mdot
.33333 .48627 Mdot
.12941 .36471 Mdot
.48627 .4902 Mdot
.37647 .37647 Mdot
.44314 .43922 Mdot
.57255 .50196 Mdot
.69804 .69804 Mdot
.07059 .0902 Mdot
.18039 .22745 Mdot
.74902 .80784 Mdot
.27843 .3098 Mdot
.38431 .38039 Mdot
.52157 .43529 Mdot
.61961 .60392 Mdot
.02353 .04706 Mdot
.32941 .34902 Mdot
.15686 .3451 Mdot
.40392 .42353 Mdot
.29804 .3098 Mdot
.46275 .4 Mdot
.6549 .64314 Mdot
.06275 .09412 Mdot
.58039 .58039 Mdot
.10196 .13725 Mdot
.41569 .39608 Mdot
.12549 .14118 Mdot
.45098 .43137 Mdot
.6549 .63137 Mdot
.65882 .66275 Mdot
.12549 .19608 Mdot
.03137 .0549 Mdot
.44706 .43137 Mdot
.28235 .29412 Mdot
.4549 .44314 Mdot
.55294 .49804 Mdot
.66667 .6549 Mdot
.07843 .12941 Mdot
.03529 .07059 Mdot
.46275 .46275 Mdot
.38824 .38824 Mdot
.49804 .4902 Mdot
.57255 .5098 Mdot
.68627 .69412 Mdot
.38824 .51765 Mdot
.26667 .32157 Mdot
.48627 .48627 Mdot
.26275 .27451 Mdot
.41961 .42353 Mdot
.47843 .37647 Mdot
.65098 .66275 Mdot
.22353 .48235 Mdot
.67843 .69412 Mdot
.03137 .07843 Mdot
.07451 .23529 Mdot
.35294 .37255 Mdot
.4902 .39608 Mdot
.71373 .71765 Mdot
.24314 .33333 Mdot
.48235 .58431 Mdot
.00392 .03922 Mdot
.0549 .23529 Mdot
.3098 .33725 Mdot
.43529 .38039 Mdot
.67451 .65882 Mdot
.05098 .07843 Mdot
.04314 .08627 Mdot
.00784 .05882 Mdot
.06667 .2902 Mdot
.22353 .23137 Mdot
.39608 .38824 Mdot
.53725 .50196 Mdot
.5098 .5451 Mdot
.56863 .63922 Mdot
.03529 .09412 Mdot
.0902 .28627 Mdot
.31765 .30196 Mdot
.47059 .47843 Mdot
.58039 .53333 Mdot
.69412 .70588 Mdot
.32157 .54118 Mdot
.42745 .48627 Mdot
.31373 .36078 Mdot
.4 .31373 Mdot
.47843 .48627 Mdot
.56471 .50588 Mdot
.7098 .72157 Mdot
.32941 .50588 Mdot
.77647 .84314 Mdot
.00392 .03529 Mdot
.40784 .39216 Mdot
.37647 .38824 Mdot
.52941 .47059 Mdot
.6902 .70588 Mdot
.06667 .08627 Mdot
.63529 .66667 Mdot
.10588 .13725 Mdot
.42353 .41569 Mdot
.30588 .32549 Mdot
.43529 .38824 Mdot
.59216 .57647 Mdot
.20784 .22745 Mdot
.15294 .39216 Mdot
.0902 .13725 Mdot
.09804 .23137 Mdot
.26667 .27059 Mdot
.38039 .33333 Mdot
.82745 .82353 Mdot
.07059 .0902 Mdot
.27451 .35686 Mdot
.02353 .04706 Mdot
.45098 .47059 Mdot
.22745 .21569 Mdot
.44706 .44706 Mdot
.51373 .4902 Mdot
.65882 .66275 Mdot
.03922 .07451 Mdot
.00392 .03137 Mdot
.17255 .3451 Mdot
.29804 .28235 Mdot
.46275 .47059 Mdot
.59608 .54118 Mdot
.70588 .71373 Mdot
.07451 .12157 Mdot
.01961 .0549 Mdot
.06275 .31373 Mdot
.18431 .27451 Mdot
.43137 .46667 Mdot
.52549 .47059 Mdot
.68235 .6902 Mdot
.1098 .19216 Mdot
.64314 .71765 Mdot
.0549 .10588 Mdot
.0549 .25882 Mdot
.33725 .37647 Mdot
.5098 .45098 Mdot
.66275 .66667 Mdot
.03922 .06667 Mdot
.49804 .54902 Mdot
.71373 .73725 Mdot
.12941 .23922 Mdot
.27451 .27843 Mdot
.41961 .4 Mdot
.53725 .52941 Mdot
.08235 .12941 Mdot
.71373 .73725 Mdot
.04314 .07843 Mdot
.18431 .30196 Mdot
.08627 .08235 Mdot
.41569 .40784 Mdot
.5451 .52941 Mdot
.70588 .71373 Mdot
.65882 .72549 Mdot
.16078 .31373 Mdot
.41569 .4902 Mdot
.30196 .27843 Mdot
.38039 .4 Mdot
.57647 .5451 Mdot
.69804 .71373 Mdot
.34118 .53333 Mdot
.01961 .05882 Mdot
.2 .37647 Mdot
.27059 .30588 Mdot
.03529 .06667 Mdot
.51373 .45882 Mdot
.63137 .63529 Mdot
.43137 .62745 Mdot
.55294 .59608 Mdot
.21961 .31373 Mdot
.21569 .28235 Mdot
.13725 .17255 Mdot
.4549 .42353 Mdot
.54118 .52549 Mdot
.06275 .1098 Mdot
.6 .62745 Mdot
.0549 .07451 Mdot
.44314 .43529 Mdot
.25098 .25882 Mdot
.41176 .41176 Mdot
.50588 .48235 Mdot
.29412 .32941 Mdot
.6 .62353 Mdot
.02353 .0549 Mdot
.48235 .47843 Mdot
.28235 .26275 Mdot
.38431 .40392 Mdot
.55686 .53725 Mdot
.6902 .69804 Mdot
.71765 .73333 Mdot
.03529 .07843 Mdot
.44314 .46275 Mdot
.12941 .01569 Mdot
.30588 .32941 Mdot
.58431 .55294 Mdot
.6902 .70588 Mdot
.66275 .67451 Mdot
.61961 .67059 Mdot
.29412 .30588 Mdot
.11765 .17647 Mdot
.31373 .35686 Mdot
.52157 .47451 Mdot
.5098 .5098 Mdot
.23137 .39608 Mdot
.6549 .7451 Mdot
.02745 .07451 Mdot
.37647 .37255 Mdot
.26275 .28627 Mdot
.44706 .42353 Mdot
.50196 .47843 Mdot
.05098 .07059 Mdot
.63137 .68235 Mdot
.00392 .03529 Mdot
.46667 .46275 Mdot
.06667 .06667 Mdot
.40784 .42353 Mdot
.46275 .4549 Mdot
.66275 .68627 Mdot
.66275 .67843 Mdot
.11373 .17647 Mdot
.43529 .43137 Mdot
.09804 .01569 Mdot
.2902 .3098 Mdot
.49412 .4549 Mdot
.65098 .66275 Mdot
.64314 .67059 Mdot
.5098 .59216 Mdot
0 .02745 Mdot
.05882 .17255 Mdot
.27451 .31765 Mdot
.55294 .51765 Mdot
.50196 .50588 Mdot
.35294 .46667 Mdot
.80784 .8549 Mdot
.00392 .03137 Mdot
.04706 .2 Mdot
.28235 .32157 Mdot
.50588 .47843 Mdot
.4902 .48235 Mdot
.03529 .05098 Mdot
.64706 .77255 Mdot
.00392 .02745 Mdot
.11765 .24706 Mdot
.27059 .2902 Mdot
.44706 .43922 Mdot
.43529 .43922 Mdot
.31765 .35686 Mdot
.72941 .81961 Mdot
0 .03137 Mdot
.42745 .41176 Mdot
.21961 .19216 Mdot
.33725 .34902 Mdot
.33725 .33333 Mdot
.63137 .64706 Mdot
.67843 .70196 Mdot
0 .03137 Mdot
.02745 .0549 Mdot
.6549 .12157 Mdot
.24706 .28235 Mdot
.49412 .44314 Mdot
.56471 .57255 Mdot
.06667 .13333 Mdot
.00392 .03529 Mdot
.26275 .34118 Mdot
.35294 .34118 Mdot
.27059 .3098 Mdot
.51765 .49412 Mdot
.4902 .48235 Mdot
.03922 .07059 Mdot
.02353 .08235 Mdot
.21176 .40784 Mdot
.03529 .21961 Mdot
.10196 .13333 Mdot
.44706 .45098 Mdot
.47059 .45098 Mdot
.65098 .67451 Mdot
.62353 .68627 Mdot
.11373 .16863 Mdot
.42353 .45098 Mdot
.39608 .38824 Mdot
.39216 .41569 Mdot
.50196 .4902 Mdot
.57255 .59608 Mdot
.65882 .68235 Mdot
.40784 .44706 Mdot
.13725 .25882 Mdot
.80784 .03529 Mdot
.27451 .30588 Mdot
.45098 .41961 Mdot
.56471 .56471 Mdot
.03529 .06275 Mdot
.07451 .12157 Mdot
.00392 .02353 Mdot
.36863 .35294 Mdot
.27451 .30588 Mdot
.52549 .50588 Mdot
.83922 .87451 Mdot
.04706 .07451 Mdot
.00784 .04706 Mdot
.05882 .12941 Mdot
.21176 .26275 Mdot
.2 .20784 Mdot
.40784 .40392 Mdot
.49804 .47451 Mdot
.61569 .63529 Mdot
.00392 .03922 Mdot
.36078 .52941 Mdot
.40392 .39216 Mdot
.12941 .13725 Mdot
.39608 .41961 Mdot
.50588 .48627 Mdot
.56471 .58039 Mdot
.06275 .11373 Mdot
.16471 .23922 Mdot
.06667 .07059 Mdot
.63529 .03137 Mdot
.28627 .31765 Mdot
.47451 .43137 Mdot
.59216 .60392 Mdot
.04706 .07451 Mdot
.20784 .31373 Mdot
.00784 .03137 Mdot
.38824 .35686 Mdot
.2549 .28235 Mdot
.46275 .43529 Mdot
.53333 .53333 Mdot
.26667 .29412 Mdot
.19216 .43529 Mdot
.00392 .04706 Mdot
.40392 .38039 Mdot
.16471 .17255 Mdot
.33725 .32157 Mdot
.53333 .52941 Mdot
.74902 .76863 Mdot
.2549 .36078 Mdot
.00392 .03137 Mdot
.40784 .39216 Mdot
.32941 .30588 Mdot
.37647 .4 Mdot
.47451 .46275 Mdot
.53725 .55294 Mdot
.03922 .06667 Mdot
.31373 .48627 Mdot
.06667 .09804 Mdot
.64706 .1098 Mdot
.04314 .0902 Mdot
.45098 .42745 Mdot
.57647 .58824 Mdot
.09412 .14118 Mdot
.13333 .18824 Mdot
.30196 .37647 Mdot
.36863 .3451 Mdot
.24314 .2902 Mdot
.49804 .47451 Mdot
.51373 .50588 Mdot
.77647 .79216 Mdot
.11765 .22353 Mdot
.24706 .36078 Mdot
.41176 .38039 Mdot
.24706 .2549 Mdot
.42745 .41961 Mdot
.4902 .48235 Mdot
.61961 .65098 Mdot
.46667 .61176 Mdot
.02353 .05098 Mdot
.41176 .39216 Mdot
.27451 .23922 Mdot
.33333 .34118 Mdot
.48627 .46667 Mdot
.76863 .78431 Mdot
.13333 .16471 Mdot
.00784 .04314 Mdot
.18431 .20392 Mdot
.62353 .00784 Mdot
.24706 .27843 Mdot
.47843 .45098 Mdot
.60392 .62353 Mdot
.0549 .08627 Mdot
.54118 .65882 Mdot
0 .02745 Mdot
.38824 .36078 Mdot
.04706 .06275 Mdot
.51373 .50196 Mdot
.46667 .46275 Mdot
.42353 .47451 Mdot
.29412 .40392 Mdot
.12941 .18824 Mdot
.41176 .4 Mdot
.26667 .26275 Mdot
.42353 .43529 Mdot
.46275 .45098 Mdot
.63137 .66667 Mdot
.29412 .34118 Mdot
.08627 .3098 Mdot
.38824 .37255 Mdot
.15294 .12157 Mdot
.27843 .31765 Mdot
.46667 .45882 Mdot
.78039 .78824 Mdot
.02353 .07059 Mdot
.00392 .04314 Mdot
.00392 .01176 Mdot
.32157 .28627 Mdot
.30196 .32157 Mdot
.54902 .53333 Mdot
.38431 .43922 Mdot
.07451 .11765 Mdot
.83529 .87843 Mdot
0 .01569 Mdot
.4 .36471 Mdot
.22745 .2549 Mdot
.46667 .46275 Mdot
.47843 .48235 Mdot
.27451 .3451 Mdot
.28627 .52157 Mdot
.00392 .03529 Mdot
.40392 .37647 Mdot
.23137 .19608 Mdot
.41176 .42745 Mdot
.47843 .47451 Mdot
.80784 .84314 Mdot
.15686 .21961 Mdot
.00784 .0549 Mdot
.33333 .37647 Mdot
.08627 0 Mdot
.35294 .38824 Mdot
.48627 .45882 Mdot
.58431 .60392 Mdot
.0549 .10196 Mdot
.16078 .21569 Mdot
.00784 .02745 Mdot
.37647 .36078 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.50588 .55686 Mdot
.21569 .38431 Mdot
.82353 .87059 Mdot
.21176 .31373 Mdot
.4 .38039 Mdot
.25098 .2549 Mdot
.30196 .31373 Mdot
.49412 .4902 Mdot
.6902 .72549 Mdot
.8549 .91765 Mdot
.01569 .05098 Mdot
.41176 .39608 Mdot
.08627 .05098 Mdot
.37255 .38824 Mdot
.82353 .83137 Mdot
.77255 .80392 Mdot
.02745 .07059 Mdot
.00784 .04314 Mdot
.08627 .23529 Mdot
.33333 .26667 Mdot
.12157 .14902 Mdot
.54902 .5098 Mdot
.52549 .54118 Mdot
.48235 .52157 Mdot
.81569 .85098 Mdot
.01569 .04706 Mdot
.38039 .35686 Mdot
.13333 .16471 Mdot
.42353 .42353 Mdot
.18431 .35294 Mdot
.31373 .33725 Mdot
.83529 .87059 Mdot
.60784 .72941 Mdot
.40784 .39608 Mdot
.28235 .2549 Mdot
.40392 .41961 Mdot
.47059 .45882 Mdot
.84706 .88627 Mdot
.23137 .44314 Mdot
.17255 .35686 Mdot
.41176 .38824 Mdot
.25098 .0549 Mdot
.41176 .43137 Mdot
.49804 .50588 Mdot
.56078 .58824 Mdot
.06667 .09412 Mdot
.18824 .24706 Mdot
.37255 .4549 Mdot
.38039 .3451 Mdot
.28627 .30196 Mdot
.4902 .47451 Mdot
.72941 .74902 Mdot
.30196 .55294 Mdot
.82745 .86275 Mdot
.53725 .59216 Mdot
.40392 .38039 Mdot
.08235 .10196 Mdot
.16078 .18431 Mdot
.10588 .32941 Mdot
.69412 .79608 Mdot
.83529 .86667 Mdot
.58824 .65882 Mdot
.40784 .38824 Mdot
.26667 .19608 Mdot
.3451 .38824 Mdot
.47059 .48235 Mdot
.82353 .84706 Mdot
.16863 .4 Mdot
.61569 .72941 Mdot
.42745 .42353 Mdot
.37255 .32941 Mdot
.37647 .41569 Mdot
.56863 .5451 Mdot
.68627 .71373 Mdot
.05098 .0902 Mdot
.82353 .85882 Mdot
.57647 .60392 Mdot
.38431 .36471 Mdot
.33333 .36471 Mdot
.39216 .38431 Mdot
.48627 .4902 Mdot
.23529 .47843 Mdot
.83529 .87451 Mdot
.7451 .79608 Mdot
.41569 .39608 Mdot
.04706 .01176 Mdot
.22353 .24314 Mdot
.45882 .47451 Mdot
.8549 .88235 Mdot
.84706 .87843 Mdot
.65882 .76078 Mdot
.43137 .42353 Mdot
.36078 .30588 Mdot
.14118 .18431 Mdot
.57255 .55294 Mdot
.60784 .64706 Mdot
.20784 .47059 Mdot
.82745 .86667 Mdot
.49412 .51765 Mdot
.39216 .37255 Mdot
.3098 .35686 Mdot
.46275 .44314 Mdot
.56863 .58431 Mdot
.12157 .2 Mdot
.83137 .86275 Mdot
.62353 .66275 Mdot
.41176 .40784 Mdot
.21569 .18039 Mdot
.47451 .49804 Mdot
.21176 .44314 Mdot
.84706 .8902 Mdot
.8549 .88627 Mdot
.37255 .48235 Mdot
.41961 .41569 Mdot
.1451 .02745 Mdot
.40392 .43137 Mdot
.62353 .61176 Mdot
.67059 .69412 Mdot
.8549 .88627 Mdot
.81961 .85882 Mdot
.53725 .55294 Mdot
.39608 .36078 Mdot
.18431 .21176 Mdot
.53333 .52549 Mdot
.84314 .86275 Mdot
.72157 .91373 Mdot
.83922 .87059 Mdot
.78431 .82353 Mdot
.41569 .38824 Mdot
.25882 .26667 Mdot
.43529 .45098 Mdot
.58431 .61176 Mdot
.83137 .87843 Mdot
.8549 .88235 Mdot
.56078 .63137 Mdot
.43137 .41176 Mdot
.15294 .07451 Mdot
.40784 .43922 Mdot
.53333 .63922 Mdot
.69412 .73333 Mdot
.8549 .88627 Mdot
.83137 .87451 Mdot
.55686 .57647 Mdot
.37255 .3451 Mdot
.36471 .40392 Mdot
.50588 .49412 Mdot
.61176 .63529 Mdot
.72157 .8549 Mdot
.8549 .88235 Mdot
.65882 .69412 Mdot
.40784 .39216 Mdot
.13333 .12157 Mdot
.33333 .3451 Mdot
.61569 .64706 Mdot
.78824 .9098 Mdot
.85882 .88627 Mdot
.5451 .64706 Mdot
.45882 .43529 Mdot
.13725 .0902 Mdot
.20784 .25098 Mdot
.12941 .46667 Mdot
.98039 1 Mdot
.87451 .90196 Mdot
.83922 .90196 Mdot
.58824 .61176 Mdot
.39216 .35686 Mdot
.35686 .4 Mdot
.56863 .57255 Mdot
.84706 .86667 Mdot
.91765 .9451 Mdot
.85098 .89804 Mdot
.79608 .81961 Mdot
.41176 .39216 Mdot
.32941 .35294 Mdot
.4549 .45098 Mdot
.76471 .81569 Mdot
.91373 .9451 Mdot
.86275 .89804 Mdot
.64706 .72157 Mdot
.47451 .46667 Mdot
.1098 .06275 Mdot
.29412 .30588 Mdot
.14902 .52157 Mdot
1 1 Mdot
.88235 .91373 Mdot
.77255 .86275 Mdot
.68235 .69804 Mdot
.40392 .36471 Mdot
.29804 .32941 Mdot
.56078 .56078 Mdot
.94902 .96471 Mdot
.91373 .95294 Mdot
.83922 .88235 Mdot
.76471 .8 Mdot
.44314 .42745 Mdot
.32549 .34118 Mdot
.50196 .50588 Mdot
.87451 .89804 Mdot
.92157 .98824 Mdot
.84706 .88627 Mdot
.35686 .4902 Mdot
.4902 .49412 Mdot
.18431 .11765 Mdot
.19216 .22353 Mdot
.23529 .63922 Mdot
.9451 .95686 Mdot
.84706 .8902 Mdot
.81569 .87059 Mdot
.62353 .64706 Mdot
.42353 .38824 Mdot
.31373 .34118 Mdot
.64706 .6549 Mdot
.99608 1 Mdot
.87451 .9098 Mdot
.82745 .87451 Mdot
.4902 .52941 Mdot
.46667 .46275 Mdot
.11373 .12157 Mdot
.57255 .59216 Mdot
.88235 .91373 Mdot
.89412 .98824 Mdot
.83137 .87843 Mdot
.43137 .54902 Mdot
.46275 .46667 Mdot
.23529 .12549 Mdot
.22353 .23922 Mdot
.30588 .69804 Mdot
.52157 .6549 Mdot
.85098 .8902 Mdot
.82353 .8902 Mdot
.53333 .5451 Mdot
.44706 .42745 Mdot
.06275 .1098 Mdot
.76863 .77647 Mdot
.76863 .82745 Mdot
.86667 .90196 Mdot
.83137 .97647 Mdot
.58039 .6549 Mdot
.43922 .43137 Mdot
.18039 .18039 Mdot
.64314 .65098 Mdot
.80784 .85098 Mdot
.81176 .92549 Mdot
.64706 .92941 Mdot
.33333 .63529 Mdot
.50588 .52157 Mdot
.23529 .12941 Mdot
.15294 .22353 Mdot
.23922 .61176 Mdot
.84706 .89412 Mdot
.62353 .9098 Mdot
.18039 .60392 Mdot
.34902 .5451 Mdot
.60784 .61961 Mdot
.22745 .25098 Mdot
.69804 .72157 Mdot
.8549 .88627 Mdot
.74902 .9451 Mdot
.17255 .5098 Mdot
.09804 .41176 Mdot
.42745 .40784 Mdot
.13333 .13333 Mdot
.63922 .6549 Mdot
.85098 .87843 Mdot
.71765 .94118 Mdot
.43137 .91373 Mdot
.04706 .18039 Mdot
.14902 .38824 Mdot
.12549 .02745 Mdot
.23922 .25882 Mdot
.15686 .41176 Mdot
.7098 .93725 Mdot
.66667 1 Mdot
.03137 .08627 Mdot
.03922 .18039 Mdot
.60392 .62353 Mdot
.37647 .41569 Mdot
.62745 .65098 Mdot
.56471 .87843 Mdot
.85882 1 Mdot
.03137 .09412 Mdot
.02745 .08235 Mdot
.34118 .47059 Mdot
.25882 .26275 Mdot
.60392 .62745 Mdot
.59608 .86275 Mdot
.83529 .99216 Mdot
.06667 .20392 Mdot
.32157 .38039 Mdot
.03922 .16078 Mdot
.04706 .03137 Mdot
.53333 .57255 Mdot
.54118 .78824 Mdot
.6 .99608 Mdot
.15686 .48235 Mdot
.53725 .55686 Mdot
0 .02353 Mdot
.37647 .32549 Mdot
.47451 .5098 Mdot
.62745 .74118 Mdot
.4902 .98039 Mdot
.18431 .44706 Mdot
.41961 .52157 Mdot
.57647 .59608 Mdot
.21961 .45882 Mdot
.27843 .28235 Mdot
.64706 .67843 Mdot
.45098 .97255 Mdot
.21569 .47843 Mdot
.06275 .10588 Mdot
.57255 .62745 Mdot
.01176 .05882 Mdot
.20392 .17647 Mdot
.58431 .60392 Mdot
.28235 .84314 Mdot
.27451 .52549 Mdot
.31765 .67843 Mdot
.58039 .64706 Mdot
.13725 .17647 Mdot
.22353 .17647 Mdot
.47451 .50196 Mdot
.21176 .73333 Mdot
.28235 .54118 Mdot
.57255 .99608 Mdot
.6 .67059 Mdot
0 .01176 Mdot
.69412 .07451 Mdot
.4 .43922 Mdot
.21961 .69412 Mdot
.22745 .4902 Mdot
.54902 .94902 Mdot
.34902 .4549 Mdot
.31373 .36863 Mdot
.06667 .18039 Mdot
.37647 .40392 Mdot
.2 .65882 Mdot
.18824 .45098 Mdot
.5098 .93333 Mdot
.05882 .09804 Mdot
.21176 .2902 Mdot
.59608 .63137 Mdot
.43137 .43529 Mdot
.16863 .61176 Mdot
.11373 .52157 Mdot
.44314 .93333 Mdot
.11765 .26667 Mdot
.10588 .20392 Mdot
.42745 .45882 Mdot
.4 .33333 Mdot
.18039 .58039 Mdot
.17647 .45882 Mdot
.4 .92157 Mdot
.46667 .95294 Mdot
.04314 .09804 Mdot
.47451 .4902 Mdot
.31373 .21176 Mdot
.14118 .47451 Mdot
.03922 .30588 Mdot
.37255 .8902 Mdot
.66275 .99608 Mdot
.05882 .1098 Mdot
.00392 .04706 Mdot
.55686 .0902 Mdot
.17647 .38824 Mdot
.13333 .33725 Mdot
.33725 .83529 Mdot
.88627 1 Mdot
.05098 .12549 Mdot
.00392 .03137 Mdot
.1451 .23922 Mdot
.40392 .47843 Mdot
.10196 .29804 Mdot
.28627 .79216 Mdot
.87451 .98039 Mdot
.06667 .14902 Mdot
.01961 .06275 Mdot
.42353 .50196 Mdot
.38431 .40392 Mdot
.10196 .25882 Mdot
.19216 .7098 Mdot
.64706 .89412 Mdot
.14118 .38824 Mdot
.06275 .18824 Mdot
.02745 .10588 Mdot
.38824 .39608 Mdot
.12157 .34902 Mdot
.23137 .76863 Mdot
.5451 .96078 Mdot
.2549 .68627 Mdot
.12549 .41176 Mdot
.01961 .06275 Mdot
.38431 .36863 Mdot
.11765 .43529 Mdot
.22745 .79216 Mdot
.48235 .97255 Mdot
.27843 .76078 Mdot
.17647 .58431 Mdot
.03137 .05882 Mdot
.36471 .3098 Mdot
.09412 .41961 Mdot
.41569 .95294 Mdot
.41569 .93333 Mdot
.31373 .76863 Mdot
.19608 .62353 Mdot
.03137 .14118 Mdot
.35294 .25882 Mdot
.09412 .41961 Mdot
.25882 .81961 Mdot
.37647 .88627 Mdot
.31765 .72549 Mdot
.24706 .53333 Mdot
.09412 .40392 Mdot
.34902 .24706 Mdot
.10588 .45098 Mdot
.23529 .78039 Mdot
.36078 .86667 Mdot
.38431 .61176 Mdot
.4902 .57647 Mdot
.13333 .47451 Mdot
.34118 .23137 Mdot
.11765 .4902 Mdot
.22353 .74902 Mdot
.34118 .83137 Mdot
.52157 .57647 Mdot
.7098 .7098 Mdot
.18824 .39608 Mdot
.3451 .17255 Mdot
.13725 .51765 Mdot
.26275 .78431 Mdot
.3451 .76863 Mdot
.59608 .60392 Mdot
.77255 .77255 Mdot
.35294 .4 Mdot
.34118 .12157 Mdot
.15294 .5451 Mdot
.23137 .73333 Mdot
.41176 .62745 Mdot
.67059 .67451 Mdot
.78431 .80784 Mdot
.38039 .37255 Mdot
.23529 .07451 Mdot
.14902 .55686 Mdot
.21176 .71373 Mdot
.55294 .57255 Mdot
.87843 .88235 Mdot
.49412 .52549 Mdot
.36471 .34902 Mdot
.07451 .12941 Mdot
.16078 .58039 Mdot
.14118 .61569 Mdot
.59608 .59216 Mdot
.56471 .58824 Mdot
.41961 .37647 Mdot
.34902 .31765 Mdot
.07843 .21569 Mdot
.16078 .58824 Mdot
.21961 .51765 Mdot
.78824 .78824 Mdot
.45098 .40392 Mdot
.39608 .2902 Mdot
.34118 .29804 Mdot
.03529 .0902 Mdot
.14902 .59216 Mdot
.52157 .53333 Mdot
.54902 .58039 Mdot
.41176 .30588 Mdot
.38039 .28627 Mdot
.32549 .28627 Mdot
.09804 .36863 Mdot
.18824 .62353 Mdot
.60784 .6 Mdot
.43922 .37255 Mdot
.36471 .24314 Mdot
.39608 .3098 Mdot
.30588 .25098 Mdot
.13333 .52157 Mdot
.28235 .52549 Mdot
.60784 .63137 Mdot
.39216 .2902 Mdot
.37255 .25882 Mdot
.38431 .28627 Mdot
.27843 .20392 Mdot
.09412 .47843 Mdot
.56078 .57647 Mdot
.36078 .27843 Mdot
.38824 .26275 Mdot
.36078 .2549 Mdot
.36863 .25882 Mdot
.1451 .03529 Mdot
.12941 .53333 Mdot
.76078 .74902 Mdot
.40392 .28627 Mdot
.37255 .25098 Mdot
.39608 .29412 Mdot
.35686 .25098 Mdot
.07843 .15686 Mdot
.17647 .43137 Mdot
.39608 .38039 Mdot
.41569 .31765 Mdot
.36863 .25098 Mdot
.38039 .2902 Mdot
.33725 .27843 Mdot
.12549 .45098 Mdot
.56863 .56471 Mdot
.46275 .38431 Mdot
.43922 .33333 Mdot
.37255 .25098 Mdot
.37647 .27451 Mdot
.27843 .2 Mdot
.11765 .49412 Mdot
.68627 .69412 Mdot
.52157 .46275 Mdot
.41961 .32941 Mdot
.35686 .23529 Mdot
.41569 .33333 Mdot
.33725 .24314 Mdot
.15294 .42353 Mdot
.52549 .4549 Mdot
.55686 .49412 Mdot
.39216 .31373 Mdot
.36078 .27451 Mdot
.36863 .28627 Mdot
.14118 .02745 Mdot
.65098 .64314 Mdot
.57255 .59608 Mdot
.45098 .39608 Mdot
.40784 .34902 Mdot
.41569 .38039 Mdot
.34902 .30588 Mdot
.16471 .52549 Mdot
.35686 .31373 Mdot
.42745 .39216 Mdot
.52157 .48235 Mdot
.34118 .32157 Mdot
.37255 .32157 Mdot
.41961 .36471 Mdot
.25098 .43137 Mdot
.39608 .28627 Mdot
.41569 .31765 Mdot
.23137 .21569 Mdot
.27059 .24314 Mdot
.44706 .38431 Mdot
.38431 .29804 Mdot
.55686 .54902 Mdot
.38431 .2549 Mdot
.47059 .41961 Mdot
.33333 .30588 Mdot
.22353 .18039 Mdot
.34118 .30588 Mdot
.26667 .61961 Mdot
.40392 .3098 Mdot
.40392 .2902 Mdot
.43137 .4 Mdot
.39216 .33333 Mdot
.41176 .36078 Mdot
.44314 .40784 Mdot
.45098 .42745 Mdot
.41176 .27451 Mdot
.39608 .33333 Mdot
.51373 .47059 Mdot
.43922 .33333 Mdot
.37647 .32157 Mdot
.6549 .04706 Mdot
.40392 .28627 Mdot
.4 .25882 Mdot
.7098 .69412 Mdot
.41961 .26667 Mdot
.39608 .30588 Mdot
.50196 .46667 Mdot
.38824 .31765 Mdot
.41176 .2902 Mdot
.40392 .31373 Mdot
.5098 .43922 Mdot
.38039 .26275 Mdot
.42353 .4 Mdot
.35686 .17647 Mdot
.40784 .28235 Mdot
.39216 .27451 Mdot
.44314 .39216 Mdot
.37255 .25098 Mdot
.42353 .32549 Mdot
.54902 .52549 Mdot
.30588 .16863 Mdot
.40392 .27059 Mdot
.78431 .76471 Mdot
.3451 .33333 Mdot
.43137 .38039 Mdot
.59608 .59216 Mdot
.3098 .18824 Mdot
.41569 .29804 Mdot
.4 .21961 Mdot
.4549 .40392 Mdot
.48235 .43922 Mdot
.62353 .61569 Mdot
.38431 .27843 Mdot
.34118 .1451 Mdot
.36863 .19608 Mdot
.45882 .38824 Mdot
.44706 .37255 Mdot
.52157 .46667 Mdot
.59608 .59608 Mdot
.35686 .27843 Mdot
.43922 .33725 Mdot
.38039 .23529 Mdot
.63137 .64314 Mdot
.48627 .41176 Mdot
.71373 .71765 Mdot
.23922 .16471 Mdot
.41569 .28627 Mdot
.46275 .36078 Mdot
.6 .57255 Mdot
.53725 .52157 Mdot
.78824 .79608 Mdot
.37255 .19216 Mdot
.40784 .29412 Mdot
.44706 .32157 Mdot
.53725 .42353 Mdot
.64706 .63922 Mdot
.8902 .89412 Mdot
.33725 .07843 Mdot
.41569 .32941 Mdot
.45882 .3451 Mdot
.45882 .29804 Mdot
.59608 .48627 Mdot
.92157 .93725 Mdot
.35686 .0902 Mdot
.39608 .33333 Mdot
.46275 .36863 Mdot
.56078 .42745 Mdot
.8902 .81569 Mdot
.85882 .8902 Mdot
.3451 .19608 Mdot
.38824 .32157 Mdot
.4549 .37647 Mdot
.63137 .55294 Mdot
.99608 .98824 Mdot
.81569 .84706 Mdot
.34902 .30196 Mdot
.4902 .43922 Mdot
.52941 .45098 Mdot
.88235 .84706 Mdot
.99216 .99608 Mdot
.73725 .74118 Mdot
.43137 .38824 Mdot
.47843 .42745 Mdot
.61176 .56078 Mdot
.99216 .99216 Mdot
.87451 .89412 Mdot
.35686 .16471 Mdot
.42745 .36078 Mdot
.57647 .55294 Mdot
.99608 .99216 Mdot
.89412 .9098 Mdot
.76863 .78039 Mdot
.47451 .43137 Mdot
.59608 .58431 Mdot
1 .99216 Mdot
.97255 .98039 Mdot
.82353 .82745 Mdot
.45098 .41569 Mdot
.57647 .55294 Mdot
.92157 .92157 Mdot
.97647 .98039 Mdot
.83529 .84314 Mdot
.43137 .38824 Mdot
.60784 .59216 Mdot
.90196 .90588 Mdot
.92157 .92941 Mdot
.83137 .84706 Mdot
.46275 .43137 Mdot
.67059 .66275 Mdot
.98824 .99216 Mdot
.93333 .92941 Mdot
.52549 .44314 Mdot
.53725 .51373 Mdot
.89804 .90588 Mdot
.96078 .96078 Mdot
.85098 .8549 Mdot
.48235 .43922 Mdot
.7451 .7451 Mdot
.96863 .96471 Mdot
.8902 .8902 Mdot
.38824 .2549 Mdot
.72549 .72549 Mdot
.93333 .93725 Mdot
.90196 .9098 Mdot
.4902 .41569 Mdot
.83529 .83922 Mdot
.91765 .92941 Mdot
.77255 .18824 Mdot
.6902 .68627 Mdot
.94118 .94118 Mdot
.78039 .20784 Mdot
.69804 .67451 Mdot
.65882 .59608 Mdot
.49804 .32157 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.567362 0.477324 1.05965 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.39083 .53213 Mdot
1 .5 0 r
.45381 .53792 Mdot
.43603 .53768 Mdot
.628 .126 .941 r
.41705 .53801 Mdot
.42691 .53781 Mdot
.41895 .53737 Mdot
1 .5 0 r
.46964 .55763 Mdot
.38337 .50195 Mdot
.628 .126 .941 r
.40904 .46767 Mdot
1 .5 0 r
.46742 .46581 Mdot
.45589 .4701 Mdot
.44142 .47888 Mdot
.628 .126 .941 r
.42804 .42977 Mdot
.37777 .50352 Mdot
1 .5 0 r
.49969 .51033 Mdot
.48477 .48959 Mdot
.628 .126 .941 r
.38584 .50944 Mdot
1 .5 0 r
.4818 .49766 Mdot
.628 .126 .941 r
.48146 .48035 Mdot
1 .5 0 r
.45525 .46538 Mdot
.628 .126 .941 r
.43719 .44222 Mdot
1 .5 0 r
.35115 .43648 Mdot
.48785 .4956 Mdot
.39065 .45722 Mdot
.34454 .43884 Mdot
.41057 .42387 Mdot
.50902 .52668 Mdot
.628 .126 .941 r
.30673 .4804 Mdot
1 .5 0 r
.49015 .51774 Mdot
.628 .126 .941 r
.49023 .46873 Mdot
1 .5 0 r
.34329 .41297 Mdot
.34837 .41464 Mdot
.34515 .41402 Mdot
.34402 .41092 Mdot
.34402 .41092 Mdot
.34702 .41508 Mdot
.34476 .40886 Mdot
.35013 .41747 Mdot
.33843 .40586 Mdot
.34362 .40574 Mdot
.628 .126 .941 r
.52047 .54433 Mdot
1 .5 0 r
.35098 .41363 Mdot
.34985 .41052 Mdot
.33718 .40451 Mdot
.35183 .4098 Mdot
.34029 .4069 Mdot
.628 .126 .941 r
.5279 .55415 Mdot
1 .5 0 r
.34861 .40918 Mdot
.34538 .40857 Mdot
.5687 .55896 Mdot
.34946 .40534 Mdot
.34946 .40534 Mdot
.628 .126 .941 r
.53296 .55277 Mdot
.66449 .34914 Mdot
1 .5 0 r
.37569 .33215 Mdot
.628 .126 .941 r
.64349 .35499 Mdot
1 .5 0 r
.45846 .37183 Mdot
.41316 .35674 Mdot
.76966 .35403 Mdot
.628 .126 .941 r
.56673 .33097 Mdot
.55848 .35793 Mdot
.59388 .37477 Mdot
.53058 .33467 Mdot
.44229 .47728 Mdot
.64544 .37292 Mdot
.54354 .32626 Mdot
.43247 .31987 Mdot
1 .5 0 r
.57577 .51652 Mdot
.628 .126 .941 r
.50476 .31236 Mdot
.52276 .3355 Mdot
.45621 .31481 Mdot
.42218 .32328 Mdot
.52456 .31992 Mdot
.3533 .30335 Mdot
.55815 .34868 Mdot
.50269 .33511 Mdot
.5948 .41744 Mdot
.63871 .43049 Mdot
1 .5 0 r
.39756 .2807 Mdot
.628 .126 .941 r
.25816 .41989 Mdot
.60087 .48505 Mdot
.45757 .31581 Mdot
.47687 .32406 Mdot
1 .5 0 r
.19927 .34566 Mdot
.628 .126 .941 r
.28577 .40779 Mdot
.22883 .39198 Mdot
1 .5 0 r
.28933 .41986 Mdot
.628 .126 .941 r
.42072 .36312 Mdot
.26687 .37826 Mdot
.35416 .38128 Mdot
1 .5 0 r
.08846 .24555 Mdot
.09176 .2481 Mdot
.09176 .2481 Mdot
.0905 .24469 Mdot
.0905 .24469 Mdot
.0905 .24469 Mdot
.48382 .29452 Mdot
.29842 .44519 Mdot
.09021 .24652 Mdot
.628 .126 .941 r
.2619 .27082 Mdot
1 .5 0 r
.22844 .41866 Mdot
.628 .126 .941 r
.22154 .41539 Mdot
1 .5 0 r
.09663 .24211 Mdot
.15222 .29868 Mdot
.628 .126 .941 r
.26507 .26388 Mdot
.43866 .37376 Mdot
1 .5 0 r
.10764 .24367 Mdot
.10073 .24039 Mdot
.10073 .24039 Mdot
.11223 .24964 Mdot
.628 .126 .941 r
.29777 .44156 Mdot
1 .5 0 r
.10405 .24294 Mdot
.28982 .44441 Mdot
.628 .126 .941 r
.4014 .39667 Mdot
1 .5 0 r
.10483 .23867 Mdot
.14708 .30781 Mdot
.628 .126 .941 r
.36074 .29816 Mdot
1 .5 0 r
.1025 .24135 Mdot
.628 .126 .941 r
.32616 .45243 Mdot
1 .5 0 r
.10689 .2378 Mdot
.11021 .24036 Mdot
.11021 .24036 Mdot
.11587 .24022 Mdot
.53513 .37547 Mdot
.1192 .24278 Mdot
.1116 .26467 Mdot
.628 .126 .941 r
.44205 .39354 Mdot
1 .5 0 r
.32779 .43457 Mdot
.16964 .3301 Mdot
.628 .126 .941 r
.45219 .38989 Mdot
.39359 .42438 Mdot
1 .5 0 r
.11073 .2379 Mdot
.628 .126 .941 r
.46738 .41132 Mdot
.30199 .46495 Mdot
1 .5 0 r
.11512 .23434 Mdot
.12079 .23421 Mdot
.628 .126 .941 r
.4473 .37628 Mdot
1 .5 0 r
.1564 .30975 Mdot
.11279 .23703 Mdot
.14993 .27171 Mdot
.628 .126 .941 r
.36279 .42967 Mdot
1 .5 0 r
.11846 .2369 Mdot
.17275 .33458 Mdot
.37351 .45465 Mdot
.628 .126 .941 r
.47603 .33136 Mdot
1 .5 0 r
.15895 .27415 Mdot
.12052 .23603 Mdot
.2876 .44129 Mdot
.23743 .38433 Mdot
.12259 .23516 Mdot
.51655 .42446 Mdot
.15651 .34216 Mdot
.628 .126 .941 r
.38886 .43376 Mdot
.27906 .42701 Mdot
.33477 .47435 Mdot
1 .5 0 r
.12185 .27179 Mdot
.31967 .46439 Mdot
.628 .126 .941 r
.13054 .37255 Mdot
1 .5 0 r
.20076 .2838 Mdot
.628 .126 .941 r
.38316 .38192 Mdot
.4014 .43889 Mdot
1 .5 0 r
.37235 .47628 Mdot
.12753 .22912 Mdot
.12078 .23539 Mdot
.628 .126 .941 r
.41603 .43171 Mdot
1 .5 0 r
.42126 .46643 Mdot
.628 .126 .941 r
.34433 .50754 Mdot
.41357 .4249 Mdot
.41823 .43093 Mdot
.41823 .43093 Mdot
1 .5 0 r
.13529 .22811 Mdot
.13296 .23081 Mdot
.3192 .45879 Mdot
.628 .126 .941 r
.30757 .3319 Mdot
.44534 .41735 Mdot
.33649 .468 Mdot
.32993 .48385 Mdot
1 .5 0 r
.5466 .3887 Mdot
.13503 .22994 Mdot
.13503 .22994 Mdot
.628 .126 .941 r
.31538 .50257 Mdot
1 .5 0 r
.41731 .44862 Mdot
.628 .126 .941 r
.35294 .49295 Mdot
1 .5 0 r
.13376 .2265 Mdot
.628 .126 .941 r
.3205 .47375 Mdot
1 .5 0 r
.43482 .46741 Mdot
.16429 .26759 Mdot
.54988 .38174 Mdot
.628 .126 .941 r
.41588 .43564 Mdot
.37727 .45143 Mdot
.35092 .45125 Mdot
.40809 .44808 Mdot
.12279 .37502 Mdot
1 .5 0 r
.18773 .24175 Mdot
.44548 .42887 Mdot
.51512 .4193 Mdot
.628 .126 .941 r
.40543 .43168 Mdot
1 .5 0 r
.41152 .45072 Mdot
.628 .126 .941 r
.43645 .43791 Mdot
.12513 .32973 Mdot
1 .5 0 r
.42715 .49143 Mdot
.628 .126 .941 r
.42133 .4279 Mdot
.34377 .504 Mdot
1 .5 0 r
.14382 .2342 Mdot
.628 .126 .941 r
.33139 .45634 Mdot
1 .5 0 r
.2557 .39281 Mdot
.628 .126 .941 r
.44542 .43084 Mdot
.41268 .45611 Mdot
1 .5 0 r
.13558 .22745 Mdot
.3926 .48455 Mdot
.16024 .25913 Mdot
.16634 .27817 Mdot
.14128 .22732 Mdot
.2087 .33823 Mdot
.2083 .31905 Mdot
.33309 .49049 Mdot
.628 .126 .941 r
.36479 .47138 Mdot
.33223 .50625 Mdot
1 .5 0 r
.47297 .4364 Mdot
.1514 .22361 Mdot
.628 .126 .941 r
.35276 .32508 Mdot
.34241 .50261 Mdot
.46395 .44544 Mdot
.34831 .51208 Mdot
.35047 .32781 Mdot
.3667 .51514 Mdot
1 .5 0 r
.14672 .22901 Mdot
.628 .126 .941 r
.43868 .26713 Mdot
1 .5 0 r
.34152 .40055 Mdot
.628 .126 .941 r
.36546 .51173 Mdot
.46064 .45437 Mdot
.39642 .45425 Mdot
.37013 .5178 Mdot
.39622 .44466 Mdot
.40805 .46361 Mdot
.4657 .36174 Mdot
1 .5 0 r
.12976 .25045 Mdot
.628 .126 .941 r
.34275 .46967 Mdot
.34839 .52369 Mdot
.37375 .53005 Mdot
1 .5 0 r
.24206 .36473 Mdot
.628 .126 .941 r
.32922 .48226 Mdot
.35419 .46943 Mdot
.35963 .51387 Mdot
1 .5 0 r
.30589 .22774 Mdot
.13989 .24674 Mdot
.628 .126 .941 r
.37803 .51693 Mdot
1 .5 0 r
.15198 .22111 Mdot
.628 .126 .941 r
.36897 .52601 Mdot
1 .5 0 r
.47721 .4272 Mdot
.628 .126 .941 r
.46368 .4398 Mdot
1 .5 0 r
.41461 .27754 Mdot
.628 .126 .941 r
.46922 .43008 Mdot
1 .5 0 r
.31252 .22327 Mdot
.18402 .28682 Mdot
.628 .126 .941 r
.4491 .45858 Mdot
.41036 .47443 Mdot
.11855 .34706 Mdot
.41571 .4551 Mdot
1 .5 0 r
.28906 .37869 Mdot
.44701 .47095 Mdot
.628 .126 .941 r
.34434 .50588 Mdot
.43413 .45816 Mdot
.45932 .45492 Mdot
1 .5 0 r
.2062 .31169 Mdot
.37733 .37214 Mdot
.628 .126 .941 r
.45302 .42623 Mdot
.36887 .52804 Mdot
.45236 .45162 Mdot
.35598 .51526 Mdot
.36848 .50883 Mdot
1 .5 0 r
.47718 .42917 Mdot
.628 .126 .941 r
.37927 .534 Mdot
1 .5 0 r
.15382 .22206 Mdot
.41086 .50525 Mdot
.52505 .47006 Mdot
.29204 .244 Mdot
.628 .126 .941 r
.44866 .44135 Mdot
1 .5 0 r
.15148 .22477 Mdot
.15719 .22463 Mdot
.34712 .24353 Mdot
.628 .126 .941 r
.27373 .48869 Mdot
1 .5 0 r
.38805 .51734 Mdot
.15592 .22118 Mdot
.628 .126 .941 r
.19826 .38993 Mdot
.30533 .45991 Mdot
1 .5 0 r
.15464 .21772 Mdot
.628 .126 .941 r
.44496 .43107 Mdot
.37325 .52655 Mdot
1 .5 0 r
.16036 .21759 Mdot
.628 .126 .941 r
.43733 .45318 Mdot
.46274 .45955 Mdot
.43714 .44357 Mdot
.21388 .43077 Mdot
.42951 .46568 Mdot
.36503 .51983 Mdot
.48607 .47831 Mdot
.13004 .3795 Mdot
1 .5 0 r
.16373 .22016 Mdot
.47957 .43996 Mdot
.628 .126 .941 r
.34429 .51954 Mdot
.36971 .52591 Mdot
.42722 .46845 Mdot
.35002 .51943 Mdot
1 .5 0 r
.14249 .25487 Mdot
.628 .126 .941 r
.35556 .50969 Mdot
.42571 .50969 Mdot
1 .5 0 r
.2045 .31202 Mdot
.628 .126 .941 r
.38012 .53188 Mdot
1 .5 0 r
.1544 .21955 Mdot
.16012 .21942 Mdot
.45677 .45204 Mdot
.628 .126 .941 r
.37907 .53808 Mdot
1 .5 0 r
.41758 .44868 Mdot
.628 .126 .941 r
.41052 .49967 Mdot
.27705 .43906 Mdot
.37783 .53467 Mdot
.46778 .48686 Mdot
.40335 .48674 Mdot
.37658 .53125 Mdot
1 .5 0 r
.4348 .44832 Mdot
.628 .126 .941 r
.40889 .477 Mdot
.33522 .23786 Mdot
1 .5 0 r
.15649 .21867 Mdot
.56207 .42588 Mdot
.628 .126 .941 r
.41416 .51195 Mdot
.30872 .23766 Mdot
1 .5 0 r
.45193 .50227 Mdot
.628 .126 .941 r
.47153 .44483 Mdot
.45202 .44795 Mdot
.37429 .53404 Mdot
1 .5 0 r
.16094 .21507 Mdot
.628 .126 .941 r
.38003 .53392 Mdot
1 .5 0 r
.48273 .48928 Mdot
.628 .126 .941 r
.43778 .48604 Mdot
1 .5 0 r
.31631 .45403 Mdot
.55237 .46041 Mdot
.46266 .46354 Mdot
.29848 .30722 Mdot
.18424 .2338 Mdot
.628 .126 .941 r
.37773 .53671 Mdot
.44229 .48249 Mdot
1 .5 0 r
.16432 .21765 Mdot
.27649 .42178 Mdot
.628 .126 .941 r
.44804 .48238 Mdot
.37648 .53329 Mdot
.39609 .47582 Mdot
1 .5 0 r
.42154 .4822 Mdot
.15625 .2205 Mdot
.628 .126 .941 r
.46574 .44693 Mdot
1 .5 0 r
.55578 .39908 Mdot
.20628 .24908 Mdot
.628 .126 .941 r
.4335 .44687 Mdot
.37419 .53608 Mdot
1 .5 0 r
.1607 .2169 Mdot
.24301 .24555 Mdot
.628 .126 .941 r
.26564 .46252 Mdot
.39161 .54537 Mdot
.40414 .53893 Mdot
.44309 .46867 Mdot
.40395 .5293 Mdot
.28634 .22607 Mdot
1 .5 0 r
.17701 .23232 Mdot
.628 .126 .941 r
.43025 .40147 Mdot
.21218 .44289 Mdot
1 .5 0 r
.43459 .50667 Mdot
.15047 .23211 Mdot
.47288 .46186 Mdot
.628 .126 .941 r
.396 .47782 Mdot
.39506 .54805 Mdot
.11611 .36285 Mdot
1 .5 0 r
.45948 .48415 Mdot
.16873 .22553 Mdot
.628 .126 .941 r
.42816 .41386 Mdot
1 .5 0 r
.16853 .21588 Mdot
.16173 .2222 Mdot
.628 .126 .941 r
.41268 .56697 Mdot
1 .5 0 r
.22474 .26363 Mdot
.628 .126 .941 r
.42004 .47114 Mdot
1 .5 0 r
.4389 .49349 Mdot
.47635 .46452 Mdot
.15938 .22492 Mdot
.628 .126 .941 r
.41794 .48356 Mdot
.49418 .49308 Mdot
1 .5 0 r
.17064 .215 Mdot
.17064 .215 Mdot
.628 .126 .941 r
.38347 .55033 Mdot
.53722 .45434 Mdot
.46029 .47031 Mdot
.46029 .47031 Mdot
1 .5 0 r
.4214 .48622 Mdot
.628 .126 .941 r
.38203 .53727 Mdot
.33444 .2241 Mdot
.34341 .5084 Mdot
.41988 .52757 Mdot
.34982 .48279 Mdot
1 .5 0 r
.36918 .47001 Mdot
.47094 .48592 Mdot
.17275 .21411 Mdot
.628 .126 .941 r
.39917 .47285 Mdot
1 .5 0 r
.17148 .21064 Mdot
.20311 .23621 Mdot
.628 .126 .941 r
.25769 .43426 Mdot
.37743 .54286 Mdot
1 .5 0 r
.42257 .49167 Mdot
.628 .126 .941 r
.46724 .47563 Mdot
1 .5 0 r
.47338 .4948 Mdot
.628 .126 .941 r
.42927 .42124 Mdot
1 .5 0 r
.51144 .49474 Mdot
.16933 .22302 Mdot
.47895 .48504 Mdot
.628 .126 .941 r
.34557 .38909 Mdot
1 .5 0 r
.49104 .51375 Mdot
.17487 .21323 Mdot
.628 .126 .941 r
.42047 .5041 Mdot
.38174 .52967 Mdot
.32373 .51357 Mdot
.38749 .52955 Mdot
.10132 .35042 Mdot
.43113 .51973 Mdot
.4246 .48125 Mdot
.39814 .5452 Mdot
1 .5 0 r
.17826 .21581 Mdot
.1514 .26044 Mdot
.628 .126 .941 r
.10489 .3627 Mdot
.3967 .53212 Mdot
.30059 .51607 Mdot
1 .5 0 r
.42203 .52886 Mdot
.18165 .21839 Mdot
.628 .126 .941 r
.51814 .42629 Mdot
.47258 .45821 Mdot
1 .5 0 r
.17463 .21506 Mdot
.50944 .45471 Mdot
.628 .126 .941 r
.38654 .54748 Mdot
1 .5 0 r
.50216 .49624 Mdot
.1791 .21145 Mdot
.628 .126 .941 r
.47692 .44499 Mdot
1 .5 0 r
.27144 .39036 Mdot
.628 .126 .941 r
.3918 .46389 Mdot
1 .5 0 r
.44287 .47669 Mdot
.18249 .21403 Mdot
.628 .126 .941 r
.29787 .20763 Mdot
.11629 .37404 Mdot
.46101 .46045 Mdot
.28775 .46039 Mdot
1 .5 0 r
.42091 .53714 Mdot
.628 .126 .941 r
.48569 .48273 Mdot
1 .5 0 r
.1748 .23623 Mdot
.49165 .49227 Mdot
.40756 .50496 Mdot
.51019 .49536 Mdot
.628 .126 .941 r
.39346 .55285 Mdot
1 .5 0 r
.50319 .49204 Mdot
.54131 .49198 Mdot
.42713 .38308 Mdot
.628 .126 .941 r
.2786 .46951 Mdot
1 .5 0 r
.49618 .48872 Mdot
.628 .126 .941 r
.41199 .55594 Mdot
.39922 .55274 Mdot
1 .5 0 r
.37395 .50146 Mdot
.17887 .21328 Mdot
.628 .126 .941 r
.431 .52381 Mdot
1 .5 0 r
.36174 .4085 Mdot
.628 .126 .941 r
.45635 .52055 Mdot
.43156 .43405 Mdot
1 .5 0 r
.44339 .50769 Mdot
.628 .126 .941 r
.40393 .55886 Mdot
1 .5 0 r
.17759 .20981 Mdot
.628 .126 .941 r
.41698 .51718 Mdot
1 .5 0 r
.18334 .20967 Mdot
.628 .126 .941 r
.43485 .54582 Mdot
1 .5 0 r
.48605 .50408 Mdot
.48605 .50408 Mdot
.19484 .2094 Mdot
.18206 .20619 Mdot
.628 .126 .941 r
.35147 .4784 Mdot
1 .5 0 r
.44658 .55526 Mdot
.44686 .51037 Mdot
.50441 .4975 Mdot
.18099 .21239 Mdot
.52315 .51025 Mdot
.628 .126 .941 r
.377 .366 Mdot
.47213 .44287 Mdot
1 .5 0 r
.50336 .50373 Mdot
.4902 .48119 Mdot
.628 .126 .941 r
.58591 .46826 Mdot
1 .5 0 r
.4759 .51945 Mdot
.54643 .51945 Mdot
.5079 .50017 Mdot
.628 .126 .941 r
.14983 .4008 Mdot
1 .5 0 r
.2159 .23093 Mdot
.50705 .51607 Mdot
.5007 .48718 Mdot
.49389 .49353 Mdot
.628 .126 .941 r
.4222 .55435 Mdot
1 .5 0 r
.2009 .29475 Mdot
.48072 .47098 Mdot
.24615 .24341 Mdot
.49265 .49009 Mdot
.43394 .56379 Mdot
.18183 .20803 Mdot
.628 .126 .941 r
.28742 .46439 Mdot
.1087 .3746 Mdot
1 .5 0 r
.18758 .20789 Mdot
.628 .126 .941 r
.50439 .49953 Mdot
.31761 .53152 Mdot
1 .5 0 r
.51036 .50908 Mdot
.628 .126 .941 r
.49757 .50588 Mdot
1 .5 0 r
.4773 .53461 Mdot
.17968 .22044 Mdot
.49653 .51211 Mdot
.23063 .22357 Mdot
.628 .126 .941 r
.39356 .51205 Mdot
.33736 .30024 Mdot
.1736 .45067 Mdot
.42213 .55642 Mdot
1 .5 0 r
.34613 .45696 Mdot
.5058 .51468 Mdot
.3611 .27413 Mdot
.50542 .49532 Mdot
.50523 .48564 Mdot
.18736 .20972 Mdot
.44116 .40529 Mdot
.51016 .50144 Mdot
.20571 .2031 Mdot
.38153 .49496 Mdot
.18608 .20624 Mdot
.18608 .20624 Mdot
.628 .126 .941 r
.13205 .4051 Mdot
.32968 .50774 Mdot
.48371 .51094 Mdot
.11905 .39221 Mdot
1 .5 0 r
.19184 .2061 Mdot
.39991 .48837 Mdot
.628 .126 .941 r
.47669 .50762 Mdot
1 .5 0 r
.63007 .53643 Mdot
.1976 .20597 Mdot
.15162 .28295 Mdot
.43744 .51392 Mdot
.628 .126 .941 r
.46256 .55562 Mdot
.20072 .42724 Mdot
.37211 .54909 Mdot
.50152 .4753 Mdot
1 .5 0 r
.56552 .49134 Mdot
.53945 .52022 Mdot
.60401 .44631 Mdot
.18948 .20883 Mdot
.48057 .52967 Mdot
.48701 .50394 Mdot
.628 .126 .941 r
.44131 .53597 Mdot
1 .5 0 r
.39655 .49741 Mdot
.20101 .20856 Mdot
.628 .126 .941 r
.42148 .52944 Mdot
1 .5 0 r
.51821 .50056 Mdot
.58222 .5166 Mdot
.23163 .29513 Mdot
.628 .126 .941 r
.51185 .47162 Mdot
.4981 .539 Mdot
1 .5 0 r
.51138 .50692 Mdot
.628 .126 .941 r
.10814 .3785 Mdot
1 .5 0 r
.19289 .21142 Mdot
.628 .126 .941 r
.15163 .41361 Mdot
1 .5 0 r
.48387 .52267 Mdot
.18585 .20808 Mdot
.48368 .51298 Mdot
.32603 .26899 Mdot
.628 .126 .941 r
.33552 .51934 Mdot
.41851 .55786 Mdot
1 .5 0 r
.19161 .20794 Mdot
.53405 .54175 Mdot
.30999 .45824 Mdot
.19738 .2078 Mdot
.628 .126 .941 r
.45597 .51905 Mdot
1 .5 0 r
.4942 .51899 Mdot
.1961 .20432 Mdot
.1961 .20432 Mdot
.628 .126 .941 r
.58984 .55104 Mdot
.39704 .52851 Mdot
.24314 .48029 Mdot
.37815 .45134 Mdot
.47265 .54433 Mdot
.50387 .54095 Mdot
1 .5 0 r
.4847 .50878 Mdot
.48423 .5441 Mdot
.628 .126 .941 r
.47739 .55047 Mdot
1 .5 0 r
.50396 .48624 Mdot
.19823 .20342 Mdot
.55133 .23875 Mdot
.628 .126 .941 r
.43743 .58242 Mdot
1 .5 0 r
.49608 .49885 Mdot
.628 .126 .941 r
.34267 .36055 Mdot
1 .5 0 r
.49504 .5051 Mdot
.48155 .52752 Mdot
.20272 .19979 Mdot
.628 .126 .941 r
.46769 .53056 Mdot
1 .5 0 r
.44775 .57875 Mdot
.628 .126 .941 r
.33208 .47571 Mdot
.52988 .56883 Mdot
1 .5 0 r
.59521 .46916 Mdot
.4709 .5783 Mdot
.588 .45613 Mdot
.49027 .501 Mdot
.628 .126 .941 r
.47631 .55879 Mdot
.47631 .55879 Mdot
1 .5 0 r
.20378 .20512 Mdot
.48257 .52332 Mdot
.628 .126 .941 r
.45645 .55225 Mdot
1 .5 0 r
.39879 .51041 Mdot
.53368 .52648 Mdot
.628 .126 .941 r
.3036 .3882 Mdot
1 .5 0 r
.39195 .51678 Mdot
.628 .126 .941 r
.48789 .55857 Mdot
.41645 .58423 Mdot
1 .5 0 r
.2025 .20163 Mdot
.21533 .20484 Mdot
.628 .126 .941 r
.10988 .39129 Mdot
1 .5 0 r
.52646 .51345 Mdot
.50679 .5166 Mdot
.2325 .31401 Mdot
.19478 .22393 Mdot
.20123 .19814 Mdot
.20123 .19814 Mdot
.628 .126 .941 r
.42166 .55501 Mdot
.47325 .5228 Mdot
1 .5 0 r
.38326 .49059 Mdot
.628 .126 .941 r
.34743 .25902 Mdot
.42108 .5259 Mdot
.66415 .61266 Mdot
1 .5 0 r
.19907 .21058 Mdot
.628 .126 .941 r
.33782 .42282 Mdot
1 .5 0 r
.51696 .50321 Mdot
.47732 .55461 Mdot
.19201 .20723 Mdot
.50327 .51596 Mdot
.48331 .5642 Mdot
.52874 .51269 Mdot
.628 .126 .941 r
.43711 .57689 Mdot
.43711 .57689 Mdot
1 .5 0 r
.51486 .51573 Mdot
.54633 .52204 Mdot
.37883 .5059 Mdot
.50716 .53807 Mdot
.628 .126 .941 r
.42902 .57983 Mdot
.42264 .55082 Mdot
1 .5 0 r
.46095 .55076 Mdot
.50545 .57001 Mdot
.60319 .46057 Mdot
.36434 .47981 Mdot
.628 .126 .941 r
.09485 .35742 Mdot
.5043 .51175 Mdot
1 .5 0 r
.21169 .21564 Mdot
.43231 .57283 Mdot
.628 .126 .941 r
.36297 .41181 Mdot
.43811 .57272 Mdot
.49621 .51467 Mdot
1 .5 0 r
.24745 .20859 Mdot
.628 .126 .941 r
.42962 .55623 Mdot
1 .5 0 r
.49478 .50151 Mdot
.628 .126 .941 r
.40906 .57537 Mdot
.66099 .50449 Mdot
.32618 .43676 Mdot
.10095 .38841 Mdot
.09456 .35937 Mdot
.4138 .58153 Mdot
1 .5 0 r
.23138 .22407 Mdot
.49077 .53628 Mdot
.47174 .51374 Mdot
.628 .126 .941 r
.33594 .52334 Mdot
1 .5 0 r
.40017 .53944 Mdot
.45775 .57164 Mdot
.628 .126 .941 r
.45109 .58774 Mdot
1 .5 0 r
.36286 .41379 Mdot
.628 .126 .941 r
.48925 .57797 Mdot
1 .5 0 r
.46269 .58752 Mdot
.20979 .19453 Mdot
.25976 .3137 Mdot
.27316 .22661 Mdot
.494 .58413 Mdot
.20871 .20077 Mdot
.628 .126 .941 r
.33579 .33927 Mdot
1 .5 0 r
.39232 .37774 Mdot
.52608 .50015 Mdot
.51922 .50653 Mdot
.44782 .54197 Mdot
.628 .126 .941 r
.39593 .56452 Mdot
1 .5 0 r
.21342 .20687 Mdot
.21322 .19713 Mdot
.628 .126 .941 r
.26749 .47742 Mdot
1 .5 0 r
.53788 .50964 Mdot
.628 .126 .941 r
.50456 .59018 Mdot
1 .5 0 r
.20635 .20351 Mdot
.41362 .51901 Mdot
.21106 .2096 Mdot
.30153 .19672 Mdot
.628 .126 .941 r
.40628 .56084 Mdot
1 .5 0 r
.51008 .51573 Mdot
.628 .126 .941 r
.67149 .50284 Mdot
.34942 .448 Mdot
.46332 .56389 Mdot
1 .5 0 r
.46951 .58323 Mdot
.628 .126 .941 r
.65075 .51227 Mdot
1 .5 0 r
.22244 .19959 Mdot
.48817 .58634 Mdot
.42369 .5605 Mdot
.22116 .19609 Mdot
.628 .126 .941 r
.33451 .40238 Mdot
1 .5 0 r
.26478 .28628 Mdot
.50007 .54093 Mdot
.628 .126 .941 r
.45348 .59884 Mdot
.26704 .52464 Mdot
.356 .55348 Mdot
.42699 .55348 Mdot
.33846 .36958 Mdot
.35084 .40827 Mdot
.45766 .57582 Mdot
.48967 .54669 Mdot
.4506 .57248 Mdot
.31269 .24349 Mdot
1 .5 0 r
.22223 .20143 Mdot
.628 .126 .941 r
.38092 .40139 Mdot
1 .5 0 r
.71736 .34333 Mdot
.51435 .55941 Mdot
.628 .126 .941 r
.46193 .61747 Mdot
.55343 1.01415 Mdot
1 .5 0 r
.2349 .19491 Mdot
.2349 .19491 Mdot
.2349 .19491 Mdot
.628 .126 .941 r
.36004 .46577 Mdot
1 .5 0 r
.24069 .19477 Mdot
.24069 .19477 Mdot
.20828 .20445 Mdot
.26623 .19148 Mdot
.628 .126 .941 r
.33486 .36888 Mdot
.1976 .49468 Mdot
1 .5 0 r
.51264 .59144 Mdot
.628 .126 .941 r
.54581 .50107 Mdot
.40263 .5623 Mdot
1 .5 0 r
.23941 .19127 Mdot
.628 .126 .941 r
.47393 .51708 Mdot
.33312 .40089 Mdot
.44704 .57186 Mdot
.12535 .43625 Mdot
.44809 .44593 Mdot
.45886 .58137 Mdot
1 .5 0 r
.47173 .5846 Mdot
.53828 .41354 Mdot
.628 .126 .941 r
.32927 .56512 Mdot
1 .5 0 r
.21731 .19716 Mdot
.21731 .19716 Mdot
.628 .126 .941 r
.48431 .51338 Mdot
1 .5 0 r
.51673 .5037 Mdot
.628 .126 .941 r
.4968 .49713 Mdot
1 .5 0 r
.21603 .19366 Mdot
.33142 .2582 Mdot
.628 .126 .941 r
.34839 .41304 Mdot
1 .5 0 r
.21515 .20966 Mdot
.29288 .19352 Mdot
.628 .126 .941 r
.15983 .48076 Mdot
.6825 .52271 Mdot
1 .5 0 r
.21351 .30641 Mdot
.628 .126 .941 r
.29459 .52265 Mdot
.34685 .45482 Mdot
1 .5 0 r
.22054 .19001 Mdot
.21366 .1964 Mdot
.2521 .19633 Mdot
.51825 .58369 Mdot
.3845 .41578 Mdot
.37628 .4737 Mdot
.628 .126 .941 r
.46549 .56733 Mdot
1 .5 0 r
.50346 .60278 Mdot
.22398 .19262 Mdot
.628 .126 .941 r
.3881 .48321 Mdot
.44488 .58653 Mdot
1 .5 0 r
.22998 .20223 Mdot
.628 .126 .941 r
.33256 .26358 Mdot
1 .5 0 r
.24846 .19557 Mdot
.22162 .19536 Mdot
.29224 .23088 Mdot
.628 .126 .941 r
.3915 .54092 Mdot
1 .5 0 r
.24719 .19206 Mdot
.628 .126 .941 r
.65617 .54409 Mdot
.63604 .52777 Mdot
.55185 .51479 Mdot
1 .5 0 r
.24483 .1948 Mdot
.628 .126 .941 r
.35756 .41758 Mdot
.53658 .56942 Mdot
.46526 .55967 Mdot
.54928 .5629 Mdot
.70491 .53059 Mdot
1 .5 0 r
.24355 .19129 Mdot
.24355 .19129 Mdot
.628 .126 .941 r
.59425 .53694 Mdot
.16799 .44635 Mdot
.46353 .59175 Mdot
.47575 .62078 Mdot
.53429 .57225 Mdot
1 .5 0 r
.71526 .58195 Mdot
.30585 .21996 Mdot
.628 .126 .941 r
.47011 .5108 Mdot
.49475 .5786 Mdot
.52006 .62061 Mdot
1 .5 0 r
.2842 .19032 Mdot
.628 .126 .941 r
.51872 .55235 Mdot
.64864 .51356 Mdot
1 .5 0 r
.21904 .19994 Mdot
.628 .126 .941 r
.47984 .53289 Mdot
1 .5 0 r
.23174 .19341 Mdot
.628 .126 .941 r
.32011 .35827 Mdot
.47296 .5393 Mdot
1 .5 0 r
.23046 .1899 Mdot
.54796 .61661 Mdot
.628 .126 .941 r
.43263 .50662 Mdot
.46329 .58411 Mdot
.34764 .39948 Mdot
.46806 .59029 Mdot
1 .5 0 r
.52589 .62263 Mdot
.628 .126 .941 r
.09511 .38001 Mdot
.09511 .38001 Mdot
.48077 .58377 Mdot
.49396 .54166 Mdot
1 .5 0 r
.30117 .41223 Mdot
.56231 .63518 Mdot
.42158 .48309 Mdot
.25006 .18857 Mdot
.31296 .30173 Mdot
.628 .126 .941 r
.27089 .54114 Mdot
1 .5 0 r
.50944 .61879 Mdot
.628 .126 .941 r
.28934 .58962 Mdot
.471 .56373 Mdot
.30683 .22719 Mdot
.49089 .50544 Mdot
.47033 .58956 Mdot
.3683 .44714 Mdot
1 .5 0 r
.22897 .18822 Mdot
.2477 .19132 Mdot
.628 .126 .941 r
.48199 .58933 Mdot
.65126 .52462 Mdot
.44402 .49867 Mdot
1 .5 0 r
.36091 .3691 Mdot
.628 .126 .941 r
.47472 .57622 Mdot
.63061 .54386 Mdot
1 .5 0 r
.22593 .21679 Mdot
.628 .126 .941 r
.55831 .55016 Mdot
1 .5 0 r
.22552 .19723 Mdot
.628 .126 .941 r
.48217 .35901 Mdot
.4219 .50467 Mdot
.47978 .53704 Mdot
.50513 .57912 Mdot
.3514 .42368 Mdot
.39684 .41721 Mdot
1 .5 0 r
.44132 .48195 Mdot
.628 .126 .941 r
.48532 .5823 Mdot
.47193 .61467 Mdot
.0862 .36535 Mdot
.4261 .60161 Mdot
.49738 .60161 Mdot
1 .5 0 r
.56865 .60161 Mdot
.23695 .18717 Mdot
.26259 .18386 Mdot
.628 .126 .941 r
.48982 .63387 Mdot
1 .5 0 r
.47747 .53987 Mdot
.50905 .60138 Mdot
.628 .126 .941 r
.58703 .5852 Mdot
.71715 .54634 Mdot
1 .5 0 r
.46436 .52686 Mdot
.628 .126 .941 r
.31087 .32599 Mdot
.16637 .46846 Mdot
.48359 .49436 Mdot
.57335 .54287 Mdot
1 .5 0 r
.60445 .64002 Mdot
.628 .126 .941 r
.55354 .54605 Mdot
.69613 .54605 Mdot
1 .5 0 r
.45621 .5298 Mdot
.628 .126 .941 r
.67633 .54923 Mdot
.39668 .59452 Mdot
.6436 .54918 Mdot
.62379 .55236 Mdot
.4743 .55878 Mdot
.5255 .60736 Mdot
.34154 .28342 Mdot
.49995 .55548 Mdot
.4473 .61378 Mdot
1 .5 0 r
.26477 .18295 Mdot
.628 .126 .941 r
.44184 .51332 Mdot
1 .5 0 r
.53814 .53587 Mdot
.25076 .18598 Mdot
.24406 .20218 Mdot
.628 .126 .941 r
.65473 .51962 Mdot
.42001 .59407 Mdot
.50473 .56167 Mdot
1 .5 0 r
.40784 .50978 Mdot
.628 .126 .941 r
.28682 .29909 Mdot
.4333 .49671 Mdot
.42564 .58418 Mdot
.64681 .53234 Mdot
.56141 .5906 Mdot
.29408 .19204 Mdot
1 .5 0 r
.53584 .53871 Mdot
.628 .126 .941 r
.46355 .60998 Mdot
1 .5 0 r
.64587 .48345 Mdot
.23439 .19176 Mdot
.628 .126 .941 r
.10778 .41852 Mdot
.66369 .55786 Mdot
.61179 .53512 Mdot
.52713 .51232 Mdot
1 .5 0 r
.23893 .1881 Mdot
.27752 .18803 Mdot
.628 .126 .941 r
.61592 .56718 Mdot
.49217 .58009 Mdot
.70674 .54443 Mdot
.18161 .49251 Mdot
.51094 .58322 Mdot
1 .5 0 r
.23656 .19085 Mdot
.23656 .19085 Mdot
.628 .126 .941 r
.32833 .5798 Mdot
.5233 .55711 Mdot
.45077 .61865 Mdot
1 .5 0 r
.2413 .19699 Mdot
.41282 .47258 Mdot
.628 .126 .941 r
.50241 .56661 Mdot
.3168 .34931 Mdot
.63828 .57304 Mdot
.6838 .56655 Mdot
.61893 .54055 Mdot
1 .5 0 r
.24693 .18705 Mdot
.628 .126 .941 r
.60581 .52752 Mdot
.66426 .52428 Mdot
.37322 .4237 Mdot
.52033 .58584 Mdot
1 .5 0 r
.51985 .62151 Mdot
.51275 .61815 Mdot
.24564 .18352 Mdot
.41864 .35216 Mdot
.628 .126 .941 r
.37838 .44946 Mdot
.28686 .4981 Mdot
.44931 .48513 Mdot
.47566 .45594 Mdot
.36353 .58891 Mdot
.49291 .62134 Mdot
.57773 .58891 Mdot
1 .5 0 r
.23873 .18994 Mdot
.628 .126 .941 r
.34608 .41372 Mdot
.73838 .66339 Mdot
.29756 .56922 Mdot
.49789 .63734 Mdot
1 .5 0 r
.23745 .18642 Mdot
.628 .126 .941 r
.29428 .28042 Mdot
.49176 .56262 Mdot
.3679 .57554 Mdot
.44756 .397 Mdot
.60747 .55266 Mdot
.55407 .63695 Mdot
.63136 .63684 Mdot
.52013 .57816 Mdot
.57192 .59114 Mdot
1 .5 0 r
.23874 .20159 Mdot
.628 .126 .941 r
.45338 .63965 Mdot
.35947 .32796 Mdot
.44128 .49992 Mdot
.29461 .24662 Mdot
.15435 .50623 Mdot
.54872 .6035 Mdot
.40701 .48658 Mdot
1 .5 0 r
.57395 .63591 Mdot
.2418 .18459 Mdot
.45191 .50599 Mdot
.628 .126 .941 r
.49585 .59684 Mdot
.64553 .58061 Mdot
.27909 .23633 Mdot
.50746 .65192 Mdot
1 .5 0 r
.25346 .18431 Mdot
.63201 .54797 Mdot
.62894 .26866 Mdot
.628 .126 .941 r
.46782 .603 Mdot
.48107 .56073 Mdot
.51993 .57047 Mdot
.6111 .55748 Mdot
.39526 .60932 Mdot
1 .5 0 r
.29621 .2163 Mdot
.628 .126 .941 r
.40495 .3234 Mdot
1 .5 0 r
.35168 .41759 Mdot
.628 .126 .941 r
.49325 .52477 Mdot
.61611 .57349 Mdot
.67447 .56044 Mdot
1 .5 0 r
.54614 .41097 Mdot
.628 .126 .941 r
.46599 .57012 Mdot
.51158 .56363 Mdot
.51734 .61885 Mdot
.66738 .55708 Mdot
.63993 .59264 Mdot
.52934 .57309 Mdot
.56102 .63481 Mdot
.39234 .58278 Mdot
.09546 .39104 Mdot
1 .5 0 r
.44495 .51449 Mdot
.628 .126 .941 r
.53472 .60871 Mdot
1 .5 0 r
.24052 .19272 Mdot
.628 .126 .941 r
.38003 .43309 Mdot
1 .5 0 r
.42564 .42659 Mdot
.58599 .5923 Mdot
.628 .126 .941 r
.63832 .56955 Mdot
.50178 .5435 Mdot
.49458 .59549 Mdot
.5133 .65398 Mdot
1 .5 0 r
.25199 .18262 Mdot
.628 .126 .941 r
.38893 .59196 Mdot
.34551 .40991 Mdot
.38393 .4554 Mdot
1 .5 0 r
.25071 .17909 Mdot
.52492 .5886 Mdot
.34752 .21152 Mdot
.628 .126 .941 r
.52425 .61454 Mdot
1 .5 0 r
.60186 .62424 Mdot
.628 .126 .941 r
.69359 .57548 Mdot
1 .5 0 r
.24962 .18538 Mdot
.46047 .47141 Mdot
.628 .126 .941 r
.64087 .57862 Mdot
1 .5 0 r
.58131 .65338 Mdot
.628 .126 .941 r
.54241 .64363 Mdot
1 .5 0 r
.34 .18849 Mdot
.628 .126 .941 r
.41445 .45829 Mdot
.51099 .5363 Mdot
.50331 .62407 Mdot
1 .5 0 r
.25526 .17542 Mdot
.628 .126 .941 r
.23797 .49399 Mdot
.50984 .59801 Mdot
.63377 .57525 Mdot
.60687 .64027 Mdot
.55643 1.00435 Mdot
.52934 .5752 Mdot
.71812 .56869 Mdot
.52339 .51012 Mdot
.63291 .59139 Mdot
.523 .49049 Mdot
1 .5 0 r
.58689 .57828 Mdot
.32488 .19782 Mdot
.628 .126 .941 r
.39934 .46768 Mdot
.54058 .61073 Mdot
.59901 .59767 Mdot
.56615 .59761 Mdot
.62476 .59436 Mdot
1 .5 0 r
.55894 .64964 Mdot
.628 .126 .941 r
.65724 .5748 Mdot
1 .5 0 r
.41153 .43166 Mdot
.54606 .591 Mdot
.628 .126 .941 r
.67676 .55198 Mdot
.53482 .43485 Mdot
.50003 .57788 Mdot
.34607 .38595 Mdot
.18124 .54205 Mdot
.39056 .44117 Mdot
1 .5 0 r
.26301 .21996 Mdot
.628 .126 .941 r
.39766 .3239 Mdot
.6221 .57759 Mdot
.66776 .57109 Mdot
1 .5 0 r
.24943 .18722 Mdot
.628 .126 .941 r
.44658 .48634 Mdot
.58164 .60995 Mdot
1 .5 0 r
.25399 .18355 Mdot
.628 .126 .941 r
.46406 .54141 Mdot
.63231 .61949 Mdot
.38695 .44049 Mdot
1 .5 0 r
.5031 .49574 Mdot
.41733 .55425 Mdot
.628 .126 .941 r
.52117 .58028 Mdot
.51396 .63233 Mdot
1 .5 0 r
.29165 .18977 Mdot
.628 .126 .941 r
.43732 .49562 Mdot
.35972 .43049 Mdot
.65108 .55739 Mdot
.578 .66476 Mdot
1 .5 0 r
.25855 .17987 Mdot
.628 .126 .941 r
.18863 .51171 Mdot
.45453 .59632 Mdot
.62378 .60283 Mdot
1 .5 0 r
.58387 .66465 Mdot
.628 .126 .941 r
.68947 .53769 Mdot
.61061 .58975 Mdot
.59792 .54088 Mdot
1 .5 0 r
.2765 .19912 Mdot
.49338 .54082 Mdot
.57032 .63195 Mdot
.628 .126 .941 r
.56964 .65793 Mdot
.60985 .55047 Mdot
1 .5 0 r
.56416 .55698 Mdot
.628 .126 .941 r
.5507 .58953 Mdot
.54348 .6416 Mdot
.22925 .24773 Mdot
1 .5 0 r
.25618 .18263 Mdot
.628 .126 .941 r
.37016 .42674 Mdot
.37016 .42674 Mdot
.29397 .25417 Mdot
.56888 .61865 Mdot
.667 .58936 Mdot
.56244 .5893 Mdot
.65278 .58262 Mdot
.11313 .44577 Mdot
1 .5 0 r
.40658 .42949 Mdot
.628 .126 .941 r
.52203 .56623 Mdot
.59323 .60204 Mdot
.43245 .3707 Mdot
.41176 .45535 Mdot
.54647 .61489 Mdot
.61816 .61489 Mdot
.63067 .65397 Mdot
.48807 .57251 Mdot
.64357 .59193 Mdot
1 .5 0 r
.26422 .18157 Mdot
.45621 .44534 Mdot
.628 .126 .941 r
.57217 .54629 Mdot
.39875 .3313 Mdot
.49287 .57874 Mdot
.30211 .19765 Mdot
.22608 .52006 Mdot
.46188 .43539 Mdot
.40269 .47447 Mdot
.57112 .55263 Mdot
.61683 .54611 Mdot
.61635 .58194 Mdot
.55023 .62748 Mdot
.52531 .49383 Mdot
.46611 .53291 Mdot
.0958 .41234 Mdot
1 .5 0 r
.58749 .6696 Mdot
.628 .126 .941 r
.45253 .50016 Mdot
.69897 .59788 Mdot
1 .5 0 r
.59356 .67932 Mdot
.2675 .17435 Mdot
.628 .126 .941 r
.56737 .66298 Mdot
.64612 .60103 Mdot
1 .5 0 r
.26641 .18066 Mdot
.26641 .18066 Mdot
.628 .126 .941 r
.34344 .27187 Mdot
.4065 .43151 Mdot
.63227 .61395 Mdot
1 .5 0 r
.50181 .6172 Mdot
.26621 .17081 Mdot
.628 .126 .941 r
.22846 .52912 Mdot
1 .5 0 r
.59819 .67574 Mdot
.40543 .43784 Mdot
.628 .126 .941 r
.51327 .66265 Mdot
1 .5 0 r
.585 .66265 Mdot
.628 .126 .941 r
.39849 .44429 Mdot
.43027 .5062 Mdot
1 .5 0 r
.57807 .66911 Mdot
.628 .126 .941 r
.54639 .5517 Mdot
.73514 .58103 Mdot
.55198 .59726 Mdot
.37122 .43427 Mdot
1 .5 0 r
.4863 .60698 Mdot
.628 .126 .941 r
.67554 .60046 Mdot
.37776 .40814 Mdot
.47888 .64929 Mdot
1 .5 0 r
.59012 .62322 Mdot
.628 .126 .941 r
.17435 .47325 Mdot
.53166 .5808 Mdot
.54399 .61007 Mdot
.65475 .61985 Mdot
1 .5 0 r
.33286 .27758 Mdot
.38487 .29062 Mdot
.628 .126 .941 r
.53657 .65239 Mdot
.69405 .58394 Mdot
.60169 .61316 Mdot
.55594 .61968 Mdot
.69301 .59029 Mdot
.42695 .45985 Mdot
1 .5 0 r
.28033 .17945 Mdot
.628 .126 .941 r
.37474 .43697 Mdot
.58185 .56084 Mdot
.37839 .62598 Mdot
.60093 .57382 Mdot
1 .5 0 r
.32521 .18909 Mdot
.628 .126 .941 r
.34833 .41077 Mdot
.43648 .64874 Mdot
.62627 .60636 Mdot
.67877 .58354 Mdot
.67184 .59001 Mdot
.14416 .50193 Mdot
.54014 .65515 Mdot
.47636 .52143 Mdot
.56645 .61598 Mdot
1 .5 0 r
.25214 .18555 Mdot
.628 .126 .941 r
.61828 .61918 Mdot
.6708 .59636 Mdot
.57204 .66157 Mdot
.39262 .39089 Mdot
.56654 .56044 Mdot
1 .5 0 r
.258 .18541 Mdot
.628 .126 .941 r
.3852 .43321 Mdot
.44378 .42011 Mdot
.44282 .49185 Mdot
.55807 .60912 Mdot
.5441 .6776 Mdot
.51933 .55363 Mdot
.24446 .58292 Mdot
.50612 .54052 Mdot
.58274 .66771 Mdot
1 .5 0 r
.60877 .67423 Mdot
.35365 .20455 Mdot
.628 .126 .941 r
.60327 .57308 Mdot
.67441 .59911 Mdot
.57591 .61862 Mdot
1 .5 0 r
.60801 .63488 Mdot
.26128 .17818 Mdot
.32539 .26625 Mdot
.628 .126 .941 r
.57601 .56306 Mdot
.49773 .53365 Mdot
.48472 .53039 Mdot
1 .5 0 r
.52887 .62166 Mdot
.628 .126 .941 r
.67299 .58578 Mdot
1 .5 0 r
.49638 .58572 Mdot
.628 .126 .941 r
.11298 .42582 Mdot
.16985 .56609 Mdot
.58054 .61503 Mdot
.44567 .3996 Mdot
.62548 .6247 Mdot
.29313 .54961 Mdot
.53996 .64748 Mdot
.57949 .62138 Mdot
1 .5 0 r
.59877 .64422 Mdot
.628 .126 .941 r
.39948 .38642 Mdot
.65161 .57565 Mdot
.56513 .67021 Mdot
.29253 .52007 Mdot
.57843 .62774 Mdot
.55192 .65711 Mdot
1 .5 0 r
.5712 .67995 Mdot
.628 .126 .941 r
.41074 .42206 Mdot
1 .5 0 r
.54478 .65374 Mdot
.26348 .17726 Mdot
.628 .126 .941 r
.61065 .58842 Mdot
.74132 .58516 Mdot
.4036 .41867 Mdot
.51981 .51983 Mdot
.55018 .68952 Mdot
.48682 .51977 Mdot
.30406 .99623 Mdot
1 .5 0 r
.60236 .64699 Mdot
.628 .126 .941 r
.63497 .62735 Mdot
.53157 .5196 Mdot
.50457 .58487 Mdot
.43898 .60445 Mdot
.59475 .67952 Mdot
.53572 .67294 Mdot
.12654 .47052 Mdot
.60112 .64351 Mdot
.48469 .53247 Mdot
.54932 .5847 Mdot
.5744 .66304 Mdot
.34318 .34309 Mdot
.68611 .59117 Mdot
.34394 .26142 Mdot
1 .5 0 r
.46501 .48992 Mdot
.628 .126 .941 r
.59476 .55847 Mdot
.28538 .21892 Mdot
.53717 .44416 Mdot
.46433 .51598 Mdot
1 .5 0 r
.56032 .66614 Mdot
.4733 .31025 Mdot
.628 .126 .941 r
.45111 .50286 Mdot
.54035 .66935 Mdot
.62573 .6367 Mdot
1 .5 0 r
.56621 .66603 Mdot
.60528 .67582 Mdot
.628 .126 .941 r
.54769 .5615 Mdot
.51488 .5713 Mdot
.64562 .56803 Mdot
.48265 .48956 Mdot
1 .5 0 r
.53283 .64628 Mdot
.628 .126 .941 r
.37246 .39808 Mdot
1 .5 0 r
.4815 .55154 Mdot
.628 .126 .941 r
.57123 .68214 Mdot
.5585 .63311 Mdot
.28232 .24775 Mdot
.69582 .60366 Mdot
.17355 .53503 Mdot
.48139 .48605 Mdot
.69544 .58396 Mdot
.32563 .35531 Mdot
.56304 .68514 Mdot
.58939 .64589 Mdot
1 .5 0 r
.26788 .17541 Mdot
.48554 .51835 Mdot
.65445 .59674 Mdot
.628 .126 .941 r
.39364 .52156 Mdot
1 .5 0 r
.49239 .44637 Mdot
.628 .126 .941 r
.55513 .64235 Mdot
.56864 .60969 Mdot
.50426 .51164 Mdot
.41284 .47892 Mdot
.5031 .57365 Mdot
.48283 .62264 Mdot
.57405 .64551 Mdot
.63275 .63239 Mdot
1 .5 0 r
.58641 .67485 Mdot
.628 .126 .941 r
.31639 .30892 Mdot
.55436 .60293 Mdot
.57415 .58987 Mdot
.1371 .48854 Mdot
1 .5 0 r
.50203 .58001 Mdot
.628 .126 .941 r
.42914 .65188 Mdot
1 .5 0 r
.56585 .6485 Mdot
.628 .126 .941 r
.37883 .42954 Mdot
.50869 .49816 Mdot
1 .5 0 r
.56566 .63865 Mdot
.628 .126 .941 r
.34753 .27585 Mdot
1 .5 0 r
.4268 .16788 Mdot
.628 .126 .941 r
.49826 .69071 Mdot
.42854 .50112 Mdot
.55794 .60569 Mdot
.48725 .48799 Mdot
.49208 .61544 Mdot
.55679 .66773 Mdot
1 .5 0 r
.42863 .44545 Mdot
.28074 .18053 Mdot
.27378 .18699 Mdot
.628 .126 .941 r
.47662 .67072 Mdot
.5679 .6936 Mdot
.60798 .6315 Mdot
1 .5 0 r
.27358 .17712 Mdot
.628 .126 .941 r
.30497 .27517 Mdot
.15766 .52685 Mdot
.55563 .60857 Mdot
.1449 .47776 Mdot
.29608 .42547 Mdot
.63996 .63793 Mdot
1 .5 0 r
.25965 .19005 Mdot
.628 .126 .941 r
.50241 .60186 Mdot
.52124 .6607 Mdot
.36793 .3599 Mdot
1 .5 0 r
.28513 .16696 Mdot
.41603 .16369 Mdot
.628 .126 .941 r
.58655 .62136 Mdot
.31681 .21919 Mdot
.51535 .53958 Mdot
.57332 .60823 Mdot
.59312 .59515 Mdot
.67815 .59842 Mdot
1 .5 0 r
.30356 .20605 Mdot
.628 .126 .941 r
.4567 .49702 Mdot
.61226 .60817 Mdot
.55216 .67351 Mdot
.60444 .63089 Mdot
1 .5 0 r
.57787 .66032 Mdot
.628 .126 .941 r
.72281 .58839 Mdot
.45495 .52947 Mdot
.5139 .5262 Mdot
.65624 .62424 Mdot
.32555 .36913 Mdot
.52656 .50974 Mdot
.55748 .64381 Mdot
1 .5 0 r
.26882 .18266 Mdot
.43262 .16958 Mdot
.628 .126 .941 r
.60319 .6274 Mdot
1 .5 0 r
.35269 .248 Mdot
.628 .126 .941 r
.57643 .64697 Mdot
.603 .61753 Mdot
.71463 .59137 Mdot
1 .5 0 r
.28146 .16617 Mdot
.39067 .31988 Mdot
.628 .126 .941 r
.6292 .56836 Mdot
.50916 .70894 Mdot
.69377 .61082 Mdot
.53555 .66964 Mdot
.54231 .65329 Mdot
.61481 .61731 Mdot
.55469 .68267 Mdot
1 .5 0 r
.27908 .16894 Mdot
.628 .126 .941 r
.3364 .26374 Mdot
.39924 .46001 Mdot
.44322 .5974 Mdot
.56793 .5745 Mdot
1 .5 0 r
.65929 .5974 Mdot
.628 .126 .941 r
.58659 .62352 Mdot
1 .5 0 r
.36259 .21453 Mdot
.628 .126 .941 r
.40513 .45989 Mdot
.55305 .65945 Mdot
1 .5 0 r
.54 .65618 Mdot
.60168 .42711 Mdot
.628 .126 .941 r
.47599 .52199 Mdot
.55962 .63322 Mdot
1 .5 0 r
.28387 .17513 Mdot
.628 .126 .941 r
.51496 .52193 Mdot
.61116 .67242 Mdot
.63775 .64298 Mdot
1 .5 0 r
.2769 .1816 Mdot
.628 .126 .941 r
.18001 .54471 Mdot
.61174 .5807 Mdot
.13435 .50539 Mdot
.66957 .63954 Mdot
.69598 .60022 Mdot
.44146 .50854 Mdot
.52607 .54781 Mdot
.63003 .60998 Mdot
.55122 .62634 Mdot
.61021 .62307 Mdot
1 .5 0 r
.62229 .69833 Mdot
.628 .126 .941 r
.60325 .62956 Mdot
.60325 .62956 Mdot
.59725 .56405 Mdot
.64851 .64914 Mdot
.58304 .6229 Mdot
.34928 .44612 Mdot
.57559 .66539 Mdot
.18465 .48533 Mdot
.19073 .49509 Mdot
.57473 .68165 Mdot
.58101 .70129 Mdot
.64775 .60964 Mdot
.51118 .5114 Mdot
.6998 .61286 Mdot
1 .5 0 r
.54871 .61935 Mdot
.628 .126 .941 r
.58769 .6193 Mdot
.68588 .62584 Mdot
1 .5 0 r
.60656 .67821 Mdot
.628 .126 .941 r
.52095 .71095 Mdot
1 .5 0 r
.27782 .17712 Mdot
.628 .126 .941 r
.38086 .31134 Mdot
.48292 .51759 Mdot
.25198 .61247 Mdot
.61286 .57646 Mdot
.63831 .60914 Mdot
.57252 .62878 Mdot
.403 .54033 Mdot
.55975 .57961 Mdot
.70343 .61563 Mdot
.60377 .71713 Mdot
.4236 .44532 Mdot
.63067 .64177 Mdot
1 .5 0 r
.28891 .20296 Mdot
.628 .126 .941 r
.27197 .48782 Mdot
.69628 .61224 Mdot
1 .5 0 r
.28241 .17342 Mdot
.628 .126 .941 r
.43337 .64493 Mdot
1 .5 0 r
.68816 .6809 Mdot
.628 .126 .941 r
.57814 .55313 Mdot
.56411 .6219 Mdot
.32314 .9952 Mdot
1 .5 0 r
.28132 .17975 Mdot
.628 .126 .941 r
.68198 .60547 Mdot
.64908 .61529 Mdot
1 .5 0 r
.31403 .16003 Mdot
.628 .126 .941 r
.53159 .53003 Mdot
1 .5 0 r
.28632 .19585 Mdot
.628 .126 .941 r
.33085 .29738 Mdot
.55008 .56922 Mdot
.68074 .60197 Mdot
.47971 .41522 Mdot
1 .5 0 r
.60215 .57243 Mdot
.28592 .17605 Mdot
.28592 .17605 Mdot
.628 .126 .941 r
.77136 .64116 Mdot
1 .5 0 r
.43866 .49371 Mdot
.5224 .60507 Mdot
.628 .126 .941 r
.6463 .65421 Mdot
.73874 .60507 Mdot
.14951 .51985 Mdot
.55463 .6214 Mdot
.57351 .68036 Mdot
.6645 .73932 Mdot
1 .5 0 r
.29161 .16601 Mdot
.628 .126 .941 r
.47457 .69996 Mdot
1 .5 0 r
.28463 .17249 Mdot
.28463 .17249 Mdot
.45308 .32318 Mdot
.31686 .1888 Mdot
.628 .126 .941 r
.6649 .63761 Mdot
.67149 .61134 Mdot
.52753 .56542 Mdot
.57352 .55887 Mdot
1 .5 0 r
.54592 .66043 Mdot
.628 .126 .941 r
.28285 .20497 Mdot
.67692 .64727 Mdot
.15947 .55214 Mdot
.68314 .60123 Mdot
.32514 .37508 Mdot
.55851 .57824 Mdot
.62969 .65033 Mdot
.59657 .65027 Mdot
.66242 .63061 Mdot
.5775 .5814 Mdot
.62912 .62067 Mdot
.60927 .63378 Mdot
.76035 .61739 Mdot
1 .5 0 r
.81168 .7026 Mdot
.29964 .22079 Mdot
.628 .126 .941 r
.3316 .28306 Mdot
.61537 .64355 Mdot
1 .5 0 r
.56259 .66649 Mdot
.628 .126 .941 r
.70108 .61078 Mdot
1 .5 0 r
.63426 .70254 Mdot
.28685 .17156 Mdot
.628 .126 .941 r
.51203 .4993 Mdot
.64036 .71232 Mdot
1 .5 0 r
.5438 .55167 Mdot
.628 .126 .941 r
.70022 .62706 Mdot
.50486 .4959 Mdot
1 .5 0 r
.5746 .67616 Mdot
.29254 .16152 Mdot
.628 .126 .941 r
.38891 .31229 Mdot
.43153 .55811 Mdot
.29282 .60394 Mdot
.6212 .57772 Mdot
1 .5 0 r
.58778 .62361 Mdot
.628 .126 .941 r
.63941 .66289 Mdot
1 .5 0 r
.63893 .69895 Mdot
.28446 .17434 Mdot
.37504 .26941 Mdot
.628 .126 .941 r
.15562 .48576 Mdot
.55475 .56772 Mdot
.57461 .5546 Mdot
.11666 .42997 Mdot
.54196 .51848 Mdot
.60687 .57094 Mdot
.57975 .6365 Mdot
1 .5 0 r
.56018 .60366 Mdot
.628 .126 .941 r
.65173 .62661 Mdot
.57471 .98723 Mdot
.64379 .70524 Mdot
1 .5 0 r
.62471 .63633 Mdot
.628 .126 .941 r
.31833 .45923 Mdot
.30844 .68213 Mdot
.66987 .64606 Mdot
1 .5 0 r
.28208 .17712 Mdot
.628 .126 .941 r
.39448 .60338 Mdot
1 .5 0 r
.597 .67224 Mdot
.628 .126 .941 r
.59148 .57053 Mdot
.57646 .71153 Mdot
.2056 .44587 Mdot
1 .5 0 r
.51813 .63278 Mdot
.628 .126 .941 r
.64944 .6295 Mdot
.70836 .61633 Mdot
.50611 .50149 Mdot
.71447 .62611 Mdot
1 .5 0 r
.34503 .25219 Mdot
.628 .126 .941 r
.21759 .45552 Mdot
.22853 .5932 Mdot
1 .5 0 r
.29956 .16678 Mdot
.628 .126 .941 r
.12462 .48491 Mdot
.40715 .46524 Mdot
.58093 .69804 Mdot
.68707 .61604 Mdot
.478 .51759 Mdot
.44533 .48145 Mdot
.4778 .50769 Mdot
.54323 .52409 Mdot
.61448 .59625 Mdot
.60624 .72089 Mdot
1 .5 0 r
.51832 .39939 Mdot
.628 .126 .941 r
.71182 .6092 Mdot
1 .5 0 r
.27731 .18269 Mdot
.628 .126 .941 r
.70484 .61571 Mdot
.5919 .71412 Mdot
.6777 .68132 Mdot
1 .5 0 r
.65017 .72714 Mdot
.628 .126 .941 r
.32566 .41869 Mdot
1 .5 0 r
.63089 .64829 Mdot
.628 .126 .941 r
.67646 .67782 Mdot
.65707 .65485 Mdot
.53373 .52356 Mdot
1 .5 0 r
.61664 .7073 Mdot
.628 .126 .941 r
.46741 .52344 Mdot
.50668 .53328 Mdot
.47933 .58901 Mdot
.13196 .51019 Mdot
.55138 .57911 Mdot
.66921 .60864 Mdot
.63575 .65458 Mdot
.62169 .72349 Mdot
.62169 .72349 Mdot
1 .5 0 r
.3839 .30996 Mdot
.628 .126 .941 r
.25686 .47732 Mdot
.22243 .59546 Mdot
.47923 .5232 Mdot
.6024 .64463 Mdot
.6538 .72995 Mdot
.59639 .57893 Mdot
.72684 .64785 Mdot
1 .5 0 r
.67398 .67082 Mdot
.628 .126 .941 r
.10494 .46401 Mdot
.45993 .44432 Mdot
.29969 .61164 Mdot
.73937 .62143 Mdot
1 .5 0 r
.32402 .21765 Mdot
.628 .126 .941 r
.43994 .39161 Mdot
.5738 .69687 Mdot
.52947 .5491 Mdot
1 .5 0 r
.56778 .63116 Mdot
.628 .126 .941 r
.41869 .45714 Mdot
.42887 .67706 Mdot
.63889 .69348 Mdot
.52908 .52929 Mdot
.28275 .23043 Mdot
1 .5 0 r
.58545 .68675 Mdot
.628 .126 .941 r
.61873 .63089 Mdot
.32795 .24014 Mdot
.63115 .66038 Mdot
.75631 .6374 Mdot
.77572 .66038 Mdot
.65764 .62092 Mdot
1 .5 0 r
.63678 .70629 Mdot
.28874 .17434 Mdot
.628 .126 .941 r
.3979 .36477 Mdot
.59729 .68653 Mdot
.48115 .50261 Mdot
.55101 .6832 Mdot
.67667 .6241 Mdot
.51637 .30225 Mdot
.48095 .4927 Mdot
.60953 .70613 Mdot
.58925 .69945 Mdot
.22853 .6173 Mdot
.59003 .6173 Mdot
1 .5 0 r
.62138 .70592 Mdot
.628 .126 .941 r
.14999 .54166 Mdot
.29225 .66634 Mdot
1 .5 0 r
.31195 .15392 Mdot
.628 .126 .941 r
.4459 .45937 Mdot
.71331 .61702 Mdot
.50511 .94547 Mdot
.58208 .57427 Mdot
.55442 .67609 Mdot
1 .5 0 r
.35038 .18005 Mdot
.628 .126 .941 r
.66488 .7483 Mdot
1 .5 0 r
.29096 .17341 Mdot
.628 .126 .941 r
.50986 .51831 Mdot
.60043 .60366 Mdot
1 .5 0 r
.29687 .17327 Mdot
.628 .126 .941 r
.52161 .57404 Mdot
1 .5 0 r
.67189 .61997 Mdot
.628 .126 .941 r
.685 .62326 Mdot
1 .5 0 r
.30957 .1567 Mdot
.628 .126 .941 r
.47607 .48851 Mdot
.75666 .64948 Mdot
1 .5 0 r
.65628 .73151 Mdot
.30168 .17948 Mdot
.30799 .1992 Mdot
.628 .126 .941 r
.57113 .68217 Mdot
.69638 .65917 Mdot
.69619 .64926 Mdot
.62337 .6854 Mdot
1 .5 0 r
.45519 .45206 Mdot
.628 .126 .941 r
.63726 .60649 Mdot
1 .5 0 r
.67542 .18913 Mdot
.628 .126 .941 r
.56521 .56043 Mdot
.72204 .63601 Mdot
1 .5 0 r
.30719 .15948 Mdot
.30719 .15948 Mdot
.63639 .62281 Mdot
.628 .126 .941 r
.72816 .64581 Mdot
1 .5 0 r
.34466 .25792 Mdot
.628 .126 .941 r
.32115 .51419 Mdot
.66787 .6555 Mdot
1 .5 0 r
.29909 .17234 Mdot
.628 .126 .941 r
.62737 .70803 Mdot
.61407 .69483 Mdot
1 .5 0 r
.65254 .72102 Mdot
.2978 .16876 Mdot
.2978 .16876 Mdot
.628 .126 .941 r
.63924 .70782 Mdot
.7388 .64208 Mdot
.67256 .65189 Mdot
.64536 .71763 Mdot
1 .5 0 r
.30371 .16862 Mdot
.30322 .20478 Mdot
.628 .126 .941 r
.7122 .61567 Mdot
.75106 .66169 Mdot
.27173 .53995 Mdot
.68462 .66158 Mdot
.67782 .67802 Mdot
1 .5 0 r
.30893 .19471 Mdot
.628 .126 .941 r
.70435 .63852 Mdot
.41415 .66476 Mdot
1 .5 0 r
.60506 .65819 Mdot
.68279 .75024 Mdot
.628 .126 .941 r
.42949 .47731 Mdot
.53249 .64827 Mdot
.67045 .66471 Mdot
.46933 .94088 Mdot
.11379 .41472 Mdot
.39635 .42123 Mdot
.6762 .65468 Mdot
1 .5 0 r
.29412 .16798 Mdot
.28732 .18442 Mdot
.63617 .67107 Mdot
.59322 .41453 Mdot
.628 .126 .941 r
.76766 .65786 Mdot
1 .5 0 r
.66106 .73015 Mdot
.29302 .17434 Mdot
.628 .126 .941 r
.45338 .48675 Mdot
.53093 .5689 Mdot
.72093 .63467 Mdot
1 .5 0 r
.29894 .17419 Mdot
.628 .126 .941 r
.61365 .73323 Mdot
1 .5 0 r
.31165 .15761 Mdot
.62638 .71668 Mdot
.628 .126 .941 r
.66605 .68044 Mdot
.53609 .52908 Mdot
.3893 .67381 Mdot
1 .5 0 r
.6853 .69355 Mdot
.39493 .22969 Mdot
.65157 .72968 Mdot
.628 .126 .941 r
.69853 .64081 Mdot
.63826 .71647 Mdot
1 .5 0 r
.717 .7362 Mdot
.628 .126 .941 r
.67112 .69668 Mdot
1 .5 0 r
.69699 .68341 Mdot
.54124 .48925 Mdot
.628 .126 .941 r
.72986 .66362 Mdot
.72336 .63395 Mdot
.65675 .68988 Mdot
1 .5 0 r
.33403 .15345 Mdot
.628 .126 .941 r
.50711 .50552 Mdot
.54601 .55158 Mdot
1 .5 0 r
.67582 .69306 Mdot
.31341 .19286 Mdot
.628 .126 .941 r
.60251 .70941 Mdot
1 .5 0 r
.33877 .21576 Mdot
.3128 .16303 Mdot
.628 .126 .941 r
.76696 .6764 Mdot
.60193 .67963 Mdot
.60825 .69938 Mdot
.74033 .64996 Mdot
.54932 .60048 Mdot
1 .5 0 r
.66069 .64656 Mdot
.3045 .16596 Mdot
.628 .126 .941 r
.76555 .66296 Mdot
1 .5 0 r
.6853 .75183 Mdot
.29748 .17248 Mdot
.628 .126 .941 r
.50302 .54106 Mdot
.69173 .71551 Mdot
1 .5 0 r
.64553 .7221 Mdot
.628 .126 .941 r
.35593 .67596 Mdot
.62588 .68913 Mdot
1 .5 0 r
.69865 .64299 Mdot
.628 .126 .941 r
.78377 .68249 Mdot
1 .5 0 r
.31613 .15573 Mdot
.628 .126 .941 r
.67755 .71865 Mdot
.61801 .71201 Mdot
1 .5 0 r
.45145 .33336 Mdot
.628 .126 .941 r
.76327 .66587 Mdot
.59087 .72178 Mdot
.78254 .67898 Mdot
.62522 .59333 Mdot
.67046 .65917 Mdot
.78236 .66905 Mdot
1 .5 0 r
.58465 .64595 Mdot
.628 .126 .941 r
.59681 .72168 Mdot
1 .5 0 r
.69557 .72826 Mdot
.628 .126 .941 r
.64935 .73485 Mdot
.78752 .75131 Mdot
.31375 .15852 Mdot
.69501 .69847 Mdot
1 .5 0 r
.64197 .72152 Mdot
.628 .126 .941 r
.37757 .26375 Mdot
.18197 .59633 Mdot
1 .5 0 r
.6554 .67866 Mdot
.628 .126 .941 r
.66778 .64221 Mdot
.67411 .66197 Mdot
.67314 .73443 Mdot
1 .5 0 r
.34348 .22388 Mdot
.42086 .35233 Mdot
.628 .126 .941 r
.74643 .65204 Mdot
1 .5 0 r
.31748 .17111 Mdot
.36254 .22703 Mdot
.628 .126 .941 r
.78481 .66834 Mdot
1 .5 0 r
.30325 .17419 Mdot
.33537 .23678 Mdot
.628 .126 .941 r
.5286 .57606 Mdot
1 .5 0 r
.679 .66829 Mdot
.628 .126 .941 r
.6386 .73087 Mdot
.75104 .70452 Mdot
.63793 .75717 Mdot
1 .5 0 r
.32183 .21358 Mdot
.44449 .40794 Mdot
.43797 .37822 Mdot
.628 .126 .941 r
.61321 .58577 Mdot
1 .5 0 r
.47866 .26944 Mdot
.628 .126 .941 r
.67124 .63507 Mdot
.67708 .69108 Mdot
.67689 .68114 Mdot
.74943 .68114 Mdot
.71662 .64484 Mdot
.77553 .67779 Mdot
.42306 .89854 Mdot
1 .5 0 r
.6473 .3812 Mdot
.628 .126 .941 r
.77535 .66785 Mdot
.7622 .66455 Mdot
1 .5 0 r
.69482 .74688 Mdot
.67467 .75012 Mdot
.628 .126 .941 r
.28885 .47986 Mdot
.78745 .67757 Mdot
1 .5 0 r
.56337 .59172 Mdot
.32407 .21266 Mdot
.63574 .58178 Mdot
.628 .126 .941 r
.35163 .59161 Mdot
.77921 .6806 Mdot
.71328 .65417 Mdot
.67968 .70032 Mdot
.56669 .76294 Mdot
1 .5 0 r
.65386 .65747 Mdot
.628 .126 .941 r
.64588 .73652 Mdot
.79832 .68378 Mdot
.68612 .66395 Mdot
1 .5 0 r
.64569 .72658 Mdot
.628 .126 .941 r
.68525 .68032 Mdot
.45515 .59456 Mdot
.69091 .72642 Mdot
.51 .41649 Mdot
.64542 .65055 Mdot
.73115 .65384 Mdot
.7706 .66373 Mdot
1 .5 0 r
.71099 .65709 Mdot
.70319 .7461 Mdot
.31475 .1658 Mdot
.31475 .1658 Mdot
.49304 .15591 Mdot
.628 .126 .941 r
.63773 .6834 Mdot
1 .5 0 r
.62409 .71637 Mdot
.628 .126 .941 r
.70244 .70632 Mdot
.66844 .7326 Mdot
.65529 .7293 Mdot
.80779 .67654 Mdot
1 .5 0 r
.64243 .67978 Mdot
.628 .126 .941 r
.31236 .1686 Mdot
.54966 .68303 Mdot
.74066 .7127 Mdot
.69389 .75557 Mdot
1 .5 0 r
.31849 .17842 Mdot
.628 .126 .941 r
.78043 .67638 Mdot
1 .5 0 r
.67469 .68627 Mdot
.70003 .76541 Mdot
.628 .126 .941 r
.5481 .72574 Mdot
.46896 .696 Mdot
.59986 .75532 Mdot
.5867 .75202 Mdot
.41203 .46172 Mdot
.75885 .66615 Mdot
.78468 .70903 Mdot
.77816 .67929 Mdot
.77182 .6595 Mdot
.64558 .71888 Mdot
1 .5 0 r
.33568 .14809 Mdot
.628 .126 .941 r
.47704 .43838 Mdot
.46339 .47136 Mdot
.77096 .67589 Mdot
1 .5 0 r
.32865 .15461 Mdot
.628 .126 .941 r
.65086 .74511 Mdot
.67426 .96943 Mdot
1 .5 0 r
.3341 .19076 Mdot
.33459 .15447 Mdot
.628 .126 .941 r
.78307 .68562 Mdot
.78307 .68562 Mdot
.72994 .70871 Mdot
1 .5 0 r
.68978 .72516 Mdot
.54674 .53374 Mdot
.628 .126 .941 r
.57843 .63272 Mdot
.62328 .735 Mdot
.6696 .7284 Mdot
.59774 .64587 Mdot
1 .5 0 r
.3133 .16408 Mdot
.37864 .21687 Mdot
.628 .126 .941 r
.41666 .33565 Mdot
.70237 .6986 Mdot
.78166 .67215 Mdot
1 .5 0 r
.64221 .72825 Mdot
.628 .126 .941 r
.66201 .7051 Mdot
.64885 .7018 Mdot
1 .5 0 r
.31201 .16049 Mdot
.43489 .35519 Mdot
.628 .126 .941 r
.72161 .64559 Mdot
1 .5 0 r
.66846 .66869 Mdot
.64798 .71819 Mdot
.628 .126 .941 r
.72648 .77429 Mdot
1 .5 0 r
.74648 .76109 Mdot
.34399 .21322 Mdot
.628 .126 .941 r
.80608 .70158 Mdot
1 .5 0 r
.33091 .15367 Mdot
.628 .126 .941 r
.74689 .65862 Mdot
1 .5 0 r
.32388 .1602 Mdot
.628 .126 .941 r
.61269 .74098 Mdot
1 .5 0 r
.63952 .71127 Mdot
.7117 .74758 Mdot
.65444 .55938 Mdot
.628 .126 .941 r
.6523 .69466 Mdot
.38481 .90917 Mdot
.64441 .71761 Mdot
.81661 .68789 Mdot
.48295 .93219 Mdot
.65739 .71095 Mdot
.75057 .66143 Mdot
1 .5 0 r
.70959 .76047 Mdot
.7291 .78358 Mdot
.33425 .14634 Mdot
.47963 .14634 Mdot
.35962 .22558 Mdot
.628 .126 .941 r
.68306 .74391 Mdot
.60481 .64151 Mdot
1 .5 0 r
.49534 .40373 Mdot
.64365 .67777 Mdot
.628 .126 .941 r
.68219 .76032 Mdot
1 .5 0 r
.41073 .2815 Mdot
.628 .126 .941 r
.62961 .69087 Mdot
.58228 .77012 Mdot
.42868 .34734 Mdot
1 .5 0 r
.33186 .14913 Mdot
.628 .126 .941 r
.36992 .26802 Mdot
.67392 .76336 Mdot
.67441 .72704 Mdot
.69374 .74019 Mdot
1 .5 0 r
.36298 .21827 Mdot
.628 .126 .941 r
.49699 .55178 Mdot
.65364 .7004 Mdot
.63363 .71361 Mdot
.77955 .67728 Mdot
1 .5 0 r
.35623 .1785 Mdot
.628 .126 .941 r
.77832 .67376 Mdot
.7178 .74974 Mdot
.59997 .63737 Mdot
.73127 .70674 Mdot
.21074 .54812 Mdot
.7511 .68356 Mdot
.77708 .67024 Mdot
1 .5 0 r
.72924 .78587 Mdot
.628 .126 .941 r
.59871 .63384 Mdot
.67682 .72635 Mdot
.78306 .67013 Mdot
1 .5 0 r
.68298 .73621 Mdot
.32005 .16126 Mdot
.32005 .16126 Mdot
.628 .126 .941 r
.70915 .73285 Mdot
.71599 .71633 Mdot
1 .5 0 r
.37843 .22066 Mdot
.628 .126 .941 r
.68846 .77245 Mdot
1 .5 0 r
.32599 .16111 Mdot
.628 .126 .941 r
.67557 .72283 Mdot
.81472 .70301 Mdot
1 .5 0 r
.32579 .15113 Mdot
.628 .126 .941 r
.37022 .28991 Mdot
1 .5 0 r
.72177 .70626 Mdot
.33193 .16097 Mdot
.628 .126 .941 r
.68789 .74256 Mdot
1 .5 0 r
.33173 .15098 Mdot
.31785 .17404 Mdot
.628 .126 .941 r
.72853 .62348 Mdot
.78712 .69288 Mdot
.70685 .73579 Mdot
.7801 .69944 Mdot
1 .5 0 r
.33043 .14739 Mdot
.32339 .15392 Mdot
.33638 .14724 Mdot
.70512 .76863 Mdot
.71812 .76197 Mdot
.628 .126 .941 r
.40367 .48089 Mdot
.73777 .72881 Mdot
.81103 .69245 Mdot
1 .5 0 r
.33508 .14364 Mdot
.64721 .55025 Mdot
.628 .126 .941 r
.57345 .62298 Mdot
1 .5 0 r
.67115 .73868 Mdot
.628 .126 .941 r
.69752 .74529 Mdot
.71706 .76843 Mdot
.8172 .70231 Mdot
.32804 .15018 Mdot
.43795 .34192 Mdot
.7838 .70226 Mdot
.68414 .73201 Mdot
.68414 .73201 Mdot
.69177 .63278 Mdot
1 .5 0 r
.65074 .73196 Mdot
.628 .126 .941 r
.80315 .71543 Mdot
1 .5 0 r
.31396 .16326 Mdot
.32715 .16657 Mdot
.71601 .77489 Mdot
.628 .126 .941 r
.3714 .29544 Mdot
1 .5 0 r
.46373 .31858 Mdot
.628 .126 .941 r
.32625 .18295 Mdot
.46207 .4177 Mdot
.7894 .68221 Mdot
.36465 .25562 Mdot
1 .5 0 r
.69834 .53998 Mdot
.628 .126 .941 r
.76869 .72183 Mdot
1 .5 0 r
.37178 .19273 Mdot
.61753 .61927 Mdot
.628 .126 .941 r
.59701 .66887 Mdot
1 .5 0 r
.66913 .69527 Mdot
.628 .126 .941 r
.65526 .71836 Mdot
.72123 .7349 Mdot
1 .5 0 r
.69514 .68194 Mdot
.628 .126 .941 r
.78114 .68524 Mdot
.82072 .69516 Mdot
1 .5 0 r
.75329 .78776 Mdot
.71352 .76786 Mdot
.628 .126 .941 r
.55402 .79096 Mdot
.78712 .68513 Mdot
.60758 .72146 Mdot
1 .5 0 r
.64795 .64864 Mdot
.628 .126 .941 r
.71295 .73794 Mdot
1 .5 0 r
.32325 .15578 Mdot
.628 .126 .941 r
.34133 .28808 Mdot
.51483 .67836 Mdot
1 .5 0 r
.33625 .14909 Mdot
.628 .126 .941 r
.52979 .52615 Mdot
.5337 .72792 Mdot
.72626 .68492 Mdot
.79908 .68492 Mdot
.75803 .78414 Mdot
1 .5 0 r
.3292 .15563 Mdot
.32216 .16218 Mdot
.628 .126 .941 r
.67828 .73437 Mdot
1 .5 0 r
.34717 .22158 Mdot
.628 .126 .941 r
.80371 .73763 Mdot
1 .5 0 r
.3279 .15203 Mdot
.628 .126 .941 r
.32057 .20496 Mdot
.68425 .73427 Mdot
.79033 .72434 Mdot
1 .5 0 r
.71798 .68795 Mdot
.628 .126 .941 r
.79082 .68795 Mdot
1 .5 0 r
.3409 .14534 Mdot
.34021 .17174 Mdot
.628 .126 .941 r
.38469 .31069 Mdot
1 .5 0 r
.57242 .6316 Mdot
.628 .126 .941 r
.7572 .67792 Mdot
.17183 .35694 Mdot
.77657 .6911 Mdot
1 .5 0 r
.66589 .52562 Mdot
.628 .126 .941 r
.70237 .74393 Mdot
1 .5 0 r
.32571 .16483 Mdot
.628 .126 .941 r
.70218 .73395 Mdot
1 .5 0 r
.80192 .70417 Mdot
.628 .126 .941 r
.74863 .72733 Mdot
1 .5 0 r
.34555 .1416 Mdot
.34507 .178 Mdot
.37831 .16807 Mdot
.628 .126 .941 r
.7416 .7339 Mdot
.108 .5187 Mdot
.62289 .64776 Mdot
1 .5 0 r
.72068 .76358 Mdot
.628 .126 .941 r
.80772 .69408 Mdot
.75442 .71725 Mdot
1 .5 0 r
.72753 .74703 Mdot
.32441 .16123 Mdot
.70045 .76683 Mdot
.60343 .56822 Mdot
.34943 .22066 Mdot
.628 .126 .941 r
.33016 .15109 Mdot
1 .5 0 r
.33016 .15109 Mdot
.628 .126 .941 r
.6808 .67732 Mdot
.75367 .67732 Mdot
.82605 .71373 Mdot
.82587 .70374 Mdot
.79946 .69712 Mdot
.70586 .73679 Mdot
.71955 .70369 Mdot
.76552 .73348 Mdot
1 .5 0 r
.32906 .15749 Mdot
.628 .126 .941 r
.73795 .7897 Mdot
1 .5 0 r
.38707 .25341 Mdot
.628 .126 .941 r
.79156 .72013 Mdot
.69129 .78634 Mdot
1 .5 0 r
.33502 .15734 Mdot
.628 .126 .941 r
.33453 .19376 Mdot
.79822 .6936 Mdot
1 .5 0 r
.33482 .14734 Mdot
.35438 .17051 Mdot
.40016 .1903 Mdot
.628 .126 .941 r
.41043 .4121 Mdot
.18297 .57431 Mdot
.69836 .65702 Mdot
.67762 .69669 Mdot
.70257 .81257 Mdot
.35798 .29603 Mdot
1 .5 0 r
.58889 .37218 Mdot
.628 .126 .941 r
.66325 .75623 Mdot
.68311 .73301 Mdot
.32577 .1767 Mdot
1 .5 0 r
.33242 .15014 Mdot
.628 .126 .941 r
.75514 .74946 Mdot
1 .5 0 r
.62304 .71634 Mdot
.628 .126 .941 r
.71551 .73952 Mdot
.83471 .72291 Mdot
.28749 .97784 Mdot
1 .5 0 r
.76113 .74935 Mdot
.628 .126 .941 r
.45414 .38835 Mdot
.53145 .55392 Mdot
.68803 .73937 Mdot
.82113 .69963 Mdot
.75409 .75592 Mdot
1 .5 0 r
.72044 .74588 Mdot
.33708 .14639 Mdot
.33708 .14639 Mdot
.33708 .14639 Mdot
.36987 .17289 Mdot
.628 .126 .941 r
.74668 .74252 Mdot
.82008 .70609 Mdot
.80638 .73921 Mdot
.11274 .53713 Mdot
.69951 .77559 Mdot
.32297 .15949 Mdot
.32884 .2158 Mdot
.63404 .66618 Mdot
.25914 .93778 Mdot
.7652 .77217 Mdot
.73828 .80198 Mdot
.78557 .7125 Mdot
.75229 .72244 Mdot
.71166 .78537 Mdot
.64668 .63952 Mdot
1 .5 0 r
.67849 .73889 Mdot
.628 .126 .941 r
.70492 .74552 Mdot
.48349 .42414 Mdot
1 .5 0 r
.62691 .60634 Mdot
.628 .126 .941 r
.68447 .73879 Mdot
1 .5 0 r
.34064 .14905 Mdot
.628 .126 .941 r
.81694 .72548 Mdot
.33359 .1556 Mdot
.66304 .80494 Mdot
1 .5 0 r
.76242 .81157 Mdot
.44451 .26486 Mdot
.703 .76845 Mdot
.74265 .77839 Mdot
.3792 .16539 Mdot
.33249 .16201 Mdot
.628 .126 .941 r
.35746 .27798 Mdot
.68303 .72527 Mdot
.70879 .75835 Mdot
.72201 .76167 Mdot
.76197 .72517 Mdot
1 .5 0 r
.33825 .15185 Mdot
.628 .126 .941 r
.72163 .74168 Mdot
.72751 .79801 Mdot
.76129 .75162 Mdot
1 .5 0 r
.73436 .78145 Mdot
.80781 .745 Mdot
.35126 .14515 Mdot
.628 .126 .941 r
.70137 .74494 Mdot
1 .5 0 r
.72713 .77803 Mdot
.628 .126 .941 r
.8138 .74489 Mdot
1 .5 0 r
.37632 .20466 Mdot
.628 .126 .941 r
.32989 .1548 Mdot
1 .5 0 r
.34997 .14154 Mdot
.34997 .14154 Mdot
.3625 .1713 Mdot
.65732 .44639 Mdot
.628 .126 .941 r
.4673 .76457 Mdot
.71228 .75121 Mdot
.73922 .72138 Mdot
.71895 .72464 Mdot
.68467 .80751 Mdot
.33475 .16107 Mdot
.84464 .7279 Mdot
.77784 .73779 Mdot
.824 .71117 Mdot
.81029 .74432 Mdot
1 .5 0 r
.35354 .1442 Mdot
.73809 .66138 Mdot
.628 .126 .941 r
.75671 .75753 Mdot
1 .5 0 r
.75719 .72106 Mdot
.46405 .29 Mdot
.34627 .14074 Mdot
.628 .126 .941 r
.73673 .71432 Mdot
.78327 .70769 Mdot
1 .5 0 r
.74898 .79058 Mdot
.33921 .1473 Mdot
.48227 .36613 Mdot
.628 .126 .941 r
.7292 .75737 Mdot
1 .5 0 r
.35224 .14059 Mdot
.628 .126 .941 r
.70255 .74074 Mdot
.24522 .67105 Mdot
.56272 .75063 Mdot
.68129 .81695 Mdot
1 .5 0 r
.60515 .53173 Mdot
.35114 .147 Mdot
.628 .126 .941 r
.7549 .724 Mdot
.49353 .39233 Mdot
1 .5 0 r
.67435 .76706 Mdot
.628 .126 .941 r
.76745 .75379 Mdot
1 .5 0 r
.33702 .16012 Mdot
.34388 .14354 Mdot
.628 .126 .941 r
.7408 .73716 Mdot
.59948 .8565 Mdot
.82686 .73048 Mdot
.74024 .70715 Mdot
1 .5 0 r
.53764 .44507 Mdot
.628 .126 .941 r
.55313 .75017 Mdot
.71222 .74348 Mdot
.78574 .70699 Mdot
.72546 .7468 Mdot
.81221 .71363 Mdot
.73183 .7667 Mdot
.11062 .52781 Mdot
.69812 .75664 Mdot
1 .5 0 r
.7442 .7865 Mdot
.628 .126 .941 r
.59793 .7765 Mdot
.75136 .72342 Mdot
1 .5 0 r
.34038 .15276 Mdot
.628 .126 .941 r
.36636 .19589 Mdot
.1095 .53427 Mdot
.57127 .75986 Mdot
1 .5 0 r
.72372 .77976 Mdot
.628 .126 .941 r
.80393 .71668 Mdot
.37822 .25215 Mdot
.41723 .28857 Mdot
1 .5 0 r
.7359 .78956 Mdot
.628 .126 .941 r
.33202 .15571 Mdot
.7414 .82596 Mdot
1 .5 0 r
.61747 .61017 Mdot
.628 .126 .941 r
.80869 .71304 Mdot
1 .5 0 r
.35102 .14886 Mdot
.628 .126 .941 r
.74133 .75944 Mdot
.70112 .78599 Mdot
.76192 .70967 Mdot
1 .5 0 r
.38298 .19185 Mdot
.76743 .74606 Mdot
.33668 .15196 Mdot
.48723 .31789 Mdot
.628 .126 .941 r
.7339 .74601 Mdot
.73978 .80243 Mdot
.32912 .19503 Mdot
.72684 .7526 Mdot
.84013 .72605 Mdot
1 .5 0 r
.36914 .15845 Mdot
.628 .126 .941 r
.39758 .51358 Mdot
.34833 .19821 Mdot
1 .5 0 r
.42141 .19821 Mdot
.628 .126 .941 r
.72695 .69607 Mdot
.69311 .74254 Mdot
.81946 .70929 Mdot
1 .5 0 r
.73903 .7624 Mdot
.628 .126 .941 r
.35382 .23458 Mdot
.34037 .22123 Mdot
.61878 .73901 Mdot
.73797 .76888 Mdot
.47044 .38043 Mdot
1 .5 0 r
.42384 .38707 Mdot
.628 .126 .941 r
.77114 .74891 Mdot
1 .5 0 r
.37889 .171 Mdot
.35907 .13773 Mdot
.628 .126 .941 r
.72929 .75192 Mdot
.77571 .73527 Mdot
.33785 .15743 Mdot
.17131 .65546 Mdot
1 .5 0 r
.79496 .73848 Mdot
.78171 .73516 Mdot
.628 .126 .941 r
.84158 .73184 Mdot
1 .5 0 r
.84747 .78829 Mdot
.628 .126 .941 r
.77447 .73173 Mdot
1 .5 0 r
.35667 .14053 Mdot
.75367 .77153 Mdot
.3496 .1471 Mdot
.75397 .72499 Mdot
.628 .126 .941 r
.77998 .76816 Mdot
1 .5 0 r
.37491 .21678 Mdot
.628 .126 .941 r
.70697 .71159 Mdot
.765 .79785 Mdot
.78561 .74803 Mdot
1 .5 0 r
.35447 .15338 Mdot
.34122 .15006 Mdot
.628 .126 .941 r
.78592 .70147 Mdot
.72505 .77787 Mdot
.8515 .7446 Mdot
1 .5 0 r
.78426 .80107 Mdot
.628 .126 .941 r
.5352 .50869 Mdot
.35219 .22285 Mdot
1 .5 0 r
.76995 .80424 Mdot
.75031 .78099 Mdot
.36623 .14305 Mdot
.36623 .14305 Mdot
.35915 .14962 Mdot
.7627 .80082 Mdot
.4321 .13958 Mdot
.35895 .13958 Mdot
.72275 .78083 Mdot
.628 .126 .941 r
.38379 .24583 Mdot
.52028 .48174 Mdot
.72845 .8273 Mdot
.84923 .74756 Mdot
1 .5 0 r
.38457 .16269 Mdot
.7811 .82055 Mdot
.35765 .13596 Mdot
.3437 .15915 Mdot
.3437 .15915 Mdot
.628 .126 .941 r
.43847 .53134 Mdot
1 .5 0 r
.76157 .7407 Mdot
.36363 .13581 Mdot
.67103 .52464 Mdot
.628 .126 .941 r
.25932 .94332 Mdot
1 .5 0 r
.77986 .81703 Mdot
.628 .126 .941 r
.76671 .75711 Mdot
1 .5 0 r
.36233 .1322 Mdot
.38197 .15546 Mdot
.71938 .79029 Mdot
.628 .126 .941 r
.79992 .73711 Mdot
.77291 .76703 Mdot
.11656 .57419 Mdot
1 .5 0 r
.3413 .16196 Mdot
.36094 .18523 Mdot
.69247 .7636 Mdot
.628 .126 .941 r
.7524 .76028 Mdot
1 .5 0 r
.34728 .16182 Mdot
.3792 .26154 Mdot
.34707 .15177 Mdot
.628 .126 .941 r
.39914 .2382 Mdot
.54159 .53074 Mdot
.80488 .7435 Mdot
.83122 .74012 Mdot
1 .5 0 r
.37909 .19485 Mdot
.67187 .6902 Mdot
.628 .126 .941 r
.12884 .47072 Mdot
.68986 .81316 Mdot
1 .5 0 r
.34577 .14816 Mdot
.628 .126 .941 r
.53442 .47066 Mdot
.26815 .9727 Mdot
1 .5 0 r
.81052 .72334 Mdot
.35883 .14143 Mdot
.35883 .14143 Mdot
.35883 .14143 Mdot
.35883 .14143 Mdot
.628 .126 .941 r
.77625 .74983 Mdot
1 .5 0 r
.76937 .76646 Mdot
.33759 .16116 Mdot
.74295 .70318 Mdot
.79602 .71648 Mdot
.628 .126 .941 r
.73509 .79296 Mdot
1 .5 0 r
.35753 .13781 Mdot
.628 .126 .941 r
.50691 .41382 Mdot
.66493 .51684 Mdot
1 .5 0 r
.35664 .15429 Mdot
.70061 .80943 Mdot
.34935 .15082 Mdot
.38277 .14084 Mdot
.628 .126 .941 r
.3342 .23715 Mdot
.10419 .50989 Mdot
1 .5 0 r
.35464 .17721 Mdot
.628 .126 .941 r
.69917 .79588 Mdot
1 .5 0 r
.50582 .29689 Mdot
.7791 .76922 Mdot
.35424 .15711 Mdot
.36112 .14048 Mdot
.38766 .14713 Mdot
.628 .126 .941 r
.36042 .16702 Mdot
1 .5 0 r
.39286 .23022 Mdot
.628 .126 .941 r
.37271 .24353 Mdot
1 .5 0 r
.57552 .4863 Mdot
.628 .126 .941 r
.7515 .76906 Mdot
1 .5 0 r
.75789 .78902 Mdot
.3669 .13028 Mdot
.36641 .16687 Mdot
.628 .126 .941 r
.52027 .60933 Mdot
1 .5 0 r
.8044 .77234 Mdot
.628 .126 .941 r
.28509 .24664 Mdot
.70472 .70902 Mdot
.73667 .80883 Mdot
1 .5 0 r
.81631 .82879 Mdot
.628 .126 .941 r
.77041 .75222 Mdot
1 .5 0 r
.77631 .80878 Mdot
.35183 .15993 Mdot
.35872 .14329 Mdot
.628 .126 .941 r
.66157 .89856 Mdot
1 .5 0 r
.79627 .78544 Mdot
.78232 .80868 Mdot
.628 .126 .941 r
.38388 .20304 Mdot
1 .5 0 r
.79541 .80197 Mdot
.35762 .14972 Mdot
.3645 .13309 Mdot
.35073 .16636 Mdot
.60445 .61558 Mdot
.35053 .15631 Mdot
.628 .126 .941 r
.68292 .69872 Mdot
1 .5 0 r
.35672 .16622 Mdot
.628 .126 .941 r
.36852 .27936 Mdot
1 .5 0 r
.53964 .43244 Mdot
.628 .126 .941 r
.75502 .76189 Mdot
1 .5 0 r
.37668 .14285 Mdot
.3634 .13952 Mdot
.36242 .21273 Mdot
.70959 .64869 Mdot
.628 .126 .941 r
.72759 .77177 Mdot
1 .5 0 r
.51446 .2492 Mdot
.50561 .41228 Mdot
.37558 .14928 Mdot
.7223 .6219 Mdot
.628 .126 .941 r
.61489 .65845 Mdot
.77227 .84484 Mdot
1 .5 0 r
.68995 .50196 Mdot
.69339 .74161 Mdot
.628 .126 .941 r
.75241 .81151 Mdot
1 .5 0 r
.36809 .13575 Mdot
.36809 .13575 Mdot
.628 .126 .941 r
.16672 .7182 Mdot
.67265 .72481 Mdot
1 .5 0 r
.79119 .828 Mdot
.58864 .48168 Mdot
.3597 .13871 Mdot
.37298 .14204 Mdot
.3597 .13871 Mdot
.628 .126 .941 r
.70405 .79456 Mdot
.75078 .7879 Mdot
1 .5 0 r
.37278 .13198 Mdot
.37188 .14848 Mdot
.39845 .15514 Mdot
.37828 .16846 Mdot
.43141 .18177 Mdot
.628 .126 .941 r
.76184 .86095 Mdot
1 .5 0 r
.74935 .77433 Mdot
.37767 .13827 Mdot
.39076 .13153 Mdot
.37747 .1282 Mdot
.37747 .1282 Mdot
.628 .126 .941 r
.54329 .68431 Mdot
.716 .7276 Mdot
1 .5 0 r
.37038 .13479 Mdot
.40925 .21804 Mdot
.67841 .52441 Mdot
.3564 .15803 Mdot
.36329 .14138 Mdot
.628 .126 .941 r
.50107 .30456 Mdot
1 .5 0 r
.3562 .14796 Mdot
.3562 .14796 Mdot
.37588 .17128 Mdot
.628 .126 .941 r
.40737 .30782 Mdot
.79466 .75409 Mdot
.72016 .81731 Mdot
1 .5 0 r
.80038 .80066 Mdot
.79349 .81731 Mdot
.3553 .16447 Mdot
.36219 .14782 Mdot
.628 .126 .941 r
.73375 .77397 Mdot
1 .5 0 r
.76722 .76397 Mdot
.40136 .18438 Mdot
.628 .126 .941 r
.66614 .82054 Mdot
.67923 .81383 Mdot
.77275 .80051 Mdot
1 .5 0 r
.77914 .82049 Mdot
.628 .126 .941 r
.3921 .32747 Mdot
.15416 .64385 Mdot
1 .5 0 r
.40006 .18076 Mdot
.40597 .23739 Mdot
.39268 .23406 Mdot
.72591 .7404 Mdot
.628 .126 .941 r
.71262 .73707 Mdot
1 .5 0 r
.35269 .15722 Mdot
.35889 .16715 Mdot
.37267 .13383 Mdot
.37267 .13383 Mdot
.628 .126 .941 r
.52971 .35705 Mdot
1 .5 0 r
.77684 .82348 Mdot
.80343 .83014 Mdot
.38576 .12709 Mdot
.36558 .14042 Mdot
.47093 .24037 Mdot
.35848 .14701 Mdot
.35848 .14701 Mdot
.628 .126 .941 r
.79616 .82671 Mdot
1 .5 0 r
.79616 .82671 Mdot
.628 .126 .941 r
.80237 .83665 Mdot
.48855 .34346 Mdot
1 .5 0 r
.7623 .81661 Mdot
.8084 .83656 Mdot
.37047 .14672 Mdot
.35028 .16005 Mdot
.628 .126 .941 r
.44827 .31333 Mdot
.82889 .77652 Mdot
.12554 .47989 Mdot
.68246 .72982 Mdot
.80212 .75981 Mdot
.78143 .8098 Mdot
1 .5 0 r
.37647 .14657 Mdot
.628 .126 .941 r
.59265 .43983 Mdot
.79503 .76642 Mdot
1 .5 0 r
.80094 .82308 Mdot
.628 .126 .941 r
.36248 .16982 Mdot
1 .5 0 r
.35608 .14983 Mdot
.37627 .1365 Mdot
.628 .126 .941 r
.42108 .27647 Mdot
.11035 .56641 Mdot
1 .5 0 r
.72098 .79303 Mdot
.43565 .15975 Mdot
.38838 .20308 Mdot
.628 .126 .941 r
.80697 .82298 Mdot
.35518 .16635 Mdot
1 .5 0 r
.39458 .21301 Mdot
.44678 .29966 Mdot
.628 .126 .941 r
.56301 .58629 Mdot
1 .5 0 r
.36827 .15961 Mdot
.35477 .1462 Mdot
.37497 .13287 Mdot
.37497 .13287 Mdot
.37497 .13287 Mdot
.40058 .21286 Mdot
.36097 .15613 Mdot
.48558 .31612 Mdot
.37407 .14939 Mdot
.38096 .13272 Mdot
.79865 .82606 Mdot
.628 .126 .941 r
.90553 .81606 Mdot
1 .5 0 r
.45317 .19598 Mdot
.38696 .13257 Mdot
.628 .126 .941 r
.74458 .8293 Mdot
1 .5 0 r
.36656 .13583 Mdot
.37888 .21251 Mdot
.60794 .54588 Mdot
.628 .126 .941 r
.24933 .91592 Mdot
.75769 .82258 Mdot
1 .5 0 r
.37966 .12909 Mdot
.7974 .82253 Mdot
.7974 .82253 Mdot
.37256 .13569 Mdot
.36567 .15236 Mdot
.45858 .16562 Mdot
.39039 .2489 Mdot
.74917 .81561 Mdot
.80238 .82895 Mdot
.37036 .14858 Mdot
.37726 .13191 Mdot
.47433 .35866 Mdot
.36306 .1451 Mdot
.39558 .20846 Mdot
.42269 .17845 Mdot
.628 .126 .941 r
.4148 .26849 Mdot
1 .5 0 r
.35596 .1517 Mdot
.76793 .78868 Mdot
.73374 .82532 Mdot
.628 .126 .941 r
.76676 .852 Mdot
.53691 .54511 Mdot
1 .5 0 r
.37506 .1448 Mdot
.628 .126 .941 r
.77279 .8519 Mdot
.7994 .85857 Mdot
1 .5 0 r
.60305 .54165 Mdot
.628 .126 .941 r
.73958 .81516 Mdot
.76668 .78514 Mdot
1 .5 0 r
.36776 .14132 Mdot
.37416 .16134 Mdot
.36086 .158 Mdot
.41409 .17134 Mdot
.628 .126 .941 r
.40009 .19462 Mdot
.64535 .79833 Mdot
.79816 .85504 Mdot
1 .5 0 r
.36666 .14777 Mdot
.41299 .1778 Mdot
.4192 .18773 Mdot
.628 .126 .941 r
.77806 .81157 Mdot
.66794 .53462 Mdot
.79809 .78817 Mdot
.72414 .82487 Mdot
.77147 .7815 Mdot
1 .5 0 r
.75766 .81486 Mdot
.87727 .83483 Mdot
.39888 .13413 Mdot
.80363 .82477 Mdot
.80363 .82477 Mdot
.628 .126 .941 r
.69566 .90818 Mdot
1 .5 0 r
.38467 .14733 Mdot
.628 .126 .941 r
.40291 .2808 Mdot
1 .5 0 r
.71106 .70789 Mdot
.628 .126 .941 r
.78255 .8547 Mdot
.79635 .82133 Mdot
.82969 .80126 Mdot
1 .5 0 r
.36405 .14051 Mdot
.37736 .14385 Mdot
.628 .126 .941 r
.41582 .26397 Mdot
.77576 .81456 Mdot
1 .5 0 r
.37716 .13376 Mdot
.38357 .15378 Mdot
.37025 .15045 Mdot
.628 .126 .941 r
.38948 .21051 Mdot
.53001 .19049 Mdot
.73514 .83119 Mdot
1 .5 0 r
.80861 .83119 Mdot
.37005 .14036 Mdot
.628 .126 .941 r
.65654 .69098 Mdot
.76157 .82781 Mdot
1 .5 0 r
.81483 .84115 Mdot
.36295 .14696 Mdot
.628 .126 .941 r
.78752 .86113 Mdot
.80133 .82776 Mdot
1 .5 0 r
.80133 .82776 Mdot
.80133 .82776 Mdot
.37606 .14022 Mdot
.80114 .81769 Mdot
.38137 .1667 Mdot
.628 .126 .941 r
.38531 .86761 Mdot
.80008 .82422 Mdot
1 .5 0 r
.8134 .82756 Mdot
.36785 .15327 Mdot
.80039 .77744 Mdot
.628 .126 .941 r
.7195 .83085 Mdot
1 .5 0 r
.75304 .82083 Mdot
.36765 .14318 Mdot
.628 .126 .941 r
.1018 .53706 Mdot
.70501 .89088 Mdot
.78541 .87419 Mdot
.36004 .18651 Mdot
1 .5 0 r
.39408 .13977 Mdot
.628 .126 .941 r
.70087 .6772 Mdot
1 .5 0 r
.81925 .81739 Mdot
.628 .126 .941 r
.71844 .83737 Mdot
1 .5 0 r
.36654 .14964 Mdot
.37966 .14289 Mdot
.77972 .70374 Mdot
.79156 .81724 Mdot
.37946 .1328 Mdot
.37946 .1328 Mdot
.628 .126 .941 r
.78397 .86059 Mdot
.09933 .53998 Mdot
.49035 .25945 Mdot
1 .5 0 r
.71828 .70352 Mdot
.80363 .81704 Mdot
.37125 .14586 Mdot
.37815 .12916 Mdot
.41121 .15588 Mdot
.37104 .13577 Mdot
.37104 .13577 Mdot
.628 .126 .941 r
.80227 .87037 Mdot
1 .5 0 r
.38416 .12902 Mdot
.8159 .82691 Mdot
.628 .126 .941 r
.73134 .62984 Mdot
.77525 .84356 Mdot
.36994 .14223 Mdot
1 .5 0 r
.57374 .39602 Mdot
.628 .126 .941 r
.78148 .85353 Mdot
.70795 .85353 Mdot
.87523 .84017 Mdot
.36283 .14883 Mdot
.48521 .49281 Mdot
1 .5 0 r
.80843 .8134 Mdot
.8418 .79331 Mdot
.80133 .82003 Mdot
.628 .126 .941 r
.43398 .2756 Mdot
.74045 .85004 Mdot
1 .5 0 r
.36173 .15529 Mdot
.38838 .16197 Mdot
.628 .126 .941 r
.39874 .38574 Mdot
1 .5 0 r
.38176 .13184 Mdot
.628 .126 .941 r
.13647 .47586 Mdot
.4395 .3122 Mdot
.54611 .33892 Mdot
.76672 .83658 Mdot
1 .5 0 r
.80028 .82656 Mdot
.80028 .82656 Mdot
.8141 .79316 Mdot
.36774 .15514 Mdot
.3939 .19857 Mdot
.628 .126 .941 r
.76011 .80647 Mdot
1 .5 0 r
.39419 .15173 Mdot
.628 .126 .941 r
.75351 .77636 Mdot
.77275 .83648 Mdot
1 .5 0 r
.38757 .12159 Mdot
.37375 .155 Mdot
.41324 .20176 Mdot
.628 .126 .941 r
.83969 .80637 Mdot
.75875 .85982 Mdot
.77158 .8999 Mdot
1 .5 0 r
.75886 .80293 Mdot
.38647 .12805 Mdot
.628 .126 .941 r
.50988 .39865 Mdot
.81149 .84297 Mdot
.8113 .8329 Mdot
1 .5 0 r
.38557 .14461 Mdot
.37224 .14127 Mdot
.628 .126 .941 r
.54157 .4787 Mdot
.75731 .84621 Mdot
1 .5 0 r
.38537 .13451 Mdot
.628 .126 .941 r
.44412 .24142 Mdot
1 .5 0 r
.81735 .8328 Mdot
.628 .126 .941 r
.80352 .86621 Mdot
.77094 .80273 Mdot
1 .5 0 r
.38516 .12441 Mdot
.52291 .32488 Mdot
.628 .126 .941 r
.17633 .73585 Mdot
1 .5 0 r
.39138 .13436 Mdot
.628 .126 .941 r
.73649 .82936 Mdot
1 .5 0 r
.36402 .15434 Mdot
.81629 .83933 Mdot
.82962 .84267 Mdot
.628 .126 .941 r
.57811 .62208 Mdot
.75586 .8326 Mdot
1 .5 0 r
.37004 .15419 Mdot
.37695 .13748 Mdot
.628 .126 .941 r
.40954 .20097 Mdot
.78185 .86596 Mdot
1 .5 0 r
.38316 .14743 Mdot
.628 .126 .941 r
.65969 .47493 Mdot
.44143 .78905 Mdot
.78264 .78237 Mdot
1 .5 0 r
.84931 .79908 Mdot
.628 .126 .941 r
.3558 .16741 Mdot
.81505 .83579 Mdot
.74128 .82571 Mdot
1 .5 0 r
.84893 .77893 Mdot
.84844 .81569 Mdot
.83492 .80227 Mdot
.628 .126 .941 r
.80726 .86911 Mdot
.86159 .80895 Mdot
.40112 .20396 Mdot
1 .5 0 r
.80757 .82227 Mdot
.80757 .82227 Mdot
.628 .126 .941 r
.79374 .8557 Mdot
1 .5 0 r
.38166 .13369 Mdot
.628 .126 .941 r
.3945 .1738 Mdot
1 .5 0 r
.3943 .1637 Mdot
.43924 .30409 Mdot
.82034 .79538 Mdot
.628 .126 .941 r
.78577 .87895 Mdot
1 .5 0 r
.38056 .14016 Mdot
.628 .126 .941 r
.83991 .8087 Mdot
1 .5 0 r
.38678 .15011 Mdot
.38678 .15011 Mdot
.79922 .82537 Mdot
.8259 .83205 Mdot
.37324 .13667 Mdot
.57181 .29713 Mdot
.628 .126 .941 r
.36612 .14328 Mdot
1 .5 0 r
.81218 .80855 Mdot
.81842 .81853 Mdot
.75815 .82187 Mdot
.37213 .14313 Mdot
.40573 .1331 Mdot
.628 .126 .941 r
.11228 .5577 Mdot
.73079 .84188 Mdot
1 .5 0 r
.81755 .83515 Mdot
.628 .126 .941 r
.35789 .15636 Mdot
1 .5 0 r
.42459 .17308 Mdot
.43101 .19314 Mdot
.628 .126 .941 r
.46263 .33022 Mdot
.63209 .66792 Mdot
.78308 .8618 Mdot
.80976 .86848 Mdot
.39059 .1629 Mdot
.76017 .55078 Mdot
.72311 .81828 Mdot
1 .5 0 r
.79624 .85506 Mdot
.628 .126 .941 r
.507 .44037 Mdot
.75603 .83495 Mdot
1 .5 0 r
.81631 .8316 Mdot
.628 .126 .941 r
.80247 .86504 Mdot
1 .5 0 r
.39018 .14269 Mdot
.628 .126 .941 r
.62588 .53394 Mdot
1 .5 0 r
.38998 .13258 Mdot
.628 .126 .941 r
.14192 .66095 Mdot
.46657 .90842 Mdot
1 .5 0 r
.3962 .14254 Mdot
.42239 .18602 Mdot
.78245 .76452 Mdot
.628 .126 .941 r
.74192 .79127 Mdot
1 .5 0 r
.81506 .82806 Mdot
.38888 .13905 Mdot
.38888 .13905 Mdot
.3958 .12233 Mdot
.628 .126 .941 r
.74766 .83804 Mdot
.8213 .83804 Mdot
1 .5 0 r
.8213 .83804 Mdot
.8213 .83804 Mdot
.8213 .83804 Mdot
.8213 .83804 Mdot
.8549 .82801 Mdot
.628 .126 .941 r
.80746 .87149 Mdot
1 .5 0 r
.38868 .12894 Mdot
.40202 .13229 Mdot
.84187 .77779 Mdot
.80134 .80455 Mdot
.38156 .13556 Mdot
.37464 .15228 Mdot
.47447 .19576 Mdot
.628 .126 .941 r
.81351 .87139 Mdot
.37443 .14217 Mdot
1 .5 0 r
.43424 .17562 Mdot
.3947 .12879 Mdot
.628 .126 .941 r
.39371 .20238 Mdot
.67592 .62383 Mdot
1 .5 0 r
.82024 .84459 Mdot
.628 .126 .941 r
.38016 .18893 Mdot
.43058 .42307 Mdot
1 .5 0 r
.80819 .72077 Mdot
.82006 .8345 Mdot
.82006 .8345 Mdot
.82006 .8345 Mdot
.628 .126 .941 r
.79337 .82781 Mdot
1 .5 0 r
.83983 .85792 Mdot
.8334 .83785 Mdot
.3938 .14537 Mdot
.628 .126 .941 r
.49958 .24572 Mdot
.84013 .81104 Mdot
1 .5 0 r
.44006 .16537 Mdot
.628 .126 .941 r
.41139 .30586 Mdot
1 .5 0 r
.83995 .80095 Mdot
.78557 .86116 Mdot
.81968 .81433 Mdot
.81257 .82097 Mdot
.628 .126 .941 r
.83235 .84439 Mdot
1 .5 0 r
.38627 .13177 Mdot
.39962 .13511 Mdot
.40605 .15518 Mdot
.628 .126 .941 r
.10599 .55998 Mdot
.4278 .52987 Mdot
.79162 .86107 Mdot
1 .5 0 r
.83858 .85438 Mdot
.83858 .85438 Mdot
.628 .126 .941 r
.37202 .145 Mdot
1 .5 0 r
.4704 .2989 Mdot
.81152 .82751 Mdot
.628 .126 .941 r
.38468 .17504 Mdot
1 .5 0 r
.41088 .21853 Mdot
.628 .126 .941 r
.75744 .84085 Mdot
1 .5 0 r
.87856 .79735 Mdot
.8311 .84085 Mdot
.81757 .82741 Mdot
.39119 .13809 Mdot
.4965 .27527 Mdot
.628 .126 .941 r
.81738 .81733 Mdot
.78326 .86417 Mdot
.73679 .83406 Mdot
1 .5 0 r
.38407 .1447 Mdot
.38386 .13459 Mdot
.628 .126 .941 r
.39623 .21156 Mdot
1 .5 0 r
.79624 .84734 Mdot
.42371 .13452 Mdot
.44844 .28845 Mdot
.40324 .13779 Mdot
.628 .126 .941 r
.78202 .86063 Mdot
.81613 .81378 Mdot
1 .5 0 r
.84246 .80029 Mdot
.38878 .14091 Mdot
.81508 .82032 Mdot
.83486 .84375 Mdot
.38858 .1308 Mdot
.41529 .13749 Mdot
.628 .126 .941 r
.1146 .57929 Mdot
1 .5 0 r
.80778 .81687 Mdot
.38768 .14739 Mdot
.628 .126 .941 r
.81402 .82686 Mdot
.80067 .82352 Mdot
.80017 .86034 Mdot
1 .5 0 r
.8338 .85029 Mdot
.8338 .85029 Mdot
.84073 .83356 Mdot
.628 .126 .941 r
.42606 .25777 Mdot
.77327 .84355 Mdot
.79355 .83016 Mdot
1 .5 0 r
.8534 .86363 Mdot
.40063 .1305 Mdot
.628 .126 .941 r
.80672 .82342 Mdot
1 .5 0 r
.83986 .8502 Mdot
.37322 .15051 Mdot
.85352 .80663 Mdot
.628 .126 .941 r
.81247 .87023 Mdot
.78576 .86354 Mdot
1 .5 0 r
.74618 .81667 Mdot
.628 .126 .941 r
.37302 .1404 Mdot
1 .5 0 r
.42001 .1337 Mdot
.628 .126 .941 r
.54862 .53542 Mdot
1 .5 0 r
.81277 .82332 Mdot
.81277 .82332 Mdot
.82613 .82666 Mdot
.39953 .13697 Mdot
.628 .126 .941 r
.09283 .52197 Mdot
.16703 .48514 Mdot
1 .5 0 r
.75916 .79983 Mdot
.82001 .75966 Mdot
.628 .126 .941 r
.75867 .83666 Mdot
1 .5 0 r
.87294 .80988 Mdot
.3924 .1436 Mdot
.50519 .22729 Mdot
.628 .126 .941 r
.52943 .41812 Mdot
1 .5 0 r
.82526 .8433 Mdot
.628 .126 .941 r
.79805 .87344 Mdot
1 .5 0 r
.85871 .82317 Mdot
.628 .126 .941 r
.76422 .87339 Mdot
.79143 .84326 Mdot
1 .5 0 r
.81153 .81977 Mdot
.81153 .81977 Mdot
.81153 .81977 Mdot
.83132 .84321 Mdot
.628 .126 .941 r
.40347 .21696 Mdot
.12343 .60872 Mdot
1 .5 0 r
.83737 .84311 Mdot
.628 .126 .941 r
.55516 .37427 Mdot
1 .5 0 r
.69321 .57518 Mdot
.628 .126 .941 r
.78326 .85645 Mdot
1 .5 0 r
.81146 .75265 Mdot
.85104 .79953 Mdot
.82383 .82966 Mdot
.38376 .13646 Mdot
.628 .126 .941 r
.76624 .60191 Mdot
.81671 .83631 Mdot
1 .5 0 r
.37663 .14308 Mdot
.628 .126 .941 r
.46125 .33061 Mdot
.8096 .84296 Mdot
1 .5 0 r
.83632 .84966 Mdot
.8096 .84296 Mdot
.628 .126 .941 r
.79556 .86635 Mdot
1 .5 0 r
.83613 .83956 Mdot
.84949 .84291 Mdot
.628 .126 .941 r
.44006 .36061 Mdot
.7825 .81607 Mdot
1 .5 0 r
.82902 .84621 Mdot
.628 .126 .941 r
.37553 .14955 Mdot
.81497 .8696 Mdot
.81497 .8696 Mdot
.45401 .27005 Mdot
.55992 .37053 Mdot
1 .5 0 r
.82914 .78917 Mdot
.628 .126 .941 r
.7747 .84946 Mdot
1 .5 0 r
.83508 .84611 Mdot
.628 .126 .941 r
.79499 .83606 Mdot
1 .5 0 r
.82864 .82602 Mdot
.82153 .83266 Mdot
.38135 .13929 Mdot
.628 .126 .941 r
.78057 .83926 Mdot
1 .5 0 r
.82066 .84931 Mdot
.84738 .85601 Mdot
.42104 .12909 Mdot
.628 .126 .941 r
.31215 .24968 Mdot
.80661 .87271 Mdot
.81335 .84586 Mdot
1 .5 0 r
.39341 .13899 Mdot
.38648 .15574 Mdot
.39341 .13899 Mdot
.628 .126 .941 r
.47013 .41703 Mdot
.59784 .89271 Mdot
.5031 .43372 Mdot
1 .5 0 r
.81298 .82567 Mdot
.628 .126 .941 r
.81793 .95632 Mdot
1 .5 0 r
.80734 .72176 Mdot
.628 .126 .941 r
.37894 .14212 Mdot
.37894 .14212 Mdot
1 .5 0 r
.83884 .84902 Mdot
.3921 .13534 Mdot
.628 .126 .941 r
.41141 .19565 Mdot
1 .5 0 r
.46438 .2459 Mdot
.628 .126 .941 r
.18913 .76856 Mdot
.68023 .6513 Mdot
.80103 .6446 Mdot
.48201 .40666 Mdot
.56964 .37315 Mdot
1 .5 0 r
.79817 .80866 Mdot
.84471 .83882 Mdot
.83184 .79861 Mdot
.85115 .85892 Mdot
.77125 .79186 Mdot
.83759 .84547 Mdot
.79105 .81531 Mdot
.40417 .13504 Mdot
.4106 .15515 Mdot
.40961 .22887 Mdot
.628 .126 .941 r
.574 .47348 Mdot
.7062 .61756 Mdot
.38366 .13832 Mdot
.40991 .18188 Mdot
1 .5 0 r
.42179 .29582 Mdot
.628 .126 .941 r
.80305 .87218 Mdot
1 .5 0 r
.83029 .84202 Mdot
.39683 .13155 Mdot
.43644 .17846 Mdot
.628 .126 .941 r
.39584 .20527 Mdot
1 .5 0 r
.77167 .68782 Mdot
.74444 .71798 Mdot
.628 .126 .941 r
.79643 .84197 Mdot
1 .5 0 r
.84991 .85538 Mdot
.38969 .13817 Mdot
.628 .126 .941 r
.73137 .66766 Mdot
.73019 .73128 Mdot
.80199 .87874 Mdot
1 .5 0 r
.8426 .85193 Mdot
.8426 .85193 Mdot
.82279 .82847 Mdot
.85647 .81841 Mdot
.84935 .82507 Mdot
.628 .126 .941 r
.38166 .16141 Mdot
.72318 .68084 Mdot
1 .5 0 r
.8153 .81491 Mdot
.628 .126 .941 r
.80787 .86854 Mdot
1 .5 0 r
.40156 .12775 Mdot
.39442 .13438 Mdot
.44048 .20141 Mdot
.84761 .85838 Mdot
.83473 .81816 Mdot
.88129 .84833 Mdot
.38728 .14101 Mdot
.38728 .14101 Mdot
.628 .126 .941 r
.83355 .8818 Mdot
.82643 .88846 Mdot
1 .5 0 r
.85367 .85829 Mdot
.39332 .14086 Mdot
.84705 .82807 Mdot
.628 .126 .941 r
.79999 .83477 Mdot
.41441 .54307 Mdot
1 .5 0 r
.84637 .85484 Mdot
.82655 .83137 Mdot
.82655 .83137 Mdot
.38598 .13736 Mdot
.8333 .8045 Mdot
.39915 .13058 Mdot
.628 .126 .941 r
.5547 .53959 Mdot
1 .5 0 r
.8133 .77092 Mdot
.83262 .83127 Mdot
.628 .126 .941 r
.81212 .83457 Mdot
.86513 .88486 Mdot
1 .5 0 r
.85869 .86475 Mdot
.43838 .15725 Mdot
.628 .126 .941 r
.67271 .69706 Mdot
.74505 .8077 Mdot
1 .5 0 r
.80499 .84123 Mdot
.8585 .85464 Mdot
.40498 .1203 Mdot
.628 .126 .941 r
.72405 .84789 Mdot
.40428 .14704 Mdot
.64012 .57624 Mdot
.77093 .83107 Mdot
.82394 .88137 Mdot
.81106 .84113 Mdot
1 .5 0 r
.85862 .79754 Mdot
.40408 .13691 Mdot
.43084 .14362 Mdot
.40388 .12678 Mdot
.84369 .83763 Mdot
.84369 .83763 Mdot
.628 .126 .941 r
.86977 .87111 Mdot
.82269 .87782 Mdot
.37482 .1902 Mdot
.43379 .29752 Mdot
1 .5 0 r
.84264 .84419 Mdot
.628 .126 .941 r
.38156 .1633 Mdot
1 .5 0 r
.39543 .12976 Mdot
.628 .126 .941 r
.50595 .39807 Mdot
1 .5 0 r
.84889 .8542 Mdot
.8155 .81726 Mdot
.88241 .83403 Mdot
.87547 .8508 Mdot
.87547 .8508 Mdot
.40147 .12961 Mdot
.40147 .12961 Mdot
.84852 .83398 Mdot
.86797 .83723 Mdot
.628 .126 .941 r
.8873 .89761 Mdot
1 .5 0 r
.46728 .15287 Mdot
.39888 .24679 Mdot
.8539 .86066 Mdot
.8539 .86066 Mdot
.84033 .8472 Mdot
.628 .126 .941 r
.51794 .33052 Mdot
1 .5 0 r
.85353 .84044 Mdot
.87386 .82702 Mdot
.85353 .84044 Mdot
.628 .126 .941 r
.41909 .16606 Mdot
1 .5 0 r
.38588 .13923 Mdot
.628 .126 .941 r
.81964 .84039 Mdot
1 .5 0 r
.39906 .13244 Mdot
.79912 .84369 Mdot
.82639 .8135 Mdot
.8596 .84034 Mdot
.628 .126 .941 r
.41175 .16256 Mdot
1 .5 0 r
.42563 .12901 Mdot
.84603 .82687 Mdot
.85248 .847 Mdot
.86636 .81345 Mdot
.53053 .29334 Mdot
.628 .126 .941 r
.80519 .84359 Mdot
1 .5 0 r
.41134 .14228 Mdot
.628 .126 .941 r
.4044 .15906 Mdot
.10345 .56505 Mdot
.1099 .58519 Mdot
1 .5 0 r
.84516 .84354 Mdot
.628 .126 .941 r
.75096 .85697 Mdot
.37693 .17912 Mdot
.53093 .18911 Mdot
1 .5 0 r
.84479 .82331 Mdot
.85768 .86358 Mdot
.41718 .13199 Mdot
.85749 .85346 Mdot
.85104 .83333 Mdot
.39665 .13528 Mdot
.628 .126 .941 r
.86375 .86348 Mdot
1 .5 0 r
.85018 .85001 Mdot
.628 .126 .941 r
.58567 .51436 Mdot
1 .5 0 r
.61345 .44724 Mdot
.628 .126 .941 r
.87627 .88352 Mdot
.78899 .88016 Mdot
.4734 .84655 Mdot
1 .5 0 r
.83641 .82642 Mdot
.84236 .88347 Mdot
.628 .126 .941 r
.82234 .84986 Mdot
1 .5 0 r
.82928 .83308 Mdot
.40853 .12484 Mdot
.41497 .14497 Mdot
.67733 .61822 Mdot
.628 .126 .941 r
.41626 .52418 Mdot
1 .5 0 r
.61713 .57453 Mdot
.85519 .85648 Mdot
.84874 .83634 Mdot
.52022 .26231 Mdot
.82177 .8195 Mdot
.85482 .83624 Mdot
.40722 .12118 Mdot
.44541 .27895 Mdot
.7832 .64149 Mdot
.83429 .83954 Mdot
.41347 .13118 Mdot
.628 .126 .941 r
.17388 .46016 Mdot
1 .5 0 r
.41326 .12103 Mdot
.628 .126 .941 r
.39293 .13446 Mdot
.41922 .1781 Mdot
1 .5 0 r
.39293 .13446 Mdot
.84663 .84947 Mdot
.78611 .85282 Mdot
.628 .126 .941 r
.37863 .14774 Mdot
1 .5 0 r
.85289 .85949 Mdot
.628 .126 .941 r
.85884 .91656 Mdot
.81878 .84932 Mdot
1 .5 0 r
.86591 .8426 Mdot
.445 .13409 Mdot
.84538 .84591 Mdot
.84538 .84591 Mdot
.628 .126 .941 r
.39696 .15744 Mdot
1 .5 0 r
.40391 .14065 Mdot
.85146 .84581 Mdot
.42901 .24804 Mdot
.83788 .83233 Mdot
.87112 .8592 Mdot
.83788 .83233 Mdot
.628 .126 .941 r
.84383 .88942 Mdot
.81089 .81549 Mdot
1 .5 0 r
.39635 .127 Mdot
.74421 .75163 Mdot
.8504 .85238 Mdot
.8504 .85238 Mdot
.628 .126 .941 r
.30683 .26126 Mdot
1 .5 0 r
.44925 .16722 Mdot
.85022 .84226 Mdot
.85667 .86241 Mdot
.4292 .13356 Mdot
.86969 .84552 Mdot
.86969 .84552 Mdot
.4417 .15357 Mdot
.628 .126 .941 r
.67794 .58349 Mdot
1 .5 0 r
.88936 .8589 Mdot
.88936 .8589 Mdot
.88241 .8757 Mdot
.81522 .84878 Mdot
.42789 .12991 Mdot
.628 .126 .941 r
.26956 .40534 Mdot
1 .5 0 r
.82893 .80506 Mdot
.85505 .8386 Mdot
.8481 .8554 Mdot
.628 .126 .941 r
.37984 .15327 Mdot
1 .5 0 r
.50641 .24061 Mdot
.85486 .82847 Mdot
.87472 .85199 Mdot
.90103 .89566 Mdot
.39999 .12968 Mdot
.86758 .85866 Mdot
.84773 .83514 Mdot
.628 .126 .941 r
.46928 .45212 Mdot
1 .5 0 r
.40603 .12953 Mdot
.64878 .57972 Mdot
.628 .126 .941 r
.85331 .872 Mdot
1 .5 0 r
.39888 .13618 Mdot
.628 .126 .941 r
.13031 .60653 Mdot
.77369 .7678 Mdot
.40443 .17299 Mdot
1 .5 0 r
.8597 .82481 Mdot
.628 .126 .941 r
.80539 .8382 Mdot
1 .5 0 r
.88583 .85836 Mdot
.89873 .89869 Mdot
.628 .126 .941 r
.56837 .43494 Mdot
1 .5 0 r
.66718 .5895 Mdot
.44384 .14245 Mdot
.8381 .8347 Mdot
.84554 .78093 Mdot
.8515 .83806 Mdot
.39646 .13902 Mdot
.44364 .1323 Mdot
.44364 .1323 Mdot
.86404 .85812 Mdot
.85758 .83796 Mdot
.85063 .85476 Mdot
.8844 .84468 Mdot
.628 .126 .941 r
.73871 .6497 Mdot
1 .5 0 r
.85044 .84463 Mdot
.86385 .84799 Mdot
.89067 .85471 Mdot
.40231 .12871 Mdot
.628 .126 .941 r
.58159 .30348 Mdot
1 .5 0 r
.85721 .81769 Mdot
.82344 .82777 Mdot
.628 .126 .941 r
.11307 .60254 Mdot
1 .5 0 r
.41482 .14873 Mdot
.628 .126 .941 r
.09994 .55206 Mdot
1 .5 0 r
.47988 .31342 Mdot
.628 .126 .941 r
.39405 .14186 Mdot
.90861 .90152 Mdot
1 .5 0 r
.822 .81408 Mdot
.84187 .83761 Mdot
.42742 .11146 Mdot
.86851 .8342 Mdot
.628 .126 .941 r
.42622 .17525 Mdot
.22057 .45764 Mdot
1 .5 0 r
.86782 .86104 Mdot
.628 .126 .941 r
.30183 .3937 Mdot
1 .5 0 r
.81498 .7635 Mdot
.86764 .85091 Mdot
.82094 .82065 Mdot
.86049 .85758 Mdot
.84758 .81724 Mdot
.628 .126 .941 r
.85354 .87439 Mdot
1 .5 0 r
.85404 .83741 Mdot
.86745 .84077 Mdot
.90123 .83069 Mdot
.43257 .12796 Mdot
.628 .126 .941 r
.57813 .31288 Mdot
1 .5 0 r
.84689 .84408 Mdot
.84689 .84408 Mdot
.86726 .83064 Mdot
.628 .126 .941 r
.88018 .87098 Mdot
1 .5 0 r
.41846 .15142 Mdot
.51285 .13798 Mdot
.41826 .14126 Mdot
.4111 .14791 Mdot
.40464 .12774 Mdot
.81255 .82376 Mdot
.628 .126 .941 r
.83888 .86747 Mdot
.39748 .13439 Mdot
1 .5 0 r
.43077 .16129 Mdot
.87248 .84725 Mdot
.87248 .84725 Mdot
.41069 .12759 Mdot
.43703 .1713 Mdot
.85192 .85056 Mdot
.83204 .82702 Mdot
.86534 .85392 Mdot
.5208 .42344 Mdot
.628 .126 .941 r
.40263 .15091 Mdot
.12683 .63854 Mdot
1 .5 0 r
.86428 .8605 Mdot
.43572 .16765 Mdot
.40828 .13043 Mdot
.40828 .13043 Mdot
.4217 .13379 Mdot
.628 .126 .941 r
.421 .16063 Mdot
1 .5 0 r
.42746 .18081 Mdot
.46126 .17072 Mdot
.86285 .8468 Mdot
.8698 .82998 Mdot
.86266 .83666 Mdot
.628 .126 .941 r
.4196 .2143 Mdot
.46732 .17057 Mdot
.48024 .21094 Mdot
1 .5 0 r
.85551 .84334 Mdot
.628 .126 .941 r
.56395 .39569 Mdot
.21348 .92052 Mdot
1 .5 0 r
.7288 .63113 Mdot
.88043 .87337 Mdot
.628 .126 .941 r
.41838 .15331 Mdot
1 .5 0 r
.4323 .11966 Mdot
.75546 .62771 Mdot
.78659 .79252 Mdot
.628 .126 .941 r
.40406 .16662 Mdot
.40455 .12961 Mdot
1 .5 0 r
.4314 .13634 Mdot
.45129 .15989 Mdot
.44483 .1397 Mdot
.45129 .15989 Mdot
.45726 .21709 Mdot
.628 .126 .941 r
.39739 .13626 Mdot
1 .5 0 r
.86576 .86645 Mdot
.628 .126 .941 r
.46332 .21695 Mdot
.44372 .14621 Mdot
1 .5 0 r
.43726 .12602 Mdot
.44323 .18323 Mdot
.87185 .86635 Mdot
.43656 .15287 Mdot
.5932 .52641 Mdot
.85177 .83265 Mdot
.628 .126 .941 r
.80304 .95043 Mdot
1 .5 0 r
.88509 .85957 Mdot
.88509 .85957 Mdot
.4093 .12579 Mdot
.628 .126 .941 r
.11916 .63729 Mdot
1 .5 0 r
.83778 .79884 Mdot
.84425 .81904 Mdot
.628 .126 .941 r
.11248 .60694 Mdot
1 .5 0 r
.40819 .1323 Mdot
.40819 .1323 Mdot
.628 .126 .941 r
.44798 .17942 Mdot
1 .5 0 r
.4816 .15915 Mdot
.42768 .13552 Mdot
.87564 .86928 Mdot
.40688 .12864 Mdot
.628 .126 .941 r
.22085 .93656 Mdot
1 .5 0 r
.86203 .85576 Mdot
.628 .126 .941 r
.41265 .17569 Mdot
1 .5 0 r
.88155 .85903 Mdot
.72963 .60648 Mdot
.628 .126 .941 r
.72516 .93978 Mdot
1 .5 0 r
.89411 .87913 Mdot
.628 .126 .941 r
.46457 .22254 Mdot
.16756 .76124 Mdot
1 .5 0 r
.98727 .91944 Mdot
.45173 .12474 Mdot
.50398 .24933 Mdot
.90002 .86889 Mdot
.4172 .16171 Mdot
.4376 .14824 Mdot
.84013 .78802 Mdot
.89268 .86542 Mdot
.41679 .14136 Mdot
.76014 .67343 Mdot
.86662 .77445 Mdot
.8925 .85527 Mdot
.41659 .13118 Mdot
.79876 .7845 Mdot
.92515 .90911 Mdot
.46914 .20856 Mdot
.89144 .86186 Mdot
.4558 .14779 Mdot
.4762 .13432 Mdot
.628 .126 .941 r
.20348 .36335 Mdot
1 .5 0 r
.42245 .12085 Mdot
.50208 .21515 Mdot
.90469 .85508 Mdot
.43569 .11404 Mdot
.87695 .86508 Mdot
.628 .126 .941 r
.46166 .13747 Mdot
1 .5 0 r
.48137 .15087 Mdot
.43458 .12055 Mdot
.43458 .12055 Mdot
.628 .126 .941 r
.43259 .26876 Mdot
1 .5 0 r
.88304 .86498 Mdot
.48067 .17774 Mdot
.79077 .68303 Mdot
.628 .126 .941 r
.43268 .21136 Mdot
1 .5 0 r
.43368 .13724 Mdot
.628 .126 .941 r
.42004 .12369 Mdot
.86158 .88505 Mdot
1 .5 0 r
.44672 .12025 Mdot
.628 .126 .941 r
.92163 .90858 Mdot
1 .5 0 r
.41176 .13687 Mdot
.628 .126 .941 r
.44421 .18053 Mdot
1 .5 0 r
.90676 .8915 Mdot
.628 .126 .941 r
.49081 .20067 Mdot
1 .5 0 r
.8795 .86445 Mdot
.43016 .14661 Mdot
.628 .126 .941 r
.74686 .67231 Mdot
1 .5 0 r
.48374 .1499 Mdot
.628 .126 .941 r
.51242 .50032 Mdot
1 .5 0 r
.443 .11942 Mdot
.87228 .80359 Mdot
.87825 .86088 Mdot
.628 .126 .941 r
.42238 .12272 Mdot
1 .5 0 r
.81961 .65855 Mdot
.83754 .83045 Mdot
.4412 .15283 Mdot
.74452 .67529 Mdot
.89046 .86068 Mdot
.42017 .13575 Mdot
.628 .126 .941 r
.20747 .90099 Mdot
1 .5 0 r
.48721 .14242 Mdot
.41278 .13223 Mdot
.44666 .12212 Mdot
.45812 .27383 Mdot
.53782 .36822 Mdot
.42603 .12541 Mdot
.84201 .80645 Mdot
.85496 .8469 Mdot
.628 .126 .941 r
.23253 .94126 Mdot
1 .5 0 r
.42513 .14212 Mdot
.67623 .53998 Mdot
.49916 .13193 Mdot
.6018 .5298 Mdot
.628 .126 .941 r
.88728 .88047 Mdot
.40429 .13523 Mdot
.56074 .5466 Mdot
1 .5 0 r
.87315 .90403 Mdot
.81416 .74887 Mdot
.628 .126 .941 r
.39601 .14842 Mdot
1 .5 0 r
.41644 .13493 Mdot
.86642 .80604 Mdot
.46985 .12803 Mdot
.628 .126 .941 r
.44792 .25282 Mdot
1 .5 0 r
.77914 .69796 Mdot
.86486 .84973 Mdot
.93164 .9037 Mdot
.44902 .12114 Mdot
.90436 .87662 Mdot
.628 .126 .941 r
.48051 .23905 Mdot
1 .5 0 r
.44791 .12766 Mdot
.46067 .15794 Mdot
.45419 .1377 Mdot
.46067 .15794 Mdot
.8699 .85623 Mdot
.42707 .12076 Mdot
.45378 .11731 Mdot
.4466 .12398 Mdot
.628 .126 .941 r
.4798 .14078 Mdot
.90206 .87965 Mdot
.922 .90327 Mdot
1 .5 0 r
.43922 .12046 Mdot
.45916 .14408 Mdot
.88841 .86611 Mdot
.87476 .85256 Mdot
.628 .126 .941 r
.56446 .29914 Mdot
1 .5 0 r
.43811 .12698 Mdot
.628 .126 .941 r
.11402 .62301 Mdot
.9073 .89633 Mdot
1 .5 0 r
.89433 .85584 Mdot
.44419 .12683 Mdot
.628 .126 .941 r
.91341 .89623 Mdot
.89296 .90973 Mdot
1 .5 0 r
.45047 .13688 Mdot
.80732 .7004 Mdot
.628 .126 .941 r
.40897 .13328 Mdot
1 .5 0 r
.53514 .29528 Mdot
.93211 .91629 Mdot
.628 .126 .941 r
.42223 .12646 Mdot
.42173 .16358 Mdot
1 .5 0 r
.4357 .12983 Mdot
.42872 .14671 Mdot
.44198 .13988 Mdot
.49564 .14318 Mdot
.628 .126 .941 r
.40587 .28833 Mdot
1 .5 0 r
.48816 .19719 Mdot
.89116 .87564 Mdot
.90463 .87902 Mdot
.5531 .3422 Mdot
.628 .126 .941 r
.95064 .92618 Mdot
1 .5 0 r
.85749 .7708 Mdot
.90338 .87545 Mdot
.628 .126 .941 r
.94329 .92271 Mdot
1 .5 0 r
.43328 .13268 Mdot
.57296 .29811 Mdot
.628 .126 .941 r
.88224 .91591 Mdot
.41262 .13598 Mdot
.41262 .13598 Mdot
.43258 .15962 Mdot
1 .5 0 r
.54682 .20688 Mdot
.45263 .12571 Mdot
.8757 .82799 Mdot
.628 .126 .941 r
.10724 .60497 Mdot
1 .5 0 r
.53096 .20638 Mdot
.92715 .90203 Mdot
.628 .126 .941 r
.41648 .14889 Mdot
1 .5 0 r
.4569 .15903 Mdot
.628 .126 .941 r
.6615 .52713 Mdot
.42715 .26006 Mdot
1 .5 0 r
.91924 .86801 Mdot
.628 .126 .941 r
.93802 .95578 Mdot
1 .5 0 r
.92504 .91525 Mdot
.4487 .11467 Mdot
.4487 .11467 Mdot
.628 .126 .941 r
.91138 .90169 Mdot
1 .5 0 r
.45499 .12473 Mdot
.42085 .12465 Mdot
.46058 .16174 Mdot
.49432 .14139 Mdot
.46087 .11437 Mdot
.628 .126 .941 r
.79932 .5907 Mdot
.40576 .16497 Mdot
1 .5 0 r
.44669 .13794 Mdot
.44619 .1751 Mdot
.87682 .81357 Mdot
.45258 .12758 Mdot
.4386 .16137 Mdot
.45957 .11069 Mdot
.45886 .13764 Mdot
.628 .126 .941 r
.66307 .54311 Mdot
1 .5 0 r
.42471 .13757 Mdot
.628 .126 .941 r
.46275 .27596 Mdot
1 .5 0 r
.94111 .91802 Mdot
.45756 .13396 Mdot
.628 .126 .941 r
.43039 .11699 Mdot
1 .5 0 r
.79392 .74895 Mdot
.46993 .14388 Mdot
.628 .126 .941 r
.53266 .48516 Mdot
1 .5 0 r
.88574 .89074 Mdot
.628 .126 .941 r
.42208 .13021 Mdot
.44885 .12675 Mdot
.4928 .38026 Mdot
1 .5 0 r
.44865 .11654 Mdot
.46863 .1402 Mdot
.83174 .80947 Mdot
.46143 .14688 Mdot
.46843 .12998 Mdot
.628 .126 .941 r
.60709 .35978 Mdot
1 .5 0 r
.44055 .13997 Mdot
.79771 .75185 Mdot
.44643 .12961 Mdot
.45992 .13299 Mdot
.628 .126 .941 r
.42475 .2073 Mdot
1 .5 0 r
.45182 .15643 Mdot
.628 .126 .941 r
.43783 .19024 Mdot
1 .5 0 r
.44492 .1157 Mdot
.4784 .14276 Mdot
.45841 .11909 Mdot
.628 .126 .941 r
.12592 .66007 Mdot
.53366 .53833 Mdot
.35965 .31494 Mdot
.17026 .80871 Mdot
.42851 .15238 Mdot
1 .5 0 r
.46118 .13855 Mdot
.51417 .22651 Mdot
.44049 .14186 Mdot
.61244 .44633 Mdot
.75141 .68651 Mdot
.50017 .13479 Mdot
.628 .126 .941 r
.93662 .91637 Mdot
.41827 .13126 Mdot
1 .5 0 r
.45857 .13119 Mdot
.628 .126 .941 r
.93557 .92299 Mdot
.61787 .34768 Mdot
1 .5 0 r
.46446 .12081 Mdot
.48426 .13427 Mdot
.628 .126 .941 r
.44985 .12397 Mdot
.44965 .11374 Mdot
.42823 .14405 Mdot
.14915 .74655 Mdot
1 .5 0 r
.94534 .91566 Mdot
.628 .126 .941 r
.16616 .81051 Mdot
1 .5 0 r
.45262 .14345 Mdot
.45963 .12652 Mdot
.94918 .91862 Mdot
.86293 .75602 Mdot
.628 .126 .941 r
.43018 .12261 Mdot
.96058 .93527 Mdot
1 .5 0 r
.48292 .13247 Mdot
.628 .126 .941 r
.42776 .12547 Mdot
.46079 .18983 Mdot
1 .5 0 r
.53568 .14233 Mdot
.48141 .11854 Mdot
.48752 .11839 Mdot
.48752 .11839 Mdot
.628 .126 .941 r
.19194 .89419 Mdot
1 .5 0 r
.67105 .56554 Mdot
.93702 .91104 Mdot
.5533 .16891 Mdot
.628 .126 .941 r
.48551 .14173 Mdot
1 .5 0 r
.45847 .13495 Mdot
.46528 .10777 Mdot
.49182 .15182 Mdot
.8161 .72785 Mdot
.47138 .10762 Mdot
.628 .126 .941 r
.17601 .83614 Mdot
.18117 .85289 Mdot
.99408 .94441 Mdot
.98688 .95114 Mdot
.40665 .17819 Mdot
.44822 .11379 Mdot
.46075 .19175 Mdot
.5422 .16456 Mdot
.43379 .1272 Mdot
1 .5 0 r
.4396 .17458 Mdot
.628 .126 .941 r
.16164 .60842 Mdot
1 .5 0 r
.47306 .13367 Mdot
.79822 .68296 Mdot
.628 .126 .941 r
.47265 .11318 Mdot
.45712 .25899 Mdot
.19357 .67946 Mdot
.45802 .11634 Mdot
.45781 .10609 Mdot
1 .5 0 r
.98932 .94032 Mdot
.48397 .12968 Mdot
.628 .126 .941 r
.49028 .13978 Mdot
1 .5 0 r
.47675 .13639 Mdot
.628 .126 .941 r
.99547 .94023 Mdot
1 .5 0 r
.46953 .1431 Mdot
.49639 .13963 Mdot
.628 .126 .941 r
.97455 .93335 Mdot
1 .5 0 r
.48246 .11574 Mdot
.45539 .10895 Mdot
.56947 .18351 Mdot
.628 .126 .941 r
.1863 .88228 Mdot
.21286 .92638 Mdot
.45428 .11551 Mdot
.3846 .24782 Mdot
1 .5 0 r
.48115 .11204 Mdot
.628 .126 .941 r
.98597 .95004 Mdot
.46039 .11536 Mdot
.48004 .1186 Mdot
.71719 .66488 Mdot
1 .5 0 r
.47241 .1048 Mdot
.61732 .44075 Mdot
.628 .126 .941 r
.17707 .85474 Mdot
.47873 .1149 Mdot
.46519 .11151 Mdot
1 .5 0 r
.45817 .12847 Mdot
.628 .126 .941 r
.9835 .94288 Mdot
1 .5 0 r
.96996 .93949 Mdot
.49096 .1146 Mdot
.628 .126 .941 r
.6023 .42345 Mdot
1 .5 0 r
.71594 .5354 Mdot
.628 .126 .941 r
.9958 .94269 Mdot
.40028 .24003 Mdot
.46277 .11437 Mdot
1 .5 0 r
.4754 .13458 Mdot
.628 .126 .941 r
.98736 .94586 Mdot
1 .5 0 r
.48854 .11746 Mdot
.628 .126 .941 r
.45893 .17141 Mdot
1 .5 0 r
.94511 .91162 Mdot
.628 .126 .941 r
.99227 .94218 Mdot
1 .5 0 r
.99227 .94218 Mdot
.99227 .94218 Mdot
.628 .126 .941 r
.4784 .16439 Mdot
1 .5 0 r
.48522 .13715 Mdot
.628 .126 .941 r
.49174 .15753 Mdot
1 .5 0 r
.46394 .17783 Mdot
.46444 .14047 Mdot
.48461 .10636 Mdot
.48391 .13345 Mdot
.49023 .14357 Mdot
.99613 .94516 Mdot
.47648 .12991 Mdot
.54875 .31673 Mdot
.628 .126 .941 r
.14271 .68357 Mdot
.4833 .10266 Mdot
1 .5 0 r
.55708 .17739 Mdot
.628 .126 .941 r
.14802 .76843 Mdot
.47557 .14674 Mdot
1 .5 0 r
.4826 .12976 Mdot
.628 .126 .941 r
.10212 .61552 Mdot
1 .5 0 r
.48239 .11949 Mdot
.48852 .11934 Mdot
.46793 .13293 Mdot
.47496 .11594 Mdot
.628 .126 .941 r
.46723 .16003 Mdot
.56763 .27894 Mdot
1 .5 0 r
.48741 .12591 Mdot
.628 .126 .941 r
.46481 .28899 Mdot
.4861 .1222 Mdot
1 .5 0 r
.49965 .1256 Mdot
.49242 .13232 Mdot
.628 .126 .941 r
.45154 .11186 Mdot
.4651 .11526 Mdot
1 .5 0 r
.49222 .12205 Mdot
.51281 .10846 Mdot
.50467 .13202 Mdot
.48438 .09796 Mdot
.628 .126 .941 r
.47011 .12167 Mdot
.47011 .12167 Mdot
1 .5 0 r
.54405 .13852 Mdot
.628 .126 .941 r
.55691 .16904 Mdot
1 .5 0 r
.48869 .13149 Mdot
.628 .126 .941 r
.49482 .13134 Mdot
.34913 .33873 Mdot
1 .5 0 r
.52878 .11087 Mdot
.628 .126 .941 r
.50768 .16187 Mdot
.48738 .12779 Mdot
.46005 .11072 Mdot
.47994 .12424 Mdot
1 .5 0 r
.4722 .16837 Mdot
.5338 .11729 Mdot
.48345 .24289 Mdot
.49812 .11351 Mdot
.49088 .12023 Mdot
.48364 .12696 Mdot
.628 .126 .941 r
.30874 .47731 Mdot
1 .5 0 r
.48253 .13354 Mdot
.4957 .11637 Mdot
.50857 .14692 Mdot
.48122 .12983 Mdot
.47398 .13656 Mdot
.54748 .19085 Mdot
.49419 .10238 Mdot
.74055 .52091 Mdot
.628 .126 .941 r
.47246 .12257 Mdot
.49962 .12938 Mdot
1 .5 0 r
.49962 .12938 Mdot
.54668 .14972 Mdot
.49106 .1324 Mdot
.47708 .10843 Mdot
.50424 .11523 Mdot
.51761 .10835 Mdot
.628 .126 .941 r
.49045 .10154 Mdot
.50313 .12181 Mdot
.1337 .71409 Mdot
.49548 .10797 Mdot
1 .5 0 r
.52264 .11478 Mdot
.50906 .11137 Mdot
.628 .126 .941 r
.48823 .1147 Mdot
1 .5 0 r
.67488 .42453 Mdot
.628 .126 .941 r
.48753 .14186 Mdot
1 .5 0 r
.51409 .1178 Mdot
.50644 .10395 Mdot
.628 .126 .941 r
.49194 .11742 Mdot
1 .5 0 r
.51207 .14126 Mdot
.51187 .13097 Mdot
.51117 .15814 Mdot
.628 .126 .941 r
.4557 .1511 Mdot
.50291 .1134 Mdot
.50291 .1134 Mdot
1 .5 0 r
.50945 .13384 Mdot
.59483 .35181 Mdot
.53392 .19132 Mdot
.50683 .12642 Mdot
.48568 .17754 Mdot
.51337 .14687 Mdot
.50512 .22858 Mdot
.51952 .14672 Mdot
.49847 .13975 Mdot
.628 .126 .941 r
.56625 .14649 Mdot
1 .5 0 r
.49172 .109 Mdot
.628 .126 .941 r
.60383 .37138 Mdot
1 .5 0 r
.5176 .11211 Mdot
.628 .126 .941 r
.4897 .13248 Mdot
1 .5 0 r
.51015 .10854 Mdot
.628 .126 .941 r
.50924 .12544 Mdot
1 .5 0 r
.54349 .11521 Mdot
.52264 .11854 Mdot
.628 .126 .941 r
.49523 .10142 Mdot
1 .5 0 r
.50158 .11157 Mdot
.628 .126 .941 r
.13134 .69452 Mdot
.48545 .16916 Mdot
1 .5 0 r
.55378 .1384 Mdot
.628 .126 .941 r
.4921 .1315 Mdot
.49915 .11445 Mdot
1 .5 0 r
.52616 .11096 Mdot
.628 .126 .941 r
.49895 .10414 Mdot
1 .5 0 r
.53957 .10406 Mdot
.53231 .11081 Mdot
.59279 .18244 Mdot
.80448 .68725 Mdot
.628 .126 .941 r
.49078 .12779 Mdot
1 .5 0 r
.51074 .14135 Mdot
.628 .126 .941 r
.51709 .15151 Mdot
.51034 .12073 Mdot
1 .5 0 r
.50913 .18548 Mdot
.628 .126 .941 r
.50287 .11717 Mdot
.55712 .12051 Mdot
.50267 .10686 Mdot
1 .5 0 r
.482 .12051 Mdot
.628 .126 .941 r
.4945 .13051 Mdot
1 .5 0 r
.50811 .13393 Mdot
.5422 .11338 Mdot
.52132 .11671 Mdot
.50065 .13036 Mdot
.52132 .11671 Mdot
.5068 .13021 Mdot
.5068 .13021 Mdot
.628 .126 .941 r
.50559 .19498 Mdot
.49298 .11648 Mdot
1 .5 0 r
.5543 .10276 Mdot
.628 .126 .941 r
.50569 .13681 Mdot
.49802 .12293 Mdot
1 .5 0 r
.53212 .10237 Mdot
.53101 .10897 Mdot
.628 .126 .941 r
.58549 .12262 Mdot
1 .5 0 r
.50942 .13954 Mdot
.628 .126 .941 r
.14547 .75403 Mdot
1 .5 0 r
.51537 .12907 Mdot
.51517 .11875 Mdot
.52828 .15973 Mdot
.53585 .10509 Mdot
.8961 .76069 Mdot
.52859 .11185 Mdot
.53454 .10137 Mdot
.628 .126 .941 r
.47227 .13203 Mdot
1 .5 0 r
.5409 .11154 Mdot
.628 .126 .941 r
.51294 .13196 Mdot
1 .5 0 r
.54706 .11139 Mdot
.53959 .10782 Mdot
.52526 .13165 Mdot
.55958 .12141 Mdot
.628 .126 .941 r
.1144 .68843 Mdot
1 .5 0 r
.68032 .24423 Mdot
.52415 .13826 Mdot
.628 .126 .941 r
.49689 .13143 Mdot
1 .5 0 r
.51667 .13469 Mdot
.628 .126 .941 r
.50991 .10387 Mdot
.12479 .72215 Mdot
1 .5 0 r
.82354 .63331 Mdot
.55676 .10364 Mdot
.628 .126 .941 r
.50132 .1069 Mdot
1 .5 0 r
.52111 .11016 Mdot
.51334 .15451 Mdot
.52728 .11001 Mdot
.82648 .65319 Mdot
.52526 .13355 Mdot
.53587 .10886 Mdot
.52768 .13257 Mdot
.53475 .11547 Mdot
.628 .126 .941 r
.40973 .22483 Mdot
1 .5 0 r
.548 .09821 Mdot
.60156 .18714 Mdot
.628 .126 .941 r
.51292 .13576 Mdot
1 .5 0 r
.54689 .10482 Mdot
.628 .126 .941 r
.12768 .70677 Mdot
1 .5 0 r
.76554 .62126 Mdot
.52505 .12512 Mdot
.88647 .74429 Mdot
.54416 .15568 Mdot
.58411 .11424 Mdot
.54245 .13128 Mdot
.56955 .12778 Mdot
.628 .126 .941 r
.51423 .14139 Mdot
.22254 .8976 Mdot
1 .5 0 r
.54801 .10009 Mdot
.85612 .57228 Mdot
.75443 .29448 Mdot
.52262 .12991 Mdot
.628 .126 .941 r
.28591 .86258 Mdot
1 .5 0 r
.54883 .14338 Mdot
.57666 .11256 Mdot
.53426 .15693 Mdot
.628 .126 .941 r
.53456 .1089 Mdot
1 .5 0 r
.56119 .14307 Mdot
.52707 .10532 Mdot
.54661 .15662 Mdot
.53872 .13234 Mdot
.628 .126 .941 r
.59897 .11483 Mdot
1 .5 0 r
.55796 .10455 Mdot
.58288 .11429 Mdot
.57539 .11071 Mdot
.58127 .15862 Mdot
.56152 .09693 Mdot
.85203 .72025 Mdot
.628 .126 .941 r
.48756 .24016 Mdot
.39463 .49041 Mdot
.56417 .10629 Mdot
1 .5 0 r
.57765 .09935 Mdot
.64484 .18158 Mdot
.56964 .13349 Mdot
.57015 .09577 Mdot
.628 .126 .941 r
.4844 .14317 Mdot
.58669 .11893 Mdot
1 .5 0 r
.51755 .12915 Mdot
.55111 .13586 Mdot
.628 .126 .941 r
.1379 .73288 Mdot
1 .5 0 r
.52992 .12884 Mdot
.58518 .10482 Mdot
.56399 .0978 Mdot
.628 .126 .941 r
.13421 .74263 Mdot
1 .5 0 r
.51247 .12457 Mdot
.53986 .13143 Mdot
.58674 .12083 Mdot
.53103 .12411 Mdot
.57701 .13052 Mdot
.5952 .1093 Mdot
.6014 .10914 Mdot
.628 .126 .941 r
.1496 .79588 Mdot
1 .5 0 r
.55471 .13205 Mdot
.56731 .14213 Mdot
.628 .126 .941 r
.57422 .11455 Mdot
1 .5 0 r
.56488 .14504 Mdot
.79844 .34351 Mdot
.628 .126 .941 r
.53745 .14008 Mdot
1 .5 0 r
.55587 .12922 Mdot
.59706 .13955 Mdot
.628 .126 .941 r
.12552 .7485 Mdot
.14587 .7726 Mdot
1 .5 0 r
.56963 .13458 Mdot
.628 .126 .941 r
.38691 .39291 Mdot
1 .5 0 r
.55895 .16138 Mdot
.59565 .12922 Mdot
.97123 .88758 Mdot
.628 .126 .941 r
.54613 .14278 Mdot
1 .5 0 r
.57365 .14968 Mdot
.57324 .12884 Mdot
.628 .126 .941 r
.40265 .44594 Mdot
1 .5 0 r
.73009 .19413 Mdot
.76855 .31455 Mdot
.628 .126 .941 r
.52728 .13474 Mdot
1 .5 0 r
.59307 .12362 Mdot
.76241 .2475 Mdot
.66331 .14656 Mdot
.628 .126 .941 r
.54976 .14089 Mdot
1 .5 0 r
.76661 .25431 Mdot
.62594 .14282 Mdot
.63218 .14267 Mdot
.58946 .12852 Mdot
.65625 .15921 Mdot
.628 .126 .941 r
.47879 .22077 Mdot
.53281 .17185 Mdot
1 .5 0 r
.74886 .22268 Mdot
.63839 .13591 Mdot
.76843 .26411 Mdot
.76713 .26036 Mdot
.76713 .26036 Mdot
.75032 .22844 Mdot
.74185 .24201 Mdot
.72096 .19679 Mdot
.72612 .20335 Mdot
.6425 .1511 Mdot
.73219 .19272 Mdot
.71078 .18564 Mdot
.74512 .21339 Mdot
.628 .126 .941 r
.35676 .46254 Mdot
1 .5 0 r
.71443 .17795 Mdot
.62965 .13238 Mdot
.65715 .12883 Mdot
.69726 .19462 Mdot
.76528 .27786 Mdot
.75175 .22572 Mdot
.70314 .1735 Mdot
.71267 .14465 Mdot
.65633 .14797 Mdot
.73138 .2034 Mdot
.71693 .16843 Mdot
.628 .126 .941 r
.54968 .14396 Mdot
1 .5 0 r
.67403 .15423 Mdot
.628 .126 .941 r
.49536 .51213 Mdot
1 .5 0 r
.77234 .50145 Mdot
.74062 .22328 Mdot
.76065 .28584 Mdot
.67614 .26122 Mdot
.75227 .24022 Mdot
.76153 .26014 Mdot
.74485 .23861 Mdot
.7617 .26216 Mdot
.73294 .20262 Mdot
.6486 .12913 Mdot
.628 .126 .941 r
.3714 .48066 Mdot
1 .5 0 r
.77525 .30599 Mdot
.69322 .15963 Mdot
.61398 .22196 Mdot
.72721 .47807 Mdot
.628 .126 .941 r
.43555 .62742 Mdot
1 .5 0 r
.77952 .31298 Mdot
.70201 .21134 Mdot
.75029 .23221 Mdot
.628 .126 .941 r
.56286 .25011 Mdot
.49615 .40848 Mdot
.57471 .47253 Mdot
.54696 .42476 Mdot
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.567362 0.97619 1.05965 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.15686 .86275 Mdot
.30196 .71765 Mdot
.63922 .4902 Mdot
.58824 .43137 Mdot
.6902 .52549 Mdot
.30588 .72157 Mdot
.75294 .40784 Mdot
.66667 .42745 Mdot
.29412 .72157 Mdot
.5451 .25098 Mdot
.44706 .05098 Mdot
.61569 .48235 Mdot
.63529 .49412 Mdot
.81176 .07451 Mdot
.63137 .24706 Mdot
.58039 .42745 Mdot
.41569 .07059 Mdot
.84706 .08235 Mdot
.49804 .06275 Mdot
.57255 .43137 Mdot
.43922 .01569 Mdot
.79608 .08235 Mdot
.57255 .02745 Mdot
.61961 .49804 Mdot
.40392 .01569 Mdot
.62745 .03529 Mdot
.52549 .02745 Mdot
.8549 .83137 Mdot
.59216 .39216 Mdot
.61176 .01569 Mdot
.87059 .16863 Mdot
.49804 .01176 Mdot
.58431 .45882 Mdot
.54118 .01961 Mdot
.64706 .02745 Mdot
.69412 .03529 Mdot
.81176 .80392 Mdot
.57255 .40392 Mdot
.59608 .00784 Mdot
.65882 .0549 Mdot
.61569 .03529 Mdot
.67451 .65098 Mdot
.39216 .06667 Mdot
.63922 .02745 Mdot
.68235 .07059 Mdot
.55686 .04314 Mdot
.76078 .74118 Mdot
.4 .0549 Mdot
.60784 .01569 Mdot
.67059 .06667 Mdot
.24314 .03922 Mdot
.84314 .82353 Mdot
.38824 .18039 Mdot
.61176 .01569 Mdot
.69412 .06275 Mdot
.55686 .51373 Mdot
.83529 .73725 Mdot
.12941 .84706 Mdot
.55294 .01569 Mdot
.68627 .03922 Mdot
.81569 .7451 Mdot
.58431 .02353 Mdot
.79608 .81176 Mdot
.43922 .01176 Mdot
.6549 .02745 Mdot
.48627 .11765 Mdot
.91373 .87451 Mdot
.87451 .84314 Mdot
.51765 .32941 Mdot
.54902 .01961 Mdot
.68627 .03922 Mdot
.92549 .90196 Mdot
.47843 .06275 Mdot
.83137 .83529 Mdot
.3098 0 Mdot
.59216 .02353 Mdot
.63529 .07059 Mdot
.90196 .89804 Mdot
.49412 .05882 Mdot
.80784 .81176 Mdot
.43922 .00784 Mdot
.63529 .01569 Mdot
.83137 .76078 Mdot
.90196 .90196 Mdot
.89412 .83137 Mdot
.65882 .62353 Mdot
.4549 0 Mdot
.62745 .02353 Mdot
.9098 .8902 Mdot
.88235 .88235 Mdot
.72157 .68235 Mdot
.66275 .6 Mdot
.56078 .01961 Mdot
.62745 .02745 Mdot
.88627 .8902 Mdot
.8902 .88235 Mdot
.76078 .67059 Mdot
.57647 .54902 Mdot
.73725 .05098 Mdot
.61176 .02353 Mdot
.89804 .89804 Mdot
.88235 .88235 Mdot
.41569 .11373 Mdot
.75294 .75686 Mdot
.7451 .0549 Mdot
.62745 .02353 Mdot
.88627 .8902 Mdot
.87451 .87451 Mdot
.52549 .01961 Mdot
.81569 .81569 Mdot
.70196 .08627 Mdot
.63137 .02353 Mdot
.87059 .86667 Mdot
.89804 .87843 Mdot
.48627 .04314 Mdot
.8 .81569 Mdot
.60392 .00784 Mdot
.53333 .01176 Mdot
.82353 .75294 Mdot
.8902 .82745 Mdot
.87451 .85098 Mdot
.8 .78431 Mdot
.5098 .00392 Mdot
.79216 .0549 Mdot
.56078 .07059 Mdot
.88627 .87451 Mdot
.87059 .86667 Mdot
.78824 .75294 Mdot
.3451 .14902 Mdot
.72549 .04314 Mdot
.63529 .02745 Mdot
.88235 .88627 Mdot
.61569 .05882 Mdot
.56863 .06275 Mdot
.81569 .83137 Mdot
.67843 .03529 Mdot
.80392 .05098 Mdot
.85882 .85098 Mdot
.62353 .07451 Mdot
.84706 .8549 Mdot
.81961 .80784 Mdot
.53333 .09412 Mdot
.76078 .04314 Mdot
.59608 .02745 Mdot
.88627 .78824 Mdot
.61569 .03922 Mdot
.49412 .02745 Mdot
.75294 .77255 Mdot
.65098 .02353 Mdot
.81176 .0549 Mdot
.84706 .84314 Mdot
.65098 .05098 Mdot
.84706 .84706 Mdot
.71765 .70196 Mdot
.55294 .1098 Mdot
.73333 .04314 Mdot
.58039 .02745 Mdot
.61961 .18824 Mdot
.61569 .03529 Mdot
.51373 .03922 Mdot
.8 .81961 Mdot
.64706 .02353 Mdot
.8 .05098 Mdot
.87059 .85098 Mdot
.65882 .07059 Mdot
.87059 .82745 Mdot
.76078 .72941 Mdot
.35686 .28627 Mdot
.72157 .03922 Mdot
.83922 .07843 Mdot
.64706 .0902 Mdot
.6549 .03922 Mdot
.64706 .19216 Mdot
.8 .81569 Mdot
.58039 .00784 Mdot
.77647 .05098 Mdot
.84314 .83922 Mdot
.6549 .07843 Mdot
.55294 .00392 Mdot
.66667 .33725 Mdot
.54118 .47843 Mdot
.63529 .01569 Mdot
.81961 .06275 Mdot
.64706 .41961 Mdot
.16078 .03137 Mdot
.8549 .84314 Mdot
.64706 .62353 Mdot
.43922 .14118 Mdot
.7451 .04706 Mdot
.83529 .74118 Mdot
.66275 .07059 Mdot
.61569 .03922 Mdot
.65098 .15686 Mdot
.73333 .75294 Mdot
.56863 .00392 Mdot
.78824 .05882 Mdot
.86275 .85098 Mdot
.72157 .66275 Mdot
.53333 .00784 Mdot
.43529 .17647 Mdot
.36863 .29412 Mdot
.63137 .01176 Mdot
.82745 .07059 Mdot
.66275 .0549 Mdot
.89412 .84706 Mdot
.76078 .61961 Mdot
.66275 .65882 Mdot
.62745 .62745 Mdot
.73333 .04314 Mdot
.8902 .88627 Mdot
.23529 .08235 Mdot
.61176 .04314 Mdot
.68235 .06667 Mdot
.73725 .77255 Mdot
.55686 .00784 Mdot
.78039 .04706 Mdot
.83922 .6549 Mdot
.8902 .88627 Mdot
.54902 .00784 Mdot
.5451 .22353 Mdot
.47059 .45098 Mdot
.60392 .00784 Mdot
.81176 .07059 Mdot
.62745 .05098 Mdot
.87843 .87843 Mdot
.83529 .77647 Mdot
.69412 .66275 Mdot
.45882 .48235 Mdot
.71373 .03922 Mdot
.88627 .88235 Mdot
.88235 .85098 Mdot
.51765 .23922 Mdot
.75294 .03529 Mdot
.77255 .80784 Mdot
.20392 .00392 Mdot
.78039 .04706 Mdot
.74902 .12157 Mdot
.87059 .87843 Mdot
.60392 .02353 Mdot
.51373 .01569 Mdot
.56078 .60784 Mdot
.56078 .00392 Mdot
.78431 .07451 Mdot
.62353 .11373 Mdot
.87059 .87451 Mdot
.86275 .83529 Mdot
.80392 .68627 Mdot
.76471 .75294 Mdot
.63922 .04706 Mdot
.87843 .88235 Mdot
.87843 .88235 Mdot
.68627 .52941 Mdot
.72549 .04706 Mdot
.80392 .83529 Mdot
.16863 .00784 Mdot
.76078 .04706 Mdot
.81961 .07843 Mdot
.89412 .88235 Mdot
.63922 .02353 Mdot
.67451 .04706 Mdot
.52549 .57647 Mdot
.47843 .00784 Mdot
.73725 .0902 Mdot
.44706 .25882 Mdot
.8549 .80784 Mdot
.83529 .81176 Mdot
.58039 .23137 Mdot
.50588 .6549 Mdot
.64314 .03137 Mdot
.85882 .85882 Mdot
.86667 .86667 Mdot
.51765 .23529 Mdot
.54118 0 Mdot
.79608 .82353 Mdot
.1451 .01176 Mdot
.63137 .05882 Mdot
.77255 .05882 Mdot
.56078 .19608 Mdot
.62745 .02353 Mdot
.70588 .02353 Mdot
.79608 .83137 Mdot
.03529 0 Mdot
.76471 .05098 Mdot
.43529 .17647 Mdot
.34902 .08235 Mdot
.75686 .55686 Mdot
.50588 .03529 Mdot
.21569 .21176 Mdot
.44314 .01176 Mdot
.86275 .87843 Mdot
.85098 .85098 Mdot
.80392 .71373 Mdot
.53725 .03922 Mdot
.81176 .61961 Mdot
.32157 .36863 Mdot
.63922 .03529 Mdot
.74902 .06275 Mdot
.59216 .10588 Mdot
.63922 .03922 Mdot
.52549 0 Mdot
.8 .81961 Mdot
.05098 .01176 Mdot
.74902 .04314 Mdot
.75294 .08627 Mdot
.29804 .07059 Mdot
.58431 .03137 Mdot
.6902 .02353 Mdot
.69412 .7451 Mdot
.16078 .00392 Mdot
.6902 .5451 Mdot
.84314 .84314 Mdot
.88235 .82353 Mdot
.83529 .80392 Mdot
.52157 .01961 Mdot
.43922 .34118 Mdot
.41176 .00784 Mdot
.61569 .22353 Mdot
.87843 .85882 Mdot
.65098 .04706 Mdot
.53725 .00392 Mdot
.73333 .63137 Mdot
.24314 .28627 Mdot
.68235 .03137 Mdot
.46275 .04314 Mdot
.28235 .17255 Mdot
.63529 .02745 Mdot
.52549 .00784 Mdot
.73725 .77255 Mdot
.00392 0 Mdot
.76471 .06275 Mdot
.85882 .84314 Mdot
.86667 .86275 Mdot
.76863 .50588 Mdot
.68235 .03137 Mdot
.49804 .56471 Mdot
.21176 .00392 Mdot
.87059 .87843 Mdot
.76471 .14118 Mdot
.18824 .04314 Mdot
.51373 .03137 Mdot
.47843 .03529 Mdot
.30196 .73725 Mdot
.43137 0 Mdot
.68235 .61569 Mdot
.88627 .87059 Mdot
.55294 .07451 Mdot
.51765 .00392 Mdot
.64706 .60392 Mdot
.03922 .00392 Mdot
.6902 .03529 Mdot
.66667 .4 Mdot
.7098 .73333 Mdot
.63137 .03137 Mdot
.51373 .00392 Mdot
.78824 .83137 Mdot
.08235 .00392 Mdot
.88235 .68235 Mdot
.32941 .2902 Mdot
.86275 .81569 Mdot
.83529 .81569 Mdot
.67059 .01961 Mdot
.48627 .53333 Mdot
.23137 .00392 Mdot
.36471 .13333 Mdot
.80392 .76471 Mdot
.87059 .8549 Mdot
.56078 .00784 Mdot
.53725 .02745 Mdot
.31765 .36863 Mdot
.43137 .01176 Mdot
.86275 .84314 Mdot
.84706 .82353 Mdot
.51765 .07843 Mdot
.53725 .01569 Mdot
.6549 .6549 Mdot
.00392 .00392 Mdot
.75294 .05098 Mdot
.89412 .80392 Mdot
.86667 .86667 Mdot
.7451 .45098 Mdot
.50196 .00392 Mdot
.72941 .78431 Mdot
.15294 .00392 Mdot
.79216 .8 Mdot
.88627 .84314 Mdot
.86667 .85882 Mdot
.44314 .09412 Mdot
.67451 .01569 Mdot
.63529 .59216 Mdot
.24706 0 Mdot
.83137 .80784 Mdot
.81569 .78431 Mdot
.85098 .85098 Mdot
.56078 .00784 Mdot
.59216 .0549 Mdot
.08235 .11765 Mdot
.50588 .01176 Mdot
.75294 .04706 Mdot
.90196 .90196 Mdot
.60392 .05098 Mdot
.51373 .00392 Mdot
.6549 .69804 Mdot
0 0 Mdot
.76078 .04706 Mdot
.76863 .08627 Mdot
.86275 .86275 Mdot
.83137 .82745 Mdot
.51373 0 Mdot
.72157 .78431 Mdot
.17647 0 Mdot
.65882 .18824 Mdot
.32549 .08235 Mdot
.86275 .8 Mdot
.58039 .01961 Mdot
.67451 .02353 Mdot
.26275 .68627 Mdot
.41176 .01569 Mdot
.76471 .05882 Mdot
.8902 .8902 Mdot
.85098 .82745 Mdot
.53333 .00784 Mdot
.50196 .04314 Mdot
.00392 0 Mdot
.54118 .01176 Mdot
.75686 .05098 Mdot
.94902 .77647 Mdot
.58039 .20392 Mdot
.52549 .00392 Mdot
.72941 .78431 Mdot
.09804 .00392 Mdot
.78431 .05882 Mdot
.56863 .08235 Mdot
.75294 .09412 Mdot
.84706 .80392 Mdot
.52549 .00392 Mdot
.43529 .49412 Mdot
.34118 .00392 Mdot
.72157 .03137 Mdot
.84706 .8549 Mdot
.84706 .84314 Mdot
.56471 .00784 Mdot
.69412 .03529 Mdot
.34902 .4 Mdot
.59216 .03922 Mdot
.74902 .04706 Mdot
.80392 .38431 Mdot
.59216 .06667 Mdot
.52157 .00392 Mdot
.6549 .55294 Mdot
.02745 0 Mdot
.57255 .00784 Mdot
.73725 .05098 Mdot
.82353 .08235 Mdot
.84706 .82353 Mdot
.51765 .00784 Mdot
.76863 .82745 Mdot
.28235 .00392 Mdot
.75686 .04314 Mdot
.8549 .85098 Mdot
.39216 .27451 Mdot
.4549 .37647 Mdot
.56078 .00784 Mdot
.42745 .4 Mdot
.19608 0 Mdot
.76471 .05098 Mdot
.71765 .23922 Mdot
.43529 .19608 Mdot
.53333 .00392 Mdot
.70196 .04706 Mdot
.05882 .08627 Mdot
.45098 .03137 Mdot
.74118 .03922 Mdot
.81961 .08235 Mdot
.59608 .0549 Mdot
.49804 .00392 Mdot
.56863 .41961 Mdot
.16863 0 Mdot
.61569 .01176 Mdot
.85882 .82745 Mdot
.24706 .07451 Mdot
.80784 .81176 Mdot
.50588 0 Mdot
.68627 .74902 Mdot
.31373 .00392 Mdot
.76471 .0549 Mdot
.32941 .36078 Mdot
.77255 .77255 Mdot
.23529 .22745 Mdot
.63137 .03922 Mdot
.23922 .67843 Mdot
.59216 .36471 Mdot
.73725 .04706 Mdot
.72157 .15294 Mdot
.50196 .42353 Mdot
.51765 .00392 Mdot
.6902 .05882 Mdot
.2 .00784 Mdot
.55686 .01569 Mdot
.70588 .25882 Mdot
.23529 .04706 Mdot
.7451 .51373 Mdot
.49804 .00392 Mdot
.62353 .63137 Mdot
.27451 .01176 Mdot
.62353 .01961 Mdot
.82353 .77647 Mdot
.86275 .87843 Mdot
.80392 .81961 Mdot
.44706 .00784 Mdot
.58431 .64706 Mdot
.27843 0 Mdot
.72549 .03529 Mdot
.84314 .84706 Mdot
.83529 .84706 Mdot
.66275 .63922 Mdot
.67451 .05098 Mdot
.63529 .70588 Mdot
.50196 .01176 Mdot
.69412 .01569 Mdot
.20392 .08235 Mdot
.64314 .47843 Mdot
.51373 .00392 Mdot
.65098 .16078 Mdot
.22745 .01176 Mdot
.57647 .01569 Mdot
.85882 .83529 Mdot
.84314 .85882 Mdot
.84314 .83529 Mdot
.4902 .00392 Mdot
.61569 .66275 Mdot
.19216 .00392 Mdot
.63529 .01569 Mdot
.83529 .82353 Mdot
.83922 .85882 Mdot
.8 .81961 Mdot
.40784 .00392 Mdot
.33333 .33333 Mdot
.38431 .00784 Mdot
.65098 .01961 Mdot
.10196 .16863 Mdot
.82353 .84706 Mdot
.47451 .0902 Mdot
.67843 .06667 Mdot
.66275 .7098 Mdot
.51373 .01569 Mdot
.71373 .03137 Mdot
.85882 .86275 Mdot
.58039 .07059 Mdot
.49804 0 Mdot
.63529 .04706 Mdot
.14118 .00392 Mdot
.55686 .01176 Mdot
.65882 .13333 Mdot
.85098 .84706 Mdot
.82745 .76471 Mdot
.47843 .00392 Mdot
.63922 .6902 Mdot
.18824 .00392 Mdot
.57255 .00392 Mdot
.64706 .16078 Mdot
.47059 .22745 Mdot
.81569 .83137 Mdot
.36078 .00392 Mdot
.45098 .51373 Mdot
.30588 .00392 Mdot
.66275 .01569 Mdot
.80392 .79216 Mdot
.83922 .84706 Mdot
.50196 .04314 Mdot
.50588 .02353 Mdot
.44314 .45098 Mdot
.48627 .01176 Mdot
.70196 .02353 Mdot
.83529 .85098 Mdot
.21176 .04314 Mdot
.52157 .00392 Mdot
.6902 .04706 Mdot
.17255 .00392 Mdot
.55686 .01961 Mdot
.70588 .03529 Mdot
.67059 .21176 Mdot
.6 .04314 Mdot
.51765 .01176 Mdot
.42353 .07451 Mdot
.14902 .00392 Mdot
.56078 .01569 Mdot
.56863 .08235 Mdot
.66275 .65882 Mdot
.80784 .82353 Mdot
.47451 .00392 Mdot
.71765 .76863 Mdot
.2 .00392 Mdot
.56078 .01569 Mdot
.83137 .83529 Mdot
.84314 .84706 Mdot
.62353 .5098 Mdot
.85098 .70196 Mdot
.18039 .60784 Mdot
.40784 .00784 Mdot
.67843 .03529 Mdot
.83922 .7451 Mdot
.81961 .84706 Mdot
.53725 .00392 Mdot
.57647 .03137 Mdot
.16471 .08235 Mdot
.50196 .01176 Mdot
.70196 .03529 Mdot
.14902 .09804 Mdot
.58431 .07059 Mdot
.50588 0 Mdot
.63137 .03529 Mdot
.13333 .00392 Mdot
.54118 .00784 Mdot
.3451 .06275 Mdot
.85882 .86667 Mdot
.55294 .05882 Mdot
.46667 .00392 Mdot
.74118 .76471 Mdot
.15686 0 Mdot
.55686 .00784 Mdot
.84314 .84314 Mdot
.83529 .85098 Mdot
.79608 .81569 Mdot
.45098 .00392 Mdot
.4902 .50588 Mdot
.3451 .00784 Mdot
.61961 .01569 Mdot
.37255 .12941 Mdot
.82353 .83529 Mdot
.5098 .01961 Mdot
.4549 0 Mdot
.42745 .36078 Mdot
.47451 .00784 Mdot
.68235 .02745 Mdot
.85098 .8549 Mdot
.54118 .07843 Mdot
.51765 .00784 Mdot
.58824 .01569 Mdot
.13333 .00392 Mdot
.50588 .01176 Mdot
.73333 .51373 Mdot
.84706 .86667 Mdot
.60784 .04314 Mdot
.4902 .00392 Mdot
.47451 .0902 Mdot
.18431 .00392 Mdot
.52941 .00392 Mdot
.81569 .84314 Mdot
.36471 .37647 Mdot
.52941 .05882 Mdot
.45882 .00392 Mdot
.75686 .81569 Mdot
.32549 .00784 Mdot
.57255 .00784 Mdot
.67059 .67843 Mdot
.83529 .85098 Mdot
.80392 .81176 Mdot
.45098 0 Mdot
.34118 .41176 Mdot
.38431 .00784 Mdot
.6902 .03529 Mdot
.84314 .8549 Mdot
.60784 .06667 Mdot
.50588 .00392 Mdot
.59608 .01569 Mdot
.12157 .00392 Mdot
.44314 .00392 Mdot
.58431 .06667 Mdot
.81569 .68235 Mdot
.62353 .03137 Mdot
.50588 .00392 Mdot
.57255 .02745 Mdot
.13725 0 Mdot
.53725 .01176 Mdot
.81176 .83137 Mdot
.61569 .61176 Mdot
.59608 .02745 Mdot
.4902 .00392 Mdot
.77647 .79608 Mdot
.26275 .00784 Mdot
.56471 .00392 Mdot
.83137 .84706 Mdot
.74902 .49412 Mdot
.56078 .03529 Mdot
.4549 .00392 Mdot
.47451 .41961 Mdot
.32157 0 Mdot
.62353 .02353 Mdot
.85098 .83922 Mdot
.71373 .06275 Mdot
.63922 .55294 Mdot
.5098 .00392 Mdot
.21176 .00784 Mdot
.42353 .00392 Mdot
.68627 .03922 Mdot
.70196 .14118 Mdot
.58824 .04706 Mdot
.49412 .00392 Mdot
.55294 .00784 Mdot
.12549 .00784 Mdot
.4902 0 Mdot
.75294 .69804 Mdot
.8549 .85882 Mdot
.48235 .07059 Mdot
.47451 .00392 Mdot
.42745 .03922 Mdot
.24314 .00392 Mdot
.55686 0 Mdot
.83922 .84706 Mdot
.75294 .08627 Mdot
.53333 .03529 Mdot
.45098 0 Mdot
.47451 .52157 Mdot
.27843 .00392 Mdot
.59608 .02353 Mdot
.67451 .14118 Mdot
.15294 .02353 Mdot
.57255 .02745 Mdot
.46275 0 Mdot
.21176 .01176 Mdot
.36078 .00392 Mdot
.69412 .03922 Mdot
.78039 .08627 Mdot
.56863 .6 Mdot
.52549 .01569 Mdot
.61176 .01961 Mdot
.10588 .00784 Mdot
.4902 .00392 Mdot
.59608 .15294 Mdot
.67451 .25882 Mdot
.78824 .79608 Mdot
.4902 .00392 Mdot
.51765 0 Mdot
.21961 .00392 Mdot
.54118 .00392 Mdot
.71373 .56471 Mdot
.08235 .0549 Mdot
.76078 .76471 Mdot
.44706 .00392 Mdot
.56078 .56863 Mdot
.26275 .00392 Mdot
.60392 .02745 Mdot
.65882 .21961 Mdot
.84314 .85098 Mdot
.09412 .06275 Mdot
.45098 .00392 Mdot
.33725 .28235 Mdot
.35686 .00784 Mdot
.66667 .04314 Mdot
.77255 .07059 Mdot
.82353 .83922 Mdot
.52157 .01176 Mdot
.53725 .01176 Mdot
.11765 .00392 Mdot
.43922 .00392 Mdot
.71373 .04706 Mdot
.16863 .01176 Mdot
.81961 .83137 Mdot
.47059 0 Mdot
.53725 .00392 Mdot
.13725 .00784 Mdot
.37255 .00392 Mdot
.18431 .05882 Mdot
.87059 .87843 Mdot
.81176 .83922 Mdot
.46667 0 Mdot
.36863 .04706 Mdot
.23922 .00392 Mdot
.57647 .00784 Mdot
.84706 .84706 Mdot
.83922 .85882 Mdot
.8 .81569 Mdot
.37647 0 Mdot
.47059 .47843 Mdot
.30196 0 Mdot
.59608 .02353 Mdot
.65098 .10588 Mdot
.83529 .8549 Mdot
.46275 .34902 Mdot
.4549 0 Mdot
.23922 .00392 Mdot
.4 .00392 Mdot
.67843 .04314 Mdot
.80784 .82745 Mdot
.80392 .83529 Mdot
.49412 0 Mdot
.56863 .00392 Mdot
.11765 .00392 Mdot
.4902 .00392 Mdot
.74902 .54902 Mdot
.87451 .87843 Mdot
.82745 .82353 Mdot
.44314 .00392 Mdot
.51373 .01176 Mdot
.2 .00392 Mdot
.55294 .00784 Mdot
.85098 .85098 Mdot
.85882 .87451 Mdot
.81569 .83137 Mdot
.45882 .00392 Mdot
.51765 .53725 Mdot
.13725 0 Mdot
.6 .01176 Mdot
.3098 .34902 Mdot
.81961 .72941 Mdot
.79216 .81961 Mdot
.48627 .00392 Mdot
.12157 .55294 Mdot
.36471 .00392 Mdot
.64314 .03137 Mdot
.8549 .87059 Mdot
.47451 .11765 Mdot
.40784 .10588 Mdot
.56863 .02353 Mdot
.28627 .01569 Mdot
.42745 .00784 Mdot
.70588 .04314 Mdot
.88627 .8902 Mdot
.04706 .03137 Mdot
.5098 .01176 Mdot
.57647 .00392 Mdot
.17647 0 Mdot
.44706 .00784 Mdot
.68235 .0549 Mdot
.85098 .86667 Mdot
.51373 .36863 Mdot
.52157 .02353 Mdot
.53333 .00392 Mdot
.12549 .00392 Mdot
.4902 .00392 Mdot
.80784 .50196 Mdot
.86275 .66275 Mdot
.52549 .09412 Mdot
.4902 .00392 Mdot
.45882 0 Mdot
.20392 .01176 Mdot
.52549 .00392 Mdot
.41961 .38039 Mdot
.72157 .11373 Mdot
.55294 .03529 Mdot
.4902 .01176 Mdot
.61961 .56078 Mdot
.12941 0 Mdot
.56863 .00784 Mdot
.88627 .90196 Mdot
.41961 .42745 Mdot
.63922 .64314 Mdot
.50196 .00784 Mdot
.14902 .12549 Mdot
.14902 .00784 Mdot
.58824 .01961 Mdot
.87059 .8902 Mdot
.84706 .87059 Mdot
.79608 .83137 Mdot
.52941 .01961 Mdot
.12941 .56078 Mdot
.2549 .00392 Mdot
.59608 .03137 Mdot
.86667 .88235 Mdot
.82353 .85098 Mdot
.44706 .08235 Mdot
.35686 0 Mdot
.24314 .00784 Mdot
.32941 0 Mdot
.67059 .03529 Mdot
.73333 .27451 Mdot
.75686 .6902 Mdot
.49804 .00784 Mdot
.32157 .00784 Mdot
.22353 .00392 Mdot
.40392 .00392 Mdot
.58039 .0902 Mdot
.8 .07451 Mdot
.60392 .03922 Mdot
.48627 .00392 Mdot
.58431 .01176 Mdot
.12549 0 Mdot
.47451 .00784 Mdot
.83529 .84706 Mdot
.32549 .14902 Mdot
.52549 .03137 Mdot
.51373 .00784 Mdot
.51373 .00392 Mdot
.18431 0 Mdot
.50196 0 Mdot
.83922 .85882 Mdot
.8549 .86275 Mdot
.34902 .37647 Mdot
.49804 .00392 Mdot
.4902 .23529 Mdot
.24706 .00392 Mdot
.52157 .00392 Mdot
.85882 .87451 Mdot
.83529 .85098 Mdot
.81569 .81961 Mdot
.49804 .00392 Mdot
.41569 .4 Mdot
.27451 .00392 Mdot
.53725 0 Mdot
.64314 .27059 Mdot
.78824 .64706 Mdot
.47843 .07451 Mdot
.5098 .01569 Mdot
.15294 .05098 Mdot
.32549 .00784 Mdot
.58039 .00784 Mdot
.80784 .08235 Mdot
.60784 .05882 Mdot
.53333 .01569 Mdot
.58039 .02353 Mdot
.30588 .03529 Mdot
.27843 .00392 Mdot
.27843 .01961 Mdot
.83529 .07843 Mdot
.50588 .06667 Mdot
.51373 0 Mdot
.67843 .03922 Mdot
.21176 .00392 Mdot
.47059 0 Mdot
.83137 .83137 Mdot
.84706 .50196 Mdot
.34118 .38824 Mdot
.49804 .00392 Mdot
.64706 .02353 Mdot
.17647 .00392 Mdot
.4902 .02745 Mdot
.83529 .83922 Mdot
.86275 .86667 Mdot
.82745 .85098 Mdot
.47451 .00392 Mdot
.54902 .00392 Mdot
.17255 .00784 Mdot
.38431 .01569 Mdot
.78039 .64314 Mdot
.71765 .7098 Mdot
.26275 .22745 Mdot
.5098 .00784 Mdot
.44706 .02353 Mdot
.24314 .01176 Mdot
.51765 .00392 Mdot
.71373 .06667 Mdot
.0902 .01569 Mdot
.03137 .02353 Mdot
.48627 .00784 Mdot
.38824 .34902 Mdot
.22745 0 Mdot
.54118 .00392 Mdot
.72157 .07059 Mdot
.39608 .44314 Mdot
.18039 .21961 Mdot
.51373 .00392 Mdot
.03922 .00392 Mdot
.16863 .00392 Mdot
.32941 .03137 Mdot
.72941 .08235 Mdot
.80392 .83529 Mdot
.03529 .01569 Mdot
.5451 .01176 Mdot
.22745 .59216 Mdot
.41569 .01176 Mdot
.81176 .81961 Mdot
.75294 .04706 Mdot
.78431 .82353 Mdot
.47059 .02745 Mdot
.64314 .03529 Mdot
.18431 0 Mdot
.36471 .00784 Mdot
.81176 .82745 Mdot
.73725 .05882 Mdot
.33333 .40784 Mdot
.52157 .00392 Mdot
.6549 .04314 Mdot
.16471 .00784 Mdot
.23529 0 Mdot
.57647 .18824 Mdot
.68627 .22353 Mdot
.83137 .85098 Mdot
.52157 .00392 Mdot
.59608 .00392 Mdot
.15686 .00392 Mdot
.53725 .00784 Mdot
.23137 .01176 Mdot
.72157 .36471 Mdot
.81569 .84706 Mdot
.51765 .01176 Mdot
.47451 .00784 Mdot
.24314 .01176 Mdot
.55294 .01569 Mdot
.72549 .76471 Mdot
.67059 .12157 Mdot
.80784 .83137 Mdot
.48627 .00392 Mdot
.45882 .38431 Mdot
.2902 .00392 Mdot
.54902 .06275 Mdot
.86667 .86275 Mdot
.35294 .03137 Mdot
.80392 .83922 Mdot
.48235 .01176 Mdot
.01569 0 Mdot
.35294 .00784 Mdot
.78824 .80784 Mdot
.84314 .8549 Mdot
.68627 .72941 Mdot
.80784 .84314 Mdot
.56078 .01569 Mdot
.27059 .03922 Mdot
.47843 .28627 Mdot
.8 .81961 Mdot
.8 .6549 Mdot
.81961 .85098 Mdot
.71373 .67059 Mdot
.60784 .01961 Mdot
.15294 .00392 Mdot
.37647 .03529 Mdot
.36863 .11373 Mdot
.76078 .06667 Mdot
.81961 .85098 Mdot
.52941 .01961 Mdot
.61569 .01961 Mdot
.26275 .1098 Mdot
.47059 .00392 Mdot
.73725 .76078 Mdot
.78039 .06667 Mdot
.80392 .80784 Mdot
.48627 0 Mdot
.57255 .00784 Mdot
.08627 .00392 Mdot
.51373 .01176 Mdot
.69412 .51373 Mdot
.73333 .06275 Mdot
.46667 .1098 Mdot
.49804 .01176 Mdot
.50196 0 Mdot
.16863 .00392 Mdot
.54118 .01961 Mdot
.71373 .05882 Mdot
.61569 .62745 Mdot
.43529 .06667 Mdot
.43922 0 Mdot
.56078 .45098 Mdot
.23922 0 Mdot
.42745 .31765 Mdot
.39216 .36863 Mdot
.8549 .87059 Mdot
.71765 .76471 Mdot
.43137 0 Mdot
.00392 .00392 Mdot
.28627 0 Mdot
.8 .83137 Mdot
.87451 .86275 Mdot
.83529 .86667 Mdot
.78824 .79608 Mdot
.51373 .00392 Mdot
.18431 0 Mdot
.36078 .00392 Mdot
.06667 .08627 Mdot
.75686 .08627 Mdot
.36471 .40784 Mdot
.51373 .03137 Mdot
.52157 .00392 Mdot
.29804 .12157 Mdot
.41176 .00784 Mdot
.81961 .83137 Mdot
.78431 .06275 Mdot
.49804 .09412 Mdot
.49412 .00784 Mdot
.57255 .00784 Mdot
.08627 .00392 Mdot
.35294 .02353 Mdot
.59608 .07059 Mdot
.76471 .07843 Mdot
.39608 .06275 Mdot
.50196 .00784 Mdot
.57255 .00392 Mdot
.08627 .00392 Mdot
.43137 .00784 Mdot
.22353 .01176 Mdot
.40784 .3098 Mdot
.15294 .20784 Mdot
.48627 .00392 Mdot
.57255 .00784 Mdot
.0902 0 Mdot
.52941 .01176 Mdot
.56471 .62745 Mdot
.83922 .85882 Mdot
.79608 .84314 Mdot
.49412 .00784 Mdot
.46667 .03137 Mdot
.07451 0 Mdot
.52941 .01961 Mdot
.84314 .85098 Mdot
.86275 .8549 Mdot
.7451 .7098 Mdot
.45882 .00392 Mdot
.20784 .10196 Mdot
.2 .00784 Mdot
.62745 .41569 Mdot
.58824 .19608 Mdot
.55686 .14902 Mdot
.4902 .06667 Mdot
.44314 0 Mdot
.00392 0 Mdot
.27059 .00392 Mdot
.78824 .81569 Mdot
.71765 .0549 Mdot
.36078 .05098 Mdot
.4 .05098 Mdot
.49412 0 Mdot
.04706 0 Mdot
.31373 .00392 Mdot
.72941 .76471 Mdot
.71373 .0549 Mdot
.08627 .12157 Mdot
.12941 0 Mdot
.48627 .00392 Mdot
.2549 .01569 Mdot
.36078 .00392 Mdot
.8 .82745 Mdot
.70588 .0549 Mdot
.67843 .73725 Mdot
.06275 0 Mdot
.4902 0 Mdot
.25098 .00392 Mdot
.38431 .00392 Mdot
.76471 .80392 Mdot
.68235 .03529 Mdot
.81961 .86667 Mdot
.13333 .00392 Mdot
.50588 .00392 Mdot
.37255 .16078 Mdot
.41176 0 Mdot
.81569 .81176 Mdot
.71373 .0549 Mdot
.79216 .84314 Mdot
.39608 .03137 Mdot
.52941 .00392 Mdot
.11373 .00784 Mdot
.45098 .00784 Mdot
.55294 .16471 Mdot
.72549 .0549 Mdot
.68235 .74118 Mdot
.47843 .01176 Mdot
.53333 .00392 Mdot
.05882 .00392 Mdot
.48235 .01176 Mdot
.65098 .03529 Mdot
.71373 .06667 Mdot
.78039 .82353 Mdot
.44706 0 Mdot
.53725 .00392 Mdot
.05098 0 Mdot
.50588 .01176 Mdot
.65882 .03137 Mdot
.66667 .07059 Mdot
.82353 .85098 Mdot
.44314 0 Mdot
.44706 .0902 Mdot
.0549 .00392 Mdot
.50588 .00392 Mdot
.69804 .05098 Mdot
.65098 .05882 Mdot
.82353 .8549 Mdot
.4902 .00392 Mdot
.13333 .07843 Mdot
.06275 .00392 Mdot
.5098 .01569 Mdot
.6902 .04314 Mdot
.43137 .06275 Mdot
.82745 .85882 Mdot
.5451 .00784 Mdot
.00392 0 Mdot
.19216 .00784 Mdot
.54902 .31373 Mdot
.70196 .04706 Mdot
.20392 .24706 Mdot
.82745 .85882 Mdot
.52941 .00392 Mdot
.05882 .00392 Mdot
.26275 0 Mdot
.8 .83137 Mdot
.71373 .04706 Mdot
.83137 .86667 Mdot
.81569 .8549 Mdot
.5451 .01176 Mdot
.27843 .01176 Mdot
.3098 .00392 Mdot
.78431 .82353 Mdot
.71373 .05098 Mdot
.83922 .87059 Mdot
.81961 .8549 Mdot
.54118 .01569 Mdot
.30196 .00784 Mdot
.35686 .00392 Mdot
.76078 .80392 Mdot
.73725 .05882 Mdot
.83922 .87059 Mdot
.81569 .8549 Mdot
.55294 .00784 Mdot
.21176 0 Mdot
.38039 0 Mdot
.14118 .14118 Mdot
.74118 .05098 Mdot
.83922 .87059 Mdot
.66667 .63922 Mdot
.58431 .01176 Mdot
.32157 .12157 Mdot
.43137 .00392 Mdot
.30196 .03922 Mdot
.51373 .07451 Mdot
.80392 .76471 Mdot
.47451 .03922 Mdot
.61569 .02745 Mdot
.36078 .23529 Mdot
.4549 .00392 Mdot
.59216 .05882 Mdot
.36078 .4 Mdot
.54902 .11373 Mdot
.47843 .01176 Mdot
.63137 .05882 Mdot
.09804 .01176 Mdot
.45882 .00784 Mdot
.62745 .0549 Mdot
.82353 .85882 Mdot
.62353 .04706 Mdot
.50588 .01569 Mdot
.58431 .21961 Mdot
.1098 .0549 Mdot
.47451 .00784 Mdot
.64314 .03922 Mdot
.8549 .87451 Mdot
.56078 .07059 Mdot
.52549 .00784 Mdot
.64706 .47843 Mdot
.04314 0 Mdot
.47843 .01569 Mdot
.67843 .04706 Mdot
.83922 .86667 Mdot
.13725 .00392 Mdot
.53725 .01176 Mdot
.47059 .33333 Mdot
.03137 0 Mdot
.46275 .00784 Mdot
.67843 .03922 Mdot
.84314 .87451 Mdot
.30588 .37255 Mdot
.52941 .00392 Mdot
.4 .30588 Mdot
.03137 .00784 Mdot
.47451 .01176 Mdot
.67843 .04314 Mdot
.84314 .87059 Mdot
.72549 .78431 Mdot
.53725 .00784 Mdot
.07451 .01176 Mdot
.02353 0 Mdot
.47843 .00784 Mdot
.68627 .04314 Mdot
.67451 .6902 Mdot
.81176 .85098 Mdot
.5451 .01176 Mdot
.09412 .01961 Mdot
.02353 0 Mdot
.49804 .01961 Mdot
.66667 .03922 Mdot
.06275 .11373 Mdot
.8 .83529 Mdot
.54118 .00784 Mdot
.11765 .00392 Mdot
.02745 .00392 Mdot
.50588 .01176 Mdot
.51765 .06275 Mdot
.66275 .72157 Mdot
.80392 .83922 Mdot
.5451 .01961 Mdot
.22353 .00392 Mdot
.08627 0 Mdot
.54118 .01176 Mdot
.1098 .06275 Mdot
.84314 .86667 Mdot
.80392 .83922 Mdot
.56863 .02353 Mdot
.33725 .01176 Mdot
.20392 .00784 Mdot
.59216 .02353 Mdot
.67451 .72549 Mdot
.81569 .72549 Mdot
.80392 .83922 Mdot
.58039 .01961 Mdot
.41569 .00392 Mdot
.27451 .00392 Mdot
.61569 .03137 Mdot
.83529 .86275 Mdot
.53333 .17255 Mdot
.8 .84314 Mdot
.57647 .01176 Mdot
.49804 .01176 Mdot
.29804 .00392 Mdot
.61569 .02745 Mdot
.83922 .85882 Mdot
.15294 .01961 Mdot
.67059 .72941 Mdot
.55686 .00784 Mdot
.47451 .00784 Mdot
.30196 .00392 Mdot
.60392 .04314 Mdot
.83137 .86275 Mdot
.6 .65882 Mdot
.69804 .75294 Mdot
.55294 .00392 Mdot
.4 .00392 Mdot
.32549 0 Mdot
.57647 .05882 Mdot
.85098 .84706 Mdot
.83529 .87843 Mdot
.8 .83529 Mdot
.54902 .00784 Mdot
.32941 .00392 Mdot
.36078 .00784 Mdot
.53333 .08627 Mdot
.59608 .30588 Mdot
.83529 .87059 Mdot
.79608 .83922 Mdot
.52941 .01569 Mdot
.2902 .00784 Mdot
.35294 0 Mdot
.54118 .18039 Mdot
.63529 .06275 Mdot
.83137 .86667 Mdot
.4902 .56078 Mdot
.4902 .16078 Mdot
.27451 .00392 Mdot
.36078 .00784 Mdot
.60392 .34902 Mdot
.51765 .08235 Mdot
.81569 .84706 Mdot
.60784 .67059 Mdot
.83137 .76471 Mdot
.27843 .01569 Mdot
.33333 0 Mdot
.64314 .47059 Mdot
.15294 .11373 Mdot
.83529 .82353 Mdot
.78039 .82745 Mdot
.55686 .5098 Mdot
.07059 .76078 Mdot
.34902 .00392 Mdot
.55294 .24314 Mdot
.52941 .56863 Mdot
.6549 .4902 Mdot
.78039 .82353 Mdot
.33333 .25882 Mdot
.13725 .52157 Mdot
.35686 .00392 Mdot
.49804 .09412 Mdot
.6902 .74118 Mdot
.51765 .14902 Mdot
.78039 .81961 Mdot
.20392 .11373 Mdot
.14118 .51765 Mdot
.38824 .03137 Mdot
.43922 .06667 Mdot
.81961 .86275 Mdot
.4902 .10196 Mdot
.78039 .81961 Mdot
.24314 .12941 Mdot
.14902 .52549 Mdot
.38039 .00784 Mdot
.24706 .01961 Mdot
.83529 .85882 Mdot
.19216 .01569 Mdot
.78039 .82353 Mdot
.43137 .32157 Mdot
.1451 .52157 Mdot
.39216 .00784 Mdot
.1098 .04314 Mdot
.83922 .79608 Mdot
.07451 .0902 Mdot
.77255 .82353 Mdot
.62745 .5451 Mdot
.15294 .52157 Mdot
.38431 .00784 Mdot
.2902 .31373 Mdot
.64706 .43137 Mdot
.54118 .61176 Mdot
.77647 .82353 Mdot
.72549 .67059 Mdot
.14118 .51765 Mdot
.33333 .00392 Mdot
.56863 .62353 Mdot
.58039 .1451 Mdot
.72157 .77647 Mdot
.78039 .81569 Mdot
.78431 .75686 Mdot
.1451 .52549 Mdot
.30588 0 Mdot
.7451 .79608 Mdot
.69412 .0902 Mdot
.81961 .86275 Mdot
.76078 .76471 Mdot
.76078 .75686 Mdot
.14118 .52157 Mdot
.34902 .00392 Mdot
.77255 .81569 Mdot
.78824 .08235 Mdot
.84314 .87843 Mdot
.61176 .53333 Mdot
.72157 .7451 Mdot
.1451 .51373 Mdot
.39216 .00784 Mdot
.77647 .81961 Mdot
.87059 .1098 Mdot
.87059 .89804 Mdot
.47059 .23922 Mdot
.69412 .74118 Mdot
.14118 .50588 Mdot
.38431 .00392 Mdot
.77647 .81961 Mdot
.95686 .17647 Mdot
.89804 .91765 Mdot
.5098 .09412 Mdot
.70588 .76078 Mdot
.14902 .5098 Mdot
.37255 .00392 Mdot
.78824 .83137 Mdot
.99216 .25098 Mdot
.92157 .93333 Mdot
.60392 .04706 Mdot
.68235 .74902 Mdot
.15294 .51765 Mdot
.36863 .00392 Mdot
.80392 .82745 Mdot
1 .28627 Mdot
.94118 .94902 Mdot
.66667 .03529 Mdot
.63529 .7098 Mdot
.15294 .51373 Mdot
.37647 .00392 Mdot
.85098 .80784 Mdot
.97647 .2549 Mdot
.93333 .93725 Mdot
.72549 .05098 Mdot
.67059 .73725 Mdot
.15686 .51765 Mdot
.38431 .00392 Mdot
.8549 .71765 Mdot
.99216 .29412 Mdot
.9451 .93725 Mdot
.76078 .05882 Mdot
.69412 .74902 Mdot
.15686 .5098 Mdot
.39608 .00392 Mdot
.71373 .53333 Mdot
.99608 .27451 Mdot
1 .89412 Mdot
.74902 .05098 Mdot
.60784 .67059 Mdot
.15686 .5098 Mdot
.41176 .00392 Mdot
.40392 .30196 Mdot
.98431 .21176 Mdot
.87059 .40392 Mdot
.74118 .05882 Mdot
.51765 .59216 Mdot
.1451 .5098 Mdot
.43137 .00784 Mdot
.17647 .18431 Mdot
.9098 .12549 Mdot
.83137 .1451 Mdot
.6902 .06667 Mdot
.70588 .76471 Mdot
.13725 .50196 Mdot
.47059 .01569 Mdot
.24314 .30196 Mdot
.80784 .07059 Mdot
.8 .08627 Mdot
.63529 .10588 Mdot
.73333 .79216 Mdot
.13725 .50588 Mdot
.47843 .01961 Mdot
.62353 .6902 Mdot
.75686 .06275 Mdot
.79216 .08235 Mdot
.76078 .34118 Mdot
.61569 .67059 Mdot
.27843 .01569 Mdot
.59216 .14118 Mdot
.73725 .78824 Mdot
.79608 .08235 Mdot
.83137 .09804 Mdot
.83922 .47843 Mdot
.66667 .72941 Mdot
.28235 .01961 Mdot
.6 .10588 Mdot
.78431 .82353 Mdot
.90196 .14118 Mdot
.91373 .14118 Mdot
.65882 .28627 Mdot
.61176 .68235 Mdot
.27843 .01961 Mdot
.57255 .03529 Mdot
.78431 .76471 Mdot
.96863 .20784 Mdot
.97647 .22353 Mdot
.5451 .10588 Mdot
.57255 .64706 Mdot
.26275 .01569 Mdot
.50196 .03529 Mdot
.65882 .43529 Mdot
1 .28627 Mdot
.96078 .32941 Mdot
.58431 .0549 Mdot
.51765 .60784 Mdot
.27059 .01569 Mdot
.70196 .39216 Mdot
.63529 .12157 Mdot
1 .28627 Mdot
.97647 .60392 Mdot
.6549 .04314 Mdot
.5098 .58824 Mdot
.28627 .02745 Mdot
.48235 .25882 Mdot
.74118 .07843 Mdot
.97255 .21569 Mdot
.9098 .63137 Mdot
.71373 .04706 Mdot
.52941 .59608 Mdot
.27059 .01961 Mdot
.56863 .3098 Mdot
.8 .1098 Mdot
.99216 .24706 Mdot
.90588 .64706 Mdot
.73333 .04314 Mdot
.51765 .58039 Mdot
.27059 .01961 Mdot
.40392 .05098 Mdot
.81176 .14902 Mdot
.99608 .24706 Mdot
.9451 .75294 Mdot
.72941 .03529 Mdot
.48235 .55294 Mdot
.26275 .01569 Mdot
.41569 0 Mdot
.73725 .12549 Mdot
.95294 .15294 Mdot
.91373 .70588 Mdot
.73725 .05098 Mdot
.49412 .56863 Mdot
.26275 .01569 Mdot
.44314 .00784 Mdot
.61961 .10588 Mdot
.9098 .10196 Mdot
.73725 .49804 Mdot
.70588 .06667 Mdot
.58431 .6549 Mdot
.28235 .02353 Mdot
.46275 .00784 Mdot
.38431 .03529 Mdot
.88235 .09804 Mdot
.84314 .58039 Mdot
.61569 .05882 Mdot
.60392 .66667 Mdot
.2902 .01569 Mdot
.46667 .01176 Mdot
.16078 .00392 Mdot
.8902 .1098 Mdot
.91373 .45882 Mdot
.52941 .06275 Mdot
.54118 .60784 Mdot
.29412 .01176 Mdot
.43529 0 Mdot
.15294 .1098 Mdot
.92941 .14118 Mdot
.8902 .21961 Mdot
.4549 .07843 Mdot
.60392 .66667 Mdot
.31373 .01961 Mdot
.43529 .00784 Mdot
.3098 .33725 Mdot
.98039 .21569 Mdot
.99608 .31373 Mdot
.55294 .26667 Mdot
.74902 .80784 Mdot
.32941 .03137 Mdot
.42353 .00392 Mdot
.53725 .59216 Mdot
1 .2902 Mdot
1 .31765 Mdot
.78824 .58431 Mdot
.6902 .7451 Mdot
.3098 .01961 Mdot
.41176 .01961 Mdot
.71765 .76863 Mdot
.98431 .23529 Mdot
.9451 .19216 Mdot
.90196 .77255 Mdot
.58824 .63529 Mdot
.33333 .04314 Mdot
.51373 .10588 Mdot
.78431 .81569 Mdot
.97647 .18039 Mdot
.8902 .12157 Mdot
.8549 .79608 Mdot
.60784 .65098 Mdot
.34118 .0549 Mdot
.48235 .01961 Mdot
.84706 .82353 Mdot
.96863 .18824 Mdot
.94118 .18824 Mdot
.82353 .81569 Mdot
.65098 .6902 Mdot
.34902 .06667 Mdot
.4549 0 Mdot
.7098 .37255 Mdot
.99608 .28235 Mdot
.98431 .24706 Mdot
.79216 .81961 Mdot
.55686 .53725 Mdot
.39608 .46275 Mdot
.43922 .00392 Mdot
.77647 .08627 Mdot
1 .38431 Mdot
.99608 .27451 Mdot
.78431 .81569 Mdot
.10588 .03529 Mdot
.33333 .12157 Mdot
.47451 .00392 Mdot
.83529 .08627 Mdot
.97647 .33725 Mdot
.99608 .23922 Mdot
.81961 .80784 Mdot
.1098 .02353 Mdot
.19216 .01176 Mdot
.62745 .02353 Mdot
.87843 .11373 Mdot
.98431 .29412 Mdot
.86667 .28627 Mdot
.52941 .0902 Mdot
.18824 .08627 Mdot
.21176 0 Mdot
.65098 .00784 Mdot
.83137 .07451 Mdot
.99216 .2549 Mdot
.84706 .67843 Mdot
.77647 .60392 Mdot
.31765 .00392 Mdot
.39608 .03922 Mdot
.68235 .01569 Mdot
.91765 .11373 Mdot
.99216 .23529 Mdot
.64706 .12549 Mdot
.76471 .83529 Mdot
.4902 .01176 Mdot
.12549 0 Mdot
.72941 .04314 Mdot
.98039 .16078 Mdot
.98431 .21176 Mdot
.68627 .02353 Mdot
.81569 .87843 Mdot
.34902 .01176 Mdot
.04706 .00784 Mdot
.70588 .07451 Mdot
.96078 .19216 Mdot
.88627 .24706 Mdot
.83529 .68235 Mdot
.85098 .90196 Mdot
.49804 .04706 Mdot
.29804 .00392 Mdot
.73725 .04706 Mdot
.85098 .67059 Mdot
.68627 .34902 Mdot
.75294 .80784 Mdot
.77647 .81961 Mdot
.2902 .37647 Mdot
.42745 .00392 Mdot
.8 .1451 Mdot
.60784 .53725 Mdot
.51765 .46667 Mdot
.40784 .07843 Mdot
.5098 .07843 Mdot
.22745 .01569 Mdot
.66275 .03922 Mdot
.72157 .52157 Mdot
.53333 .57647 Mdot
.45882 .5098 Mdot
.71765 .78039 Mdot
.63137 .05882 Mdot
.18431 .00392 Mdot
.75294 .12549 Mdot
.69412 .73333 Mdot
.60392 .65882 Mdot
.43922 .5098 Mdot
.69412 .77647 Mdot
.6 .02745 Mdot
.19216 .00392 Mdot
.57255 .34118 Mdot
.78039 .80784 Mdot
.81176 .84706 Mdot
.40784 .4902 Mdot
.74902 .83137 Mdot
.40784 .00392 Mdot
.40784 .10588 Mdot
.47059 .55294 Mdot
.87451 .89412 Mdot
.83137 .83529 Mdot
.39608 .4902 Mdot
.6549 .74902 Mdot
.44706 .23922 Mdot
.5451 .16471 Mdot
.58039 .64706 Mdot
.4549 .44314 Mdot
.54118 .52941 Mdot
.37647 .47843 Mdot
.46667 .05882 Mdot
.3451 .01569 Mdot
.45882 .52157 Mdot
.43137 .43137 Mdot
.43922 .43922 Mdot
.56863 .56471 Mdot
.36078 .46275 Mdot
.53725 .01569 Mdot
.21961 .01961 Mdot
.4902 .51373 Mdot
.4549 .45098 Mdot
.4549 .47059 Mdot
.52157 .4902 Mdot
.35686 .43922 Mdot
.27059 .67059 Mdot
.41176 .4902 Mdot
.4902 .46667 Mdot
.46275 .46667 Mdot
.58039 .59608 Mdot
.52549 .4902 Mdot
.41961 .06667 Mdot
.35294 .03529 Mdot
.37255 .4 Mdot
.4549 .4549 Mdot
.46667 .47843 Mdot
.45098 .4549 Mdot
.56471 .58039 Mdot
.61176 .08627 Mdot
.35294 .43529 Mdot
.47451 .45098 Mdot
.46667 .44706 Mdot
.44706 .46275 Mdot
.40392 .38431 Mdot
.36078 .45882 Mdot
.43137 .08627 Mdot
.4549 .47059 Mdot
.47451 .44706 Mdot
.44314 .46275 Mdot
.50196 .47059 Mdot
.47059 .44706 Mdot
.5451 .09412 Mdot
.35686 .43137 Mdot
.5098 .48235 Mdot
.45882 .45098 Mdot
.43529 .45882 Mdot
.46275 .42353 Mdot
.50588 .45882 Mdot
.41569 .09412 Mdot
.46667 .45098 Mdot
.49412 .47451 Mdot
.43922 .46667 Mdot
.45098 .41961 Mdot
.48235 .47059 Mdot
.34118 .38039 Mdot
.37255 .40392 Mdot
.50588 .46667 Mdot
.44706 .45882 Mdot
.43137 .47059 Mdot
.48235 .45098 Mdot
.43137 .40392 Mdot
.42745 .31765 Mdot
.4902 .46667 Mdot
.47843 .46667 Mdot
.53333 .58824 Mdot
.4549 .42353 Mdot
.48235 .45882 Mdot
.32941 .38824 Mdot
.45098 .43922 Mdot
.48627 .45882 Mdot
.42745 .47843 Mdot
.40784 .46275 Mdot
.46667 .46667 Mdot
.43529 .41569 Mdot
.38824 .41176 Mdot
.47059 .45098 Mdot
.47451 .48627 Mdot
.11765 .23922 Mdot
.42353 .42745 Mdot
.47059 .4549 Mdot
.29412 .28627 Mdot
.48627 .47451 Mdot
.4902 .47059 Mdot
.24314 .35294 Mdot
.38824 .42353 Mdot
.4549 .4549 Mdot
.25098 .31765 Mdot
.36471 .38039 Mdot
.4902 .46667 Mdot
.19608 .2902 Mdot
.51373 .58824 Mdot
.47843 .46275 Mdot
.47451 .45098 Mdot
.39608 .27059 Mdot
.48627 .46667 Mdot
.39608 .42745 Mdot
.54118 .55294 Mdot
.4902 .44706 Mdot
.4902 .45098 Mdot
.19608 .2902 Mdot
.38039 .42745 Mdot
.48235 .46275 Mdot
.40784 .40392 Mdot
.57647 .59608 Mdot
.43922 .44314 Mdot
.4 .43137 Mdot
.36863 .42353 Mdot
.4902 .47059 Mdot
.19216 .30196 Mdot
.67451 .68235 Mdot
.47843 .47451 Mdot
.47843 .46667 Mdot
.41961 .38824 Mdot
.40392 .43922 Mdot
.23137 .32941 Mdot
.46667 .40392 Mdot
.46667 .40392 Mdot
.50196 .46667 Mdot
.2 .31373 Mdot
.3451 .41569 Mdot
.51373 .49804 Mdot
.51373 .44314 Mdot
.51373 .48235 Mdot
.50196 .48627 Mdot
.39216 .41961 Mdot
.27843 .69804 Mdot
.37255 .38431 Mdot
.36863 .40392 Mdot
.37255 .4 Mdot
.50588 .43529 Mdot
.47059 .43922 Mdot
.3098 .40784 Mdot
.43137 .4902 Mdot
.50588 .51373 Mdot
.55686 .47843 Mdot
.30588 .36471 Mdot
.52157 .50196 Mdot
.32549 .39216 Mdot
.47451 .52157 Mdot
.43922 .43529 Mdot
.51373 .47059 Mdot
.23529 .32157 Mdot
.52941 .5098 Mdot
.29804 .37647 Mdot
.55686 .42353 Mdot
.46275 .52549 Mdot
.46667 .41176 Mdot
.6902 .67843 Mdot
.53333 .50196 Mdot
.38039 .37255 Mdot
.38039 .46667 Mdot
.5098 .58431 Mdot
.51765 .43137 Mdot
.53333 .48627 Mdot
.58039 .52941 Mdot
.40784 .41569 Mdot
.39608 .47451 Mdot
.52941 .60784 Mdot
.47843 .50196 Mdot
.56863 .61961 Mdot
.63529 .58039 Mdot
.45098 .45098 Mdot
.40784 .49412 Mdot
.53725 .61176 Mdot
.50196 .56471 Mdot
.43922 .47843 Mdot
.73725 .65882 Mdot
.47843 .47843 Mdot
.44706 .52549 Mdot
.57255 .60392 Mdot
.53725 .60392 Mdot
.52941 .48235 Mdot
.82745 .78431 Mdot
.53725 .56471 Mdot
.45882 .53333 Mdot
.51765 .52941 Mdot
.56863 .63137 Mdot
.56863 .49804 Mdot
.85098 .83922 Mdot
.58431 .6 Mdot
.45098 .53725 Mdot
.58039 .65098 Mdot
.55294 .62745 Mdot
.56863 .56078 Mdot
.87451 .88235 Mdot
.7098 .64706 Mdot
.43137 .50588 Mdot
.60784 .68627 Mdot
.61569 .67843 Mdot
.98824 .99608 Mdot
.78039 .83137 Mdot
.54118 .60784 Mdot
.31373 .74902 Mdot
.61569 .6902 Mdot
.75294 .8 Mdot
.99216 .99216 Mdot
.67059 .7098 Mdot
.46667 .54118 Mdot
.64314 .72157 Mdot
.64706 .72157 Mdot
.99608 .99608 Mdot
.75294 .81176 Mdot
.5451 .62745 Mdot
.66667 .69804 Mdot
.66275 .73725 Mdot
.9451 .95294 Mdot
.88627 .92549 Mdot
.59608 .65882 Mdot
.65882 .67059 Mdot
.69412 .76863 Mdot
.92549 .94118 Mdot
.88235 .92549 Mdot
.54118 .61569 Mdot
.69412 .76863 Mdot
.78431 .83922 Mdot
.99216 .99216 Mdot
.8 .84314 Mdot
.17647 .88627 Mdot
.72941 .80392 Mdot
.93333 .95294 Mdot
.92157 .94902 Mdot
.4549 .41176 Mdot
.75294 .81569 Mdot
.91373 .9451 Mdot
.91373 .94118 Mdot
.32549 .76078 Mdot
.76471 .82353 Mdot
.98824 .99216 Mdot
.70196 .72549 Mdot
.67059 .6 Mdot
.96471 .97647 Mdot
.61176 .6 Mdot
.64706 .56078 Mdot
.75686 .72549 Mdot
.40784 .81961 Mdot
.628 .126 .941 r
.34902 .78431 Mdot
.47451 .43529 Mdot
.8 .7451 Mdot
.74118 .75686 Mdot
.71373 .63529 Mdot
.43137 .43137 Mdot
.77255 .72157 Mdot
.76078 .7098 Mdot
.73725 .75294 Mdot
.79216 .79216 Mdot
.81176 .71765 Mdot
.83922 .83137 Mdot
.79216 .81569 Mdot
.72941 .58824 Mdot
.76863 .68627 Mdot
.61569 .63137 Mdot
.78039 .81961 Mdot
.7451 .63529 Mdot
.72549 .66275 Mdot
.71765 .74902 Mdot
.76078 .8 Mdot
.71765 .62353 Mdot
.84314 .76471 Mdot
.83922 .83137 Mdot
.78431 .81176 Mdot
.11765 .83529 Mdot
.65098 .60392 Mdot
.76863 .75686 Mdot
.16863 .30588 Mdot
.75686 .79608 Mdot
.71765 .63922 Mdot
.87451 .80784 Mdot
.73725 .7098 Mdot
.79216 .83137 Mdot
.74118 .74902 Mdot
.80392 .73333 Mdot
.87059 .80784 Mdot
.73333 .73333 Mdot
.77647 .81569 Mdot
.33333 .52549 Mdot
.82745 .73725 Mdot
.84706 .78431 Mdot
.72157 .72941 Mdot
.78824 .81569 Mdot
.10196 .82745 Mdot
.82353 .7451 Mdot
.86667 .79216 Mdot
.83922 .83137 Mdot
.79608 .82353 Mdot
.44314 .49804 Mdot
.8 .71765 Mdot
.80784 .81569 Mdot
.83529 .80784 Mdot
.78824 .83922 Mdot
.75294 .79608 Mdot
.7451 .65882 Mdot
.84706 .75686 Mdot
.81176 .76471 Mdot
.66275 .73725 Mdot
.75294 .78039 Mdot
.6902 .59216 Mdot
.79608 .7098 Mdot
.87059 .79608 Mdot
.7451 .70588 Mdot
.80392 .83922 Mdot
.72157 .75686 Mdot
.76863 .68627 Mdot
.83922 .7451 Mdot
.83137 .75686 Mdot
.38824 .44706 Mdot
.76471 .79216 Mdot
.6549 .56078 Mdot
.76078 .67843 Mdot
.84706 .76471 Mdot
.86667 .84706 Mdot
.08627 .22353 Mdot
.77255 .81176 Mdot
.69804 .61176 Mdot
.79216 .7098 Mdot
.85882 .78824 Mdot
.80784 .77647 Mdot
.80392 .83137 Mdot
.70588 .73725 Mdot
.84314 .58039 Mdot
.44314 .43922 Mdot
.85098 .76078 Mdot
.79608 .77647 Mdot
.79216 .83529 Mdot
.50588 .57647 Mdot
.70196 .14118 Mdot
.60392 .57647 Mdot
.83922 .75294 Mdot
.8 .76863 Mdot
.78824 .83137 Mdot
.2549 .34902 Mdot
.69412 .15294 Mdot
.65098 .62353 Mdot
.83922 .76471 Mdot
.71765 .69412 Mdot
.8 .83529 Mdot
.18431 .26275 Mdot
.61176 .26275 Mdot
.61961 .61176 Mdot
.85098 .77647 Mdot
.82745 .82353 Mdot
.80392 .83922 Mdot
.7451 .79216 Mdot
.68235 .61569 Mdot
.77255 .65882 Mdot
.85098 .76078 Mdot
.76471 .70588 Mdot
.72941 .5098 Mdot
.74902 .77647 Mdot
.61569 .56863 Mdot
.75686 .63922 Mdot
.82353 .7451 Mdot
.78431 .70588 Mdot
.67059 .38824 Mdot
.77255 .81176 Mdot
.50588 .44314 Mdot
.72157 .61961 Mdot
.36471 .41569 Mdot
.83529 .74902 Mdot
.7098 .64314 Mdot
.78431 .64314 Mdot
.39608 .46667 Mdot
.67843 .61176 Mdot
.7451 .61569 Mdot
.8549 .76863 Mdot
.82353 .75686 Mdot
.71765 .02745 Mdot
.73725 .72941 Mdot
.5451 .51765 Mdot
.70588 .61569 Mdot
.81176 .72549 Mdot
.80392 .73725 Mdot
.71373 .03529 Mdot
.80392 .80392 Mdot
.51765 .5451 Mdot
.68627 .62353 Mdot
.72941 .61176 Mdot
.85098 .76863 Mdot
.76078 .64314 Mdot
.6902 .01961 Mdot
.78039 .79216 Mdot
.56863 .56471 Mdot
.70196 .6 Mdot
.8 .7098 Mdot
.81176 .73333 Mdot
.7098 .01961 Mdot
.57647 .24314 Mdot
.61176 .66275 Mdot
.64314 .58824 Mdot
.7451 .61176 Mdot
.83529 .76078 Mdot
.83137 .61961 Mdot
.70196 .01961 Mdot
.66275 .59608 Mdot
.66275 .73333 Mdot
.68235 .59608 Mdot
.78039 .6549 Mdot
.46275 .46667 Mdot
.72941 .02745 Mdot
.67059 .02353 Mdot
.20784 .27843 Mdot
.60392 .59608 Mdot
.7098 .57255 Mdot
.8 .72157 Mdot
.80392 .71765 Mdot
.67843 .03137 Mdot
.74902 .58824 Mdot
.10588 .82745 Mdot
.63922 .58039 Mdot
.75686 .62745 Mdot
.53725 .49412 Mdot
.78039 .07451 Mdot
.4 .30588 Mdot
.65098 .59216 Mdot
.73725 .77647 Mdot
.68627 .6 Mdot
.77255 .65098 Mdot
.51373 .5451 Mdot
.76078 .04314 Mdot
.21961 .28627 Mdot
.68627 .62745 Mdot
.8 .82353 Mdot
.67451 .58824 Mdot
.79608 .68235 Mdot
.81961 .76471 Mdot
.65098 .11373 Mdot
.58431 .28235 Mdot
.41176 .43922 Mdot
.57647 .56863 Mdot
.69412 .56863 Mdot
.80784 .72549 Mdot
.88627 .61176 Mdot
.15294 .23529 Mdot
.63137 .02353 Mdot
.53333 .53725 Mdot
.62745 .58824 Mdot
.71765 .59216 Mdot
.82745 .76078 Mdot
.81176 .06667 Mdot
.80784 .81961 Mdot
.66667 .67059 Mdot
.69804 .7451 Mdot
.62353 .57255 Mdot
.75294 .63529 Mdot
.86667 .78824 Mdot
.8 .05882 Mdot
.70196 .68235 Mdot
.66667 .59216 Mdot
.70588 .77255 Mdot
.64706 .59608 Mdot
.76863 .66667 Mdot
.85098 .78824 Mdot
.7098 .34118 Mdot
.72157 .74902 Mdot
.57255 .50196 Mdot
.47451 .57647 Mdot
.64706 .58039 Mdot
.78431 .6902 Mdot
.83529 .77647 Mdot
.12941 .24314 Mdot
.21176 .27843 Mdot
.51373 .46275 Mdot
.57255 .66275 Mdot
.67059 .57647 Mdot
.78039 .69804 Mdot
.84706 .76078 Mdot
.67843 .61961 Mdot
.69412 .79608 Mdot
.43137 .39216 Mdot
.77255 .81569 Mdot
.67059 .56471 Mdot
.8 .70588 Mdot
.72157 .25882 Mdot
.7451 .4549 Mdot
.77255 .81961 Mdot
.4902 .43922 Mdot
.65882 .69412 Mdot
.67843 .56471 Mdot
.78824 .7098 Mdot
.82353 .08235 Mdot
.7098 .04314 Mdot
.78431 .82353 Mdot
.38039 .37255 Mdot
.52157 .55294 Mdot
.67843 .55686 Mdot
.80784 .72157 Mdot
.83922 .0902 Mdot
.71765 .02353 Mdot
.79216 .82745 Mdot
.29412 .30196 Mdot
.54902 .56471 Mdot
.69804 .56863 Mdot
.80392 .71373 Mdot
.81569 .09412 Mdot
.71373 .02353 Mdot
.77647 .74118 Mdot
.39216 .38431 Mdot
.56471 .56863 Mdot
.67843 .56471 Mdot
.81569 .72941 Mdot
.75686 .30196 Mdot
.70588 .02745 Mdot
.59216 .37647 Mdot
.54902 .51765 Mdot
.58431 .58431 Mdot
.70588 .59216 Mdot
.82353 .74118 Mdot
.19608 .27059 Mdot
.63137 .11765 Mdot
.52549 .07843 Mdot
.56078 .49412 Mdot
.58431 .58431 Mdot
.69804 .6 Mdot
.80784 .73725 Mdot
.12941 .30196 Mdot
.51373 .34902 Mdot
.51765 .07059 Mdot
.52549 .44706 Mdot
.58824 .59216 Mdot
.71765 .62353 Mdot
.81176 .72941 Mdot
.46667 .58431 Mdot
.08235 .16863 Mdot
.52157 .06275 Mdot
.5451 .47451 Mdot
.58431 .58431 Mdot
.71373 .62745 Mdot
.80392 .72549 Mdot
.71373 .74118 Mdot
.32549 .41176 Mdot
.52549 .07059 Mdot
.49804 .43137 Mdot
.59216 .58824 Mdot
.70588 .61961 Mdot
.8 .72941 Mdot
.78039 .7451 Mdot
.77647 .77255 Mdot
.52549 .06667 Mdot
.52157 .47451 Mdot
.5451 .54902 Mdot
.71373 .63529 Mdot
.79608 .72549 Mdot
.80784 .72941 Mdot
.7098 .62353 Mdot
.53725 .07451 Mdot
.59216 .55686 Mdot
.52549 .53333 Mdot
.71765 .62745 Mdot
.80392 .72157 Mdot
.85882 .67451 Mdot
.72941 .50196 Mdot
.5451 .06667 Mdot
.58431 .57255 Mdot
.52549 .52941 Mdot
.73725 .63922 Mdot
.80392 .73333 Mdot
.71373 .26275 Mdot
.63529 .16863 Mdot
.54902 .0549 Mdot
.58824 .58039 Mdot
.50196 .50588 Mdot
.73725 .63922 Mdot
.8 .72549 Mdot
.75686 .11765 Mdot
.68235 .0549 Mdot
.56471 .0549 Mdot
.65098 .65882 Mdot
.50196 .50588 Mdot
.72549 .63922 Mdot
.80392 .72549 Mdot
.78039 .10196 Mdot
.66275 .05882 Mdot
.57647 .0549 Mdot
.60392 .63529 Mdot
.4902 .49804 Mdot
.72157 .64314 Mdot
.81569 .73333 Mdot
.73725 .1098 Mdot
.60784 .22353 Mdot
.56863 .04706 Mdot
.5098 .5451 Mdot
.48235 .48627 Mdot
.72157 .63529 Mdot
.80392 .73333 Mdot
.70588 .23529 Mdot
.32941 .18824 Mdot
.56078 .03922 Mdot
.68235 .72549 Mdot
.44314 .46275 Mdot
.69804 .61569 Mdot
.78431 .72157 Mdot
.73725 .30588 Mdot
.66275 .31373 Mdot
.49804 .06667 Mdot
.47843 .56863 Mdot
.65882 .69412 Mdot
.68235 .61569 Mdot
.78431 .7098 Mdot
.73725 .47059 Mdot
.63922 .04706 Mdot
.52941 .31373 Mdot
.3098 .41961 Mdot
.72941 .76471 Mdot
.69804 .62745 Mdot
.79216 .71765 Mdot
.50588 .47059 Mdot
.69412 .04706 Mdot
.35294 .35686 Mdot
.62745 .73333 Mdot
.70588 .76078 Mdot
.71765 .65098 Mdot
.76863 .70196 Mdot
.20784 .3098 Mdot
.63137 .07843 Mdot
.37647 .4549 Mdot
.35686 .47451 Mdot
.54902 .65098 Mdot
.7098 .64706 Mdot
.78039 .70196 Mdot
.6549 .66275 Mdot
.61569 .17647 Mdot
.56471 .63137 Mdot
.7098 .79608 Mdot
.40392 .51765 Mdot
.70196 .6549 Mdot
.77255 .6902 Mdot
.81569 .77255 Mdot
.6549 .27451 Mdot
.58039 .41961 Mdot
.72549 .79216 Mdot
.38431 .5098 Mdot
.67451 .64314 Mdot
.76078 .68235 Mdot
.81176 .78039 Mdot
.67451 .3098 Mdot
.54902 .03922 Mdot
.70588 .77647 Mdot
.33333 .45882 Mdot
.68235 .6549 Mdot
.7451 .67451 Mdot
.81569 .78039 Mdot
.66275 .30196 Mdot
.63922 .01176 Mdot
.73333 .80392 Mdot
.31765 .42353 Mdot
.68627 .65098 Mdot
.74118 .67843 Mdot
.81961 .78431 Mdot
.6549 .30196 Mdot
.65882 .01569 Mdot
.72157 .79216 Mdot
.34902 .46275 Mdot
.66667 .63922 Mdot
.74118 .66275 Mdot
.82353 .78824 Mdot
.77255 .62353 Mdot
.63922 .38824 Mdot
.72157 .79608 Mdot
.56078 .6549 Mdot
.63137 .63137 Mdot
.73333 .6549 Mdot
.8 .76078 Mdot
.73333 .68627 Mdot
.62353 .65098 Mdot
.72549 .79216 Mdot
.53725 .54902 Mdot
.60784 .61176 Mdot
.73725 .64314 Mdot
.80392 .75686 Mdot
.73725 .72549 Mdot
.61961 .63137 Mdot
.72941 .79608 Mdot
.68627 .56078 Mdot
.55686 .56863 Mdot
.72941 .64314 Mdot
.79608 .75294 Mdot
.72941 .7098 Mdot
.61176 .60392 Mdot
.71765 .80392 Mdot
.31373 .26667 Mdot
.55686 .56471 Mdot
.71765 .63922 Mdot
.8 .74118 Mdot
.73725 .71765 Mdot
.61961 .61176 Mdot
.63922 .7451 Mdot
.1098 .16863 Mdot
.56078 .56471 Mdot
.69412 .61569 Mdot
.80392 .73725 Mdot
.7451 .73333 Mdot
.62745 .61961 Mdot
.43922 .2549 Mdot
.52549 .59216 Mdot
.5451 .56078 Mdot
.70196 .61569 Mdot
.8 .73725 Mdot
.75294 .72941 Mdot
.64706 .63529 Mdot
.5451 .02353 Mdot
.56471 .63922 Mdot
.65882 .69412 Mdot
.70196 .62745 Mdot
.79608 .73725 Mdot
.75686 .72941 Mdot
.61569 .61176 Mdot
.59216 .00784 Mdot
.40784 .48627 Mdot
.33333 .42745 Mdot
.68627 .62353 Mdot
.79608 .72549 Mdot
.77647 .75686 Mdot
.56471 .12941 Mdot
.50588 .26667 Mdot
.4 .52941 Mdot
.55294 .65098 Mdot
.66275 .60784 Mdot
.77647 .70196 Mdot
.78824 .76471 Mdot
.67451 .0549 Mdot
.65098 .59216 Mdot
.67451 .76863 Mdot
.16863 .30196 Mdot
.67059 .62353 Mdot
.77255 .69804 Mdot
.78039 .74902 Mdot
.70196 .04706 Mdot
.61176 .04314 Mdot
.7098 .78824 Mdot
.3451 .45098 Mdot
.67059 .64314 Mdot
.74902 .67451 Mdot
.78039 .75686 Mdot
.69804 .07843 Mdot
.66275 .01569 Mdot
.69804 .77647 Mdot
.44706 .55686 Mdot
.63922 .61176 Mdot
.73333 .65882 Mdot
.76471 .74902 Mdot
.62353 .28235 Mdot
.6549 .00784 Mdot
.72157 .79216 Mdot
.49804 .58039 Mdot
.61961 .61961 Mdot
.74118 .65882 Mdot
.76471 .73725 Mdot
.73333 .68627 Mdot
.66275 .01569 Mdot
.7098 .69412 Mdot
.69804 .66275 Mdot
.59608 .6 Mdot
.71373 .64706 Mdot
.75686 .72941 Mdot
.75294 .72549 Mdot
.65098 .01569 Mdot
.52157 .01961 Mdot
.27451 .21176 Mdot
.58039 .58824 Mdot
.7098 .63529 Mdot
.77255 .7451 Mdot
.72941 .72941 Mdot
.66667 .02353 Mdot
.57647 .00392 Mdot
.01569 .08235 Mdot
.52549 .55686 Mdot
.69804 .61961 Mdot
.75294 .72941 Mdot
.7451 .75294 Mdot
.68627 .03922 Mdot
.59216 .00392 Mdot
.02353 .1098 Mdot
.76471 .81961 Mdot
.68235 .60784 Mdot
.74118 .68627 Mdot
.75294 .75686 Mdot
.70196 .02745 Mdot
.53725 .44706 Mdot
.57647 .65882 Mdot
.25098 .35294 Mdot
.64314 .58039 Mdot
.69412 .63922 Mdot
.76078 .76078 Mdot
.7098 .03137 Mdot
.41569 .43529 Mdot
.16471 .29804 Mdot
.58431 .6902 Mdot
.61569 .56078 Mdot
.68627 .61961 Mdot
.76471 .76863 Mdot
.72157 .04314 Mdot
.58039 .03529 Mdot
.68627 .78039 Mdot
.23137 .34902 Mdot
.62353 .59216 Mdot
.66275 .59608 Mdot
.56863 .59216 Mdot
.7098 .05098 Mdot
.6549 .01569 Mdot
.67059 .77255 Mdot
.37255 .48627 Mdot
.60392 .58431 Mdot
.68627 .61176 Mdot
.66275 .66667 Mdot
.60784 .11373 Mdot
.63922 .00784 Mdot
.65098 .77647 Mdot
.66667 .73725 Mdot
.60784 .58824 Mdot
.6902 .60784 Mdot
.72549 .71373 Mdot
.78039 .62745 Mdot
.64706 .00392 Mdot
.29412 .4549 Mdot
.63922 .59216 Mdot
.57647 .55686 Mdot
.67059 .59608 Mdot
.66667 .63922 Mdot
.70588 .70588 Mdot
.64706 .01176 Mdot
.03529 .08235 Mdot
.33725 .32941 Mdot
.56471 .56863 Mdot
.66275 .57255 Mdot
.66275 .62353 Mdot
.7098 .70588 Mdot
.67843 .03137 Mdot
.15294 .04706 Mdot
.22353 .30196 Mdot
.52549 .54118 Mdot
.66667 .58431 Mdot
.66667 .63922 Mdot
.73333 .72941 Mdot
.67843 .02745 Mdot
.57255 .47843 Mdot
.32941 .39216 Mdot
.47059 .48627 Mdot
.64314 .55686 Mdot
.64706 .60392 Mdot
.7451 .75686 Mdot
.69412 .02745 Mdot
.60392 .72941 Mdot
.41176 .48627 Mdot
.43137 .40392 Mdot
.63137 .55294 Mdot
.64706 .58824 Mdot
.76078 .75686 Mdot
.68627 .03529 Mdot
.36863 .56078 Mdot
.64706 .73725 Mdot
.42745 .33333 Mdot
.61569 .53725 Mdot
.65882 .57647 Mdot
.77255 .77647 Mdot
.69804 .03137 Mdot
.04706 .1451 Mdot
.27451 .40392 Mdot
.44314 .45882 Mdot
.6 .53333 Mdot
.64314 .56471 Mdot
.76863 .75294 Mdot
.71765 .04706 Mdot
.38431 .31765 Mdot
.28627 .39608 Mdot
.65882 .73725 Mdot
.59608 .55294 Mdot
.63137 .56471 Mdot
.73725 .74118 Mdot
.71373 .03529 Mdot
.56471 .3098 Mdot
.69412 .78039 Mdot
.68627 .75686 Mdot
.56078 .53725 Mdot
.63137 .54902 Mdot
.63529 .63137 Mdot
.60784 .1098 Mdot
.51765 .1451 Mdot
.36078 .37255 Mdot
.67451 .64706 Mdot
.56863 .56471 Mdot
.62353 .54118 Mdot
.62353 .61176 Mdot
.70588 .72157 Mdot
.57647 .03922 Mdot
.56471 .42745 Mdot
.17647 .23922 Mdot
.52941 .53725 Mdot
.61961 .52941 Mdot
.62353 .60392 Mdot
.7098 .72549 Mdot
.46667 .10588 Mdot
.74118 .81176 Mdot
.25882 .36078 Mdot
.4549 .47843 Mdot
.63137 .54118 Mdot
.61569 .59216 Mdot
.7098 .73725 Mdot
.56863 .62745 Mdot
.4902 .64314 Mdot
.1451 .2549 Mdot
.37647 .12157 Mdot
.61961 .54902 Mdot
.66275 .63137 Mdot
.72549 .7451 Mdot
.57255 .58431 Mdot
.20392 .31373 Mdot
.31373 .43529 Mdot
.4549 .33333 Mdot
.63529 .55686 Mdot
.61961 .58824 Mdot
.74118 .74902 Mdot
.51765 .12941 Mdot
.58824 .56078 Mdot
.01569 .12549 Mdot
.43922 .18431 Mdot
.62353 .54118 Mdot
.63137 .59216 Mdot
.7451 .74902 Mdot
.57647 .12157 Mdot
.58039 .37647 Mdot
.5451 .63529 Mdot
.31373 .11373 Mdot
.56863 .49412 Mdot
.63922 .6 Mdot
.53725 .58039 Mdot
.58824 .1451 Mdot
.51373 .13333 Mdot
.3098 .43922 Mdot
.32157 .22353 Mdot
.54118 .49804 Mdot
.61569 .55294 Mdot
.53725 .56471 Mdot
.7451 .64706 Mdot
.50196 .10588 Mdot
.70588 .78824 Mdot
.30196 .70588 Mdot
.54902 .5098 Mdot
.61569 .56863 Mdot
.66275 .66667 Mdot
.6902 .71373 Mdot
.53725 .14902 Mdot
.44706 .11373 Mdot
.00392 .07059 Mdot
.4902 .48235 Mdot
.61176 .54902 Mdot
.66275 .67059 Mdot
.71373 .72941 Mdot
.53725 .12549 Mdot
.58039 .00784 Mdot
.00392 .04706 Mdot
.47451 .47451 Mdot
.61961 .54118 Mdot
.69412 .68627 Mdot
.69412 .73333 Mdot
.56863 .15294 Mdot
.56863 .00392 Mdot
.00784 .07843 Mdot
.46667 .43137 Mdot
.60392 .52941 Mdot
.66667 .65882 Mdot
.7098 .7451 Mdot
.55294 .20392 Mdot
.59608 .00784 Mdot
.32549 .39608 Mdot
.38824 .21176 Mdot
.58431 .50588 Mdot
.66275 .64706 Mdot
.70588 .72157 Mdot
.43137 .35686 Mdot
.61569 .00784 Mdot
.36863 .46275 Mdot
.32941 .08627 Mdot
.53333 .43922 Mdot
.66275 .63922 Mdot
.69412 .71765 Mdot
.21176 .23922 Mdot
.59608 .00784 Mdot
.37647 .47059 Mdot
.47451 .20784 Mdot
.50196 .42745 Mdot
.64706 .61176 Mdot
.69804 .71765 Mdot
.27059 .28627 Mdot
.55686 .02353 Mdot
.35686 .44706 Mdot
.38039 .19608 Mdot
.47451 .44314 Mdot
.65098 .61176 Mdot
.6902 .72157 Mdot
.70196 .67451 Mdot
.52941 .04314 Mdot
.33333 .18039 Mdot
.46667 .31373 Mdot
.50196 .47451 Mdot
.61961 .59216 Mdot
.68235 .70588 Mdot
.68627 .71373 Mdot
.51765 .06275 Mdot
.49804 .00392 Mdot
.26667 .31373 Mdot
.43922 .42353 Mdot
.6 .54902 Mdot
.68627 .7098 Mdot
.65098 .6902 Mdot
.50588 .07059 Mdot
.44706 .16078 Mdot
.24706 .34118 Mdot
.40784 .40392 Mdot
.61569 .56863 Mdot
.65098 .67059 Mdot
.68235 .71373 Mdot
.57647 .03137 Mdot
.53333 .5098 Mdot
.32941 .40392 Mdot
.3451 .34902 Mdot
.60392 .54902 Mdot
.68235 .68627 Mdot
.66667 .7098 Mdot
.63529 .01961 Mdot
.55294 .03137 Mdot
.00784 .1098 Mdot
.30196 .29804 Mdot
.58431 .51765 Mdot
.6902 .69412 Mdot
.65098 .68627 Mdot
.67059 .02353 Mdot
.60784 .00392 Mdot
.36471 .44314 Mdot
.33725 .30196 Mdot
.55294 .4549 Mdot
.67843 .66275 Mdot
.7098 .72941 Mdot
.65882 .00784 Mdot
.61176 .00392 Mdot
.39608 .47843 Mdot
.39608 .12157 Mdot
.51373 .43922 Mdot
.67059 .63922 Mdot
.69412 .71373 Mdot
.70588 .03529 Mdot
.59608 .00784 Mdot
.48235 .6 Mdot
.47451 .3451 Mdot
.4902 .4549 Mdot
.6549 .61961 Mdot
.66667 .70196 Mdot
.69412 .03922 Mdot
.50588 .04314 Mdot
.41569 .04706 Mdot
.19216 .27843 Mdot
.38431 .38431 Mdot
.65098 .6 Mdot
.58431 .58824 Mdot
.65098 .34902 Mdot
.51765 .56471 Mdot
.55686 .42745 Mdot
.00392 .0549 Mdot
.31373 .31765 Mdot
.61569 .55294 Mdot
.53333 .54902 Mdot
.66275 .68235 Mdot
.49804 .59216 Mdot
.63137 .80392 Mdot
.01569 .08627 Mdot
.27843 .27451 Mdot
.59608 .52549 Mdot
.61176 .61569 Mdot
.63137 .66275 Mdot
.34118 .4902 Mdot
.10196 .18824 Mdot
.35294 .43922 Mdot
.29804 .27451 Mdot
.58039 .50196 Mdot
.66667 .66275 Mdot
.67059 .69804 Mdot
.03529 .18824 Mdot
.02353 .12941 Mdot
.39608 .47451 Mdot
.39608 .39608 Mdot
.5098 .44314 Mdot
.62353 .61961 Mdot
.68235 .70588 Mdot
.42745 .33333 Mdot
.02353 .12941 Mdot
.40784 .48627 Mdot
.43137 .37647 Mdot
.48235 .44314 Mdot
.60392 .57255 Mdot
.63922 .69804 Mdot
.60392 .07059 Mdot
.52941 .18039 Mdot
.62353 .74902 Mdot
.20784 .27843 Mdot
.40392 .38431 Mdot
.56863 .52157 Mdot
.61176 .61961 Mdot
.66667 .02353 Mdot
.5098 .32941 Mdot
.1451 .15686 Mdot
.28627 .40392 Mdot
.30588 .29804 Mdot
.52157 .46275 Mdot
.63529 .6549 Mdot
.65882 .06275 Mdot
.54118 .58039 Mdot
.47843 .10196 Mdot
.32157 .41569 Mdot
.29412 .12549 Mdot
.55294 .45098 Mdot
.65098 .6549 Mdot
.66667 .65882 Mdot
.54902 .12549 Mdot
.52941 .03137 Mdot
.34902 .44706 Mdot
.35686 .28235 Mdot
.53333 .4549 Mdot
.54902 .55294 Mdot
.60784 .66667 Mdot
.55294 .07843 Mdot
.51765 .03529 Mdot
.38431 .46275 Mdot
.41569 .38824 Mdot
.54902 .49804 Mdot
.58431 .57255 Mdot
.64706 .68627 Mdot
.57255 .38824 Mdot
.40784 .26667 Mdot
.46275 .48627 Mdot
.19608 .26275 Mdot
.45882 .41961 Mdot
.5451 .47843 Mdot
.63137 .65098 Mdot
.12157 .22353 Mdot
.61961 .67843 Mdot
.47843 .03137 Mdot
0 .07451 Mdot
.37647 .35294 Mdot
.54902 .4902 Mdot
.67843 .71373 Mdot
.58431 .24314 Mdot
.3451 .48235 Mdot
.55686 .00392 Mdot
.00392 .0549 Mdot
.36078 .3098 Mdot
.52941 .43529 Mdot
.66275 .67451 Mdot
.72157 .05098 Mdot
.56078 .04314 Mdot
.55294 .00784 Mdot
.00392 .06667 Mdot
.26667 .22353 Mdot
.4902 .39608 Mdot
.54118 .53725 Mdot
.68235 .5098 Mdot
.50196 .56863 Mdot
.50196 .03529 Mdot
.00784 .0902 Mdot
.45882 .31765 Mdot
.54902 .47059 Mdot
.58431 .58039 Mdot
.65882 .69412 Mdot
.13333 .32157 Mdot
.4902 .42745 Mdot
.41961 .31373 Mdot
.56863 .4 Mdot
.51373 .47843 Mdot
.60784 .56471 Mdot
.67843 .7098 Mdot
.40784 .32941 Mdot
.69804 .77647 Mdot
.52549 .00392 Mdot
.3098 .40784 Mdot
.41569 .37647 Mdot
.6 .52941 Mdot
.65882 .6902 Mdot
.67843 .06667 Mdot
.53725 .63529 Mdot
.44314 .10588 Mdot
.29412 .42353 Mdot
.35294 .30588 Mdot
.53333 .43529 Mdot
.55686 .59216 Mdot
.72549 .20784 Mdot
.06275 .15294 Mdot
.46667 .0902 Mdot
.01569 .09804 Mdot
.32157 .26667 Mdot
.47843 .38039 Mdot
.78824 .82745 Mdot
.71765 .07059 Mdot
.52941 .27451 Mdot
.48235 .02353 Mdot
.33333 .45098 Mdot
.32549 .22745 Mdot
.53333 .44706 Mdot
.48235 .51373 Mdot
.60392 .65882 Mdot
.59608 .03922 Mdot
.54902 .00392 Mdot
.06275 .17255 Mdot
.38824 .29804 Mdot
.52549 .46275 Mdot
.60392 .59608 Mdot
.65882 .70588 Mdot
.62353 .07451 Mdot
.55686 .01961 Mdot
.04314 .06275 Mdot
.1098 .18431 Mdot
.49804 .43137 Mdot
.58039 .52549 Mdot
.65098 .68235 Mdot
.54902 .1098 Mdot
.57647 .64314 Mdot
.43137 .0549 Mdot
.00784 .0549 Mdot
.39608 .33725 Mdot
.57255 .5098 Mdot
.63922 .66275 Mdot
.6902 .03922 Mdot
.42745 .49804 Mdot
.67059 .71373 Mdot
.05098 .12941 Mdot
.33333 .27451 Mdot
.51373 .41961 Mdot
.5098 .53725 Mdot
.57255 .08235 Mdot
.63137 .71373 Mdot
.45098 .04314 Mdot
.06275 .18431 Mdot
.32941 .08627 Mdot
.52157 .41569 Mdot
.52941 .5451 Mdot
.65098 .70588 Mdot
.53725 .65882 Mdot
.07059 .16078 Mdot
.31765 .41569 Mdot
.47059 .30196 Mdot
.44706 .38039 Mdot
.58824 .57647 Mdot
.66275 .69804 Mdot
.19216 .34118 Mdot
.52157 .01961 Mdot
.07451 .2 Mdot
.17255 .27059 Mdot
.43137 .03529 Mdot
.56863 .51373 Mdot
.59216 .63137 Mdot
.25098 .43137 Mdot
.46275 .55294 Mdot
.31373 .21961 Mdot
.1098 .21569 Mdot
.34118 .13725 Mdot
.53333 .4549 Mdot
.50196 .54118 Mdot
.67059 .06275 Mdot
.48627 .6 Mdot
.47451 .0549 Mdot
.3451 .44314 Mdot
.32941 .25098 Mdot
.51373 .41176 Mdot
.48627 .50588 Mdot
.58431 .29412 Mdot
.52549 .6 Mdot
.48627 .02353 Mdot
.38039 .48235 Mdot
.33725 .28235 Mdot
.48627 .38431 Mdot
.53725 .55686 Mdot
.63529 .6902 Mdot
.64314 .71765 Mdot
.40784 .03529 Mdot
.32941 .44314 Mdot
.36863 .12941 Mdot
.38824 .30588 Mdot
.59608 .58431 Mdot
.65098 .6902 Mdot
.6 .66275 Mdot
.65098 .61961 Mdot
.41569 .29412 Mdot
.01569 .11765 Mdot
.39608 .31373 Mdot
.57255 .52157 Mdot
.46667 .5098 Mdot
.24706 .23137 Mdot
.5098 .6549 Mdot
.42745 .02745 Mdot
.25098 .37647 Mdot
.37647 .26275 Mdot
.51765 .44706 Mdot
.46275 .50196 Mdot
.72157 .05098 Mdot
.53725 .63137 Mdot
.52549 .00392 Mdot
.36471 .46667 Mdot
.38039 .06667 Mdot
.51765 .40784 Mdot
.43137 .46275 Mdot
.62745 .66275 Mdot
.57255 .66275 Mdot
.4 .11373 Mdot
.35686 .43529 Mdot
.30196 .09804 Mdot
.36471 .2902 Mdot
.49804 .49412 Mdot
.58824 .65098 Mdot
.57647 .64314 Mdot
.58039 .5098 Mdot
.43137 0 Mdot
.00392 .05882 Mdot
.37255 .27451 Mdot
.58431 .55294 Mdot
.44706 .50196 Mdot
.55686 .35294 Mdot
.74118 .80784 Mdot
.4549 .00392 Mdot
.00392 .04706 Mdot
.36078 .28235 Mdot
.57647 .50588 Mdot
.43529 .4902 Mdot
.71373 .03529 Mdot
.46667 .64706 Mdot
.5098 .00392 Mdot
.02745 .11765 Mdot
.32549 .27059 Mdot
.54118 .44706 Mdot
.36471 .43529 Mdot
.60392 .31765 Mdot
.60784 .72941 Mdot
.50588 0 Mdot
.31765 .42745 Mdot
.43529 .21961 Mdot
.41961 .33725 Mdot
.28627 .33725 Mdot
.57647 .63137 Mdot
.60392 .67843 Mdot
.51765 0 Mdot
.3451 .02745 Mdot
.1451 .6549 Mdot
.32941 .24706 Mdot
.4902 .49412 Mdot
.51373 .56471 Mdot
.56863 .06667 Mdot
.55686 .00392 Mdot
.32941 .26275 Mdot
.21176 .35294 Mdot
.34118 .27059 Mdot
.56078 .51765 Mdot
.42745 .4902 Mdot
.70196 .03922 Mdot
.56078 .02353 Mdot
.08235 .21176 Mdot
0 .03529 Mdot
.34118 .10196 Mdot
.5451 .44706 Mdot
.40784 .47059 Mdot
.67843 .65098 Mdot
.67451 .62353 Mdot
.42745 .11373 Mdot
.32941 .42353 Mdot
.48235 .39608 Mdot
.48235 .39216 Mdot
.4902 .50196 Mdot
.50588 .57255 Mdot
.61176 .65882 Mdot
.56471 .40784 Mdot
.05098 .13725 Mdot
.05882 .80784 Mdot
.35686 .27451 Mdot
.44706 .45098 Mdot
.49412 .56471 Mdot
.69412 .03529 Mdot
.44314 .07451 Mdot
.44706 .00392 Mdot
.2549 .36863 Mdot
.35686 .27451 Mdot
.57255 .52549 Mdot
.76863 .83922 Mdot
.68235 .04706 Mdot
.58039 .00784 Mdot
.41961 .05882 Mdot
.11373 .21176 Mdot
.3098 .2 Mdot
.51373 .40784 Mdot
.44706 .49804 Mdot
.55686 .61569 Mdot
.61176 .00392 Mdot
.28235 .36078 Mdot
.30196 .40392 Mdot
.45098 .12941 Mdot
.47451 .39608 Mdot
.47059 .50588 Mdot
.48235 .56471 Mdot
.59216 .06275 Mdot
.45882 .16471 Mdot
.31373 .06667 Mdot
.2549 .63529 Mdot
.37647 .28627 Mdot
.45098 .47451 Mdot
.53333 .59216 Mdot
.66275 .04706 Mdot
.44706 .20784 Mdot
.44706 .00784 Mdot
.28627 .38824 Mdot
.32549 .2549 Mdot
.49412 .46275 Mdot
.46667 .53333 Mdot
.53333 .26667 Mdot
.04314 .19216 Mdot
.4902 .00392 Mdot
.28627 .40392 Mdot
.31373 .16471 Mdot
.56078 .33725 Mdot
.47843 .53333 Mdot
.67451 .74902 Mdot
.47451 .2549 Mdot
.51765 .00392 Mdot
.28627 .40784 Mdot
.51373 .32941 Mdot
.48235 .37647 Mdot
.4549 .47451 Mdot
.45882 .53725 Mdot
.69804 .03922 Mdot
.41961 .31373 Mdot
.32157 .06667 Mdot
.13333 .64706 Mdot
.33725 .04314 Mdot
.43529 .45098 Mdot
.50196 .57647 Mdot
.68627 .09412 Mdot
.49412 .13333 Mdot
.41569 .30196 Mdot
.25098 .36863 Mdot
.33725 .24314 Mdot
.53725 .49804 Mdot
.44314 .51373 Mdot
.70588 .77647 Mdot
.5098 .11765 Mdot
.28627 .24706 Mdot
.28235 .41176 Mdot
.30588 .24706 Mdot
.51373 .42745 Mdot
.44706 .4902 Mdot
.54118 .61961 Mdot
.32941 .46667 Mdot
.42353 .02353 Mdot
.29412 .41176 Mdot
.46275 .27451 Mdot
.4 .33333 Mdot
.46667 .48627 Mdot
.6902 .76863 Mdot
.62353 .13333 Mdot
.54902 .00784 Mdot
.31373 .18431 Mdot
.24314 .62353 Mdot
.37647 .24706 Mdot
.46667 .47843 Mdot
.52549 .60392 Mdot
.72157 .0549 Mdot
.50588 .54118 Mdot
.44706 0 Mdot
.27059 .38824 Mdot
.33725 .04706 Mdot
.54902 .51373 Mdot
.38824 .46667 Mdot
.63922 .42353 Mdot
.51765 .29412 Mdot
.41961 .12941 Mdot
.29804 .41176 Mdot
.32549 .26667 Mdot
.51373 .42353 Mdot
.41569 .46275 Mdot
.55686 .63137 Mdot
.73725 .29412 Mdot
.02353 .08627 Mdot
.25098 .38824 Mdot
.37255 .15294 Mdot
.35686 .27843 Mdot
.42353 .46667 Mdot
.70196 .78039 Mdot
.67059 .02353 Mdot
.56863 .00392 Mdot
.41176 .00392 Mdot
.20392 .32157 Mdot
.37647 .30196 Mdot
.55294 .54902 Mdot
.27059 .38431 Mdot
.62353 .07451 Mdot
.74118 .83529 Mdot
.44314 0 Mdot
.28235 .4 Mdot
.34118 .22745 Mdot
.51765 .46667 Mdot
.40392 .47843 Mdot
.54902 .27451 Mdot
.11373 .28627 Mdot
.51373 .00392 Mdot
.27843 .40392 Mdot
.32941 .23137 Mdot
.47451 .41176 Mdot
.42353 .47843 Mdot
.74118 .80784 Mdot
.53333 .15686 Mdot
.52549 .00784 Mdot
.2 .33333 Mdot
.32941 .08627 Mdot
.44314 .35294 Mdot
.47059 .48627 Mdot
.50588 .58431 Mdot
.63137 .0549 Mdot
.48627 .16078 Mdot
.40784 .00784 Mdot
.27059 .37647 Mdot
.37255 .29804 Mdot
.52941 .51765 Mdot
.37255 .50588 Mdot
.2 .21569 Mdot
.74902 .82353 Mdot
.26667 .21176 Mdot
.28235 .4 Mdot
.30588 .25098 Mdot
.40392 .30196 Mdot
.42745 .49412 Mdot
.73333 .6902 Mdot
.71373 .8549 Mdot
.47843 .01569 Mdot
.2902 .41176 Mdot
.34902 .08627 Mdot
.42745 .37255 Mdot
.78039 .82353 Mdot
.70196 .77255 Mdot
.59608 .02745 Mdot
.51765 .00784 Mdot
.00784 .08627 Mdot
.23922 .33333 Mdot
.44314 .12157 Mdot
.54118 .54902 Mdot
.44706 .52549 Mdot
.73333 .48235 Mdot
.74118 .81569 Mdot
.42745 .01569 Mdot
.2549 .38039 Mdot
.36863 .13333 Mdot
.47451 .42353 Mdot
.04314 .18431 Mdot
.56863 .31373 Mdot
.7451 .83529 Mdot
.48627 .60784 Mdot
.28627 .40784 Mdot
.36863 .28235 Mdot
.44706 .40392 Mdot
.41176 .47059 Mdot
.77647 .84706 Mdot
.05882 .23137 Mdot
.15686 .17255 Mdot
.29412 .41176 Mdot
.48235 .25098 Mdot
.46275 .41176 Mdot
.44706 .49804 Mdot
.49412 .56078 Mdot
.6 .06667 Mdot
.32941 .18824 Mdot
.23137 .37255 Mdot
.24706 .38039 Mdot
.40784 .28627 Mdot
.49804 .4902 Mdot
.64706 .72941 Mdot
.10588 .30196 Mdot
.7451 .82745 Mdot
.4902 .53725 Mdot
.27843 .40392 Mdot
.39216 .08235 Mdot
.50196 .16078 Mdot
.01176 .10588 Mdot
.59216 .69412 Mdot
.76078 .83529 Mdot
.44314 .58824 Mdot
.2902 .40784 Mdot
.36863 .26667 Mdot
.47843 .3451 Mdot
.45098 .47059 Mdot
.73333 .82353 Mdot
.03137 .16863 Mdot
.49804 .61569 Mdot
.3098 .42745 Mdot
.26667 .37255 Mdot
.42353 .37647 Mdot
.55294 .56863 Mdot
.60784 .68627 Mdot
.64706 .05098 Mdot
.73333 .82353 Mdot
.48235 .57647 Mdot
.26667 .38431 Mdot
.38039 .33333 Mdot
.48235 .39216 Mdot
.4 .48627 Mdot
.03922 .23529 Mdot
.75686 .83529 Mdot
.63137 .7451 Mdot
.2902 .41569 Mdot
.34902 .04706 Mdot
.48627 .22353 Mdot
.41961 .45882 Mdot
.77255 .8549 Mdot
.76863 .84706 Mdot
.53333 .65882 Mdot
.31765 .43137 Mdot
.29412 .36078 Mdot
.43529 .14118 Mdot
.54902 .57255 Mdot
.52157 .60784 Mdot
.03922 .20784 Mdot
.71373 .82745 Mdot
.39608 .49412 Mdot
.27843 .39216 Mdot
.38824 .3098 Mdot
.47843 .46275 Mdot
.48627 .56863 Mdot
.59216 .12157 Mdot
.7451 .83137 Mdot
.51765 .62353 Mdot
.2902 .41176 Mdot
.43529 .21569 Mdot
.52157 .47451 Mdot
.05882 .21176 Mdot
.76863 .84706 Mdot
.77255 .8549 Mdot
.23137 .37255 Mdot
.30196 .41961 Mdot
.36078 .1451 Mdot
.47059 .40392 Mdot
.57647 .62353 Mdot
.59608 .67059 Mdot
.78431 .8549 Mdot
.72549 .81961 Mdot
.43137 .53725 Mdot
.27843 .39608 Mdot
.36078 .18431 Mdot
.52941 .53333 Mdot
.76471 .84314 Mdot
.49804 .72157 Mdot
.74902 .83922 Mdot
.68235 .78431 Mdot
.2902 .41569 Mdot
.40392 .25882 Mdot
.50196 .43529 Mdot
.49804 .58431 Mdot
.7451 .83137 Mdot
.77647 .8549 Mdot
.41961 .56078 Mdot
.3098 .43137 Mdot
.38039 .15294 Mdot
.47059 .40784 Mdot
.46275 .53333 Mdot
.62353 .69412 Mdot
.78431 .8549 Mdot
.7451 .83137 Mdot
.44706 .55686 Mdot
.25098 .37255 Mdot
.40784 .36471 Mdot
.50588 .50588 Mdot
.5098 .61176 Mdot
.50196 .72157 Mdot
.76471 .8549 Mdot
.56078 .65882 Mdot
.2902 .40784 Mdot
.38824 .13333 Mdot
.47843 .33333 Mdot
.52941 .61569 Mdot
.56863 .78824 Mdot
.78039 .85882 Mdot
.38824 .5451 Mdot
.32549 .45882 Mdot
.36471 .13725 Mdot
.55294 .20784 Mdot
.00784 .12941 Mdot
.91373 .98039 Mdot
.80392 .87451 Mdot
.74902 .83922 Mdot
.48235 .58824 Mdot
.27843 .39216 Mdot
.4549 .35686 Mdot
.55294 .56863 Mdot
.76471 .84706 Mdot
.87451 .91765 Mdot
.76471 .85098 Mdot
.69804 .79608 Mdot
.2902 .41176 Mdot
.37647 .32941 Mdot
.50588 .4549 Mdot
.67843 .76471 Mdot
.82353 .91373 Mdot
.79216 .86275 Mdot
.52157 .64706 Mdot
.36078 .47451 Mdot
.3451 .1098 Mdot
.55686 .29412 Mdot
0 .14902 Mdot
.98039 1 Mdot
.81569 .88235 Mdot
.67843 .77255 Mdot
.60784 .68235 Mdot
.29412 .40392 Mdot
.50196 .29804 Mdot
.52157 .56078 Mdot
.92549 .94902 Mdot
.85882 .91373 Mdot
.76078 .83922 Mdot
.65098 .76471 Mdot
.33333 .44314 Mdot
.4 .32549 Mdot
.54118 .50196 Mdot
.83529 .87451 Mdot
.75294 .92157 Mdot
.74118 .84706 Mdot
.17255 .35686 Mdot
.38039 .4902 Mdot
.3451 .18431 Mdot
.53725 .19216 Mdot
.00784 .23529 Mdot
.92941 .9451 Mdot
.76078 .84706 Mdot
.71373 .81569 Mdot
.52549 .62353 Mdot
.32941 .42353 Mdot
.42745 .31373 Mdot
.63137 .64706 Mdot
.98039 .99608 Mdot
.79216 .87451 Mdot
.7451 .82745 Mdot
.37647 .4902 Mdot
.36471 .46667 Mdot
.38824 .11373 Mdot
.59216 .57255 Mdot
.84314 .88235 Mdot
.74118 .89412 Mdot
.74902 .83137 Mdot
.28627 .43137 Mdot
.35294 .46275 Mdot
.34118 .23529 Mdot
.50196 .22353 Mdot
.00784 .30588 Mdot
.39216 .52157 Mdot
.77255 .85098 Mdot
.71765 .82353 Mdot
.41961 .53333 Mdot
.34902 .44706 Mdot
.44706 .06275 Mdot
.76078 .76863 Mdot
.68235 .76863 Mdot
.79216 .86667 Mdot
.64706 .83137 Mdot
.42745 .58039 Mdot
.32157 .43922 Mdot
.42745 .18039 Mdot
.76078 .64314 Mdot
.75294 .80784 Mdot
.61176 .81176 Mdot
.32157 .64706 Mdot
.12157 .33333 Mdot
.40392 .50588 Mdot
.33725 .23529 Mdot
.49804 .15294 Mdot
.02353 .23922 Mdot
.74118 .84706 Mdot
.19608 .62353 Mdot
.07843 .18039 Mdot
.2 .34902 Mdot
.51765 .60784 Mdot
.43137 .22745 Mdot
.70196 .69804 Mdot
.78039 .8549 Mdot
.32941 .74902 Mdot
.43137 .17255 Mdot
.13725 .09804 Mdot
.30588 .42745 Mdot
.39608 .13333 Mdot
.71373 .63922 Mdot
.76863 .85098 Mdot
.28627 .71765 Mdot
.14902 .43137 Mdot
.55686 .04706 Mdot
.03137 .14902 Mdot
.32549 .12549 Mdot
.62745 .23922 Mdot
.02353 .15686 Mdot
.31373 .7098 Mdot
.06667 .66667 Mdot
.63922 .03137 Mdot
.38824 .03922 Mdot
.50588 .60392 Mdot
.55686 .37647 Mdot
.60392 .62745 Mdot
.23137 .56471 Mdot
.35686 .85882 Mdot
.68627 .03137 Mdot
.5098 .02745 Mdot
.19608 .34118 Mdot
.41569 .25882 Mdot
.62353 .60392 Mdot
.36078 .59608 Mdot
.4 .83529 Mdot
.65882 .06667 Mdot
.56471 .32157 Mdot
.39608 .03922 Mdot
.36471 .04706 Mdot
.56078 .53333 Mdot
.33725 .54118 Mdot
.04706 .6 Mdot
.41569 .15686 Mdot
.72941 .53725 Mdot
.44314 0 Mdot
.34118 .37647 Mdot
.51765 .47451 Mdot
.50588 .62745 Mdot
.02353 .4902 Mdot
.62353 .18431 Mdot
.6 .41961 Mdot
.70588 .57647 Mdot
.06667 .21961 Mdot
.47451 .27843 Mdot
.6 .64706 Mdot
.01569 .45098 Mdot
.68627 .21569 Mdot
.76863 .06275 Mdot
.60784 .57255 Mdot
.48235 .01176 Mdot
.33333 .20392 Mdot
.61569 .58431 Mdot
.01176 .28235 Mdot
.69804 .27451 Mdot
.4549 .31765 Mdot
.63137 .58039 Mdot
.43529 .13725 Mdot
.44314 .22353 Mdot
.50588 .47451 Mdot
.01176 .21176 Mdot
.56863 .28235 Mdot
.03137 .57255 Mdot
.75686 .6 Mdot
.43922 0 Mdot
.32549 .69412 Mdot
.4549 .4 Mdot
.02745 .21961 Mdot
.43529 .22745 Mdot
.02745 .54902 Mdot
.59216 .34902 Mdot
.4 .31373 Mdot
.52941 .06667 Mdot
.40392 .37647 Mdot
.00784 .2 Mdot
.47059 .18824 Mdot
.03529 .5098 Mdot
.75686 .05882 Mdot
.51373 .21176 Mdot
.70196 .59608 Mdot
.46667 .43137 Mdot
.00392 .16863 Mdot
.00784 .11373 Mdot
.00784 .44314 Mdot
.76471 .11765 Mdot
.65098 .10588 Mdot
.5451 .42745 Mdot
.57255 .4 Mdot
.00784 .18039 Mdot
.32157 .17647 Mdot
0 .4 Mdot
.00392 .46667 Mdot
.74902 .04314 Mdot
.67843 .47451 Mdot
.52549 .31373 Mdot
.00392 .14118 Mdot
.21961 .03922 Mdot
0 .37255 Mdot
.03529 .66275 Mdot
.77647 .05882 Mdot
.52549 .00392 Mdot
.04706 .55686 Mdot
.09804 .17647 Mdot
.32941 .13333 Mdot
0 .33725 Mdot
.33725 .88627 Mdot
.78039 .05098 Mdot
.53333 .00392 Mdot
.59216 .1451 Mdot
.39216 .40392 Mdot
.42745 .10196 Mdot
0 .28627 Mdot
.5451 .87451 Mdot
.7451 .06667 Mdot
.6 .01961 Mdot
.58824 .42353 Mdot
.43529 .38431 Mdot
.44314 .10196 Mdot
0 .19216 Mdot
.24706 .64706 Mdot
.47059 .14118 Mdot
.50588 .06275 Mdot
.56078 .02745 Mdot
.43529 .38824 Mdot
.28235 .12157 Mdot
.01961 .23137 Mdot
.03137 .5451 Mdot
.0902 .2549 Mdot
.2 .12549 Mdot
.58039 .01961 Mdot
.43137 .38431 Mdot
.11373 .11765 Mdot
.00392 .22745 Mdot
.00784 .48235 Mdot
.00392 .27843 Mdot
.02353 .17647 Mdot
.55294 .03137 Mdot
.43922 .36471 Mdot
.07451 .09412 Mdot
.0549 .41569 Mdot
0 .41569 Mdot
.01176 .31373 Mdot
.00784 .19608 Mdot
.35294 .03137 Mdot
.41176 .35294 Mdot
.0549 .09412 Mdot
.01961 .25882 Mdot
.00392 .37647 Mdot
.01961 .31765 Mdot
.05882 .24706 Mdot
.05882 .09412 Mdot
.41176 .34902 Mdot
.01176 .10588 Mdot
.01176 .23529 Mdot
.00392 .36078 Mdot
.16863 .38431 Mdot
.35294 .4902 Mdot
.00392 .13333 Mdot
.41961 .34118 Mdot
.00392 .11765 Mdot
0 .22353 Mdot
.00392 .34118 Mdot
.40784 .52157 Mdot
.61961 .7098 Mdot
.03529 .18824 Mdot
.47843 .3451 Mdot
.01176 .13725 Mdot
.01176 .26275 Mdot
.02745 .3451 Mdot
.51373 .59608 Mdot
.70588 .77255 Mdot
.21961 .35294 Mdot
.49804 .34118 Mdot
.00784 .15294 Mdot
.00784 .23137 Mdot
.18039 .41176 Mdot
.60784 .67059 Mdot
.72157 .78431 Mdot
.25882 .38039 Mdot
.35294 .23529 Mdot
.00392 .14902 Mdot
.01569 .21176 Mdot
.43922 .55294 Mdot
.85098 .87843 Mdot
.46275 .49412 Mdot
.23529 .36471 Mdot
.03137 .07451 Mdot
.00392 .16078 Mdot
.00392 .14118 Mdot
.51765 .59608 Mdot
.58824 .56471 Mdot
.47059 .41961 Mdot
.23922 .34902 Mdot
.00784 .07843 Mdot
.00392 .16078 Mdot
.07843 .21961 Mdot
.74118 .78824 Mdot
.52157 .45098 Mdot
.46275 .39608 Mdot
.2549 .34118 Mdot
.24706 .03529 Mdot
.00392 .14902 Mdot
.43137 .52157 Mdot
.56078 .54902 Mdot
.4549 .41176 Mdot
.40392 .38039 Mdot
.2549 .32549 Mdot
.00784 .09804 Mdot
0 .18824 Mdot
.53725 .60784 Mdot
.48235 .43922 Mdot
.37647 .36471 Mdot
.38431 .39608 Mdot
.20392 .30588 Mdot
.00392 .13333 Mdot
.10588 .28235 Mdot
.56863 .60784 Mdot
.40392 .39216 Mdot
.37647 .37255 Mdot
.36471 .38431 Mdot
.1451 .27843 Mdot
.00392 .09412 Mdot
.4902 .56078 Mdot
.41176 .36078 Mdot
.40392 .38824 Mdot
.36471 .36078 Mdot
.35294 .36863 Mdot
.22745 .1451 Mdot
.00392 .12941 Mdot
.69412 .76078 Mdot
.42353 .40392 Mdot
.37647 .37255 Mdot
.39608 .39608 Mdot
.33725 .35686 Mdot
.01961 .07843 Mdot
.03922 .17647 Mdot
.41569 .39608 Mdot
.43137 .41569 Mdot
.38824 .36863 Mdot
.37255 .38039 Mdot
.28235 .33725 Mdot
.00392 .12549 Mdot
.4902 .56863 Mdot
.48235 .46275 Mdot
.43137 .43922 Mdot
.38039 .37255 Mdot
.36078 .37647 Mdot
.19608 .27843 Mdot
0 .11765 Mdot
.63922 .68627 Mdot
.50588 .52157 Mdot
.40784 .41961 Mdot
.3451 .35686 Mdot
.39216 .41569 Mdot
.30196 .33725 Mdot
.02353 .15294 Mdot
.52549 .52549 Mdot
.55686 .55686 Mdot
.35686 .39216 Mdot
.34902 .36078 Mdot
.3451 .36863 Mdot
.23529 .14118 Mdot
.60784 .65098 Mdot
.58039 .57255 Mdot
.43529 .45098 Mdot
.34902 .40784 Mdot
.35686 .41569 Mdot
.28235 .34902 Mdot
0 .16471 Mdot
.3451 .35686 Mdot
.44314 .42745 Mdot
.45098 .52157 Mdot
.24314 .34118 Mdot
.34902 .37255 Mdot
.34902 .41961 Mdot
.12941 .25098 Mdot
.42745 .39608 Mdot
.43137 .41569 Mdot
.1098 .23137 Mdot
.19216 .27059 Mdot
.40784 .44706 Mdot
.35686 .38431 Mdot
.5098 .55686 Mdot
.43529 .38431 Mdot
.42353 .47059 Mdot
.23137 .33333 Mdot
.12549 .22353 Mdot
.26667 .34118 Mdot
.03529 .26667 Mdot
.43922 .40392 Mdot
.46667 .40392 Mdot
.32549 .43137 Mdot
.3451 .39216 Mdot
.36471 .41176 Mdot
.38431 .44314 Mdot
.44706 .45098 Mdot
.43922 .41176 Mdot
.36863 .39608 Mdot
.56078 .51373 Mdot
.4902 .43922 Mdot
.34118 .37647 Mdot
.18824 .6549 Mdot
.44706 .40392 Mdot
.4549 .4 Mdot
.61961 .7098 Mdot
.52941 .41961 Mdot
.38824 .39608 Mdot
.43529 .50196 Mdot
.37647 .38824 Mdot
.43137 .41176 Mdot
.40784 .40392 Mdot
.54118 .5098 Mdot
.42353 .38039 Mdot
.36078 .42353 Mdot
.43922 .35686 Mdot
.4549 .40784 Mdot
.42353 .39216 Mdot
.45882 .44314 Mdot
.38039 .37255 Mdot
.43922 .42353 Mdot
.46275 .54902 Mdot
.30196 .30588 Mdot
.44314 .40392 Mdot
.73333 .78431 Mdot
.27843 .3451 Mdot
.37255 .43137 Mdot
.52549 .59608 Mdot
.35294 .3098 Mdot
.43529 .41569 Mdot
.45098 .4 Mdot
.42353 .4549 Mdot
.42353 .48235 Mdot
.54902 .62353 Mdot
.40784 .38431 Mdot
.4 .34118 Mdot
.42353 .36863 Mdot
.47059 .45882 Mdot
.44314 .44706 Mdot
.50196 .52157 Mdot
.52941 .59608 Mdot
.31765 .35686 Mdot
.46275 .43922 Mdot
.42353 .38039 Mdot
.59608 .63137 Mdot
.45882 .48627 Mdot
.67059 .71373 Mdot
.18431 .23922 Mdot
.43137 .41569 Mdot
.48235 .46275 Mdot
.57255 .6 Mdot
.49412 .53725 Mdot
.75294 .78824 Mdot
.43922 .37255 Mdot
.41569 .40784 Mdot
.45882 .44706 Mdot
.59608 .53725 Mdot
.67843 .64706 Mdot
.87059 .8902 Mdot
.46667 .33725 Mdot
.4 .41569 Mdot
.46667 .45882 Mdot
.54118 .45882 Mdot
.65098 .59608 Mdot
.90196 .92157 Mdot
.4902 .35686 Mdot
.38039 .39608 Mdot
.47059 .46275 Mdot
.57647 .56078 Mdot
.91765 .8902 Mdot
.81961 .85882 Mdot
.36471 .3451 Mdot
.35686 .38824 Mdot
.45098 .4549 Mdot
.60784 .63137 Mdot
.99608 .99608 Mdot
.78039 .81569 Mdot
.24706 .34902 Mdot
.43922 .4902 Mdot
.4902 .52941 Mdot
.87059 .88235 Mdot
.98431 .99216 Mdot
.69804 .73725 Mdot
.37255 .43137 Mdot
.42745 .47843 Mdot
.57647 .61176 Mdot
.99216 .99216 Mdot
.83529 .87451 Mdot
.42353 .35686 Mdot
.36471 .42745 Mdot
.50588 .57647 Mdot
.99608 .99608 Mdot
.87843 .89412 Mdot
.75294 .76863 Mdot
.40392 .47451 Mdot
.52157 .59608 Mdot
.99216 1 Mdot
.95294 .97255 Mdot
.77255 .82353 Mdot
.36863 .45098 Mdot
.51765 .57647 Mdot
.86667 .92157 Mdot
.97255 .97647 Mdot
.79608 .83529 Mdot
.35294 .43137 Mdot
.52941 .60784 Mdot
.85882 .90196 Mdot
.90588 .92157 Mdot
.8 .83137 Mdot
.4 .46275 Mdot
.6 .67059 Mdot
.98039 .98824 Mdot
.89412 .93333 Mdot
.60784 .52549 Mdot
.47843 .53725 Mdot
.84314 .89804 Mdot
.93333 .96078 Mdot
.81569 .85098 Mdot
.42353 .48235 Mdot
.68627 .7451 Mdot
.94118 .96863 Mdot
.8549 .8902 Mdot
.41961 .38824 Mdot
.65882 .72549 Mdot
.91373 .93333 Mdot
.89804 .90196 Mdot
.46667 .4902 Mdot
.77647 .83529 Mdot
.89804 .91765 Mdot
.34118 .77255 Mdot
.61176 .6902 Mdot
.9098 .94118 Mdot
.36078 .78039 Mdot
.67059 .69804 Mdot
.74118 .65882 Mdot
.60392 .49804 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002@3ooonfo`000140oooo]P00
000:0?ooo`002@3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oooooogl000Coogl000<0oooo
oomo003oool00oooO`000`3oooooogl00?ooo`0>oomo00050?ooooooO`3oogl0oomo003oool01?oo
O`001@2P8?3oogl00?ooooooO`00oooo00Coogl000D0X23`oomo003oooooogl00?ooo`04oomo0005
0?ooooooO`3oogl0oomo003oool00_ooO`030?ooo`;oogl000<0oooooomo003oool00P3oool3oomo
00030?ooooooO`3oogl000;oogl000H0oooooomo003oool0X23`oomo003oool4oomo00040?mo0?oo
O`00oooooomo00P0oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?ooo`0o0?ooo`03o`00
003oool0oooo00l0oooo1_ooO`020?ooo`05oomo003oooooogl00?ooooooO`001P3oool01?ooO`00
ogl00?ooooooO`0O0?ooo`03oj0Pl03oool0oooo00/0oooo00?oogl00?ooo`3oool01`3oool00onP
8?00oooo0?ooo`0:0?ooo`Googl0403oool00onP8?00oooo0?ooo`0F0?ooo`03oomo003oool0oooo
02T0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool00`3oool00oooO`00
oooo0?ooo`080?ooo`03oomo003oool0oooo00D0oooo0oooO`020?ooo`04oomo003oool0oooo0?oo
o`;oogl00`3oool00oooO`00oooooomo00020?ooo`03oomo003oool0oooo0080oooo0_ooO`030?oo
o`?oogl000L0oooooomo0?ooO`3oogl00?ooo`3oO`00X23`00D0oooo00?oogl00?ooo`3oool00P3o
ool01P2P8?00oooo0?ooo`3oooooogl00:0Pl0?oogl000H0oooooomo0?ooO`3oogl00?ooooooO`02
0?ooo`Ooogl0103oool01?ooO`00oooo0?ooooooO`0;0?ooo`03oomo003oool0oooo00@0oooo00<0
X23`0?ooo`3oool0=P3oool00ol00000oooo0?ooo`0?0?ooo`04oj0Pl?ooO`00ogl0oomo00@0oooo
00?oX23`0?ooooooO`002`3oool00oooO`00oooo0?ooo`150?ooo`03oomo003oool0oooo00X0oooo
00<0ogl00?ooo`3oool00`3oool00onP8?00oooo0?ooo`110?ooo`030000003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo01D0oooo00Coogl00?ooooooO`3oogl00P3oool00oooO`00oooo
0?ooo`040?ooo`03oomo003oool0oooo00;oogl00P3oool00oooO`00oooooomo00020?ooo`?oogl0
0P3oool00`2P8?3oogl0oomo00040?ooo`07oomo003oooooogl00?mo0?ooO`00X23`0?ooo`02oomo
00030?ooo`2P8?00oooo00?oogl000D0oooooomo002P8?3oogl00:0Pl003oomo00040?ooooooO`00
oooo0?oooa3oogl000<0oooooomo003oool00`3oool2oomo00D0oooo00?oogl00?ooo`3oool01@3o
ool00oooO`00oooo0?ooo`0e0?ooo`03o`00003oool0oooo00l0oooo00?oX23`oomo0?ooO`000P3o
O`001@3oooooogl00?mo003oool0ogl000<0oooo00D0ogl00?ooo`3oool0oooooj0Pl0050?ooo`03
oj0Pl03oool0oooo02/0oooo00?oX23`0?oooonP8?005`3oool00oooO`00oooo0?ooo`1C0?ooo`03
0000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0180oooo00?oogl00?ooooooO`00
0`3oool00oooO`00oooooomo00090?ooo`040?mo003oool0oooooomo00L0oooo00?oogl00?ooo`3o
ool01`3oool01_ooO`00oooooomo003oooooogl00?ooo`Coogl00P3oool01_ooO`00oooooomo003o
ooooogl00?ooo`;oogl00P2P8?02oomo00060?ooooooO`00oooo0?ooooooO`00oooo1OooO`001@2P
8?3oogl00?ooo`2P8?00oooo00;oogl000H0oooo0:0Pl03oooooogl00?ooooooO`020?ooo`0:oomo
003oooooogl0oomo003oooooogl00?ooooooO`00X23`0?ooo`?oogl000<0oooo0:0Pl03oool0=`3o
ool00ol00000oooo0?ooo`0?0?ooo`;oX23`00@0ogl0oj0Pl03oO`00ogl00P3oool00`3oO`00oooo
0?mo00160?ooo`05oj0Pl03oool0oooo0?oooonP8?00103oool00onP8?00oooo0?ooo`080?ooo`03
0?mo003oool0oooo04d0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
9`3oool00`2P8?00oooo0?ooo`040?ooo`03oomo003oool0oooo00L0oooo00<0X23`0?ooooooO`00
0`3oool02@2P8?00oooo0?ooo`2P8?3oogl00?ooo`3oO`00oooo0:0Pl002oomo00030?ooooooO`00
X23`0080oooo00@0X23`0?ooo`3oool0oooo0_ooO`000`3oooooogl0oomo0002oomo00030:0Pl?oo
O`3oogl000_oogl000H0oooo0:0Pl03oooooogl00:0Pl03oool3oomo00030:0Pl03oooooogl000H0
oooo00Coogl00?ooo`3oool0X23`=@3oool00ol00000oooo0?ooo`0?0?ooo`CoX23`0P3oO`060?oo
o`030?mo003oool0oooo00L0oooo00?oX23`0?ooo`3oool00_nP8?0F0?ooo`03oomo003oool0oooo
00l0oooo00?oX23`0?ooo`3oool0K`3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`020?ooo`03oomo003oool0oooo0080oooo00@0X23`0?ooo`3oooooogl00P3oool00ooo
O`00oooo0?ooo`030?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool0103oool01Ooo
O`00oooo0?ooo`3oooooogl00080oooo00H0X23`0?ooo`3oooooogl00?ooo`2P8?070?ooo`06oomo
003oool0oooooomo003oooooogl00`3oool02OooO`00oooo0?ooo`2P8?3oogl00?ooooooO`00oooo
oomo00060?ooo`03oomo003oooooogl00080X23`00?oogl00?ooooooO`001?ooO`020:0Pl003oomo
002P8?00X23`0080X23`0_ooO`020:0Pl004oomo002P8?3oogl00?ooo`;oogl000@0X23`oomo003o
ool0oooo0oooO`000`3oool0X23`0?ooo`060:0Pl0?oogl000@0oooo0:0Pl02P8?00X23`0oooO`00
103oooooogl00?ooo`3oool2oomo0080oooo00?oogl00?ooo`3oool09@3oool00ol00000oooo0?oo
o`0?0?ooo`KoX23`00<0ogl0oomo0?nP8?000P3oO`0;0?ooo`050?mo003oool0oooo0?oooonP8?00
0P3oool00`3oO`00oooo0?ooo`0e0?ooo`03oj0Pl03oool0oooo00`0oooo00<0ogl00?ooo`3oool0
303oool00onP8?00oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo0200oooo00<000000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool09`3oool00oooO`00oooooomo00090?ooo`03oomo003o
ool0oooo00H0oooo00Coogl00?ooo`3oooooogl01`3oool2oomo00D0oooo2?ooO`001@3oooooogl0
0?ooo`3oool0X23`00Coogl00P3oool00`2P8?3oogl0oomo00020?ooo`06oomo003oooooogl0oomo
003oool0X23`0`3oool20:0Pl0<0oooo00Koogl00:0Pl03oool0X23`0?ooooooO`020?ooo`03oomo
003oool0X23`00;oogl000<0X23`0?ooo`3oool00P3oool01?ooO`00oooo0?ooo`3oool2oomo0004
0?ooooooO`00oooooomo0280oooo00?o00000?ooo`3oool03`3oool00onP8?00ogl0oomo0003oj0P
l0D0ogl000D0oooooomo003oO`00oooo0?mo00130?ooo`03oj0Pl03oool0oooo01D0oooo00?oX23`
0?ooo`3oool0A`3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0<0?oo
o`03oomo003oooooogl00080oooo00Coogl00?ooo`3oooooogl0103oool00oooO`00oooo0?ooo`02
0?ooo`03oomo002P8?00oooo00P0oooo00?oogl00?ooo`3oool00`3oool00`3oO`00oooo0?ooo`09
0?ooo`03oomo003oooooogl000X0oooo00@0ogl00?ooo`2P8?00ogl00P3oool01?ooO`00oooooomo
003oool2oomo0080X23`1?ooO`000`2P8?00oooo0:0Pl0030?ooo`80X23`00<0oooo0:0Pl?ooO`00
0P2P8?001?ooO`00X23`0?ooooooO`020:0Pl0040?ooooooO`3oogl00:0Pl0Coogl000@0X23`0?oo
o`3oooooogl00`2P8?001?ooO`00X23`0:0Pl03oool:oomo0080oooo00?oogl00?ooooooO`000P3o
ool00oooO`00oooo0?ooo`050?ooo`03oomo003oool0oooo01H0oooo00?o00000?ooo`3oool03`3o
ool2oj0Pl003oomo0?nP8?3oX23`00;oX23`00<0ogl0oj0Pl03oO`00103oO`00103oooooogl00?oo
ooooO`0Q0?ooo`03oomo003oool0oooo01T0oooo00?oX23`0?ooo`3oool0903oool00onP8?00oooo
0?ooo`050?ooo`03oomo003oool0oooo01P0oooo00@0ogl00?ooo`3oool0ogl0603oool00`000000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`050?ooo`03oomo003oool0oooo00H0oooo
00Googl00:0Pl02P8?3oogl00:0Pl00U0?ooo`08oomo003oooooogl00?ooo`2P8?3oogl00?oooooo
O`030?ooo`;oogl0103oool00`2P8?00oooo0?ooo`070?ooo`030:0Pl?ooO`00oooo0080oooo00Go
ogl00?ooo`3oool0oooooomo00050?ooo`?oogl00`3oool01?ooO`00oooo0?ooo`2P8?02oomo0080
oooo00?oogl00?ooooooO`000P3oool30:0Pl0040?ooooooO`3oogl00?ooo`<0X23`0`3oool01Ooo
O`00oooo0?ooo`3oool0X23`00H0oooo00<0X23`0?ooo`3oool00P3oool01OooO`00oooo0?ooo`3o
ooooogl001/0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`04oj0Pl0040?mo0?nP
8?00ogl0oj0Pl0<0ogl000<0oooooj0Pl03oool0>@3oool00`3oO`00oooo0?ooo`0]0?ooo`03oomo
003oool0oooo01P0oooo00?oX23`0?oooonP8?007@3oool00`000000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`0M0?ooo`03oomo003oool0oooo01<0oooo00?oogl00?ooo`3oool01@3o
ool00`2P8?00oooo0?ooo`040?ooo`03oomo003oool0oooo00D0oooo00?oogl00?ooo`3oool01`3o
ool20:0Pl0080?ooooooO`00oooo0?ooooooO`00oooo0:0Pl?ooO`030?ooo`050:0Pl03oool0oooo
0?ooooooO`000P3oool02?ooO`00oooooomo003oooooogl00?ooooooO`00oooo0oooO`020?ooo`Co
ogl000<0X23`0?ooo`3oool00`3oool00`2P8?00oooooomo00040?ooo`05oomo003oool0oooo0?oo
o`2P8?00103oool00oooO`00oooooomo000P0?ooo`03o`00003oool0oooo00l0oooo00<00000oj0P
l03oool00onP8?000oooO`3oX23`oj0Pl0020?mo00050?ooo`3oO`3oX23`0?ooo`3oO`007@3oool0
0onP8?00oooo0?ooo`0n0?ooo`030?mo003oool0oooo04@0oooo00<000000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool04@3oool00oooO`00oooo0?ooo`0>0?ooo`03oomo003oool0oooo
00L0oooo00?oogl00?ooo`3oO`002`3oool20:0Pl0D0oooo00?oogl00?ooo`3oool02@3oool00ooo
O`00oooo0?ooo`020?ooo`;oogl000<0X23`0?ooo`3oool00`3oool00oooO`00X23`0?ooo`020?oo
o`@0X23`0P3oool20:0Pl0040?ooooooO`00X23`0?ooo`;oogl00P3oool2oomo00030?ooooooO`00
oooo00;oogl000T0oooo0:0Pl02P8?3oogl00:0Pl03oool0X23`0?ooo`2P8?000`3oool00oooO`00
oooo0?ooo`050?ooo`03oomo003oool0oooo00<0oooo00L0X23`oomo003oool0oooo0:0Pl03ooooo
ogl001/0oooo00?o00000?ooo`3oool03`3oool00`00003oX23`oj0Pl006oj0Pl0030?mo0?nP8?00
ogl000@0ogl00_nP8?020?ooo`03oj0Pl03oool0oooo02@0oooo00<0ogl00?ooo`3oool06`3oool0
1OnP8?00oooo0?ooo`3oooooX23`01/0oooo00Coogl00?ooo`3oool0ogl0>03oool00`000000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0A0?ooo`03oomo003oool0oooo00@0oooo00?o
ogl00?ooo`3oool09P3oool0102P8?00oooo0?ooooooO`060?ooo`030:0Pl03oool0oooo00@0oooo
00?oogl00?ooo`3oool01`3oool0302P8?00oooo0?ooo`3oooooogl00?ooooooO`00X23`0?ooo`2P
8?00oooooomo00@0oooo00?oogl00?ooo`3oool00`3oool2oomo00030?ooooooO`00oooo0080oooo
0`2P8?001OooO`00oooooomo003oooooogl00080oooo00?oogl00?ooooooO`002@3oool0102P8?00
oooo0?ooo`2P8?0O0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool3oj0P
l0?oogl000KoX23`0?mo003oO`3oX23`0?ooo`3oO`110?ooo`03oomo003oool0oooo05l0oooo00<0
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool02@3oool00oooO`00oooo0?ooo`0L
0?ooo`03oomo003oool0oooo00X0oooo00@0X23`0?ooo`3oool0X23`103oool01@2P8?3oogl00?oo
o`3oool0X23`0080oooo00?oogl00?ooo`3oool00`3oool01@2P8?00oooo0?ooo`3oool0ogl000<0
oooo00<0X23`0?ooo`3oool00P3oool01_ooO`00oooo0?ooo`2P8?00oooooomo00@0oooo00P0X23`
0?ooo`3oooooogl00?ooooooO`00oooo0:0Pl080oooo00?oogl00?ooooooO`000_ooO`050?ooo`80
X23`00Googl00:0Pl03oool0oooooomo00020:0Pl003oomo002P8?3oogl000?oogl000D0oooooomo
0?ooO`00oooooomo00040?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool07@3oool0
0ol00000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`OoX23`00Googl0oj0Pl03oO`00oooo
0?mo000;0?ooo`03oj0Pl03oool0oooo00`0oooo00?oX23`oomo003oool0C@3oool0103oO`00oooo
0?oooonP8?0g0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo04D0oooo
00Googl00:0Pl03oool0oooo0?mo00040?ooo`060:0Pl03oool0oooo0:0Pl03oool0X23`0P3oool0
0oooO`00oooo0?ooo`060?ooo`030?mo002P8?3oogl000@0oooo00D0X23`0?ooooooO`00oooooomo
00020?ooo`03oomo003oool0X23`00`0oooo00Koogl00?ooooooO`00X23`0?ooooooO`020?ooo`03
oomo003oooooogl002/0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`Go
X23`00D0ogl0oomo0?ooO`00ogl0oj0Pl0020?ooo`03oomo003oool0oooo02T0oooo00?oX23`0?oo
o`3oool0M@3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0E0?ooo`03
oomo003oool0oooo00D0oooo00<0ogl00?ooo`3oool04`3oool00`2P8?00oooo0?ooo`020?ooo`04
0:0Pl03oool0oooooomo00<0oooo00?oogl00?ooo`3oool02@3oool00oooO`00oooo0?ooo`060?oo
o`03oomo003oool0oooo0080oooo00<0X23`0?ooo`3oool0103oool01P2P8?00oooo0:0Pl02P8?00
oooo0:0Pl080oooo00<0X23`0?ooo`3oool02P3oool00`2P8?00oooo0?ooo`020?ooo`040:0Pl03o
ool0oooo0?ooo`;oogl01@3oool2oomo00<0oooo00H0X23`0?ooo`3oooooogl00?ooooooO`0R0?oo
o`03o`00003oool0oooo00l0oooo00@000000?ooo`3oool0oooo0_nP8?040?ooo`03oj0Pl03oO`00
ogl00080ogl000CoX23`0?ooo`3oO`3oX23`1@3oool0103oO`00oooo0?oooonP8?180?ooo`03oj0P
l03oool0oooo00@0oooo00?oX23`0?ooo`3oool04@3oool00onP8?00oooo0?ooo`0N0?ooo`03oomo
003oool0oooo0180oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool01@3o
ool00`2P8?00oooooomo000Q0?ooo`030:0Pl03oool0oooo00h0oooo00<0X23`0?ooo`3oool00P3o
ool01@2P8?00oooo0?ooo`3oooooogl000D0oooo00?oogl00?ooo`3oool00`3oool01?ooO`00oooo
0?ooooooO`020?ooo`040:0Pl03oool0X23`0:0Pl0<0oooo00<0X23`0?ooo`3oool00`3oool0102P
8?3oogl00?ooooooO`020?ooo`03oomo003oool0X23`00D0oooo00<0X23`0?ooo`2P8?00103oool0
0`2P8?00oooo0?ooo`040?ooo`80X23`0P3oool00`2P8?00oooo0?ooo`020?ooo`;oogl000<0oooo
oomo003oool00`3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo01/0oooo00?o0000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`;oX23`00D0oooooj0Pl?nP8?3oX23`0?mo
0002oj0Pl0;oogl000D0ogl00?ooo`3oool0ogl0oj0Pl0040?ooo`03oj0Pl03oool0oooo00@0oooo
00<0ogl00?ooo`3oool07@3oool00onP8?00oooo0?ooo`0Q0?ooo`03oj0Pl03oool0oooo04h0oooo
00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool02P3oool00oooO`00oooo0?oo
o`0V0?ooo`03oomo003oool0oooo0180oooo00<0X23`0?ooo`3oool00`3oool01OooO`00oooo0?oo
o`3oooooogl00080oooo00Koogl00?ooo`2P8?3oogl00?ooooooO`0=0?ooo`06oomo002P8?00oooo
oomo003oooooogl01P3oool00`2P8?00oooo0?ooo`020?ooo`040:0Pl03oool0X23`0:0Pl0L0oooo
00?oogl00?ooo`3oool01P3oool00oooO`00oooo0?ooo`0R0?ooo`03o`00003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool2oj0Pl0040?oooonP8?00oooo0?mo00;oX23`00Coogl0oj0Pl03o
ooooogl00`3oool30?mo0080oooo00?oX23`0?ooo`3oool0I@3oool00`3oO`00oooo0?ooo`0a0?oo
o`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0100oooo00?oogl00?ooo`3o
ool0903oool20:0Pl0/0oooo00D0X23`0?ooo`3oool0oooooomo00020?ooo`;oogl000L0oooooomo
003oool0oooo0?mo003oooooogl000H0oooo00@0X23`0?ooo`2P8?00oooo0P2P8?0:0?ooo`03oomo
003oool0oooo0080oooo00@0X23`0?ooo`3oooooogl02`3oool01?ooO`00oooo0?ooooooO`020?oo
o`030:0Pl?ooO`00X23`00@0oooo0_ooO`060?ooo`03oomo003oool0oooo01`0oooo00?o00000?oo
o`3oool03`3oool00`000000oooo0?ooo`030?ooo`04oomo003oooooX23`0?ooo`CoX23`00@0ogl0
oj0Pl03oooooogl00P3oool00`3oO`3oX23`0?ooo`2N0?ooo`030000003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0380oooo00?oogl00?ooooooO`004@3oool00oooO`00oooo0?ooo`02
0?ooo`030:0Pl03oool0oooo00L0oooo00Coogl00?ooo`3oool0X23`0_ooO`070?ooo`050:0Pl03o
ool0oooo0?ooooooO`00703oool01_ooO`00oooo0?ooooooO`00oooo0:0Pl1X0oooo00?oogl00?oo
o`3oool0303oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00?oX23`0?oo
o`3oool00P3oool2oj0Pl0050?mo0?nP8?3oogl0oomo003oO`000`3oool00oooO`00oooo0?ooo`1[
0?ooo`030?mo003oool0oooo0300oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool05@3oool0102P8?00oooo0?ooooooO`020?ooo`03oomo003oool0oooo00@0oooo00?oogl0
0?ooo`3oool01`3oool01OooO`00oooo0?ooo`3oooooogl001<0oooo00<0X23`0?ooooooO`001`3o
ool00`2P8?00oooo0?ooo`090?ooo`80X23`00?oogl00?ooo`3oool02@3oool00`2P8?00oooo0?oo
o`050?ooo`03oomo003oool0oooo00<0oooo00<0X23`0?ooo`3oool0303oool3oomo00030?ooo`2P
8?00oooo0080oooo00?oogl00?ooo`3oool02P3oool3oomo00040?ooooooO`00oooo0?ooo`;oogl0
3`3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0_nP8?001@3oooooX23`
0?ooooooO`00oooo00;oogl000@0ogl0oomo003oooooX23`0P3oool00oooO`00oooo0?ooo`030?oo
o`030?mo003oool0oooo01/0oooo00?oogl00?ooo`3oool0=@3oool00onP8?00oooo0?ooo`0m0?oo
o`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00`0oooo00Coogl00?ooo`3o
ooooogl0203oool00oooO`00oooo0?ooo`0P0?ooo`050:0Pl03oool0oooo0?ooooooO`00;@3oool0
0`2P8?00oooo0?ooo`020?ooo`040:0Pl03oool0oooooomo03`0oooo00?o00000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0:0?ooo`03oj0Pl03oool0oooo00<0oooo00@0ogl0oj0Pl03oO`00ogl0
1`3oool0103oO`00oooo0?oooonP8?2C0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo01L0oooo00<0X23`0?ooo`3oool06`3oool00`2P8?00oooo0?ooo`080?ooo`040:0P
l03oool0oooo0:0Pl0T0oooo00<0X23`0?ooo`3oool01`3oool00`2P8?00oooo0?ooo`020?ooo`03
0:0Pl?ooO`00oooo00h0oooo00<0X23`0?ooo`3oool0@P3oool00ol00000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00X0oooo0_nP8?000oooO`00oooo0?mo00020?ooo`05oj0Pl03oool0oooo0?oo
oonP8?000P3oool00onP8?00oooo0?ooo`0O0?ooo`03oj0Pl03oool0oooo03H0oooo00?oX23`0?oo
o`3oool03P3oool00oooO`00oooo0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo0080oooo00<0X23`0?ooo`3oool01`3oool00oooO`00oooo0?ooo`0O0?ooo`03
0:0Pl03oool0oooo00T0oooo00<0X23`0?ooo`3oool00`3oool00oooO`00oooo0?ooo`030?ooo`04
oomo003oool0oooo0:0Pl0d0oooo00<0X23`0?ooo`3oool01`3oool0102P8?00oooo0?ooo`2P8?08
0?ooo`03oomo003oool0X23`00X0oooo00?oogl00?ooooooO`000P3oool01?ooO`00oooo0?oooooo
O`060?ooo`05oomo002P8?00oooo0?ooooooO`00403oool01?ooO`00oooo0?ooooooO`0<0?ooo`05
oomo003oool0oooo0?ooool000004@3oool00`000000oooo0?ooo`060?ooo`;oX23`0P3oool3oj0P
l0;oogl000`0oooooj0Pl03oooooX23`oomo003oO`00oooo0?mo0?ooO`00ogl00?ooooooO`080?oo
o`05oj0Pl03oool0oooo0?oooonP8?00RP3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`0j0?ooo`030:0Pl03oool0oooo00L0oooo00<0X23`0?ooo`3oool01@3oool00ooo
O`00oooo0?ooo`0;0?ooo`03oomo003oool0oooo00H0oooo00<0X23`0?ooo`3oool00`3oool00ooo
O`00oooo0:0Pl0060?ooo`03oomo003oooooogl000X0oooo00?oogl00?ooo`3oool07P3oool00ooo
O`00oooo0?ooo`0?0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00onP
8?00oooo0?ooo`030?ooo`03oj0Pl?ooO`3oX23`00<0oooo00GoX23`oomo003oool0oooo0?mo002H
0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00P0oooo00?oogl00?oo
o`3oool02`3oool00oooO`00oooo0?ooo`060?ooo`04oomo003oool0oooooomo00l0oooo00<0X23`
oomo003oool00`3oool00oooO`00oooo0?ooo`020?ooo`030:0Pl03oool0oooo00d0oooo0P2P8?02
0?ooo`030:0Pl?ooO`00X23`00P0oooo00?oogl00?ooo`3oool02@3oool01?ooO`00oooo0?ooo`2P
8?0=0?ooo`030:0Pl03oool0oooo01<0oooo00?oogl00?ooo`3oool0203oool00oooO`00oooo0?oo
o`080?ooo`03oomo003oool0oooo00X0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`03oj0Pl03oool0oooo00L0oooo00?oogl0oj0Pl?nP8?000onP8?001`3oO`3oX23`oj0P
l03oooooogl00?ooooooO`000P3oool00`3oO`00oooo0?ooo`1T0?ooo`030?mo003oool0oooo02d0
oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0:@3oool00oooO`00oooo
0?ooo`0I0?ooo`030:0Pl03oool0oooo00<0oooo00?oogl00?ooo`3oool05@3oool0102P8?00oooo
0?ooooooO`0;0?ooo`03oomo003oool0oooo03d0oooo00?o00000?ooo`3oool03`3oool00`000000
oooo0?ooo`0D0?ooo`03oj0Pl03oool0oooo00H0oooo00<0ogl00?ooo`3oO`000P3oool00`3oO`00
oooo0?ooo`0E0?ooo`03oj0Pl03oool0oooo07D0oooo00<000000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0@@3oool00`2P8?00oooo0?ooo`090?ooo`030:0Pl03oool0oooo00D0oooo
00?oogl00?ooo`3oool0:`3oool00`2P8?00oooo0?ooo`0S0?ooo`03oomo003oool0oooo00H0oooo
00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`03oj0Pl03oool0oooo00<0oooo
00Googl00?ooo`3oool0oooooj0Pl0040?ooo`03oomo003oool0oooo09L0oooo00<000000?ooo`3o
ool0203oool000T0oooo00Co00000?ooo`3oool0X23`=`3oool00`3oO`00oooo0?ooo`0F0?ooo`03
oomo003oool0oooo00/0oooo00<0ogl00?ooo`3oool0103oool00`2P8?00oooooomo00070?ooo`03
0:0Pl03oooooogl000@0oooo00?oogl00?ooo`3oool0<03oool01?ooO`00oooo0?ooooooO`040?oo
o`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00onP8?00oooo0?ooo`030?oo
o`030?mo003oool0oooo0080oooo00Soogl00?ooo`3oool0oooo0?mo0?nP8?00oooooomo04H0oooo
00?oX23`0?ooo`3oool07`3oool00oooO`00oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo04@0oooo00<0X23`0?ooo`3oool04P3oool00oooO`00oooo0?oo
o`1@0?ooo`03oomo003oool0oooo00<0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?oo
o`040?ooo`03oj0Pl03oool0oooo00L0oooo00?oogl00?ooo`3oool03P3oool00oooO`00oooo0?oo
o`2@0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01h0oooo00<0X23`
0?ooo`3oool04P3oool00`2P8?00oooo0?ooo`090?ooo`030:0Pl03oool0oooo00L0oooo0P2P8?0:
0?ooo`03oomo003oool0oooo0080oooo00L0X23`0?ooo`3oool0oooo0:0Pl03oooooogl000/0oooo
0P2P8?0l0?ooo`04oomo003oool0oooooomo00@0oooo00?o00000?ooo`3oool03`3oool00`000000
oooo0?ooo`0A0?ooo`03oj0Pl03oooooX23`00;oX23`103oool01_ooO`00oooo0?oooonP8?00oooo
oomo00D0oooo00Coogl00?ooo`3oooooX23`2`3oool00onP8?00oooo0?ooo`060?ooo`03oj0Pl03o
ool0oooo0780oooo00<000000?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0=@3oool0
0`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo01H0oooo00<0X23`0?ooo`3oool0103oool0
0`2P8?00oooo0?ooo`020?ooo`03oomo003oool0ogl00100oooo00?oogl00?ooo`3oool0?@3oool0
0ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00?oX23`0?ooo`3oool02`3oool2
oj0Pl0<0oooo00<0ogl0oj0Pl03oool03@3oool00`3oO`00oooo0?ooo`0>0?ooo`03oj0Pl03oool0
oooo00/0oooo00?oogl00?ooo`3oool0IP3oool00`000000oooo0?ooo`080?ooo`002@3oool01?l0
0000oooo0?ooo`2P8?0L0?ooo`03oomo003oool0oooo01T0oooo00<0X23`0?ooo`3oool02@3oool0
0`2P8?00oooo0?ooo`030?ooo`<0X23`7@3oool00`2P8?00oooo0?ooo`080?ooo`03oomo003oool0
oooo03H0oooo00Coogl00?ooo`3ooooo00004@3oool00`000000oooo0?ooo`0A0?ooo`;oX23`00@0
ogl00?ooo`3oooooX23`1`3oool02?ooO`00oooo0?ooo`3oooooX23`oomo003oooooX23`1P3oool0
0onP8?00oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo0780oooo00<000000?ooo`3oool0203oool0
00T0oooo00Co00000:0Pl03oool0X23`4P3oool00`2P8?00oooo0?ooo`0[0?ooo`030:0Pl03oool0
X23`00H0oooo0`2P8?000`3oool0X23`0?ooo`070?ooo`080:0Pl03oool0oooo0:0Pl03oool0X23`
0?ooo`2P8?020?ooo`050:0Pl?ooO`00X23`0?ooo`2P8?003P3oool00oooO`00oooo0?ooo`0M0?oo
o`03oomo003oool0oooo0100oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`030?oo
o`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0103oool2oj0Pl0<0oooo00CoX23`0?oo
o`3oooooX23`103oool00onP8?00oooooj0Pl0020?ooo`?oX23`00@0oooooj0Pl03oool0oooo0_nP
8?001OooO`3oX23`0?ooooooO`00oooo00;oX23`;@3oool00oooO`00oooo0?ooo`1L0?ooo`030000
003oool0oooo00P0oooo00090?ooo`030:0Pl03oool0oooo01P0oooo00?oogl00?ooo`3oool07`3o
ool0102P8?00oooo0?ooo`2P8?0;0?ooo`030:0Pl03oooooogl000X0oooo00<0X23`0?ooo`2P8?00
503oool01?ooO`00oooo0?ooooooO`0k0?ooo`03oomo003oool0oooo00<0oooo00?o00000?ooo`3o
ool03`3oool00`000000oooo0?ooo`080?ooo`03oj0Pl03oooooX23`00P0oooo00?oogl0oj0Pl?nP
8?002@3oool20?mo00040?ooo`3oO`00oooooomo00/0oooo00<0ogl00?ooo`3oool00P3oool00onP
8?00oooo0?ooo`1@0?ooo`03oj0Pl03oool0oooo02L0oooo00<000000?ooo`3oool0203oool000T0
oooo00<0X23`0?ooo`3oool09`3oool00oooO`00oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo00@0
oooo00<0X23`0?ooo`3oool01`3oool0102P8?00oooo0:0Pl02P8?0=0?ooo`03oomo003oool0oooo
00<0oooo00<0X23`0?ooo`3oool00`3oool00oooO`00oooo0?ooo`090?ooo`030:0Pl03oool0oooo
03T0oooo0_ooO`020?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00onP
8?00oooo0?ooo`090?ooo`03oj0Pl03oooooX23`00l0oooo00Koogl0oj0Pl03oool0ogl0oj0Pl03o
O`040?ooo`03oj0Pl03oool0oooo00/0oooo00CoX23`0?ooo`3oool0oooo0_nP8?090?ooo`030?mo
003oool0oooo01/0oooo00?oX23`0?ooo`3oool0A`3oool00`000000oooo0?ooo`080?ooo`002@3o
ool01@2P8?00oooo0?ooo`3oool0X23`01h0oooo00<0X23`0?ooo`3oool0?P3oool01?ooO`00oooo
0?ooooooO`030?ooo`050:0Pl03oool0oooo0?ooooooO`00<03oool00oooO`00oooo0?ooo`0@0?oo
o`03oomo003ooooo00000140oooo00<000000?ooo`3oool01@3oool00onP8?00oooo0?ooo`090?oo
o`03oj0Pl03oooooX23`00@0oooo00<0ogl00?ooo`3oool02P3oool01@3oO`00oooooomo003ooooo
ogl000D0oooo00?oX23`0?ooo`3oool06@3oool00`3oO`00oooo0?ooo`1T0?ooo`030000003oool0
oooo00P0oooo00090?ooo`04o`00002P8?00oooo0:0Pl1H0oooo00<0X23`0?ooo`3oool00`3oool0
0oooO`00oooo0?ooo`0E0?ooo`030:0Pl03oool0oooo00@0oooo00<0X23`0?ooo`2P8?003`3oool0
0`2P8?00oooo0?ooo`0>0?ooo`03oomo003oooooogl000@0oooo00?oogl00?ooo`3oool02@3oool0
0`2P8?00oooo0:0Pl00k0?ooo`03oomo003ooooo00000140oooo00<000000?ooo`3oool02@3oool0
1?nP8?00oooooj0Pl?nP8?030?ooo`03oj0Pl03oool0oooo00@0oooo00Soogl00?ooo`3oooooX23`
0?mo003oooooogl0oj0Pl080oooo00CoX23`0?ooo`3oool0ogl0103oool01?ooO`00oooo0?ooo`3o
O`020?ooo`03oj0Pl03oool0oooo05P0oooo00?oX23`0?ooo`3oool09@3oool00`000000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`0A0?ooo`030:0Pl03oool0oooo02X0oooo00<0X23`
0?ooo`3oool01@3oool00`3oO`00oooo0?ooo`0C0?ooo`040:0Pl03oool0oooooomo00L0oooo00D0
X23`0?ooo`3oool0oooo0:0Pl00@0?ooo`03oomo003oool0oooo02T0oooo00?oogl00?ooo`3oool0
1`3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00GoX23`0?ooo`3oool0
oooooj0Pl0020?ooo`03oj0Pl?ooO`00oooo00@0oooo00?oX23`0?ooo`3oool0103oool00`3oO`00
oooo0?ooo`060?ooo`03oj0Pl03oool0oooo05T0oooo00?oogl00?ooo`3oool07P3oool00`000000
oooo0?ooo`080?ooo`002@3oool00ol00000X23`0?ooo`0A0?ooo`030:0Pl03oool0oooo00`0oooo
00<0ogl00?ooo`3oool0503oool30:0Pl100oooo00<0ogl00?ooo`3oool0203oool00`2P8?00oooo
0?ooo`020?ooo`03oomo003oool0oooo00P0oooo00?oogl00?ooo`3oool0303oool00oooO`00oooo
0?ooo`0h0?ooo`?oogl000?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`03oj0P
l03oool0oooo00X0oooo00?oogl00?oooonP8?00103oool00`3oO`00oooo0?ooo`020?ooo`050?mo
0?nP8?3oX23`oj0Pl03oool00_ooO`060?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3o
ool08`3oool00onP8?00oooo0?ooo`1C0?ooo`030000003oool0oooo00P0oooo00090?ooo`030:0P
l03oool0oooo0180oooo00<0ogl00?ooo`3oool03`3oool00oooO`00oooo0?ooo`0;0?ooo`040?mo
003oool0oooo0:0Pl0P0oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?ooo`070?ooo`03
0:0Pl03oool0oooo00H0oooo00@0X23`0?ooo`2P8?3oogl00P3oool20:0Pl0L0oooo00?oogl00?oo
o`3oool0:P3oool00oooO`00oooo0?ooo`0L0?ooo`03o`00003oool0oooo00l0oooo00<000000?oo
o`3oool00`3oool00onP8?00oooo0?ooo`0<0?ooo`03oj0Pl03oool0oooo0080oooo00?oogl0oj0P
l?nP8?000P3oool01?ooO`00oooo0?oooonP8?030?ooo`060?mo003oool0oooo0?ooo`3oO`3oogl0
103oool01?nP8?00ogl00?ooooooO`0D0?ooo`03oj0Pl03oool0oooo06X0oooo00<000000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0>@3oool00`2P8?00oooo0?ooo`0F0?ooo`030:0P
l03oool0oooo00L0oooo00<0X23`0?ooo`3oool01`3oool2oomo01P0oooo00<0X23`0?ooo`3oool0
;P3oool00oooO`3o00000?ooo`0@0?ooo`030000003oool0oooo01d0oooo00?oX23`0?ooo`3oool0
0P3oool00onP8?00oooo0?mo000;0?ooo`03oomo003oool0oooo01P0oooo00<0ogl00?ooo`3oool0
I03oool00`000000oooo0?ooo`080?ooo`002@3oool20:0Pl0030?ooo`2P8?00oooo02/0oooo00<0
X23`0?ooo`3oool02`3oool00`2P8?00oooo0?ooo`050?ooo`030:0Pl03oool0oooo00<0oooo00<0
X23`0?ooo`3oool0:P3oool00oooO`00oooo0?ooo`030?ooo`040:0Pl03oooooogl00:0Pl2d0oooo
00?oogl00?ooooooO`000_ooO`000ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo
00SoX23`0?ooo`3oooooX23`0?oooonP8?00oooooj0Pl1@0oooo00GoX23`0?oooonP8?00oooooj0P
l002oomo00030?ooooooO`3oX23`00d0oooo00CoX23`0?ooo`3oooooX23`0`3oool00onP8?00oooo
0?ooo`1^0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00H0oooo00<0
X23`0?ooo`3oool0A`3oool00`2P8?00oooo0?ooo`040?ooo`040:0Pl03oool0oooo0?mo00d0oooo
00<0X23`0?ooo`3oool0AP3oool00oooO`3o00000?ooo`0@0?ooo`030000003oool0oooo01@0oooo
00CoX23`0?ooo`3oooooX23`0`3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00H0
oooo00?oX23`0?ooooooO`006P3oool00oooO`00oooooomo001T0?ooo`030000003oool0oooo00P0
oooo00090?ooo`03o`00003oool0oooo01l0oooo00<0X23`0?ooo`3oool04@3oool00`2P8?00oooo
0?ooo`0;0?ooo`030:0Pl03oool0oooo00h0oooo00Coogl00?ooo`3oool0X23`4@3oool00oooO`00
oooo0?ooo`050?ooo`03oomo003oool0oooo00`0oooo00<0X23`0?ooo`3oool0<@3oool00ol00000
oooo0?ooo`0?0?ooo`030000003oool0oooo0200oooo00<0ogl00?ooo`3oool00P3oool01OnP8?00
ogl00?ooo`3oool0ogl00080oooo00?oX23`0?oooonP8?002`3oool00onP8?00oooo0?ooo`020?oo
o`03oj0Pl03oool0oooo0700oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool00P3oool00`2P8?00oooo0?ooo`0L0?ooo`030?mo002P8?00oooo00H0oooo00<0ogl00?ooo`3o
ool02`3oool00`2P8?00oooo0:0Pl0060?ooo`030:0Pl03oool0X23`00<0oooo00H0X23`0?ooo`3o
O`00oooo0:0Pl?ooO`080?ooo`03oomo003oool0oooo00T0oooo00<0X23`0?ooo`3oool0C@3oool0
0oooO`3o00000?ooo`0@0?ooo`030000003oool0oooo0180oooo00?oX23`0?ooo`3oool02P3oool0
1?nP8?00oooo0?oooonP8?030?ooo`03oj0Pl03oO`00oooo00L0oooo00Googl00?mo003oool0oooo
oj0Pl002oomo00<0oooo00D0ogl00?oooonP8?3oX23`0?ooo`02oj0Pl080oooo00?oogl00?ooo`3o
ool0K03oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0O0?ooo`040?mo
003oool0oooooomo0140oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`020?ooo`03
0:0Pl03oool0oooo00L0oooo00<0X23`0?ooo`2P8?001@3oool00`3oO`00oooo0?ooo`0=0?ooo`03
0:0Pl03oool0oooo04d0oooo00?oogl0o`00003oool0403oool00`000000oooo0?ooo`0R0?ooo`05
oj0Pl03oool0oooo0?oooonP8?000P3oool2oj0Pl0D0oooo00CoX23`oomo003oooooogl02P3oool0
1?nP8?00oooo0?ooo`3oool2oj0Pl080oooo00?oogl00?ooo`3oool0J@3oool00`000000oooo0?oo
o`080?ooo`002@3oool00ol00000X23`0?ooo`060?ooo`030:0Pl03oool0oooo00P0oooo00<0X23`
0?ooo`3oool0103oool00`2P8?00oooo0?ooo`050?ooo`030?mo003oool0oooo01D0oooo00<0X23`
0?ooo`2P8?000P3oool01@2P8?00oooo0?ooo`3oool0X23`00@0oooo102P8?030?ooo`050:0Pl03o
ool0X23`0?ooo`2P8?004`3oool00`2P8?3oogl00?ooo`060?ooo`030:0Pl03oool0oooo0080oooo
00<0X23`0?ooo`3oool0:03oool00oooO`00oooo0?ooo`090?ooo`03oomo003oool0oooo00@0oooo
00?oogl0o`00003oool0403oool00`000000oooo0?ooo`050?ooo`03oj0Pl03oooooX23`00L0oooo
00?oX23`0?ooo`3oool0103oool00onP8?00oooo0?ooo`060?ooo`06oj0Pl03oool0oooo0?oooonP
8?3oogl00`3oool3oj0Pl0070?oooonP8?3oX23`oj0Pl03oooooX23`oomo00030?ooo`04oj0Pl03o
ool0oooooomo00@0oooo00?oX23`0?oooonP8?000_nP8?00103oooooX23`0?oooonP8?02oomo00P0
oooo00<0ogl00?ooo`3oool0G`3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`0X0?ooo`030:0Pl03oool0oooo00l0oooo00?oogl00?ooo`3oool02@3oool00`2P8?00oooo
0?ooo`0C0?ooo`030:0Pl03oool0oooo02P0oooo00<0X23`0?ooo`3oool0:03oool00ol00000oooo
0?ooo`0?0?ooo`030000003oool0oooo0180oooo00?oX23`0?ooo`3oool05`3oool01OnP8?00oooo
0?ooo`3oool0ogl000P0oooo00?oX23`0?ooo`3oool03@3oool00onP8?00oooo0?ooo`1V0?ooo`03
0000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03L0oooo00<0X23`0?ooo`3oool0
4`3oool00`2P8?00oooo0?ooo`080?ooo`03oomo003oool0oooo00T0oooo00?oogl00?ooo`3oool0
4P3oool00oooO`00oooo0?ooo`0f0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0
9@3oool00`3oO`00oooo0?ooo`050?ooo`03oj0Pl03oool0oooo01H0oooo00?oX23`0?ooo`3oool0
:P3oool00`3oO`00oooo0?ooo`0l0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo0140oooo00<0X23`0?ooo`3oool02@3oool0102P8?00oooo0?ooo`2P8?0;0?ooo`05oomo
003oool0oooo0?ooo`2P8?000P3oool0102P8?00ogl00?ooo`2P8?020?ooo`060:0Pl03oool0oooo
0:0Pl03oool0X23`0P3oO`000`2P8?00oooo0?ooo`020?ooo`80X23`00D0oooo0:0Pl03oool0oooo
0:0Pl0040?ooo`040?mo002P8?00oooooomo00`0oooo00?oogl00?ooo`3oool02@3oool00`2P8?00
oooo0?ooo`090?ooo`03oomo003oool0oooo00T0oooo00?oogl00?ooo`3oool0:03oool00oooO`00
ooooo`00000A0?ooo`030000003oool0oooo01h0oooo00?oX23`0?ooo`3oool01@3oool0103oO`00
oooooj0Pl?nP8?020?ooo`08oj0Pl?ooO`3oX23`0?oooonP8?00oooooomo0?nP8?060?ooo`03oj0P
l03oooooogl000;oX23`00Woogl00?oooonP8?3oX23`0?oooonP8?00oooo0?mo0?nP8?00JP3oool0
0`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0A0?ooo`030:0Pl03oool0oooo
02@0oooo00<0X23`0?ooo`3oool0203oool00`2P8?00oooo0?ooo`090?ooo`040:0Pl03oool0oooo
0:0Pl1D0oooo00?oogl00?ooo`3oool0A`3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0
oooo02@0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooooj0Pl0030?ooo`05oj0Pl03oool0
oooo0?oooonP8?00403oool00`3oO`00oooooj0Pl01[0?ooo`030000003oool0oooo00P0oooo0009
0?ooo`80X23`8`3oool00`2P8?00oooo0?ooo`020?ooo`050?mo003oool0oooo0?ooo`2P8?00303o
ool0102P8?3oogl00:0Pl02P8?030?ooo`<0X23`103oool00`2P8?00oooo0?ooo`030:0Pl080oooo
00@0X23`0?ooo`2P8?00X23`203oool00`2P8?00oooo0?ooo`070?ooo`04oomo003oool0oooo0:0P
l0l0oooo00?oogl00?ooo`3oool0=@3oool01?ooO`00oooo0?ooool0000A0?ooo`030000003oool0
oooo00T0oooo00GoX23`0?ooo`3oool0oooooj0Pl00E0?ooo`03oj0Pl03oool0oooo00<0oooo00Ko
X23`0?ooo`3oooooX23`0?oooonP8?030?ooo`03oomo003oool0oooo0080oooo0_nP8?000`3ooooo
ogl00?ooo`030?ooo`07oj0Pl?ooO`3oX23`oj0Pl03oooooX23`0?ooo`03oj0Pl1d0oooo00?oX23`
0?ooo`3oool0B@3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0Y0?oo
o`03oomo003oool0oooo00<0oooo00<0X23`0?ooo`3oool02`3oool00`2P8?00oooo0?mo00040?oo
o`050:0Pl03oool0oooo0?ooo`2P8?00503oool00`2P8?00oooo0?ooo`1B0?ooo`03o`00003oool0
oooo00l0oooo00<000000?ooo`3oool0;@3oool2oj0Pl0050?oooonP8?00oooo0?ooooooO`00403o
ool00onP8?00oooooj0Pl01[0?ooo`030000003oool0oooo00P0oooo00090?ooo`04o`00003oool0
oooo0:0Pl0L0oooo00<0X23`0?ooo`3oool06P3oool01`2P8?00oooo0?ooo`3oool0X23`0?ooo`2P
8?004@3oool00`2P8?00oooo0?ooo`030?ooo`040?mo003oool0oooo0:0Pl0<0oooo0P2P8?040?oo
o`030:0Pl03oooooogl000D0oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?mo000>0?oo
o`03oomo003oool0oooo0080oooo00<0X23`0?ooo`3oool03P3oool00`2P8?00oooo0?ooo`0T0?oo
o`03oomo003oool0oooo0080oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`05oj0Pl03oool0oooo0?oooonP8?002P3oool00onP8?00oooo0?ooo`070?ooo`03oomo003oool0
oooo0080oooo00CoX23`0?ooo`3oooooX23`0P3oool01?nP8?00oooo0?oooonP8?030?ooo`03oj0P
l03oooooX23`00D0oooo00?oX23`0?ooo`3oool00P3oool01OooO`3oX23`0?ooo`3oooooogl000@0
oooo00KoX23`0?ooo`3oooooogl00?ooo`3oO`1L0?ooo`030000003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo01`0oooo00<0X23`0?ooo`3oool01@3oool0102P8?00oooo0?ooo`2P8?05
0?ooo`070:0Pl03oool0oooo0:0Pl03oool0X23`0?mo00060?ooo`040:0Pl03oool0oooo0:0Pl0D0
oooo00<0X23`0?ooo`3oool00P3oool0102P8?00oooo0?ooo`3oO`020?ooo`030?mo002P8?00oooo
00T0oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?ooo`0?0?ooo`050:0Pl03oool0oooo
0?ooo`2P8?00>P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00?oX23`
0?ooo`3oool09`3oool01?nP8?00oooo0?ooo`3oool2oj0Pl0040?oooonP8?00oooo0?ooo`?oX23`
00@0oooooj0Pl03oooooX23`0P3oool01?ooO`00oooo0?oooonP8?020?ooo`03oj0Pl?ooO`3oogl0
06P0oooo00<000000?ooo`3oool0203oool000T0oooo00Go00000?ooo`3oool0oooo0:0Pl00P0?oo
o`030:0Pl03oool0oooo00`0oooo00Coogl00?ooo`3oool0X23`1@3oool00`2P8?00oooo0?ooo`02
0?ooo`040:0Pl03oool0oooo0:0Pl0<0oooo00<0ogl00?ooo`3oool00`3oool0102P8?00oooo0?oo
o`3oO`030?ooo`03oomo003oool0oooo00@0oooo00<0ogl00?ooo`3oool00`3oool00oooO`00oooo
0?ooo`0O0?ooo`030:0Pl03oool0oooo02d0oooo00?o00000?ooo`3oool03`3oool00`000000oooo
0?ooo`0<0?ooo`03oj0Pl03oool0oooo01l0oooo0_nP8?000`3oO`3oX23`0?ooo`02oj0Pl003oomo
003oool0oooo00L0oooo00?oX23`0?ooo`3oool00P3oool01?nP8?00oooooj0Pl03oool2oomo00P0
oooo00?oogl00?ooo`3oool0G@3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`050?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool05@3oool00`2P8?00oooo
0?ooo`030?ooo`030:0Pl?ooO`00oooo0080oooo00<0X23`0?ooo`3oool01@3oool00`2P8?00oooo
0?ooo`020?ooo`80X23`00@0oooo0:0Pl03oool0oooo0P2P8?040?ooo`030:0Pl03oool0oooo0080
oooo00@0X23`0?ooo`3oool0X23`0`3oool00`2P8?00oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo
00H0oooo00?oogl00?ooo`3oool00P3oool01OooO`00oooo0?ooo`3oooooogl000/0oooo00?oogl0
0?ooo`3oool0;@3oool00oooO`3o00000?ooo`0@0?ooo`030000003oool0oooo00P0oooo00?oX23`
0?ooo`3oool03`3oool00onP8?00oooo0?ooo`050?ooo`?oX23`2@3oool3oj0Pl080oooo00?oX23`
0?ooooooO`001@3oool3oj0Pl0D0oooo1?nP8?00103oooooX23`0?ooo`3oO`090?ooo`030?mo003o
ool0oooo05/0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool07`3oool0
0`2P8?00oooo0?ooo`070?ooo`030:0Pl03oool0oooo00L0oooo00<0X23`0?ooo`3oool00P3oool0
103oO`00oooo0:0Pl03oool30:0Pl0030?ooo`2P8?00X23`00<0oooo00?oogl00:0Pl03oool0203o
ool00`2P8?00oooo0?ooo`0?0?ooo`030:0Pl03oool0oooo00D0oooo00<0X23`0?ooo`3oool00`3o
ool00oooO`00oooo0?ooo`0o0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0;@3o
ool01?nP8?00oooooj0Pl?nP8?020?ooo`03oj0Pl03oO`00oooo00@0oooo00?oX23`0?ooo`3oool0
0`3oool2oj0Pl0030?oooonP8?3oogl000T0oooo00?oX23`0?ooo`3oool01@3oool00`3oO`3oX23`
0?ooo`1I0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0X23`00<0oooo00<0
X23`0?ooo`3oool08`3oool01@3oO`00oooo0?ooo`3oool0X23`00`0oooo00D0X23`0?ooo`3oool0
X23`0?ooo`020?mo0080oooo00@0X23`0?ooo`2P8?00X23`1@3oool01@2P8?00oooo0?ooo`3oool0
ogl000H0oooo0P2P8?0=0?ooo`030:0Pl03oool0oooo00@0oooo00?oogl00?ooo`3oool01@3oool0
0oooO`00oooo0?ooo`0i0?ooo`03oomo0?l00000oooo0100oooo00<000000?ooo`3oool0303oool0
1OnP8?00oooo0?ooo`3oooooX23`01X0oooo00?oX23`0?ooo`3oool0103oool3oj0Pl0030?oooooo
O`00oooo0080oooo00@0ogl00?ooo`3oO`3oogl00P3oool2oj0Pl003oomo003oool0oooo00;oogl0
00<0oooooj0Pl?nP8?000`3oool00onP8?00oooo0?ooo`070?ooo`030?mo003oool0oooo05P0oooo
00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06`3oool00`2P8?00oooo0?oo
o`0A0?ooo`80X23`103oool00`2P8?00oooo0?ooo`030?ooo`070:0Pl03oool0oooo0?ooo`2P8?00
oooo0:0Pl0020?ooo`030:0Pl03oool0oooo0080oooo00<0ogl00?ooo`2P8?001`3oool00`2P8?00
oooo0:0Pl00>0?ooo`030:0Pl03oool0X23`04/0oooo00?o00000?ooo`3oool03`3oool00`000000
oooo0?ooo`0Y0?ooo`03oj0Pl03oool0oooo00L0oooo00CoX23`0?ooo`3oooooX23`0`3oool2oj0P
l0D0oooo00?oX23`0?ooo`3oool00_nP8?020?ooo`05oj0Pl03oooooogl00?oooonP8?00I@3oool0
0`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0]0?ooo`030:0Pl03oool0oooo
00P0oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?mo000:0?ooo`08oomo003oO`00oooo
0?mo003oool0X23`0?ooo`3oO`070?ooo`03oomo003oool0oooo00H0oooo00@0X23`0?ooo`3oool0
X23`B`3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00?oX23`0?ooo`3o
ool0603oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oooooogl000L0oooo00<0ogl00?ooo`3o
ool00`3oool00oooO`00oooo0?ooo`030?ooo`04oomo0?nP8?00oooooomo06<0oooo00<000000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0203oool00`2P8?00oooo0?ooo`0<0?ooo`03
0:0Pl03oool0oooo00@0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`030?ooo`80
X23`2P3oool01OooO`00oooo0?ooo`2P8?3oogl000H0oooo00H0ogl00?ooo`3oool0oooo0?mo002P
8?040?ooo`030:0Pl03oool0oooo00@0oooo00<0X23`0?mo002P8?000P3oO`060?ooo`050:0Pl03o
ool0oooo0?ooo`2P8?00503oool00`2P8?00oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo02d0oooo
00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`04oj0Pl03oool0oooooj0Pl0h0
oooo0_nP8?000`3oooooX23`0?ooo`020?ooo`04oj0Pl03oool0oooooj0Pl080oooo0_nP8?001Ooo
O`00oooo0?oooonP8?00oooo00?oX23`103oool01?ooO`00oooo0?ooooooO`040?ooo`03oomo003o
ooooX23`0640oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool09`3oool0
0`2P8?00oooo0?ooo`060?ooo`030:0Pl03oool0oooo00T0oooo00<0X23`0?ooo`3oool02P3oool0
102P8?00oooo0?ooo`3oO`040?ooo`80ogl000<0oooo0?mo003oO`000`3oool01@2P8?00oooo0?oo
o`3oool0ogl005@0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`03oj0P
l03oool0oooo0280oooo00?oX23`0?oooonP8?00103oool00onP8?00oooo0?mo00040?ooo`03oj0P
l03oool0oooo00@0oooo0_ooO`00103oooooogl00?ooooooO`020?ooo`03oomo003oool0oooo05X0
oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool01@3oool00`2P8?00oooo
0?ooo`0A0?ooo`030:0Pl03oool0oooo00l0oooo00@0X23`0?ooo`3oool0oooo0P2P8?060?ooo`;o
ogl00P3oool00`2P8?00oooo0?ooo`030?ooo`060:0Pl03oool0X23`0:0Pl03oool0ogl0203oool0
0oooO`00oooo0?ooo`040?mo00H0oooo00<0X23`0?ooo`3oool0103oool00`3oO`00oooo0?ooo`04
0?ooo`030:0Pl03oool0oooo04D0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0L
0?ooo`03oj0Pl03oooooX23`00l0oooo00?oX23`0?ooo`3oool0103oool2oj0Pl0030?oooonP8?00
ogl00080oooo00OoX23`0?ooo`3oO`3oX23`0?oooonP8?00oooo00;oX23`0`3oool02?ooO`00oooo
0?ooo`3oooooogl00?ooooooO`00oooo0_ooO`050?ooo`03oomo003oool0oooo05P0oooo00<00000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0;P3oool30:0Pl0<0oooo00?oogl00?oo
o`3oool00`3oool00`3oO`00oooo0?ooo`020?ooo`030:0Pl03oool0ogl00080oooo00?oogl00?oo
o`3oool00P3oool00`2P8?00oooo0?ooo`060?ooo`040:0Pl03oool0X23`0?mo01@0oooo00?oogl0
0?ooo`3oool0A@3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo02T0oooo00?oX23`
0?oooonP8?002@3oool00onP8?00oooo0?ooo`040?ooo`03oomo003oool0oooo0080ogl000CoX23`
0?oooonP8?3oX23`0P3oool01?nP8?00oooo0?oooonP8?050?ooo`03oj0Pl?ooO`00oooo05l0oooo
00<000000?ooo`3oool0203oool000T0oooo00Go00000?ooo`3oool0oooo0:0Pl00:0?ooo`030:0P
l03oool0oooo01d0oooo0P2P8?020?ooo`030:0Pl03oool0X23`00T0oooo00<0X23`0?ooo`3oool0
0P3oool00`2P8?00oooo0?ooo`0;0?ooo`030:0Pl03oool0oooo0080ogl000@0oooo0?mo003oool0
ogl08@3oool00oooO`00oooo0?ooo`0f0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3o
ool0503oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo01/0oooo00?oX23`0?ooo`3o
ool00P3oool01OnP8?00oooo0?ooo`3oooooX23`0080oooo0_nP8?020?ooo`03oj0Pl03oool0oooo
0080oooo0_ooO`000`3oooooogl0oomo00090?ooo`030?mo003oool0oooo05<0oooo00<000000?oo
o`3oool0203oool000T0oooo00?o00000:0Pl03oool0303oool00`2P8?00oooo0?ooo`0H0?ooo`06
0:0Pl03oool0X23`0:0Pl03oool0X23`0P3oool00`2P8?00oooo0?ooo`030?ooo`030?mo003oool0
oooo00T0oooo00D0X23`0?ooo`3oool0ogl00:0Pl0050?ooo`040:0Pl03oool0X23`0?ooo`<0ogl0
00H0X23`0?ooo`2P8?00ogl00?ooo`3oO`020?ooo`03oomo003oool0oooo00/0oooo00?oogl00?oo
o`3oool02`3oool00`2P8?00oooo0?ooo`0:0?ooo`03oomo003oool0oooo02`0oooo00?o00000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo01@0oooo00?oX23`0?oo
o`3oool0303oool00oooO`3oX23`0?ooo`030?ooo`07oj0Pl03oooooX23`oj0Pl03oool0ogl00?oo
o`04oj0Pl0030?ooooooO`00oooo0080oooo0_ooO`001OnP8?00oooooj0Pl?ooO`3oX23`00;oogl0
0P3oool00oooO`00oooo0?ooo`1J0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo00D0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`0D0?ooo`030:0Pl03o
ool0oooo00/0oooo00<0X23`0?ooo`3oool0103oool00oooO`00oooo0:0Pl00;0?ooo`050:0Pl03o
ool0oooo0?ooo`2P8?000P3oool0202P8?00oooo0?ooo`2P8?00ogl00?ooo`3oO`00X23`303oool0
1@2P8?00oooo0?ooo`3oool0X23`01H0oooo00@0X23`0?ooo`3oool0X23`=03oool00ol00000oooo
0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00?oX23`0?ooo`3oool01`3oool00onP8?00oooo
0?ooo`0?0?ooo`03oj0Pl03oooooX23`00<0oooo0_nP8?040?ooo`030?mo003oooooX23`0080oooo
00?oX23`0?oooonP8?000P3oool00onP8?00oooo0?ooo`020?ooo`06oomo0?nP8?00oooooomo003o
ooooX23`3`3oool2oj0Pl4d0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0603oool00`2P8?00oooo0?ooo`060?ooo`030:0Pl03oool0X23`00/0oooo0P2P8?090?ooo`04
oomo003oool0oooo0:0Pl080oooo00@0X23`0?ooo`3oool0ogl00P3oool00`2P8?00oooo0:0Pl002
0?ooo`040?mo003oool0oooo0?mo00@0oooo00<0ogl00:0Pl03oool00P3oool30?mo00030?ooo`2P
8?00oooo00D0oooo00@0X23`0?ooo`3oool0ogl02`3oool00`2P8?00oooo0?ooo`0m0?ooo`03o`00
003oool0oooo00l0oooo00<000000?ooo`3oool0903oool01?nP8?00oooo0?oooonP8?070?ooo`03
oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`030?ooo`03
oj0Pl03oO`3oX23`00CoX23`00?oogl00?oooonP8?000P3oool00onP8?3oogl0oj0Pl004oomo00@0
oooo00Coogl00?ooo`3oooooogl0E@3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`020?ooo`030:0Pl03oool0oooo00T0oooo00<0X23`0?ooo`3oool06@3oool00`2P8?00
oooo0?ooo`040?ooo`80X23`1@3oool00`2P8?00oooo0?ooo`020?ooo`080:0Pl03oool0oooo0:0P
l03oool0X23`0?ooo`2P8?020?ooo`80X23`00D0oooo0:0Pl03oool0ogl00:0Pl0020?ooo`030?mo
003oool0X23`00<0X23`00<0ogl0oomo003oool00P3oool00`3oO`00oooo0:0Pl00I0?ooo`030:0P
l03oool0oooo03P0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`03oj0P
l03oooooX23`00@0oooo00?oX23`0?ooo`3oool06@3oool01OnP8?00oooooj0Pl03oooooX23`0080
oooo1OnP8?000`3oooooX23`oj0Pl002oj0Pl0030?oooonP8?3oX23`00<0oooo00?oX23`oomo0?oo
O`00103oool00oooO`00oooo0?ooo`090?ooo`03oj0Pl03oool0oooo04`0oooo00<000000?ooo`3o
ool0203oool000T0oooo00Go00000?ooo`3oool0oooo0:0Pl0060?ooo`030:0Pl03oool0oooo01P0
oooo00<0X23`0?ooo`3oool02P3oool40:0Pl0030?ooo`2P8?00oooo00H0oooo00<0ogl00?ooo`3o
ool03@3oool0102P8?00ogl00?ooo`2P8?040?ooo`030?mo003oool0oooo02D0oooo00<0X23`0?oo
o`3oool0<P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00GoX23`0?oo
o`3oool0oooooj0Pl00?0?ooo`03oj0Pl03oool0oooo00l0oooo00?oX23`0?ooo`3oool02@3oool2
oj0Pl080oooo00CoX23`oomo003oooooX23`0P3oool2oomo0600oooo00<000000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool00P3oool20:0Pl0/0oooo00<0X23`0?ooo`3oool04P3oool0
0`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0X23`00@0oooo0P2P8?000`3oool0X23`0?ooo`02
0?ooo`80X23`1@3oool20:0Pl0H0oooo00L0X23`0?ooo`3oool0oooooomo002P8?00ogl000<0X23`
103oool00`2P8?00oooo0?ooo`030?ooo`80X23`00D0oooo0?mo003oool0oooo0:0Pl00F0?ooo`03
0:0Pl03oool0oooo0080oooo00?oogl00?ooo`3oool03`3oool00oooO`00oooo0?ooo`0Q0?ooo`03
o`00003oool0oooo00l0oooo00<000000?ooo`3oool06`3oool01OnP8?00oooo0?ooo`3oooooX23`
00L0oooo00?oX23`0?ooo`3oool04P3oool2oj0Pl0080?mo003oool0oooooj0Pl03oO`3oX23`oomo
003oO`04oj0Pl0080?oooonP8?3oX23`0?oooonP8?00oooooj0Pl?ooO`030?ooo`03oj0Pl03ooooo
ogl000T0oooo00?oX23`0?ooo`3oool0CP3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`070?ooo`030:0Pl03oool0oooo0140oooo00<0X23`0?ooo`3oool0103oool00`2P
8?00oooo0?ooo`0H0?ooo`030?mo003oool0oooo00D0oooo0P2P8?020?ooo`030:0Pl03oool0X23`
00T0oooo00<0X23`0?ooo`3oool00P3oool20:0Pl0L0oooo00Coogl00?ooo`3oool0X23`5`3oool0
0`2P8?00oooo0?ooo`0a0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0onP8?00oooo0?ooo`0Q0?ooo`CoX23`2@3oool01?nP8?00oooooj0Pl?nP8?030?ooo`06oj0Pl03o
ool0oooo0?mo003oooooogl00P3oool2oj0Pl080oooo00?oogl00?ooo`3oool04`3oool00onP8?00
oooo0?ooo`170?ooo`030000003oool0oooo00P0oooo00090?ooo`05o`00003oool0oooo0?ooo`2P
8?002P3oool00`2P8?00oooo0?ooo`070?ooo`030:0Pl03oool0oooo00P0oooo00<0X23`0?ooo`3o
ool03@3oool00`2P8?00oooo0?ooo`030:0Pl0/0oooo00<0X23`0?ooo`3oool00`3oool00oooO`00
oooo0?ooo`050?ooo`030:0Pl03oool0oooo00L0oooo0P2P8?0D0?ooo`040?mo003oool0oooo0:0P
l0<0oooo00<0X23`0?ooo`2P8?000`3oool00oooO`00oooooomo000b0?ooo`03o`00003oool0oooo
00l0oooo00<000000?ooo`3oool03P3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oool0oooo
00<0oooo00?oX23`0?ooo`3oool01`3oool00onP8?00oooo0?ooo`0I0?ooo`030?mo0?ooO`00oooo
00<0oooo00D0ogl00?oooonP8?3oX23`0?ooo`02oj0Pl0030?oooonP8?00oooo00H0oooo00?oX23`
0?ooo`3oool02P3oool2oj0Pl080oooo00?oogl00?ooo`3oool0B@3oool00`000000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`0b0?ooo`80X23`2`3oool00`2P8?00oooo0?ooo`070?oo
o`030:0Pl03oool0ogl000<0oooo00H0ogl00?ooo`2P8?00ogl00?ooo`2P8?020?ooo`030:0Pl03o
O`00oooo00<0oooo00D0X23`0?ooo`3oool0oooo0:0Pl00I0?ooo`030:0Pl03oool0oooo00D0oooo
00<0X23`0?ooo`3oool0;03oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo
00CoX23`0?ooo`3oooooX23`103oool2oj0Pl004oomo0?nP8?00oooooj0Pl0<0oooo00Coogl00?oo
o`3oooooX23`103oool00oooO`00oooo0?ooo`060?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`
0?ooo`3oool0A03oool00`000000oooo0?ooo`080?ooo`002@3oool01Ol00000oooo0?ooo`3oool0
X23`00D0oooo00@0X23`0?ooo`3oool0X23`2@3oool00`2P8?00oooo0?ooo`0=0?ooo`030:0Pl03o
ool0oooo00T0oooo00<0X23`0?ooo`3oool00P3oool20:0Pl080oooo00?oogl00?ooo`3oool0203o
ool00oooO`00oooo0?ooo`020?ooo`0:0:0Pl03oool0oooo0?mo003oool0X23`0?ooo`2P8?00ogl0
0:0Pl0L0oooo00@0X23`0?ooo`3oool0X23`2P3oool00`2P8?00oooo0?ooo`020?ooo`060:0Pl?oo
O`00oooo0:0Pl03oooooogl00`3oool00`2P8?00oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo02`0
oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo00L0
oooo00?oX23`0?ooo`3oool03P3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo00h0
oooo00SoX23`0?oooonP8?3oX23`0?oooonP8?00oooo0?mo00?oX23`00@0oooooj0Pl?nP8?3oX23`
0P3oool00onP8?3oogl00?ooo`070?ooo`03oj0Pl03oooooX23`00@0oooo00?oX23`0?ooo`3oool0
C03oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0h0?ooo`80X23`0P3o
ool20:0Pl0<0oooo00<0ogl00?ooo`3oool01P3oool20:0Pl080oooo00D0X23`0?ooo`3oool0oooo
0:0Pl0090?ooo`030?mo003oool0oooo00H0oooo00<0X23`0?ooo`3oool01@3oool00`2P8?00oooo
0?ooo`120?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0?@3oool00onP8?00oooo
0?ooo`040?ooo`04oj0Pl03oool0oooooj0Pl0D0oooo0_nP8?020?ooo`05oomo003oooooX23`0?oo
ooooO`002@3oool01?nP8?00oooo0?oooonP8?1?0?ooo`030000003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo00@0oooo00<0X23`0?ooo`3oool03@3oool00`2P8?00oooo0?ooo`040?oo
o`030:0Pl03oool0oooo0100oooo00<0X23`0?ooo`3oool01P3oool00`2P8?00oooo0?ooo`020?oo
o`80X23`1`3oool20:0Pl0H0oooo00Koogl00:0Pl03oool0X23`0?ooo`2P8?070?ooo`030:0Pl03o
O`00oooo00@0oooo00<0X23`0?ooo`3oool04`3oool00`2P8?00oooo0?ooo`0h0?ooo`03o`00003o
ool0oooo00l0oooo00<000000?ooo`3oool07@3oool00onP8?00oooo0?ooo`0:0?ooo`03oj0Pl03o
ool0oooo00<0oooo00GoX23`0?ooo`3oool0oooooj0Pl00A0?ooo`;oX23`0`3oool2oj0Pl0030?oo
oonP8?00oooo00?oX23`0P3oool00oooO`00oooo0?ooo`0?0?ooo`03oj0Pl03oool0oooo04P0oooo
00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool01@3oool00`2P8?00oooo0?oo
o`090?ooo`030:0Pl03oool0oooo01X0oooo00<0X23`0?ooo`3oool01`3oool0202P8?00oooo0?oo
o`2P8?00oooo0:0Pl03oO`00X23`2@3oool0102P8?00ogl00:0Pl02P8?020?ooo`080:0Pl03oool0
X23`0:0Pl03oool0X23`0?ooo`2P8?020?ooo`80X23`103oool01@2P8?00oooo0:0Pl03oool0X23`
00/0oooo00<0X23`0?ooo`2P8?003`3oool00`2P8?00oooo0:0Pl0020?ooo`030:0Pl03oool0oooo
02T0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`03oj0Pl03oool0oooo
00X0oooo00?oX23`0?ooo`3oool06P3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo
00;oX23`0P3oool00onP8?00oooooj0Pl005oj0Pl080oooo00?oogl0oj0Pl?nP8?000`3oool00onP
8?00oooooj0Pl0040?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo00CoX23`0?ooo`3oool0oooo0_nP
8?000`3oooooX23`0?ooo`120?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo00L0oooo00<0X23`0?ooo`3oool0@@3oool00`2P8?00oooo0?ooo`040?ooo`04oomo002P8?00
oooo0:0Pl0L0oooo00<0X23`0?ooo`2P8?002`3oool00`2P8?00oooo0?ooo`060?ooo`030:0Pl03o
ool0oooo00D0oooo00<0X23`0?ooo`3oool02@3oool00oooO`00oooo0?ooo`0W0?ooo`03o`00003o
ool0oooo00l0oooo00<000000?ooo`3oool08`3oool01OnP8?00oooo0?ooo`3oooooX23`02<0oooo
00CoX23`0?ooo`3oool0ogl00_nP8?050?ooo`07oj0Pl03oool0ogl00?oooonP8?00oooooj0Pl008
0?ooo`05oj0Pl03oool0oooo0?oooonP8?00B03oool00`000000oooo0?ooo`080?ooo`002@3oool0
0`2P8?00oooo0:0Pl00f0?ooo`040:0Pl03oool0X23`0:0Pl0<0oooo00<0ogl00?ooo`3oool00P3o
ool01`2P8?00oooo0?ooo`3oool0X23`0?ooo`2P8?000P3oool00`3oO`00oooo0?ooo`030?ooo`80
X23`00@0ogl00?ooo`2P8?00oooo0P2P8?040?ooo`030:0Pl03oool0X23`00<0oooo0P2P8?060?oo
o`050:0Pl03oool0X23`0?ooo`2P8?000P3oool00`3oO`00oooo0?ooo`0m0?ooo`03o`00003oool0
oooo00l0oooo00<000000?ooo`3oool0403oool01?nP8?00oooo0?oooonP8?0:0?ooo`;oX23`5P3o
ool00onP8?00oooo0?ooo`0=0?ooo`03oj0Pl03oool0oooo00?oX23`00?oogl00?oooonP8?000_nP
8?002@3oooooX23`oj0Pl03oooooogl00?ooooooO`00oooooj0Pl0020?ooo`03oj0Pl03oool0oooo
00;oX23`00<0oooooomo0?nP8?00CP3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0W0?ooo`030:0Pl03oool0oooo01@0oooo00<0X23`0?ooo`3oool02P3oool00`2P8?00
oooo0?ooo`020?ooo`03oomo003oool0oooo00@0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00
oooo0?ooo`090?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool0203oool01@2P8?00
oooo0?ooo`3oool0X23`03D0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0l0?oo
o`05oj0Pl03oool0oooo0?oooonP8?003`3oool00onP8?00oooo0?ooo`030?ooo`04oj0Pl03oool0
oooooomo0080oooo00CoX23`0?ooo`3oooooX23`203oool00onP8?00oooo0?ooo`170?ooo`030000
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00T0oooo00<0X23`0?ooo`3oool05P3o
ool00`2P8?00oooo0?ooo`0B0?ooo`030:0Pl03oool0oooo00@0oooo00<0ogl00:0Pl03oool00`3o
ool01P3oO`00oooo0?ooo`2P8?00oooo0:0Pl0P0oooo00<0X23`0?ooo`3oool02@3oool20:0Pl0<0
oooo00<0X23`0?ooo`3oool01P3oool00`2P8?00oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo00<0
oooo00?oogl00?ooo`2P8?00<03oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0
oooo00?oX23`0?ooo`3oool0103oool00onP8?00oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo00h0
oooo00D0ogl00?ooo`3oool0oooooj0Pl0050?ooo`?oX23`0P3oool3oj0Pl080oooo00?oX23`oomo
003oool0103oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo04L0oooo00<000000?oo
o`3oool0203oool000T0oooo00?o00000:0Pl03oool00`3oool00`2P8?00oooo0?ooo`0J0?ooo`03
0:0Pl03oool0oooo01D0oooo00<0X23`0?ooo`3oool00P3oool30:0Pl0030?ooo`3oO`00X23`0080
X23`00<0oooo0?mo003oool00`3oool01`2P8?00oooo0:0Pl03oool0X23`0?ooo`2P8?000P3oool0
0`2P8?00oooo0?ooo`020:0Pl0030?ooo`2P8?00oooo00D0oooo00<0X23`oomo003oool0203oool0
0`2P8?00oooo0?ooo`070?ooo`030:0Pl03oool0oooo0080oooo0P2P8?040?ooo`03oomo003oool0
oooo02h0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`03oj0Pl03oool0
oooo00P0oooo00?oX23`0?ooo`3oool0303oool00onP8?00oooo0?ooo`0<0?ooo`03oj0Pl03oool0
oooo00/0oooo00GoX23`0?oooonP8?00ogl00?ooo`03oj0Pl005oomo003oooooX23`oomo0?nP8?00
0P3oool00`3oO`3oX23`0?ooo`060?ooo`03oj0Pl03oooooX23`00<0oooo00CoX23`0?ooo`3ooooo
X23`A@3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`040?ooo`030:0P
l03oool0oooo01T0oooo00<0X23`0?ooo`3oool05P3oool00`2P8?00oooo0?ooo`0P0?ooo`040:0P
l03oool0oooooomo0080oooo00D0X23`0?ooo`3oool0oooo0:0Pl0020?ooo`030:0Pl03oool0oooo
00D0oooo00?oogl00?ooo`3oool03`3oool00oooO`00oooo0?ooo`0/0?ooo`03o`00003oool0oooo
00l0oooo00<000000?ooo`3oool08P3oool00onP8?00oooo0?ooo`0E0?ooo`03oj0Pl03oool0oooo
0140oooo00?oX23`0?oooonP8?000P3oool00`3oO`00oooo0?ooo`020?ooo`05oj0Pl03oooooX23`
0?oooonP8?00E@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`2P8?00oooo0?ooo`040?oo
o`030:0Pl03oool0oooo02T0oooo00<0X23`0?ooo`3oool03P3oool04P2P8?00oooo0?ooo`2P8?00
oooooomo003oO`00oooo0:0Pl03oool0X23`oomo003oool0X23`0?ooo`2P8?00oooo0?mo0080oooo
00<0X23`0?ooo`2P8?001P3oool00`2P8?00oooo0:0Pl0020?ooo`@0X23`1@3oool0102P8?00oooo
0?ooo`3oool30:0Pl0H0oooo00<0X23`0?ooo`3oool01P3oool01@3oO`00oooo0?ooo`2P8?3oogl0
02/0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo
00@0oooo0_nP8?0=0?ooo`04oj0Pl03oool0oooooj0Pl1D0oooo00?oX23`0?ooo`3oool0103oool0
0onP8?00oooooj0Pl0020?ooo`;oX23`1@3oool00onP8?00oooooj0Pl003oj0Pl0060?oooonP8?3o
X23`oomo003oooooX23`1@3oool00`3oO`00oooooj0Pl0020?ooo`;oX23`00<0oooooj0Pl03oool0
1@3oool01OnP8?00oooo0?ooo`3oooooogl003d0oooo00<000000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool04`3oool00`2P8?00oooo0?ooo`0A0?ooo`030:0Pl03oool0oooo01L0oooo
00<0X23`0?ooo`3oool00P3oool0102P8?00oooo0:0Pl03oool20:0Pl080oooo00<0X23`0?ooo`3o
ool0103oool00`2P8?00oooo0:0Pl00B0?ooo`030:0Pl03oool0oooo00<0oooo00<0X23`0?ooo`3o
ool00P3oool20:0Pl0L0oooo00<0X23`0?ooo`3oool0<@3oool00ol00000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01T0oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?ooo`0H0?ooo`03
oj0Pl03oool0oooo00l0oooo0_nP8?001@3oooooX23`0?ooo`3oooooX23`0080oooo0_nP8?070?oo
o`05oj0Pl03oooooX23`0?oooonP8?00103oool00onP8?00oooo0?ooo`120?ooo`030000003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo03d0oooo00<0X23`0?ooo`3oool02@3oool20:0P
l0D0oooo00<0X23`0?ooo`2P8?000P3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo
00H0oooo00<0X23`0?ooooooO`000`3oool20:0Pl080oooo00@0X23`0?ooo`3oool0oooo0P2P8?06
0?ooo`03oomo003oool0oooo00D0oooo00<0X23`0?ooo`3oool0;P3oool00ol00000oooo0?ooo`0?
0?ooo`030000003oool0oooo03D0oooo00GoX23`0?ooo`3oool0oooooj0Pl00@0?ooo`05oj0Pl03o
ool0oooo0?oooonP8?00103oool4oj0Pl0030?oooonP8?3oX23`0080oooo00Coogl00?ooo`3oool0
oooo0_nP8?000`3oooooX23`oj0Pl0020?ooo`;oX23`B@3oool00`000000oooo0?ooo`080?ooo`00
2@3oool00`2P8?00oooo0?ooo`0L0?ooo`030:0Pl03oool0oooo00l0oooo00<0X23`0?ooo`3oool0
1@3oool00`2P8?00oooo0?ooo`080?ooo`040:0Pl03oool0oooo0?ooo`<0X23`0P3oool20:0Pl0<0
oooo00D0X23`0?ooo`3oool0X23`0?ooo`020:0Pl080oooo00<0X23`0?ooo`3oool00P3oool60:0P
l0<0oooo00<0X23`0?ooo`2P8?000P3oool00oooO`00X23`0?ooo`030?ooo`;oogl00P3oool01@2P
8?00oooo0:0Pl03oooooogl000h0oooo00<0X23`0?ooo`3oool09`3oool00ol00000oooo0?ooo`0?
0?ooo`030000003oool0oooo0180oooo00?oX23`0?ooo`3oool04@3oool00onP8?00oooo0?ooo`0D
0?ooo`03oj0Pl03oool0oooo00H0oooo00KoX23`0?oooonP8?3oX23`0?ooooooO`020?ooo`04oj0P
l03oool0oooo0?ooo`;oX23`00<0oooooj0Pl?nP8?000_nP8?001`3oooooX23`0?oooonP8?00oooo
oj0Pl03oO`000_nP8?001`3oooooX23`0?ooo`3oooooX23`0?oooonP8?002@3oool00onP8?00oooo
0?ooo`0m0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01@0oooo00<0
X23`0?ooo`3oool07P3oool00`2P8?00oooo0?ooo`030?ooo`030:0Pl03oool0oooo01@0oooo00Co
ogl00?ooo`3oool0ogl01@3oool00`2P8?00oooo0?ooo`020?ooo`80X23`2`3oool00`2P8?00oooo
0?ooo`020?ooo`03oomo003oool0oooo00H0oooo00@0X23`0?ooo`3oool0X23`<`3oool00ol00000
oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo00?oX23`0?ooo`3oool0503oool2oj0Pl080
oooo00KoX23`0?ooo`3oool0oooooj0Pl03oO`060?ooo`03oomo003oool0oooo00<0oooo0_nP8?09
0?ooo`03oj0Pl03oooooX23`04@0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0=@3oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0oooo00L0oooo00<0X23`0?oo
o`3oool0103oool20:0Pl0040?ooo`3oO`00oooo0:0Pl0D0oooo00L0X23`0?ooo`3oO`00oooo0:0P
l03oool0ogl00080X23`0P3oool00`3oO`00X23`0?ooo`020:0Pl0030?ooo`2P8?00X23`00<0X23`
00L0oooo0:0Pl02P8?00oooo0:0Pl03oooooogl00080oooo00<0X23`0?ooo`2P8?00103oool20:0P
l080oooo00<0X23`0?ooo`3oool01@3oool00`2P8?00oooo0?ooo`0U0?ooo`03o`00003oool0oooo
00l0oooo00<000000?ooo`3oool0>03oool00onP8?00oooo0?ooo`0>0?ooo`03oj0Pl03oooooogl0
00@0oooo00WoX23`0?oooonP8?00oooo0?mo0?nP8?00oooooj0Pl03oool00_nP8?001?ooO`3oX23`
oj0Pl?nP8?020?ooo`04oj0Pl?ooO`3oX23`oj0Pl080oooo0onP8?000`3oooooX23`0?ooo`02oj0P
l0@0oooo0_nP8?0m0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo04@0
oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?ooo`030?ooo`030:0Pl03oool0oooo00H0
oooo00<0X23`0?ooo`3oool00P3oool0102P8?00oooo0?ooo`2P8?030?ooo`030:0Pl03oool0oooo
00@0oooo00?oogl00?ooo`3oool0303oool00`2P8?00oooo0?ooo`070?ooo`030:0Pl03oool0oooo
00`0oooo00<0X23`oomo003oool00P3oool00oooO`00oooo0?ooo`0E0?ooo`03o`00003oool0oooo
00l0oooo00<000000?ooo`3oool0703oool00onP8?00oooo0?ooo`0W0?ooo`03oomo003oool0oooo
00P0oooo0_nP8?040?ooo`030?mo003oooooX23`00@0oooo00?oX23`0?oooonP8?000`3oool00onP
8?00oooooj0Pl0060?ooo`04oj0Pl03oool0oooooj0Pl440oooo00<000000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`2P8?002`3oool00`2P8?00oooo0?ooo`0d0?ooo`050:0Pl03oool0X23`
0?ooo`2P8?001P3oool00`2P8?00oooo0?ooo`030?ooo`030:0Pl03oool0oooo00@0oooo00<0X23`
0?ooo`2P8?001`3oool30:0Pl0D0oooo00<0X23`0?ooo`3oool00`3oool0102P8?3oogl00?oooooo
O`020?ooo`80X23`103oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl?ooO`00oooo02`0oooo00?o
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`03oj0Pl03oool0oooo00/0oooo00?o
X23`0?ooo`3oool0703oool00onP8?00oooo0?ooo`0:0?ooo`03oj0Pl03oool0oooo0080oooo0_nP
8?020?ooo`04oj0Pl03oool0oooo0?ooo`?oX23`00@0oooooj0Pl03oooooX23`103oool01?nP8?00
ogl0oj0Pl03oool2oj0Pl080oooo00?oX23`0?ooo`3oool0?`3oool00`000000oooo0?ooo`080?oo
o`002@3oool20:0Pl180oooo00<0X23`0?ooo`3oool08@3oool00`2P8?00oooo0?ooo`080?ooo`04
0:0Pl03oool0oooo0:0Pl080oooo00<0X23`0?ooo`3oool03@3oool00`2P8?00ogl00?ooo`0@0?oo
o`050:0Pl03oool0oooo0?ooo`2P8?00203oool01@3oO`00oooo0?ooo`3oool0X23`00H0oooo00<0
X23`0?ooo`3oool02`3oool00oooO`00oooo0?ooo`0P0?ooo`03o`00003oool0oooo00l0oooo00<0
00000?ooo`3oool04@3oool01OnP8?00oooo0?ooo`3oooooX23`0080oooo00?oX23`0?ooo`3oool0
5@3oool00onP8?00oooo0?ooo`0F0?ooo`06oj0Pl03oool0oooooj0Pl03oooooX23`1@3oool2oj0P
l0030?ooo`3oO`3oX23`00D0oooo0_nP8?030?ooo`03oomo003oool0oooo00<0oooo00Coogl00?oo
o`3oooooX23`A@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`2P8?00oooo0?ooo`0@0?oo
o`030:0Pl03oool0oooo02h0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`020?oo
o`06oomo003oool0oooo0?mo003oool0X23`1P3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03o
ool0oooo0080oooo00<0X23`0?ooo`3oool0203oool20:0Pl0d0oooo00@0X23`0?ooo`3oool0X23`
<`3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01/0oooo00?oX23`0?ooo`3oool0
403oool00onP8?00oooooj0Pl00N0?ooo`03oj0Pl03oool0oooo00@0oooo00GoX23`0?ooo`3oool0
oooooj0Pl0020?ooo`05oj0Pl?ooO`3oX23`oj0Pl03oool00_nP8?040?ooo`03oj0Pl03oool0oooo
00<0oooo00?oX23`0?oooonP8?00@@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`2P8?00
oooo0?ooo`070?ooo`030:0Pl03oool0oooo01D0oooo00<0X23`0?ooo`3oool03P3oool00`2P8?00
oooo0?ooo`050?ooo`030:0Pl03oool0oooo00H0oooo00<0X23`0?ooo`3oool0103oool0102P8?00
oooo0?ooo`2P8?040?ooo`060?mo002P8?00ogl00:0Pl03oooooogl00`3oool00`2P8?00oooo0?oo
o`020:0Pl0040?ooo`2P8?00oooo0:0Pl0@0oooo00D0X23`0?ooo`3oool0oooo0:0Pl0020?ooo`04
0:0Pl03oool0oooo0:0Pl0X0oooo0P2P8?0;0?ooo`030:0Pl03oool0oooo01L0oooo00?oogl00?oo
o`3oool03@3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00?oX23`0?oo
o`3oool04P3oool00onP8?00oooo0?ooo`0>0?ooo`05oj0Pl03oool0oooo0?oooonP8?00203oool0
1OnP8?00oooo0?ooo`3oooooX23`00@0oooo00?oogl00?ooo`3oool00P3oool02?nP8?00oooo0?oo
o`3oO`3oogl00?oooonP8?3oogl01OnP8?030?ooo`;oX23`00D0oooooj0Pl03oooooX23`0?ooo`02
oj0Pl0H0oooo00?oX23`0?ooo`3oool0>`3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`1>0?ooo`03oomo003oool0oooo00`0oooo0P2P8?020?ooo`030:0Pl03oool0oooo
00@0oooo00<0X23`0?ooo`3oool00P3oool20:0Pl0040?ooo`2P8?00oooo0:0Pl0X0oooo00<0X23`
0?ooo`3oool0<P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00?oX23`
0?mo003oool01@3oool00onP8?00oooooj0Pl0030?ooo`?oX23`00<0oooooj0Pl03oool00`3oool0
0onP8?00oooo0?ooo`0o0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00002P8?00oooo
01D0oooo00<0X23`0?ooo`3oool02@3oool00`2P8?00oooo0?ooo`0U0?ooo`040:0Pl03oool0oooo
0?ooo`80X23`1P3oool00oooO`00oooo0?ooo`020?ooo`030?mo002P8?00oooo00<0oooo0P2P8?00
1P3oool0X23`0:0Pl03oO`00oooo0:0Pl080oooo00<0X23`0?ooo`3oool0103oool20:0Pl003oomo
003oool0oooo0080oooo00<0X23`0?ooo`3oool00`3oool20:0Pl080oooo00<0X23`0?ooooooO`00
;@3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00?oX23`0?ooo`3oool0
5@3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0
503oool01onP8?00oooooomo003oooooX23`0?oooonP8?000P3oool2oj0Pl080oooo00D0ogl0oj0P
l03oooooX23`0?ooo`02oj0Pl003oomo0?nP8?00oooo00CoX23`0P3oool2oj0Pl400oooo00<00000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0<03oool00`2P8?00oooo0?ooo`0G0?oo
o`030:0Pl03oool0oooo00`0oooo00<0X23`oomo003oool01`3oool00`2P8?00oooo0?ooo`050?oo
o`030:0Pl03oool0oooo00h0oooo00@0X23`0?ooo`3oool0oooo0P2P8?0;0?ooo`030:0Pl03oool0
oooo0280oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`1;0?ooo`03oj0Pl03oool0
oooo00T0oooo00?oX23`0?ooo`3oool0103oool01P3oO`00oooo0?oooonP8?00oooooj0Pl0H0oooo
00KoX23`0?ooo`3oool0oooooj0Pl03oool2oj0Pl0H0oooo00?oX23`0?ooo`3oool0=`3oool00`00
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0@0?ooo`030:0Pl03oool0oooo03P0
oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`050?ooo`0:0:0Pl03oool0X23`0?oo
o`2P8?00ogl00:0Pl03oool0X23`0?ooo`80X23`00D0oooo0:0Pl03oool0oooo0:0Pl0020?ooo`03
0:0Pl03oool0X23`00D0oooo00<0X23`0?ooo`3oool0103oool00oooO`00oooo0?ooo`050?ooo`03
0:0Pl03oool0oooo02d0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0c0?ooo`03
oj0Pl03oool0oooo0240oooo00Coogl00?ooo`3oool0ogl00`3oool4oj0Pl0030?oooonP8?3oX23`
00;oX23`00Soogl0oj0Pl03oool0oooooj0Pl03oooooX23`0?ooo`?oX23`@03oool00`000000oooo
0?ooo`080?ooo`002@3oool00`2P8?00oooo0?ooo`100?ooo`030:0Pl03oool0oooo01L0oooo0P2P
8?030?ooo`060:0Pl03oool0oooo0?ooo`3oO`00oooo0`2P8?050?ooo`060:0Pl03oool0oooooomo
003oool0X23`0P3oool0102P8?00oooo0?ooooooO`030:0Pl080oooo00@0X23`0?ooo`3oool0X23`
1P3oool00`2P8?00oooo0?ooo`0W0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0
603oool00onP8?00oooo0?ooo`0m0?ooo`03oj0Pl03oool0oooo00<0oooo0_nP8?00103oool0ogl0
oj0Pl?ooO`020?ooo`?oX23`00Coogl00?oooonP8?00ogl00_nP8?000`3oooooX23`0?ooo`02oj0P
l0030?oooonP8?00oooo03/0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0E@3oool20:0Pl0D0oooo00<0X23`0?ooo`3oool0303oool0102P8?00oooo0?ooooooO`030?oo
o`040:0Pl03oool0oooo0:0Pl0P0oooo00?oogl00?ooo`3oool0<@3oool00ol00000oooo0?ooo`0?
0?ooo`030000003oool0oooo05d0oooo00Ooogl00?ooooooO`00oooooj0Pl03oooooX23`00L0oooo
00?oX23`0?oooonP8?00A03oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`1<0?ooo`030:0Pl03oool0oooo00<0oooo00?oogl00?ooo`3oool00`3oool01@2P8?00ogl00:0P
l03oooooogl00080oooo00H0ogl00?ooo`2P8?00X23`oomo002P8?030?ooo`070:0Pl03oool0oooo
0:0Pl03oooooogl00:0Pl0060?ooo`030:0Pl03oool0oooo00h0oooo00<0X23`0?ooo`3oool02P3o
ool00`2P8?00oooo0?ooo`0L0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0DP3o
ool00onP8?00oooo0?ooo`060?ooo`030?mo003oooooX23`00<0oooo00?oX23`0?mo0?nP8?000P3o
ool01?ooO`3oX23`0?oooonP8?030?ooo`03oj0Pl03oooooX23`00;oX23`@03oool00`000000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0m0?ooo`030:0Pl03oool0oooo00H0oooo00<0
X23`0?ooo`3oool01@3oool00`2P8?00oooo0?ooo`030?ooo`03oomo002P8?00oooo00<0oooo00D0
X23`0?ooo`3oool0oooo0:0Pl0020?ooo`040:0Pl03oool0oooo0?mo00H0oooo00?oogl00:0Pl02P
8?005@3oool00`2P8?00oooo0?ooo`040?ooo`040:0Pl03oool0oooo0:0Pl0l0oooo00<0X23`0?oo
o`3oool04P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo05D0oooo00?oX23`0?oo
o`3oool00`3oool00onP8?00oooooomo00030?ooo`?oX23`0P3oool02?nP8?00oooooj0Pl03ooooo
ogl0oj0Pl03oooooX23`1P3oool2oj0Pl0<0oooo00GoX23`0?ooo`3oool0oooooj0Pl00d0?ooo`03
0000003oool0oooo00P0oooo00090?ooo`80X23`?P3oool00`2P8?00oooo0?ooo`0D0?ooo`030:0P
l03oool0oooo00D0oooo00Coogl00?ooo`3oool0X23`0P3oool00`2P8?00oooo0?ooo`030?ooo`03
0:0Pl03oool0X23`00`0oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?ooo`0/0?ooo`03
oomo003oool0oooo0080oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`04
oj0Pl03oool0oooooj0Pl3@0oooo00?oX23`0?ooo`3oool02`3oool01onP8?00oooo0?oooonP8?00
oooo0?mo0?nP8?000P3oool01OnP8?3oogl00?ooo`3oooooX23`0080oooo00?oX23`0?oooonP8?00
?`3oool00`000000oooo0?ooo`080?ooo`002@3oool01@2P8?00oooo0?ooo`3oool0X23`03T0oooo
00<0X23`0?ooo`3oool05`3oool30:0Pl0<0oooo00<0X23`0?ooo`3oool00`3oool00oooO`00oooo
0:0Pl0020?ooo`80X23`0`3oool00`2P8?3oogl00?ooo`020?ooo`030:0Pl03oool0oooo0080oooo
0`2P8?050?ooo`030:0Pl03oool0oooo0080oooo0P2P8?020?ooo`030:0Pl03oool0oooo0080oooo
00?oogl00?ooo`3oool0903oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01X0oooo
00CoX23`0?ooo`3oooooX23`=P3oool00onP8?00oooo0?ooo`070?ooo`04oomo003oool0oooo0?oo
o`;oX23`00<0oooooj0Pl?ooO`000_nP8?020?ooo`040?mo0?nP8?3oX23`0?ooo`;oX23`00<0oooo
oj0Pl03oool00`3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo02h0oooo00<00000
0?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0CP3oool00`2P8?00oooo0?ooo`040?oo
o`030:0Pl03oool0oooo0080oooo00@0X23`0?ooo`2P8?00oooo0P3oO`020?ooo`07oomo003oool0
oooo0?ooo`2P8?00oooo0:0Pl0060?ooo`030:0Pl03oool0oooo0080oooo00?oogl00?ooo`3oool0
1@3oool00`2P8?00oooo0?ooo`020?ooo`040:0Pl03oool0oooo0:0Pl0D0oooo00<0X23`0?ooo`3o
ool09@3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00?oX23`0?ooo`3o
ool0?P3oool00onP8?00oooo0?ooo`020?ooo`07oj0Pl03oool0oooooj0Pl?ooO`00ogl0oj0Pl002
0?ooo`;oX23`0P3oool01OnP8?00oooo0?mo003oooooX23`00<0oooo0_nP8?060?ooo`03oj0Pl03o
ool0oooo03@0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0D03oool0
0`2P8?00oooo0?ooo`040?ooo`09oomo002P8?3oogl0oomo003oool0X23`0?ooo`2P8?00ogl000H0
oooo00<0X23`0?ooo`3oool0103oool01P2P8?00oooo0?ooo`2P8?00oooo0:0Pl080oooo0`2P8?04
0?ooo`030:0Pl03oooooogl000@0oooo00H0X23`0?ooo`3oool0X23`0?ooo`2P8?0Y0?ooo`03o`00
003oool0oooo00l0oooo00<000000?ooo`3oool0H@3oool00onP8?00oooo0?mo0002oj0Pl0030?oo
ooooO`3oX23`0080oooo00?oX23`oomo0?nP8?000P3oool2oj0Pl080oooo00CoX23`0?ooo`3oool0
oooo0_nP8?0h0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00/0oooo
00<0X23`0?ooo`3oool0AP3oool01`2P8?00oooo0?ooo`3oool0X23`0?ooo`2P8?000P3oool00`2P
8?00oooo0?ooo`060?ooo`030?mo003oool0oooo0080oooo0`2P8?040?ooo`03oomo003oool0oooo
00H0oooo00<0X23`0?ooo`3oool00P3oool01@2P8?00oooo0?ooo`3oool0X23`00L0oooo0P2P8?0T
0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00onP8?00oooo0?ooo`15
0?ooo`;oX23`00@0oooooj0Pl03oool0ogl00P3oool00onP8?00oooooj0Pl0050?ooo`03oj0Pl03o
ooooX23`00D0oooo00?oX23`0?oooonP8?00<P3oool00`000000oooo0?ooo`080?ooo`002@3oool0
1@2P8?00oooo0?ooo`3oool0X23`01T0oooo00<0X23`0?ooo`3oool06P3oool00`2P8?00oooo0?oo
o`0:0?ooo`030:0Pl03oool0oooo00X0oooo0`2P8?020?ooo`040:0Pl03oool0oooooomo00@0oooo
00L0ogl00?ooo`3oO`00oooo0?mo003oool0X23`00`0oooo00?oogl00?ooo`3oool00P2P8?000`3o
ool0X23`0?ooo`050?ooo`05oomo003oool0oooo0?ooo`2P8?00103oool0202P8?00oooo0?ooo`2P
8?00oooo0:0Pl03oooooogl08P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01/0
oooo00?oX23`0?ooo`3oool02P3oool00onP8?00oooo0?ooo`0G0?ooo`03oj0Pl03oool0oooo00`0
oooo00?oX23`0?ooo`3oool0203oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oooooX23`00;o
X23`0`3oool00oooO`00oooooj0Pl002oomo00CoX23`00<0oooo0?mo003oool00P3oool00onP8?00
oooo0?ooo`02oj0Pl3@0oooo00<000000?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0
FP3oool00oooO`00oooo0?ooo`030?ooo`030:0Pl03oooooogl00180oooo00Googl00?ooo`3oool0
oooo0:0Pl0030?ooo`050:0Pl03oool0oooo0?ooooooO`001P3oool00`2P8?3oogl00:0Pl0020?oo
o`030:0Pl03oool0oooo0280oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?oo
o`03oj0Pl03oool0oooo0540oooo0_ooO`001@3oooooX23`0?ooo`3oO`00oooo00;oX23`00<0oooo
0?mo003oool00`3oool00onP8?00oooo0?ooo`02oj0Pl3@0oooo00<000000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool00`3oool00`2P8?00oooo0?ooo`1D0?ooo`030:0Pl03oooooogl0
00H0oooo00?oogl00?ooo`3oool01P3oool00oooO`00oooo0?ooo`080?ooo`03oomo003oool0oooo
0100oooo00H0X23`0?ooo`3oool0X23`0?ooo`2P8?0R0?ooo`03o`00003oool0oooo00l0oooo00<0
00000?ooo`3oool0;@3oool00onP8?00oooo0?ooo`0h0?ooo`07oomo003oool0oooooj0Pl03ooooo
ogl00?mo00030?ooo`030?mo003oool0oooo00L0oooo00GoX23`0?oooonP8?00oooooj0Pl00a0?oo
o`030000003oool0oooo00P0oooo00090?ooo`80X23`7P3oool00`2P8?00oooo0?ooo`0:0?ooo`03
0:0Pl03oool0oooo00D0oooo00<0X23`0?ooo`3oool01@3oool00`2P8?00oooo0?ooo`0H0?ooo`04
0:0Pl03oool0X23`0:0Pl0<0oooo00<0X23`0?ooo`3oool01@3oool00`2P8?00oooo0?ooo`040?oo
o`030:0Pl03oool0X23`00L0oooo00<0X23`0?ooo`3oO`003P3oool01OooO`00oooo0?ooo`3oool0
X23`00<0oooo0P2P8?040?ooo`05oomo003oool0oooo0?ooo`2P8?006@3oool00ol00000oooo0?oo
o`0?0?ooo`030000003oool0oooo01l0oooo0_nP8?0V0?ooo`05oj0Pl03oool0oooo0?oooonP8?00
0`3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo00`0oooo0onP8?00103oooooX23`
oj0Pl?nP8?050?ooo`050?mo003oool0oooo0?mo003oool00onP8?000oooO`00oooo0?ooo`030?oo
o`;oX23`<P3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`190?ooo`03
0:0Pl03oool0oooo00/0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`040?ooo`03
0:0Pl03oool0oooo00X0oooo00?oogl00?ooo`2P8?002@3oool00`2P8?00oooo0?ooo`0=0?ooo`@0
X23`103oool00`2P8?00oooo0?ooo`0K0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3o
ool0HP3oool01onP8?00oooo0?ooo`3oooooX23`0?oooonP8?000P3oool00onP8?00oooo0?ooo`03
0?ooo`030?mo003oooooX23`00X0oooo00KoX23`0?oooonP8?3oX23`0?oooonP8?0^0?ooo`030000
003oool0oooo00P0oooo00090?ooo`03o`00002P8?00oooo01<0oooo00<0X23`0?ooo`3oool0>P3o
ool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0X23`00D0oooo00?oogl00?ooo`2P8?001P3o
ool01@2P8?00oooo0?ooo`3oool0X23`00;oogl01P3oool01@2P8?00oooo0:0Pl03oool0ogl000`0
oooo00<0X23`0?ooo`2P8?000P2P8?020?ooo`80X23`0`3oool0102P8?00oooo0?ooooooO`0L0?oo
o`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool09`3oool00onP8?00oooo0?ooo`0?0?oo
o`03oj0Pl03oool0oooo0240oooo00?oX23`0?ooo`3oool00`3oool01?nP8?00oooo0?ooooooO`04
0?ooo`;oX23`00<0oooooj0Pl?nP8?000P3oool01_nP8?00oooooj0Pl?nP8?00oooooomo00<0oooo
0onP8?000`3oooooX23`oj0Pl003oj0Pl2h0oooo00<000000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0IP3oool00`3oO`00oooo0:0Pl0020?ooo`030:0Pl03oool0oooo0080oooo00<0
X23`0?ooo`3oool00P3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo00X0oooo00<0
X23`0?ooo`3oool0103oool00`2P8?00oooo0:0Pl00Q0?ooo`03o`00003oool0oooo00l0oooo00<0
00000?ooo`3oool0K`3oool00onP8?00oooo0?ooo`02oj0Pl080ogl01P3oool00onP8?00oooo0?oo
o`020?ooo`03oj0Pl03oool0oooo02h0oooo00<000000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0@`3oool00`2P8?00oooo0?ooo`0E0?ooo`80X23`203oool00`2P8?00oooo0?ooo`02
0?ooo`03oomo003oool0oooo0080oooo00<0X23`0?ooo`3oool00P3oool00`3oO`00X23`oomo000:
0?ooo`030:0Pl03oool0oooo00X0oooo0P2P8?020?ooo`050:0Pl03oool0oooo0?ooo`2P8?002P3o
ool00oooO`00oooo0?ooo`0>0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0G`3o
ool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo0080oooo0onP8?000`3oooooX23`0?oo
o`030?ooo`06oomo0?nP8?3oogl00?mo003oooooX23`1P3oool3oj0Pl0<0oooo00?oX23`0?ooo`3o
ool0:@3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`140?ooo`030:0P
l03oool0oooo00<0oooo00<0X23`0?ooo`3oool04P3oool01@2P8?00oooo0?ooo`3oool0X23`00@0
oooo00@0ogl00?ooo`2P8?00X23`0`3oool0102P8?00oooo0?ooo`2P8?050?ooo`030:0Pl03oool0
oooo00<0oooo00<0X23`oomo003oool01@3oool00`2P8?00oooo0?ooo`040?ooo`080:0Pl03oool0
X23`0:0Pl03oool0ogl00?ooo`2P8?070?ooo`03oomo003oool0oooo01<0oooo00?o00000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1K0?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?ooo`3o
ool0103oool2oj0Pl0060?oooonP8?3oX23`oj0Pl03oooooogl00_nP8?000`3oool0ogl0oj0Pl006
0?ooo`?oX23`0P3oool00onP8?00oooo0?ooo`020?ooo`03oomo003oool0oooo02D0oooo00<00000
0?ooo`3oool0203oool000T0oooo00?o00000:0Pl03oool0C@3oool00`2P8?00oooo0?ooo`080?oo
o`030:0Pl03oool0oooo00P0oooo00@0X23`oomo003oool0ogl00P3oool00oooO`00oooo0?ooo`07
0?ooo`03oomo003oool0X23`00@0oooo00<0X23`0?ooo`3oool05@3oool00`2P8?00oooo0:0Pl002
0?ooo`030:0Pl03oool0oooo01P0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q
0?ooo`03oj0Pl03oool0oooo03/0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`06
0?ooo`05oj0Pl03oooooogl00?mo0?ooO`000P3oool00onP8?00oooooj0Pl0090?ooo`;oX23`00<0
oooooj0Pl03oool0:P3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1J
0?ooo`060:0Pl03oool0oooo0?ooo`2P8?00oooo0P2P8?050?ooo`040:0Pl03oool0X23`0:0Pl080
oooo00@0X23`0?ooo`2P8?00X23`103oool01@2P8?00oooo0?ooo`3oool0X23`00L0oooo00D0X23`
0?ooo`2P8?00oooo0:0Pl0040?ooo`040:0Pl03oool0oooo0:0Pl0@0oooo00H0X23`0?ooo`2P8?00
X23`0?ooo`2P8?0J0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0K@3oool00onP
8?00oooooj0Pl003oj0Pl0040?mo0?nP8?3oX23`oj0Pl080oooo0_nP8?060?ooo`?oX23`0P3oool2
oj0Pl2X0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0I@3oool00`2P
8?00oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo00T0oooo00@0X23`0?ooo`2P8?00X23`103oool0
1@2P8?00oooo0?ooo`3oooooogl00080oooo00<0X23`0?ooo`3oool00P3oool00oooO`00oooo0?oo
o`020?ooo`030:0Pl03oool0oooo00H0oooo00?oogl00?ooo`3oool03`3oool00ol00000oooo0?oo
o`0?0?ooo`030000003oool0oooo06T0oooo00GoX23`0?ooo`3oool0oooooj0Pl0030?ooo`03oj0P
l?ooO`00oooo00H0oooo00?oX23`0?ooo`3oO`000_nP8?060?ooo`04oj0Pl03oool0oooooj0Pl2T0
oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0H@3oool00`2P8?00oooo
0?ooo`020?ooo`06oomo003oool0oooo0:0Pl03oool0X23`0`3oool00`2P8?00oooo0?ooo`040?oo
o`80X23`2P3oool00`2P8?00oooo0?ooo`090?ooo`03oomo002P8?00oooo00D0oooo00<0X23`0?oo
o`3oool06@3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo0780oooo00?oX23`oomo
003oool00_nP8?020?ooo`030?mo003oooooX23`00@0oooo0_nP8?050?ooo`03oj0Pl03oool0oooo
02P0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0C`3oool00`2P8?00
oooo0?ooo`0<0?ooo`80X23`103oool00`2P8?00oooooomo00020?ooo`040:0Pl?ooO`00X23`0?mo
00D0oooo00<0X23`0?ooo`3oool01`3oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oooooogl0
0080oooo00<0X23`0?ooo`3oool00P3oool20:0Pl080oooo00D0X23`0?ooo`3oooooogl00?ooo`02
0:0Pl1X0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0f0?ooo`03oj0Pl03oool0
oooo03H0oooo0_nP8?000`3oooooX23`0?ooo`02oj0Pl0?oogl000CoX23`0?ooo`3oO`3oX23`0P3o
ool00onP8?00oooo0?ooo`02oj0Pl080oooo1?nP8?0X0?ooo`030000003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo00d0oooo00<0X23`0?ooo`3oool0E`3oool01OooO`00oooo0?ooo`3o
ool0X23`0080oooo00<0X23`0?ooo`3oool01P3oool00`2P8?00oooo0?ooo`020?ooo`070:0Pl03o
ool0oooo0?ooooooO`00oooo0:0Pl0030?ooo`030:0Pl03oool0oooo00D0oooo00?oogl00?ooo`3o
ool00P3oool20:0Pl1d0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0[0?ooo`03
oj0Pl03oool0oooo03l0oooo00CoX23`0?ooo`3oooooogl0103oool00onP8?3oogl0oj0Pl002oj0P
l0<0oooo00GoX23`0?mo003oool0oooooj0Pl0040?ooo`03oj0Pl03oool0oooo02T0oooo00<00000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool00P3oool00`2P8?00oooo0?ooo`1?0?oo
o`030:0Pl03oool0oooo00/0oooo0P2P8?040?ooo`060:0Pl03oooooogl0oomo003oO`00X23`0P3o
ool00`2P8?00oooo0:0Pl0020?ooo`030:0Pl03oO`00oooo00H0oooo00Googl00?ooo`3oool0oooo
0:0Pl0020?ooo`040:0Pl?ooO`00oooo0:0Pl080oooo00Soogl00?ooo`2P8?00X23`0?ooooooO`00
oooo0:0Pl0@0oooo00?oogl00:0Pl03oool0603oool00ol00000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02@0oooo00?oX23`0?ooo`3oool0@P3oool00onP8?00oooo0?ooo`030?ooo`07oj0Pl03o
ool0oooo0?mo003oooooX23`oomo0004oj0Pl0030?ooooooO`3oX23`00;oX23`0P3oool00onP8?00
oooooj0Pl0020?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0903oool00`000000
oooo0?ooo`080?ooo`002@3oool00ol00000X23`0?ooo`1A0?ooo`030:0Pl03oool0oooo01L0oooo
00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo0080oooo
00Coogl00?ooo`3oool0X23`0`3oool0102P8?00oooo0:0Pl03oool30:0Pl0P0oooo00Googl00?oo
o`3oool0oooo0:0Pl00M0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0=03oool0
0onP8?00oooo0?ooo`0_0?ooo`03oj0Pl03oool0oooo00l0oooo0_nP8?000`3oooooX23`oj0Pl003
0?ooo`?oX23`1P3oool00onP8?00oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo06D0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooooomo00050?oo
o`<0X23`0`3oool20:0Pl080oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`020?oo
o`030?mo002P8?00oooo00X0oooo00Koogl00?ooo`3oool0X23`oomo003oool20:0Pl1L0oooo00?o
00000?ooo`3oool03`3oool00`000000oooo0?ooo`1d0?ooo`;oX23`00?oogl0oj0Pl03oool00_nP
8?000`3oO`3oX23`0?ooo`02oj0Pl007oomo0?nP8?00oooo0?oooonP8?00oooo0?mo00030?ooo`;o
X23`00<0oooooj0Pl03oool08`3oool00`000000oooo0?ooo`080?ooo`002@3oool00`2P8?00oooo
0?ooo`1R0?ooo`030:0Pl03oool0oooo00P0oooo00@0X23`0?ooo`3oooooogl0103oool0102P8?00
oooo0?ooo`3oool20:0Pl080oooo00<0X23`0?ooo`3oool01P3oool01OooO`00oooo0?ooo`3oool0
X23`00@0oooo00<0X23`0?ooo`3oool00P3oool00oooO`00oooo0?ooo`020?ooo`030:0Pl03oool0
oooo01H0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`03oj0Pl03oool0
oooo0540oooo00?oX23`0?ooo`3oool00`3oool0103oO`3oX23`0?ooo`3oool2oj0Pl0@0oooo00?o
X23`0?ooo`3oool0103oool00onP8?00oooooj0Pl00U0?ooo`030000003oool0oooo00P0oooo0009
0?ooo`04o`00003oool0oooo0:0Pl6X0oooo00<0X23`0?ooo`3oool00`3oool00`3oO`00X23`0?oo
o`020:0Pl0030?ooooooO`00oooo0080oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?oo
o`060?ooo`030:0Pl?ooO`00oooo00<0oooo00D0X23`0?ooo`3oool0oooooomo000M0?ooo`03o`00
003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool00onP8?00oooo0?ooo`1@0?ooo`03oj0P
l03oool0oooo00CoX23`00X0oooooj0Pl?ooO`3oogl0oj0Pl03oO`00oooooj0Pl03oO`3oX23`0`3o
ool00onP8?00oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo05/0oooo00<0X23`0?ooo`3oool01`3oool00`2P8?00oooo0?ooo`080?ooo`03oomo003oool0
ogl000<0oooo0`2P8?001OooO`00X23`0?ooo`2P8?3oogl000@0oooo00D0X23`0?ooo`3oool0oooo
oomo00030?ooo`070:0Pl03oool0oooo0?ooooooO`00X23`oomo00020:0Pl0@0oooo00<0X23`0?oo
o`3oool0603oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo0740oooo0_nP8?080?oo
o`GoX23`00Coogl0oj0Pl03oooooX23`0`3oool00onP8?00oooo0?ooo`03oj0Pl2D0oooo00<00000
0?ooo`3oool0203oool000T0oooo00Co00000?ooo`3oool0X23`G@3oool00`2P8?00oooo0?ooo`05
0?ooo`030:0Pl03oool0oooo00/0oooo00@0X23`0?ooo`3oooooogl01@3oool02`2P8?3oogl00:0P
l03oool0X23`0?ooo`2P8?00oooooomo003oooooogl000P0oooo00<0X23`0?ooo`3oool0203oool0
0`2P8?00oooo0?ooo`0D0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0=P3oool0
0onP8?00oooo0?ooo`0k0?ooo`03oj0Pl03oool0oooo0080oooo00GoX23`0?ooo`3oool0oooo0?mo
00020?ooo`;oX23`0`3oool01?nP8?00ogl00?oooonP8?060?ooo`03oj0Pl03oool0oooo0200oooo
00<000000?ooo`3oool0203oool000T0oooo00?o00000:0Pl02P8?00E@3oool00`2P8?00oooo0:0P
l00E0?ooo`050:0Pl03oool0oooo0?ooo`2P8?001@3oool00oooO`00oooo0:0Pl0030?ooo`80X23`
00H0oooooomo003oool0oooo0:0Pl03oool20:0Pl0050?ooo`2P8?00X23`0?ooo`2P8?003P3oool0
0`2P8?00oooo0?ooo`0E0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool0
1OnP8?00oooo0?ooo`3oooooX23`04<0oooo0_nP8?040?ooo`03oj0Pl03oool0oooo00H0oooo00Co
X23`0?ooo`3oool0oooo0_nP8?000`3oooooX23`0?mo00030?ooo`;oX23`1`3oool00onP8?00oooo
0?ooo`0P0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06l0oooo00<0
X23`0?ooo`3oool00`3oool01@3oO`00X23`0?ooo`2P8?3oogl000<0oooo00<0X23`0?ooo`3oool0
0`3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo02L0oooo00?o00000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1n0?ooo`07oj0Pl03oooooX23`0?oooonP8?3oogl00?ooo`02oj0P
l2/0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0F03oool00`2P8?00
oooo0?ooo`0O0?ooo`03oomo002P8?00oooo00<0oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00
oooo0?ooo`040?ooo`030:0Pl03oool0oooo00L0oooo00?oogl00?ooo`3oool0603oool00ol00000
oooo0?ooo`0?0?ooo`030000003oool0oooo06h0oooo00?oX23`0?ooo`3oool03@3oool01?ooO`00
oooo0?ooo`3oool2oj0Pl080oooo00?oX23`0?oooonP8?00:@3oool00`000000oooo0?ooo`080?oo
o`002@3oool00`2P8?00oooo0?ooo`0o0?ooo`030:0Pl03oool0oooo01L0oooo00<0X23`0?ooo`3o
ool0503oool00oooO`00oooo0:0Pl0020?ooo`;oogl000@0oooooomo002P8?00X23`0P3oool00`2P
8?00oooooomo00030?ooo`030:0Pl03oool0oooo00T0oooo00@0X23`0?ooo`3oooooogl07`3oool0
0ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo00?oX23`0?ooo`3oool0>P3oool0
0onP8?00oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo00H0oooo0P3oO`030?ooo`09oj0Pl?ooO`3o
X23`oj0Pl03oooooX23`0?mo003oooooX23`02P0oooo00<000000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0N03oool00oooO`00oooo0?ooo`030?ooo`030:0Pl03oool0oooo0080oooo
00Coogl00:0Pl03oooooogl00P2P8?0I0?ooo`03oomo003oool0oooo00d0oooo00?o00000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1l0?ooo`03oomo003oO`00oooo00D0oooo00CoX23`0?oooooo
O`00ogl00_nP8?0X0?ooo`030000003oool0oooo00P0oooo00090?ooo`030:0Pl03oool0oooo05d0
oooo00<0X23`0?ooo`3oool05@3oool00`2P8?00oooo0?ooo`020?ooo`050?mo0?ooO`00X23`0?oo
ooooO`000`3oool00`2P8?00oooo0?ooo`030?ooo`03oomo003oooooogl00080oooo00@0X23`oomo
003oooooogl00`3oool00oooO`00oooo0?ooo`0K0?ooo`03o`00003oool0oooo00l0oooo00<00000
0?ooo`3oool0;`3oool00onP8?00oooo0?ooo`120?ooo`03oj0Pl03oool0oooo00T0oooo00[oogl0
oj0Pl?nP8?00ogl00?oooonP8?3oogl00?mo0?ooO`3oX23`0P3oool00`3oO`00oooo0?ooo`0S0?oo
o`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07X0oooo00D0ogl00:0Pl?oo
O`00oooo0:0Pl0020?ooo`030:0Pl03oool0oooo00d0oooo00?oogl00?ooo`3oool07P3oool00ol0
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0840oooo00X0ogl00?oooonP8?3oogl00?mo0?oo
O`00oooooomo003oooooX23`9`3oool00`000000oooo0?ooo`080?ooo`002@3oool01_l00000oooo
0:0Pl02P8?00oooo0:0Pl6l0oooo00<0X23`0?ooo`3oool00P3oool0102P8?00oooo0?ooooooO`05
0?ooo`;oogl04@3oool00oooO`00X23`0?ooo`0L0?ooo`03o`00003oool0oooo00l0oooo00<00000
0?ooo`3oool09`3oool00onP8?00oooo0?ooo`0;0?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`
0?ooo`3oool0A03oool00onP8?00ogl0oj0Pl0020?ooo`04oomo003oool0oooo0?mo00@0oooo00?o
X23`0?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1A
0?ooo`030:0Pl03oool0oooo0240oooo00<0X23`0?ooo`3oool0103oool0102P8?00oooooomo0?oo
O`030?ooo`040:0Pl03oool0oooo0:0Pl080oooo00D0X23`0?ooooooO`00oooooomo00040?ooo`03
oomo003oool0oooo0080oooo00<0ogl00?ooooooO`001P3oool00oooO`00oooo0?ooo`050?ooo`03
oomo003oool0oooo00L0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`1b0?ooo`03
oj0Pl03oool0oooo00d0oooo0onP8?001_ooO`00oooooomo0?nP8?3oogl00?mo0080oooo00@0ogl0
0?ooo`3oO`00ogl00`3oool00oooO`00oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0X23`07T0oooo00?oogl00?ooo`3oool01@3oool01@2P8?3oogl00?ooo`3o
ool0X23`00<0oooo00<0X23`0?ooo`3oool09P3oool00ol00000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02L0oooo00?oX23`0?ooo`3oool0FP3oool00`3oO`00oooo0?ooo`02oj0Pl2T0oooo00<0
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`2P8?00>P3oool00`2P8?00oooo0?ooo`0g
0?ooo`80X23`0`3oool0102P8?00oooo0?ooo`2P8?060?ooo`030:0Pl03oooooogl000H0oooo00<0
X23`0?ooo`3oool02P3oool01?ooO`00oooo0?ooo`3oool2oomo01<0oooo00?o00000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0/0?ooo`03oj0Pl03oool0oooo0300oooo00?oX23`0?ooo`3oool0
803oool02?nP8?3oogl00?ooo`3oooooX23`0?oooonP8?00oooo0onP8?020?mo02<0oooo00<00000
0?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0JP3oool00`2P8?00oooo0?ooo`0?0?oo
o`040:0Pl03oool0oooo0:0Pl080oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`05
0?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooooooO`004@3oool00oooO`00oooo0?ooo`07
0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool09P3oool00onP8?00oooo0?ooo`07
0?ooo`03oj0Pl03oool0oooo04h0oooo00CoX23`0?ooo`3oooooX23`103oool00onP8?00oooooomo
00020?ooo`050?mo003oool0oooo0?ooo`3oO`007`3oool00`000000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`1X0?ooo`030:0Pl03oool0oooo00@0oooo00@0X23`0?ooo`3oool0X23`
3P3oool01P3oO`00oooooomo003oool0X23`oomo00<0oooo0_ooO`020?ooo`05oomo003oool0oooo
oomo002P8?00103oool00oooO`00oooo0?ooo`040?ooo`03oomo003oool0oooo0140oooo00?o0000
0?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`03oj0Pl03oool0oooo00H0oooo00GoX23`
0?ooo`3oool0oooooj0Pl0030?ooo`03oj0Pl03oooooogl000;oogl00P3oool01OnP8?00ogl00?oo
o`3oool0ogl001/0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0L`3o
ool00`3oO`00oooo0?ooo`060?ooo`030:0Pl03oool0oooo00<0oooo0_ooO`000`3oool0X23`oomo
00030?ooo`03oomo003oool0oooo00L0oooo0oooO`00103oooooogl00?ooooooO`0G0?ooo`03o`00
003oool0oooo00l0oooo00<000000?ooo`3oool0Q03oool01oooO`00oooo0?ooooooO`3oX23`0?oo
oonP8?000P3oool00oooO`00ogl00?mo00020?ooo`030?mo003oool0oooo01d0oooo00<000000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0K@3oool0102P8?00oooo0?ooo`2P8?0>0?oo
o`040:0Pl03oool0oooo0:0Pl0<0oooo00<0X23`0?ooo`3oool00`3oool00oooO`00oooo0?ooo`05
0?ooo`030:0Pl03oool0oooo01/0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`23
0?ooo`;oX23`103oool2oj0Pl080oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`0L
0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06h0oooo00<0X23`0?oo
o`3oool01P3oool00`2P8?00oooo0?ooo`020?ooo`060:0Pl03oooooogl00:0Pl03oooooogl00`3o
ool20:0Pl0060?ooooooO`00oooo0?ooooooO`00oooo0_ooO`040?ooo`07oomo002P8?00oooooomo
003oooooogl00:0Pl0020?ooo`03oomo003oool0oooo00@0oooo00<0X23`0?ooo`3oool0303oool0
0ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo0840oooo00?oX23`0?ooo`3oool00P3oool3
oj0Pl0060?ooooooO`00oooooomo0?nP8?00ogl00_ooO`020?ooo`05oj0Pl03oO`00oooooj0Pl03o
O`001P3oool00onP8?00oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00090?ooo`04o`00
003oool0oooo0:0Pl6X0oooo00<0X23`0?ooo`3oool03@3oool00`2P8?00oooo0?ooo`070?ooo`05
oomo003oool0oooooomo003oool00_ooO`030?ooo`030:0Pl03oool0oooo00@0oooo00?oogl00?oo
o`3oool01@3oool00oooO`00oooo0?ooo`0A0?ooo`03o`00003oool0oooo00l0oooo00<000000?oo
o`3oool0;03oool00onP8?00oooo0?ooo`1B0?ooo`03oj0Pl03oool0oooo00T0oooo00CoX23`0?oo
ooooO`3oX23`0P3oO`020?ooo`030?mo003oool0oooo01X0oooo00<000000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool0N03oool20:0Pl004oomo003oool0oooo0?ooo`;oogl000D0X23`
oomo003oool0oooooomo00020?ooo`D0X23`0_ooO`020:0Pl0040?ooooooO`3oogl0oomo00<0oooo
0_ooO`020?ooo`;oogl05@3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo08H0oooo
00[oX23`0?oooonP8?3oogl0oj0Pl03oooooX23`0?mo0?nP8?3oogl00onP8?020?ooo`030?mo003o
ool0oooo01X0oooo00<000000?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0O03oool0
0`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo00H0oooo00@0X23`0?ooo`2P8?3oogl00P3o
ool01OooO`00oooo0?ooo`3oooooogl00080oooo0oooO`0H0?ooo`03o`00003oool0oooo00l0oooo
00<000000?ooo`3oool0>P3oool00onP8?00oooo0?ooo`1<0?ooo`06oj0Pl03oooooX23`0?oooonP
8?00oooo0_nP8?001?ooO`3oX23`oomo003oO`020?ooo`030?mo003oool0oooo01P0oooo00<00000
0?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0M`3oool00`2P8?00oooo0?ooo`020:0P
l0`0oooo00P0X23`0?ooo`3oooooogl00?ooo`2P8?3oogl00?ooo`;oogl00`3oool3oomo00H0oooo
00?oogl00?ooo`3oool04@3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo
00?oX23`0?ooo`3oool0B`3oool3oj0Pl0@0oooo00GoX23`0?ooo`3oO`3oX23`oomo00020?mo0003
0?ooo`3oO`00oooo01T0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`2P8?00
MP3oool00`2P8?00oooo0?ooo`020?ooo`090:0Pl03oool0oooo0?ooo`2P8?00oooo0:0Pl03oool0
X23`00@0oooo0P2P8?00103oO`00oooo0:0Pl02P8?03oomo000;0?ooooooO`3oogl00?ooooooO`00
oooooomo003oooooogl00?ooo`3oO`005P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0
oooo0300oooo00?oX23`0?ooo`3oool0E@3oool2oj0Pl080oooo00GoX23`0?oooonP8?3oX23`0?oo
o`020?mo00;oX23`0P3oO`000`3oool0ogl00?ooo`020?ooo`03oomo003oool0oooo01<0oooo00<0
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0O@3oool00`2P8?00oooo0?ooo`02
0:0Pl0H0oooo00D0X23`0?ooo`2P8?00oooooomo00020:0Pl080oooo00Coogl00?ooooooO`00oooo
0_ooO`030?ooo`040:0Pl?ooO`00oooooomo00@0oooo00?oogl00?ooo`3oool03@3oool00ol00000
oooo0?ooo`0?0?ooo`030000003oool0oooo08/0oooo0_nP8?030?ooo`03oj0Pl03oooooX23`00;o
X23`0`3oO`020?ooo`80ogl000?oX23`0?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`1G0?ooo`030:0Pl03oool0oooo01l0oooo00<0X23`0?ooo`3oool0
0P3oool20:0Pl0<0oooo00@0X23`0?ooo`2P8?00oooo0P2P8?00203oooooogl00:0Pl02P8?00ogl0
0:0Pl?ooO`00X23`0_ooO`000`3oO`3oogl0oomo0002oomo00030?ooooooO`3oogl00080oooo00?o
ogl00?ooo`3oool04P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo07l0oooo00?o
X23`0?ooo`3oool0203oool00onP8?00oooo0?ooo`08oj0Pl0;oogl000?oX23`0?mo003oO`00603o
ool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1j0?ooo`030:0Pl03oool0
oooo00<0oooo0P2P8?060?ooo`;oogl000<0X23`0?ooo`2P8?000P3oool00oooO`00oooooomo0004
oomo00<0oooo00?oogl00?ooo`3oool05P3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0
oooo08d0oooo00CoX23`0?ooo`3oool0oooo0_nP8?00103oooooX23`0?ooooooO`030?mo01P0oooo
00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0?P3oool00`2P8?00oooo0?oo
o`0a0?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool02@3oool01@2P8?00oooo0?oo
o`3oool0X23`00D0oooo00?oogl00?ooo`3oool00oooO`002`3oooooogl0oomo003oooooogl00?oo
ooooO`00oooooomo003oooooogl001@0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?oo
o`1X0?ooo`03oj0Pl03oool0oooo01d0oooo0_nP8?050?ooo`03oj0Pl03oool0oooo00;oX23`00<0
oooooj0Pl03oO`000`3oO`000`3oool0ogl00?mo000E0?ooo`030000003oool0oooo00P0oooo0009
0?ooo`030:0Pl03oool0oooo07h0oooo00<0X23`0?ooo`3oool00P3oool20:0Pl0030?ooo`2P8?00
X23`00D0oooo0P2P8?020?ooo`[oogl05`3oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0
oooo03h0oooo00?oX23`0?ooo`3oool0C`3oool01onP8?00oooooj0Pl03oO`3oX23`0?oooonP8?00
0P3oO`000oooO`00ogl00?mo000F0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo07d0oooo00<0X23`0?ooo`3oool00`3oool01P2P8?3oogl00?ooo`2P8?00oooo0:0Pl0X0
oooo0oooO`020?ooo`;oogl0103oool00oooO`00oooo0?ooo`0A0?ooo`03o`00003oool0oooo00l0
oooo00<000000?ooo`3oool0S@3oool00onP8?00oooo0?ooo`020?ooo`?oX23`0P3oool0103oO`3o
ogl0oomo0?ooO`020?ooo`030?mo003oool0oooo0180oooo00<000000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool09`3oool00`2P8?00oooo0?ooo`1I0?ooo`80X23`00<0oooo0:0Pl02P
8?000P2P8?0:0?ooo`;oogl000D0oooo0:0Pl?ooO`3oogl00?ooo`05oomo00030?ooooooO`00oooo
00l0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`1S0?ooo`03oj0Pl03oool0oooo
02d0oooo0_nP8?00103oooooX23`oj0Pl03oool20?mo0004oj0Pl03oO`00ogl00?mo01<0oooo00<0
00000?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0P`3oool00`2P8?00oooo0?ooo`02
0?ooo`<0X23`403oool01?ooO`00oooo0?ooooooO`0C0?ooo`03o`00003oool0oooo00l0oooo00<0
00000?ooo`3oool0@@3oool00onP8?00oooo0?ooo`1B0?ooo`?oX23`0P3oool30?mo01@0oooo00<0
00000?ooo`3oool0203oool000T0oooo00<0X23`0?ooo`3oool0:@3oool00`2P8?00oooo0?ooo`1B
0?ooo`030:0Pl03oool0oooo0080oooo00H0X23`0?ooo`3oool0X23`0?ooo`2P8?080?ooo`040:0P
l03oool0oooo0:0Pl080oooo00H0X23`0?ooooooO`00X23`oomo003oool3oomo0180oooo00?o0000
0?ooo`3oool03`3oool00`000000oooo0?ooo`100?ooo`03oj0Pl03oool0oooo02l0oooo00?oX23`
0?ooo`3oool07@3oool01?nP8?00oooo0?ooo`3oool3oj0Pl080oooo00GoX23`0?mo003oooooX23`
0?mo000B0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08L0oooo00<0
X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`050?ooo`030:0Pl03oool0oooo00<0oooo00?o
ogl00?ooo`3oool01`3oool00oooO`00oooo0?ooo`0;0?ooo`03o`00003oool0oooo00l0oooo00<0
00000?ooo`3oool0U`3oool01OnP8?00oooooj0Pl03oooooX23`0080oooo00<0ogl0oomo003oO`00
4@3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`240?ooo`030:0Pl03o
ool0oooo00D0oooo00<0X23`0?ooo`2P8?008`3oool00ol00000oooo0?ooo`0?0?ooo`030000003o
ool0oooo09@0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooooj0Pl00F0?ooo`030000003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0200oooo00<0X23`0?ooo`3oool0@03oool0
0`2P8?00oooo0?ooo`090?ooo`030:0Pl03oool0oooo01X0oooo00D0X23`0?ooo`3oool0oooooomo
00040?ooo`040:0Pl03oool0oooo0:0Pl080oooo00H0X23`0?ooooooO`00oooo0:0Pl?ooO`0A0?oo
o`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0K@3oool00onP8?00oooo0?ooo`0K0?oo
o`04oj0Pl03oool0oooooj0Pl0`0oooo00?oX23`0?ooo`3oool00onP8?0A0?ooo`030000003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo01P0oooo00<0X23`0?ooo`3oool0?03oool00`2P
8?00oooo0?ooo`0f0?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool06P3oool00ol0
0000oooo0?ooo`0?0?ooo`030000003oool0oooo04/0oooo00?oX23`0?ooo`3oool0<@3oool00onP
8?00oooo0?ooo`0J0?ooo`03oj0Pl03oool0oooo01<0oooo00<000000?ooo`3oool0203oool000T0
oooo00<0X23`0?ooo`3oool0OP3oool00`2P8?00oooo0?ooo`0H0?ooo`070:0Pl03oool0oooo0?oo
o`3oO`00oooooomo000B0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0A@3oool0
0onP8?00oooo0?ooo`1?0?ooo`03oj0Pl03oool0oooo00T0oooo00?oX23`oomo003oool0303oool0
0`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1[0?ooo`030:0Pl03oool0oooo
02d0oooo0P3oO`0E0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0S`3oool00onP
8?00oooo0?ooo`0<0?ooo`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0g0?ooo`030:0Pl03oool0oooo06@0
oooo0`2P8?0A0?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0LP3oool00onP8?00
oooo0?ooo`0^0?ooo`03oj0Pl03oooooX23`00`0oooo00<000000?ooo`3oool0203oool000T0oooo
0P2P8?040?ooo`030:0Pl03oool0oooo02l0oooo00<0X23`0?ooo`3oool0G`3oool00oooO`00oooo
0?ooo`060?ooo`050:0Pl03oool0X23`oomo003oO`003@3oool00ol00000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04P0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`090?ooo`03
oj0Pl03oool0oooo0240oooo00?oX23`0?ooo`3oool0803oool02?ooO`00oooo0?oooonP8?00oooo
oj0Pl03oooooogl02P3oool00`000000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0`
0?ooo`030:0Pl03oool0oooo06h0oooo00<0X23`0?mo003oool03P3oool00ol00000oooo0?ooo`0?
0?ooo`030000003oool0oooo07h0oooo00?oX23`0?ooo`3oool09P3oool00onP8?3oogl00?ooo`08
0?ooo`030000003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0080oooo00<0X23`0?oo
o`3oool0<`3oool00`2P8?00oooo0?ooo`1G0?ooo`030:0Pl03oool0oooo00H0oooo00<0X23`0?oo
o`3oool0503oool00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo0600oooo00?oX23`0?oo
o`3oool08@3oool00onP8?00oooo0?ooo`0K0?ooo`;oX23`3P3oool00`000000oooo0?ooo`080?oo
o`002@3oool00`2P8?00oooo0?ooo`070?ooo`030:0Pl03oool0oooo08h0oooo00<0X23`0?ooo`3o
ool01`3oool20?mo00030?ooooooO`00oooo00P0oooo00@0ogl00?ooooooO`3o00004@3oool00`00
0000oooo0?ooo`180?ooo`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3oool0BP3oool01Ooo
O`00oooo0?ooo`3oooooX23`00<0oooo0oooO`080?ooo`03oomo00000000oooo00T0oooo00090?oo
o`03o`00003oool0oooo0:D0oooo00@0X23`0?ooooooO`3oogl02@3oool00ol00000oooo0?ooo`0?
0?ooo`030000003oool0oooo0:H0oooo00Coogl00?oooonP8?3oogl0203oool00`000000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`020?ooo`030:0Pl03oool0oooo09l0oooo0P2P8?00
0`3oool0X23`0?mo00090?ooo`03o`00003oool0oooo00l0oooo00<000000?ooo`3oool0G`3oool0
0onP8?00oooo0?ooo`160?ooo`05oj0Pl?ooO`3oX23`0?oooonP8?001@3oool00`000000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00<00000
0?ooo`3oool0/P3oool00`000000oooo0?ooo`080?ooo`002@3oool01?l00000X23`0?ooo`2P8?1a
0?ooo`030:0Pl03oool0oooo03d0oooo00?o00000?ooo`3oool03`3oool00`000000oooo0?ooo`1>
0?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?ooo`3oool0?03oool00onP8?00oooo0?ooo`0L
0?ooo`030000003oool0oooo00P0oooo00090?ooo`05o`00003oool0oooo0?ooo`2P8?00G@3oool0
0`2P8?00oooo0?ooo`170?ooo`040:0Pl03oool0oooo0:0Pl0D0oooo00?o00000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1E0?ooo`03oj0Pl03oool0oooo04<0oooo00?oX23`0?ooo`3oool03P3o
ool2oj0Pl0@0oooo00<000000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0P`3oool0
0`2P8?00oooo0:0Pl00U0?ooo`080?mo003oool0oooo0?ooo`3oO`00oooo0:0Pl?l0000A0?ooo`03
0000003oool0oooo09h0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`070?ooo`06
oomo003oool0oooooomo0?nP8?0000002P3oool000T0oooo00?o00000?ooo`3oool0A@3oool00`2P
8?00oooo0?ooo`1V0?ooo`050:0Pl03oool0X23`0:0Pl?l000004@3oool00`000000oooo0?ooo`2D
0?ooo`03oj0Pl03oool0oooo01P0oooo0onP8?000`000000oooo0?ooo`080?ooo`002@3oool5o`00
0080X23`00?o00000:0Pl?l00000Z?l00000102P8?3o00000?mo0?l0000A0?ooofL0000000?oX23`
0000000000000P0000000onP8?0000000000000900000003oj0Pl0000000000003P0000000?oX23`
oomo000000002P3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00880oooo0_l0003o0?ooo`d0oooo
001o0?ooo`?o000000<0ooooo`00003oool0o`3oool<0?ooo`00O@3oool2o`0000@0oooo0_l0003o
0?ooo``0oooo001k0?ooo`;o00001P3oool00ol00000ooooo`00003o0?ooo`/0oooo001h0?ooo`?o
0000203oool00ol00000ooooo`00003o0?ooo`/0oooo001f0?ooo`;o00002`3oool01?l00000oooo
0?ooool0003o0?ooo`X0oooo001c0?ooo`?o00003@3oool01?l00000oooo0?ooool0003o0?ooo`X0
oooo001a0?ooo`;o0000403oool01Ol00000oooo0?ooo`3ooooo00000?l0oooo2@3oool006l0oooo
0_l0000B0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool0A@3ooonfo`0000X0oooo
001/0?ooo`?o0000503oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo04D0oooo00?o
ogl00?ooo`3oool00P3oool01OooO`00oooooomo0?ooO`00oooo00;oogl00`3oool01?ooO`00oooo
oomo003oool4oomo00040?ooooooO`3oogl00?ooo`Soogl000<0oooooomo0?ooO`000oooO`000`3o
ooooogl0oomo0004oomo00030?ooooooO`3oogl000;oogl000<0oooooomo0?ooO`003_ooO`000`3o
ooooogl0oomo0002oj0Pl0Koogl00_nP8?04oomo00050?oooonP8?3oogl0oj0Pl?ooO`000_nP8?00
0oooO`3oX23`oj0Pl002oomo00;oX23`00?oogl0oj0Pl?ooO`000_nP8?00103oooooX23`0?oooooo
O`02oj0Pl0<0oooo00?oX23`0?oooonP8?000_nP8?0m0?ooo`03o`00003oool0oooo00P0oooo001Z
0?ooo`;o0000603oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo04@0oooo00?o0000
0?ooo`3oool01P3oool01OooO`00oooo0?ooo`3oooooogl000<0oooo00?oogl00?ooo`3oool01P3o
ool01OooO`00oooo0?ooo`3oooooogl000<0oooo00?oogl00?ooo`3oool00_ooO`001P3oooooogl0
oomo0?ooO`00oooooomo00@0oooo0_ooO`020?ooo`03oomo003oool0oooo00D0oooo00?oogl00?oo
ooooO`002`3oool00oooO`00oooo0?ooo`03oomo00<0oooo0oooO`000onP8?3oogl00?ooo`09oomo
00030?ooooooO`00oooo0080oooo0_ooO`020?ooo`04oomo003oool0oooooomo0080oooo00Coogl0
oj0Pl03oooooX23`?`3oool00ol00000oooo0?ooo`080?ooo`00I`3oool3o`0001X0oooo00?o0000
0?ooo`3oool00P3oool00ol00000oooo0?ooo`140?ooo`03o`00003oool0oooo00<0oooo00?oogl0
0?ooo`3oool01`3oool00oooO`00oooo0?ooo`0?0?ooo`03oomo003oool0oooo00@0oooo00?oogl0
0?ooo`3oool00P3oool2oomo00030?ooooooO`3oogl000;oogl02@3oool00oooO`00oooo0?ooo`04
0?ooo`04oomo003oool0oooo0?ooo`;oogl00P3oool00onP8?00oooooomo00050?ooo`03oomo0?nP
8?00oooo00<0oooo0oooO`000`3oooooogl0oomo0002oomo00030?ooooooO`3oogl00080oooo00Co
ogl00?ooooooO`3oogl00P3oool00oooO`00oooooomo00020?ooo`03oomo003oooooX23`00?oX23`
00D0oooooomo0?ooO`00oooooomo000g0?ooo`03o`00003oool0oooo00P0oooo001U0?ooo`;o0000
7@3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo04<0oooo00?o00000?ooo`3oool0
0P3oool00oooO`00oooo0?ooo`090?ooo`04oomo003oool0oooooomo00H0oooo00?oogl00?ooo`3o
ool02@3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo0080oooo0oooO`040?ooo`03
oomo003oool0oooo00D0oooo00?oogl00?ooo`3oool01`3oool00oooO`00oooooj0Pl0040?ooo`03
oomo003oool0oooo0080oooo00Coogl0oj0Pl?nP8?00oooo0oooO`000`3oooooX23`oomo00020?oo
o`05oj0Pl?ooO`3oX23`oj0Pl?ooO`000P3oool01?nP8?3oogl0oomo0?nP8?05oomo00;oX23`00@0
oooooomo003oool0oooo0_nP8?000oooO`00oooooj0Pl0020?ooo`?oX23`<`3oool00ol00000oooo
0?ooo`080?ooo`00HP3oool3o`0001l0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`120?ooo`03o`00003oool0oooo0300oooo00?oogl00?ooo`3oool0203oool00onP8?00oooo0?oo
o`0<0?ooo`03oj0Pl03oool0oooo00D0oooo00?oogl00?ooo`3oool00_ooO`020?ooo`06oj0Pl03o
ool0oooooomo003oooooogl00`3oool01onP8?00oooooomo003oooooogl00?oooonP8?000_ooO`00
1`3oooooogl00?ooooooO`00oooooomo003oool00_ooO`030?ooo`08oj0Pl?ooO`00oooooj0Pl03o
ooooX23`0?oooonP8?020?ooo`03oj0Pl03oool0oooo02h0oooo00?o00000?ooo`3oool0203oool0
0600oooo0_l0000R0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0@P3oool00onP
8?00oooo0?ooo`050?ooo`03oomo003oool0oooo00P0oooo00?oogl00?ooo`3oool01`3oool00ooo
O`00oooo0?ooo`0<0?ooo`03oj0Pl03oool0oooo00P0oooo00Googl00?ooo`3oool0oooooomo0004
0?ooo`04oj0Pl03oool0oooo0?ooo`Coogl000<0oooooj0Pl03oool00`3oool01?nP8?00oooo0?oo
ooooO`020?ooo`03oomo003oooooX23`00<0oooo00OoX23`oomo003oooooX23`0?oooonP8?3oogl0
00<0oooo00CoX23`oomo003oooooogl00_nP8?000`3oooooogl00?ooo`020?ooo`Coogl000CoX23`
oomo0?ooO`00oooo0oooO`000onP8?3oogl0oj0Pl005oj0Pl0?oogl00`3oool00oooO`00oooo0?oo
o`0Z0?ooo`03o`00003oool0oooo00P0oooo001N0?ooo`;o0000903oool00ol00000oooo0?ooo`05
0?ooo`03o`00003oool0oooo0440oooo00?o00000?ooo`3oool0903oool00onP8?00oooo0?ooo`02
0?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`0=
0?ooo`;oX23`1@3oool00oooO`00oooo0?ooo`050?ooo`03oomo003oool0oooo00D0oooo00Woogl0
0?ooo`3oool0oooooomo003oooooX23`0?oooonP8?000P3oool02?nP8?00oooo0?oooonP8?00oooo
oomo003oooooogl00P3oool3oomo00070?ooooooO`00oooooomo003oooooogl00?ooo`04oj0Pl003
0?ooooooO`3oogl000<0oooo00?oogl00?ooo`3oool0;03oool00ol00000oooo0?ooo`080?ooo`00
F`3oool3o`0002H0oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?ooo`100?ooo`03o`00
003oool0oooo0140oooo00?oogl00?ooo`3oool02`3oool01OooO`00oooo0?ooo`3oooooogl001D0
oooo00?oogl0oj0Pl03oool04P3oool00onP8?00oooooomo00040?ooo`04oomo003oooooogl0oj0P
l0<0oooo00?oX23`0?ooo`3oool00P3oool00oooO`3oX23`0?ooo`050?ooo`;oogl000?oX23`0?oo
o`3oool01@3oool01oooO`00oooooomo003oooooogl00?ooooooO`000P3oool01?ooO`3oX23`0?oo
oonP8?02oomo0080oooo00?oX23`0?oooonP8?00:`3oool00ol00000oooo0?ooo`080?ooo`00F@3o
ool2o`0001D0oooo00?oogl00?ooo`3oool04@3oool00ol00000oooo0?ooo`060?ooo`03o`00003o
ool0oooo0400oooo00?oX23`0?ooo`3oool0603oool00onP8?00oooo0?ooo`0<0?ooo`03oomo003o
ool0oooo0100oooo00KoX23`0?oooonP8?00oooooomo0?nP8?050?ooo`;oogl000<0oooooj0Pl03o
ool0103oool00oooO`00oooo0?ooo`060?ooo`03oomo003oool0oooo00L0oooo00?oX23`0?oooonP
8?000`3oool01?ooO`00oooo0?ooooooO`020?ooo`;oogl000@0oooooj0Pl03oooooX23`0P3oool0
1onP8?00oooooomo0?nP8?3oogl0oj0Pl?ooO`001?nP8?000oooO`00oooooomo0005oomo00030?oo
ooooO`3oX23`0080oooo0_ooO`0S0?ooo`03o`00003oool0oooo00P0oooo001F0?ooo`?o00001`3o
ool00oooO`00oooooj0Pl0060?ooo`05oomo003oool0oooooomo003oool00_ooO`000`3oooooogl0
0?ooo`0A0?ooo`03o`00003oool0oooo00L0oooo00?o00000?ooo`3oool0?`3oool2oj0Pl0d0oooo
00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`0V0?ooo`03oomo003oool0oooo00P0oooo
00?oogl00?ooo`3oool00`3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo00/0oooo
00WoX23`0?ooo`3oooooX23`0?oooonP8?3oogl00?ooooooO`001@3oool00oooO`3oX23`0?ooo`03
0?ooo`;oogl000<0oooooj0Pl?nP8?000`3oool01OooO`00oooooomo0?nP8?3oogl00080oooo00Go
ogl00?ooo`3oool0oooooomo00040?ooo`04oomo003oool0oooooomo0280oooo00?o00000?ooo`3o
ool0203oool005@0oooo0_l000050?ooo`05oj0Pl03oool0oooooomo003oool00_nP8?001?ooO`3o
X23`oj0Pl?nP8?020?ooo`?oogl000D0oooooomo0?ooO`3oogl0oj0Pl0030?ooo`03oomo003oool0
oooo00h0oooo00?o00000?ooo`3oool01`3oool00ol00000oooo0?ooo`0o0?ooo`03oj0Pl03oool0
oooo00D0oooo00?oX23`0?ooo`3oool01P3oool01?ooO`00oooo0?ooooooO`0<0?ooo`03oomo003o
ool0oooo01X0oooo00?oogl00?ooo`3oool01P3oool00oooO`00oooo0?ooo`020?ooo`03oj0Pl03o
ooooogl00080oooo00KoX23`0?ooo`3oooooogl00?ooooooO`020?ooo`;oogl000GoX23`0?oooonP
8?3oX23`oomo00030?ooo`;oogl000@0oooooomo003oooooogl00P3oool00onP8?00oooo0?ooo`02
oomo0080oooo0_ooO`000`3oooooogl00?ooo`03oj0Pl080oooo0_ooO`030?ooo`03oomo003oool0
oooo00Coogl000<0oooooj0Pl?ooO`000_nP8?02oomo00030?oooonP8?00oooo0080oooo00?oogl0
0?ooo`3oool07P3oool00ol00000oooo0?ooo`080?ooo`00DP3oool2o`000080oooo00Koogl00?oo
o`3oool0oooooj0Pl?ooO`02oj0Pl0?oogl000@0oooooomo0?ooO`00oooo1?ooO`001?nP8?3oogl0
0?ooooooO`040?ooo`03oomo003oool0oooo00;oogl03P3oool00ol00000oooo0?ooo`080?ooo`03
o`00003oool0oooo03h0oooo00?oX23`0?ooo`3oool0=@3oool00onP8?00oooooj0Pl0040?ooo`03
oomo003oool0oooo0080oooo00CoX23`0?ooo`3oooooogl0103oool01?ooO`00oooooomo0?ooO`08
0?ooo`04oomo003oooooX23`oomo00<0oooo00CoX23`0?ooo`3oooooX23`0`3oool02OnP8?00oooo
0?ooooooO`00oooooomo0?nP8?00oooooomo00080?ooo`04oj0Pl03oooooogl0oj0Pl0;oogl00P3o
ool00oooO`00oooooomo00040?ooo`04oj0Pl03oool0oooooomo00<0oooo00?oogl00?ooo`3oool0
0P3oool00onP8?00oooo0?ooo`0P0?ooo`03o`00003oool0oooo00P0oooo001?0?ooo`?o00001@3o
ool00onP8?00oooooomo0005oj0Pl0;oogl01?nP8?001`3oooooogl0oomo003oooooogl00?oooooo
O`001@3oool01OnP8?3oogl00?ooo`3oooooX23`00h0oooo00?o00000?ooo`3oool02@3oool00ol0
0000oooo0?ooo`0m0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0903oool00ooo
O`00oooo0?ooo`070?ooo`03oomo003oool0oooo0180oooo0_ooO`030?ooo`03oj0Pl03oool0oooo
00<0oooo0_ooO`030?ooo`07oj0Pl03oooooX23`0?oooonP8?00oooooj0Pl0020?ooo`;oogl00`3o
ool01OooO`00oooooomo003oooooX23`0080oooo00CoX23`0?ooo`3oooooogl00`3oool2oomo0080
oooo00Soogl00?ooo`3oool0oooooomo003oooooX23`oomo00P0oooo00?oogl00?oooonP8?000P3o
ool00oooO`00oooooomo00020?ooo`;oogl07P3oool00ol00000oooo0?ooo`080?ooo`00C@3oool2
o`0000;oogl000@0oooooomo0?ooO`00oooo0_nP8?04oomo00030?ooooooO`3oogl000;oX23`0ooo
O`03oj0Pl0;oogl01@3oool00onP8?3oogl00?ooo`030?ooo`03oomo003oool0oooo00h0oooo00?o
00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0m0?ooo`04o`000?nP8?00oooooj0Pl1@0oooo
00?oogl00?ooo`3oool0;P3oool00oooO`00oooo0?ooo`060?ooo`03oomo003oool0oooo00L0oooo
0_ooO`001`3oooooX23`0?ooo`3oooooogl00?oooonP8?003@3oool01OnP8?00oooo0?ooo`3ooooo
ogl000L0oooo00?oX23`0?ooo`3oool01@3oool01OooO`00oooo0?ooo`3oooooogl000T0oooo00Co
ogl00?ooo`3oooooogl07@3oool00ol00000oooo0?ooo`080?ooo`00BP3oool3o`0000Ooogl000@0
oooooomo0?nP8?3oX23`0_ooO`002OnP8?3oogl0oomo003oooooogl0oj0Pl?ooO`3oX23`0?ooo`04
oomo00030?ooooooO`3oogl000H0oooo00?oogl00?ooo`3oool00_ooO`0;0?ooo`05oomo003oool0
oooo0?ooool00000303oool00ol00000oooo0?ooo`0l0?ooo`04o`00003oool0oooooj0Pl080oooo
00?oX23`0?ooo`3oool05@3oool00oooO`00oooo0?ooo`040?ooo`03oomo003oool0oooo0080oooo
00?oogl00?ooo`3oool03P3oool01OooO`00oooo0?ooo`3oooooogl000L0oooo00?oX23`0?ooo`3o
ool01`3oool00oooO`00oooo0?ooo`090?ooo`03oomo003oool0oooo00H0oooo00?oogl0oj0Pl03o
ool06`3oool00oooO`00oooo0?ooo`070?ooo`?oogl000D0oooooomo003oooooogl0oj0Pl0030?oo
o`03oomo003oool0oooo01T0oooo00?o00000?ooo`3oool0203oool004P0oooo0_l00007oomo0003
oj0Pl?ooO`3oX23`00;oX23`0_ooO`000`3oooooogl00?ooo`03oomo0003oj0Pl?ooO`3oogl000?o
X23`00?oogl0oj0Pl?ooO`000_ooO`001@3oooooogl0oomo003oooooogl00080oooo0_ooO`020?oo
o`03oomo003oool0oooo00@0oooo00Coogl00?ooo`3oooooogl01@3oool00ol00000oooo0?ooo`0:
0?ooo`03o`00003oool0oooo03`0oooo00?o0000oj0Pl03oool00_nP8?050?ooo`04oomo003ooooo
ogl0oomo01@0oooo00?oogl00?ooo`3oool05P3oool01OnP8?00oooo0?ooo`3oooooX23`00h0oooo
00Coogl00?ooo`3oooooogl00P3oool00onP8?3oogl00?ooo`080?ooo`;oogl0203oool00oooO`00
oooo0?ooo`020?ooo`03oomo003oool0oooo00@0oooo00?oogl00?ooo`3oool01@3oool00oooO`00
oooooomo00050?ooo`03oomo003oool0oooo00;oogl000@0oooooomo0?ooO`3oogl00P3oool00ooo
O`00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo01/0oooo00?o00000?ooo`3oool0203oool004H0
oooo0_l000000`3oooooogl0oomo0006oomo00?oX23`2OooO`001@3oooooogl0oomo0?ooO`3oX23`
00;oogl00_nP8?02oomo0003oj0Pl03oooooX23`00?oogl01`3oool00oooO`00oooo0?ooo`040?oo
o`03oomo003oool0oooo00D0oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`0k0?oo
o`03oj0Pl03oool0oooo00L0oooo00CoX23`0?ooo`3oooooX23`?@3oool00oooO`00oooo0?ooo`02
0?ooo`03oomo003oool0oooo00L0oooo00?oogl00?ooooooO`000P3oool2oomo00030?ooooooO`00
oooo01P0oooo00?oX23`0?ooo`3oool02@3oool00oooO`00oooo0?ooo`080?ooo`03oj0Pl03oool0
oooo01l0oooo00?o00000?ooo`3oool0203oool004<0oooo0ol00005oomo00?oX23`0_ooO`000onP
8?00oooooomo0002oomo00030?oooonP8?3oogl000;oogl000<0oooooomo0?ooO`000oooO`02oj0P
l005oomo003oool0oooooomo0?nP8?000`3oool01?ooO`3oX23`oj0Pl03oool2oomo00X0oooo0_oo
O`080?ooo`03o`00003oool0oooo00<0oooo00?oogl00?ooo`3oool01P3oool00ol00000oooo0?oo
o`0j0?ooo`04o`000?nP8?00oooooj0Pl1D0oooo00?oX23`0?ooooooO`002@3oool00oooO`00oooo
0?ooo`0>0?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool03@3oool01?nP8?00oooo
0?oooonP8?050?ooo`03oj0Pl03oooooogl003@0oooo00?oX23`0?ooo`3oool01P3oool00oooO`00
oooo0?ooo`060?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool03P3oool00ol00000
oooo0?ooo`080?ooo`00@@3oool2o`0000030?ooooooO`3oogl000Coogl000CoX23`oomo0?ooO`3o
X23`0_ooO`03oj0Pl00:oomo0?nP8?00oooooomo003oooooogl0oj0Pl03oooooX23`oomo0080oooo
00?oX23`oomo003oool00`3oool3oomo00@0oooo00Googl00?ooo`3oooooX23`oomo000<0?ooo`05
oomo003oooooogl00?ooooooO`000`3oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo
03X0oooo00?o00000?oooonP8?00AP3oool00oooO`00oooo0?ooo`040?ooo`05oj0Pl03oool0oooo
0?oooonP8?001@3oool01?nP8?00oooo0?ooooooO`040?ooo`03oomo003oool0oooo00H0oooo0_oo
O`030?ooo`06oomo003oool0oooooomo003oooooX23`?`3oool00ol00000oooo0?ooo`080?ooo`00
?P3oool3o`0000?oogl00_nP8?03oomo0005oj0Pl?ooO`3oogl0oomo0?nP8?001_ooO`001?nP8?00
oooooj0Pl03oool3oomo0080oooo00?oogl00?ooo`3oool00P3oool01OooO`00oooo0?ooo`3ooooo
ogl000@0oooo0_ooO`0F0?ooo`03oomo003ooooo000000h0oooo00?o00000?ooo`3oool0>@3oool0
1Ol0003oX23`0?ooo`3oooooX23`01H0oooo00?oogl00?ooo`3oool04@3oool00oooO`00oooo0?oo
o`0<0?ooo`03oj0Pl03oool0oooo01<0oooo00?oogl00?ooo`3oool0303oool00onP8?3oogl00?oo
o`080?ooo`03oj0Pl03oool0oooo01@0oooo00?oX23`0?ooo`3oool0203oool00oooO`00oooo0?oo
o`0:0?ooo`05oomo003oool0oooo0?ooooooO`004`3oool00ol00000oooo0?ooo`080?ooo`00?03o
ool2o`000008oomo003oooooogl0oomo003oooooX23`oomo0?nP8?07oomo000=0?oooonP8?3oogl0
oj0Pl03oooooX23`0?ooooooO`3oX23`0?oooonP8?3oogl00?ooo`03oomo0009oj0Pl03oool0oooo
oomo003oooooX23`0?oooonP8?3oogl00080oooo0_ooO`040?ooo`05oomo003oool0oooo0?oooooo
O`00303oool00oooO`00oooo0?ooo`030?ooo`03o`000?ooO`00oooo00`0oooo00?o00000?ooo`3o
ool0>@3oool2oj0Pl0040?oooonP8?00oooooj0Pl0D0oooo00Googl00?ooo`3oool0oooooomo0004
0?ooo`03oj0Pl03oool0oooo00@0oooo00?oogl00?ooo`3oool01`3oool00oooO`00oooo0?ooo`0@
0?ooo`03oj0Pl03oool0oooo00L0oooo00Ooogl00?ooo`3oool0oooooj0Pl03oooooX23`0080oooo
00?oogl00?oooonP8?000`3oool01OnP8?00oooo0?ooo`3oooooogl00080oooo00Googl00?ooo`3o
ool0oooooj0Pl0060?ooo`03oomo003oool0oooo00P0oooo00GoX23`0?ooooooO`00oooooj0Pl002
0?ooo`03oj0Pl03oool0oooo00X0oooo00?oogl00?ooo`3oool0103oool2oj0Pl1<0oooo00?oogl0
0?ooo`3oool01@3oool00oooO`00oooo0?ooo`0<0?ooo`03o`00003oool0oooo00P0oooo000j0?oo
o`;o00000_ooO`000`3oooooogl0oomo0002oomo00030?ooooooO`00oooo0080oooo00Koogl0oj0P
l?ooO`3oogl00?ooooooO`02oj0Pl003oomo003oooooX23`00?oX23`00L0oooooomo0?ooO`00oooo
oomo003oooooogl00080oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?ooo`0G0?ooo`03
o`00003oool0oooo00d0oooo00?o00000?ooo`3oool0>03oool00ol00000oooo0?ooo`0<0?ooo`03
oomo003oool0oooo0240oooo00CoX23`0?ooo`3oooooogl00`3oool00oooO`00oooooomo00070?oo
o`04oj0Pl03oool0oooooj0Pl0P0oooo00?oX23`0?ooo`3oool05@3oool01?nP8?00oooo0?oooonP
8?070?ooo`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool02`3oool00oooO`00oooo0?oo
o`0G0?ooo`03oomo003oool0oooo0140oooo00?o00000?ooo`3oool0203oool003L0oooo0ol00000
0`3oooooogl0oomo0004oomo0003oj0Pl?ooO`00oooo0080oooo00Koogl00?ooo`3oooooogl0oj0P
l03oool2oomo00@0oooo00?oX23`0?ooooooO`001?ooO`030?ooo`;oX23`00?oogl00?oooonP8?00
203oool01OnP8?00oooo0?ooo`3oooooX23`01L0oooo00?o00000?ooo`3oool00P3oool00oooO`00
oooo0?ooo`090?ooo`03o`00003oool0oooo03L0oooo0_nP8?000`3oooooX23`oj0Pl0040?ooo`03
oj0Pl03oool0oooo00l0oooo00?oogl00?ooo`3oool01P3oool00onP8?00oooo0?ooo`050?ooo`03
oomo003oool0oooo00H0oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`040?ooo`03
oj0Pl?ooO`00oooo00L0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`090?ooo`07
oj0Pl03oool0oooo0?oooonP8?00oooooj0Pl0020?ooo`03oj0Pl03oool0oooo00`0oooo00?oogl0
0?ooo`3oool03@3oool01?ooO`00oooo0?ooooooO`0K0?ooo`03oomo003oool0oooo00h0oooo00?o
00000?ooo`3oool0203oool003D0oooo0_l00009oomo0080oooo00?oogl00?oooonP8?000P3oool0
0oooO`00oooooomo00040?ooo`04oj0Pl03oooooX23`0?ooo`?oX23`00?oogl0oj0Pl?ooO`000_oo
O`030?ooo`03oomo003oool0oooo00;oogl02`3oool00oooO`00oooo0?ooo`0E0?ooo`06o`00003o
ool0oooooomo003oooooogl02`3oool00ol00000oooo0?ooo`0g0?ooo`03oj0Pl03oool0oooo03P0
oooo00?oX23`0?ooo`3oool0103oool01?nP8?00oooo0?ooo`3oool2oj0Pl140oooo00GoX23`0?oo
o`3oool0oooooj0Pl00B0?ooo`03oj0Pl03oool0oooo00@0oooo00?oogl00?ooo`3oool0>`3oool0
0ol00000oooo0?ooo`080?ooo`00<P3oool3o`0000Googl000<0oooooomo0?ooO`000P3oool00ooo
O`00oooo0?ooo`020?ooo`05oj0Pl03oool0oooo0?ooooooO`00103oool01onP8?00oooo0?ooo`3o
ooooogl00?oooonP8?000P3oool2oomo00030?oooonP8?3oX23`01D0oooo00Googl00?ooo`3oool0
oooooomo00080?ooo`03oomo003oool0oooo00D0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0f0?ooo`03o`00003oooooX23`00H0oooo00?oX23`0?ooo`3oool0<@3oool00onP8?00
oooo0?ooo`020?ooo`03oj0Pl03oool0oooo00T0oooo00?oX23`0?ooo`3oool0I03oool00ol00000
oooo0?ooo`080?ooo`00<03oool2o`000003oomo003oooooogl000?oogl00P3oool2oomo00030?oo
ooooO`00oooo00<0oooo0_ooO`020?ooo`05oomo003oool0oooo0?oooonP8?000P3oool00onP8?00
oooo0?ooo`040?ooo`;oogl01P3oool00onP8?00oooo0?ooo`060?ooo`05oomo003oool0oooo0?oo
oonP8?002`3oool00oooO`00oooo0?ooo`0;0?ooo`03oomo003ooooo000000<0oooo00?oogl00?oo
o`3oool0303oool00ol00000oooo0?ooo`0e0?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`0?oo
o`3oool03P3oool00oooO`00oooo0?ooo`0=0?ooo`;oX23`5P3oool00onP8?00oooo0?ooo`0:0?oo
o`03oj0Pl?ooO`00oooo00@0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`090?oo
o`03oomo0?nP8?3oX23`00h0oooo00?oogl00?ooo`3oool00P3oool00onP8?00oooo0?ooo`080?oo
o`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?ooo`0:0?oo
o`03oomo003oooooogl00080oooo00?oogl00?ooo`3oool02P3oool00ol00000oooo0?ooo`080?oo
o`00;@3oool3o`0000;oogl000@0oooooomo0?ooO`3oogl00P3oool2oomo0080oooo00?oogl00?oo
oonP8?000P3oool00oooO`00oooo0?ooo`02oj0Pl0H0oooo00?oX23`oomo0?ooO`000P3oool00onP
8?00oooo0?ooo`030?ooo`03oomo0?nP8?00oooo0080oooo00?oX23`0?ooo`3oool01@3oool00onP
8?00oooo0?ooo`020?ooo`04oomo003oool0oooooomo01P0oooo00?o00000?ooooooO`001@3oool0
0oooO`00oooo0?ooo`080?ooo`03o`00003oool0oooo03D0oooo00?oX23`0?ooo`3oool00P3oool0
0onP8?00oooo0?ooo`0c0?ooo`04oomo003oool0oooooomo01h0oooo00Googl00?ooo`3oool0oooo
oj0Pl0020?ooo`03oomo003oool0oooo02/0oooo00?oogl00?ooo`3oool0803oool00ol00000oooo
0?ooo`080?ooo`00:`3oool2o`0000Googl00P3oool00oooO`00oooooomo00040?ooo`;oogl00P3o
ool01OnP8?3oogl00?ooo`3oooooogl000@0oooo00CoX23`0?ooo`3oooooX23`103oool01_ooO`00
oooo0?oooonP8?00oooooomo00D0oooo00Coogl00?ooo`3oooooogl00P3oool00oooO`00oooo0?oo
o`0Q0?ooo`03o`00003oool0oooo00<0oooo00?oogl00?ooo`3oool02`3oool00ol00000oooo0?oo
o`0d0?ooo`05o`000?nP8?00oooo0?oooonP8?001P3oool00onP8?00oooo0?ooo`0<0?ooo`03oj0P
l03oool0oooo02H0oooo0_nP8?060?ooo`03oj0Pl03oool0oooo00`0oooo00?oX23`0?ooo`3oool0
0`3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo0080oooo00?oogl00?ooo`3oool0
1`3oool00oooO`00oooo0?ooo`050?ooo`03oj0Pl03oool0oooo0080oooo00?oogl00?ooo`3oool0
9`3oool00oooO`00oooo0?ooo`060?ooo`03o`00003oool0oooo00P0oooo000Y0?ooo`;o00001?oo
O`001@3oooooogl0oomo0?ooO`00oooo00;oogl01P3oool00onP8?3oogl00?ooo`02oomo0080oooo
00?oX23`0?ooo`3oool00`3oool01oooO`00oooo0?ooo`3oooooogl0oj0Pl?ooO`000_nP8?000`3o
ooooX23`0?ooo`030?ooo`03oomo003oool0oooo00h0oooo00?oogl00?ooo`3oool06@3oool00ol0
0000oooo0?ooo`040?ooo`;oogl02`3oool00ol00000oooo0?ooo`0d0?ooo`03oj0Pl03oool0oooo
00X0oooo00?oX23`0?ooo`3oool0<`3oool00oooO`00oooo0?ooo`0;0?ooo`03oj0Pl03oool0oooo
00@0oooo00?oX23`0?oooonP8?006P3oool00oooO`00oooo0?ooo`0i0?ooo`05oomo003oool0oooo
0?ooool000002P3oool002H0oooo0ol00005oomo00030?ooooooO`3oogl000@0oooo00?oogl00?oo
o`3oool01`3oool00onP8?00oooo0?ooo`060?ooo`03oomo003oool0oooo00@0oooo0_nP8?040?oo
o`03oj0Pl03oooooX23`00H0oooo00?oogl00?oooonP8?002`3oool00oooO`00oooo0?ooo`0F0?oo
o`04o`00003oool0oooooomo0140oooo00?o00000?ooo`3oool0<`3oool00onP8?00oooo0?ooo`02
0?ooo`03oj0Pl03oool0oooo00L0oooo00KoX23`0?ooo`3oooooogl00?oooonP8?0S0?ooo`03oj0P
l03oool0oooo01P0oooo00?oX23`0?ooo`3oool0303oool00oooO`00oooooomo000>0?ooo`03oj0P
l03oool0oooo02L0oooo00?oogl00?ooo`3oool05@3oool00ol00000oooo0?ooo`080?ooo`00903o
ool2o`0000Googl0103oool01?ooO`00oooo0?ooooooO`0;0?ooo`03oomo003oool0oooo0080oooo
00?oogl0oj0Pl03oool00_ooO`020?ooo`04oomo003oooooogl0oomo0080oooo0_ooO`001?nP8?00
oooo0?oooonP8?050?ooo`03oomo0?nP8?00oooo00D0oooo00?oogl00?ooo`3oool07`3oool00ol0
0000oooo0?ooo`070?ooo`03oomo003oool0oooo00T0oooo00?o00000?ooo`3oool0<P3oool00ol0
0000oooo0?ooo`080?ooo`03oj0Pl03oool0oooo00h0oooo00?oX23`0?ooo`3oool0503oool00ooo
O`00oooo0?ooo`0H0?ooo`03oj0Pl03oool0oooo00l0oooo00?oogl00?ooo`3oool0DP3oool00ol0
0000oooo0?ooo`080?ooo`008@3oool3o`0000Coogl000<0oooooomo003oool03@3oool01OooO`00
oooo0?ooo`3oooooX23`0080oooo0_ooO`000`3oooooX23`oomo00020?ooo`05oj0Pl?ooO`3oX23`
0?ooooooO`000P3oool00oooO`00oooo0?ooo`030?ooo`03oomo003oool0oooo00L0oooo00?oX23`
0?oooonP8?00603oool00oooO`00oooo0?ooo`0:0?ooo`03o`00003oool0oooo00P0oooo00?oogl0
0?ooo`3oool0203oool00ol00000oooo0?ooo`0b0?ooo`05o`00003oool0oooo0?oooonP8?000P3o
ool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo02H0oooo00?oX23`0?ooo`3oool04@3o
ool00oooO`00oooo0?ooo`0N0?ooo`03oj0Pl03oool0oooo03/0oooo00?oogl00?ooo`3oool01@3o
ool00ol00000oooo0?ooo`080?ooo`007`3oool2o`0000;oogl000D0oooooomo0?ooO`00oooooomo
00040?ooo`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool01@3oool00oooO`00oooooj0P
l0030?ooo`03oj0Pl?ooO`00oooo0080oooo00?oX23`0?ooooooO`000P3oool00oooO`00oooo0?oo
o`060?ooo`03oj0Pl03oool0oooo00h0oooo00?oogl00?ooooooO`007P3oool00ol00000oooo0?oo
o`070?ooo`?oogl02P3oool00ol00000oooo0?ooo`0a0?ooo`03o`000?nP8?00oooo00D0oooo00Co
X23`0?ooo`3oooooX23`0P3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo00T0oooo
00?oogl00?ooo`3oool05@3oool01onP8?00oooo0?ooo`3oooooX23`0?oooonP8?000P3oool00onP
8?00oooo0?ooo`020?ooo`03oomo003oool0oooo00@0oooo00?oX23`0?oooonP8?003`3oool01?nP
8?00oooo0?ooooooO`0=0?ooo`03oj0Pl03oool0oooo03d0oooo00?oogl00?ooo`3oool00P3oool0
0ol00000oooo0?ooo`080?ooo`007@3oool2o`0000040?ooooooO`3oogl00?ooo`;oogl0103oool2
oomo00D0oooo00?oogl00?ooo`3oool02@3oool00onP8?00oooooomo000A0?ooo`04oomo003oool0
oooooomo0340oooo00?o00000?ooo`3oool0203oool00oooO`00oooo0?ooo`090?ooo`03o`00003o
ool0oooo0340oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`090?ooo`03oj0Pl03o
ool0oooo02H0oooo00?oX23`0?ooo`3oool05`3oool00onP8?00oooo0?ooo`0@0?ooo`03oomo003o
ool0oooo00D0oooo00?oogl00?ooo`3oool0103oool00oooO`00oooo0?ooo`0`0?ooo`03oomo003o
ool0oooo0080oooo00?oogl00?ooo`3oool00`3oool00ol00000oooo0?ooo`080?ooo`006P3oool3
o`0000?oogl00`3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo0080oooo00?oogl0
0?ooo`3oool02`3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oool0oooo0080oooo00GoX23`
0?ooo`3oool0oooooj0Pl0070?ooo`03oj0Pl?ooO`00oooo00`0oooo00?oX23`0?ooo`3oool02@3o
ool00oooO`00oooo0?ooo`0F0?ooo`03o`00003oool0oooo00L0oooo00?oogl00?ooo`3oool02`3o
ool00ol00000oooo0?ooo`0`0?ooo`;oX23`1P3oool00onP8?00oooo0?ooo`0i0?ooo`03oj0Pl03o
ool0oooo00L0oooo00?oogl00?ooo`3oool0403oool01OnP8?00oooo0?ooo`3oooooogl000@0oooo
00?oogl00?ooo`3oool0203oool00oooO`00oooo0?ooo`0c0?ooo`03oomo003oooooogl000L0oooo
00?o00000?ooo`3oool0203oool001T0oooo00?o0000oomo0?ooO`000oooO`0<0?ooo`03oomo003o
ool0oooo00L0oooo00?oogl00?ooo`3oool01@3oool01OooO`00oooo0?ooo`3oooooX23`0080oooo
00CoX23`0?ooo`3oooooogl0103oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oool0oooo00D0
oooo00?oX23`0?ooo`3oool00P3oool01?ooO`00oooooomo0?nP8?020?ooo`03oomo003oool0oooo
01d0oooo00?oogl0o`00003oool0203oool00oooO`00oooooomo000<0?ooo`03o`00003oool0oooo
02l0oooo00?o0000oj0Pl03oool02P3oool00onP8?00oooo0?ooo`0X0?ooo`03oj0Pl03oool0oooo
07X0oooo00?o00000?ooo`3oool0203oool001T0oooo00Go00000?ooo`3oool0oooooomo00020?oo
o`03oomo003oooooogl000/0oooo00Googl00?ooo`3oool0oooooj0Pl0020?ooo`03oomo003oool0
oooo00@0oooo00?oX23`0?oooonP8?000P3oool00onP8?00oooo0?ooo`040?ooo`03oomo003oool0
oooo00<0oooo00CoX23`oomo003oooooogl0103oool00oooO`00oooo0?ooo`040?ooo`03oomo003o
ool0oooo00<0oooo00CoX23`oomo003oooooogl01`3oool00onP8?00oooo0?ooo`0E0?ooo`03o`00
003oool0oooo00X0oooo00?oogl00?ooo`3oool0203oool00ol00000oooo0?ooo`0_0?ooo`03o`00
003oool0oooo03T0oooo00?oX23`0?ooo`3oool09@3oool00onP8?00oooo0?ooo`020?ooo`03oomo
003oool0oooo04T0oooo00?o00000?ooo`3oool0203oool001T0oooo0_l000070?ooo`03oomo003o
ool0oooo01T0oooo00?oX23`0?ooo`3oool01P3oool02OooO`00oooo0?ooo`3oooooX23`0?oooonP
8?00oooooomo000:0?ooo`03oj0Pl03oool0oooo02T0oooo00?o00000?ooo`3oool02P3oool00ooo
O`00oooo0?ooo`090?ooo`03o`00003oool0oooo02h0oooo00Co00000?oooonP8?3oX23`0`3oool0
1?nP8?00oooo0?oooonP8?040?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0103o
ool00oooO`00oooo0?ooo`090?ooo`03oomo003oool0oooo00H0oooo0_nP8?0D0?ooo`03oj0Pl03o
ool0oooo00P0oooo00GoX23`0?ooo`3oool0oooooj0Pl0070?ooo`03oj0Pl03oool0oooo00@0oooo
00?oX23`0?ooo`3oool04P3oool00oooO`00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo02T0oooo
00Coogl00?ooo`3oooooogl00P3oool00ol00000oooo0?ooo`080?ooo`006@3oool00ol00000oooo
o`0000080?ooo`03oomo003oooooogl001T0oooo00?oX23`0?ooo`3oool00P3oool00oooO`00oooo
oomo00050?ooo`03oomo003oool0oooo00H0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo
0?ooo`030?ooo`03oj0Pl03oool0oooo01l0oooo00Coogl00?ooo`3ooooo00002`3oool2oomo00`0
oooo00?o00000?ooo`3oool0;@3oool00ol00000oooo0?ooo`0A0?ooo`03oj0Pl03oool0oooo00d0
oooo00?oX23`0?ooo`3oool09`3oool00onP8?00oooo0?ooo`0[0?ooo`03oj0Pl03oool0oooo0300
oooo00?oogl00?ooooooO`000`3oool00ol00000oooo0?ooo`080?ooo`00603oool01_l00000oooo
0?ooo`3ooooo0000oomo01<0oooo00?oogl00?ooo`3oool01@3oool00onP8?00oooo0?ooo`080?oo
o`03oomo0?nP8?00oooo00H0oooo00?oX23`0?ooo`3oool0103oool01_nP8?00oooo0?ooo`3ooooo
X23`oomo00d0oooo00?oogl00?ooo`3oool0703oool00ol00000oooo0?ooo`090?ooo`03oomo003o
ooooogl000/0oooo00?o00000?ooo`3oool0;@3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03o
ool0oooo00@0oooo00CoX23`0?oooonP8?3oX23`1P3oool00onP8?00oooo0?ooo`070?ooo`03oomo
003oool0oooo00d0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooooj0Pl00C0?ooo`03oj0P
l03oooooX23`00L0oooo00?oX23`0?oooonP8?001`3oool00oooO`00oooo0?ooo`040?ooo`03oomo
003oool0oooo0080oooo00?oX23`oomo003oool01P3oool00oooO`00oooo0?ooo`020?ooo`03oomo
003oool0oooo0280oooo00?oogl00?ooo`3oool0303oool00oooO`00oooo0?ooo`020?ooo`03o`00
003oool0oooo00P0oooo000H0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooooooO`00103o
ool00oooO`00oooooomo000A0?ooo`03oj0Pl03oool0oooo00T0oooo00Coogl00?ooo`3oooooX23`
103oool00onP8?00oooo0?ooo`050?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo00GoX23`0?ooo`3o
ool0oooooomo000J0?ooo`03oomo003oool0oooo00T0oooo00?o00000?ooo`3oool0603oool00ol0
0000oooo0?ooo`0/0?ooo`03oj0Pl03oool0oooo02L0oooo00?oogl00?ooo`3oool00P3oool00ooo
O`00oooo0?ooo`090?ooo`03oj0Pl03oooooX23`0100oooo00?oX23`0?ooo`3oool0103oool00ooo
O`00oooo0?ooo`1M0?ooo`03o`00003oool0oooo00P0oooo000H0?ooo`03o`00003oool0oooo00<0
oooo00?o00000?ooo`3oool0103oool00oooO`00oooooomo000H0?ooo`03oj0Pl03oool0oooo0080
oooo00?oogl00?ooo`3oool00_nP8?000oooO`00oooo0?ooo`070?ooo`04oomo0?nP8?00oooooj0P
l0@0oooo00?oX23`0?ooo`3oool00`3oool00oooO`00oooo0?ooo`0Q0?ooo`03o`00003oool0oooo
00X0oooo00?oogl00?ooo`3oool02`3oool00ol00000oooo0?ooo`0/0?ooo`04o`000?nP8?00oooo
oj0Pl0H0oooo00?oX23`0?ooo`3oool01`3oool00onP8?00oooo0?ooo`0E0?ooo`03oj0Pl03oool0
oooo00`0oooo00?oX23`0?ooo`3oool0:`3oool00oooO`00oooo0?ooo`190?ooo`03o`00003oool0
oooo00P0oooo000H0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00P3oool00ooo
O`00oooo0?ooo`060?ooo`03oomo003oool0oooo00h0oooo00?oX23`0?ooo`3oool0103oool2oj0P
l0@0oooo00?oX23`0?ooo`3oool00`3oool00oooO`3oX23`oomo00050?ooo`03oomo003oool0oooo
01<0oooo00?oX23`0?ooo`3oool0503oool00ol00000oooo0?ooo`0I0?ooo`03o`00003oool0oooo
02/0oooo00Go0000oj0Pl?nP8?00oooooj0Pl0020?ooo`03oj0Pl03oool0oooo00/0oooo00?oogl0
0?ooo`3oool00`3oool00onP8?00oooo0?ooo`020?ooo`;oX23`103oool00onP8?00oooo0?ooo`0D
0?ooo`05oj0Pl03oool0oooooj0Pl?ooO`003`3oool01OooO`00oooo0?ooo`3oooooogl00080oooo
00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`0A0?ooo`03oj0Pl03oool0oooo00/0oooo
00?oX23`0?ooooooO`00<03oool3oomo0003o`00003oool0oooo00P0oooo000H0?ooo`03o`00003o
ool0oooo00D0oooo00?o00000?ooo`3oool01`3oool00oooO`00oooo0?ooo`0<0?ooo`03oomo003o
ool0oooo00X0oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooooj0Pl0050?ooo`04oomo003o
ool0oooooj0Pl2P0oooo00?o00000?ooo`3oool02@3oool00oooO`00oooo0?ooo`0>0?ooo`03o`00
003oool0oooo02X0oooo00?o00000?ooo`3oool0503oool00onP8?00oooo0?ooo`0S0?ooo`03oj0P
l03oool0oooo02@0oooo00Coogl00?ooo`3oool0oooo0_nP8?1;0?ooo`03o`00003oool0oooo00P0
oooo000H0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool02@3oool00oooO`00oooo
0?ooo`0L0?ooo`03oj0Pl03oooooogl000h0oooo00Coogl00?ooo`3oooooogl0203oool00oooO`00
oooo0?ooo`0J0?ooo`03o`00003oool0oooo00P0oooo00?oogl00?ooo`3oool03`3oool00ol00000
oooo0?ooo`0Z0?ooo`03o`00003oool0oooo00L0oooo00?oX23`0?ooo`3oool02P3oool00onP8?00
oooo0?ooo`0;0?ooo`03oomo003oool0oooo00/0oooo00GoX23`0?ooo`3oool0oooooj0Pl0030?oo
o`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3oool0403oool00onP8?00oooo0?ooo`080?oo
o`03oomo003oool0oooo00d0oooo00?oogl00?ooo`3oool0:`3oool00oooO`00oooo0?ooo`0?0?oo
o`?oogl000?o00000?ooo`3oool0203oool001L0oooo00?o00000?ooo`3oool0203oool00ol00000
oooooomo000>0?ooo`03oomo003oool0oooo00L0oooo00?oX23`0?ooo`3oool0103oool00onP8?00
oooooj0Pl0020?ooo`;oX23`00<0oooooj0Pl03oool01`3oool01OooO`00oooooj0Pl03oooooogl0
00@0oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo
00<0oooo00?oX23`oomo003oool0503oool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo
02T0oooo00?o00000?ooo`3oool03@3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo
01h0oooo00?oX23`0?ooo`3oool04@3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo
05P0oooo00Koogl00?ooo`3oooooogl00?ooool0000:0?ooo`005`3oool00ol00000oooo0?ooo`09
0?ooo`03o`00003oool0oooo01/0oooo00?oogl00?ooo`3oool01@3oool00onP8?00oooo0?ooo`07
0?ooo`03oj0Pl03oool0oooo0080oooo00?oogl00?ooo`3oool0203oool01?nP8?00oooo0?oooonP
8?0;0?ooo`03oj0Pl03oool0oooo0140oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?oo
o`0Y0?ooo`04o`00003oooooX23`oj0Pl1d0oooo00?oX23`0?oooonP8?005`3oool00onP8?3oogl0
0?ooo`060?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?oooonP8?001@3oool00oooO`00oooo
0?ooo`030?ooo`03oomo003oool0oooo01@0oooo00?oX23`0?ooo`3oool02@3oool00oooO`00oooo
0?ooo`020?ooo`04oomo003oooooX23`oj0Pl380oooo00?o00000?ooo`3oool0203oool001L0oooo
00?o00000?ooo`3oool02@3oool00oooO`3o0000oomo00090?ooo`03oomo003oool0oooo00d0oooo
00Coogl00?ooo`3oooooX23`2`3oool01OnP8?00oooo0?ooo`3oooooX23`00/0oooo00?oogl00?oo
o`3oool09@3oool00ol00000oooo0?ooo`0<0?ooo`03oomo003oool0oooo00d0oooo00?o00000?oo
o`3oool0:03oool00ol00000oooo0?ooo`030?ooo`03oj0Pl03oool0oooo02l0oooo00CoX23`0?oo
oonP8?3oX23`1P3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo00l0oooo00?oX23`
0?ooo`3oool00P3oool01OnP8?00oooo0?ooo`3oooooogl00500oooo00?o00000?ooo`3oool0203o
ool001L0oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`060?ooo`03oomo003oool0
oooo0080oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`0?0?ooo`03oj0Pl03oool0
oooo0080oooo00?oX23`0?ooo`3oool01P3oool01?nP8?00oooooj0Pl?nP8?030?ooo`;oogl00`3o
ool00onP8?00oooo0?ooo`050?ooo`03oomo003oool0oooo0080oooo00?oX23`0?ooo`3oool04P3o
ool00ol00000oooo0?ooo`0;0?ooo`03oomo003oooooogl000l0oooo00?o00000?ooo`3oool09`3o
ool00ol00000oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo00;oX23`5`3oool00onP8?00oooooj0P
l0090?ooo`03oomo003oool0oooo02X0oooo00?oogl00?ooo`3oool0?P3oool00ol00000oooo0?oo
o`080?ooo`005`3oool00ol00000oooo0?ooo`0<0?ooo`03o`00003oool0oooo00D0oooo00?oogl0
0?ooo`3oool07P3oool00oooO`00oooo0?ooo`050?ooo`03oj0Pl03oool0oooo00<0oooo00Googl0
0?ooo`3oool0oooooomo00060?ooo`03oj0Pl03oool0oooo01/0oooo00?o00000?ooo`3oool07@3o
ool00ol00000oooo0?ooo`0W0?ooo`03oj0Pl03oool0oooo01L0oooo00?oX23`0?ooo`3oool01@3o
ool2oj0Pl0030?oooonP8?3oX23`00/0oooo00GoX23`0?ooo`3oool0oooooj0Pl0050?ooo`05oj0P
l03oool0oooo0?oooonP8?000P3oool01OnP8?00oooo0?ooo`3oooooogl000/0oooo00?oX23`0?oo
oonP8?002@3oool01OnP8?00oooo0?ooo`3oooooX23`0180oooo00?oX23`0?ooo`3oool01@3oool0
0onP8?00oooo0?ooo`030?ooo`03oomo003oool0oooo02d0oooo00?oogl0o`00003oool02@3oool0
01L0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0G0?ooo`03oj0Pl03oool0oooo
00@0oooo00?oX23`0?oooonP8?001@3oool3oj0Pl080oooo00?oX23`0?ooo`3oool00`3oool01Ooo
O`00oooo0?ooo`3oooooX23`00L0oooo00Googl00?ooo`3oool0oooooj0Pl00J0?ooo`03o`00003o
ool0oooo01h0oooo00?o00000?ooo`3oool09P3oool00ol00000oooooj0Pl00@0?ooo`03oj0Pl03o
ool0oooo02L0oooo00?oX23`0?ooo`3oool00onP8?0S0?ooo`04oj0Pl03oool0oooooj0Pl0H0oooo
00?oX23`0?ooo`3oool0@@3oool00oooO`3o00000?ooo`090?ooo`005`3oool00ol00000oooo0?oo
o`050?ooo`03oj0Pl03oool0oooo00D0oooo00?oogl0o`00003oool05P3oool00onP8?00oooo0?oo
o`0:0?ooo`05oomo003oool0oooo0?oooonP8?00203oool00oooO`00oooooj0Pl0020?ooo`03oj0P
l03oool0oooo00@0oooo00?oX23`0?ooo`3oool01P3oool00onP8?00oooo0?ooo`0D0?ooo`03o`00
003oool0oooo01h0oooo00?o00000?ooo`3oool09P3oool00onP8?00oooo0?ooo`0A0?ooo`03oj0P
l03oool0oooo00`0oooo00Googl00?ooo`3oool0oooooj0Pl0040?ooo`03oomo003oool0oooo0080
oooo00GoX23`0?ooo`3oool0oooooomo00050?ooo`03oomo003oool0oooo0080oooo00Googl00?oo
oonP8?00oooooj0Pl0040?ooo`03oj0Pl03oool0oooo00X0oooo00?oogl00?ooo`3oool07P3oool0
0oooO`00oooo0?ooo`0R0?ooo`03oomo003oool0oooo01D0oooo00?oogl0o`00003oool02@3oool0
01H0oooo00?o00000?ooo`3oool03`3oool00oooO`3o00000?ooo`030?ooo`03oomo003oool0oooo
01L0oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?ooo`0=0?ooo`08oj0Pl03oool0oooo
oj0Pl03oooooX23`0?oooonP8?0J0?ooo`03o`00003oool0oooo01l0oooo00?o00000?ooo`3oool0
9@3oool00ol00000oooo0?ooo`0o0?ooo`03oomo003oool0oooo00H0oooo00?oX23`0?ooo`3oool0
3`3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0
6@3oool00onP8?00oooo0?ooo`0Z0?ooo`;oogl000<0ooooo`00003oool02@3oool001H0oooo00?o
00000?ooo`3oool0303oool00oooO`00oooo0?ooo`020?ooo`03o`00003oool0oooo01P0oooo00?o
X23`0?oooonP8?00403oool00onP8?00oooo0?ooo`060?ooo`03oj0Pl03oool0oooo00T0oooo00?o
ogl00?ooo`3oool05P3oool01Ol00000oooo0?ooo`3oooooogl000h0oooo00?oogl00?ooo`3oool0
3@3oool00ol00000oooo0?ooo`0T0?ooo`03o`00003oool0oooo01/0oooo00?oX23`0?ooo`3oool0
5@3oool2oj0Pl0/0oooo00CoX23`0?ooo`3oooooX23`4`3oool00onP8?00oooo0?ooo`1H0?ooo`03
o`00003oool0oooo00P0oooo000F0?ooo`03o`00003oool0oooo00D0oooo00?oX23`0?ooo`3oool0
2P3oool00ol00000oooooomo000D0?ooo`03oj0Pl03oool0oooo0140oooo00?oX23`0?ooo`3oool0
5@3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3oool0
0`3oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo02@0oooo00?o0000oj0Pl03oool0
403oool01OnP8?00oooo0?ooo`3oooooX23`00H0oooo00GoX23`0?ooo`3oool0oooooomo00020?oo
o`04oj0Pl03oool0oooooj0Pl0<0oooo00?oogl00?ooo`3oool01P3oool2oj0Pl0H0oooo00CoX23`
0?ooo`3oooooX23`0`3oool01?nP8?00oooooj0Pl03oool2oj0Pl0030?oooonP8?00oooo00P0oooo
00?oX23`0?ooo`3oool04`3oool00oooO`00oooo0?ooo`080?ooo`03oj0Pl03oooooX23`00`0oooo
00GoX23`0?ooo`3oool0oooooj0Pl00[0?ooo`03o`00003oool0oooo00P0oooo000F0?ooo`03o`00
003oool0oooo0080oooo00?oX23`0?ooo`3oool03P3oool00ol00000oooo0?ooo`0E0?ooo`03oj0P
l03oool0oooo00d0oooo0_ooO`000`3oooooogl00?ooo`0K0?ooo`03oomo003oool0oooo00H0oooo
00?oX23`0?ooo`3oool01`3oool00ol00000oooo0?ooo`0:0?ooo`03oomo003oool0oooo01<0oooo
00?o00000?ooo`3oool08`3oool00ol00000oooo0?ooo`0R0?ooo`03oj0Pl03oool0oooo01P0oooo
0_nP8?040?ooo`04oj0Pl03oool0oooooomo01`0oooo00?oX23`0?ooo`3oool04@3oool00onP8?00
oooo0?ooo`0h0?ooo`03o`00003oool0oooo00P0oooo000F0?ooo`05o`00003oool0oooo0?oooonP
8?003@3oool00onP8?00oooo0?ooo`020?ooo`03o`00003oool0oooo01<0oooo00GoX23`0?ooo`3o
ool0oooooj0Pl0030?ooo`03oj0Pl03oool0oooo00D0oooo00?oogl00?ooo`3oool00P3oool00onP
8?00oooo0?ooo`030?ooo`03oomo003oooooX23`00L0oooo00?oX23`0?ooo`3oool00`3oool00onP
8?00oooo0?ooo`050?ooo`03oj0Pl03oool0oooo00h0oooo00?o00000?ooo`3oool08@3oool00ol0
0000oooo0?ooo`0R0?ooo`04o`00003oooooX23`oj0Pl200oooo00?oogl0oj0Pl03oool01P3oool0
1?ooO`00oooo0?oooonP8?030?ooo`05oomo003oool0oooo0?oooonP8?00303oool01?nP8?00oooo
oj0Pl?nP8?030?ooo`;oX23`103oool3oj0Pl0X0oooo00GoX23`0?ooo`3oool0oooooomo00020?oo
o`03oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool0203oool00onP8?00oooo0?ooo`0i0?oo
o`03oomo0?l00000oooo00T0oooo000F0?ooo`03o`00003oooooX23`00<0oooo00?oX23`0?oooonP
8?003P3oool00onP8?3o00000?ooo`040?ooo`03oomo003oool0oooo01H0oooo00GoX23`0?ooo`3o
ool0oooooj0Pl0030?ooo`03oj0Pl03oool0oooo00D0oooo00CoX23`0?ooo`3oooooogl09P3oool0
0ol00000oooo0?ooo`0Q0?ooo`03o`00003oool0oooo0280oooo00?o00000?ooo`3oool05@3oool0
0onP8?00oooo0?ooo`0:0?ooo`03oj0Pl03oool0oooo0080oooo00?oogl00?ooo`3oool08@3oool0
0oooO`00oooo0?ooo`0E0?ooo`03oj0Pl03oool0oooo04`0oooo00?o00000?ooo`3oool0203oool0
01D0oooo00?o00000?ooo`3oool05`3oool00ol00000oooo0?ooo`0B0?ooo`?oX23`0`3oool01?oo
O`00oooo0?ooooooO`090?ooo`03oj0Pl03oool0oooo0080oooo00?oogl00?ooo`3oool02`3oool0
1OooO`00oooo0?ooo`3oooooX23`00@0oooo00Coogl00?ooo`3oooooX23`403oool00ol00000oooo
0?ooo`0R0?ooo`03o`00003oool0oooo0240oooo00?o00000?ooo`3oool0:`3oool00onP8?00oooo
0?ooo`0G0?ooo`03oj0Pl03oool0oooo06X0oooo00?o00000?ooo`3oool0203oool001D0oooo00?o
00000?ooo`3oool0103oool00onP8?00oooooj0Pl002oj0Pl0l0oooo00?o00000?ooo`3oool0403o
ool00onP8?00oooo0?ooo`0:0?ooo`03oomo003oool0oooo00D0oooo00?oX23`0?oooonP8?003P3o
ool01OooO`00oooo0?ooo`3oooooX23`0080oooo00GoX23`0?ooo`3oool0oooooj0Pl0080?ooo`03
oj0Pl03oool0oooo00L0oooo00?o00000?ooo`3oool08P3oool00ol00000oooo0?ooo`0Q0?ooo`03
o`00003oool0oooo01<0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooo0?ooo`030?ooo`;o
X23`403oool00oooO`3oX23`0?ooo`050?ooo`04oj0Pl03oool0oooo0?ooo`;oX23`0`3oool00onP
8?00oooo0?ooo`020?ooo`05oj0Pl03oool0oooooomo0?nP8?001@3oool2oj0Pl4l0oooo00?oogl0
0?ooo`3oool01@3oool00ol00000oooo0?ooo`080?ooo`005@3oool00ol00000oooo0?ooo`020?oo
o`03oj0Pl03oooooX23`00<0oooo00?oX23`0?ooo`3oool03P3oool00ol00000oooo0?ooo`050?oo
o`05oj0Pl03oool0oooo0?ooooooO`002`3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oool0
oooo00D0oooo00?oogl00?ooooooO`001@3oool01OnP8?00oooo0?ooo`3oooooX23`00T0oooo00?o
ogl00?ooo`3oool03`3oool00oooO`00oooo0?ooo`060?ooo`03o`00003oool0oooo02<0oooo00?o
00000?ooo`3oool0803oool00onP8?00oooo0?ooo`0`0?ooo`06oj0Pl03oool0oooooj0Pl03ooooo
ogl03P3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3o
ool03P3oool00onP8?00oooo0?ooo`0@0?ooo`03oomo003oool0oooo03D0oooo00?oogl00?ooo`3o
ool00P3oool00ol00000oooo0?ooo`080?ooo`005@3oool00ol00000oooo0?ooo`030?ooo`03oj0P
l03oool0oooo01@0oooo00?o00000?ooooooO`002`3oool00onP8?00oooo0?ooo`040?ooo`03oj0P
l03oool0oooo00L0oooo00GoX23`0?ooo`3oool0oooooomo00050?ooo`03oj0Pl03oool0oooo00h0
oooo00?oogl00?ooo`3oool0603oool00ol00000oooo0?ooo`0T0?ooo`03o`00003oool0oooo01l0
oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`0J0?ooo`;oX23`203oool01onP8?00
oooooj0Pl03oooooX23`0?oooonP8?003`3oool00onP8?00oooo0?ooo`030?ooo`05oj0Pl03oool0
oooo0?oooonP8?000P3oool00oooO`00oooo0?ooo`030?ooo`;oX23`0`3oool00onP8?00oooo0?oo
o`0:0?ooo`03oomo003oool0oooo01H0oooo00?oX23`0?ooo`3oool01P3oool00oooO`00oooo0?oo
o`0Y0?ooo`03o`00003oool0oooo00P0oooo000E0?ooo`03o`00003oool0oooo0080oooo00?oX23`
0?ooo`3oool00_nP8?0>0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`o`00003oool00P3oool0
1?ooO`00oooo0?ooooooO`040?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3oool01@3o
ool2oj0Pl0L0oooo0onP8?070?ooo`03oj0Pl03oool0oooo0280oooo00?o00000?ooo`3oool0903o
ool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo0240oooo00?oX23`0?ooo`3oool00`3o
ool3oj0Pl0030?oooonP8?00oooo00<0oooo00?oX23`0?ooo`3oool00P3oool00oooO`00oooo0?oo
o`030?ooo`03oj0Pl03oool0oooo00D0oooo00Googl00?ooo`3oool0oooooj0Pl0080?ooo`03oomo
003oool0oooo00L0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooooomo00070?ooo`03oj0P
l03oool0oooo00@0oooo00?oogl00?ooo`3oool0=P3oool00ol00000oooo0?ooo`080?ooo`005@3o
ool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo0140oooo00GoX23`0?ooo`3oool0oooo
oj0Pl0040?ooo`03oj0Pl03oool0oooo00D0oooo0_nP8?090?ooo`;oX23`00?oogl00?ooo`3oool0
103oool01?ooO`00oooooj0Pl?ooO`0F0?ooo`03o`00003oool0oooo02D0oooo00?o00000?ooo`3o
ool07P3oool00ol00000oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo00@0oooo0_nP8?040?ooo`03
oomo0?nP8?00oooo00X0oooo00CoX23`0?ooo`3oool0oooo0_nP8?000`3oooooX23`0?ooo`020?oo
o`03oj0Pl03oool0oooo00<0oooo00CoX23`0?oooonP8?00oooo0onP8?000`3oooooX23`0?ooo`04
0?ooo`03oj0Pl03oool0oooo00T0oooo00?oX23`0?ooo`3oool0CP3oool00ol00000oooo0?ooo`08
0?ooo`00503oool00ol00000oooo0?ooo`0:0?ooo`04oj0Pl03oool0oooooj0Pl100oooo00Go0000
0?ooo`3oool0oooooj0Pl00;0?ooo`04oj0Pl?ooO`00oooooomo00D0oooo00?oX23`0?ooo`3oool0
1@3oool00onP8?00oooooomo00090?ooo`03oomo003oool0oooo0280oooo00?o00000?ooo`3oool0
9@3oool00ol00000oooo0?ooo`0N0?ooo`03oj0Pl03oool0oooo02`0oooo00OoX23`0?ooo`3oool0
oooooj0Pl03oooooX23`00D0oooo00Googl00?ooo`3oool0oooooj0Pl0020?ooo`03oj0Pl03oool0
oooo00D0oooo00CoX23`0?ooo`3oooooogl0I`3oool00ol00000oooo0?ooo`080?ooo`00503oool0
0ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo00<0oooo00?oX23`0?ooo`3oool01`3oool0
1OooO`3oX23`oj0Pl03oooooogl00080oooo00?oX23`0?ooo`3oool02@3oool00oooO`00oooo0?oo
o`040?ooo`03oj0Pl03oooooX23`00P0oooo00?oogl00?ooo`3oool06@3oool00ol00000oooo0?oo
o`0V0?ooo`03o`00003oool0oooo01d0oooo00?o00000?ooo`3oool09`3oool00onP8?00oooo0?oo
o`0:0?ooo`03oomo003oool0oooo00X0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?oo
o`030?ooo`03oj0Pl03oool0oooo01T0oooo00?oogl00?ooo`3oool0503oool00oooO`00oooo0?oo
o`0`0?ooo`03o`00003oool0oooo00P0oooo000D0?ooo`03o`00003oool0oooo00<0oooo00CoX23`
0?ooo`3oooooX23`1P3oool00onP8?00oooo0?ooo`0:0?ooo`03oj0Pl03oool0oooo00<0oooo00?o
00000?ooo`3oool01@3oool00oooO`00oooo0?ooo`050?ooo`;oX23`00<0oooooomo003oool00P3o
ool00oooO`00oooo0?ooo`020?ooo`04oj0Pl03oool0oooooj0Pl0H0oooo00?oX23`0?oooonP8?00
103oool00oooO`3oX23`0?ooo`030?ooo`03oomo003oool0oooo00L0oooo00?oogl00?ooo`3oool0
403oool00ol00000oooo0?ooo`0U0?ooo`?o00007P3oool00onP8?00oooo0?ooo`0W0?ooo`03oj0P
l03oool0oooo00;oX23`00<0oooooj0Pl03oool01@3oool01?ooO`00oooooomo0?ooO`030?ooo`Co
X23`0P3oool01?nP8?00oooooj0Pl?ooO`040?ooo`;oX23`00<0oooooj0Pl03oool0303oool00ooo
O`00oooo0?ooo`0P0?ooo`03oomo003oool0oooo0380oooo00?o00000?ooo`3oool0203oool001@0
oooo00?o00000?ooo`3oool01@3oool00onP8?00oooo0?ooo`0C0?ooo`03oomo003oool0oooo0080
oooo00OoX23`o`00003oool0oooooomo003oooooogl000H0oooo00KoX23`0?ooo`3oool0oooooomo
0?nP8?060?ooo`03oj0Pl03oooooX23`00<0oooo00CoX23`0?ooo`3oooooX23`0P3oool00onP8?00
oooooj0Pl0070?ooo`03oomo003oooooX23`00/0oooo00?oX23`0?ooo`3oool0403oool00ol00000
oooo0?ooo`0R0?ooo`?o00000P3oool00ol00000oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo02X0
oooo00GoX23`0?ooo`3oool0oooooj0Pl0020?ooo`03oomo003oooooogl000H0oooo00KoX23`0?oo
ooooO`00oooooj0Pl?ooO`060?ooo`06oj0Pl03oooooX23`oj0Pl03oooooX23`0`3oool00oooO`00
oooo0?ooo`020?ooo`03oj0Pl03oool0oooo00X0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00
oooooj0Pl0190?ooo`03o`00003oool0oooo00P0oooo000D0?ooo`03o`00003oool0oooo00H0oooo
00?oX23`0?ooo`3oool03@3oool00onP8?00oooo0?ooo`090?ooo`03o`00003oooooX23`0080oooo
00?oX23`0?ooo`3oool01@3oool00onP8?00oooooj0Pl0030?ooo`05oj0Pl03oool0oooo0?oooonP
8?000P3oool01OnP8?00oooo0?ooooooO`3oX23`00<0oooo00KoX23`0?ooo`3oool0oooooomo0?nP
8?050?ooo`03oj0Pl?ooO`00oooo00<0oooo00?oX23`0?ooooooO`001P3oool00oooO`3oX23`0?oo
o`0;0?ooo`05oomo003oool0oooo0?ooool000008@3oool3o`0000D0oooo00?o00000?ooo`3oool0
703oool00ol00000oooo0?ooo`0K0?ooo`03oj0Pl03oool0oooo00/0oooo00?oX23`0?oooonP8?00
0onP8?0;0?ooo`05oomo003oool0oooooj0Pl03oool00_nP8?001P3oooooX23`0?oooonP8?00oooo
oj0Pl080oooo00?oX23`0?oooonP8?000P3oool00onP8?00oooooomo00020?ooo`03oj0Pl03ooooo
X23`03P0oooo00?oogl00?ooo`3oool0803oool00oooO`3o00000?ooo`090?ooo`00503oool00ol0
0000oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00h0oooo00?oX23`0?ooo`3oool0203oool00ol0
0000oooo0?ooo`0=0?ooo`04oj0Pl03oool0oooooj0Pl0@0oooo00?oX23`oomo0?nP8?000_nP8?02
0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`oomo003oool02@3oool00oooO`00oooo0?ooo`0?
0?ooo`03oj0Pl03oool0oooo00P0oooo00?o00000?ooo`3oool0703oool3o`0000P0oooo00?o0000
0?ooo`3oool0703oool00ol00000oooo0?ooo`0Z0?ooo`07oj0Pl03oool0oooo0?oooonP8?00oooo
oj0Pl0070?ooo`03oomo003oooooogl00080oooo00GoX23`0?ooo`3oool0oooooj0Pl0040?ooo`06
oj0Pl03oooooX23`oj0Pl03oooooX23`603oool00onP8?00oooo0?ooo`090?ooo`03oj0Pl03oool0
oooo00<0oooo00?oX23`0?ooo`3oool0>@3oool00ol00000oooo0?ooo`080?ooo`00503oool00ol0
0000oooo0?ooo`080?ooo`03oj0Pl03oool0oooo01D0oooo00GoX23`0?ooo`3oool0ooooo`000008
0?ooo`05oj0Pl03oool0oooo0?ooooooO`000`3oool4oj0Pl080oooo00?oogl00?oooonP8?000P3o
ool2oj0Pl0<0oooo00CoX23`0?ooooooO`3oX23`103oool00onP8?00oooo0?ooo`020?ooo`03oj0P
l03oool0oooo00<0oooo00?oX23`0?ooo`3oool05@3oool00ol00000oooo0?ooo`0I0?ooo`?o0000
2`3oool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo02l0oooo00?oX23`0?ooo`3oool0
1P3oool01_nP8?00oooo0?oooonP8?00oooooj0Pl0P0oooo00KoX23`0?ooo`3oooooX23`0?oooonP
8?080?ooo`03oj0Pl03oool0oooo0140oooo00?oogl00?ooo`3oool04@3oool00oooO`00oooo0?oo
o`0c0?ooo`03o`00003oool0oooo00P0oooo000C0?ooo`03o`00003oool0oooo01T0oooo00?oX23`
0?ooo`3oool02@3oool01OnP8?3o0000oomo003oooooX23`00L0oooo00?oogl00?ooo`3oool01@3o
ool00onP8?00oooooj0Pl0060?ooo`03oj0Pl03oooooX23`0080oooo0_nP8?000oooO`00oooo0?oo
o`020?ooo`03oj0Pl03oool0oooo00d0oooo00GoX23`0?ooo`3oool0oooooomo000?0?ooo`03o`00
003oool0oooo01D0oooo0ol0000?0?ooo`03o`00003oool0oooo01/0oooo00?oX23`0?ooo`3oool0
;`3oool2oj0Pl0L0oooo00WoX23`0?ooo`3oool0oooooomo003oooooogl0oj0Pl?ooO`001?nP8?03
0?ooo`03oj0Pl03oooooX23`00<0oooo0onP8?000`3oooooX23`0?ooo`02oj0Pl0d0oooo0_nP8?0@
0?ooo`03oomo003oool0oooo03X0oooo00?o00000?ooo`3oool0203oool001<0oooo00?o00000?oo
o`3oool01`3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?oo
o`3oool0303oool00oooO`00oooooomo00080?ooo`06oj0Pl03oool0oooooj0Pl03oooooX23`0P3o
ool3oj0Pl0050?ooooooO`3oX23`oomo0?nP8?000P3oool00onP8?3oogl0oj0Pl003oj0Pl080oooo
00?oogl00?ooo`3oool01@3oool00oooO`00oooo0?ooo`090?ooo`?oogl01`3oool00oooO`00oooo
0?ooo`050?ooo`03o`00003oool0oooo0180oooo0ol0000B0?ooo`03o`00003oool0oooo01/0oooo
00?o00000?ooo`3oool0;P3oool3oj0Pl0030?oooonP8?3oX23`00@0oooo00?oX23`0?ooo`3oool0
103oool2oomo00<0oooo00?oX23`0?oooonP8?000P3oool00onP8?00oooooj0Pl003oj0Pl080oooo
0_nP8?0A0?ooo`03oomo003oool0oooo03<0oooo00?oogl00?ooo`3oool05@3oool00ol00000oooo
0?ooo`080?ooo`004`3oool00ol00000oooo0?ooo`0B0?ooo`03oj0Pl03oool0oooo01<0oooo00Oo
00000?ooo`3oool0oooooomo003oooooX23`0080oooo0_nP8?030?ooo`05oomo0?nP8?00oooo0?oo
oonP8?000P3oool00oooO`3oX23`0?ooo`020?ooo`07oj0Pl03oooooX23`oomo0?nP8?00oooooj0P
l0060?ooo`03oomo003oool0oooo0080oooo00?oX23`0?ooo`3oool06`3oool00ol00000oooo0?oo
o`0?0?ooo`?o00005@3oool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo01d0oooo00?o
X23`0?ooo`3oool0403oool4oj0Pl0050?oooonP8?00oooo0?oooonP8?000_ooO`001@3oooooX23`
0?ooo`3oooooX23`00<0oooo00?oogl00?ooo`3oool00P3oool00onP8?00oooo0?ooo`02oj0Pl080
oooo0_nP8?000oooO`3oX23`0?ooo`060?ooo`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3o
ool07`3oool00oooO`00oooo0?ooo`0Z0?ooo`03o`00003oool0oooo00P0oooo000C0?ooo`03o`00
003oool0oooo0180oooo00?oX23`0?ooo`3oool01@3oool2oj0Pl0/0oooo00KoX23`0?ooool0003o
X23`oomo0?nP8?020?ooo`03oj0Pl03oooooogl000H0oooo00?oX23`oomo003oool01?nP8?00103o
ooooX23`oj0Pl03oool2oj0Pl0030?oooonP8?00oooo00;oX23`3@3oool00oooO`00oooo0?ooo`03
0?ooo`04oomo003oool0oooooomo0140oooo00?o00000?ooo`3oool0303oool3o`0001P0oooo00?o
00000?ooo`3oool06`3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo02L0oooo00?o
X23`0?ooo`3oool00P3oool2oj0Pl0<0oooo00Googl00?oooonP8?00oooooj0Pl0040?ooo`;oX23`
00?oogl00?ooo`3oool00P3oool00onP8?00oooo0?ooo`0=0?ooo`03oj0Pl03oool0oooo0100oooo
00?oogl00?ooo`3oool0@@3oool00ol00000oooo0?ooo`080?ooo`004`3oool00ol00000oooo0?oo
o`060?ooo`03oj0Pl03oool0oooo01X0oooo00[oX23`0?ooo`3oool0oooooj0Pl03oooooX23`o`00
003oooooogl01P3oool2oj0Pl0D0oooo00CoX23`0?oooonP8?3oX23`0P3oool00onP8?00oooo0?oo
o`020?ooo`Googl0:03oool00ol00000oooo0?ooo`090?ooo`?o00006`3oool00ol00000oooo0?oo
o`0K0?ooo`03o`00003oool0oooo03<0oooo00?oX23`0?oooonP8?001P3oool00onP8?00oooo0?oo
o`050?ooo`03oomo003oooooX23`00L0oooo00Googl00?oooonP8?00oooooj0Pl0070?ooo`03oj0P
l03oooooX23`00H0oooo00Coogl00?ooo`3oooooX23`0P3oool00onP8?00oooo0?ooo`060?ooo`03
oomo003oool0oooo03d0oooo00?o00000?ooo`3oool0203oool001<0oooo00?o00000?ooo`3oool0
2P3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo0140oooo00?oX23`0?ooo`3oool0
0`3oool00ol00000oooo0?ooo`020?ooo`;oX23`00@0oooooj0Pl03oooooogl01@3oool01?nP8?00
oooooj0Pl03oool2oj0Pl003oomo003oooooX23`00;oogl000KoX23`0?ooo`3oool0oooooomo0?nP
8?030?ooo`05oj0Pl03oool0oooooomo0?nP8?002@3oool00onP8?3oogl00?ooo`0B0?ooo`03o`00
003oool0oooo00H0oooo0ol0000N0?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0
<P3oool00onP8?00oooooj0Pl002oj0Pl0030?oooonP8?3oX23`00@0oooo0_nP8?000`3oooooogl0
0?ooo`02oomo00@0oooo00?oogl00?ooo`3oool00_nP8?001@3oooooogl0oomo003oooooX23`0080
oooo00?oX23`0?oooonP8?000P3oool00onP8?00oooo0?ooo`020?ooo`05oj0Pl03oooooX23`0?oo
oonP8?000P3oool00oooO`3oX23`0?ooo`070?ooo`03oj0Pl03oool0oooo0080oooo00?oogl00?oo
o`3oool0>P3oool00ol00000oooo0?ooo`080?ooo`004P3oool00ol00000oooo0?ooo`0<0?ooo`03
oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool05`3oool01?l0003oX23`0?oooonP8?060?oo
o`;oogl00P3oool2oj0Pl0030?ooooooO`00oooo00@0oooo00Googl00?ooo`3oool0oooooj0Pl005
0?ooo`03oj0Pl03oool0oooo00X0oooo0_nP8?0>0?ooo`03oj0Pl03oool0oooo00D0oooo00?o0000
0?ooo`3oool00`3oool3o`000240oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`0H
0?ooo`03oj0Pl03oool0oooo00l0oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`02
0?ooo`;oX23`00<0oooooj0Pl03oool00`3oool01?nP8?00oooo0?oooonP8?040?ooo`03oomo003o
ool0oooo00<0oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`030?ooo`04oj0Pl03o
ool0oooooomo00T0oooo00Coogl00?ooo`3oooooogl02P3oool00oooO`00oooo0?ooo`0m0?ooo`03
o`00003oool0oooo00P0oooo000B0?ooo`03o`00003oool0oooo00X0oooo00GoX23`0?ooo`3oool0
oooooj0Pl0020?ooo`03oj0Pl03oool0oooo00`0oooo00GoX23`0?oooonP8?00oooooj0Pl0030?oo
o`04oj0Pl03oool0oooooj0Pl080oooo00?o0000oj0Pl03oool00P3oool01OnP8?00oooo0?oooooo
O`3oX23`00<0oooo00GoX23`0?oooonP8?3oX23`0?ooo`02oj0Pl0040?ooooooO`3oX23`oj0Pl0D0
oooo00?oX23`oomo003oool0103oool01OnP8?00oooo0?ooo`3oooooX23`00L0oooo00?oogl00?oo
o`3oool04P3oool01_l00000oooo0?ooool0003oogl0o`0002D0oooo00?o00000?ooo`3oool06P3o
ool00ol00000oooo0?ooo`0e0?ooo`03oj0Pl03oooooX23`00D0oooo00?oX23`0?oooonP8?001P3o
ool00oooO`3oX23`oj0Pl0020?ooo`09oj0Pl?ooO`3oX23`oomo003oooooX23`0?oooonP8?00oooo
00;oX23`00H0oooooj0Pl?ooO`00oooooj0Pl03oool2oj0Pl1H0oooo00?oogl00?ooo`3oool0>`3o
ool00ol00000oooo0?ooo`080?ooo`004P3oool00ol00000oooo0?ooo`0:0?ooo`03oj0Pl03oool0
oooo00<0oooo00?oX23`0?oooonP8?000P3oool00onP8?00oooo0?ooo`0=0?ooo`03oj0Pl03oool0
oooo00L0oooo00?oX23`0?ooo`3oool0203oool01onP8?3oogl00?oooonP8?00oooooj0Pl?ooO`00
0P3oool4oj0Pl004oomo0?nP8?3oogl0oomo00;oX23`00<0oooooomo0?ooO`00103oool00onP8?00
oooo0?ooo`050?ooo`05oomo003oool0oooo0?oooonP8?001`3oool00oooO`00oooo0?ooo`080?oo
o`?o0000:03oool00ol00000oooo0?ooo`0J0?ooo`03o`000?nP8?00oooo03P0oooo0_nP8?000`3o
ooooX23`0?ooo`020?ooo`06oj0Pl03oool0oooooj0Pl03oooooogl01`3oool02OooO`00oooo0?oo
ooooO`3oX23`0?oooonP8?00oooooj0Pl0030?ooo`;oX23`00?oogl00?ooo`3oool0E@3oool00ol0
0000oooo0?ooo`080?ooo`004P3oool00ol00000oooo0?ooo`0<0?ooo`03oj0Pl03oool0oooo00D0
oooo00?oX23`0?ooo`3oool03P3oool00onP8?00oooo0?ooo`080?ooo`04oomo003oool0oooooj0P
l0D0oooo00Coogl00?oooonP8?3oogl00`3oool2oomo00030?ooooooO`3oX23`00<0oooo00Soogl0
0?oooonP8?3oX23`0?ooooooO`00oooooomo0080oooo0_nP8?020?ooo`05oomo003oool0oooo0?oo
ooooO`005@3oool4o`0002X0oooo00?o00000?ooo`3oool06P3oool01?l00000oooo0?oooonP8?0h
0?ooo`03oj0Pl03oooooX23`00;oX23`00<0oooooj0Pl03oool00P3oool01?nP8?00oooo0?oooonP
8?040?ooo`06oj0Pl03oooooX23`oj0Pl?ooO`3oX23`0_ooO`000`3oooooogl0oomo00040?ooo`Ko
X23`00<0oooooj0Pl?ooO`00803oool00oooO`00oooo0?ooo`0/0?ooo`03o`00003oool0oooo00P0
oooo000B0?ooo`03o`00003oool0oooo01H0oooo0_nP8?070?ooo`03oj0Pl03oool0oooo00H0oooo
00?oX23`0?ooo`3oool01P3oool00ol00000oooo0?ooo`050?ooo`03oomo003oooooogl000H0oooo
0onP8?001`3oooooX23`0?ooo`3oooooogl00?oooonP8?000_ooO`03oj0Pl1/0oooo1?l000030?oo
o`03o`00003oool0oooo02P0oooo00?o00000?ooo`3oool06P3oool00ol00000oooo0?ooo`0b0?oo
o`03oj0Pl03oool0oooo00`0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`020?oo
o`05oj0Pl?ooO`00oooo0?ooooooO`000P3oool01?nP8?00oooo0?oooonP8?040?ooo`05oj0Pl03o
ool0oooo0?oooonP8?008@3oool00onP8?00oooo0?ooo`0/0?ooo`03o`00003oool0oooo00P0oooo
000B0?ooo`03o`00003oool0oooo00h0oooo00?oX23`0?ooo`3oool0703oool00onP8?00oooo0?oo
o`020?ooo`03oj0Pl03oool0oooo0080oooo00?oogl0oj0Pl?ooO`00103oool01onP8?00oooooj0P
l?nP8?00oooooj0Pl03oool00_nP8?040?ooo`04oj0Pl?ooO`3oogl00?ooo`;oX23`00?oogl00?oo
ooooO`000P3oool00onP8?00oooo0?ooo`0@0?ooo`;o000000?oX23`0?oooonP8?000P3oool01?oo
O`00oooo0?ooool0000;0?ooo`03oomo003oool0oooo01`0oooo00?o00000?ooo`3oool06P3oool0
0ol00000oooo0?ooo`0h0?ooo`;oX23`103oool00oooO`00oooo0?ooo`080?ooo`06oj0Pl03ooooo
ogl00?oooonP8?3oogl00P3oool2oj0Pl0030?ooooooO`3oogl00080oooo00?oogl00?ooo`3oool0
103oool00onP8?00oooo0?ooo`040?ooo`03oomo003oool0oooo03T0oooo00?oogl00?ooo`3oool0
3@3oool00ol00000oooo0?ooo`080?ooo`004@3oool00ol00000oooo0?ooo`070?ooo`03oj0Pl03o
ool0oooo00<0oooo00GoX23`0?ooo`3oool0oooooj0Pl00N0?ooo`;oX23`00T0oooooj0Pl?l0003o
X23`0?oooonP8?00oooooomo0?nP8?000P3oool3oomo0080oooo0_nP8?000`3oooooX23`oomo0004
0?ooo`04oj0Pl?ooO`3oX23`oomo00;oX23`00?oogl00?oooonP8?000_nP8?000oooO`00oooo0?oo
o`0>0?ooo`?o00002P3oool00ol00000oooo0?ooo`0X0?ooo`03o`00003oool0oooo01X0oooo00?o
X23`0?ooo`3oool0>03oool01?nP8?00oooo0?ooo`3oool2oj0Pl004oomo0?nP8?00oooooomo00Co
X23`00coogl00?oooonP8?3oX23`0?oooonP8?3oogl0oj0Pl?ooO`00oooooj0Pl?ooO`03oj0Pl005
oomo0?nP8?3oogl0oomo003oool00onP8?1E0?ooo`03o`00003oool0oooo00P0oooo000A0?ooo`03
o`00003oool0oooo01L0oooo00?oX23`0?ooo`3oool05@3oool00onP8?00oooo0?ooo`020?ooo`Co
X23`103oool2oj0Pl080oooo00CoX23`0?ooo`3oool0oooo0_ooO`030?ooo`;oX23`00D0oooooj0P
l?ooO`3oX23`0?ooo`02oj0Pl003oomo003oooooX23`00<0oooo00?oX23`0?ooo`3oool0103oool0
0onP8?00oooo0?ooo`020?ooo`?o00000`3oool00onP8?00oooo0?ooo`070?ooo`03o`00003oool0
oooo02P0oooo00?o00000?ooo`3oool06P3oool00ol00000oooo0?ooo`110?ooo`03oj0Pl03oool0
oooo0080oooo0_nP8?00103oooooX23`0?ooooooO`020?ooo`03oj0Pl?ooO`00oooo00<0oooo0_oo
O`001@3oooooogl0oj0Pl03oooooogl000D0oooo00?oX23`0?ooo`3oool03P3oool00oooO`00oooo
0?ooo`0>0?ooo`03oj0Pl03oool0oooo02d0oooo00?o00000?ooo`3oool0203oool00140oooo00?o
00000?ooo`3oool0203oool00onP8?00oooo0?ooo`050?ooo`03oj0Pl03oool0oooo00/0oooo00?o
X23`0?ooo`3oool02@3oool2oj0Pl0D0oooo00KoX23`0?oooonP8?3oX23`0?ooool00003oj0Pl003
0?ooooooO`3oogl00080oooo00Googl0oj0Pl03oool0oooooj0Pl0030?ooo`03oj0Pl03oool0oooo
00CoX23`00[oogl00?ooooooO`3oX23`0?oooonP8?00oooooj0Pl?ooO`3oX23`1@3oool2oomo0080
oooo0ol000070?ooo`03oj0Pl03oooooX23`00H0oooo00?o00000?ooo`3oool0103oool00oooO`00
oooo0?ooo`0R0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool0?@3oool2oj0Pl080
oooo00Koogl00?ooo`3oooooX23`0?oooonP8?020?ooo`;oX23`00<0oooooomo003oool00_nP8?00
1@3oooooX23`oj0Pl?ooO`00oooo00;oogl00_nP8?000`3oooooX23`oj0Pl0030?ooo`03oj0Pl03o
ooooogl00080oooo00?oX23`0?ooo`3oool02P3oool2oomo00@0oooo00?oX23`0?ooo`3oool06P3o
ool00oooO`00oooo0?ooo`0K0?ooo`03o`00003oool0oooo00P0oooo000A0?ooo`03o`00003oool0
oooo00D0oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?ooo`0A0?ooo`03oj0Pl03oool0
oooo0080oooo00?oX23`0?ooo`3oool0103oool01?nP8?00oooo0?oooonP8?020?ooo`;oX23`0`3o
ool01?nP8?00oooo0?ooo`3oool2oj0Pl0030?oooonP8?00oooo00@0oooo0onP8?000oooO`00oooo
oj0Pl0020?ooo`03oomo0?nP8?00oooo00;oX23`00<0oooooj0Pl03oool01@3oool2o`000003oomo
003oool0oooo00L0oooo00?oX23`0?ooo`3oool00oooO`001OnP8?00oooo0?ooo`3ooooo000002/0
oooo00?o00000?ooo`3oool06@3oool00ol0003oX23`0?ooo`0k0?ooo`03oj0Pl03oool0oooo00<0
oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`040?ooo`03oomo003oool0oooo0080
oooo00CoX23`0?ooo`3oool0oooo0_ooO`000`3oooooogl00?ooo`0>0?ooo`03oomo003oool0oooo
0180oooo00?oX23`0?ooo`3oool0;P3oool00ol00000oooo0?ooo`080?ooo`004@3oool00ol00000
oooo0?ooo`090?ooo`03oj0Pl03oool0oooo0180oooo00?oX23`0?ooo`3oool03@3oool00onP8?00
oooo0?ooo`060?ooo`KoX23`00@0oooooj0Pl03oool0oooo0_nP8?001`3oooooX23`0?ooo`3ooooo
X23`0?oooonP8?000P3oool00onP8?00oooo0?ooo`050?ooo`CoX23`0`3oool3o`0000@0oooo00?o
ogl00?ooo`3oool00`3oool01OnP8?00oooooj0Pl03oooooX23`00L0oooo00?o00000?ooo`3oool0
:@3oool00ol00000oooo0?ooo`0I0?ooo`03o`00003oool0oooo0400oooo00?oX23`0?ooo`3oool0
0P3oool3oj0Pl0P0oooo0onP8?001@3oooooX23`0?ooo`3oooooogl000D0oooo00?oogl00?ooo`3o
ool0DP3oool00ol00000oooo0?ooo`080?ooo`004@3oool00ol00000oooo0?ooo`070?ooo`?oX23`
2P3oool00onP8?00oooo0?ooo`0Q0?ooo`?oX23`1@3oool01OnP8?3oogl0oj0Pl03oooooX23`0080
oooo00Soogl00?oooonP8?00oooooj0Pl03oooooogl00?ooo`?oX23`103oool00oooO`00oooooj0P
l002o`0000D0oooo00CoX23`0?ooo`3oooooX23`0P3oool00onP8?3oogl00?ooo`040?ooo`05oj0P
l03oool0oooo0?oooonP8?000P3oool00ol00000oooooomo000Y0?ooo`03o`00003oool0oooo01T0
oooo00Go00000?ooo`3oool0oooooj0Pl00h0?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo00GoX23`
0?ooo`3oooooX23`0?ooo`02oomo0080oooo0onP8?000`3oooooX23`0?ooo`02oj0Pl0<0oooo00?o
X23`0?oooonP8?000`3oool2oomo00050?oooonP8?00oooooj0Pl03oool00_nP8?0<0?ooo`04oomo
003oool0oooooomo0100oooo00?oogl00?ooo`3oool0:`3oool00ol00000oooo0?ooo`080?ooo`00
4@3oool00ol00000oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3oool0
0P3oool00onP8?00oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo0100oooo00SoX23`o`000?nP8?00
oooooomo0?nP8?00oooooj0Pl0D0oooo00?oogl00?ooo`3oool00_nP8?001?ooO`00oooo0?oooooo
O`02oj0Pl0090?oooonP8?00oooo0?oooonP8?3oogl0o`00003oooooX23`0080oooo00?oX23`0?oo
o`3oool00P3oool01OnP8?3oogl00?ooo`3oooooX23`00L0oooo00?oX23`0?ooooooO`000`3oool0
0oooO`00ooooo`00000Z0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool0BP3oool0
0onP8?00oooo0?ooo`02oj0Pl0H0oooo00?oX23`0?ooo`3oool00P3oool01?ooO`00oooo0?ooo`3o
ool3oj0Pl080oooo00?oogl00?ooo`3oool0103oool01?nP8?00oooo0?ooooooO`0D0?ooo`03oomo
003oool0oooo02d0oooo00?o00000?ooo`3oool0203oool00100oooo00?o00000?ooo`3oool05P3o
ool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo01X0oooo00?oX23`0?ooo`3oool00onP
8?050?ooo`03oj0Pl03oool0oooo00@0oooo00CoX23`0?ooooooO`3oX23`103oool01Ol0003oX23`
oj0Pl03oooooX23`0080oooo0_nP8?000`3oooooX23`0?ooo`050?ooo`05oomo0?nP8?00oooo0?oo
ooooO`000`3oool00onP8?00oooo0?ooo`050?ooo`04oj0Pl03ooooo0000oj0Pl2T0oooo00?o0000
0?ooo`3oool06@3oool00ol00000oooo0?ooo`0F0?ooo`03oomo003oool0oooo02L0oooo00?oX23`
0?ooo`3oool00`3oool00onP8?00oooo0?ooo`020?ooo`0<oj0Pl03oool0oooooj0Pl03oooooX23`
0?oooonP8?3oogl00?oooonP8?00oooo0_nP8?020?ooo`05oomo003oooooogl00?oooonP8?00103o
ool3oj0Pl1X0oooo00?oX23`0?ooo`3oool0103oool00oooO`00oooo0?ooo`040?ooo`03oomo003o
ool0oooo00@0oooo00?oogl00?ooo`3oool06@3oool00ol00000oooo0?ooo`080?ooo`00403oool0
0ol00000oooo0?ooo`080?ooo`03oj0Pl03oool0oooo00L0oooo00?oX23`0?ooo`3oool05P3oool0
0onP8?00oooo0?ooo`080?ooo`03oj0Pl03oool0oooo0080oooo00CoX23`0?oooonP8?3oX23`0P3o
ool00oooO`3oX23`oj0Pl0040?ooo`04oj0Pl?ooO`00oooo0?ooo`;oogl00P3oool00onP8?3o0000
o`000004oj0Pl0060?oooonP8?00oooo0?oooonP8?00oooo0_nP8?000`3oooooX23`0?ooo`020?oo
o`03oj0Pl03oooooX23`00<0oooo00?oX23`oomo003oool00`3oool00onP8?00oooo0?ooo`030?oo
o`03o`00003oool0oooo00H0oooo00?oX23`0?ooo`3oool07`3oool00ol00000oooo0?ooo`0I0?oo
o`03o`00003oool0oooo00<0oooo00?oX23`0?ooo`3oool04@3oool3oomo02P0oooo00?oX23`0?oo
o`3oool01`3oool01_ooO`00oooo0?ooo`3oooooogl0oj0Pl0X0oooo00?oogl0oj0Pl03oool00_nP
8?001_ooO`00oooo0?oooonP8?00oooooj0Pl0H0oooo00?oogl00?ooo`3oool0203oool00onP8?00
oooo0?ooo`060?ooo`03oj0Pl03oool0oooo02h0oooo00?o00000?ooo`3oool0203oool00100oooo
00?o00000?ooo`3oool02@3oool2oj0Pl3<0oooo00?o0000oj0Pl?nP8?001?nP8?00103oooooogl0
0?ooo`3oool4oj0Pl004o`000?nP8?3o0000oj0Pl080oooo00?oogl0oj0Pl03oool01P3oool00ooo
O`3oX23`0?ooo`020?ooo`04oj0Pl03oool0oooooj0Pl0H0oooo00CoX23`oomo003oooooX23`1`3o
ool00ol00000oooo0?ooo`0X0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool05`3o
ool2oomo03@0oooo00?oX23`oomo003oool0103oool01OnP8?3oogl00?ooo`3oooooogl000L0oooo
00CoX23`oomo0?nP8?3oX23`5P3oool00oooO`00oooo0?ooo`040?ooo`03oomo003oooooogl002h0
oooo00?o00000?ooo`3oool0203oool00100oooo00?o00000?ooo`3oool0203oool00onP8?00oooo
0?ooo`0V0?ooo`03oj0Pl03oool0oooo00T0oooo0onP8?020?ooo`03oomo003oooooogl000@0oooo
00SoX23`o`000?nP8?3o0000oj0Pl03oooooX23`0?ooo`;oX23`0P3oool01OnP8?00oooo0?ooo`3o
ooooX23`0080oooo00CoX23`0?oooonP8?3oX23`0P3oool00onP8?00oooo0?ooo`0:0?ooo`03oomo
0?nP8?00oooo00@0oooo00?o00000?ooo`3oool0:@3oool00ol00000oooo0?ooo`0H0?ooo`03o`00
003oool0oooo01H0oooo1?ooO`0Z0?ooo`03oj0Pl03oooooX23`00@0oooo00SoX23`0?ooo`3ooooo
X23`0?ooooooO`00oooooomo00@0oooo0_nP8?030?ooo`03oj0Pl03oool0oooo00;oX23`00H0oooo
oj0Pl?nP8?3oX23`0?oooonP8?0H0?ooo`03oomo003oool0oooo0300oooo00?o00000?ooo`3oool0
203oool00100oooo00?o00000?ooo`3oool02P3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03o
ool0oooo01@0oooo00?oX23`0?ooo`3oool04P3oool00onP8?00oooo0?ooo`040?ooo`?o000000?o
X23`0?ooo`3oool0103oool01OnP8?00oooo0?oooonP8?00oooo00;oX23`00<0oooooj0Pl?nP8?00
1P3oool02?nP8?00oooooomo003oooooX23`0?oooonP8?00oooo0_nP8?030?ooo`04oj0Pl03oool0
oooooj0Pl0@0oooo00?o00000?oooonP8?00:@3oool00ol00000oooo0?ooo`0H0?ooo`03o`00003o
ool0oooo01L0oooo0_ooO`0P0?ooo`03oj0Pl03oool0oooo0180oooo00?oX23`0?ooooooO`002`3o
ool00onP8?00oooo0?ooo`050?ooo`05oj0Pl03oooooX23`0?oooonP8?000P3oool00onP8?00oooo
0?ooo`0;0?ooo`03oomo003oool0oooo03H0oooo00?o00000?ooo`3oool0203oool00100oooo00?o
00000?ooo`3oool02`3oool00onP8?00oooo0?ooo`090?ooo`03oj0Pl03oool0oooo01h0oooo00?o
X23`0?ooo`3oool01@3oool01onP8?3o00000?ooo`3oooooogl0oj0Pl?l000000_nP8?030?ooo`03
oj0Pl03oooooX23`0080oooo00?oX23`0?oooonP8?000onP8?050?ooo`04oj0Pl03oool0oooooj0P
l080oooo00CoX23`oomo003oooooogl00P3oool2oj0Pl080oooo0_nP8?050?ooo`04oomo003oool0
ooooo`0001X0oooo00?oogl00?ooo`3oool03P3oool00ol00000oooo0?ooo`0H0?ooo`03o`00003o
ool0oooo04D0oooo00GoX23`0?ooo`3oool0oooooj0Pl0060?ooo`;oX23`00@0oooooj0Pl03ooooo
X23`103oool00oooO`00oooooj0Pl0020?ooo`04oomo003oool0oooooj0Pl0<0oooo00?oogl00?oo
o`3oool00_nP8?000oooO`00oooooj0Pl00;0?ooo`03oomo003oool0oooo0080oooo00?oogl00?oo
o`3oool0<@3oool00ol00000oooo0?ooo`080?ooo`003`3oool00ol00000oooo0?ooo`0;0?ooo`03
oj0Pl03oool0oooo02@0oooo00?oX23`0?ooo`3oool0303oool03OnP8?00ooooo`000?nP8?00oooo
oj0Pl03oooooogl00?oooonP8?00oooooomo003oool00onP8?001oooO`3oX23`0?ooo`3oooooX23`
0?oooonP8?000P3oool00onP8?00oooooj0Pl0020?ooo`06oj0Pl03oooooogl00?oooonP8?00oooo
0onP8?020?ooo`03oomo0?nP8?3oogl000X0oooo00?o0000oomo003oool00P3oool00onP8?00oooo
0?ooo`0T0?ooo`03o`00003oool0oooo01P0oooo00?o00000?ooo`3oool0B`3oool01_nP8?00oooo
0?ooooooO`00oooooj0Pl080oooo00CoX23`0?oooonP8?3oX23`0P3oool00onP8?3oogl00?ooo`02
oj0Pl0050?oooonP8?00oooooomo0?nP8?001@3oool01OnP8?00oooo0?ooooooO`3oX23`01@0oooo
00?oX23`0?ooo`3oool0;P3oool00ol00000oooo0?ooo`080?ooo`003`3oool00ol00000oooo0?oo
o`0;0?ooo`03oj0Pl03oool0oooo01D0oooo00?oX23`0?ooo`3oool0603oool02?nP8?00oooo0?oo
o`3oooooX23`o`000?nP8?00oooo0onP8?001P3oooooX23`0?ooooooO`00oooooj0Pl0;oogl000D0
oooooj0Pl?nP8?3oogl0oj0Pl0040?ooo`03oj0Pl03oooooX23`00@0oooo00?oX23`0?ooo`3oool0
0P3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo00;oX23`0P3oool01?nP8?3o0000
o`000?l000050?ooo`03oj0Pl03oool0oooo02<0oooo00?o00000?ooo`3oool0603oool00ol00000
oooo0?ooo`020?ooo`03oj0Pl03oool0oooo03D0oooo00?oX23`0?ooo`3oool01P3oool00onP8?00
oooo0?ooo`0;0?ooo`03oomo003oool0oooo00<0oooo1?nP8?000`3oooooX23`0?ooo`0?0?ooo`03
oj0Pl?ooO`3oX23`00T0oooo00?oogl00?ooo`3oool0=P3oool00ol00000oooo0?ooo`080?ooo`00
3`3oool00ol00000oooo0?ooo`0P0?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?ooo`3oool0
203oool00onP8?00oooooj0Pl0040?ooo`03oj0Pl03oool0oooo00<0oooo00?o00000?ooo`3oool0
103oool5oj0Pl0<0oooo00GoX23`oomo003oool0oooooomo00020?ooo`05oomo0?nP8?00oooooj0P
l?ooO`000_nP8?000`3oooooogl00?ooo`020?ooo`03oj0Pl03oool0oooo00CoX23`0`3oool00ooo
O`3oX23`0?ooo`03o`000080oooo00?o0000oj0Pl?nP8?003@3oool00onP8?00oooo0?ooo`0I0?oo
o`03o`00003oool0oooo01P0oooo00?o00000?ooo`3oool00P3oool00onP8?00oooo0?ooo`1;0?oo
o`03oj0Pl03oool0oooo00X0oooo0onP8?000`3oooooX23`oj0Pl0020?ooo`04oomo003oool0oooo
0?ooo`?oX23`00@0oooooj0Pl03oooooX23`503oool00oooO`00oooo0?ooo`0[0?ooo`03o`00003o
ool0oooo00P0oooo000?0?ooo`03o`00003oool0oooo01P0oooo00?oX23`0?ooo`3oool0103oool0
0onP8?00oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo0080oooo00OoX23`0?ooo`3oool0oooooj0P
l03oooooX23`00H0oooo00CoX23`0?ooo`3oooooX23`1`3oool00onP8?00oooooj0Pl0040?ooo`;o
X23`0P3oool00onP8?00oooooj0Pl0040?ooo`;oogl00ol000030?ooo`04oj0Pl03oool0ooooo`00
02X0oooo00?o00000?ooo`3oool0603oool00ol00000oooo0?ooo`0C0?ooo`03oomo003oool0oooo
03H0oooo00WoX23`0?ooo`3oool0oooooj0Pl03oooooogl00?ooooooO`001P3oool01_nP8?00oooo
0?ooo`3oooooogl0oj0Pl0D0oooo00?oX23`0?oooonP8?000`3oool01OnP8?00oooo0?oooonP8?3o
ogl00080oooo00?oogl00?ooo`3oool0?03oool00ol00000oooo0?ooo`080?ooo`003`3oool00ol0
0000oooo0?ooo`0;0?ooo`03oj0Pl03oool0oooo01h0oooo00?oX23`0?ooo`3oool03`3oool00onP
8?00oooo0?ooo`020?ooo`03o`000?nP8?00oooo00D0oooo00?oX23`0?ooo`3oool00`3oool2oj0P
l003oomo003oool0oooo00@0oooo0_nP8?000oooO`00oooooomo00030?ooo`;oX23`0`3oool00onP
8?00oooo0?ooo`020?ooo`?o00000P3oool2oj0Pl080oooo00GoX23`0?ooo`3oool0ooooo`000007
0?ooo`03oj0Pl03oool0oooo0200oooo00?o00000?ooo`3oool05`3oool00ol00000oooo0?ooo`05
0?ooo`03oj0Pl03oool0oooo00`0oooo00?oogl00?ooo`3oool0:03oool00onP8?00oooo0?ooo`07
0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0103oool2oj0Pl080oooo00GoX23`
0?oooonP8?3oX23`0?ooo`02oj0Pl0070?oooonP8?00oooooomo003oooooX23`0?ooo`02oj0Pl0<0
oooo00CoX23`oomo003oool0oooo0_nP8?000oooO`3oX23`0?ooo`020?ooo`03oj0Pl03oooooX23`
00`0oooo00?oogl00?ooo`3oool0:@3oool00ol00000oooo0?ooo`080?ooo`003`3oool00ol00000
oooo0?ooo`0:0?ooo`;oX23`00<0oooooj0Pl?nP8?001@3oool00onP8?00oooo0?ooo`0W0?ooo`03
oj0Pl03oool0oooo0080oooo00Co00000?ooo`3oooooX23`203oool00oooO`00oooo0?ooo`030?oo
o`?oX23`0`3oool2oj0Pl0030?oooonP8?00oooo00D0oooo00?oX23`0?ooo`3oool01?l000001onP
8?00oooo0?ooo`3oooooX23`0?oooonP8?00103oool01_nP8?00oooo0?ooool0003oogl0oj0Pl2L0
oooo00?o00000?ooo`3oool05`3oool00ol00000oooo0?ooo`0W0?ooo`03oj0Pl03oool0oooo02X0
oooo00CoX23`0?oooonP8?3oogl00P3oool01_nP8?00oooo0?ooo`3oooooX23`0?ooo`CoX23`0`3o
ool01OnP8?00oooo0?ooo`3oooooX23`00<0oooo00?oX23`0?oooonP8?00103oool2oj0Pl0H0oooo
00?oogl00?ooo`3oool0<@3oool00ol00000oooo0?ooo`080?ooo`003P3oool00ol00000oooo0?oo
o`0U0?ooo`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3oool04`3oool00ol00000oooo0?oo
o`020?ooo`03oj0Pl03oool0oooo00;oX23`0`3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03o
ool0oooo00?oX23`1@3oool01OnP8?00oooo0?oooonP8?00oooo00?o000000D0oooooj0Pl03oool0
oooooj0Pl0020?ooo`;oX23`0`3oool2oj0Pl0D0oooo00?o00000?ooo`3oool09P3oool00ol00000
oooo0?ooo`0G0?ooo`03o`00003oool0oooo0080oooo00?oX23`0?ooo`3oool0CP3oool01?nP8?00
oooooj0Pl?ooO`02oj0Pl0<0oooo00Coogl00?ooo`3oool0oooo0_nP8?000oooO`3oX23`0?ooo`02
oj0Pl0030?oooonP8?00oooo00CoX23`1`3oool00onP8?00oooo0?ooo`020?ooo`;oX23`00<0oooo
oj0Pl03oool0<`3oool00ol00000oooo0?ooo`080?ooo`003P3oool00ol00000oooo0?ooo`0:0?oo
o`03oj0Pl03oool0oooo01@0oooo00?oX23`0?ooo`3oool0803oool00ol00000oooo0?ooo`020?oo
o`03oj0Pl03oooooX23`0080oooo00OoX23`0?ooo`3oool0oooooomo003oooooogl000;oX23`103o
ool00oooO`3oX23`0?ooo`03oj0Pl0030?oooonP8?3o000000;o000000<0oooooomo003oool00_nP
8?030?ooo`;oX23`00D0oooooomo0?ooO`00oooooj0Pl0020?ooo`?oX23`0P3oool00ol00000oooo
0?ooo`020?ooo`03oj0Pl03oool0oooo0240oooo00?o00000?ooo`3oool05`3oool00ol00000oooo
0?ooo`1B0?ooo`03oj0Pl03oooooX23`0080oooo0_nP8?000`3oooooX23`0?ooo`02oomo00T0oooo
00CoX23`0?ooo`3oooooX23`2@3oool00onP8?00oooooj0Pl0050?ooo`03oj0Pl03oool0oooo03<0
oooo00?o00000?ooo`3oool0203oool000h0oooo00?o00000?ooo`3oool0303oool00onP8?00oooo
0?ooo`0]0?ooo`03oj0Pl03oool0oooo00D0oooo00?o00000?ooo`3oool0203oool01OnP8?00oooo
oj0Pl03oooooX23`0080oooo0_ooO`030?ooo`;oX23`00<0oooooj0Pl?l000000ol000020?ooo`07
oomo0?nP8?00oooo0?oooonP8?00oooooomo00020?ooo`07oj0Pl03oool0oooo0?oooonP8?00oooo
oj0Pl0040?ooo`05oj0Pl?ooO`3oX23`0?ooool00000103oool00oooO`00oooo0?ooo`0P0?ooo`03
o`00003oool0oooo01L0oooo00?o00000?ooo`3oool0BP3oool00onP8?00oooo0?ooo`0:0?ooo`04
oj0Pl03oool0oooooomo00<0oooo0_nP8?030?ooo`03oomo003oool0oooo00;oX23`1`3oool4oj0P
l280oooo00?oX23`0?ooo`3oool06P3oool00ol00000oooo0?ooo`080?ooo`003P3oool00ol00000
oooo0?ooo`140?ooo`03o`00003oooooX23`01@0oooo00KoX23`o`000?l0003o0000oomo0?nP8?04
0?ooo`;oX23`00H0oooooj0Pl03oool0oooooj0Pl03oool3oj0Pl0H0oooo00?oX23`0?ooo`3oool0
0P3oool01_ooO`3oX23`0?ooool00000oooooomo02@0oooo00?o00000?ooo`3oool05`3oool00ol0
0000oooo0?ooo`1=0?ooo`05oj0Pl03oool0oooo0?oooonP8?000P3oool00onP8?00oooo0?ooo`02
oj0Pl0;oogl00P3oool00oooO`00oooo0?ooo`040?ooo`06oj0Pl03oooooX23`0?oooonP8?00oooo
1OnP8?020?ooo`;oX23`0P3oool00onP8?00oooooj0Pl0090?ooo`04oj0Pl03oool0oooooj0Pl0H0
oooo00?oogl00?ooo`3oool0903oool00ol00000oooo0?ooo`080?ooo`003P3oool00ol00000oooo
0?ooo`0=0?ooo`03oj0Pl03oool0oooo03@0oooo00?o00000?ooo`3oool02@3oool00onP8?00oooo
oj0Pl0020?ooo`04oomo003oool0oooo0?ooo`?o00000_nP8?00103oooooogl0oj0Pl?nP8?020?oo
o`03oj0Pl03oooooX23`0080oooo00?oogl0oj0Pl03oool01@3oool01OnP8?00oooo0?ooo`3ooooo
X23`00@0oooo0_nP8?030?ooo`03o`000?nP8?00oooo00/0oooo00?oogl00?ooo`3oool05@3oool0
0ol00000oooo0?ooo`0G0?ooo`03o`00003oool0oooo02H0oooo00?oogl00?ooo`3oool0;P3oool0
1OnP8?00oooo0?ooooooO`00oooo00;oX23`00Koogl00?ooo`3oooooX23`0?oooonP8?030?ooo`03
oj0Pl03oool0oooo0080oooo0_nP8?001@3oooooX23`oj0Pl03oooooX23`0080oooo00GoX23`0?oo
o`3oool0oooooj0Pl0020?ooo`03oj0Pl03oooooX23`03<0oooo00?o00000?ooo`3oool0203oool0
00h0oooo00?o00000?ooo`3oool03`3oool00onP8?00oooo0?ooo`0b0?ooo`03o`00003oool0oooo
00<0oooo00?oX23`0?ooo`3oool02@3oool3o`0000060?oooonP8?00oooooj0Pl03oooooogl01P3o
ool00onP8?00oooo0?ooo`020?ooo`;oX23`00@0oooooj0Pl03oool0oooo0_nP8?040?ooo`03oomo
0?nP8?00oooo00@0oooo00CoX23`0?ooo`3ooooo00000P3oool00onP8?00oooooomo000O0?ooo`03
o`00003oool0oooo01L0oooo00?o00000?ooo`3oool01@3oool00onP8?00oooo0?ooo`0f0?ooo`03
oj0Pl03oool0oooo01<0oooo0_nP8?040?ooo`?oX23`1P3oool02OooO`3oX23`oomo0?ooO`00oooo
oj0Pl03oooooX23`oomo00040?ooo`03oj0Pl03oooooX23`0080oooo0_nP8?00103oooooX23`oj0P
l03oool2oj0Pl0T0oooo00?oX23`0?ooo`3oool0:@3oool00ol00000oooo0?ooo`080?ooo`003P3o
ool00ol00000oooo0?ooo`0D0?ooo`03oj0Pl03oool0oooo02`0oooo00Co00000?ooo`3oooooX23`
2`3oool4o`000080oooo0onP8?00103oooooX23`0?ooooooO`02oj0Pl003oomo0?nP8?00oooo00;o
X23`00D0oooooj0Pl?nP8?00oooooomo00040?ooo`04oomo003oooooX23`oj0Pl0H0oooo0onP8?05
0?ooo`03o`00003oool0oooo00D0oooo00?oX23`0?ooo`3oool06P3oool00ol00000oooo0?ooo`0F
0?ooo`03o`00003oool0oooo05P0oooo00OoX23`0?ooo`3oool0oooooj0Pl03oooooogl000D0oooo
00?oogl00?ooo`3oool0103oool00onP8?00oooooj0Pl0040?ooo`03oj0Pl03oool0oooo01@0oooo
00?oogl00?ooo`3oool08@3oool00oooO`00oooo0?ooo`020?ooo`03o`00003oool0oooo00P0oooo
000=0?ooo`03o`00003oool0oooo04@0oooo00Go00000?oooonP8?00oooooj0Pl0060?ooo`08oj0P
l?l0003o0000o`00003oooooX23`0?oooonP8?030?ooo`;oX23`0P3oool01OooO`00oooo0?ooo`3o
ooooogl00080oooo00?oX23`0?ooo`3oool00`3oool01?nP8?00oooooj0Pl?ooO`030?ooo`03oj0P
l03oooooX23`0080oooo00?oX23`0?ooooooO`000`3oool4oj0Pl0030?ooool00000oooo00X0oooo
00?oogl00?ooo`3oool05P3oool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo01d0oooo
00?oogl00?ooo`3oool0=@3oool00onP8?00oooo0?ooo`020?ooo`?oX23`00<0oooooj0Pl?ooO`00
0P3oool00oooO`3oX23`0?ooo`0@0?ooo`03oj0Pl03oool0oooo00;oX23`>03oool00ol00000oooo
0?ooo`080?ooo`003@3oool00ol00000oooo0?ooo`0H0?ooo`03oj0Pl03oool0oooo02T0oooo00?o
00000?ooo`3oool01P3oool3o`0000X0oooo00Coogl00?oooonP8?3oX23`0P3oool00onP8?00oooo
0?ooo`030?ooo`03oomo003oooooX23`00<0oooo00CoX23`0?oooonP8?3oogl01?nP8?030?ooo`04
oj0Pl03oooooogl0oj0Pl0D0oooo00GoX23`0?ooo`3ooooo0000oj0Pl0080?ooo`03oomo003oool0
oooo01L0oooo00?o00000?ooo`3oool05P3oool00ol00000oooo0?ooo`1G0?ooo`03oj0Pl03ooooo
X23`0080oooo00KoX23`0?ooooooO`3oogl00?oooonP8?030?ooo`03oj0Pl03oool0oooo00<0oooo
0onP8?020?ooo`03oj0Pl03oooooX23`00@0oooo1_nP8?040?ooo`03oj0Pl03oooooX23`01T0oooo
00?oX23`0?ooo`3oool04P3oool00ol00000oooo0?ooo`080?ooo`003@3oool00ol00000oooo0?oo
o`0?0?ooo`04oj0Pl03oool0oooooj0Pl340oooo00?oX23`0?ooo`3oool00P3oool4o`0000P0oooo
00?oX23`0?oooonP8?000`3oool01?ooO`00oooo0?ooo`3oool2oj0Pl0;oogl0203oool2oj0Pl0D0
oooo0_nP8?000`3oooooX23`0?ooo`030?ooo`06oj0Pl03oool0oooooj0Pl?ooO`00oooo0_nP8?00
103oooooX23`o`000?nP8?0Q0?ooo`03o`00003oool0oooo01H0oooo00?o00000?ooo`3oool0G`3o
ool01OnP8?00oooo0?ooo`3oooooogl000L0oooo00CoX23`0?oooonP8?3oX23`0`3oool2oj0Pl0<0
oooo00CoX23`0?oooonP8?00oooo0_nP8?020?ooo`03oj0Pl03oool0oooo00@0oooo00?oogl00?oo
o`3oool01P3oool01OooO`00oooo0?ooo`3oooooX23`01h0oooo00?o00000?ooo`3oool0203oool0
00d0oooo00?o00000?ooo`3oool0;P3oool00onP8?00oooo0?ooo`0C0?ooo`03o`00003ooooo0000
00;o00001P3oool00onP8?00oooo0?ooo`080?ooo`04oj0Pl03oool0oooooj0Pl0;oogl000H0oooo
oj0Pl?nP8?3oogl00?oooonP8?050?ooo`03oj0Pl03oool0oooo00@0oooo0_ooO`090?ooo`03oj0P
l03oool0oooo0080oooo0_nP8?00103ooooo0000oj0Pl?nP8?0O0?ooo`03o`00003oool0oooo01H0
oooo00?o00000?ooo`3oool0803oool00onP8?00oooo0?ooo`060?ooo`03oj0Pl03oool0oooo02`0
oooo00GoX23`0?oooonP8?00oooooj0Pl0020?ooo`07oomo0?nP8?3oogl00?oooonP8?00oooooj0P
l0040?ooo`05oj0Pl03oooooogl00?ooooooO`000`3oool00onP8?00oooooomo0003oj0Pl0030?oo
oonP8?00oooo00CoX23`1`3oool01OnP8?00oooooj0Pl03oooooX23`02L0oooo00?o00000?ooo`3o
ool0203oool000d0oooo00?o00000?ooo`3oool09@3oool00onP8?00oooo0?ooo`0A0?ooo`03oj0P
l03oool0oooo00<0oooo00CoX23`0?ooo`3oool0oooo0ol0000D0?ooo`04oj0Pl03oool0oooooj0P
l0<0oooo00Coogl00?ooooooO`00oooo0_ooO`000onP8?00oooo0?ooo`020?ooo`03oomo003oool0
oooo00@0oooo00?oogl00?ooo`3oool02@3oool01OooO`3oX23`0?ooooooO`00oooo00;oX23`00?o
00000?ooo`3oool07P3oool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo05h0oooo00So
X23`0?ooo`3oooooX23`0?oooonP8?00oooooj0Pl080oooo00?oX23`0?ooo`3oool00onP8?000`3o
ooooX23`oj0Pl0040?ooo`03oj0Pl03oool0oooo00T0oooo00?oogl00?ooo`3oool07@3oool00ooo
O`00oooo0?ooo`0>0?ooo`03o`00003oool0oooo00P0oooo000=0?ooo`03o`00003oool0oooo01`0
oooo00?oX23`0?ooo`3oool08@3oool3o`0000040?ooool00000oooooj0Pl0l0oooo00?oX23`0?oo
o`3oool00P3oool00onP8?00oooo0?ooo`020?ooo`;oX23`0P3oool00onP8?00oooooj0Pl0060?oo
o`06oomo003oooooogl00?oooonP8?00oooo0onP8?000`3oooooX23`0?ooo`020?ooo`03oj0Pl03o
ool0oooo0080oooo1?nP8?00103oooooX23`o`000?nP8?030?ooo`03oj0Pl03oool0oooo01T0oooo
00?o00000?ooo`3oool05P3oool00ol00000oooo0?ooo`0[0?ooo`03oj0Pl03oool0oooo0300oooo
0_nP8?030?ooo`05oj0Pl03oool0oooo0?ooooooO`000P3oool00onP8?00oooo0?ooo`050?ooo`03
oj0Pl03oool0oooo00;oX23`0`3oool00onP8?00oooo0?ooo`04oj0Pl0040?oooonP8?3oX23`0?oo
o`;oX23`:`3oool00ol00000oooo0?ooo`080?ooo`00303oool00ol00000oooo0?ooo`0C0?ooo`03
oj0Pl03oool0oooo01/0oooo00?oX23`0?ooo`3oool02@3oool4o`0000@0oooo00?o00000?ooo`3o
ool0503oool3oj0Pl0030?oooonP8?3oX23`0080oooo00?oogl00?oooonP8?000`3oool01?nP8?00
oooo0?oooonP8?060?ooo`03oomo003oool0oooo00;oogl0103oool00onP8?00oooo0?ooo`020?oo
o`03oomo003oool0oooo0080oooo00?oX23`o`000?ooO`000_ooO`0M0?ooo`03o`00003oool0oooo
01D0oooo00?o00000?ooo`3oool0E@3oool00onP8?00oooo0?ooo`0=0?ooo`03oj0Pl03oool0oooo
00P0oooo00?oogl00?ooo`3oool00`3oool2oj0Pl0D0oooo00CoX23`0?oooonP8?00oooo0_nP8?03
0?ooo`05oj0Pl03oool0oooo0?oooonP8?009`3oool00ol00000oooo0?ooo`080?ooo`00303oool0
0ol00000oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo02T0oooo0ol000080?ooo`03o`00003oool0
oooo00`0oooo00?oX23`0?ooo`3oool01P3oool00onP8?00oooo0?ooo`0;0?ooo`;oX23`0`3oool0
1OnP8?00oooo0?ooooooO`3oX23`00L0oooo00?oogl00?ooo`3oool01P3oool01OooO`3oX23`0?oo
o`3ooooo00000080oooo0_nP8?0K0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool0
5@3oool00onP8?00oooo0?ooo`0A0?ooo`03oj0Pl03oool0oooo00/0oooo00?oX23`0?ooo`3oool0
5`3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00H0oooo00?oogl00?ooooooO`00
0P3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?oooonP8?00
1@3oool2oj0Pl0@0oooo00?oX23`0?ooo`3oool01@3oool00oooO`00oooo0?ooo`0B0?ooo`03oomo
003oool0oooo00l0oooo00?o00000?ooo`3oool0203oool000`0oooo00?o00000?ooo`3oool04@3o
ool00onP8?00oooo0?ooo`0S0?ooo`?o00002`3oool00ol00000oooo0?ooo`060?ooo`03oj0Pl03o
ool0oooo00l0oooo0_nP8?000`3oooooX23`0?ooo`040?ooo`05oj0Pl?ooO`00oooo0?oooonP8?00
0P3oool00onP8?00oooo0?ooo`02oj0Pl0030?ooooooO`00oooo00D0oooo00?oX23`0?ooo`3oool0
1`3oool02?ooO`3oX23`0?ooool00000oooooj0Pl03oooooX23`6P3oool00ol00000oooo0?ooo`0E
0?ooo`03o`00003oool0oooo01L0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`0f
0?ooo`03oomo0?nP8?00oooo00D0oooo0onP8?030?ooo`03oomo0?nP8?00oooo0080oooo00CoX23`
0?oooonP8?00oooo0_nP8?000`3oooooX23`oomo00030?ooo`?oX23`0P3oool00onP8?00oooooj0P
l0020?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?oooonP8?000P3oool00oooO`00oooo0?oo
o`040?ooo`03oomo003oool0oooo01/0oooo00?o00000?ooo`3oool0203oool000`0oooo00?o0000
0?ooo`3oool0<`3oool4o`0000h0oooo00?o00000?ooo`3oool01`3oool00onP8?00oooo0?ooo`0A
0?ooo`;oX23`0`3oool01?nP8?00oooo0?ooo`3oool2oomo00030?oooonP8?3oX23`00@0oooo00Go
X23`0?oooonP8?00oooooj0Pl0020?ooo`05oomo003oool0oooo0?ooooooO`001P3oool01_ooO`3o
X23`0?ooo`3ooooo0000oomo00?oX23`6@3oool00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0
oooo05d0oooo0_nP8?030?ooo`04oj0Pl03oool0oooooj0Pl080oooo0_ooO`02oj0Pl0H0oooo00Co
X23`0?ooo`3oooooX23`2`3oool00onP8?3oogl0oj0Pl0040?ooo`03oj0Pl03oool0oooo02L0oooo
00?o00000?ooo`3oool0203oool000`0oooo00?o00000?ooo`3oool04@3oool00onP8?00oooo0?oo
o`0L0?ooo`?o00004P3oool00ol00000oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo00h0oooo0_nP
8?02oomo0004oj0Pl03oooooX23`oj0Pl080oooo00?oX23`0?ooo`3oool01@3oool02_nP8?3oogl0
0?ooooooO`00oooooj0Pl03oooooX23`0?oooonP8?040?ooo`;oX23`0P3oool01?ooO`3o00000?oo
oonP8?0J0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool00`3oool00onP8?00oooo
0?ooo`030?ooo`03oj0Pl03oool0oooo05P0oooo00?oX23`0?ooo`3oool00P3oool01OnP8?3oogl0
oj0Pl?ooO`00oooo00?oX23`0P3oool01OnP8?00oooooj0Pl03oooooX23`0080oooo00?oogl0oj0P
l03oool00P3oool01OooO`3oX23`0?ooo`3oooooX23`00@0oooo00?oX23`0?ooo`3oool03P3oool0
0oooO`00oooo0?ooo`0F0?ooo`03o`00003oool0oooo00P0oooo000<0?ooo`03o`00003oool0oooo
0180oooo00?oX23`0?ooo`3oool0603oool3o`0001D0oooo00?o00000?ooo`3oool0403oool00onP
8?00oooo0?ooo`070?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo00GoX23`0?ooo`3oooooX23`oomo
00030?ooo`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3oool00P3oool2oj0Pl080oooo00?o
X23`0?ooo`3oool00P3oool02?nP8?00oooo0?ooo`3ooooo0000oj0Pl03oooooX23`6@3oool00ol0
0000oooo0?ooo`0E0?ooo`03o`00003oool0oooo02h0oooo00?oogl00?ooo`3oool0=`3oool2oj0P
l0030?oooonP8?3oogl000D0oooo00CoX23`0?ooooooO`3oX23`203oool00oooO`00oooooomo0005
0?ooo`03oomo003oool0oooo00h0oooo00?oogl00?ooo`3oool0603oool00ol00000oooo0?ooo`08
0?ooo`002`3oool00ol00000oooo0?ooo`0I0?ooo`03oj0Pl03oool0oooo00l0oooo0ol0000H0?oo
o`03o`00003oool0oooo01l0oooo00?oX23`0?ooo`3oool00_ooO`001@3oooooX23`oj0Pl?ooO`3o
X23`00<0oooo00CoX23`0?ooo`3oooooX23`0`3oool00onP8?00oooo0?ooo`020?ooo`03oomo003o
ooooX23`00H0oooo00GoX23`oomo0?nP8?00ooooo`0000060?ooo`03oomo003oool0oooo0180oooo
00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`1e0?ooo`03oj0Pl03oool0oooo00@0oooo
00?oX23`0?ooo`3oool0103oool2oj0Pl1<0oooo00?oX23`0?ooo`3oool05`3oool00ol00000oooo
0?ooo`080?ooo`002`3oool00ol00000oooo0?ooo`0A0?ooo`03oj0Pl03oool0oooo01<0oooo1?l0
000K0?ooo`03o`00003oool0oooo01D0oooo00?oX23`0?ooo`3oool01@3oool4oj0Pl0030?oooonP
8?00oooo0080oooo00?oogl00?ooooooO`000P3oool3oj0Pl003oomo003oool0oooo00<0oooo00Co
X23`0?ooo`3oooooX23`0P3oool2oomo00030?oooonP8?00oooo0080oooo00KoX23`0?ooo`3ooooo
ogl0oj0Pl?l000020?ooo`03oj0Pl03oool0oooo01H0oooo00?o00000?ooo`3oool0503oool00ol0
0000oooo0?ooo`0X0?ooo`03oomo003oool0oooo03l0oooo0_nP8?000oooO`3oX23`0?ooo`030?oo
o`04oj0Pl03oool0oooooj0Pl0;oogl000D0oooooomo003oool0oooooj0Pl0020?ooo`05oomo003o
ool0oooo0?oooonP8?000P3oool00onP8?00oooo0?ooo`040?ooo`04oj0Pl03oool0oooooomo00<0
oooo00?oogl00?ooooooO`001@3oool00oooO`00oooo0?ooo`0C0?ooo`03o`00003oool0oooo00P0
oooo000;0?ooo`03o`00003oool0oooo02@0oooo0ol0000O0?ooo`03o`00003oool0oooo0180oooo
00?oX23`0?ooo`3oool0403oool01_nP8?3oogl0oomo0?nP8?3oogl00?ooo`?oX23`00<0oooooj0P
l03oool00P3oool00onP8?00oooo0?ooo`02oj0Pl0030?oooonP8?00oooo00X0oooo00?oogl00?oo
ool000000P3oool00onP8?00oooo0?ooo`0E0?ooo`03o`00003oool0oooo01@0oooo00?o00000?oo
o`3oool0;03oool00oooO`00oooo0?ooo`0l0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?oo
oonP8?001@3oool00onP8?00oooooj0Pl0060?ooo`03oj0Pl03oooooX23`00@0oooo00?oX23`0?oo
o`3oool00`3oool00oooO`00oooo0?ooo`0Q0?ooo`03o`00003oool0oooo00P0oooo000;0?ooo`03
o`00003oool0oooo01@0oooo00?oX23`0?ooo`3oool0103oool00onP8?00oooo0?ooo`030?ooo`?o
00008P3oool00ol00000oooo0?ooo`0Q0?ooo`;oX23`0`3oool00onP8?3oogl00?ooo`020?ooo`?o
X23`0`3oool2oj0Pl003oomo0?nP8?00oooo0080oooo00SoX23`0?ooo`3oool0oooooj0Pl03ooooo
X23`oomo00P0oooo00?o00000?oooonP8?005`3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003o
ool0oooo03P0oooo00?oX23`0?ooo`3oool0:`3oool00onP8?00oooooj0Pl0020?ooo`03oj0Pl?oo
O`3oX23`0080oooo00GoX23`0?oooonP8?00oooooj0Pl0020?ooo`03oomo003oooooX23`00<0oooo
0_nP8?020?ooo`03oj0Pl03oool0oooo0080oooo00Googl00?oooonP8?00oooooj0Pl00W0?ooo`03
o`00003oool0oooo00P0oooo000;0?ooo`03o`00003oool0oooo01d0oooo1?l0000U0?ooo`03o`00
003oool0oooo0200oooo00?oX23`0?oooonP8?001`3oool00onP8?3oogl0oomo0002oj0Pl004oomo
003oooooX23`0?ooo`;oX23`00?oogl00?ooo`3oool00_nP8?001@3oooooogl00?ooo`3oooooX23`
0080oooo00Coogl0oj0Pl?nP8?3oX23`0`3oool00ol00000oooo0?ooo`0G0?ooo`03o`00003oool0
oooo01@0oooo00?o00000?ooo`3oool0;`3oool00oooO`00oooo0?ooo`0n0?ooo`05oj0Pl03oool0
oooooomo003oool00_nP8?050?ooo`03oj0Pl03oool0oooo00H0oooo00Koogl00?ooo`3oooooX23`
0?oooonP8?0W0?ooo`03o`00003oool0oooo00P0oooo000;0?ooo`03o`00003oool0oooo01<0oooo
00CoX23`0?ooo`3oooooX23`0`3oool3o`0002T0oooo00?o00000?ooo`3oool09`3oool00onP8?00
oooo0?ooo`030?ooo`03oj0Pl03oooooogl000?oX23`00@0oooooomo0?nP8?3oX23`1@3oool01Ooo
O`00oooo0?ooo`3oooooX23`0080oooo0onP8?030?ooo`04o`00003oooooX23`oj0Pl0D0oooo00?o
ogl00?ooo`3oool03@3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo07D0oooo00?o
X23`0?ooo`3oool01P3oool00oooO`00oooo0?ooo`070?ooo`?oX23`303oool00oooO`00oooo0?oo
o`0H0?ooo`03o`00003oool0oooo00P0oooo000;0?ooo`03o`00003oool0oooo0140oooo00?oX23`
0?ooo`3oool00`3oool3o`0002`0oooo00?o00000?ooo`3oool05P3oool2oj0Pl0@0oooo00?oX23`
0?ooo`3oool02`3oool00onP8?00oooooomo0002oomo00@0oooo1?nP8?000`3oooooogl00?ooo`02
oj0Pl0050?oooonP8?3oX23`0?oooonP8?000_ooO`000`3oooooogl0oomo00040?ooo`03o`00003o
ool0oooo01D0oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?ooo`0c0?ooo`03oj0Pl03o
ooooX23`03L0oooo00OoX23`0?ooo`3oooooogl00?oooonP8?00oooo00;oX23`00Coogl0oj0Pl?nP
8?3oX23`0P3oool2oj0Pl003oomo003oool0oooo00?oX23`0P3oool2oj0Pl080oooo1?nP8?0D0?oo
o`03oomo003oool0oooo00d0oooo00?o00000?ooo`3oool0203oool000X0oooo00?o00000?ooo`3o
ool05@3oool3o`0002l0oooo00?o00000?ooo`3oool07P3oool00onP8?00oooo0?ooo`040?ooo`03
oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool00P3oool2oj0Pl0030?oooonP8?00oooo0080
oooo00CoX23`0?ooo`3oool0oooo0onP8?040?ooo`03oj0Pl03oool0oooo00L0oooo00Co00000?oo
o`3oooooogl04`3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo06l0oooo00?oX23`
0?ooo`3oool0103oool5oj0Pl0D0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooo0?ooo`0Q
0?ooo`03o`00003oool0oooo00P0oooo000:0?ooo`03o`00003oool0oooo0140oooo1?l000050?oo
o`03oj0Pl03oool0oooo02X0oooo00?o00000?ooo`3oool01P3oool00onP8?00oooo0?ooo`0?0?oo
o`;oX23`4P3oool2oj0Pl0070?ooooooO`00oooo0?ooooooO`00oooooj0Pl0020?ooo`06oomo0?nP
8?3oogl0oj0Pl03oooooogl00P3oool01_ooO`00oooo0?ooo`3oooooX23`0?ooo`;oogl01@3oool0
0ol00000oooo0?ooo`050?ooo`03oomo003oool0oooo00/0oooo00?o00000?ooo`3oool0503oool0
0ol00000oooo0?ooo`0`0?ooo`03oj0Pl03oooooogl000;oogl08P3oool00onP8?00oooo0?ooo`0G
0?ooo`05oj0Pl?ooO`00oooo0?ooooooO`000`3oool4oj0Pl0D0oooo00?oX23`0?ooo`3oool00`3o
ool01?nP8?00oooooj0Pl03oool4oj0Pl0L0oooo00?oogl00?ooo`3oool0603oool00ol00000oooo
0?ooo`080?ooo`002P3oool00ol00000oooo0?ooo`0>0?ooo`?o00001@3oool00onP8?00oooo0?oo
o`050?ooo`03oj0Pl03oool0oooo02H0oooo00?o00000?ooo`3oool06`3oool00onP8?00oooo0?oo
o`0>0?ooo`04oomo003oool0oooo0?ooo`;oogl000@0oooooomo003oool0oooo0_nP8?020?ooo`08
oj0Pl03oool0oooooomo0?nP8?3oogl00?oooonP8?0;0?ooo`03o`00003oool0oooo01<0oooo00?o
00000?ooo`3oool04`3oool00ol00000oooo0?ooo`1d0?ooo`05oj0Pl03oool0oooooomo0?nP8?00
0`3oool00oooO`3oX23`0?ooo`030?ooo`05oj0Pl03oool0oooooj0Pl?ooO`001P3oool3oj0Pl003
oomo003oool0oooo01l0oooo00?o00000?ooo`3oool0203oool000X0oooo00?o00000?ooo`3oool0
2`3oool3o`0000P0oooo00?oX23`0?ooo`3oool0;@3oool00ol00000oooo0?ooo`0_0?ooo`03oj0P
l03oooooX23`0080oooo00Coogl00?oooonP8?3oX23`0P3oool2oomo00030?oooonP8?00oooo00D0
oooo00?oogl00?ooooooO`001`3oool00ol0003oogl00?ooo`0C0?ooo`03o`00003oool0oooo01<0
oooo00?o00000?ooo`3oool0JP3oool2oj0Pl0H0oooo00?oX23`0?ooo`3oool00_ooO`020?ooo`04
oomo003oool0oooo0?ooo`?oX23`00<0oooooj0Pl?nP8?000P3oool2oj0Pl0H0oooo00GoX23`0?oo
oonP8?3oX23`oomo000P0?ooo`03o`00003oool0oooo00P0oooo000:0?ooo`03o`00003oool0oooo
00L0oooo1?l0000k0?ooo`03o`00003oool0oooo01l0oooo00?oX23`0?ooo`3oool04`3oool01?oo
O`3oX23`0?ooo`3oool2oomo0003oj0Pl03oool0oooo00D0oooo00?oogl00?ooo`3oool00`3oool0
1?nP8?00oooooomo0?ooO`020?ooo`03o`00003oool0oooo0180oooo00?o00000?ooo`3oool04`3o
ool00ol00000oooo0?ooo`0c0?ooo`03oomo003oool0oooo03P0oooo00KoX23`0?ooo`3oool0oooo
oj0Pl03oool2oj0Pl0;oogl00P3oool4oj0Pl0<0oooo00?oX23`0?oooonP8?000`3oool00onP8?00
oooo0?ooo`030?ooo`CoX23`00@0oooooj0Pl03oooooogl07@3oool00ol00000oooo0?ooo`080?oo
o`002P3oool00ol00000oooo0?ooo`040?ooo`?o0000?`3oool00ol00000oooo0?ooo`0`0?ooo`;o
X23`00<0oooooj0Pl03oool00P3oool00oooO`00oooooomo00020?ooo`?oX23`00D0oooooj0Pl03o
ool0oooooomo000<0?ooo`03o`00003oool0oooo0140oooo00?o00000?ooo`3oool04`3oool00ol0
0000oooo0?ooo`1h0?ooo`?oogl00`3oool01OnP8?00oooo0?ooo`3oooooX23`00<0oooo00Coogl0
0?ooo`3oooooX23`0`3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oooooogl001d0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool00P3oool3o`000480oooo00?o0000
0?ooo`3oool00P3oool00onP8?00oooo0?ooo`0B0?ooo`03oj0Pl03oool0oooo01/0oooo00Coogl0
0?ooo`3oooooogl00_nP8?02oomo00030?ooooooO`00oooo00<0oooo00?oX23`0?ooo`3oool00`3o
ool01?ooO`00oooooomo0?ooO`040?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool0
4`3oool00ol00000oooo0?ooo`0e0?ooo`04oomo003oool0oooooj0Pl3@0oooo00CoX23`0?oooonP
8?3oX23`0P3oool02_ooO`00oooo0?ooo`3oooooX23`oomo0?nP8?3oogl0oj0Pl03oool4oj0Pl080
oooo00CoX23`0?ooo`3oool0oooo0_nP8?001@3oooooX23`0?ooo`3oooooX23`0080oooo00Googl0
0?oooonP8?00oooooj0Pl00M0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003ooooo
000000;o00005P3oool00onP8?00oooo0?ooo`0/0?ooo`03o`00003oool0oooo0340oooo0_nP8?02
0?ooo`04oomo003oool0oooooj0Pl0@0oooo00GoX23`0?ooo`3oool0oooooomo00040?ooo`;oogl0
0`3oool01?ooO`00oooo0?ooooooO`030?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool04`3oool00ol00000oooo0?ooo`1k0?ooo`03oomo003oool0oooo00<0oooo00?oogl0oj0Pl?nP
8?000`3oool01oooO`3oX23`0?ooo`3oooooogl00?oooonP8?00103oool00oooO`00oooooj0Pl00C
0?ooo`03oomo003oool0oooo00L0oooo00?o00000?ooo`3oool0203oool000T0oooo0_l000180?oo
o`03o`00003oool0oooo02L0oooo00?oX23`0?ooo`3oool0303oool00onP8?00oooooj0Pl0030?oo
o`;oogl000KoX23`0?ooo`3oooooogl00?ooooooO`050?ooo`Googl0103oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool02P3oool00oooO`00oooo0?oo
o`0[0?ooo`03oomo003oool0oooo03h0oooo0_nP8?001@3oooooX23`0?ooo`3oooooX23`0080oooo
00?oogl0oj0Pl03oool00_nP8?00103oooooX23`oj0Pl?nP8?020?ooo`;oX23`0`3oool3oj0Pl003
0?oooonP8?3oX23`01X0oooo00?o00000?ooo`3oool0203oool000/0oooo00?o00000?ooo`3oool0
6@3oool00onP8?00oooo0?ooo`0Y0?ooo`03o`00003oool0oooo02/0oooo00GoX23`0?ooo`3oool0
oooooj0Pl0080?ooo`;oX23`0P3oool00onP8?00oooooomo0002oomo0080oooo0_ooO`002P3ooooo
ogl00?ooo`3oooooogl00?ooooooO`00oooooomo003oool2oomo0080oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0B0?ooo`03o`00003oool0oooo0780oooo00?oX23`0?ooo`3oool0
0P3oool00onP8?00oooo0?ooo`020?ooo`08oomo003oooooogl00?ooooooO`3oX23`0?ooooooO`02
0?ooo`06oomo003oool0oooo0?ooooooO`3oX23`0P3oool01?ooO`3oX23`0?oooonP8?02oomo00?o
X23`6`3oool00ol00000oooo0?ooo`080?ooo`00303oool2o`0001T0oooo00?oX23`0?ooo`3oool0
:@3oool00ol00000oooo0?ooo`0^0?ooo`;oX23`00<0oooooomo0?nP8?00203oool01?nP8?00oooo
oomo003oool2oj0Pl0@0oooo00?oogl0oj0Pl?ooO`000_ooO`000`3oooooX23`0?ooo`020?ooo`03
oomo003oooooogl00080oooo00?o00000?ooo`3oool03P3oool00ol00000oooo0?ooo`0B0?ooo`03
o`00003oool0oooo07L0oooo0onP8?001OooO`00oooo0?ooo`3oooooogl000H0oooo0onP8?050?oo
o`03oj0Pl03oool0oooo00L0oooo00?oX23`0?ooo`3oool0603oool00ol00000oooo0?ooo`080?oo
o`003P3oool00ol00000oooo0?ooo`120?ooo`03o`00003oool0oooo02h0oooo00?oX23`0?ooo`3o
ool0103oool01onP8?00oooo0?oooonP8?00oooooomo003oool00_ooO`00203oooooX23`oj0Pl03o
ooooogl00?ooooooO`3oX23`0_ooO`020?ooo`?oogl000<0oooooomo003oool01@3oool00ol0003o
X23`0?ooo`0=0?ooo`03o`00003oool0oooo0180oooo00?o00000?ooo`3oool0>P3oool00onP8?00
oooo0?ooo`0e0?ooo`04oj0Pl03oool0oooo0?ooo`;oX23`0P3oool00oooO`3oX23`oj0Pl0020?oo
o`07oomo003oool0oooooj0Pl03oooooX23`oomo00020?ooo`;oX23`0`3oool02?nP8?00oooooj0P
l?nP8?00oooooomo003oooooX23`0P3oool00onP8?00oooo0?ooo`060?ooo`03oomo003oool0oooo
00D0oooo00?oogl00?ooo`3oool01`3oool00ol00000oooo0?ooo`080?ooo`003`3oool00ol00000
oooo0?ooo`110?ooo`03o`00003oool0oooo02/0oooo00?oX23`0?ooo`3oool0203oool00onP8?3o
ogl00?ooo`020?ooo`;oogl00P3oool2oomo0080oooo00?oX23`oomo0?nP8?000_ooO`030?ooo`;o
ogl000<0oooooomo003oool01P3oool00ol00000oooo0?ooo`0<0?ooo`03o`00003oool0oooo0180
oooo00?o00000?ooo`3oool0?P3oool00onP8?00oooo0?ooo`0h0?ooo`;oX23`00@0oooooj0Pl03o
ooooogl01P3oool00onP8?00oooo0?ooo`070?ooo`;oX23`8@3oool00ol00000oooo0?ooo`080?oo
o`00403oool2o`000440oooo00?o00000?ooo`3oool0=@3oool2oj0Pl0030?oooonP8?3oX23`0080
oooo00?oX23`0?ooo`3oool00`3oool00onP8?3oogl0oomo0006oomo00030?ooooooO`3oogl00080
oooo0_ooO`040?ooo`03o`00003oool0oooo00`0oooo00?o00000?ooo`3oool04P3oool00ol00000
oooo0?ooo`0l0?ooo`03oj0Pl03oool0oooo02@0oooo00?oX23`0?ooo`3oool04P3oool01?nP8?00
oooo0?ooo`3oool2oj0Pl0080?oooonP8?3oogl0oj0Pl?ooO`3oX23`0?oooonP8?070?ooo`04oomo
003oool0oooooomo00;oX23`0`3oool4oj0Pl0<0oooo00?oogl00?ooo`3oool04P3oool00ol00000
oooo0?ooo`080?ooo`004P3oool00ol00000oooo0?ooo`0C0?ooo`03oj0Pl03oool0oooo02P0oooo
00?o00000?ooo`3oool0>03oool01?nP8?00oooo0?oooonP8?020?ooo`04oj0Pl03oool0oooo0?oo
o`;oX23`00<0oooooj0Pl?nP8?001oooO`020?ooo`?oogl0103oool00ol00000oooo0?ooo`0;0?oo
o`03o`00003oool0oooo0180oooo00?o00000?ooo`3oool0O`3oool2oj0Pl003oomo003oooooX23`
00<0oooo00SoX23`0?ooo`3oooooX23`0?oooonP8?00oooooomo00X0oooo00?oX23`0?ooo`3oool0
5P3oool00ol00000oooo0?ooo`080?ooo`004`3oool2o`0003h0oooo00?o00000?ooo`3oool0=@3o
ool00onP8?00oooooj0Pl0020?ooo`04oj0Pl03oooooX23`oj0Pl080oooo00?oX23`0?ooo`3oool0
0onP8?000oooO`3oX23`0?ooo`03oomo00030?ooooooO`3oogl000;oogl000?oX23`0?ooo`3oool0
103oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo0180oooo00?o00000?ooo`3oool0
NP3oool2oj0Pl0090?oooonP8?00oooooj0Pl03oooooX23`0?ooooooO`00oooo00;oX23`0P3oool0
0oooO`00oooooomo00080?ooo`04oomo003oool0oooooomo0080oooo00?oX23`0?ooo`3oool05@3o
ool00ol00000oooo0?ooo`080?ooo`005@3oool00ol00000oooo0?ooo`0k0?ooo`03o`00003oool0
oooo00P0oooo00?oX23`0?ooo`3oool0<@3oool01?nP8?00oooooj0Pl?nP8?020?ooo`05oj0Pl?oo
O`3oX23`oomo0?nP8?001oooO`000`3oooooogl0oomo00020?ooo`03oomo003oool0oooo00<0oooo
00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0B0?ooo`03o`00003oool0oooo06l0oooo
00?oX23`0?ooo`3oool0303oool01?nP8?00oooo0?oooonP8?030?ooo`03oomo0?nP8?3oogl000@0
oooo00Coogl00?oooonP8?3oogl0103oool00oooO`00oooooomo00020?ooo`03oomo003oool0oooo
0080oooo00?oogl00?ooo`3oool04@3oool00ol00000oooo0?ooo`080?ooo`005P3oool00ol00000
oooo0?ooo`0@0?ooo`03oj0Pl03oool0oooo02L0oooo00?o00000?ooo`3oool0=P3oool01?nP8?00
oooo0?oooonP8?030?ooo`?oX23`00<0oooooomo003oool00`3oool00oooO`3oX23`0?ooo`05oomo
00030?ooooooO`3oogl000;oogl01`3oool00ol00000oooo0?ooo`090?ooo`03o`00003oool0oooo
0140oooo00?o00000?ooo`3oool01`3oool00onP8?00oooo0?ooo`1i0?ooo`03oj0Pl?ooO`3oX23`
0080oooo00Coogl00?ooooooO`3oogl00P3oool01oooO`00oooo0?ooooooO`00oooooomo0?nP8?00
0P3oool00oooO`00oooo0?ooo`02oj0Pl1H0oooo00?o00000?ooo`3oool0203oool001L0oooo0_l0
000@0?ooo`03oj0Pl03oool0oooo02L0oooo00?o00000?ooo`3oool07`3oool00onP8?00oooo0?oo
o`0A0?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3oool00P3oool01?nP8?00oooooj0P
l?ooO`060?ooo`Ooogl00P3oool2oomo00030?ooooooO`00oooo00<0oooo00?o00000?ooo`3oool0
203oool00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo06/0oooo00?oX23`0?ooo`3oool0
403oool00onP8?00oooo0?ooo`020?ooo`05oj0Pl03oooooogl0oomo003oool01OnP8?02oomo0006
oj0Pl?ooO`00oooooomo003oooooogl0103oool00oooO`00oooo0?ooo`0F0?ooo`03o`00003oool0
oooo00P0oooo000I0?ooo`03o`00003oool0oooo0200oooo00?oX23`0?ooo`3oool0503oool00ol0
0000oooo0?ooo`0l0?ooo`04oj0Pl03oool0oooo0?ooo`CoX23`2@3oool4oomo00040?ooooooO`3o
ogl0oomo00H0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`0A0?ooo`03o`00003o
ool0oooo04H0oooo00?oogl00?ooo`3oool0=`3oool00onP8?00oooo0?ooo`040?ooo`;oX23`00?o
ogl0oj0Pl03oool00oooO`000onP8?3oogl00?ooo`0P0?ooo`03o`00003oool0oooo00P0oooo000J
0?ooo`;o0000<P3oool00onP8?00oooo0?ooo`020?ooo`03o`00003oool0oooo0400oooo00?oX23`
0?ooo`3oool01?nP8?030?ooo`04oj0Pl03oool0oooo0?ooo`Soogl00`3oool01?ooO`00oooo0?oo
ool000090?ooo`03o`00003oool0oooo0140oooo00?o00000?ooo`3oool0OP3oool01?nP8?00oooo
0?oooonP8?020?ooo`07oj0Pl03oool0oooooomo0?nP8?3oogl0oj0Pl0020?ooo`03oj0Pl03ooooo
ogl00080oooo00?oX23`0?ooooooO`000_ooO`050?ooo`03oomo003oool0oooo01<0oooo00?o0000
0?ooo`3oool0203oool001`0oooo00?o00000?ooo`3oool0=03oool00ol00000oooo0?ooo`0m0?oo
o`06oj0Pl03oool0oooo0?oooonP8?00oooo1?nP8?060?ooo`06oj0Pl03oool0oooooj0Pl03ooooo
ogl02P3oool00ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo0140oooo00?o00000?ooo`3o
ool03`3oool2oj0Pl640oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?ooo`020?ooo`;o
X23`0`3oool00oooO`00oooooomo0004oj0Pl0?oogl000<0oooooomo0?nP8?000P3oool2oomo0003
0?ooooooO`00oooo0080oooo00?oogl00?ooo`3oool04@3oool00ol00000oooo0?ooo`080?ooo`00
7@3oool00ol00000oooo0?ooo`0c0?ooo`03o`00003oool0oooo0440oooo00CoX23`0?ooo`3ooooo
X23`0P3oool00onP8?00oooo0?ooo`080?ooo`05oomo0?nP8?3oogl00?ooooooO`001`3oool00ol0
0000oooo0?ooo`050?ooo`03o`00003oool0oooo0140oooo00?o00000?ooo`3oool04P3oool00onP
8?00oooo0?ooo`0`0?ooo`03oj0Pl03oool0oooo03/0oooo00OoX23`0?ooo`3oooooX23`oomo003o
ooooX23`0080oooo0_nP8?001?ooO`00oooo0?ooo`3oool2oomo00040?ooooooO`00oooo0?ooo`;o
ogl0603oool00ol00000oooo0?ooo`080?ooo`007P3oool2o`0000X0oooo00?oX23`0?ooo`3oool0
9P3oool00ol00000oooo0?ooo`180?ooo`;oX23`00<0oooooomo003oool00P3oool00onP8?00oooo
oj0Pl00=0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool04@3oool00ol00000oooo
0?ooo`240?ooo`03oj0Pl03oooooX23`00;oX23`00<0oooooomo0?nP8?000_ooO`001_nP8?3oogl0
oomo003oooooogl00?ooo`Koogl000@0oooooomo003oooooogl0503oool00ol00000oooo0?ooo`08
0?ooo`00803oool00ol00000oooo0?ooo`0`0?ooo`03o`00003oool0oooo0380oooo00?oX23`0?oo
o`3oool04`3oool01?nP8?00oooo0?oooonP8?070?ooo`05oomo003oool0oooo0?ooooooO`001`3o
ool01?l00000oooo0?ooooooO`040?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool0
503oool00oooO`00oooo0?ooo`1/0?ooo`03oj0Pl03oool0oooo00CoX23`1@3oool9oomo00030?oo
oonP8?00oooo00<0oooo00?oogl00?ooo`3oool04@3oool00ol00000oooo0?ooo`080?ooo`008@3o
ool2o`0000P0oooo00?oX23`0?ooo`3oool09@3oool00ol00000oooo0?ooo`0O0?ooo`03oj0Pl03o
ool0oooo03@0oooo00?oogl0oj0Pl?nP8?001`3oool00ol00000oooo0?ooo`040?ooo`03o`00003o
ool0oooo0100oooo00?o00000?ooo`3oool0OP3oool00onP8?00oooo0?ooo`060?ooo`CoX23`103o
ool00oooO`3oX23`oomo000;oomo01D0oooo00?o00000?ooo`3oool0203oool002<0oooo00?o0000
0?ooo`3oool0203oool01?nP8?00oooo0?oooonP8?0P0?ooo`04o`00003oool0oooooj0Pl2X0oooo
00?oX23`0?ooo`3oool04@3oool00onP8?00oooo0?ooo`0B0?ooo`04oj0Pl03oooooogl00?ooo`;o
X23`00<0oooooomo003oool01@3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo0100
oooo00?o00000?ooo`3oool0?@3oool00onP8?00oooo0?ooo`1:0?ooo`03oj0Pl03oool0oooo00@0
oooo00?oX23`oomo003oool00_ooO`001P3oooooogl0oomo0?ooO`00oooooomo01H0oooo00?o0000
0?ooo`3oool0203oool002@0oooo0_l0000/0?ooo`03o`00003oool0oooo0340oooo00?oX23`0?oo
o`3oool07P3oool00oooO`00oooo0?ooo`050?ooo`03oj0Pl03oooooogl000H0oooo00?o00000?oo
o`3oool00P3oool00ol00000oooo0?ooo`0@0?ooo`03o`00003oool0oooo01T0oooo00?oogl00?oo
o`3oool0L03oool00onP8?00oooo0?ooo`020?ooo`04oomo003oooooogl0oomo0080oooo0oooO`00
0`3oooooogl00?ooo`0E0?ooo`03o`00003oool0oooo00P0oooo000V0?ooo`03o`00003oool0oooo
02D0oooo00GoX23`0?ooo`3oool0ooooo`00000:0?ooo`03oj0Pl03oool0oooo04X0oooo00?oX23`
0?ooo`3oool00P3oool01_nP8?3oogl00?ooooooO`00oooooomo00@0oooo00Go00000?ooo`3oool0
ooooo`00000B0?ooo`03o`00003oool0oooo08`0oooo00?oX23`0?ooo`3oool00P3oool00oooO`00
oooooomo0007oomo0080oooo00?oogl00?ooo`3oool04P3oool00ol00000oooo0?ooo`080?ooo`00
9`3oool00ol00000oooo0?ooo`0<0?ooo`03oj0Pl03oool0oooo01T0oooo00?o00000?ooo`3oool0
C`3oool01OnP8?00oooo0?ooo`3oooooX23`00L0oooo0_ooO`000onP8?3oogl0oomo00050?ooo`04
o`000?ooO`00ooooo`000180oooo00?o00000?ooo`3oool0G`3oool00onP8?00oooo0?ooo`0Z0?oo
o`03oj0Pl03oooooX23`00D0oooo00?oX23`oomo003oool00_ooO`001@3oooooogl0oomo003ooooo
ogl000@0oooo00?oogl00?ooo`3oool03@3oool00ol00000oooo0?ooo`080?ooo`00:03oool2o`00
00D0oooo00?oX23`0?ooo`3oool0803oool00ol00000oooo0?ooo`1M0?ooo`;oX23`1P3oool01?l0
0000oooo0?ooool0000B0?ooo`03o`00003oool0oooo0900oooo00_oX23`0?ooo`3oool0oooooomo
0?nP8?00oooooj0Pl03oooooogl0oj0Pl005oomo0180oooo00?o00000?ooo`3oool0203oool002X0
oooo00?o00000?ooo`3oool00P3oool00onP8?00oooo0?ooo`0P0?ooo`03o`00003oool0oooo0600
oooo00?oX23`0?ooo`3oool00`3oool01?l00000oooo0?ooool0000A0?ooo`03o`00003oool0oooo
01d0oooo00?oogl00?ooo`3oool06P3oool00onP8?00oooo0?ooo`1O0?ooo`03oomo003oooooogl0
01<0oooo00?o00000?ooo`3oool0203oool002/0oooo0_l0000U0?ooo`03o`00003oool0oooo00/0
oooo00?oX23`0?ooo`3oool0D`3oool01?nP8?00oooo0?oooonP8?020?ooo`03o`00003ooooo0000
0140oooo00?o00000?ooo`3oool0U`3oool01?nP8?00oooo0?oooonP8?020?ooo`;oogl00P3oool0
0oooO`00oooooj0Pl00>0?ooo`03o`00003oool0oooo00P0oooo000]0?ooo`07o`00003oool0oooo
0?oooonP8?00oooooj0Pl0040?ooo`03oj0Pl03oool0oooo01L0oooo00?o00000?ooo`3oool02@3o
ool00onP8?00oooo0?ooo`0[0?ooo`03oj0Pl03oool0oooo02T0oooo00Googl00?ooo`3oool0oooo
oomo0002o`000140oooo00?o00000?ooo`3oool0P`3oool00onP8?00oooo0?ooo`0?0?ooo`03oj0P
l03oool0oooo0080oooo00?oogl0oj0Pl03oool00P3oool2oomo0100oooo00?oogl0o`00003oool0
2@3oool002h0oooo00?o00000?ooo`3oool01`3oool00onP8?00oooo0?ooo`0G0?ooo`03o`00003o
ool0oooo00l0oooo00?oX23`0?ooo`3oool0E03oool01?nP8?3oogl0oomo0?l0000A0?ooo`03o`00
003oool0oooo09L0oooo00?oogl0oj0Pl03oool00`3oool01?ooO`00oooooj0Pl?ooO`030?ooo`03
oomo003oool0oooo00/0oooo00?o00000?ooo`3oool0203oool002l0oooo0_l0000Q0?ooo`03o`00
003oool0oooo04D0oooo00?oX23`0?ooo`3oool06P3oool4o`000003oj0Pl03oool0oooo0180oooo
00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`00<@3oool00ol00000oooo0?oo
o`0N0?ooo`03o`00003oool0oooo04P0oooo00?oX23`0?ooo`3oool04P3oool00onP8?3o0000o`00
0002o`0001T0oooo00?o00000?ooo`3oool0TP3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03o
ool0oooo01L0oooo00?o00000?ooo`3oool0203oool00380oooo0_l0000N0?ooo`03o`00003oool0
oooo05X0oooo1?l0000M0?ooo`03o`00003oool0oooo09/0oooo00GoX23`0?ooo`3oool0oooooj0P
l00B0?ooo`03o`00003oool0oooo00P0oooo000d0?ooo`03o`00003oool0oooo01/0oooo00?o0000
0?ooo`3oool0E@3oool5o`000240oooo00?o00000?ooo`3oool0Q@3oool00onP8?00oooo0?ooo`0A
0?ooo`03oj0Pl03oool0oooo00;oogl00P3oool00onP8?00oooo0?ooo`0?0?ooo`03o`00003oool0
oooo00P0oooo000e0?ooo`05o`00003oool0oooo0?oooonP8?00603oool00ol00000oooo0?ooo`0^
0?ooo`03oj0Pl03oool0oooo0200oooo1?l0000V0?ooo`03o`00003oool0oooo0;80oooo00?o0000
0?ooo`3oool0203oool003H0oooo0_l000050?ooo`03oj0Pl03oool0oooo0180oooo00?o00000?oo
o`3oool0C@3oool4o`0002X0oooo00?o00000?ooo`3oool0WP3oool02?nP8?00oooo0?ooo`3ooooo
X23`oomo003oooooogl00P3oool00oooO`00oooo0?ooo`070?ooo`03o`00003oool0oooo00P0oooo
000h0?ooo`03o`00003oool0oooo01L0oooo00?o00000?ooo`3oool0B03oool5o`0002h0oooo00?o
00000?ooo`3oool0X@3oool01?nP8?3oogl00?ooooooO`0=0?ooo`03o`00003oool0oooo00P0oooo
000i0?ooo`;o00005`3oool00ol00000oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo02D0oooo1?l0
000c0?ooo`03o`00003oool0oooo0:80oooo0_ooO`02oj0Pl0030?ooooooO`00oooo00T0oooo00?o
00000?ooo`3oool0203oool003/0oooo00?o00000?ooo`3oool00P3oool01?nP8?00oooo0?oooonP
8?0>0?ooo`03o`00003oool0oooo0400oooo1?l0000g0?ooo`03o`00003oool0oooo0:D0oooo00Co
ogl00?ooo`3oooooogl02@3oool00ol00000oooo0?ooo`080?ooo`00?03oool2o`0001@0oooo00?o
00000?ooo`3oool0>`3oool5o`0003/0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?oo
o`080?ooo`00?P3oool00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo01P0oooo00?oX23`
0?ooo`3oool0703oool4o`000400oooo00?o00000?ooo`3oool0Y@3oool00onP8?00oooo0?ooo`0:
0?ooo`03o`00003oool0oooo00P0oooo000o0?ooo`03o`00003oool0oooo0100oooo00?o00000?oo
o`3oool0<P3oool5o`0004@0oooo00?o00000?ooo`3oool0Y`3oool00onP8?00oooo0?ooo`080?oo
o`03o`00003oool0oooo00P0oooo00100?ooo`;o0000403oool00ol00000oooo0?ooo`0H0?ooo`03
oj0Pl03oool0oooo01<0oooo1?l000190?ooo`03o`00003oool0oooo0:T0oooo00CoX23`0?oooooo
O`3oX23`1@3oool00ol00000oooo0?ooo`080?ooo`00@P3oool00ol00000oooo0?ooo`0=0?ooo`03
o`00003oool0oooo02X0oooo1?l0001=0?ooo`03o`00003oool0oooo0:80oooo00?oX23`0?ooo`3o
ool03@3oool00ol00000oooo0?ooo`080?ooo`00@`3oool2o`0000`0oooo00?o00000?ooo`3oool0
9P3oool5o`000540oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`00A@3o
ool00ol00000oooo0?ooo`090?ooo`03o`00003oool0oooo0280oooo1?l0001F0?ooo`03o`00003o
ool0oooo0:h0oooo0onP8?000`3ooooo00000?ooo`090?ooo`00AP3oool00ol00000oooo0?ooo`08
0?ooo`03o`00003oool0oooo01h0oooo1?l0001J0?oook7o000000GoX23`oomo0?l0003oX23`o`00
000:0?ooo`00A`3oool2o`0000P0oooo00?o00000?ooo`3oool06@3oool5o`000?l0oooo7`3oool0
04T0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0E0?ooo`Co0000o`3ooolT0?oo
o`00BP3oool2o`0000D0oooo00?o00000?ooo`3oool04@3oool4o`000?l0oooo:03oool004`0oooo
00?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<0?ooo`Go0000o`3oool/0?ooo`00C@3o
ool01Ol00000oooo0?ooo`3ooooo000000X0oooo1?l0003o0?oooc40oooo001>0?ooo`;o000000<0
ooooo`00003oool01@3oool4o`000?l0oooo=@3oool00500oooo0_l000000`3ooooo0000o`000003
o`000?l0oooo>@3oool00540oooo0_l0003o0?oooch0oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0500105, -0.0544783, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {422.812, 226.375}} -> {-13.5849, \
-25.7573, 1.41129, 1.41129}, {{208.5, 389.438}, {422.812, 226.375}} -> \
{-294.432, -25.7573, 1.41129, 1.41129}, {{9.5, 190.438}, {206.75, 10.3125}} -> \
{0.00361344, -1.07331, 0.00473966, 0.00473966}, {{208.5, 389.438}, {206.75, \
10.3125}} -> {-294.432, -330.684, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2d Gaussian classification (RG plane)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(which = {1, 2};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Show[gobj1, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Show[gobj2, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[g1, g2, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{g1, g2}], \ imSize, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.15686 .86275 Mdot
.30196 .71765 Mdot
.63922 .4902 Mdot
.58824 .43137 Mdot
.6902 .52549 Mdot
.30588 .72157 Mdot
.75294 .40784 Mdot
.66667 .42745 Mdot
.29412 .72157 Mdot
.5451 .25098 Mdot
.44706 .05098 Mdot
.61569 .48235 Mdot
.63529 .49412 Mdot
.81176 .07451 Mdot
.63137 .24706 Mdot
.58039 .42745 Mdot
.41569 .07059 Mdot
.84706 .08235 Mdot
.49804 .06275 Mdot
.57255 .43137 Mdot
.43922 .01569 Mdot
.79608 .08235 Mdot
.57255 .02745 Mdot
.61961 .49804 Mdot
.40392 .01569 Mdot
.62745 .03529 Mdot
.52549 .02745 Mdot
.8549 .83137 Mdot
.59216 .39216 Mdot
.61176 .01569 Mdot
.87059 .16863 Mdot
.49804 .01176 Mdot
.58431 .45882 Mdot
.54118 .01961 Mdot
.64706 .02745 Mdot
.69412 .03529 Mdot
.81176 .80392 Mdot
.57255 .40392 Mdot
.59608 .00784 Mdot
.65882 .0549 Mdot
.61569 .03529 Mdot
.67451 .65098 Mdot
.39216 .06667 Mdot
.63922 .02745 Mdot
.68235 .07059 Mdot
.55686 .04314 Mdot
.76078 .74118 Mdot
.4 .0549 Mdot
.60784 .01569 Mdot
.67059 .06667 Mdot
.24314 .03922 Mdot
.84314 .82353 Mdot
.38824 .18039 Mdot
.61176 .01569 Mdot
.69412 .06275 Mdot
.55686 .51373 Mdot
.83529 .73725 Mdot
.12941 .84706 Mdot
.55294 .01569 Mdot
.68627 .03922 Mdot
.81569 .7451 Mdot
.58431 .02353 Mdot
.79608 .81176 Mdot
.43922 .01176 Mdot
.6549 .02745 Mdot
.48627 .11765 Mdot
.91373 .87451 Mdot
.87451 .84314 Mdot
.51765 .32941 Mdot
.54902 .01961 Mdot
.68627 .03922 Mdot
.92549 .90196 Mdot
.47843 .06275 Mdot
.83137 .83529 Mdot
.3098 0 Mdot
.59216 .02353 Mdot
.63529 .07059 Mdot
.90196 .89804 Mdot
.49412 .05882 Mdot
.80784 .81176 Mdot
.43922 .00784 Mdot
.63529 .01569 Mdot
.83137 .76078 Mdot
.90196 .90196 Mdot
.89412 .83137 Mdot
.65882 .62353 Mdot
.4549 0 Mdot
.62745 .02353 Mdot
.9098 .8902 Mdot
.88235 .88235 Mdot
.72157 .68235 Mdot
.66275 .6 Mdot
.56078 .01961 Mdot
.62745 .02745 Mdot
.88627 .8902 Mdot
.8902 .88235 Mdot
.76078 .67059 Mdot
.57647 .54902 Mdot
.73725 .05098 Mdot
.61176 .02353 Mdot
.89804 .89804 Mdot
.88235 .88235 Mdot
.41569 .11373 Mdot
.75294 .75686 Mdot
.7451 .0549 Mdot
.62745 .02353 Mdot
.88627 .8902 Mdot
.87451 .87451 Mdot
.52549 .01961 Mdot
.81569 .81569 Mdot
.70196 .08627 Mdot
.63137 .02353 Mdot
.87059 .86667 Mdot
.89804 .87843 Mdot
.48627 .04314 Mdot
.8 .81569 Mdot
.60392 .00784 Mdot
.53333 .01176 Mdot
.82353 .75294 Mdot
.8902 .82745 Mdot
.87451 .85098 Mdot
.8 .78431 Mdot
.5098 .00392 Mdot
.79216 .0549 Mdot
.56078 .07059 Mdot
.88627 .87451 Mdot
.87059 .86667 Mdot
.78824 .75294 Mdot
.3451 .14902 Mdot
.72549 .04314 Mdot
.63529 .02745 Mdot
.88235 .88627 Mdot
.61569 .05882 Mdot
.56863 .06275 Mdot
.81569 .83137 Mdot
.67843 .03529 Mdot
.80392 .05098 Mdot
.85882 .85098 Mdot
.62353 .07451 Mdot
.84706 .8549 Mdot
.81961 .80784 Mdot
.53333 .09412 Mdot
.76078 .04314 Mdot
.59608 .02745 Mdot
.88627 .78824 Mdot
.61569 .03922 Mdot
.49412 .02745 Mdot
.75294 .77255 Mdot
.65098 .02353 Mdot
.81176 .0549 Mdot
.84706 .84314 Mdot
.65098 .05098 Mdot
.84706 .84706 Mdot
.71765 .70196 Mdot
.55294 .1098 Mdot
.73333 .04314 Mdot
.58039 .02745 Mdot
.61961 .18824 Mdot
.61569 .03529 Mdot
.51373 .03922 Mdot
.8 .81961 Mdot
.64706 .02353 Mdot
.8 .05098 Mdot
.87059 .85098 Mdot
.65882 .07059 Mdot
.87059 .82745 Mdot
.76078 .72941 Mdot
.35686 .28627 Mdot
.72157 .03922 Mdot
.83922 .07843 Mdot
.64706 .0902 Mdot
.6549 .03922 Mdot
.64706 .19216 Mdot
.8 .81569 Mdot
.58039 .00784 Mdot
.77647 .05098 Mdot
.84314 .83922 Mdot
.6549 .07843 Mdot
.55294 .00392 Mdot
.66667 .33725 Mdot
.54118 .47843 Mdot
.63529 .01569 Mdot
.81961 .06275 Mdot
.64706 .41961 Mdot
.16078 .03137 Mdot
.8549 .84314 Mdot
.64706 .62353 Mdot
.43922 .14118 Mdot
.7451 .04706 Mdot
.83529 .74118 Mdot
.66275 .07059 Mdot
.61569 .03922 Mdot
.65098 .15686 Mdot
.73333 .75294 Mdot
.56863 .00392 Mdot
.78824 .05882 Mdot
.86275 .85098 Mdot
.72157 .66275 Mdot
.53333 .00784 Mdot
.43529 .17647 Mdot
.36863 .29412 Mdot
.63137 .01176 Mdot
.82745 .07059 Mdot
.66275 .0549 Mdot
.89412 .84706 Mdot
.76078 .61961 Mdot
.66275 .65882 Mdot
.62745 .62745 Mdot
.73333 .04314 Mdot
.8902 .88627 Mdot
.23529 .08235 Mdot
.61176 .04314 Mdot
.68235 .06667 Mdot
.73725 .77255 Mdot
.55686 .00784 Mdot
.78039 .04706 Mdot
.83922 .6549 Mdot
.8902 .88627 Mdot
.54902 .00784 Mdot
.5451 .22353 Mdot
.47059 .45098 Mdot
.60392 .00784 Mdot
.81176 .07059 Mdot
.62745 .05098 Mdot
.87843 .87843 Mdot
.83529 .77647 Mdot
.69412 .66275 Mdot
.45882 .48235 Mdot
.71373 .03922 Mdot
.88627 .88235 Mdot
.88235 .85098 Mdot
.51765 .23922 Mdot
.75294 .03529 Mdot
.77255 .80784 Mdot
.20392 .00392 Mdot
.78039 .04706 Mdot
.74902 .12157 Mdot
.87059 .87843 Mdot
.60392 .02353 Mdot
.51373 .01569 Mdot
.56078 .60784 Mdot
.56078 .00392 Mdot
.78431 .07451 Mdot
.62353 .11373 Mdot
.87059 .87451 Mdot
.86275 .83529 Mdot
.80392 .68627 Mdot
.76471 .75294 Mdot
.63922 .04706 Mdot
.87843 .88235 Mdot
.87843 .88235 Mdot
.68627 .52941 Mdot
.72549 .04706 Mdot
.80392 .83529 Mdot
.16863 .00784 Mdot
.76078 .04706 Mdot
.81961 .07843 Mdot
.89412 .88235 Mdot
.63922 .02353 Mdot
.67451 .04706 Mdot
.52549 .57647 Mdot
.47843 .00784 Mdot
.73725 .0902 Mdot
.44706 .25882 Mdot
.8549 .80784 Mdot
.83529 .81176 Mdot
.58039 .23137 Mdot
.50588 .6549 Mdot
.64314 .03137 Mdot
.85882 .85882 Mdot
.86667 .86667 Mdot
.51765 .23529 Mdot
.54118 0 Mdot
.79608 .82353 Mdot
.1451 .01176 Mdot
.63137 .05882 Mdot
.77255 .05882 Mdot
.56078 .19608 Mdot
.62745 .02353 Mdot
.70588 .02353 Mdot
.79608 .83137 Mdot
.03529 0 Mdot
.76471 .05098 Mdot
.43529 .17647 Mdot
.34902 .08235 Mdot
.75686 .55686 Mdot
.50588 .03529 Mdot
.21569 .21176 Mdot
.44314 .01176 Mdot
.86275 .87843 Mdot
.85098 .85098 Mdot
.80392 .71373 Mdot
.53725 .03922 Mdot
.81176 .61961 Mdot
.32157 .36863 Mdot
.63922 .03529 Mdot
.74902 .06275 Mdot
.59216 .10588 Mdot
.63922 .03922 Mdot
.52549 0 Mdot
.8 .81961 Mdot
.05098 .01176 Mdot
.74902 .04314 Mdot
.75294 .08627 Mdot
.29804 .07059 Mdot
.58431 .03137 Mdot
.6902 .02353 Mdot
.69412 .7451 Mdot
.16078 .00392 Mdot
.6902 .5451 Mdot
.84314 .84314 Mdot
.88235 .82353 Mdot
.83529 .80392 Mdot
.52157 .01961 Mdot
.43922 .34118 Mdot
.41176 .00784 Mdot
.61569 .22353 Mdot
.87843 .85882 Mdot
.65098 .04706 Mdot
.53725 .00392 Mdot
.73333 .63137 Mdot
.24314 .28627 Mdot
.68235 .03137 Mdot
.46275 .04314 Mdot
.28235 .17255 Mdot
.63529 .02745 Mdot
.52549 .00784 Mdot
.73725 .77255 Mdot
.00392 0 Mdot
.76471 .06275 Mdot
.85882 .84314 Mdot
.86667 .86275 Mdot
.76863 .50588 Mdot
.68235 .03137 Mdot
.49804 .56471 Mdot
.21176 .00392 Mdot
.87059 .87843 Mdot
.76471 .14118 Mdot
.18824 .04314 Mdot
.51373 .03137 Mdot
.47843 .03529 Mdot
.30196 .73725 Mdot
.43137 0 Mdot
.68235 .61569 Mdot
.88627 .87059 Mdot
.55294 .07451 Mdot
.51765 .00392 Mdot
.64706 .60392 Mdot
.03922 .00392 Mdot
.6902 .03529 Mdot
.66667 .4 Mdot
.7098 .73333 Mdot
.63137 .03137 Mdot
.51373 .00392 Mdot
.78824 .83137 Mdot
.08235 .00392 Mdot
.88235 .68235 Mdot
.32941 .2902 Mdot
.86275 .81569 Mdot
.83529 .81569 Mdot
.67059 .01961 Mdot
.48627 .53333 Mdot
.23137 .00392 Mdot
.36471 .13333 Mdot
.80392 .76471 Mdot
.87059 .8549 Mdot
.56078 .00784 Mdot
.53725 .02745 Mdot
.31765 .36863 Mdot
.43137 .01176 Mdot
.86275 .84314 Mdot
.84706 .82353 Mdot
.51765 .07843 Mdot
.53725 .01569 Mdot
.6549 .6549 Mdot
.00392 .00392 Mdot
.75294 .05098 Mdot
.89412 .80392 Mdot
.86667 .86667 Mdot
.7451 .45098 Mdot
.50196 .00392 Mdot
.72941 .78431 Mdot
.15294 .00392 Mdot
.79216 .8 Mdot
.88627 .84314 Mdot
.86667 .85882 Mdot
.44314 .09412 Mdot
.67451 .01569 Mdot
.63529 .59216 Mdot
.24706 0 Mdot
.83137 .80784 Mdot
.81569 .78431 Mdot
.85098 .85098 Mdot
.56078 .00784 Mdot
.59216 .0549 Mdot
.08235 .11765 Mdot
.50588 .01176 Mdot
.75294 .04706 Mdot
.90196 .90196 Mdot
.60392 .05098 Mdot
.51373 .00392 Mdot
.6549 .69804 Mdot
0 0 Mdot
.76078 .04706 Mdot
.76863 .08627 Mdot
.86275 .86275 Mdot
.83137 .82745 Mdot
.51373 0 Mdot
.72157 .78431 Mdot
.17647 0 Mdot
.65882 .18824 Mdot
.32549 .08235 Mdot
.86275 .8 Mdot
.58039 .01961 Mdot
.67451 .02353 Mdot
.26275 .68627 Mdot
.41176 .01569 Mdot
.76471 .05882 Mdot
.8902 .8902 Mdot
.85098 .82745 Mdot
.53333 .00784 Mdot
.50196 .04314 Mdot
.00392 0 Mdot
.54118 .01176 Mdot
.75686 .05098 Mdot
.94902 .77647 Mdot
.58039 .20392 Mdot
.52549 .00392 Mdot
.72941 .78431 Mdot
.09804 .00392 Mdot
.78431 .05882 Mdot
.56863 .08235 Mdot
.75294 .09412 Mdot
.84706 .80392 Mdot
.52549 .00392 Mdot
.43529 .49412 Mdot
.34118 .00392 Mdot
.72157 .03137 Mdot
.84706 .8549 Mdot
.84706 .84314 Mdot
.56471 .00784 Mdot
.69412 .03529 Mdot
.34902 .4 Mdot
.59216 .03922 Mdot
.74902 .04706 Mdot
.80392 .38431 Mdot
.59216 .06667 Mdot
.52157 .00392 Mdot
.6549 .55294 Mdot
.02745 0 Mdot
.57255 .00784 Mdot
.73725 .05098 Mdot
.82353 .08235 Mdot
.84706 .82353 Mdot
.51765 .00784 Mdot
.76863 .82745 Mdot
.28235 .00392 Mdot
.75686 .04314 Mdot
.8549 .85098 Mdot
.39216 .27451 Mdot
.4549 .37647 Mdot
.56078 .00784 Mdot
.42745 .4 Mdot
.19608 0 Mdot
.76471 .05098 Mdot
.71765 .23922 Mdot
.43529 .19608 Mdot
.53333 .00392 Mdot
.70196 .04706 Mdot
.05882 .08627 Mdot
.45098 .03137 Mdot
.74118 .03922 Mdot
.81961 .08235 Mdot
.59608 .0549 Mdot
.49804 .00392 Mdot
.56863 .41961 Mdot
.16863 0 Mdot
.61569 .01176 Mdot
.85882 .82745 Mdot
.24706 .07451 Mdot
.80784 .81176 Mdot
.50588 0 Mdot
.68627 .74902 Mdot
.31373 .00392 Mdot
.76471 .0549 Mdot
.32941 .36078 Mdot
.77255 .77255 Mdot
.23529 .22745 Mdot
.63137 .03922 Mdot
.23922 .67843 Mdot
.59216 .36471 Mdot
.73725 .04706 Mdot
.72157 .15294 Mdot
.50196 .42353 Mdot
.51765 .00392 Mdot
.6902 .05882 Mdot
.2 .00784 Mdot
.55686 .01569 Mdot
.70588 .25882 Mdot
.23529 .04706 Mdot
.7451 .51373 Mdot
.49804 .00392 Mdot
.62353 .63137 Mdot
.27451 .01176 Mdot
.62353 .01961 Mdot
.82353 .77647 Mdot
.86275 .87843 Mdot
.80392 .81961 Mdot
.44706 .00784 Mdot
.58431 .64706 Mdot
.27843 0 Mdot
.72549 .03529 Mdot
.84314 .84706 Mdot
.83529 .84706 Mdot
.66275 .63922 Mdot
.67451 .05098 Mdot
.63529 .70588 Mdot
.50196 .01176 Mdot
.69412 .01569 Mdot
.20392 .08235 Mdot
.64314 .47843 Mdot
.51373 .00392 Mdot
.65098 .16078 Mdot
.22745 .01176 Mdot
.57647 .01569 Mdot
.85882 .83529 Mdot
.84314 .85882 Mdot
.84314 .83529 Mdot
.4902 .00392 Mdot
.61569 .66275 Mdot
.19216 .00392 Mdot
.63529 .01569 Mdot
.83529 .82353 Mdot
.83922 .85882 Mdot
.8 .81961 Mdot
.40784 .00392 Mdot
.33333 .33333 Mdot
.38431 .00784 Mdot
.65098 .01961 Mdot
.10196 .16863 Mdot
.82353 .84706 Mdot
.47451 .0902 Mdot
.67843 .06667 Mdot
.66275 .7098 Mdot
.51373 .01569 Mdot
.71373 .03137 Mdot
.85882 .86275 Mdot
.58039 .07059 Mdot
.49804 0 Mdot
.63529 .04706 Mdot
.14118 .00392 Mdot
.55686 .01176 Mdot
.65882 .13333 Mdot
.85098 .84706 Mdot
.82745 .76471 Mdot
.47843 .00392 Mdot
.63922 .6902 Mdot
.18824 .00392 Mdot
.57255 .00392 Mdot
.64706 .16078 Mdot
.47059 .22745 Mdot
.81569 .83137 Mdot
.36078 .00392 Mdot
.45098 .51373 Mdot
.30588 .00392 Mdot
.66275 .01569 Mdot
.80392 .79216 Mdot
.83922 .84706 Mdot
.50196 .04314 Mdot
.50588 .02353 Mdot
.44314 .45098 Mdot
.48627 .01176 Mdot
.70196 .02353 Mdot
.83529 .85098 Mdot
.21176 .04314 Mdot
.52157 .00392 Mdot
.6902 .04706 Mdot
.17255 .00392 Mdot
.55686 .01961 Mdot
.70588 .03529 Mdot
.67059 .21176 Mdot
.6 .04314 Mdot
.51765 .01176 Mdot
.42353 .07451 Mdot
.14902 .00392 Mdot
.56078 .01569 Mdot
.56863 .08235 Mdot
.66275 .65882 Mdot
.80784 .82353 Mdot
.47451 .00392 Mdot
.71765 .76863 Mdot
.2 .00392 Mdot
.56078 .01569 Mdot
.83137 .83529 Mdot
.84314 .84706 Mdot
.62353 .5098 Mdot
.85098 .70196 Mdot
.18039 .60784 Mdot
.40784 .00784 Mdot
.67843 .03529 Mdot
.83922 .7451 Mdot
.81961 .84706 Mdot
.53725 .00392 Mdot
.57647 .03137 Mdot
.16471 .08235 Mdot
.50196 .01176 Mdot
.70196 .03529 Mdot
.14902 .09804 Mdot
.58431 .07059 Mdot
.50588 0 Mdot
.63137 .03529 Mdot
.13333 .00392 Mdot
.54118 .00784 Mdot
.3451 .06275 Mdot
.85882 .86667 Mdot
.55294 .05882 Mdot
.46667 .00392 Mdot
.74118 .76471 Mdot
.15686 0 Mdot
.55686 .00784 Mdot
.84314 .84314 Mdot
.83529 .85098 Mdot
.79608 .81569 Mdot
.45098 .00392 Mdot
.4902 .50588 Mdot
.3451 .00784 Mdot
.61961 .01569 Mdot
.37255 .12941 Mdot
.82353 .83529 Mdot
.5098 .01961 Mdot
.4549 0 Mdot
.42745 .36078 Mdot
.47451 .00784 Mdot
.68235 .02745 Mdot
.85098 .8549 Mdot
.54118 .07843 Mdot
.51765 .00784 Mdot
.58824 .01569 Mdot
.13333 .00392 Mdot
.50588 .01176 Mdot
.73333 .51373 Mdot
.84706 .86667 Mdot
.60784 .04314 Mdot
.4902 .00392 Mdot
.47451 .0902 Mdot
.18431 .00392 Mdot
.52941 .00392 Mdot
.81569 .84314 Mdot
.36471 .37647 Mdot
.52941 .05882 Mdot
.45882 .00392 Mdot
.75686 .81569 Mdot
.32549 .00784 Mdot
.57255 .00784 Mdot
.67059 .67843 Mdot
.83529 .85098 Mdot
.80392 .81176 Mdot
.45098 0 Mdot
.34118 .41176 Mdot
.38431 .00784 Mdot
.6902 .03529 Mdot
.84314 .8549 Mdot
.60784 .06667 Mdot
.50588 .00392 Mdot
.59608 .01569 Mdot
.12157 .00392 Mdot
.44314 .00392 Mdot
.58431 .06667 Mdot
.81569 .68235 Mdot
.62353 .03137 Mdot
.50588 .00392 Mdot
.57255 .02745 Mdot
.13725 0 Mdot
.53725 .01176 Mdot
.81176 .83137 Mdot
.61569 .61176 Mdot
.59608 .02745 Mdot
.4902 .00392 Mdot
.77647 .79608 Mdot
.26275 .00784 Mdot
.56471 .00392 Mdot
.83137 .84706 Mdot
.74902 .49412 Mdot
.56078 .03529 Mdot
.4549 .00392 Mdot
.47451 .41961 Mdot
.32157 0 Mdot
.62353 .02353 Mdot
.85098 .83922 Mdot
.71373 .06275 Mdot
.63922 .55294 Mdot
.5098 .00392 Mdot
.21176 .00784 Mdot
.42353 .00392 Mdot
.68627 .03922 Mdot
.70196 .14118 Mdot
.58824 .04706 Mdot
.49412 .00392 Mdot
.55294 .00784 Mdot
.12549 .00784 Mdot
.4902 0 Mdot
.75294 .69804 Mdot
.8549 .85882 Mdot
.48235 .07059 Mdot
.47451 .00392 Mdot
.42745 .03922 Mdot
.24314 .00392 Mdot
.55686 0 Mdot
.83922 .84706 Mdot
.75294 .08627 Mdot
.53333 .03529 Mdot
.45098 0 Mdot
.47451 .52157 Mdot
.27843 .00392 Mdot
.59608 .02353 Mdot
.67451 .14118 Mdot
.15294 .02353 Mdot
.57255 .02745 Mdot
.46275 0 Mdot
.21176 .01176 Mdot
.36078 .00392 Mdot
.69412 .03922 Mdot
.78039 .08627 Mdot
.56863 .6 Mdot
.52549 .01569 Mdot
.61176 .01961 Mdot
.10588 .00784 Mdot
.4902 .00392 Mdot
.59608 .15294 Mdot
.67451 .25882 Mdot
.78824 .79608 Mdot
.4902 .00392 Mdot
.51765 0 Mdot
.21961 .00392 Mdot
.54118 .00392 Mdot
.71373 .56471 Mdot
.08235 .0549 Mdot
.76078 .76471 Mdot
.44706 .00392 Mdot
.56078 .56863 Mdot
.26275 .00392 Mdot
.60392 .02745 Mdot
.65882 .21961 Mdot
.84314 .85098 Mdot
.09412 .06275 Mdot
.45098 .00392 Mdot
.33725 .28235 Mdot
.35686 .00784 Mdot
.66667 .04314 Mdot
.77255 .07059 Mdot
.82353 .83922 Mdot
.52157 .01176 Mdot
.53725 .01176 Mdot
.11765 .00392 Mdot
.43922 .00392 Mdot
.71373 .04706 Mdot
.16863 .01176 Mdot
.81961 .83137 Mdot
.47059 0 Mdot
.53725 .00392 Mdot
.13725 .00784 Mdot
.37255 .00392 Mdot
.18431 .05882 Mdot
.87059 .87843 Mdot
.81176 .83922 Mdot
.46667 0 Mdot
.36863 .04706 Mdot
.23922 .00392 Mdot
.57647 .00784 Mdot
.84706 .84706 Mdot
.83922 .85882 Mdot
.8 .81569 Mdot
.37647 0 Mdot
.47059 .47843 Mdot
.30196 0 Mdot
.59608 .02353 Mdot
.65098 .10588 Mdot
.83529 .8549 Mdot
.46275 .34902 Mdot
.4549 0 Mdot
.23922 .00392 Mdot
.4 .00392 Mdot
.67843 .04314 Mdot
.80784 .82745 Mdot
.80392 .83529 Mdot
.49412 0 Mdot
.56863 .00392 Mdot
.11765 .00392 Mdot
.4902 .00392 Mdot
.74902 .54902 Mdot
.87451 .87843 Mdot
.82745 .82353 Mdot
.44314 .00392 Mdot
.51373 .01176 Mdot
.2 .00392 Mdot
.55294 .00784 Mdot
.85098 .85098 Mdot
.85882 .87451 Mdot
.81569 .83137 Mdot
.45882 .00392 Mdot
.51765 .53725 Mdot
.13725 0 Mdot
.6 .01176 Mdot
.3098 .34902 Mdot
.81961 .72941 Mdot
.79216 .81961 Mdot
.48627 .00392 Mdot
.12157 .55294 Mdot
.36471 .00392 Mdot
.64314 .03137 Mdot
.8549 .87059 Mdot
.47451 .11765 Mdot
.40784 .10588 Mdot
.56863 .02353 Mdot
.28627 .01569 Mdot
.42745 .00784 Mdot
.70588 .04314 Mdot
.88627 .8902 Mdot
.04706 .03137 Mdot
.5098 .01176 Mdot
.57647 .00392 Mdot
.17647 0 Mdot
.44706 .00784 Mdot
.68235 .0549 Mdot
.85098 .86667 Mdot
.51373 .36863 Mdot
.52157 .02353 Mdot
.53333 .00392 Mdot
.12549 .00392 Mdot
.4902 .00392 Mdot
.80784 .50196 Mdot
.86275 .66275 Mdot
.52549 .09412 Mdot
.4902 .00392 Mdot
.45882 0 Mdot
.20392 .01176 Mdot
.52549 .00392 Mdot
.41961 .38039 Mdot
.72157 .11373 Mdot
.55294 .03529 Mdot
.4902 .01176 Mdot
.61961 .56078 Mdot
.12941 0 Mdot
.56863 .00784 Mdot
.88627 .90196 Mdot
.41961 .42745 Mdot
.63922 .64314 Mdot
.50196 .00784 Mdot
.14902 .12549 Mdot
.14902 .00784 Mdot
.58824 .01961 Mdot
.87059 .8902 Mdot
.84706 .87059 Mdot
.79608 .83137 Mdot
.52941 .01961 Mdot
.12941 .56078 Mdot
.2549 .00392 Mdot
.59608 .03137 Mdot
.86667 .88235 Mdot
.82353 .85098 Mdot
.44706 .08235 Mdot
.35686 0 Mdot
.24314 .00784 Mdot
.32941 0 Mdot
.67059 .03529 Mdot
.73333 .27451 Mdot
.75686 .6902 Mdot
.49804 .00784 Mdot
.32157 .00784 Mdot
.22353 .00392 Mdot
.40392 .00392 Mdot
.58039 .0902 Mdot
.8 .07451 Mdot
.60392 .03922 Mdot
.48627 .00392 Mdot
.58431 .01176 Mdot
.12549 0 Mdot
.47451 .00784 Mdot
.83529 .84706 Mdot
.32549 .14902 Mdot
.52549 .03137 Mdot
.51373 .00784 Mdot
.51373 .00392 Mdot
.18431 0 Mdot
.50196 0 Mdot
.83922 .85882 Mdot
.8549 .86275 Mdot
.34902 .37647 Mdot
.49804 .00392 Mdot
.4902 .23529 Mdot
.24706 .00392 Mdot
.52157 .00392 Mdot
.85882 .87451 Mdot
.83529 .85098 Mdot
.81569 .81961 Mdot
.49804 .00392 Mdot
.41569 .4 Mdot
.27451 .00392 Mdot
.53725 0 Mdot
.64314 .27059 Mdot
.78824 .64706 Mdot
.47843 .07451 Mdot
.5098 .01569 Mdot
.15294 .05098 Mdot
.32549 .00784 Mdot
.58039 .00784 Mdot
.80784 .08235 Mdot
.60784 .05882 Mdot
.53333 .01569 Mdot
.58039 .02353 Mdot
.30588 .03529 Mdot
.27843 .00392 Mdot
.27843 .01961 Mdot
.83529 .07843 Mdot
.50588 .06667 Mdot
.51373 0 Mdot
.67843 .03922 Mdot
.21176 .00392 Mdot
.47059 0 Mdot
.83137 .83137 Mdot
.84706 .50196 Mdot
.34118 .38824 Mdot
.49804 .00392 Mdot
.64706 .02353 Mdot
.17647 .00392 Mdot
.4902 .02745 Mdot
.83529 .83922 Mdot
.86275 .86667 Mdot
.82745 .85098 Mdot
.47451 .00392 Mdot
.54902 .00392 Mdot
.17255 .00784 Mdot
.38431 .01569 Mdot
.78039 .64314 Mdot
.71765 .7098 Mdot
.26275 .22745 Mdot
.5098 .00784 Mdot
.44706 .02353 Mdot
.24314 .01176 Mdot
.51765 .00392 Mdot
.71373 .06667 Mdot
.0902 .01569 Mdot
.03137 .02353 Mdot
.48627 .00784 Mdot
.38824 .34902 Mdot
.22745 0 Mdot
.54118 .00392 Mdot
.72157 .07059 Mdot
.39608 .44314 Mdot
.18039 .21961 Mdot
.51373 .00392 Mdot
.03922 .00392 Mdot
.16863 .00392 Mdot
.32941 .03137 Mdot
.72941 .08235 Mdot
.80392 .83529 Mdot
.03529 .01569 Mdot
.5451 .01176 Mdot
.22745 .59216 Mdot
.41569 .01176 Mdot
.81176 .81961 Mdot
.75294 .04706 Mdot
.78431 .82353 Mdot
.47059 .02745 Mdot
.64314 .03529 Mdot
.18431 0 Mdot
.36471 .00784 Mdot
.81176 .82745 Mdot
.73725 .05882 Mdot
.33333 .40784 Mdot
.52157 .00392 Mdot
.6549 .04314 Mdot
.16471 .00784 Mdot
.23529 0 Mdot
.57647 .18824 Mdot
.68627 .22353 Mdot
.83137 .85098 Mdot
.52157 .00392 Mdot
.59608 .00392 Mdot
.15686 .00392 Mdot
.53725 .00784 Mdot
.23137 .01176 Mdot
.72157 .36471 Mdot
.81569 .84706 Mdot
.51765 .01176 Mdot
.47451 .00784 Mdot
.24314 .01176 Mdot
.55294 .01569 Mdot
.72549 .76471 Mdot
.67059 .12157 Mdot
.80784 .83137 Mdot
.48627 .00392 Mdot
.45882 .38431 Mdot
.2902 .00392 Mdot
.54902 .06275 Mdot
.86667 .86275 Mdot
.35294 .03137 Mdot
.80392 .83922 Mdot
.48235 .01176 Mdot
.01569 0 Mdot
.35294 .00784 Mdot
.78824 .80784 Mdot
.84314 .8549 Mdot
.68627 .72941 Mdot
.80784 .84314 Mdot
.56078 .01569 Mdot
.27059 .03922 Mdot
.47843 .28627 Mdot
.8 .81961 Mdot
.8 .6549 Mdot
.81961 .85098 Mdot
.71373 .67059 Mdot
.60784 .01961 Mdot
.15294 .00392 Mdot
.37647 .03529 Mdot
.36863 .11373 Mdot
.76078 .06667 Mdot
.81961 .85098 Mdot
.52941 .01961 Mdot
.61569 .01961 Mdot
.26275 .1098 Mdot
.47059 .00392 Mdot
.73725 .76078 Mdot
.78039 .06667 Mdot
.80392 .80784 Mdot
.48627 0 Mdot
.57255 .00784 Mdot
.08627 .00392 Mdot
.51373 .01176 Mdot
.69412 .51373 Mdot
.73333 .06275 Mdot
.46667 .1098 Mdot
.49804 .01176 Mdot
.50196 0 Mdot
.16863 .00392 Mdot
.54118 .01961 Mdot
.71373 .05882 Mdot
.61569 .62745 Mdot
.43529 .06667 Mdot
.43922 0 Mdot
.56078 .45098 Mdot
.23922 0 Mdot
.42745 .31765 Mdot
.39216 .36863 Mdot
.8549 .87059 Mdot
.71765 .76471 Mdot
.43137 0 Mdot
.00392 .00392 Mdot
.28627 0 Mdot
.8 .83137 Mdot
.87451 .86275 Mdot
.83529 .86667 Mdot
.78824 .79608 Mdot
.51373 .00392 Mdot
.18431 0 Mdot
.36078 .00392 Mdot
.06667 .08627 Mdot
.75686 .08627 Mdot
.36471 .40784 Mdot
.51373 .03137 Mdot
.52157 .00392 Mdot
.29804 .12157 Mdot
.41176 .00784 Mdot
.81961 .83137 Mdot
.78431 .06275 Mdot
.49804 .09412 Mdot
.49412 .00784 Mdot
.57255 .00784 Mdot
.08627 .00392 Mdot
.35294 .02353 Mdot
.59608 .07059 Mdot
.76471 .07843 Mdot
.39608 .06275 Mdot
.50196 .00784 Mdot
.57255 .00392 Mdot
.08627 .00392 Mdot
.43137 .00784 Mdot
.22353 .01176 Mdot
.40784 .3098 Mdot
.15294 .20784 Mdot
.48627 .00392 Mdot
.57255 .00784 Mdot
.0902 0 Mdot
.52941 .01176 Mdot
.56471 .62745 Mdot
.83922 .85882 Mdot
.79608 .84314 Mdot
.49412 .00784 Mdot
.46667 .03137 Mdot
.07451 0 Mdot
.52941 .01961 Mdot
.84314 .85098 Mdot
.86275 .8549 Mdot
.7451 .7098 Mdot
.45882 .00392 Mdot
.20784 .10196 Mdot
.2 .00784 Mdot
.62745 .41569 Mdot
.58824 .19608 Mdot
.55686 .14902 Mdot
.4902 .06667 Mdot
.44314 0 Mdot
.00392 0 Mdot
.27059 .00392 Mdot
.78824 .81569 Mdot
.71765 .0549 Mdot
.36078 .05098 Mdot
.4 .05098 Mdot
.49412 0 Mdot
.04706 0 Mdot
.31373 .00392 Mdot
.72941 .76471 Mdot
.71373 .0549 Mdot
.08627 .12157 Mdot
.12941 0 Mdot
.48627 .00392 Mdot
.2549 .01569 Mdot
.36078 .00392 Mdot
.8 .82745 Mdot
.70588 .0549 Mdot
.67843 .73725 Mdot
.06275 0 Mdot
.4902 0 Mdot
.25098 .00392 Mdot
.38431 .00392 Mdot
.76471 .80392 Mdot
.68235 .03529 Mdot
.81961 .86667 Mdot
.13333 .00392 Mdot
.50588 .00392 Mdot
.37255 .16078 Mdot
.41176 0 Mdot
.81569 .81176 Mdot
.71373 .0549 Mdot
.79216 .84314 Mdot
.39608 .03137 Mdot
.52941 .00392 Mdot
.11373 .00784 Mdot
.45098 .00784 Mdot
.55294 .16471 Mdot
.72549 .0549 Mdot
.68235 .74118 Mdot
.47843 .01176 Mdot
.53333 .00392 Mdot
.05882 .00392 Mdot
.48235 .01176 Mdot
.65098 .03529 Mdot
.71373 .06667 Mdot
.78039 .82353 Mdot
.44706 0 Mdot
.53725 .00392 Mdot
.05098 0 Mdot
.50588 .01176 Mdot
.65882 .03137 Mdot
.66667 .07059 Mdot
.82353 .85098 Mdot
.44314 0 Mdot
.44706 .0902 Mdot
.0549 .00392 Mdot
.50588 .00392 Mdot
.69804 .05098 Mdot
.65098 .05882 Mdot
.82353 .8549 Mdot
.4902 .00392 Mdot
.13333 .07843 Mdot
.06275 .00392 Mdot
.5098 .01569 Mdot
.6902 .04314 Mdot
.43137 .06275 Mdot
.82745 .85882 Mdot
.5451 .00784 Mdot
.00392 0 Mdot
.19216 .00784 Mdot
.54902 .31373 Mdot
.70196 .04706 Mdot
.20392 .24706 Mdot
.82745 .85882 Mdot
.52941 .00392 Mdot
.05882 .00392 Mdot
.26275 0 Mdot
.8 .83137 Mdot
.71373 .04706 Mdot
.83137 .86667 Mdot
.81569 .8549 Mdot
.5451 .01176 Mdot
.27843 .01176 Mdot
.3098 .00392 Mdot
.78431 .82353 Mdot
.71373 .05098 Mdot
.83922 .87059 Mdot
.81961 .8549 Mdot
.54118 .01569 Mdot
.30196 .00784 Mdot
.35686 .00392 Mdot
.76078 .80392 Mdot
.73725 .05882 Mdot
.83922 .87059 Mdot
.81569 .8549 Mdot
.55294 .00784 Mdot
.21176 0 Mdot
.38039 0 Mdot
.14118 .14118 Mdot
.74118 .05098 Mdot
.83922 .87059 Mdot
.66667 .63922 Mdot
.58431 .01176 Mdot
.32157 .12157 Mdot
.43137 .00392 Mdot
.30196 .03922 Mdot
.51373 .07451 Mdot
.80392 .76471 Mdot
.47451 .03922 Mdot
.61569 .02745 Mdot
.36078 .23529 Mdot
.4549 .00392 Mdot
.59216 .05882 Mdot
.36078 .4 Mdot
.54902 .11373 Mdot
.47843 .01176 Mdot
.63137 .05882 Mdot
.09804 .01176 Mdot
.45882 .00784 Mdot
.62745 .0549 Mdot
.82353 .85882 Mdot
.62353 .04706 Mdot
.50588 .01569 Mdot
.58431 .21961 Mdot
.1098 .0549 Mdot
.47451 .00784 Mdot
.64314 .03922 Mdot
.8549 .87451 Mdot
.56078 .07059 Mdot
.52549 .00784 Mdot
.64706 .47843 Mdot
.04314 0 Mdot
.47843 .01569 Mdot
.67843 .04706 Mdot
.83922 .86667 Mdot
.13725 .00392 Mdot
.53725 .01176 Mdot
.47059 .33333 Mdot
.03137 0 Mdot
.46275 .00784 Mdot
.67843 .03922 Mdot
.84314 .87451 Mdot
.30588 .37255 Mdot
.52941 .00392 Mdot
.4 .30588 Mdot
.03137 .00784 Mdot
.47451 .01176 Mdot
.67843 .04314 Mdot
.84314 .87059 Mdot
.72549 .78431 Mdot
.53725 .00784 Mdot
.07451 .01176 Mdot
.02353 0 Mdot
.47843 .00784 Mdot
.68627 .04314 Mdot
.67451 .6902 Mdot
.81176 .85098 Mdot
.5451 .01176 Mdot
.09412 .01961 Mdot
.02353 0 Mdot
.49804 .01961 Mdot
.66667 .03922 Mdot
.06275 .11373 Mdot
.8 .83529 Mdot
.54118 .00784 Mdot
.11765 .00392 Mdot
.02745 .00392 Mdot
.50588 .01176 Mdot
.51765 .06275 Mdot
.66275 .72157 Mdot
.80392 .83922 Mdot
.5451 .01961 Mdot
.22353 .00392 Mdot
.08627 0 Mdot
.54118 .01176 Mdot
.1098 .06275 Mdot
.84314 .86667 Mdot
.80392 .83922 Mdot
.56863 .02353 Mdot
.33725 .01176 Mdot
.20392 .00784 Mdot
.59216 .02353 Mdot
.67451 .72549 Mdot
.81569 .72549 Mdot
.80392 .83922 Mdot
.58039 .01961 Mdot
.41569 .00392 Mdot
.27451 .00392 Mdot
.61569 .03137 Mdot
.83529 .86275 Mdot
.53333 .17255 Mdot
.8 .84314 Mdot
.57647 .01176 Mdot
.49804 .01176 Mdot
.29804 .00392 Mdot
.61569 .02745 Mdot
.83922 .85882 Mdot
.15294 .01961 Mdot
.67059 .72941 Mdot
.55686 .00784 Mdot
.47451 .00784 Mdot
.30196 .00392 Mdot
.60392 .04314 Mdot
.83137 .86275 Mdot
.6 .65882 Mdot
.69804 .75294 Mdot
.55294 .00392 Mdot
.4 .00392 Mdot
.32549 0 Mdot
.57647 .05882 Mdot
.85098 .84706 Mdot
.83529 .87843 Mdot
.8 .83529 Mdot
.54902 .00784 Mdot
.32941 .00392 Mdot
.36078 .00784 Mdot
.53333 .08627 Mdot
.59608 .30588 Mdot
.83529 .87059 Mdot
.79608 .83922 Mdot
.52941 .01569 Mdot
.2902 .00784 Mdot
.35294 0 Mdot
.54118 .18039 Mdot
.63529 .06275 Mdot
.83137 .86667 Mdot
.4902 .56078 Mdot
.4902 .16078 Mdot
.27451 .00392 Mdot
.36078 .00784 Mdot
.60392 .34902 Mdot
.51765 .08235 Mdot
.81569 .84706 Mdot
.60784 .67059 Mdot
.83137 .76471 Mdot
.27843 .01569 Mdot
.33333 0 Mdot
.64314 .47059 Mdot
.15294 .11373 Mdot
.83529 .82353 Mdot
.78039 .82745 Mdot
.55686 .5098 Mdot
.07059 .76078 Mdot
.34902 .00392 Mdot
.55294 .24314 Mdot
.52941 .56863 Mdot
.6549 .4902 Mdot
.78039 .82353 Mdot
.33333 .25882 Mdot
.13725 .52157 Mdot
.35686 .00392 Mdot
.49804 .09412 Mdot
.6902 .74118 Mdot
.51765 .14902 Mdot
.78039 .81961 Mdot
.20392 .11373 Mdot
.14118 .51765 Mdot
.38824 .03137 Mdot
.43922 .06667 Mdot
.81961 .86275 Mdot
.4902 .10196 Mdot
.78039 .81961 Mdot
.24314 .12941 Mdot
.14902 .52549 Mdot
.38039 .00784 Mdot
.24706 .01961 Mdot
.83529 .85882 Mdot
.19216 .01569 Mdot
.78039 .82353 Mdot
.43137 .32157 Mdot
.1451 .52157 Mdot
.39216 .00784 Mdot
.1098 .04314 Mdot
.83922 .79608 Mdot
.07451 .0902 Mdot
.77255 .82353 Mdot
.62745 .5451 Mdot
.15294 .52157 Mdot
.38431 .00784 Mdot
.2902 .31373 Mdot
.64706 .43137 Mdot
.54118 .61176 Mdot
.77647 .82353 Mdot
.72549 .67059 Mdot
.14118 .51765 Mdot
.33333 .00392 Mdot
.56863 .62353 Mdot
.58039 .1451 Mdot
.72157 .77647 Mdot
.78039 .81569 Mdot
.78431 .75686 Mdot
.1451 .52549 Mdot
.30588 0 Mdot
.7451 .79608 Mdot
.69412 .0902 Mdot
.81961 .86275 Mdot
.76078 .76471 Mdot
.76078 .75686 Mdot
.14118 .52157 Mdot
.34902 .00392 Mdot
.77255 .81569 Mdot
.78824 .08235 Mdot
.84314 .87843 Mdot
.61176 .53333 Mdot
.72157 .7451 Mdot
.1451 .51373 Mdot
.39216 .00784 Mdot
.77647 .81961 Mdot
.87059 .1098 Mdot
.87059 .89804 Mdot
.47059 .23922 Mdot
.69412 .74118 Mdot
.14118 .50588 Mdot
.38431 .00392 Mdot
.77647 .81961 Mdot
.95686 .17647 Mdot
.89804 .91765 Mdot
.5098 .09412 Mdot
.70588 .76078 Mdot
.14902 .5098 Mdot
.37255 .00392 Mdot
.78824 .83137 Mdot
.99216 .25098 Mdot
.92157 .93333 Mdot
.60392 .04706 Mdot
.68235 .74902 Mdot
.15294 .51765 Mdot
.36863 .00392 Mdot
.80392 .82745 Mdot
1 .28627 Mdot
.94118 .94902 Mdot
.66667 .03529 Mdot
.63529 .7098 Mdot
.15294 .51373 Mdot
.37647 .00392 Mdot
.85098 .80784 Mdot
.97647 .2549 Mdot
.93333 .93725 Mdot
.72549 .05098 Mdot
.67059 .73725 Mdot
.15686 .51765 Mdot
.38431 .00392 Mdot
.8549 .71765 Mdot
.99216 .29412 Mdot
.9451 .93725 Mdot
.76078 .05882 Mdot
.69412 .74902 Mdot
.15686 .5098 Mdot
.39608 .00392 Mdot
.71373 .53333 Mdot
.99608 .27451 Mdot
1 .89412 Mdot
.74902 .05098 Mdot
.60784 .67059 Mdot
.15686 .5098 Mdot
.41176 .00392 Mdot
.40392 .30196 Mdot
.98431 .21176 Mdot
.87059 .40392 Mdot
.74118 .05882 Mdot
.51765 .59216 Mdot
.1451 .5098 Mdot
.43137 .00784 Mdot
.17647 .18431 Mdot
.9098 .12549 Mdot
.83137 .1451 Mdot
.6902 .06667 Mdot
.70588 .76471 Mdot
.13725 .50196 Mdot
.47059 .01569 Mdot
.24314 .30196 Mdot
.80784 .07059 Mdot
.8 .08627 Mdot
.63529 .10588 Mdot
.73333 .79216 Mdot
.13725 .50588 Mdot
.47843 .01961 Mdot
.62353 .6902 Mdot
.75686 .06275 Mdot
.79216 .08235 Mdot
.76078 .34118 Mdot
.61569 .67059 Mdot
.27843 .01569 Mdot
.59216 .14118 Mdot
.73725 .78824 Mdot
.79608 .08235 Mdot
.83137 .09804 Mdot
.83922 .47843 Mdot
.66667 .72941 Mdot
.28235 .01961 Mdot
.6 .10588 Mdot
.78431 .82353 Mdot
.90196 .14118 Mdot
.91373 .14118 Mdot
.65882 .28627 Mdot
.61176 .68235 Mdot
.27843 .01961 Mdot
.57255 .03529 Mdot
.78431 .76471 Mdot
.96863 .20784 Mdot
.97647 .22353 Mdot
.5451 .10588 Mdot
.57255 .64706 Mdot
.26275 .01569 Mdot
.50196 .03529 Mdot
.65882 .43529 Mdot
1 .28627 Mdot
.96078 .32941 Mdot
.58431 .0549 Mdot
.51765 .60784 Mdot
.27059 .01569 Mdot
.70196 .39216 Mdot
.63529 .12157 Mdot
1 .28627 Mdot
.97647 .60392 Mdot
.6549 .04314 Mdot
.5098 .58824 Mdot
.28627 .02745 Mdot
.48235 .25882 Mdot
.74118 .07843 Mdot
.97255 .21569 Mdot
.9098 .63137 Mdot
.71373 .04706 Mdot
.52941 .59608 Mdot
.27059 .01961 Mdot
.56863 .3098 Mdot
.8 .1098 Mdot
.99216 .24706 Mdot
.90588 .64706 Mdot
.73333 .04314 Mdot
.51765 .58039 Mdot
.27059 .01961 Mdot
.40392 .05098 Mdot
.81176 .14902 Mdot
.99608 .24706 Mdot
.9451 .75294 Mdot
.72941 .03529 Mdot
.48235 .55294 Mdot
.26275 .01569 Mdot
.41569 0 Mdot
.73725 .12549 Mdot
.95294 .15294 Mdot
.91373 .70588 Mdot
.73725 .05098 Mdot
.49412 .56863 Mdot
.26275 .01569 Mdot
.44314 .00784 Mdot
.61961 .10588 Mdot
.9098 .10196 Mdot
.73725 .49804 Mdot
.70588 .06667 Mdot
.58431 .6549 Mdot
.28235 .02353 Mdot
.46275 .00784 Mdot
.38431 .03529 Mdot
.88235 .09804 Mdot
.84314 .58039 Mdot
.61569 .05882 Mdot
.60392 .66667 Mdot
.2902 .01569 Mdot
.46667 .01176 Mdot
.16078 .00392 Mdot
.8902 .1098 Mdot
.91373 .45882 Mdot
.52941 .06275 Mdot
.54118 .60784 Mdot
.29412 .01176 Mdot
.43529 0 Mdot
.15294 .1098 Mdot
.92941 .14118 Mdot
.8902 .21961 Mdot
.4549 .07843 Mdot
.60392 .66667 Mdot
.31373 .01961 Mdot
.43529 .00784 Mdot
.3098 .33725 Mdot
.98039 .21569 Mdot
.99608 .31373 Mdot
.55294 .26667 Mdot
.74902 .80784 Mdot
.32941 .03137 Mdot
.42353 .00392 Mdot
.53725 .59216 Mdot
1 .2902 Mdot
1 .31765 Mdot
.78824 .58431 Mdot
.6902 .7451 Mdot
.3098 .01961 Mdot
.41176 .01961 Mdot
.71765 .76863 Mdot
.98431 .23529 Mdot
.9451 .19216 Mdot
.90196 .77255 Mdot
.58824 .63529 Mdot
.33333 .04314 Mdot
.51373 .10588 Mdot
.78431 .81569 Mdot
.97647 .18039 Mdot
.8902 .12157 Mdot
.8549 .79608 Mdot
.60784 .65098 Mdot
.34118 .0549 Mdot
.48235 .01961 Mdot
.84706 .82353 Mdot
.96863 .18824 Mdot
.94118 .18824 Mdot
.82353 .81569 Mdot
.65098 .6902 Mdot
.34902 .06667 Mdot
.4549 0 Mdot
.7098 .37255 Mdot
.99608 .28235 Mdot
.98431 .24706 Mdot
.79216 .81961 Mdot
.55686 .53725 Mdot
.39608 .46275 Mdot
.43922 .00392 Mdot
.77647 .08627 Mdot
1 .38431 Mdot
.99608 .27451 Mdot
.78431 .81569 Mdot
.10588 .03529 Mdot
.33333 .12157 Mdot
.47451 .00392 Mdot
.83529 .08627 Mdot
.97647 .33725 Mdot
.99608 .23922 Mdot
.81961 .80784 Mdot
.1098 .02353 Mdot
.19216 .01176 Mdot
.62745 .02353 Mdot
.87843 .11373 Mdot
.98431 .29412 Mdot
.86667 .28627 Mdot
.52941 .0902 Mdot
.18824 .08627 Mdot
.21176 0 Mdot
.65098 .00784 Mdot
.83137 .07451 Mdot
.99216 .2549 Mdot
.84706 .67843 Mdot
.77647 .60392 Mdot
.31765 .00392 Mdot
.39608 .03922 Mdot
.68235 .01569 Mdot
.91765 .11373 Mdot
.99216 .23529 Mdot
.64706 .12549 Mdot
.76471 .83529 Mdot
.4902 .01176 Mdot
.12549 0 Mdot
.72941 .04314 Mdot
.98039 .16078 Mdot
.98431 .21176 Mdot
.68627 .02353 Mdot
.81569 .87843 Mdot
.34902 .01176 Mdot
.04706 .00784 Mdot
.70588 .07451 Mdot
.96078 .19216 Mdot
.88627 .24706 Mdot
.83529 .68235 Mdot
.85098 .90196 Mdot
.49804 .04706 Mdot
.29804 .00392 Mdot
.73725 .04706 Mdot
.85098 .67059 Mdot
.68627 .34902 Mdot
.75294 .80784 Mdot
.77647 .81961 Mdot
.2902 .37647 Mdot
.42745 .00392 Mdot
.8 .1451 Mdot
.60784 .53725 Mdot
.51765 .46667 Mdot
.40784 .07843 Mdot
.5098 .07843 Mdot
.22745 .01569 Mdot
.66275 .03922 Mdot
.72157 .52157 Mdot
.53333 .57647 Mdot
.45882 .5098 Mdot
.71765 .78039 Mdot
.63137 .05882 Mdot
.18431 .00392 Mdot
.75294 .12549 Mdot
.69412 .73333 Mdot
.60392 .65882 Mdot
.43922 .5098 Mdot
.69412 .77647 Mdot
.6 .02745 Mdot
.19216 .00392 Mdot
.57255 .34118 Mdot
.78039 .80784 Mdot
.81176 .84706 Mdot
.40784 .4902 Mdot
.74902 .83137 Mdot
.40784 .00392 Mdot
.40784 .10588 Mdot
.47059 .55294 Mdot
.87451 .89412 Mdot
.83137 .83529 Mdot
.39608 .4902 Mdot
.6549 .74902 Mdot
.44706 .23922 Mdot
.5451 .16471 Mdot
.58039 .64706 Mdot
.4549 .44314 Mdot
.54118 .52941 Mdot
.37647 .47843 Mdot
.46667 .05882 Mdot
.3451 .01569 Mdot
.45882 .52157 Mdot
.43137 .43137 Mdot
.43922 .43922 Mdot
.56863 .56471 Mdot
.36078 .46275 Mdot
.53725 .01569 Mdot
.21961 .01961 Mdot
.4902 .51373 Mdot
.4549 .45098 Mdot
.4549 .47059 Mdot
.52157 .4902 Mdot
.35686 .43922 Mdot
.27059 .67059 Mdot
.41176 .4902 Mdot
.4902 .46667 Mdot
.46275 .46667 Mdot
.58039 .59608 Mdot
.52549 .4902 Mdot
.41961 .06667 Mdot
.35294 .03529 Mdot
.37255 .4 Mdot
.4549 .4549 Mdot
.46667 .47843 Mdot
.45098 .4549 Mdot
.56471 .58039 Mdot
.61176 .08627 Mdot
.35294 .43529 Mdot
.47451 .45098 Mdot
.46667 .44706 Mdot
.44706 .46275 Mdot
.40392 .38431 Mdot
.36078 .45882 Mdot
.43137 .08627 Mdot
.4549 .47059 Mdot
.47451 .44706 Mdot
.44314 .46275 Mdot
.50196 .47059 Mdot
.47059 .44706 Mdot
.5451 .09412 Mdot
.35686 .43137 Mdot
.5098 .48235 Mdot
.45882 .45098 Mdot
.43529 .45882 Mdot
.46275 .42353 Mdot
.50588 .45882 Mdot
.41569 .09412 Mdot
.46667 .45098 Mdot
.49412 .47451 Mdot
.43922 .46667 Mdot
.45098 .41961 Mdot
.48235 .47059 Mdot
.34118 .38039 Mdot
.37255 .40392 Mdot
.50588 .46667 Mdot
.44706 .45882 Mdot
.43137 .47059 Mdot
.48235 .45098 Mdot
.43137 .40392 Mdot
.42745 .31765 Mdot
.4902 .46667 Mdot
.47843 .46667 Mdot
.53333 .58824 Mdot
.4549 .42353 Mdot
.48235 .45882 Mdot
.32941 .38824 Mdot
.45098 .43922 Mdot
.48627 .45882 Mdot
.42745 .47843 Mdot
.40784 .46275 Mdot
.46667 .46667 Mdot
.43529 .41569 Mdot
.38824 .41176 Mdot
.47059 .45098 Mdot
.47451 .48627 Mdot
.11765 .23922 Mdot
.42353 .42745 Mdot
.47059 .4549 Mdot
.29412 .28627 Mdot
.48627 .47451 Mdot
.4902 .47059 Mdot
.24314 .35294 Mdot
.38824 .42353 Mdot
.4549 .4549 Mdot
.25098 .31765 Mdot
.36471 .38039 Mdot
.4902 .46667 Mdot
.19608 .2902 Mdot
.51373 .58824 Mdot
.47843 .46275 Mdot
.47451 .45098 Mdot
.39608 .27059 Mdot
.48627 .46667 Mdot
.39608 .42745 Mdot
.54118 .55294 Mdot
.4902 .44706 Mdot
.4902 .45098 Mdot
.19608 .2902 Mdot
.38039 .42745 Mdot
.48235 .46275 Mdot
.40784 .40392 Mdot
.57647 .59608 Mdot
.43922 .44314 Mdot
.4 .43137 Mdot
.36863 .42353 Mdot
.4902 .47059 Mdot
.19216 .30196 Mdot
.67451 .68235 Mdot
.47843 .47451 Mdot
.47843 .46667 Mdot
.41961 .38824 Mdot
.40392 .43922 Mdot
.23137 .32941 Mdot
.46667 .40392 Mdot
.46667 .40392 Mdot
.50196 .46667 Mdot
.2 .31373 Mdot
.3451 .41569 Mdot
.51373 .49804 Mdot
.51373 .44314 Mdot
.51373 .48235 Mdot
.50196 .48627 Mdot
.39216 .41961 Mdot
.27843 .69804 Mdot
.37255 .38431 Mdot
.36863 .40392 Mdot
.37255 .4 Mdot
.50588 .43529 Mdot
.47059 .43922 Mdot
.3098 .40784 Mdot
.43137 .4902 Mdot
.50588 .51373 Mdot
.55686 .47843 Mdot
.30588 .36471 Mdot
.52157 .50196 Mdot
.32549 .39216 Mdot
.47451 .52157 Mdot
.43922 .43529 Mdot
.51373 .47059 Mdot
.23529 .32157 Mdot
.52941 .5098 Mdot
.29804 .37647 Mdot
.55686 .42353 Mdot
.46275 .52549 Mdot
.46667 .41176 Mdot
.6902 .67843 Mdot
.53333 .50196 Mdot
.38039 .37255 Mdot
.38039 .46667 Mdot
.5098 .58431 Mdot
.51765 .43137 Mdot
.53333 .48627 Mdot
.58039 .52941 Mdot
.40784 .41569 Mdot
.39608 .47451 Mdot
.52941 .60784 Mdot
.47843 .50196 Mdot
.56863 .61961 Mdot
.63529 .58039 Mdot
.45098 .45098 Mdot
.40784 .49412 Mdot
.53725 .61176 Mdot
.50196 .56471 Mdot
.43922 .47843 Mdot
.73725 .65882 Mdot
.47843 .47843 Mdot
.44706 .52549 Mdot
.57255 .60392 Mdot
.53725 .60392 Mdot
.52941 .48235 Mdot
.82745 .78431 Mdot
.53725 .56471 Mdot
.45882 .53333 Mdot
.51765 .52941 Mdot
.56863 .63137 Mdot
.56863 .49804 Mdot
.85098 .83922 Mdot
.58431 .6 Mdot
.45098 .53725 Mdot
.58039 .65098 Mdot
.55294 .62745 Mdot
.56863 .56078 Mdot
.87451 .88235 Mdot
.7098 .64706 Mdot
.43137 .50588 Mdot
.60784 .68627 Mdot
.61569 .67843 Mdot
.98824 .99608 Mdot
.78039 .83137 Mdot
.54118 .60784 Mdot
.31373 .74902 Mdot
.61569 .6902 Mdot
.75294 .8 Mdot
.99216 .99216 Mdot
.67059 .7098 Mdot
.46667 .54118 Mdot
.64314 .72157 Mdot
.64706 .72157 Mdot
.99608 .99608 Mdot
.75294 .81176 Mdot
.5451 .62745 Mdot
.66667 .69804 Mdot
.66275 .73725 Mdot
.9451 .95294 Mdot
.88627 .92549 Mdot
.59608 .65882 Mdot
.65882 .67059 Mdot
.69412 .76863 Mdot
.92549 .94118 Mdot
.88235 .92549 Mdot
.54118 .61569 Mdot
.69412 .76863 Mdot
.78431 .83922 Mdot
.99216 .99216 Mdot
.8 .84314 Mdot
.17647 .88627 Mdot
.72941 .80392 Mdot
.93333 .95294 Mdot
.92157 .94902 Mdot
.4549 .41176 Mdot
.75294 .81569 Mdot
.91373 .9451 Mdot
.91373 .94118 Mdot
.32549 .76078 Mdot
.76471 .82353 Mdot
.98824 .99216 Mdot
.70196 .72549 Mdot
.67059 .6 Mdot
.96471 .97647 Mdot
.61176 .6 Mdot
.64706 .56078 Mdot
.75686 .72549 Mdot
.40784 .81961 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.34902 .78431 Mdot
.47451 .43529 Mdot
.8 .7451 Mdot
.74118 .75686 Mdot
.71373 .63529 Mdot
.43137 .43137 Mdot
.77255 .72157 Mdot
.76078 .7098 Mdot
.73725 .75294 Mdot
.79216 .79216 Mdot
.81176 .71765 Mdot
.83922 .83137 Mdot
.79216 .81569 Mdot
.72941 .58824 Mdot
.76863 .68627 Mdot
.61569 .63137 Mdot
.78039 .81961 Mdot
.7451 .63529 Mdot
.72549 .66275 Mdot
.71765 .74902 Mdot
.76078 .8 Mdot
.71765 .62353 Mdot
.84314 .76471 Mdot
.83922 .83137 Mdot
.78431 .81176 Mdot
.11765 .83529 Mdot
.65098 .60392 Mdot
.76863 .75686 Mdot
.16863 .30588 Mdot
.75686 .79608 Mdot
.71765 .63922 Mdot
.87451 .80784 Mdot
.73725 .7098 Mdot
.79216 .83137 Mdot
.74118 .74902 Mdot
.80392 .73333 Mdot
.87059 .80784 Mdot
.73333 .73333 Mdot
.77647 .81569 Mdot
.33333 .52549 Mdot
.82745 .73725 Mdot
.84706 .78431 Mdot
.72157 .72941 Mdot
.78824 .81569 Mdot
.10196 .82745 Mdot
.82353 .7451 Mdot
.86667 .79216 Mdot
.83922 .83137 Mdot
.79608 .82353 Mdot
.44314 .49804 Mdot
.8 .71765 Mdot
.80784 .81569 Mdot
.83529 .80784 Mdot
.78824 .83922 Mdot
.75294 .79608 Mdot
.7451 .65882 Mdot
.84706 .75686 Mdot
.81176 .76471 Mdot
.66275 .73725 Mdot
.75294 .78039 Mdot
.6902 .59216 Mdot
.79608 .7098 Mdot
.87059 .79608 Mdot
.7451 .70588 Mdot
.80392 .83922 Mdot
.72157 .75686 Mdot
.76863 .68627 Mdot
.83922 .7451 Mdot
.83137 .75686 Mdot
.38824 .44706 Mdot
.76471 .79216 Mdot
.6549 .56078 Mdot
.76078 .67843 Mdot
.84706 .76471 Mdot
.86667 .84706 Mdot
.08627 .22353 Mdot
.77255 .81176 Mdot
.69804 .61176 Mdot
.79216 .7098 Mdot
.85882 .78824 Mdot
.80784 .77647 Mdot
.80392 .83137 Mdot
.70588 .73725 Mdot
.84314 .58039 Mdot
.44314 .43922 Mdot
.85098 .76078 Mdot
.79608 .77647 Mdot
.79216 .83529 Mdot
.50588 .57647 Mdot
.70196 .14118 Mdot
.60392 .57647 Mdot
.83922 .75294 Mdot
.8 .76863 Mdot
.78824 .83137 Mdot
.2549 .34902 Mdot
.69412 .15294 Mdot
.65098 .62353 Mdot
.83922 .76471 Mdot
.71765 .69412 Mdot
.8 .83529 Mdot
.18431 .26275 Mdot
.61176 .26275 Mdot
.61961 .61176 Mdot
.85098 .77647 Mdot
.82745 .82353 Mdot
.80392 .83922 Mdot
.7451 .79216 Mdot
.68235 .61569 Mdot
.77255 .65882 Mdot
.85098 .76078 Mdot
.76471 .70588 Mdot
.72941 .5098 Mdot
.74902 .77647 Mdot
.61569 .56863 Mdot
.75686 .63922 Mdot
.82353 .7451 Mdot
.78431 .70588 Mdot
.67059 .38824 Mdot
.77255 .81176 Mdot
.50588 .44314 Mdot
.72157 .61961 Mdot
.36471 .41569 Mdot
.83529 .74902 Mdot
.7098 .64314 Mdot
.78431 .64314 Mdot
.39608 .46667 Mdot
.67843 .61176 Mdot
.7451 .61569 Mdot
.8549 .76863 Mdot
.82353 .75686 Mdot
.71765 .02745 Mdot
.73725 .72941 Mdot
.5451 .51765 Mdot
.70588 .61569 Mdot
.81176 .72549 Mdot
.80392 .73725 Mdot
.71373 .03529 Mdot
.80392 .80392 Mdot
.51765 .5451 Mdot
.68627 .62353 Mdot
.72941 .61176 Mdot
.85098 .76863 Mdot
.76078 .64314 Mdot
.6902 .01961 Mdot
.78039 .79216 Mdot
.56863 .56471 Mdot
.70196 .6 Mdot
.8 .7098 Mdot
.81176 .73333 Mdot
.7098 .01961 Mdot
.57647 .24314 Mdot
.61176 .66275 Mdot
.64314 .58824 Mdot
.7451 .61176 Mdot
.83529 .76078 Mdot
.83137 .61961 Mdot
.70196 .01961 Mdot
.66275 .59608 Mdot
.66275 .73333 Mdot
.68235 .59608 Mdot
.78039 .6549 Mdot
.46275 .46667 Mdot
.72941 .02745 Mdot
.67059 .02353 Mdot
.20784 .27843 Mdot
.60392 .59608 Mdot
.7098 .57255 Mdot
.8 .72157 Mdot
.80392 .71765 Mdot
.67843 .03137 Mdot
.74902 .58824 Mdot
.10588 .82745 Mdot
.63922 .58039 Mdot
.75686 .62745 Mdot
.53725 .49412 Mdot
.78039 .07451 Mdot
.4 .30588 Mdot
.65098 .59216 Mdot
.73725 .77647 Mdot
.68627 .6 Mdot
.77255 .65098 Mdot
.51373 .5451 Mdot
.76078 .04314 Mdot
.21961 .28627 Mdot
.68627 .62745 Mdot
.8 .82353 Mdot
.67451 .58824 Mdot
.79608 .68235 Mdot
.81961 .76471 Mdot
.65098 .11373 Mdot
.58431 .28235 Mdot
.41176 .43922 Mdot
.57647 .56863 Mdot
.69412 .56863 Mdot
.80784 .72549 Mdot
.88627 .61176 Mdot
.15294 .23529 Mdot
.63137 .02353 Mdot
.53333 .53725 Mdot
.62745 .58824 Mdot
.71765 .59216 Mdot
.82745 .76078 Mdot
.81176 .06667 Mdot
.80784 .81961 Mdot
.66667 .67059 Mdot
.69804 .7451 Mdot
.62353 .57255 Mdot
.75294 .63529 Mdot
.86667 .78824 Mdot
.8 .05882 Mdot
.70196 .68235 Mdot
.66667 .59216 Mdot
.70588 .77255 Mdot
.64706 .59608 Mdot
.76863 .66667 Mdot
.85098 .78824 Mdot
.7098 .34118 Mdot
.72157 .74902 Mdot
.57255 .50196 Mdot
.47451 .57647 Mdot
.64706 .58039 Mdot
.78431 .6902 Mdot
.83529 .77647 Mdot
.12941 .24314 Mdot
.21176 .27843 Mdot
.51373 .46275 Mdot
.57255 .66275 Mdot
.67059 .57647 Mdot
.78039 .69804 Mdot
.84706 .76078 Mdot
.67843 .61961 Mdot
.69412 .79608 Mdot
.43137 .39216 Mdot
.77255 .81569 Mdot
.67059 .56471 Mdot
.8 .70588 Mdot
.72157 .25882 Mdot
.7451 .4549 Mdot
.77255 .81961 Mdot
.4902 .43922 Mdot
.65882 .69412 Mdot
.67843 .56471 Mdot
.78824 .7098 Mdot
.82353 .08235 Mdot
.7098 .04314 Mdot
.78431 .82353 Mdot
.38039 .37255 Mdot
.52157 .55294 Mdot
.67843 .55686 Mdot
.80784 .72157 Mdot
.83922 .0902 Mdot
.71765 .02353 Mdot
.79216 .82745 Mdot
.29412 .30196 Mdot
.54902 .56471 Mdot
.69804 .56863 Mdot
.80392 .71373 Mdot
.81569 .09412 Mdot
.71373 .02353 Mdot
.77647 .74118 Mdot
.39216 .38431 Mdot
.56471 .56863 Mdot
.67843 .56471 Mdot
.81569 .72941 Mdot
.75686 .30196 Mdot
.70588 .02745 Mdot
.59216 .37647 Mdot
.54902 .51765 Mdot
.58431 .58431 Mdot
.70588 .59216 Mdot
.82353 .74118 Mdot
.19608 .27059 Mdot
.63137 .11765 Mdot
.52549 .07843 Mdot
.56078 .49412 Mdot
.58431 .58431 Mdot
.69804 .6 Mdot
.80784 .73725 Mdot
.12941 .30196 Mdot
.51373 .34902 Mdot
.51765 .07059 Mdot
.52549 .44706 Mdot
.58824 .59216 Mdot
.71765 .62353 Mdot
.81176 .72941 Mdot
.46667 .58431 Mdot
.08235 .16863 Mdot
.52157 .06275 Mdot
.5451 .47451 Mdot
.58431 .58431 Mdot
.71373 .62745 Mdot
.80392 .72549 Mdot
.71373 .74118 Mdot
.32549 .41176 Mdot
.52549 .07059 Mdot
.49804 .43137 Mdot
.59216 .58824 Mdot
.70588 .61961 Mdot
.8 .72941 Mdot
.78039 .7451 Mdot
.77647 .77255 Mdot
.52549 .06667 Mdot
.52157 .47451 Mdot
.5451 .54902 Mdot
.71373 .63529 Mdot
.79608 .72549 Mdot
.80784 .72941 Mdot
.7098 .62353 Mdot
.53725 .07451 Mdot
.59216 .55686 Mdot
.52549 .53333 Mdot
.71765 .62745 Mdot
.80392 .72157 Mdot
.85882 .67451 Mdot
.72941 .50196 Mdot
.5451 .06667 Mdot
.58431 .57255 Mdot
.52549 .52941 Mdot
.73725 .63922 Mdot
.80392 .73333 Mdot
.71373 .26275 Mdot
.63529 .16863 Mdot
.54902 .0549 Mdot
.58824 .58039 Mdot
.50196 .50588 Mdot
.73725 .63922 Mdot
.8 .72549 Mdot
.75686 .11765 Mdot
.68235 .0549 Mdot
.56471 .0549 Mdot
.65098 .65882 Mdot
.50196 .50588 Mdot
.72549 .63922 Mdot
.80392 .72549 Mdot
.78039 .10196 Mdot
.66275 .05882 Mdot
.57647 .0549 Mdot
.60392 .63529 Mdot
.4902 .49804 Mdot
.72157 .64314 Mdot
.81569 .73333 Mdot
.73725 .1098 Mdot
.60784 .22353 Mdot
.56863 .04706 Mdot
.5098 .5451 Mdot
.48235 .48627 Mdot
.72157 .63529 Mdot
.80392 .73333 Mdot
.70588 .23529 Mdot
.32941 .18824 Mdot
.56078 .03922 Mdot
.68235 .72549 Mdot
.44314 .46275 Mdot
.69804 .61569 Mdot
.78431 .72157 Mdot
.73725 .30588 Mdot
.66275 .31373 Mdot
.49804 .06667 Mdot
.47843 .56863 Mdot
.65882 .69412 Mdot
.68235 .61569 Mdot
.78431 .7098 Mdot
.73725 .47059 Mdot
.63922 .04706 Mdot
.52941 .31373 Mdot
.3098 .41961 Mdot
.72941 .76471 Mdot
.69804 .62745 Mdot
.79216 .71765 Mdot
.50588 .47059 Mdot
.69412 .04706 Mdot
.35294 .35686 Mdot
.62745 .73333 Mdot
.70588 .76078 Mdot
.71765 .65098 Mdot
.76863 .70196 Mdot
.20784 .3098 Mdot
.63137 .07843 Mdot
.37647 .4549 Mdot
.35686 .47451 Mdot
.54902 .65098 Mdot
.7098 .64706 Mdot
.78039 .70196 Mdot
.6549 .66275 Mdot
.61569 .17647 Mdot
.56471 .63137 Mdot
.7098 .79608 Mdot
.40392 .51765 Mdot
.70196 .6549 Mdot
.77255 .6902 Mdot
.81569 .77255 Mdot
.6549 .27451 Mdot
.58039 .41961 Mdot
.72549 .79216 Mdot
.38431 .5098 Mdot
.67451 .64314 Mdot
.76078 .68235 Mdot
.81176 .78039 Mdot
.67451 .3098 Mdot
.54902 .03922 Mdot
.70588 .77647 Mdot
.33333 .45882 Mdot
.68235 .6549 Mdot
.7451 .67451 Mdot
.81569 .78039 Mdot
.66275 .30196 Mdot
.63922 .01176 Mdot
.73333 .80392 Mdot
.31765 .42353 Mdot
.68627 .65098 Mdot
.74118 .67843 Mdot
.81961 .78431 Mdot
.6549 .30196 Mdot
.65882 .01569 Mdot
.72157 .79216 Mdot
.34902 .46275 Mdot
.66667 .63922 Mdot
.74118 .66275 Mdot
.82353 .78824 Mdot
.77255 .62353 Mdot
.63922 .38824 Mdot
.72157 .79608 Mdot
.56078 .6549 Mdot
.63137 .63137 Mdot
.73333 .6549 Mdot
.8 .76078 Mdot
.73333 .68627 Mdot
.62353 .65098 Mdot
.72549 .79216 Mdot
.53725 .54902 Mdot
.60784 .61176 Mdot
.73725 .64314 Mdot
.80392 .75686 Mdot
.73725 .72549 Mdot
.61961 .63137 Mdot
.72941 .79608 Mdot
.68627 .56078 Mdot
.55686 .56863 Mdot
.72941 .64314 Mdot
.79608 .75294 Mdot
.72941 .7098 Mdot
.61176 .60392 Mdot
.71765 .80392 Mdot
.31373 .26667 Mdot
.55686 .56471 Mdot
.71765 .63922 Mdot
.8 .74118 Mdot
.73725 .71765 Mdot
.61961 .61176 Mdot
.63922 .7451 Mdot
.1098 .16863 Mdot
.56078 .56471 Mdot
.69412 .61569 Mdot
.80392 .73725 Mdot
.7451 .73333 Mdot
.62745 .61961 Mdot
.43922 .2549 Mdot
.52549 .59216 Mdot
.5451 .56078 Mdot
.70196 .61569 Mdot
.8 .73725 Mdot
.75294 .72941 Mdot
.64706 .63529 Mdot
.5451 .02353 Mdot
.56471 .63922 Mdot
.65882 .69412 Mdot
.70196 .62745 Mdot
.79608 .73725 Mdot
.75686 .72941 Mdot
.61569 .61176 Mdot
.59216 .00784 Mdot
.40784 .48627 Mdot
.33333 .42745 Mdot
.68627 .62353 Mdot
.79608 .72549 Mdot
.77647 .75686 Mdot
.56471 .12941 Mdot
.50588 .26667 Mdot
.4 .52941 Mdot
.55294 .65098 Mdot
.66275 .60784 Mdot
.77647 .70196 Mdot
.78824 .76471 Mdot
.67451 .0549 Mdot
.65098 .59216 Mdot
.67451 .76863 Mdot
.16863 .30196 Mdot
.67059 .62353 Mdot
.77255 .69804 Mdot
.78039 .74902 Mdot
.70196 .04706 Mdot
.61176 .04314 Mdot
.7098 .78824 Mdot
.3451 .45098 Mdot
.67059 .64314 Mdot
.74902 .67451 Mdot
.78039 .75686 Mdot
.69804 .07843 Mdot
.66275 .01569 Mdot
.69804 .77647 Mdot
.44706 .55686 Mdot
.63922 .61176 Mdot
.73333 .65882 Mdot
.76471 .74902 Mdot
.62353 .28235 Mdot
.6549 .00784 Mdot
.72157 .79216 Mdot
.49804 .58039 Mdot
.61961 .61961 Mdot
.74118 .65882 Mdot
.76471 .73725 Mdot
.73333 .68627 Mdot
.66275 .01569 Mdot
.7098 .69412 Mdot
.69804 .66275 Mdot
.59608 .6 Mdot
.71373 .64706 Mdot
.75686 .72941 Mdot
.75294 .72549 Mdot
.65098 .01569 Mdot
.52157 .01961 Mdot
.27451 .21176 Mdot
.58039 .58824 Mdot
.7098 .63529 Mdot
.77255 .7451 Mdot
.72941 .72941 Mdot
.66667 .02353 Mdot
.57647 .00392 Mdot
.01569 .08235 Mdot
.52549 .55686 Mdot
.69804 .61961 Mdot
.75294 .72941 Mdot
.7451 .75294 Mdot
.68627 .03922 Mdot
.59216 .00392 Mdot
.02353 .1098 Mdot
.76471 .81961 Mdot
.68235 .60784 Mdot
.74118 .68627 Mdot
.75294 .75686 Mdot
.70196 .02745 Mdot
.53725 .44706 Mdot
.57647 .65882 Mdot
.25098 .35294 Mdot
.64314 .58039 Mdot
.69412 .63922 Mdot
.76078 .76078 Mdot
.7098 .03137 Mdot
.41569 .43529 Mdot
.16471 .29804 Mdot
.58431 .6902 Mdot
.61569 .56078 Mdot
.68627 .61961 Mdot
.76471 .76863 Mdot
.72157 .04314 Mdot
.58039 .03529 Mdot
.68627 .78039 Mdot
.23137 .34902 Mdot
.62353 .59216 Mdot
.66275 .59608 Mdot
.56863 .59216 Mdot
.7098 .05098 Mdot
.6549 .01569 Mdot
.67059 .77255 Mdot
.37255 .48627 Mdot
.60392 .58431 Mdot
.68627 .61176 Mdot
.66275 .66667 Mdot
.60784 .11373 Mdot
.63922 .00784 Mdot
.65098 .77647 Mdot
.66667 .73725 Mdot
.60784 .58824 Mdot
.6902 .60784 Mdot
.72549 .71373 Mdot
.78039 .62745 Mdot
.64706 .00392 Mdot
.29412 .4549 Mdot
.63922 .59216 Mdot
.57647 .55686 Mdot
.67059 .59608 Mdot
.66667 .63922 Mdot
.70588 .70588 Mdot
.64706 .01176 Mdot
.03529 .08235 Mdot
.33725 .32941 Mdot
.56471 .56863 Mdot
.66275 .57255 Mdot
.66275 .62353 Mdot
.7098 .70588 Mdot
.67843 .03137 Mdot
.15294 .04706 Mdot
.22353 .30196 Mdot
.52549 .54118 Mdot
.66667 .58431 Mdot
.66667 .63922 Mdot
.73333 .72941 Mdot
.67843 .02745 Mdot
.57255 .47843 Mdot
.32941 .39216 Mdot
.47059 .48627 Mdot
.64314 .55686 Mdot
.64706 .60392 Mdot
.7451 .75686 Mdot
.69412 .02745 Mdot
.60392 .72941 Mdot
.41176 .48627 Mdot
.43137 .40392 Mdot
.63137 .55294 Mdot
.64706 .58824 Mdot
.76078 .75686 Mdot
.68627 .03529 Mdot
.36863 .56078 Mdot
.64706 .73725 Mdot
.42745 .33333 Mdot
.61569 .53725 Mdot
.65882 .57647 Mdot
.77255 .77647 Mdot
.69804 .03137 Mdot
.04706 .1451 Mdot
.27451 .40392 Mdot
.44314 .45882 Mdot
.6 .53333 Mdot
.64314 .56471 Mdot
.76863 .75294 Mdot
.71765 .04706 Mdot
.38431 .31765 Mdot
.28627 .39608 Mdot
.65882 .73725 Mdot
.59608 .55294 Mdot
.63137 .56471 Mdot
.73725 .74118 Mdot
.71373 .03529 Mdot
.56471 .3098 Mdot
.69412 .78039 Mdot
.68627 .75686 Mdot
.56078 .53725 Mdot
.63137 .54902 Mdot
.63529 .63137 Mdot
.60784 .1098 Mdot
.51765 .1451 Mdot
.36078 .37255 Mdot
.67451 .64706 Mdot
.56863 .56471 Mdot
.62353 .54118 Mdot
.62353 .61176 Mdot
.70588 .72157 Mdot
.57647 .03922 Mdot
.56471 .42745 Mdot
.17647 .23922 Mdot
.52941 .53725 Mdot
.61961 .52941 Mdot
.62353 .60392 Mdot
.7098 .72549 Mdot
.46667 .10588 Mdot
.74118 .81176 Mdot
.25882 .36078 Mdot
.4549 .47843 Mdot
.63137 .54118 Mdot
.61569 .59216 Mdot
.7098 .73725 Mdot
.56863 .62745 Mdot
.4902 .64314 Mdot
.1451 .2549 Mdot
.37647 .12157 Mdot
.61961 .54902 Mdot
.66275 .63137 Mdot
.72549 .7451 Mdot
.57255 .58431 Mdot
.20392 .31373 Mdot
.31373 .43529 Mdot
.4549 .33333 Mdot
.63529 .55686 Mdot
.61961 .58824 Mdot
.74118 .74902 Mdot
.51765 .12941 Mdot
.58824 .56078 Mdot
.01569 .12549 Mdot
.43922 .18431 Mdot
.62353 .54118 Mdot
.63137 .59216 Mdot
.7451 .74902 Mdot
.57647 .12157 Mdot
.58039 .37647 Mdot
.5451 .63529 Mdot
.31373 .11373 Mdot
.56863 .49412 Mdot
.63922 .6 Mdot
.53725 .58039 Mdot
.58824 .1451 Mdot
.51373 .13333 Mdot
.3098 .43922 Mdot
.32157 .22353 Mdot
.54118 .49804 Mdot
.61569 .55294 Mdot
.53725 .56471 Mdot
.7451 .64706 Mdot
.50196 .10588 Mdot
.70588 .78824 Mdot
.30196 .70588 Mdot
.54902 .5098 Mdot
.61569 .56863 Mdot
.66275 .66667 Mdot
.6902 .71373 Mdot
.53725 .14902 Mdot
.44706 .11373 Mdot
.00392 .07059 Mdot
.4902 .48235 Mdot
.61176 .54902 Mdot
.66275 .67059 Mdot
.71373 .72941 Mdot
.53725 .12549 Mdot
.58039 .00784 Mdot
.00392 .04706 Mdot
.47451 .47451 Mdot
.61961 .54118 Mdot
.69412 .68627 Mdot
.69412 .73333 Mdot
.56863 .15294 Mdot
.56863 .00392 Mdot
.00784 .07843 Mdot
.46667 .43137 Mdot
.60392 .52941 Mdot
.66667 .65882 Mdot
.7098 .7451 Mdot
.55294 .20392 Mdot
.59608 .00784 Mdot
.32549 .39608 Mdot
.38824 .21176 Mdot
.58431 .50588 Mdot
.66275 .64706 Mdot
.70588 .72157 Mdot
.43137 .35686 Mdot
.61569 .00784 Mdot
.36863 .46275 Mdot
.32941 .08627 Mdot
.53333 .43922 Mdot
.66275 .63922 Mdot
.69412 .71765 Mdot
.21176 .23922 Mdot
.59608 .00784 Mdot
.37647 .47059 Mdot
.47451 .20784 Mdot
.50196 .42745 Mdot
.64706 .61176 Mdot
.69804 .71765 Mdot
.27059 .28627 Mdot
.55686 .02353 Mdot
.35686 .44706 Mdot
.38039 .19608 Mdot
.47451 .44314 Mdot
.65098 .61176 Mdot
.6902 .72157 Mdot
.70196 .67451 Mdot
.52941 .04314 Mdot
.33333 .18039 Mdot
.46667 .31373 Mdot
.50196 .47451 Mdot
.61961 .59216 Mdot
.68235 .70588 Mdot
.68627 .71373 Mdot
.51765 .06275 Mdot
.49804 .00392 Mdot
.26667 .31373 Mdot
.43922 .42353 Mdot
.6 .54902 Mdot
.68627 .7098 Mdot
.65098 .6902 Mdot
.50588 .07059 Mdot
.44706 .16078 Mdot
.24706 .34118 Mdot
.40784 .40392 Mdot
.61569 .56863 Mdot
.65098 .67059 Mdot
.68235 .71373 Mdot
.57647 .03137 Mdot
.53333 .5098 Mdot
.32941 .40392 Mdot
.3451 .34902 Mdot
.60392 .54902 Mdot
.68235 .68627 Mdot
.66667 .7098 Mdot
.63529 .01961 Mdot
.55294 .03137 Mdot
.00784 .1098 Mdot
.30196 .29804 Mdot
.58431 .51765 Mdot
.6902 .69412 Mdot
.65098 .68627 Mdot
.67059 .02353 Mdot
.60784 .00392 Mdot
.36471 .44314 Mdot
.33725 .30196 Mdot
.55294 .4549 Mdot
.67843 .66275 Mdot
.7098 .72941 Mdot
.65882 .00784 Mdot
.61176 .00392 Mdot
.39608 .47843 Mdot
.39608 .12157 Mdot
.51373 .43922 Mdot
.67059 .63922 Mdot
.69412 .71373 Mdot
.70588 .03529 Mdot
.59608 .00784 Mdot
.48235 .6 Mdot
.47451 .3451 Mdot
.4902 .4549 Mdot
.6549 .61961 Mdot
.66667 .70196 Mdot
.69412 .03922 Mdot
.50588 .04314 Mdot
.41569 .04706 Mdot
.19216 .27843 Mdot
.38431 .38431 Mdot
.65098 .6 Mdot
.58431 .58824 Mdot
.65098 .34902 Mdot
.51765 .56471 Mdot
.55686 .42745 Mdot
.00392 .0549 Mdot
.31373 .31765 Mdot
.61569 .55294 Mdot
.53333 .54902 Mdot
.66275 .68235 Mdot
.49804 .59216 Mdot
.63137 .80392 Mdot
.01569 .08627 Mdot
.27843 .27451 Mdot
.59608 .52549 Mdot
.61176 .61569 Mdot
.63137 .66275 Mdot
.34118 .4902 Mdot
.10196 .18824 Mdot
.35294 .43922 Mdot
.29804 .27451 Mdot
.58039 .50196 Mdot
.66667 .66275 Mdot
.67059 .69804 Mdot
.03529 .18824 Mdot
.02353 .12941 Mdot
.39608 .47451 Mdot
.39608 .39608 Mdot
.5098 .44314 Mdot
.62353 .61961 Mdot
.68235 .70588 Mdot
.42745 .33333 Mdot
.02353 .12941 Mdot
.40784 .48627 Mdot
.43137 .37647 Mdot
.48235 .44314 Mdot
.60392 .57255 Mdot
.63922 .69804 Mdot
.60392 .07059 Mdot
.52941 .18039 Mdot
.62353 .74902 Mdot
.20784 .27843 Mdot
.40392 .38431 Mdot
.56863 .52157 Mdot
.61176 .61961 Mdot
.66667 .02353 Mdot
.5098 .32941 Mdot
.1451 .15686 Mdot
.28627 .40392 Mdot
.30588 .29804 Mdot
.52157 .46275 Mdot
.63529 .6549 Mdot
.65882 .06275 Mdot
.54118 .58039 Mdot
.47843 .10196 Mdot
.32157 .41569 Mdot
.29412 .12549 Mdot
.55294 .45098 Mdot
.65098 .6549 Mdot
.66667 .65882 Mdot
.54902 .12549 Mdot
.52941 .03137 Mdot
.34902 .44706 Mdot
.35686 .28235 Mdot
.53333 .4549 Mdot
.54902 .55294 Mdot
.60784 .66667 Mdot
.55294 .07843 Mdot
.51765 .03529 Mdot
.38431 .46275 Mdot
.41569 .38824 Mdot
.54902 .49804 Mdot
.58431 .57255 Mdot
.64706 .68627 Mdot
.57255 .38824 Mdot
.40784 .26667 Mdot
.46275 .48627 Mdot
.19608 .26275 Mdot
.45882 .41961 Mdot
.5451 .47843 Mdot
.63137 .65098 Mdot
.12157 .22353 Mdot
.61961 .67843 Mdot
.47843 .03137 Mdot
0 .07451 Mdot
.37647 .35294 Mdot
.54902 .4902 Mdot
.67843 .71373 Mdot
.58431 .24314 Mdot
.3451 .48235 Mdot
.55686 .00392 Mdot
.00392 .0549 Mdot
.36078 .3098 Mdot
.52941 .43529 Mdot
.66275 .67451 Mdot
.72157 .05098 Mdot
.56078 .04314 Mdot
.55294 .00784 Mdot
.00392 .06667 Mdot
.26667 .22353 Mdot
.4902 .39608 Mdot
.54118 .53725 Mdot
.68235 .5098 Mdot
.50196 .56863 Mdot
.50196 .03529 Mdot
.00784 .0902 Mdot
.45882 .31765 Mdot
.54902 .47059 Mdot
.58431 .58039 Mdot
.65882 .69412 Mdot
.13333 .32157 Mdot
.4902 .42745 Mdot
.41961 .31373 Mdot
.56863 .4 Mdot
.51373 .47843 Mdot
.60784 .56471 Mdot
.67843 .7098 Mdot
.40784 .32941 Mdot
.69804 .77647 Mdot
.52549 .00392 Mdot
.3098 .40784 Mdot
.41569 .37647 Mdot
.6 .52941 Mdot
.65882 .6902 Mdot
.67843 .06667 Mdot
.53725 .63529 Mdot
.44314 .10588 Mdot
.29412 .42353 Mdot
.35294 .30588 Mdot
.53333 .43529 Mdot
.55686 .59216 Mdot
.72549 .20784 Mdot
.06275 .15294 Mdot
.46667 .0902 Mdot
.01569 .09804 Mdot
.32157 .26667 Mdot
.47843 .38039 Mdot
.78824 .82745 Mdot
.71765 .07059 Mdot
.52941 .27451 Mdot
.48235 .02353 Mdot
.33333 .45098 Mdot
.32549 .22745 Mdot
.53333 .44706 Mdot
.48235 .51373 Mdot
.60392 .65882 Mdot
.59608 .03922 Mdot
.54902 .00392 Mdot
.06275 .17255 Mdot
.38824 .29804 Mdot
.52549 .46275 Mdot
.60392 .59608 Mdot
.65882 .70588 Mdot
.62353 .07451 Mdot
.55686 .01961 Mdot
.04314 .06275 Mdot
.1098 .18431 Mdot
.49804 .43137 Mdot
.58039 .52549 Mdot
.65098 .68235 Mdot
.54902 .1098 Mdot
.57647 .64314 Mdot
.43137 .0549 Mdot
.00784 .0549 Mdot
.39608 .33725 Mdot
.57255 .5098 Mdot
.63922 .66275 Mdot
.6902 .03922 Mdot
.42745 .49804 Mdot
.67059 .71373 Mdot
.05098 .12941 Mdot
.33333 .27451 Mdot
.51373 .41961 Mdot
.5098 .53725 Mdot
.57255 .08235 Mdot
.63137 .71373 Mdot
.45098 .04314 Mdot
.06275 .18431 Mdot
.32941 .08627 Mdot
.52157 .41569 Mdot
.52941 .5451 Mdot
.65098 .70588 Mdot
.53725 .65882 Mdot
.07059 .16078 Mdot
.31765 .41569 Mdot
.47059 .30196 Mdot
.44706 .38039 Mdot
.58824 .57647 Mdot
.66275 .69804 Mdot
.19216 .34118 Mdot
.52157 .01961 Mdot
.07451 .2 Mdot
.17255 .27059 Mdot
.43137 .03529 Mdot
.56863 .51373 Mdot
.59216 .63137 Mdot
.25098 .43137 Mdot
.46275 .55294 Mdot
.31373 .21961 Mdot
.1098 .21569 Mdot
.34118 .13725 Mdot
.53333 .4549 Mdot
.50196 .54118 Mdot
.67059 .06275 Mdot
.48627 .6 Mdot
.47451 .0549 Mdot
.3451 .44314 Mdot
.32941 .25098 Mdot
.51373 .41176 Mdot
.48627 .50588 Mdot
.58431 .29412 Mdot
.52549 .6 Mdot
.48627 .02353 Mdot
.38039 .48235 Mdot
.33725 .28235 Mdot
.48627 .38431 Mdot
.53725 .55686 Mdot
.63529 .6902 Mdot
.64314 .71765 Mdot
.40784 .03529 Mdot
.32941 .44314 Mdot
.36863 .12941 Mdot
.38824 .30588 Mdot
.59608 .58431 Mdot
.65098 .6902 Mdot
.6 .66275 Mdot
.65098 .61961 Mdot
.41569 .29412 Mdot
.01569 .11765 Mdot
.39608 .31373 Mdot
.57255 .52157 Mdot
.46667 .5098 Mdot
.24706 .23137 Mdot
.5098 .6549 Mdot
.42745 .02745 Mdot
.25098 .37647 Mdot
.37647 .26275 Mdot
.51765 .44706 Mdot
.46275 .50196 Mdot
.72157 .05098 Mdot
.53725 .63137 Mdot
.52549 .00392 Mdot
.36471 .46667 Mdot
.38039 .06667 Mdot
.51765 .40784 Mdot
.43137 .46275 Mdot
.62745 .66275 Mdot
.57255 .66275 Mdot
.4 .11373 Mdot
.35686 .43529 Mdot
.30196 .09804 Mdot
.36471 .2902 Mdot
.49804 .49412 Mdot
.58824 .65098 Mdot
.57647 .64314 Mdot
.58039 .5098 Mdot
.43137 0 Mdot
.00392 .05882 Mdot
.37255 .27451 Mdot
.58431 .55294 Mdot
.44706 .50196 Mdot
.55686 .35294 Mdot
.74118 .80784 Mdot
.4549 .00392 Mdot
.00392 .04706 Mdot
.36078 .28235 Mdot
.57647 .50588 Mdot
.43529 .4902 Mdot
.71373 .03529 Mdot
.46667 .64706 Mdot
.5098 .00392 Mdot
.02745 .11765 Mdot
.32549 .27059 Mdot
.54118 .44706 Mdot
.36471 .43529 Mdot
.60392 .31765 Mdot
.60784 .72941 Mdot
.50588 0 Mdot
.31765 .42745 Mdot
.43529 .21961 Mdot
.41961 .33725 Mdot
.28627 .33725 Mdot
.57647 .63137 Mdot
.60392 .67843 Mdot
.51765 0 Mdot
.3451 .02745 Mdot
.1451 .6549 Mdot
.32941 .24706 Mdot
.4902 .49412 Mdot
.51373 .56471 Mdot
.56863 .06667 Mdot
.55686 .00392 Mdot
.32941 .26275 Mdot
.21176 .35294 Mdot
.34118 .27059 Mdot
.56078 .51765 Mdot
.42745 .4902 Mdot
.70196 .03922 Mdot
.56078 .02353 Mdot
.08235 .21176 Mdot
0 .03529 Mdot
.34118 .10196 Mdot
.5451 .44706 Mdot
.40784 .47059 Mdot
.67843 .65098 Mdot
.67451 .62353 Mdot
.42745 .11373 Mdot
.32941 .42353 Mdot
.48235 .39608 Mdot
.48235 .39216 Mdot
.4902 .50196 Mdot
.50588 .57255 Mdot
.61176 .65882 Mdot
.56471 .40784 Mdot
.05098 .13725 Mdot
.05882 .80784 Mdot
.35686 .27451 Mdot
.44706 .45098 Mdot
.49412 .56471 Mdot
.69412 .03529 Mdot
.44314 .07451 Mdot
.44706 .00392 Mdot
.2549 .36863 Mdot
.35686 .27451 Mdot
.57255 .52549 Mdot
.76863 .83922 Mdot
.68235 .04706 Mdot
.58039 .00784 Mdot
.41961 .05882 Mdot
.11373 .21176 Mdot
.3098 .2 Mdot
.51373 .40784 Mdot
.44706 .49804 Mdot
.55686 .61569 Mdot
.61176 .00392 Mdot
.28235 .36078 Mdot
.30196 .40392 Mdot
.45098 .12941 Mdot
.47451 .39608 Mdot
.47059 .50588 Mdot
.48235 .56471 Mdot
.59216 .06275 Mdot
.45882 .16471 Mdot
.31373 .06667 Mdot
.2549 .63529 Mdot
.37647 .28627 Mdot
.45098 .47451 Mdot
.53333 .59216 Mdot
.66275 .04706 Mdot
.44706 .20784 Mdot
.44706 .00784 Mdot
.28627 .38824 Mdot
.32549 .2549 Mdot
.49412 .46275 Mdot
.46667 .53333 Mdot
.53333 .26667 Mdot
.04314 .19216 Mdot
.4902 .00392 Mdot
.28627 .40392 Mdot
.31373 .16471 Mdot
.56078 .33725 Mdot
.47843 .53333 Mdot
.67451 .74902 Mdot
.47451 .2549 Mdot
.51765 .00392 Mdot
.28627 .40784 Mdot
.51373 .32941 Mdot
.48235 .37647 Mdot
.4549 .47451 Mdot
.45882 .53725 Mdot
.69804 .03922 Mdot
.41961 .31373 Mdot
.32157 .06667 Mdot
.13333 .64706 Mdot
.33725 .04314 Mdot
.43529 .45098 Mdot
.50196 .57647 Mdot
.68627 .09412 Mdot
.49412 .13333 Mdot
.41569 .30196 Mdot
.25098 .36863 Mdot
.33725 .24314 Mdot
.53725 .49804 Mdot
.44314 .51373 Mdot
.70588 .77647 Mdot
.5098 .11765 Mdot
.28627 .24706 Mdot
.28235 .41176 Mdot
.30588 .24706 Mdot
.51373 .42745 Mdot
.44706 .4902 Mdot
.54118 .61961 Mdot
.32941 .46667 Mdot
.42353 .02353 Mdot
.29412 .41176 Mdot
.46275 .27451 Mdot
.4 .33333 Mdot
.46667 .48627 Mdot
.6902 .76863 Mdot
.62353 .13333 Mdot
.54902 .00784 Mdot
.31373 .18431 Mdot
.24314 .62353 Mdot
.37647 .24706 Mdot
.46667 .47843 Mdot
.52549 .60392 Mdot
.72157 .0549 Mdot
.50588 .54118 Mdot
.44706 0 Mdot
.27059 .38824 Mdot
.33725 .04706 Mdot
.54902 .51373 Mdot
.38824 .46667 Mdot
.63922 .42353 Mdot
.51765 .29412 Mdot
.41961 .12941 Mdot
.29804 .41176 Mdot
.32549 .26667 Mdot
.51373 .42353 Mdot
.41569 .46275 Mdot
.55686 .63137 Mdot
.73725 .29412 Mdot
.02353 .08627 Mdot
.25098 .38824 Mdot
.37255 .15294 Mdot
.35686 .27843 Mdot
.42353 .46667 Mdot
.70196 .78039 Mdot
.67059 .02353 Mdot
.56863 .00392 Mdot
.41176 .00392 Mdot
.20392 .32157 Mdot
.37647 .30196 Mdot
.55294 .54902 Mdot
.27059 .38431 Mdot
.62353 .07451 Mdot
.74118 .83529 Mdot
.44314 0 Mdot
.28235 .4 Mdot
.34118 .22745 Mdot
.51765 .46667 Mdot
.40392 .47843 Mdot
.54902 .27451 Mdot
.11373 .28627 Mdot
.51373 .00392 Mdot
.27843 .40392 Mdot
.32941 .23137 Mdot
.47451 .41176 Mdot
.42353 .47843 Mdot
.74118 .80784 Mdot
.53333 .15686 Mdot
.52549 .00784 Mdot
.2 .33333 Mdot
.32941 .08627 Mdot
.44314 .35294 Mdot
.47059 .48627 Mdot
.50588 .58431 Mdot
.63137 .0549 Mdot
.48627 .16078 Mdot
.40784 .00784 Mdot
.27059 .37647 Mdot
.37255 .29804 Mdot
.52941 .51765 Mdot
.37255 .50588 Mdot
.2 .21569 Mdot
.74902 .82353 Mdot
.26667 .21176 Mdot
.28235 .4 Mdot
.30588 .25098 Mdot
.40392 .30196 Mdot
.42745 .49412 Mdot
.73333 .6902 Mdot
.71373 .8549 Mdot
.47843 .01569 Mdot
.2902 .41176 Mdot
.34902 .08627 Mdot
.42745 .37255 Mdot
.78039 .82353 Mdot
.70196 .77255 Mdot
.59608 .02745 Mdot
.51765 .00784 Mdot
.00784 .08627 Mdot
.23922 .33333 Mdot
.44314 .12157 Mdot
.54118 .54902 Mdot
.44706 .52549 Mdot
.73333 .48235 Mdot
.74118 .81569 Mdot
.42745 .01569 Mdot
.2549 .38039 Mdot
.36863 .13333 Mdot
.47451 .42353 Mdot
.04314 .18431 Mdot
.56863 .31373 Mdot
.7451 .83529 Mdot
.48627 .60784 Mdot
.28627 .40784 Mdot
.36863 .28235 Mdot
.44706 .40392 Mdot
.41176 .47059 Mdot
.77647 .84706 Mdot
.05882 .23137 Mdot
.15686 .17255 Mdot
.29412 .41176 Mdot
.48235 .25098 Mdot
.46275 .41176 Mdot
.44706 .49804 Mdot
.49412 .56078 Mdot
.6 .06667 Mdot
.32941 .18824 Mdot
.23137 .37255 Mdot
.24706 .38039 Mdot
.40784 .28627 Mdot
.49804 .4902 Mdot
.64706 .72941 Mdot
.10588 .30196 Mdot
.7451 .82745 Mdot
.4902 .53725 Mdot
.27843 .40392 Mdot
.39216 .08235 Mdot
.50196 .16078 Mdot
.01176 .10588 Mdot
.59216 .69412 Mdot
.76078 .83529 Mdot
.44314 .58824 Mdot
.2902 .40784 Mdot
.36863 .26667 Mdot
.47843 .3451 Mdot
.45098 .47059 Mdot
.73333 .82353 Mdot
.03137 .16863 Mdot
.49804 .61569 Mdot
.3098 .42745 Mdot
.26667 .37255 Mdot
.42353 .37647 Mdot
.55294 .56863 Mdot
.60784 .68627 Mdot
.64706 .05098 Mdot
.73333 .82353 Mdot
.48235 .57647 Mdot
.26667 .38431 Mdot
.38039 .33333 Mdot
.48235 .39216 Mdot
.4 .48627 Mdot
.03922 .23529 Mdot
.75686 .83529 Mdot
.63137 .7451 Mdot
.2902 .41569 Mdot
.34902 .04706 Mdot
.48627 .22353 Mdot
.41961 .45882 Mdot
.77255 .8549 Mdot
.76863 .84706 Mdot
.53333 .65882 Mdot
.31765 .43137 Mdot
.29412 .36078 Mdot
.43529 .14118 Mdot
.54902 .57255 Mdot
.52157 .60784 Mdot
.03922 .20784 Mdot
.71373 .82745 Mdot
.39608 .49412 Mdot
.27843 .39216 Mdot
.38824 .3098 Mdot
.47843 .46275 Mdot
.48627 .56863 Mdot
.59216 .12157 Mdot
.7451 .83137 Mdot
.51765 .62353 Mdot
.2902 .41176 Mdot
.43529 .21569 Mdot
.52157 .47451 Mdot
.05882 .21176 Mdot
.76863 .84706 Mdot
.77255 .8549 Mdot
.23137 .37255 Mdot
.30196 .41961 Mdot
.36078 .1451 Mdot
.47059 .40392 Mdot
.57647 .62353 Mdot
.59608 .67059 Mdot
.78431 .8549 Mdot
.72549 .81961 Mdot
.43137 .53725 Mdot
.27843 .39608 Mdot
.36078 .18431 Mdot
.52941 .53333 Mdot
.76471 .84314 Mdot
.49804 .72157 Mdot
.74902 .83922 Mdot
.68235 .78431 Mdot
.2902 .41569 Mdot
.40392 .25882 Mdot
.50196 .43529 Mdot
.49804 .58431 Mdot
.7451 .83137 Mdot
.77647 .8549 Mdot
.41961 .56078 Mdot
.3098 .43137 Mdot
.38039 .15294 Mdot
.47059 .40784 Mdot
.46275 .53333 Mdot
.62353 .69412 Mdot
.78431 .8549 Mdot
.7451 .83137 Mdot
.44706 .55686 Mdot
.25098 .37255 Mdot
.40784 .36471 Mdot
.50588 .50588 Mdot
.5098 .61176 Mdot
.50196 .72157 Mdot
.76471 .8549 Mdot
.56078 .65882 Mdot
.2902 .40784 Mdot
.38824 .13333 Mdot
.47843 .33333 Mdot
.52941 .61569 Mdot
.56863 .78824 Mdot
.78039 .85882 Mdot
.38824 .5451 Mdot
.32549 .45882 Mdot
.36471 .13725 Mdot
.55294 .20784 Mdot
.00784 .12941 Mdot
.91373 .98039 Mdot
.80392 .87451 Mdot
.74902 .83922 Mdot
.48235 .58824 Mdot
.27843 .39216 Mdot
.4549 .35686 Mdot
.55294 .56863 Mdot
.76471 .84706 Mdot
.87451 .91765 Mdot
.76471 .85098 Mdot
.69804 .79608 Mdot
.2902 .41176 Mdot
.37647 .32941 Mdot
.50588 .4549 Mdot
.67843 .76471 Mdot
.82353 .91373 Mdot
.79216 .86275 Mdot
.52157 .64706 Mdot
.36078 .47451 Mdot
.3451 .1098 Mdot
.55686 .29412 Mdot
0 .14902 Mdot
.98039 1 Mdot
.81569 .88235 Mdot
.67843 .77255 Mdot
.60784 .68235 Mdot
.29412 .40392 Mdot
.50196 .29804 Mdot
.52157 .56078 Mdot
.92549 .94902 Mdot
.85882 .91373 Mdot
.76078 .83922 Mdot
.65098 .76471 Mdot
.33333 .44314 Mdot
.4 .32549 Mdot
.54118 .50196 Mdot
.83529 .87451 Mdot
.75294 .92157 Mdot
.74118 .84706 Mdot
.17255 .35686 Mdot
.38039 .4902 Mdot
.3451 .18431 Mdot
.53725 .19216 Mdot
.00784 .23529 Mdot
.92941 .9451 Mdot
.76078 .84706 Mdot
.71373 .81569 Mdot
.52549 .62353 Mdot
.32941 .42353 Mdot
.42745 .31373 Mdot
.63137 .64706 Mdot
.98039 .99608 Mdot
.79216 .87451 Mdot
.7451 .82745 Mdot
.37647 .4902 Mdot
.36471 .46667 Mdot
.38824 .11373 Mdot
.59216 .57255 Mdot
.84314 .88235 Mdot
.74118 .89412 Mdot
.74902 .83137 Mdot
.28627 .43137 Mdot
.35294 .46275 Mdot
.34118 .23529 Mdot
.50196 .22353 Mdot
.00784 .30588 Mdot
.39216 .52157 Mdot
.77255 .85098 Mdot
.71765 .82353 Mdot
.41961 .53333 Mdot
.34902 .44706 Mdot
.44706 .06275 Mdot
.76078 .76863 Mdot
.68235 .76863 Mdot
.79216 .86667 Mdot
.64706 .83137 Mdot
.42745 .58039 Mdot
.32157 .43922 Mdot
.42745 .18039 Mdot
.76078 .64314 Mdot
.75294 .80784 Mdot
.61176 .81176 Mdot
.32157 .64706 Mdot
.12157 .33333 Mdot
.40392 .50588 Mdot
.33725 .23529 Mdot
.49804 .15294 Mdot
.02353 .23922 Mdot
.74118 .84706 Mdot
.19608 .62353 Mdot
.07843 .18039 Mdot
.2 .34902 Mdot
.51765 .60784 Mdot
.43137 .22745 Mdot
.70196 .69804 Mdot
.78039 .8549 Mdot
.32941 .74902 Mdot
.43137 .17255 Mdot
.13725 .09804 Mdot
.30588 .42745 Mdot
.39608 .13333 Mdot
.71373 .63922 Mdot
.76863 .85098 Mdot
.28627 .71765 Mdot
.14902 .43137 Mdot
.55686 .04706 Mdot
.03137 .14902 Mdot
.32549 .12549 Mdot
.62745 .23922 Mdot
.02353 .15686 Mdot
.31373 .7098 Mdot
.06667 .66667 Mdot
.63922 .03137 Mdot
.38824 .03922 Mdot
.50588 .60392 Mdot
.55686 .37647 Mdot
.60392 .62745 Mdot
.23137 .56471 Mdot
.35686 .85882 Mdot
.68627 .03137 Mdot
.5098 .02745 Mdot
.19608 .34118 Mdot
.41569 .25882 Mdot
.62353 .60392 Mdot
.36078 .59608 Mdot
.4 .83529 Mdot
.65882 .06667 Mdot
.56471 .32157 Mdot
.39608 .03922 Mdot
.36471 .04706 Mdot
.56078 .53333 Mdot
.33725 .54118 Mdot
.04706 .6 Mdot
.41569 .15686 Mdot
.72941 .53725 Mdot
.44314 0 Mdot
.34118 .37647 Mdot
.51765 .47451 Mdot
.50588 .62745 Mdot
.02353 .4902 Mdot
.62353 .18431 Mdot
.6 .41961 Mdot
.70588 .57647 Mdot
.06667 .21961 Mdot
.47451 .27843 Mdot
.6 .64706 Mdot
.01569 .45098 Mdot
.68627 .21569 Mdot
.76863 .06275 Mdot
.60784 .57255 Mdot
.48235 .01176 Mdot
.33333 .20392 Mdot
.61569 .58431 Mdot
.01176 .28235 Mdot
.69804 .27451 Mdot
.4549 .31765 Mdot
.63137 .58039 Mdot
.43529 .13725 Mdot
.44314 .22353 Mdot
.50588 .47451 Mdot
.01176 .21176 Mdot
.56863 .28235 Mdot
.03137 .57255 Mdot
.75686 .6 Mdot
.43922 0 Mdot
.32549 .69412 Mdot
.4549 .4 Mdot
.02745 .21961 Mdot
.43529 .22745 Mdot
.02745 .54902 Mdot
.59216 .34902 Mdot
.4 .31373 Mdot
.52941 .06667 Mdot
.40392 .37647 Mdot
.00784 .2 Mdot
.47059 .18824 Mdot
.03529 .5098 Mdot
.75686 .05882 Mdot
.51373 .21176 Mdot
.70196 .59608 Mdot
.46667 .43137 Mdot
.00392 .16863 Mdot
.00784 .11373 Mdot
.00784 .44314 Mdot
.76471 .11765 Mdot
.65098 .10588 Mdot
.5451 .42745 Mdot
.57255 .4 Mdot
.00784 .18039 Mdot
.32157 .17647 Mdot
0 .4 Mdot
.00392 .46667 Mdot
.74902 .04314 Mdot
.67843 .47451 Mdot
.52549 .31373 Mdot
.00392 .14118 Mdot
.21961 .03922 Mdot
0 .37255 Mdot
.03529 .66275 Mdot
.77647 .05882 Mdot
.52549 .00392 Mdot
.04706 .55686 Mdot
.09804 .17647 Mdot
.32941 .13333 Mdot
0 .33725 Mdot
.33725 .88627 Mdot
.78039 .05098 Mdot
.53333 .00392 Mdot
.59216 .1451 Mdot
.39216 .40392 Mdot
.42745 .10196 Mdot
0 .28627 Mdot
.5451 .87451 Mdot
.7451 .06667 Mdot
.6 .01961 Mdot
.58824 .42353 Mdot
.43529 .38431 Mdot
.44314 .10196 Mdot
0 .19216 Mdot
.24706 .64706 Mdot
.47059 .14118 Mdot
.50588 .06275 Mdot
.56078 .02745 Mdot
.43529 .38824 Mdot
.28235 .12157 Mdot
.01961 .23137 Mdot
.03137 .5451 Mdot
.0902 .2549 Mdot
.2 .12549 Mdot
.58039 .01961 Mdot
.43137 .38431 Mdot
.11373 .11765 Mdot
.00392 .22745 Mdot
.00784 .48235 Mdot
.00392 .27843 Mdot
.02353 .17647 Mdot
.55294 .03137 Mdot
.43922 .36471 Mdot
.07451 .09412 Mdot
.0549 .41569 Mdot
0 .41569 Mdot
.01176 .31373 Mdot
.00784 .19608 Mdot
.35294 .03137 Mdot
.41176 .35294 Mdot
.0549 .09412 Mdot
.01961 .25882 Mdot
.00392 .37647 Mdot
.01961 .31765 Mdot
.05882 .24706 Mdot
.05882 .09412 Mdot
.41176 .34902 Mdot
.01176 .10588 Mdot
.01176 .23529 Mdot
.00392 .36078 Mdot
.16863 .38431 Mdot
.35294 .4902 Mdot
.00392 .13333 Mdot
.41961 .34118 Mdot
.00392 .11765 Mdot
0 .22353 Mdot
.00392 .34118 Mdot
.40784 .52157 Mdot
.61961 .7098 Mdot
.03529 .18824 Mdot
.47843 .3451 Mdot
.01176 .13725 Mdot
.01176 .26275 Mdot
.02745 .3451 Mdot
.51373 .59608 Mdot
.70588 .77255 Mdot
.21961 .35294 Mdot
.49804 .34118 Mdot
.00784 .15294 Mdot
.00784 .23137 Mdot
.18039 .41176 Mdot
.60784 .67059 Mdot
.72157 .78431 Mdot
.25882 .38039 Mdot
.35294 .23529 Mdot
.00392 .14902 Mdot
.01569 .21176 Mdot
.43922 .55294 Mdot
.85098 .87843 Mdot
.46275 .49412 Mdot
.23529 .36471 Mdot
.03137 .07451 Mdot
.00392 .16078 Mdot
.00392 .14118 Mdot
.51765 .59608 Mdot
.58824 .56471 Mdot
.47059 .41961 Mdot
.23922 .34902 Mdot
.00784 .07843 Mdot
.00392 .16078 Mdot
.07843 .21961 Mdot
.74118 .78824 Mdot
.52157 .45098 Mdot
.46275 .39608 Mdot
.2549 .34118 Mdot
.24706 .03529 Mdot
.00392 .14902 Mdot
.43137 .52157 Mdot
.56078 .54902 Mdot
.4549 .41176 Mdot
.40392 .38039 Mdot
.2549 .32549 Mdot
.00784 .09804 Mdot
0 .18824 Mdot
.53725 .60784 Mdot
.48235 .43922 Mdot
.37647 .36471 Mdot
.38431 .39608 Mdot
.20392 .30588 Mdot
.00392 .13333 Mdot
.10588 .28235 Mdot
.56863 .60784 Mdot
.40392 .39216 Mdot
.37647 .37255 Mdot
.36471 .38431 Mdot
.1451 .27843 Mdot
.00392 .09412 Mdot
.4902 .56078 Mdot
.41176 .36078 Mdot
.40392 .38824 Mdot
.36471 .36078 Mdot
.35294 .36863 Mdot
.22745 .1451 Mdot
.00392 .12941 Mdot
.69412 .76078 Mdot
.42353 .40392 Mdot
.37647 .37255 Mdot
.39608 .39608 Mdot
.33725 .35686 Mdot
.01961 .07843 Mdot
.03922 .17647 Mdot
.41569 .39608 Mdot
.43137 .41569 Mdot
.38824 .36863 Mdot
.37255 .38039 Mdot
.28235 .33725 Mdot
.00392 .12549 Mdot
.4902 .56863 Mdot
.48235 .46275 Mdot
.43137 .43922 Mdot
.38039 .37255 Mdot
.36078 .37647 Mdot
.19608 .27843 Mdot
0 .11765 Mdot
.63922 .68627 Mdot
.50588 .52157 Mdot
.40784 .41961 Mdot
.3451 .35686 Mdot
.39216 .41569 Mdot
.30196 .33725 Mdot
.02353 .15294 Mdot
.52549 .52549 Mdot
.55686 .55686 Mdot
.35686 .39216 Mdot
.34902 .36078 Mdot
.3451 .36863 Mdot
.23529 .14118 Mdot
.60784 .65098 Mdot
.58039 .57255 Mdot
.43529 .45098 Mdot
.34902 .40784 Mdot
.35686 .41569 Mdot
.28235 .34902 Mdot
0 .16471 Mdot
.3451 .35686 Mdot
.44314 .42745 Mdot
.45098 .52157 Mdot
.24314 .34118 Mdot
.34902 .37255 Mdot
.34902 .41961 Mdot
.12941 .25098 Mdot
.42745 .39608 Mdot
.43137 .41569 Mdot
.1098 .23137 Mdot
.19216 .27059 Mdot
.40784 .44706 Mdot
.35686 .38431 Mdot
.5098 .55686 Mdot
.43529 .38431 Mdot
.42353 .47059 Mdot
.23137 .33333 Mdot
.12549 .22353 Mdot
.26667 .34118 Mdot
.03529 .26667 Mdot
.43922 .40392 Mdot
.46667 .40392 Mdot
.32549 .43137 Mdot
.3451 .39216 Mdot
.36471 .41176 Mdot
.38431 .44314 Mdot
.44706 .45098 Mdot
.43922 .41176 Mdot
.36863 .39608 Mdot
.56078 .51373 Mdot
.4902 .43922 Mdot
.34118 .37647 Mdot
.18824 .6549 Mdot
.44706 .40392 Mdot
.4549 .4 Mdot
.61961 .7098 Mdot
.52941 .41961 Mdot
.38824 .39608 Mdot
.43529 .50196 Mdot
.37647 .38824 Mdot
.43137 .41176 Mdot
.40784 .40392 Mdot
.54118 .5098 Mdot
.42353 .38039 Mdot
.36078 .42353 Mdot
.43922 .35686 Mdot
.4549 .40784 Mdot
.42353 .39216 Mdot
.45882 .44314 Mdot
.38039 .37255 Mdot
.43922 .42353 Mdot
.46275 .54902 Mdot
.30196 .30588 Mdot
.44314 .40392 Mdot
.73333 .78431 Mdot
.27843 .3451 Mdot
.37255 .43137 Mdot
.52549 .59608 Mdot
.35294 .3098 Mdot
.43529 .41569 Mdot
.45098 .4 Mdot
.42353 .4549 Mdot
.42353 .48235 Mdot
.54902 .62353 Mdot
.40784 .38431 Mdot
.4 .34118 Mdot
.42353 .36863 Mdot
.47059 .45882 Mdot
.44314 .44706 Mdot
.50196 .52157 Mdot
.52941 .59608 Mdot
.31765 .35686 Mdot
.46275 .43922 Mdot
.42353 .38039 Mdot
.59608 .63137 Mdot
.45882 .48627 Mdot
.67059 .71373 Mdot
.18431 .23922 Mdot
.43137 .41569 Mdot
.48235 .46275 Mdot
.57255 .6 Mdot
.49412 .53725 Mdot
.75294 .78824 Mdot
.43922 .37255 Mdot
.41569 .40784 Mdot
.45882 .44706 Mdot
.59608 .53725 Mdot
.67843 .64706 Mdot
.87059 .8902 Mdot
.46667 .33725 Mdot
.4 .41569 Mdot
.46667 .45882 Mdot
.54118 .45882 Mdot
.65098 .59608 Mdot
.90196 .92157 Mdot
.4902 .35686 Mdot
.38039 .39608 Mdot
.47059 .46275 Mdot
.57647 .56078 Mdot
.91765 .8902 Mdot
.81961 .85882 Mdot
.36471 .3451 Mdot
.35686 .38824 Mdot
.45098 .4549 Mdot
.60784 .63137 Mdot
.99608 .99608 Mdot
.78039 .81569 Mdot
.24706 .34902 Mdot
.43922 .4902 Mdot
.4902 .52941 Mdot
.87059 .88235 Mdot
.98431 .99216 Mdot
.69804 .73725 Mdot
.37255 .43137 Mdot
.42745 .47843 Mdot
.57647 .61176 Mdot
.99216 .99216 Mdot
.83529 .87451 Mdot
.42353 .35686 Mdot
.36471 .42745 Mdot
.50588 .57647 Mdot
.99608 .99608 Mdot
.87843 .89412 Mdot
.75294 .76863 Mdot
.40392 .47451 Mdot
.52157 .59608 Mdot
.99216 1 Mdot
.95294 .97255 Mdot
.77255 .82353 Mdot
.36863 .45098 Mdot
.51765 .57647 Mdot
.86667 .92157 Mdot
.97255 .97647 Mdot
.79608 .83529 Mdot
.35294 .43137 Mdot
.52941 .60784 Mdot
.85882 .90196 Mdot
.90588 .92157 Mdot
.8 .83137 Mdot
.4 .46275 Mdot
.6 .67059 Mdot
.98039 .98824 Mdot
.89412 .93333 Mdot
.60784 .52549 Mdot
.47843 .53725 Mdot
.84314 .89804 Mdot
.93333 .96078 Mdot
.81569 .85098 Mdot
.42353 .48235 Mdot
.68627 .7451 Mdot
.94118 .96863 Mdot
.8549 .8902 Mdot
.41961 .38824 Mdot
.65882 .72549 Mdot
.91373 .93333 Mdot
.89804 .90196 Mdot
.46667 .4902 Mdot
.77647 .83529 Mdot
.89804 .91765 Mdot
.34118 .77255 Mdot
.61176 .6902 Mdot
.9098 .94118 Mdot
.36078 .78039 Mdot
.67059 .69804 Mdot
.74118 .65882 Mdot
.60392 .49804 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool01oooO`3oooooooooooooooooogl0ooooooooO`000_oo
ool3oomo00;ooooo0_ooO`000oooooooogl0ooooo`02ooooo`Soogl000Cooooooomo0?ooO`3ooooo
1OooO`000oooooooogl0oomo0005oomo0003ooooooooO`3oogl000;oogl000?ooooooomo0?ooO`00
1?ooO`000oooooooogl0ooooo`02oomo0003ooooooooO`3oogl000;oogl000?ooooooomo0?ooool0
1?ooO`000oooooooogl0oomo0008oomo0003ooooooooO`3oogl000ooogl00oooool00oooO`3ooooo
ooooo`16ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool00onP8?3ooooo
ooooo`03ooooo`03oj0Pl?ooooooX23`00Gooooo0_nP8?02ooooo`?oX23`00Cooooooj0Pl?oooooo
oooo0_nP8?001_ooooooX23`oooooonP8?3ooooooj0Pl0;ooooo0_nP8?05ooooo`03oj0Pl?oooooo
oooo03gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool00_ooool01?oo
O`3oooooooooooooO`04ooooo`04oomo0?ooooooooooooooo`;oogl000Gooooooomo0?ooooooogl0
ooooo`03oomo00;ooooo0_ooO`03ooooo`Coogl00_ooool2oomo0003ooooooooO`3ooooo00;ooooo
00?oogl0ooooooooO`000_ooool00oooO`3ooooooomo0002ooooo`;oogl000?ooooooomo0?ooO`00
1?ooO`02ooooo`?oogl00_ooool2oomo0003ooooooooO`3oogl000Koogl000?ooooooomo0?ooO`00
4oooO`001Oooooooogl0oomo0?ooooooogl000;ooooo00Googl0oooooooooooooooooomo000noooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0A_ooool00onP8?3oooooooooo`04oooo
o`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool00oooool2oj0Pl0Cooooo00?oX23`oooo
ooooool00_ooool01?nP8?3ooooooj0Pl?nP8?03ooooo`04oj0Pl?ooooooooooooooo`;oX23`00?o
oooooj0Pl?ooool0??ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`03
ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool03oooool00oooO`3oooooooooo`03
ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooO`000_ooO`000oooooooogl0oomo0008
ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool00_ooO`04ooooo`03oomo0?oooooo
oooo00?ooooo0_ooO`04ooooo`?oogl000?ooooooomo0?ooO`000_ooO`000oooooooogl0oomo0002
ooooo`06oomo0?ooooooogl0ooooooooO`3ooooo0oooO`02ooooo`03oomo0?oooooooooo00;ooooo
00Koogl0ooooooooO`3oogl0ooooooooO`0gooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0B_ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo01cooooo0onP8?0loooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00;ooooo00?oogl0oooooooo
ool02?ooool01?ooO`3oooooooooooooO`07ooooo`03oomo0?oooooooooo00Wooooo00?oogl0oooo
ooooool00_ooool01?ooO`3oooooooooooooool3oomo00Cooooo0_ooO`06ooooo`03oomo0?oooooo
oooo00Oooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`02ooooo`;oogl00_ooool3
oomo0005ooooooooO`3oogl0oomo0?ooool00_ooO`001Oooooooogl0ooooooooO`3ooooo00Ooogl0
00Gooooooomo0?ooO`3oogl0ooooo`02oomo00;ooooo0_ooO`001Oooooooogl0oomo0?ooooooogl0
03Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03oj0Pl?oooooooooo
00Sooooo00?oX23`ooooooooool01?ooool01_nP8?3oooooooooooooooooX23`ooooo`;oX23`0_oo
ool01OnP8?3oooooooooooooooooX23`00Gooooo00?oX23`ooooooooool00oooool2oj0Pl0;ooooo
00CoX23`oooooonP8?3ooooo0_nP8?0booooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo033ooooo00?oogl0ooooooooool07_ooool01OooO`3oooooooooooooooooogl000Go
oooo00?oogl0ooooooooO`001Oooool00oooO`3ooooooomo0002ooooo`;oogl000Oooooooomo0?oo
ooooogl0ooooooooO`3ooooo00;oogl01?ooool00oooO`3oooooooooo`0gooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0>oooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooo
oooo00cooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooo
oooo00cooooo00?oX23`ooooooooool00onP8?001?ooooooX23`oooooonP8?0`ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Gooooo00?oogl0ooooooooool01oooool0
0oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo01Oooooo00?oogl0ooooooooool00_ooool0
1OooO`3oooooooooooooooooogl000?ooooo00Googl0ooooooooO`3ooooooomo0009ooooo`05oomo
0?ooooooogl0ooooooooO`001?ooool01?ooO`3ooooooomo0?ooool2oomo00?ooooo0_ooO`001ooo
ooooogl0oomo0?ooooooogl0ooooooooO`000_ooool00oooO`3ooooooomo0003oomo0003oooooooo
O`3oogl000;oogl000Oooooooomo0?ooooooogl0ooooooooO`3ooooo00Coogl00oooool00oooO`3o
ooooooooo`0Zooooo`03o`000?oooooooooo00oooooo00?oX23`ooooooooool0:Oooool00onP8?3o
ooooooooo`0@ooooo`03oj0Pl?oooooooooo00Oooooo00GoX23`oooooooooooooooooj0Pl008oooo
o`05oj0Pl?oooooooooooooooonP8?000_ooool00onP8?3ooooooj0Pl003ooooo`03oj0Pl?oooooo
oooo00;ooooo00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`04ooooo`;oX23`00?ooooo
oj0Pl?nP8?000_nP8?0cooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
02Sooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo
00kooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo
00Cooooo00Googl0oooooooooooooooooomo0009ooooo`05oomo0?ooooooogl0ooooooooO`000_oo
ool3oomo0004ooooooooO`3ooooooomo00;ooooo0oooO`03ooooo`;oogl00oooool00oooO`3ooooo
ooooo`0/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00onP8?3ooooo
ooooo`0Looooo`;oX23`6oooool00onP8?3ooooooj0Pl002ooooo`04oj0Pl?oooooooooooj0Pl0oo
oooo1?nP8?0eooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo013ooooo
00?oogl0ooooooooool02oooool01OooO`3oooooooooooooooooogl001Gooooo00?oogl0oooooooo
ool05Oooool01OooO`3oooooooooooooooooogl000;ooooo00?oogl0ooooooooool01oooool00ooo
O`3oooooooooo`04ooooo`Coogl01_ooool00oooO`3ooooooomo0002ooooo`?oogl000?ooooooomo
0?ooool00_ooool2oomo00;ooooo00?oogl0ooooooooO`00:oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03[ooooo00?oX23`ooooooooool04Oooool00onP8?3oooooooooo`07oooo
o`05oj0Pl?oooooooooooooooonP8?001Oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooo
oooo00oooooo00?oX23`oooooonP8?001?ooool00onP8?3ooooooj0Pl00Zooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo01Sooooo00?oogl0ooooooooool03?ooool00ooo
O`3oooooooooo`0Cooooo`03oomo0?ooooooogl000Cooooo0_ooO`07ooooo`03oomo0?oooooooooo
00Kooooo00?oogl0ooooooooool03Oooool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oooooo
ogl000;ooooo00Coogl0oooooooooooooooo0_ooO`002Oooooooogl0oomo0?ooO`3ooooooomo0?oo
ooooogl0ooooo`06oomo0003ooooooooO`3oogl000;ooooo0_ooO`0Sooooo`03o`000?oooooooooo
00oooooo00?oX23`ooooooooool06?ooool00onP8?3oooooooooo`0Oooooo`05oj0Pl?ooooooX23`
oooooonP8?002Oooool00onP8?3oooooooooo`0Fooooo`03oj0Pl?ooooooX23`00cooooo0_nP8?02
ooooo`06oj0Pl?oooooooooooooooonP8?3ooooo0_nP8?001?ooooooX23`oj0Pl?nP8?09ooooo`03
oj0Pl?oooooooooo02Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
2oooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo02Oooooo00?oogl0ooooooooool0
1oooool00oooO`3oooooooooo`0Oooooo`?oogl01?ooool00oooO`3oooooooooo`03ooooo`;oogl0
0_ooool01_ooO`3oooooooooooooooooogl0ooooo`?oogl00oooool01?ooO`3oooooooooooooO`04
ooooo`05oomo0?ooooooooooooooooooO`008Oooool00ol0003oooooooooo`0?ooooo`;oX23`Booo
ool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00_ooooo00KoX23`ooooooooooooX23`
oooooonP8?09ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooooonP8?001_ooool00onP8?3o
ooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00gooooo
00Coogl0ooooooooooooogl03Oooool00oooO`3oooooooooo`0Iooooo`03oomo0?oooooooooo00Oo
oooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`03ooooo`03oomo0?ooooooogl000;o
oooo0_ooO`03ooooo`03oomo0?ooooooogl000;ooooo0_ooO`02ooooo`;oogl00_ooool00oooO`3o
ooooooooo`02oomo00;ooooo0_ooO`02ooooo`03oomo0?oooooooooo00Cooooo00Googl0oooooooo
oooooooooomo0002ooooo`Coogl000Cooooooomo0?ooO`3oogl00_ooool00oooO`3oooooooooo`03
ooooo`03oomo0?oooooooooo01kooooo00?o0000ooooooooool03oooool00onP8?3oooooooooo`05
ooooo`03oj0Pl?oooooooooo043ooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`08
ooooo`04oj0Pl?ooooooX23`oj0Pl0_ooooo00?oX23`ooooooooool02Oooool2oj0Pl003oooooonP
8?3ooooo00gooooo00GoX23`oooooonP8?3ooooooj0Pl003ooooo`03oj0Pl?oooooooooo027ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0>oooool00oooO`3ooooooooo
o`05ooooo`03oomo0?oooooooooo00;ooooo00Coogl0ooooooooooooogl02Oooool00oooO`3ooooo
oomo000>ooooo`;oogl00_ooool00oooO`3oooooooooo`08ooooo`09oomo0?ooooooogl0oooooooo
O`3ooooooomo0?ooooooogl000Oooooo00Googl0oooooooooooooooooomo000Wooooo`03o`000?oo
oooooooo00oooooo00?oX23`ooooooooool0=Oooool00onP8?3ooooooj0Pl009ooooo`03oj0Pl?oo
oooooooo01;ooooo00?oX23`ooooooooool00_ooool2oj0Pl0;ooooo00GoX23`oooooooooooooooo
oj0Pl005ooooo`03oj0Pl?oooooooooo00Oooooo00GoX23`oooooooooooooooooj0Pl00;ooooo`03
oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool07oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`0booooo`03oomo0?oooooooooo01;ooooo00?oogl0ooooooooool0
2Oooool00oooO`3oooooooooo`0;ooooo`04oomo0?ooooooooooooooo`;oogl000?ooooooomo0?oo
ool01Oooool01?ooO`3oooooooooooooool2oomo00;ooooo00?oogl0ooooooooool01?ooool00ooo
O`3oooooooooo`06ooooo`03oomo0?oooooooooo00Cooooo0_ooO`000oooooooogl0ooooo`0Noooo
o`03o`000?oooooooooo00oooooo00?oX23`ooooooooool0F?ooool01?nP8?3ooooooj0Pl?nP8?0>
ooooo`03oj0Pl?oooooooooo017ooooo00?oX23`ooooooooool0<?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`0Dooooo`03oomo0?oooooooooo01;ooooo00?oogl0oooo
ooooool06_ooool01?ooO`3oooooooooooooO`04ooooo`05oomo0?ooooooooooooooooooO`001Ooo
ool3oomo00?ooooo00?oogl0ooooooooO`003?ooool00oooO`3oooooooooo`02ooooo`03oomo0?oo
oooooooo00Kooooo00?oogl0ooooooooool01?ooool01OooO`3oooooooooooooooooogl000?ooooo
00?oogl0ooooooooO`000_ooool2oomo0003ooooooooO`3oogl001gooooo00?o0000ooooooooool0
3oooool2oj0Pl004oooooonP8?3ooooooj0Pl4[ooooo00?oX23`ooooooooool02oooool01_nP8?3o
oooooooooonP8?3ooooooj0Pl0cooooo00?oX23`oooooonP8?002oooool00onP8?3oooooooooo`0;
ooooo`03oj0Pl?oooooooooo02Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool06_ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00?ooooo00?oogl0oooo
ooooool03Oooool01OooO`3oooooooooooooooooogl0017ooooo00?oogl0ooooooooool02_ooool0
0oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo01[ooooo00?oogl0ooooooooool01oooool3
oomo0003ooooooooO`3ooooo00;oogl00oooool00oooO`3oooooooooo`0Iooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooX23`0_ooool00onP8?3oooooooooo`0mooooo`03oj0Pl?oo
oooooooo01kooooo00?oX23`ooooooooool0:_ooool00onP8?3oooooooooo`0Mooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Oooooo0_ooO`000oooooooogl0ooooo`0B
ooooo`03oomo0?oooooooooo02Wooooo00Coogl0ooooooooooooogl01?ooool00oooO`3ooooooooo
o`07ooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool00oooool00oooO`3ooooooooo
o`03ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooO`001Oooool00oooO`3ooooooooo
o`02oomo0004ooooooooO`3oogl0oomo00;ooooo00?oogl0ooooooooool01?ooool00oooO`3ooooo
ooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oj0Pl?ooool00_nP8?0fooooo`05oj0P
l?oooooooooooooooonP8?005?ooool00onP8?3oooooooooo`10ooooo`03oj0Pl?oooooooooo01[o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Aoooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooO`000_ooool2oomo00;ooooo
00?oogl0ooooooooool08_ooool00oooO`3oooooooooo`0Zooooo`03o`000?oooooooooo00oooooo
00?oX23`ooooooooool01oooool01?nP8?3ooooooooooonP8?1]ooooo`03oj0Pl?oooooooooo01Go
oooo00?oX23`ooooooooool07_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`0Gooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool0<?ooool00oooO`3ooooo
ooooo`0jooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool00_ooool00oooO`3ooooo
ooooo`0>ooooo`03o`000?oooooooooo00oooooo00Co0000oj0Pl?ooooooX23`5?ooool00onP8?3o
ooooooooo`0Kooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool03Oooool01?nP8?3o
oooooooooonP8?05ooooo`03oj0Pl?oooooooooo03?ooooo00?oX23`ooooooooool09Oooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`16ooooo`03oomo0?oooooooooo013o
oooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`05ooooo`;oogl00oooool01?ooO`3o
ooooooooooooO`02ooooo`03oomo0?oooooooooo03cooooo00?o0000ooooooooool03oooool00ol0
003ooooooj0Pl01=ooooo`05oj0Pl?oooooooooooooooonP8?001Oooool00onP8?3oooooooooo`0H
ooooo`03oj0Pl?oooooooooo03cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool06?ooool00oooO`3oooooooooo`0Aooooo`03oomo0?oooooooooo027ooooo00?oogl0oooo
ooooool03Oooool00oooO`3oooooooooo`0Yooooo`03oomo0?oooooooooo00[ooooo00Googl0oooo
oooooooooooooomo000Cooooo`03o`000?oooooooooo00oooooo00Go0000oj0Pl?oooooooooooj0P
l00iooooo`03oj0Pl?oooooooooo02;ooooo00?oX23`ooooooooool01oooool00onP8?3ooooooooo
o`0Eooooo`03oj0Pl?oooooooooo02cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
ooooooooool02?ooool01?ooO`3oooooooooooooO`0<ooooo`03oomo0?oooooooooo00Kooooo00?o
ogl0ooooooooool06oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo00Sooooo00?o
ogl0ooooooooO`002_ooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo00kooooo00?o
ogl0ooooooooool06_ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00cooooo00?o
0000ooooooooool03oooool2oj0Pl004oooooonP8?3ooooooj0Pl0kooooo00?oX23`ooooooooool0
8Oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?ooooooX23`00Cooooo00CoX23`oooooooooooo
X23`2oooool00onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo00;ooooo00CoX23`oooooooo
ooooX23`4_ooool00onP8?3ooooooj0Pl00Yooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo00cooooo00?oogl0ooooooooool08oooool01oooO`3oooooooooooooooooogl0
ooooooooO`00=_ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00_ooooo00?oogl0
ooooooooool05oooool00oooO`3oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<?ooool00onP8?3oooooooooo`0>ooooo`04oj0Pl?oooooooooooj0Pl0Sooooo00?o
X23`ooooooooool05Oooool00onP8?3ooooooj0Pl019ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo01Oooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`0D
ooooo`03oomo0?oooooooooo02oooooo00?oogl0ooooooooool03Oooool01?ooO`3ooooooooooooo
O`0Kooooo`03oomo0?oooooooooo00kooooo00?o0000ooooooooool03oooool2oj0Pl003oooooonP
8?3oX23`00Cooooo00?oX23`ooooooooool06?ooool00onP8?3oooooooooo`0>ooooo`03oj0Pl?oo
oooooooo00;ooooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oo
oooooooo00?ooooo00?oX23`ooooooooool02Oooool01onP8?3oooooooooooooooooX23`oooooonP
8?000_ooool00onP8?3oooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo03kooooo00?oogl0ooooooooool0<_ooool00oooO`3oooooooooo`0kooooo`03o`00
0?oooooooooo00oooooo00?oX23`ooooooooool0>?ooool00onP8?3oooooooooo`04ooooo`04oj0P
l?ooooooooooooooo`;oX23`4Oooool01?nP8?3ooooooooooonP8?0Cooooo`03oj0Pl?oooooooooo
047ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?ooooooX23`00Kooooo00?oX23`ooooooooool0<Oooool01OnP8?3o
ooooooooooooooooX23`00cooooo00?oX23`ooooooooool0Hoooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`0Fooooo`03oomo0?oooooooooo03;ooooo00?oogl0oooooooo
ool05oooool00oooO`3ooooooomo000>ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
ool02?ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00?ooooo00?oogl0oooooooo
ool02_ooool00oooO`3ooooooomo0002ooooo`03oomo0?oooooooooo00[ooooo00?o0000oooooooo
ool03oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo01kooooo0_nP8?0Fooooo`03
oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`05ooooo`03
oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool04Oooool00onP8?3oooooooooo`0cooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03Oooooo00Coogl0oooooooooooo
ogl07oooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo02_ooooo00?oogl0oooooooo
ool07oooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooooooo
ool0FOooool00onP8?3oooooooooo`1@ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo06Sooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`09ooooo`03oomo
0?oooooooooo02Oooooo00?oogl0ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`05o`00
0?nP8?3ooooooooooonP8?001_ooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo02Ko
oooo0_nP8?06ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool01?ooool00onP8?3o
ooooooooo`03ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`ooooooooool0=?ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0oooooo`03oomo0?oooooooooo01?ooooo
00?oogl0ooooooooool06Oooool2oomo03[ooooo00Googl0ooooooooooooooooo`00000Aooooo`03
oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool0@Oooool00onP8?3oooooooooo`04ooooo`04
oj0Pl?oooooooooooj0Pl5Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool03oooool00oooO`3oooooooooo`1=ooooo`;oogl0>?ooool00oooO`3oooooooooo`0Eooooo`03
o`000?oooooooooo00oooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`07ooooo`03
oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool08Oooool00onP8?3oooooooooo`0Gooooo`03
oj0Pl?oooooooooo01gooooo00?oX23`ooooooooool0?oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`0_ooooo`03oomo0?oooooooooo02[ooooo00?oogl0ooooooooool0
D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?oX23`ooooooooool0
3_ooool00onP8?3oooooooooo`0^ooooo`03oj0Pl?oooooooooo06Cooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0Boooool00oooO`3oooooooooo`1Kooooo`03oomo0?oo
oooooooo00Gooooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooooooX23`00;ooooo
00?oX23`ooooooooool01oooool00onP8?3oooooooooo`0Vooooo`03oj0Pl?oooooooooo03;ooooo
00?oX23`ooooooooool0@_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0Looooo`03oomo0?oooooooooo02?ooooo00?oogl0ooooooooool06Oooool00oooO`3ooooooooo
o`1;ooooo`03oomo0?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oX23`oooo
o`05ooooo`04oj0Pl?oooooooooooj0Pl0;ooooo00?oX23`ooooooooool00oooool00onP8?3ooooo
ooooo`0Qooooo`07oj0Pl?oooooooooooooooonP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo
00Wooooo00?oX23`oooooonP8?003oooool00onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo
047ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0I?ooool00oooO`3o
ooooooooo`05ooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool0<?ooool00oooO`3o
ooooooooo`02ooooo`03oomo0?oooooooooo00?ooooo00?o0000ooooooooool03oooool00onP8?3o
ooooooooo`03ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool09_ooool00onP8?3o
ooooooooo`0Gooooo`03oj0Pl?oooooooooo05cooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0Boooool00oooO`3oooooooooo`0Cooooo`03oomo0?oooooooooo00;ooooo
00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`0cooooo`03oomo0?ooooooogl000Oooooo
00?o0000ooooooooool03oooool2oj0Pl0Kooooo00?oX23`ooooooooool0>Oooool00onP8?3ooooo
ooooo`0Jooooo`03oj0Pl?oooooooooo053ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?nP8?3ooooo00[ooooo00?o
X23`ooooooooool0:?ooool00onP8?3oooooooooo`1iooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo06Gooooo00?oogl0ooooooooool0BOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Wooooo00?oX23`ooooooooool09?ooool00onP8?3oooooooooo`1>
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo01Sooooo00?oogl0oooo
ooooool02?ooool00oooO`3oooooooooo`1?ooooo`03oomo0?oooooooooo03?ooooo00Coogl0oooo
ooooooooogl00_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooX23`oj0Pl0?ooooo00Co
X23`ooooooooooooX23`1?ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01Wooooo
0_nP8?0Dooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool00_ooool00onP8?3ooooo
ooooo`04ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool07?ooool00onP8?3ooooo
ooooo`0_ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0:_ooooo00?o
ogl0ooooooooO`000oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o
X23`ooooooooool03Oooool00onP8?3oooooooooo`0Wooooo`03oj0Pl?oooooooooo02[ooooo00?o
X23`ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0M
ooooo`03oomo0?oooooooooo03oooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`02
ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`0R
ooooo`03oomo0?oooooooooo00cooooo00?oogl0ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool01?ooool01?nP8?3ooooooj0Pl?nP
8?06ooooo`03oj0Pl?oooooooooo01Oooooo00?oX23`ooooooooool01Oooool00onP8?3ooooooj0P
l00Cooooo`03oj0Pl?ooooooX23`00Kooooo00CoX23`ooooooooooooX23`4_ooool00onP8?3ooooo
ooooo`14ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo02Oooooo00?o
ogl0ooooooooool00_ooool00oooO`3oooooooooo`0Rooooo`03oomo0?oooooooooo05gooooo00?o
0000ooooooooool03oooool00onP8?3oooooooooo`0gooooo`04oj0Pl?oooooooooooj0Pl0oooooo
0_nP8?1Uooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Gooooo00?o
ogl0ooooooooool0BOooool00ol0003oooooooooo`0?ooooo`04o`000?nP8?3oX23`oj0Pl0?ooooo
00CoX23`ooooooooooooX23`2Oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00ko
oooo00?oX23`ooooooooool03?ooool01OnP8?3ooooooj0Pl?ooooooX23`03oooooo00?oX23`oooo
ooooool0<_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Booooo`03
oomo0?oooooooooo02Sooooo00?oogl0ooooooooool03Oooool01OooO`3oooooooooooooooooogl0
00?ooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`0Qooooo`03oomo0?oooooooooo
02gooooo0oooO`000ol0003oooooooooo`0?ooooo`05o`000?oooooooooooooooonP8?006oooool2
oj0Pl0Cooooo00?oX23`ooooooooool0B?ooool00onP8?3oooooooooo`10ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo063ooooo00?oogl0ooooooooool0C_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?oX23`ooooooooool08oooool00onP
8?3oooooooooo`0Xooooo`;oX23`B_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`0Qooooo`03oomo0?oooooooooo03_ooooo00?oogl0ooooooooool03?ooool00oooO`3o
ooooooooo`0[ooooo`03oomo0?oooooooooo00oooooo0oooO`000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Oooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`0Iooooo`05
oj0Pl?oooooooooooooooonP8?000oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo
013ooooo00?oX23`ooooooooool0F_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2/ooooo`06oomo0?oooooooooooomo0?oooooo00004Oooool00ol0003oooooooooo`0=
ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool07Oooool00onP8?3oooooooooo`0B
ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool0G?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`0hooooo`03oomo0?oooooooooo01;ooooo00?oogl0oooo
ooooool00oooool00oooO`3oooooooooo`0Pooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooo
ooooool0<oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooX23`oj0Pl1gooooo00?oX23`
oooooonP8?005oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`
oooooonP8?008_ooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?ooooooX23`037ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0H?ooool00oooO`3oooooooooo`1>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00onP8?3oooooooooo`0_oooo
o`03oj0Pl?ooooooX23`00Oooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`0?oooo
o`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool0DOooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`14ooooo`03oomo0?oooooooooo02Wooooo00?oogl0oooooooo
ool0?_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?oX23`oooooooo
ool00_nP8?0Fooooo`04oj0Pl?oooooooooooj0Pl7Kooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0@oooool00oooO`3oooooooooo`0jooooo`03oomo0?oooooooooo02go
oooo00?oogl0o`000?ooool04?ooool00onP8?3oooooooooo`0Gooooo`03oj0Pl?oooooooooo00Go
oooo0_nP8?000oooooooX23`oj0Pl00;ooooo`04oj0Pl?oooooooooooj0Pl0Kooooo00GoX23`oooo
oooooooooooooj0Pl002ooooo`03oj0Pl?oooooooooo00gooooo00?oX23`oooooonP8?002Oooool0
1OnP8?3oooooooooooooooooX23`01;ooooo00?oX23`ooooooooool01Oooool00onP8?3ooooooooo
o`0cooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03Wooooo00?oogl0
ooooooooool0M?ooool00oooO`3o0000ooooo`0@ooooo`03o`000?ooooooX23`013ooooo00?oX23`
ooooooooool09oooool00onP8?3oooooooooo`03oj0Pl2?ooooo00CoX23`ooooooooooooX23`1_oo
ool00onP8?3oooooooooo`11ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo023ooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooo
oooo00Cooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`0Booooo`03oomo0?oooooo
oooo01kooooo00?oogl0ooooooooool08_ooool00oooO`3oooooooooo`0Eooooo`03oomo0?l0003o
oooo013ooooo00?oX23`ooooooooool04Oooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooo
oooo00Oooooo00?oX23`ooooooooool03Oooool01?nP8?3ooooooooooonP8?04ooooo`03oj0Pl?oo
oooooooo06Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0?oooool0
0oooO`3oooooooooo`1/ooooo`;oogl000?oooooo`000?ooool04?ooool00ol0003oooooooooo`18
ooooo`03oj0Pl?oooooooooo00oooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`02
ooooo`03oj0Pl?oooooooooo01Wooooo00?oX23`ooooooooool0;?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06_ooool00onP8?3oooooooooo`0Fooooo`;oX23`2oooool01?nP8?3ooooooooooonP8?0C
ooooo`03oj0Pl?oooooooooo05Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool07oooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo01Wooooo0_ooO`0Roooo
o`03oomo0?oooooooooo04Kooooo00?o0000ooooooooool03oooool00ol0003oX23`ooooo`0@oooo
o`05oj0Pl?oooooooooooooooonP8?001_ooool00onP8?3oooooooooo`03ooooo`05oj0Pl?oooooo
oooooooooonP8?003?ooool2oj0Pl0Kooooo00?oX23`oooooonP8?001?ooool01?nP8?3ooooooj0P
l?ooool2oj0Pl003oooooonP8?3ooooo00Sooooo00?oX23`ooooooooool07_ooool2oj0Pl0gooooo
00CoX23`ooooooooooooX23`:oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`16ooooo`03oomo0?oooooooooo01[ooooo00?oogl0ooooooooool0Boooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?oX23`ooooooooool05oooool00onP8?3ooooo
oj0Pl004ooooo`03oj0Pl?oooooooooo01gooooo00?oX23`ooooooooool04?ooool00onP8?3ooooo
ooooo`0hooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo023ooooo00?o
ogl0ooooooooool01oooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo01Gooooo00?o
ogl0ooooooooool04oooool00oooO`3oooooooooo`1>ooooo`03oomo0?l0003ooooo013ooooo00Co
0000oooooonP8?3oX23`8?ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00Gooooo
00?oX23`ooooooooool02_ooool01?nP8?3ooooooj0Pl?nP8?02ooooo`03oj0Pl?ooooooX23`00Co
oooo00?oX23`oooooonP8?002Oooool2oj0Pl0Kooooo00?oX23`ooooooooool01?ooool00onP8?3o
ooooooooo`07ooooo`03oj0Pl?oooooooooo03[ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool09oooool00oooO`3oooooooooo`0Pooooo`03oomo0?oooooooooo06Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03oj0Pl?oooooooooo00Wooooo
00?oX23`ooooooooool0?oooool00onP8?3oooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo02Kooooo00?oogl0ooooooooool0<Oooool00oooO`3ooooooooo
o`1<ooooo`03oomo0?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0[ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool01?ooool01?nP8?3ooooooooo
ooooool2oj0Pl1;ooooo00?oX23`ooooooooool0EOooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`0hooooo`03oomo0?oooooooooo01Kooooo00?oogl0ooooooooool0GOoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?oX23`ooooooooool02ooo
ool00onP8?3oooooooooo`02ooooo`03oj0Pl?ooooooX23`01Sooooo00GoX23`oooooooooooooooo
oj0Pl004ooooo`03oj0Pl?oooooooooo00;ooooo00GoX23`oooooooooooooooooj0Pl01Mooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03Cooooo00?oogl0ooooooooool0
?Oooool00oooO`3oooooooooo`0eooooo`03oomo0?oooooooooo00;ooooo00?o0000ooooooooool0
3oooool00onP8?3oooooooooo`0`ooooo`04oj0Pl?oooooooooooj0Pl13ooooo00GoX23`oooooooo
oooooooooj0Pl008ooooo`03oj0Pl?oooooooooo00kooooo00?oX23`ooooooooool0C?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1;ooooo`03oomo0?oooooooooo01Go
oooo00?oogl0ooooooooool07oooool00oooO`3oooooooooo`0Yooooo`03o`000?oooooooooo00oo
oooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0Jooooo`;oX23`2?ooool01onP8?3o
oooooj0Pl?ooooooX23`oooooonP8?003_ooool00onP8?3oooooooooo`04ooooo`04oj0Pl?oooooo
oooooj0Pl0Wooooo0_nP8?02ooooo`03oj0Pl?oooooooooo02Cooooo00?oX23`ooooooooool0<Ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0dooooo`03oomo0?oooooo
oooo00_ooooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`0Fooooo`03oomo0?oooooo
oooo00cooooo00?oogl0ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo027ooooo00?oX23`ooooooooool00_ooool01_nP8?3ooooooj0Pl?nP8?3ooooooj0Pl0Cooooo
00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00oooooo
00?oX23`ooooooooool02oooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo03cooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0:?ooool00oooO`3ooooooooo
o`26ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00onP8?3ooooooooo
o`04ooooo`;oX23`1Oooool00onP8?3oooooooooo`09ooooo`04oj0Pl?ooooooooooooooo`?oX23`
1?ooool00onP8?3oooooooooo`03ooooo`05oj0Pl?ooooooX23`oj0Pl?ooool00_nP8?000ooooooo
X23`ooooo`04ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool0COooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0hooooo`03oomo0?oooooooooo00kooooo
00?oogl0ooooooooool0IOooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo02_ooooo
00?oX23`ooooooooool00_ooool00onP8?3ooooooj0Pl009ooooo`03oj0Pl?ooooooX23`00Sooooo
00?oX23`ooooooooool0Ioooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0cooooo`03oomo0?oooooooooo037ooooo00?oogl0ooooooooool05?ooool00oooO`3ooooooooo
o`0`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00onP8?3ooooooooo
o`0Gooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00oooool00onP8?3ooooooooo
o`1Rooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03?ooooo00Coogl0
ooooooooooooogl02_ooool00oooO`3ooooooomo000Eooooo`03oomo0?oooooooooo023ooooo00?o
ogl0ooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo02Kooooo00Co
X23`oooooooooooooooo0_nP8?000oooooooX23`ooooo`0<ooooo`;oX23`00Oooooooj0Pl?oooooo
oooooj0Pl?ooooooX23`00Gooooo0_nP8?000oooooooX23`ooooo`1Sooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo037ooooo0_ooO`08ooooo`04oomo0?oooooooooooomo
00oooooo00?oogl0ooooooooool0H?ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo
02[ooooo00GoX23`oooooooooooooooooj0Pl00;ooooo`05oj0Pl?oooooooooooooooonP8?001ooo
ool00onP8?3ooooooj0Pl002oj0Pl0Wooooo00?oX23`ooooooooool02_ooool01onP8?3ooooooooo
ooooooooX23`oooooonP8?00BOooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`0jooooo`04oomo0?ooooooooooooooo`;oogl01Oooool01?ooO`3oooooooooooooO`06oooo
o`03oomo0?oooooooooo03_ooooo00?oogl0ooooooooool08?ooool00oooO`3o0000ooooo`0@oooo
o`03o`000?oooooooooo01_ooooo00?oX23`ooooooooool02oooool01?nP8?3ooooooj0Pl?ooool2
oj0Pl0kooooo0_nP8?000oooooooX23`ooooo`02oj0Pl0;ooooo00?oX23`ooooooooool00onP8?00
0oooooooX23`ooooo`04ooooo`;oX23`G?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`0hooooo`03oomo0?ooooooogl000gooooo00?oogl0ooooooooool0I_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00OoX23`oooooooooooooooooj0Pl?oo
ooooX23`00cooooo00GoX23`oooooooooooooooooj0Pl004ooooo`03oj0Pl?ooooooX23`00;ooooo
00?oX23`ooooooooool05_ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00?ooooo
00?oX23`ooooooooool0>?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0gooooo`03oomo0?oooooooooo02gooooo00?oogl0ooooooooool04Oooool00oooO`3ooooooooo
o`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;oooool2oj0Pl0Kooooo0_nP
8?02ooooo`06oj0Pl?ooooooX23`oooooonP8?3ooooo1?nP8?000oooooooX23`ooooo`03oj0Pl0Go
oooo00CoX23`oooooonP8?3ooooo0_nP8?1Kooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo03_ooooo00Googl0ooooooooO`3ooooooomo0007ooooo`03oomo0?ooooooogl0
02[ooooo00?oogl0ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo
033ooooo00?oX23`ooooooooool06oooool2oj0Pl1?ooooo0_nP8?1<ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo03oooooo00?oogl0ooooooooool01?ooool01OooO`3o
ooooooooooooooooogl000Gooooo00?oogl0ooooooooool04?ooool00oooO`3oooooooooo`0coooo
o`03oomo0?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^oooo
o`?oX23`00?ooooooj0Pl?nP8?001?ooool00onP8?3oooooooooo`08ooooo`04oj0Pl?oooooooooo
oj0Pl0;ooooo0_nP8?000oooooooX23`oj0Pl003ooooo`;oX23`G_ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`0dooooo`07oomo0?ooooooooooooooooooO`3ooooooomo
0003ooooo`05oomo0?ooooooooooooooooooO`002oooool00oooO`3ooooooomo000cooooo`03oomo
0?oooooooooo02[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03oj0P
l?oooooooooo013ooooo0onP8?02ooooo`03oj0Pl?ooooooX23`00Cooooo00?oX23`oooooonP8?00
2Oooool01OnP8?3ooooooj0Pl?ooooooX23`00;ooooo0_nP8?000oooooooX23`ooooo`05ooooo`;o
X23`2?ooool00onP8?3oooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo03[ooooo00?oogl0ooooooooool02Oooool00oooO`3oooooooooo`02ooooo`03oomo
0?oooooooooo01oooooo00?oogl0ooooooooool0@Oooool00ol0003oooooooooo`0?ooooo`03oj0P
l?oooooooooo00Oooooo00?oX23`ooooooooool09oooool00onP8?3oooooooooo`02ooooo`;oX23`
1Oooool2oj0Pl0Cooooo00?oX23`oooooonP8?001?ooool2oj0Pl0oooooo00?oX23`ooooooooool0
Doooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0oooooo`03oomo0?oo
oooooooo00;oogl02_ooool01OooO`3ooooooomo0?ooooooogl000Cooooo00?oogl0ooooooooool0
1oooool00oooO`3ooooooomo000=ooooo`03oomo0?oooooooooo03gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0booooo`;oX23`00Gooooooj0Pl?nP8?3ooooooj0Pl003ooooo`03
oj0Pl?ooooooX23`00Oooooo00?oX23`ooooooooool00oooool01?nP8?3ooooooooooonP8?02oooo
o`03oj0Pl?oooooooooo00Cooooo00CoX23`ooooooooooooX23`2?ooool01OnP8?3ooooooj0Pl?oo
ooooX23`00Kooooo00?oX23`ooooooooool0?_ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`11ooooo`04oomo0?oooooooooooomo00?ooooo0_ooO`0Kooooo`03oomo0?oo
oooooooo00cooooo00?oogl0ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Cooooo0onP8?02ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool03?oo
ool00onP8?3oooooooooo`05ooooo`05oj0Pl?ooooooX23`oooooonP8?001Oooool01OnP8?3ooooo
oj0Pl?ooooooX23`04gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
?Oooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool0
3Oooool00oooO`3oooooooooo`06ooooo`04oomo0?oooooooooooomo00[ooooo00?oogl0oooooooo
ool0?Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?oX23`oooooooo
ool03oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00;ooooo0onP8?04ooooo`05
oj0Pl?oooooooooooooooonP8?002Oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo
00;ooooo00?oX23`ooooooooool0F?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`0looooo`;oogl01oooool00oooO`3oooooooooo`03ooooo`04oomo0?oooooooooooomo
00;ooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0Iooooo`03oomo0?oooooooooo
03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0eooooo`03oj0Pl?ooooooX23`
00Cooooo0onP8?08ooooo`;oX23`00Gooooooj0Pl?oooooooooooj0Pl002ooooo`04oj0Pl?oooooo
X23`ooooo`;oX23`00Cooooooj0Pl?ooooooX23`0_ooool2oj0Pl5?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0A?ooool00oooO`3oooooooooo`04ooooo`04oomo0?oo
oooooooooomo00[ooooo00?oogl0ooooooooool0EOooool00ol0003oooooooooo`0?ooooo`03o`00
0?nP8?3ooooo03Sooooo0_nP8?001OooooooX23`ooooooooooooX23`00?ooooo00?oX23`oooooooo
ool02_ooool01_nP8?3ooooooooooonP8?3ooooooj0Pl0?ooooo0_nP8?1Gooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo04cooooo00?oogl0ooooooooO`001OooO`000ooo
ooooogl0ooooo`0:ooooo`03oomo0?oooooooooo01oooooo00?oogl0ooooooooool0:oooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooj0Pl3Sooooo00?oX23`oooooonP8?000_nP8?00
0oooooooX23`ooooo`02ooooo`04oj0Pl?oooooooooooj0Pl0Cooooo00GoX23`oooooonP8?3ooooo
oj0Pl00:ooooo`;oX23`00?ooooooj0Pl?nP8?000_nP8?1@ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo04kooooo00Coogl0ooooooooooooogl0Goooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03;ooooo00?oX23`ooooooooool03?ooool00onP8?3ooooo
ooooo`05ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool01?ooool01?nP8?3ooooo
oooooonP8?04ooooo`04oj0Pl?oooooooooooj0Pl2;ooooo00?oX23`ooooooooool0:oooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0mooooo`03oomo0?oooooooooo00Co
oooo00?oogl0ooooooooO`001?ooool3oomo00Cooooo0oooO`02ooooo`03oomo0?oooooooooo00co
oooo00?oogl0ooooooooool0>?ooool00oooO`3oooooooooo`0=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0=oooool00onP8?3ooooooj0Pl002ooooo`04oj0Pl?oooooooooooj0P
l0;ooooo00CoX23`ooooooooooooX23`0_ooool00onP8?3ooooooj0Pl002ooooo`04oj0Pl?oooooo
ooooooooo`CoX23`00Oooooooj0Pl?oooooooooooj0Pl?ooooooX23`00;ooooo00?oX23`oooooooo
ool0D?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`11ooooo`03oomo
0?oooooooooo00Oooooo00?oogl0ooooooooool00_ooool01?ooO`3ooooooomo0?ooool2oomo0005
ooooooooO`3oooooooooooooO`00E_ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo
03Sooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`02ooooo`;oX23`1?ooool00onP
8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool0E?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1:ooooo`05oomo0?oooooooooooooo
ooooO`001?ooool01oooO`3ooooooomo0?ooooooogl0ooooooooO`005_ooool00oooO`3ooooooooo
o`0nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool00onP8?3ooooooooo
o`02ooooo`;oX23`00?ooooooj0Pl?ooool00oooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oo
oooooooo00Gooooo00?oX23`ooooooooool07oooool00onP8?3oooooooooo`0/ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo043ooooo00Googl0oooooooooooooooooomo
0004ooooo`03oomo0?ooooooogl000Cooooo0oooO`000oooooooogl0oomo0008ooooo`04oomo0?oo
oooooooooomo00kooooo0_ooO`0Qooooo`03oomo0?oooooooooo01_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0mooooo`;oX23`1Oooool00onP8?3ooooooj0Pl002ooooo`;oX23`
0oooool2oj0Pl003oooooonP8?3oX23`00Cooooo1OnP8?03ooooo`03oj0Pl?oooooooooo00;ooooo
00?oX23`ooooooooool04?ooool00onP8?3oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo04oooooo00?oogl0ooooooooool01_ooool2oomo00;ooooo00?o
ogl0ooooooooool03?ooool00oooO`3oooooooooo`13ooooo`03o`000?oooooooooo00oooooo00?o
0000oj0Pl?ooool0>oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00Gooooo00?o
X23`ooooooooool02Oooool00onP8?3oooooooooo`0Yooooo`03oj0Pl?oooooooooo02gooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0A?ooool00oooO`3ooooooomo0003
ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`03
oomo01;ooooo00Coogl0ooooooooooooogl0?_ooool00ol0003oooooooooo`0?ooooo`05o`000?oo
oooooooooooooonP8?00>?ooool00onP8?3ooooooj0Pl003ooooo`;oX23`0oooool3oj0Pl0;ooooo
1?nP8?000oooooooX23`oj0Pl002oj0Pl004oooooonP8?3ooooooj0Pl0Wooooo00?oX23`oooooooo
ool0C_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`16ooooo`03oomo
0?oooooooooo00;ooooo00?oogl0ooooooooool08Oooool00oooO`3oooooooooo`0Aooooo`03oomo
0?oooooooooo02_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14ooooo`03oj0P
l?oooooooooo00?ooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`02ooooo`;oX23`
1oooool01?nP8?3oooooooooooooool2oj0Pl4gooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0FOooool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo00Kooooo
00?oogl0ooooooooool04_ooool00oooO`3oooooooooo`0]ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0B_ooool01?nP8?3ooooooooooonP8?07ooooo`03oj0Pl?oooooooooo00Ko
oooo00?oX23`oooooonP8?002Oooool00onP8?3oooooooooo`14ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`000?oooooooooo01Gooooo0_ooO`0cooooo`03oomo0?oooooooooo00Gooooo
00Coogl0ooooooooooooogl01?ooool00oooO`3ooooooomo000Zooooo`03oomo0?oooooooooo00Co
oooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Iooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0@?ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00;o
oooo00?oX23`oooooonP8?000_ooool01?nP8?3ooooooj0Pl?ooool2oj0Pl003oooooonP8?3oX23`
00Gooooo00?oX23`ooooooooool00oooool3oj0Pl1Wooooo00?oX23`ooooooooool0;_ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Fooooo`;oogl000?ooooooomo0?oo
ool0<?ooool01OooO`3oooooooooooooooooogl000cooooo00?oogl0ooooooooool00_ooool00ooo
O`3oooooooooo`09ooooo`03oomo0?oooooooooo047ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03oj0Pl?oooooooooo03cooooo00?oX23`ooooooooool03?ooool00onP
8?3oooooooooo`09ooooo`;oX23`00?ooooooj0Pl?ooool00_ooool2oj0Pl1;ooooo00?oX23`oooo
ooooool01Oooool00onP8?3oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo01Kooooo00Coogl0ooooooooO`3oogl0=?ooool00oooO`3oooooooooo`04oooo
o`03oomo0?ooooooogl000Wooooo00?oogl0ooooooooool05Oooool00oooO`3oooooooooo`04oooo
o`04oomo0?oooooooooooomo02gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`16
ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`05
ooooo`03oj0Pl?oooooooooo00;oX23`00?ooooooj0Pl?nP8?000_ooool00onP8?3oooooooooo`18
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo01Gooooo0_ooO`000ooo
ooooogl0ooooo`0eooooo`04oomo0?oooooooooooomo02_ooooo00?oogl0ooooooooool0<?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo00CoX23`ooooooooooooX23`0ooo
ool01OnP8?3oooooooooooooooooX23`00Sooooo0_nP8?0:ooooo`;oX23`C?ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`0Fooooo`;oogl0=Oooool01?ooO`3ooooooooo
ooooO`09ooooo`05oomo0?ooooooooooooooooooO`001_ooool00oooO`3oooooooooo`0@ooooo`;o
ogl0=oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo00?oX23`oooooooo
ool02Oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`oooooooo
ool00oooool00onP8?3oooooooooo`06ooooo`;oX23`0_ooool3oj0Pl003oooooonP8?3ooooo04?o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Coooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?oooooooooo01Cooooo00?oogl0ooooooooool03oooool00oooO`3ooooo
ooooo`0aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00onP8?3ooooo
ooooo`05ooooo`;oX23`00?ooooooj0Pl?ooool01_ooool2oj0Pl0Gooooo00?oX23`ooooooooool0
1?ooool00onP8?3oooooooooo`15ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo04kooooo00?oogl0ooooooooool02Oooool00oooO`3oooooooooo`04ooooo`03oomo0?oo
oooooooo00Kooooo00?oogl0ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04[ooooo00?oX23`ooooooooool00_ooool01_nP8?3oooooooooooooooooX23`ooooo`;o
X23`0_ooool00onP8?3oooooooooo`03oj0Pl0?ooooo00?oX23`ooooooooool00oooool01OnP8?3o
ooooooooooooooooX23`01?ooooo00?oX23`ooooooooool0;_ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`1@ooooo`03oomo0?oooooooooo01[ooooo00?oogl0oooooooo
ool02Oooool00oooO`3oooooooooo`0eooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool00onP8?3oooooooooo`0eooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`oooooooo
ool04Oooool6oj0Pl0oooooo0_nP8?000oooooooX23`ooooo`10ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`000?oooooooooo06Cooooo00?oogl0ooooooooool07?ooool00oooO`3ooooo
ooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00onP8?3ooooo
ooooo`1;ooooo`03oj0Pl?oooooooooo00[ooooo1?nP8?000oooooooX23`ooooo`05ooooo`CoX23`
0_ooool00onP8?3oooooooooo`0oooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo01;ooooo00?oogl0ooooooooool0??ooool00oooO`3ooooooomo000:ooooo`03oomo0?oo
oooooooo00kooooo00Coogl0ooooooooooooogl04_ooool00oooO`3oooooooooo`0Yooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01Oooool00onP8?3oooooooooo`14ooooo`;oX23`
0_ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?ooooooX23`00;ooooo00CoX23`oooooonP8?3o
X23`0oooool4oj0Pl0?ooooo00KoX23`ooooooooooooX23`oooooonP8?05ooooo`03oj0Pl?oooooo
oooo03Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool05?ooool00ooo
O`3oooooooooo`0nooooo`03oomo0?oooooooooo00_ooooo00?oogl0ooooooooool01_ooool00ooo
O`3oooooooooo`02ooooo`03oomo0?oooooooooo03gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0oooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool02_ooool2oj0P
l0Cooooo00GoX23`oooooooooooooooooj0Pl005ooooo`03oj0Pl?ooooooX23`00Cooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo03Kooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0E_ooool2oomo00Gooooo00?oogl0oooo
ooooool00oooool00oooO`3oooooooooo`0Gooooo`03oomo0?oooooooooo037ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Vooooo`03oj0Pl?oooooooooo02_ooooo00?oX23`oooo
oonP8?000_ooool2oj0Pl0?ooooo00?oX23`oooooonP8?000onP8?03ooooo`04oj0Pl?oooooooooo
oj0Pl0Cooooo00?oX23`oooooonP8?001?ooool2oj0Pl3Wooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0EOooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo
00;ooooo00?oogl0ooooooooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo00?oX23`ooooooooool0C_ooool3oj0Pl003oooooonP8?3oX23`00Oooooo0_nP8?000ooo
ooooX23`ooooo`03oj0Pl0;ooooo00CoX23`oooooonP8?3oX23`1_ooool00onP8?3oooooooooo`03
ooooo`;oX23`00?ooooooj0Pl?ooool0<_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`1Kooooo`;oogl0E?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
05;ooooo00?oX23`oooooonP8?000_ooool2oj0Pl003oooooonP8?3ooooo00_ooooo00CoX23`oooo
ooooooooX23`2?ooool01?nP8?3ooooooooooonP8?05ooooo`03oj0Pl?oooooooooo03;ooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0F?ooool00oooO`3ooooooomo0007
ooooo`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooool06?ooool00oooO`3oooooooooo`07
ooooo`03oomo0?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1:
ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooj0Pl005
ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooonP8?000_nP8?001?ooooooX23`oooooonP
8?02ooooo`?oX23`0oooool00onP8?3oooooooooo`0Mooooo`03oj0Pl?oooooooooo01Wooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0F?ooool2oomo00;ooooo00?oogl0
ooooooooool0D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`0>ooooo`?oX23`0_ooool01OnP8?3ooooooj0Pl?oo
ooooX23`00;ooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`07ooooo`05oj0Pl?oo
oooooooooooooonP8?00;?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0Uooooo`03oomo0?oooooooooo03;ooooo00Coogl0ooooooooO`3oogl01_ooool2oomo00Wooooo
00?oogl0ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo
00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`05oj0Pl0?ooooo00?oX23`oooooonP8?00
0oooool01OnP8?3ooooooooooonP8?3ooooo00;oX23`00?ooooooj0Pl?nP8?000_nP8?001Ooooooo
X23`oj0Pl?nP8?3ooooo00;oX23`00Gooooooj0Pl?nP8?3ooooooj0Pl00booooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo06?ooooo00Coogl0ooooooooooooogl01?ooool0
0oooO`3oooooooooo`06ooooo`;oogl0>oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Gooooo00?oX23`ooooooooool0C?ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooo
oooo00Kooooo00GoX23`oooooooooooooooooj0Pl007ooooo`03oj0Pl?ooooooX23`00Gooooo00Co
X23`ooooooooooooX23`2Oooool00onP8?3oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo05gooooo00?oogl0ooooooooool00oooool00oooO`3ooooooooo
o`0;ooooo`03oomo0?oooooooooo01Cooooo00?oogl0ooooooooool08Oooool00oooO`3ooooooooo
o`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0F?ooool01?nP8?3ooooooooo
oonP8?0?ooooo`03oj0Pl?ooooooX23`00?ooooo0_nP8?0nooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo01gooooo00?oogl0ooooooooool0>_ooool00oooO`3ooooooomo
0002oomo00;ooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`13ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0E?ooool00onP8?3oooooooooo`02ooooo`CoX23`00?o
oooooj0Pl?ooool00oooool00onP8?3ooooooj0Pl004ooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo
0onP8?001?ooooooX23`ooooooooool3oj0Pl003oooooonP8?3ooooo00?ooooo00CoX23`oooooooo
ooooX23`6?ooool00onP8?3oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo05kooooo00?oogl0ooooooooool05_ooool00oooO`3oooooooooo`0gooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0E_ooool00onP8?3oooooooooo`03ooooo`03
oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool01oooool00onP8?3oooooooooo`0:ooooo`03
oj0Pl?ooooooX23`00;oX23`1_ooool00onP8?3oooooooooo`0[ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`000?oooooooooo06?ooooo00?oogl0ooooooooool02oooool00oooO`3ooooo
oomo000Aooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool07oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo023ooooo00?oX23`ooooooooool01_ooool00onP8?3ooooo
ooooo`0^ooooo`;oX23`0_ooool00onP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo00?ooooo
1?nP8?03ooooo`?oX23`00Cooooooj0Pl?nP8?3oX23`0_ooool5oj0Pl0Sooooo00?oX23`oooooooo
ool02?ooool00onP8?3oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo05oooooo0_ooO`000oooooooogl0ooooo`07ooooo`03oomo0?ooooooogl004?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Hooooo`03oj0Pl?oooooooooo00Sooooo
00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`0;ooooo`05oj0Pl?oooooooooooj0Pl?oo
ool00_nP8?06ooooo`05oj0Pl?oooooooooooooooonP8?009oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`1Sooooo`03oomo0?oooooooooo00Oooooo00?oogl0oooooooo
ool04?ooool00oooO`3oooooooooo`0Mooooo`03oomo0?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1Nooooo`09oj0Pl?oooooooooooj0Pl?ooooooX23`oooooonP
8?3ooooo00;oX23`00Cooooooj0Pl?ooooooX23`0_ooool00onP8?3oooooooooo`02ooooo`03oj0P
l?oooooooooo03[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0I_oo
ool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo03[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0[ooooo`03oj0Pl?oooooooooo033ooooo0_nP8?03ooooo`03oj0Pl?oo
oooooooo00Cooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`03oj0Pl0?ooooo00?o
X23`ooooooooool00onP8?02ooooo`CoX23`:oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`1_ooooo`03oomo0?oooooooooo01Oooooo00?oogl0ooooooooool09Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Gooooo00?oX23`ooooooooool03Oooool0
0onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo00Cooooo00KoX23`oooooonP8?3oX23`oooo
oonP8?03ooooo`05oj0Pl?oooooooooooooooonP8?009_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`1Sooooo`04oomo0?ooooooogl0oomo00?ooooo00?oogl0oooooooo
ool02Oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00_ooooo00?oogl0oooooooo
ool04_ooool00oooO`3oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool05Oooool00onP8?3oooooooooo`0Aooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`oooooooo
ool05oooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooooooo
ool01?ooool01?nP8?3ooooooj0Pl?nP8?02ooooo`03oj0Pl?ooooooX23`00Cooooo00?oX23`oooo
oonP8?000_nP8?04ooooo`;oX23`1?ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo
02Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Eoooool00oooO`3o
ooooooooo`0<ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooool05oooool00oooO`3o
ooooooooo`04ooooo`03oomo0?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Gooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool0=oooool00onP8?3o
ooooooooo`06ooooo`03oj0Pl?oooooooooo00[ooooo00CoX23`ooooooooooooX23`1Oooool01?nP
8?3ooooooooooonP8?05ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool09Oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1Xooooo`;oogl02_ooool00ooo
O`3oooooooooo`0:ooooo`03oomo0?oooooooooo02gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Mooooo`;oX23`0oooool01?nP8?3ooooooooooonP8?04ooooo`;oX23`1_ooool0
1?nP8?3ooooooooooonP8?0;ooooo`?oX23`1?ooool00onP8?3oooooooooo`0Vooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Wooooo00?oogl0ooooooooO`003Oooool0
0oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo01Oooooo00?oogl0ooooooooool05_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?oX23`ooooooooool00oooool0
0onP8?3oooooooooo`1Hooooo`03oj0Pl?oooooooooo00;ooooo0onP8?02ooooo`?oX23`0_ooool3
oj0Pl003oooooonP8?3ooooo00;ooooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oo
oooooooo00;ooooo00?oX23`ooooooooool09oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`0]ooooo`03oomo0?oooooooooo03[ooooo0_ooO`07ooooo`03oomo0?oooooo
oooo00Oooooo00?oogl0ooooooooO`001Oooool00oooO`3oooooooooo`0>ooooo`03oomo0?oooooo
oooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Xooooo`?oX23`1oooool0
1?nP8?3ooooooj0Pl?nP8?0kooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo02Oooooo00?oogl0ooooooooool0@Oooool00oooO`3oooooooooo`07ooooo`05oomo0?oooooo
ooooooooooooO`006oooool00oooO`3oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0J_ooool00onP8?3ooooooj0Pl007ooooo`03oj0Pl?oooooooooo00Cooooo00?o
X23`ooooooooool01?ooool3oj0Pl003oooooonP8?3ooooo00oooooo00?oX23`ooooooooool05ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1[ooooo`03oomo0?oooooo
oooo00Sooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`0>ooooo`05oomo0?oooooo
ooooooooooooO`001oooool00oooO`3oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0J_ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?ooooooX23`00Kooooo00?o
X23`ooooooooool02?ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo02;ooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0;?ooool00oooO`3oooooooooo`0k
ooooo`;oogl000Cooooooomo0?ooooooogl00_ooool01OooO`3oooooooooooooooooogl000kooooo
00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0I_ooool01?nP8?3oooooooooooooool2oj0Pl0?ooooo1OnP8?04ooooo`03
oj0Pl?ooooooX23`00Kooooo0_nP8?04ooooo`;oX23`00?ooooooj0Pl?ooool09Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0=oooool00onP8?3oooooooooo`0]ooooo`03oj0Pl?oooooooooo00?ooooo
00?oX23`ooooooooool00oooool00onP8?3oooooooooo`03ooooo`04oj0Pl?ooooooooooooooo`;o
X23`<_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0^ooooo`03oomo
0?oooooooooo047ooooo00?oogl0ooooooooO`003oooool00oooO`3oooooooooo`0Zooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0L?ooool01onP8?3oooooooooooooooooX23`oooo
oonP8?001?ooool00onP8?3oooooooooo`0:ooooo`;oX23`9oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`1_ooooo`03oomo0?oooooooooo00cooooo00?oogl0oooooooo
ool05Oooool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0cooooo`03oj0Pl?oooooooooo03cooooo0_nP8?001Ooooooo
X23`ooooooooooooX23`00?ooooo0_nP8?05ooooo`06oj0Pl?oooooooooooooooonP8?3ooooo0_nP
8?02ooooo`03oj0Pl?oooooooooo027ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
ooooooooool0Koooool00oooO`3oooooooooo`02ooooo`;oogl02?ooool00oooO`3oooooooooo`02
ooooo`03oomo0?oooooooooo02_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0e
ooooo`03oj0Pl?oooooooooo03Cooooo00?oX23`ooooooooool01_ooool01?nP8?3ooooooj0Pl?nP
8?07ooooo`03oj0Pl?ooooooX23`00?ooooo00CoX23`oooooooooooooooo1?nP8?0Sooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03?ooooo00?oogl0ooooooooool0Eooo
ool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo01Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0`ooooo`03oj0Pl?oooooooooo03cooooo00?oX23`oooooonP8?001?oo
ool6oj0Pl0?ooooo00CoX23`ooooooooooooX23`2?ooool00onP8?3ooooooj0Pl002oj0Pl27ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0<Oooool00oooO`3ooooooomo
000looooo`;oogl00_ooool00oooO`3oooooooooo`0jooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0E_ooool2oj0Pl27ooooo00CoX23`ooooooooooooX23`2oooool00onP8?3ooooo
oj0Pl002ooooo`;oX23`8_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`1fooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01oooool00oooO`3ooooooooo
o`07ooooo`03oomo0?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1cooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooooo
o`02ooooo`03oj0Pl?ooooooX23`00Oooooo1?nP8?0Qooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo07Cooooo0_ooO`02ooooo`;oogl00_ooool00oooO`3oooooooooo`06
ooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool07_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo06[ooooo00GoX23`oooooooooooooooooj0Pl002ooooo`04oj0Pl?oo
oooooooooj0Pl0Gooooo00GoX23`ooooooooooooX23`ooooo`07oj0Pl0Oooooo1?nP8?0Pooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03?ooooo00?oogl0ooooooooool0
?_ooool2oomo0003ooooooooO`3ooooo01[ooooo00?oogl0ooooooooool06oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo077ooooo00?oX23`oooooonP8?000_nP8?05ooooo`?oX23`
2Oooool00onP8?3oooooooooo`02ooooo`?oX23`0oooool00onP8?3oooooooooo`0Looooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo07Oooooo00?oogl0ooooooooO`001?oo
ool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00Oooooo00Googl0oooooooooooooooo
oomo000Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Koooool2oj0Pl0Oooooo
00SoX23`ooooooooooooX23`oooooonP8?3ooooooj0Pl0;ooooo00?oX23`ooooooooool00oooool2
oj0Pl0?ooooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oooooooooo01[ooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0=Oooool00oooO`3oooooooooo`0j
ooooo`03oomo0?oooooooooo00;ooooo0oooO`0gooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0>?ooool00onP8?3oooooooooo`0booooo`03oj0Pl?oooooooooo00Kooooo00?oX23`
ooooooooool01Oooool2oj0Pl0;ooooo0_nP8?03ooooo`03oj0Pl?ooooooX23`00Wooooo00?oX23`
ooooooooool06oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1joooo
o`03oomo0?oooooooooo00?ooooo00Coogl0oooooooooooooooo0oooO`03ooooo`03oomo0?oooooo
oooo00Cooooo00?oogl0ooooooooool04oooool00oooO`3oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0N?ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooo
oooo00?oX23`00Gooooooj0Pl?nP8?3ooooooj0Pl002ooooo`03oj0Pl?ooooooX23`00;ooooo00?o
X23`oooooonP8?000_nP8?0Kooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo00Wooooo00?oogl0ooooooooool0:oooool00oooO`3oooooooooo`11ooooo`03oomo0?oooooo
oooo00?ooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`0Looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0N_ooool00onP8?3ooooooj0Pl009ooooo`03oj0Pl?oooooo
oooo00Cooooo00?oX23`ooooooooool00_ooool2oj0Pl003oooooonP8?3oX23`01[ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Noooool00oooO`3oooooooooo`03oomo
0005ooooooooO`3oooooooooooooO`001?ooool01?ooO`3oooooooooooooO`03ooooo`;oogl07_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07;ooooo00?oX23`ooooooooool00_oo
ool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo00Sooooo00CoX23`oooooooooooooooo
0_nP8?03ooooo`;oX23`6oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`1iooooo`03oomo0?oooooooooo00;ooooo00Coogl0ooooooooooooogl00_ooool01?ooO`3ooooo
ooooooooO`0Gooooo`03oomo0?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0jooooo`03oj0Pl?oooooooooo03Wooooo1?nP8?000oooooooX23`oj0Pl007ooooo`06
oj0Pl?ooooooX23`oj0Pl?ooooooX23`0oooool01?nP8?3ooooooooooonP8?05ooooo`;oX23`6Ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1iooooo`03oomo0?oooooo
oooo00;ooooo00?oogl0ooooooooool04?ooool00oooO`3ooooooomo000Cooooo`03oomo0?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1booooo`03oj0Pl?oooooo
oooo00Kooooo0_nP8?05ooooo`03oj0Pl?ooooooX23`00?ooooo00OoX23`oooooooooooooooooj0P
l?ooooooX23`00Cooooo00CoX23`ooooooooooooX23`6_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`1nooooo`?oogl02oooool01_ooO`3oooooooooooooO`3ooooooomo
01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oj0Pl?ooooooX23`
03Wooooo00CoX23`oooooonP8?3oX23`0oooool00onP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooo
oooo00Sooooo0_nP8?04ooooo`03oj0Pl?oooooooooo01Wooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0POooool00oooO`3oooooooooo`0Hooooo`03oomo0?oooooooooo
01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Sooooo`03oj0Pl?oooooooooo
01Kooooo0_nP8?04ooooo`03oj0Pl?ooooooX23`00cooooo00?oX23`ooooooooool00_ooool2oj0P
l003oooooonP8?3ooooo01Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool0P?ooool00oooO`3oooooooooo`0:ooooo`03oomo0?oooooooooo027ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1oooooo`05oj0Pl?oooooooooooooooonP8?000oooool01OnP
8?3ooooooj0Pl?ooooooX23`00gooooo00?oX23`ooooooooool05Oooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`23ooooo`;oogl00oooool01?ooO`3ooooooomo0?ooO`07
ooooo`06oomo0?oooooooooooomo0?ooooooogl06?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo07[ooooo0_nP8?000oooooooX23`ooooo`02oj0Pl0?ooooo0onP8?0Cooooo`03oj0P
l?oooooooooo01Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0P?oo
ool00oooO`3oooooooooo`02ooooo`;oogl02?ooool01oooO`3oooooooooooooooooogl0oooooooo
O`001oooool00oooO`3oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Koooool00onP8?3oooooooooo`0<ooooo`04oj0Pl?oooooooooooj0Pl0cooooo00?oX23`oooo
ooooool08?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`23ooooo`;o
ogl00_ooool01OooO`3ooooooomo0?ooO`3ooooo00Googl000?ooooooomo0?ooO`000_ooool00ooo
O`3oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00onP
8?3oooooooooo`1Qooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`oooooonP8?000oooool00onP
8?3ooooooj0Pl008ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool05?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`24ooooo`;oogl000?ooooooomo0?oo
ool00_ooO`002Oooooooogl0ooooooooooooogl0ooooooooO`3ooooooomo0004ooooo`03oomo0?oo
oooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1mooooo`03oj0Pl?oo
oooooooo00;ooooo00?oX23`ooooooooool00oooool2oj0Pl005oooooonP8?3ooooooooooonP8?00
8_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`16ooooo`03oomo0?oo
oooooooo03gooooo2_ooO`000oooooooogl0ooooo`03oomo00Gooooo00?oogl0ooooooooool04ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07kooooo0_nP8?001OooooooX23`oooo
ooooooooX23`00;ooooo1?nP8?001?ooooooX23`oj0Pl?nP8?03ooooo`03oj0Pl?oooooooooo01co
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Qoooool00oooO`3ooooo
oomo0002ooooo`Coogl00_ooool01?ooO`3oooooooooooooool2oomo0003ooooooooO`3ooooo00;o
oooo00?oogl0ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo0_nP8?1/ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool01Oooool00onP8?3o
ooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo08?ooooo
00?oogl0ooooooooool00oooool2oomo0003ooooooooO`3ooooo00?oogl000?ooooooomo0?ooool0
0_ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo017ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1aooooo`03oj0Pl?oooooooooo00oooooo0_nP8?06ooooo`04oj0P
l?ooooooX23`oj0Pl0Gooooo00?oX23`ooooooooool06_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`26ooooo`06oomo0?ooooooooooooooooooO`3ooooo0_ooO`000ooo
ooooogl0ooooo`04oomo0004ooooooooO`3oogl0oomo01Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`03oj0Pl?oooooooooo033ooooo00?oX23`ooooooooool0>_ooool6
oj0Pl003oooooonP8?3ooooo00CoX23`8_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`2;ooooo`;oogl000?ooooooomo0?ooO`001?ooool5oomo0004ooooooooO`3ooooo
oomo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`27ooooo`03oj0Pl?oooooo
oooo02Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool05?ooool00ooo
O`3oooooooooo`1hooooo`googl000?ooooooomo0?ooool04_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo08;ooooo00CoX23`oooooooooooooooo1?nP8?06ooooo`03oj0Pl?oooooo
oooo00Kooooo00?oX23`ooooooooool05Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`2?ooooo`?oogl000?ooooooomo0?ooO`000_ooO`000oooooooogl0oomo000Goooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0OOooool00onP8?3oooooooooo`07oooo
o`CoX23`9_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Aooooo`05
oomo0?ooooooogl0oomo0?ooool00oooO`02ooooo`03oomo0?oooooooooo01?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0mooooo`03oj0Pl?oooooooooo04Wooooo00?oX23`oooo
ooooool01?ooool00onP8?3oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo01Wooooo00?oogl0ooooooooool0M?ooool00oooO`3ooooooomo0008oomo01Ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2;ooooo`03oj0Pl?oooooooooo02?o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Toooool4oomo00Gooooo
00?oogl0ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Soooool01?ooO`3ooooooooo
ooooool2oomo0003ooooooooO`3oogl000Googl000Gooooooomo0?oooooooooooomo000?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Goooool00onP8?3oooooooooo`0Yooooo`04
oj0Pl?oooooooooooj0Pl0Cooooo00CoX23`ooooooooooooX23`6_ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`2Hooooo`03oomo0?ooooooogl000?oogl04oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo093ooooo00?oX23`ooooooooool00_ooool00onP
8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01Cooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool07?ooool00oooO`3oooooooooo`1jooooo`03oomo0?ooooooogl000;o
ogl00_ooool00oooO`3oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0>_ooool00onP8?3oooooooooo`1Jooooo`04oj0Pl?oooooooooooj0Pl0Oooooo00?oX23`oooo
ooooool03?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Jooooo`03
oomo0?oooooooooo01?ooooo00?oogl0o`000?ooool04?ooool00ol0003oooooooooo`22ooooo`03
oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool04oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`2Iooooo`03oomo0?oooooooooo00;ooooo0_ooO`0Aooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0UOooool00onP8?3oooooooooo`0Iooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo09Kooooo00?oogl0ooooooooool00ooo
ool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oooooooooo00_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2Gooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool0
3oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`2Nooooo`03oomo0?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2Aooooo`03oj0Pl?oooooooooo00?ooooo00CoX23`ooooooooooooX23`1?oo
ool00onP8?3oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`24ooooo`03oj0Pl?oooooo
oooo01;ooooo00?oX23`ooooooooool00oooool2oj0Pl13ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0Voooool2oomo01Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0:;o
oooo00?oogl0ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09ko
oooo00CoX23`ooooooooooooX23`3oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2Tooooo`04oomo0?oooooooooooomo00Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0:7o
oooo00?oogl0ooooooooO`003Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:7o
oooo00CoX23`ooooooooooooX23`3?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2Rooooo`05oomo0?ooooooooooooooooooO`002_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0:Cooooo00?oX23`ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`2Tooooo`04oomo0?oooooooooooomo00Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Uooooo`03
oj0Pl?oooooooooo00Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0:Kooooo00?oX23`oooooonP8?002?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`2Zooooo`03oomo0?oooooooooo00Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2/ooooo`03oj0Pl?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:7ooooo00?oX23`ooooooooool03Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0[Oooool01OnP8?3o
oooooooooooooooo000000_ooooo000:ooooo`03o`000?oooooooooo0:kooooo0_ooO`000ooooooo
0000ooooo`0@ooooo`03o`000?oooooooooo0:kooooo00CoX23`oooooonP8?3o00002oooool000[o
oooo/Ol000001?ooO`3o0000oomo0?l0000Aoooook3o000000GoX23`o`000?l0003oX23`o`00000;
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-14.4237, \
-6.63736, 1.4157, 1.4157}, {{208.5, 388.938}, {184.875, 4.5}} -> {-295.249, \
-6.59083, 1.41521, 1.41521}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian models", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[{
    \(\(d2d1 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data1)\);\)\), "\[IndentingNewLine]", 
    \(\(d2d2 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[d2d1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[d2d2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.6424 .98077 m
.6356 .97628 L
.61095 .95897 L
.60708 .95611 L
.58629 .94016 L
.57545 .93146 L
.56164 .91992 L
.54653 .9068 L
.53698 .89821 L
.51972 .88215 L
.51233 .87504 L
.49463 .8575 L
.48767 .85037 L
.471 .83284 L
.46302 .82419 L
.44863 .80819 L
.43836 .79645 L
.42736 .78353 L
.41371 .7671 L
.40706 .75888 L
.38905 .73607 L
.38764 .73422 L
.36906 .70957 L
.3644 .70323 L
.35126 .68491 L
.33974 .6685 L
.33413 .66026 L
.31764 .6356 L
.31509 .63172 L
.30184 .61095 L
.29043 .59267 L
.28658 .58629 L
.2719 .56164 L
.26578 .55113 L
.2578 .53698 L
.24416 .51233 L
.24112 .50674 L
.23112 .48767 L
.21847 .46302 L
.21647 .45904 L
.20643 .43836 L
.19475 .41371 L
.19181 .40737 L
.18365 .38905 L
.17294 .3644 L
.16716 .35072 L
.16272 .33974 L
.15298 .31509 L
.14361 .29043 L
.1425 .28746 L
.13483 .26578 L
.12645 .24112 L
.11847 .21647 L
.11785 .21448 L
.1111 .19181 L
.10415 .16716 L
.09765 .1425 L
.0932 .12446 L
.09167 .11785 L
.08626 .0932 L
.08136 .06854 L
.07698 .04389 L
.07318 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.6424 .98077 m
.6356 .97628 L
.61095 .95897 L
.60708 .95611 L
.58629 .94016 L
.57545 .93146 L
.56164 .91992 L
.54653 .9068 L
.53698 .89821 L
.51972 .88215 L
.51233 .87504 L
.49463 .8575 L
.48767 .85037 L
.471 .83284 L
.46302 .82419 L
.44863 .80819 L
.43836 .79645 L
.42736 .78353 L
.41371 .7671 L
.40706 .75888 L
.38905 .73607 L
.38764 .73422 L
.36906 .70957 L
.3644 .70323 L
.35126 .68491 L
.33974 .6685 L
.33413 .66026 L
.31764 .6356 L
.31509 .63172 L
.30184 .61095 L
.29043 .59267 L
.28658 .58629 L
.2719 .56164 L
.26578 .55113 L
.2578 .53698 L
.24416 .51233 L
.24112 .50674 L
.23112 .48767 L
.21847 .46302 L
.21647 .45904 L
.20643 .43836 L
.19475 .41371 L
.19181 .40737 L
.18365 .38905 L
.17294 .3644 L
.16716 .35072 L
.16272 .33974 L
.15298 .31509 L
.14361 .29043 L
.1425 .28746 L
Mistroke
.13483 .26578 L
.12645 .24112 L
.11847 .21647 L
.11785 .21448 L
.1111 .19181 L
.10415 .16716 L
.09765 .1425 L
.0932 .12446 L
.09167 .11785 L
.08626 .0932 L
.08136 .06854 L
.07698 .04389 L
.07318 .01923 L
Mfstroke
.2 g
.74284 .01923 m
.75888 .04243 L
.75985 .04389 L
.77604 .06854 L
.78353 .08031 L
.79149 .0932 L
.80628 .11785 L
.80819 .1211 L
.82035 .1425 L
.83284 .16527 L
.83384 .16716 L
.84666 .19181 L
.8575 .2135 L
.85893 .21647 L
.87056 .24112 L
.88169 .26578 L
.88215 .26683 L
.89217 .29043 L
.90216 .31509 L
.9068 .32703 L
.91156 .33974 L
.92039 .3644 L
.9287 .38905 L
.93146 .39764 L
.93639 .41371 L
.94351 .43836 L
.95006 .46302 L
.95601 .48767 L
.95611 .48813 L
.96133 .51233 L
.96598 .53698 L
.96993 .56164 L
.97315 .58629 L
.97559 .61095 L
.9772 .6356 L
.97791 .66026 L
.97763 .68491 L
.97625 .70957 L
.97361 .73422 L
.96952 .75888 L
.9637 .78353 L
.95611 .80724 L
.95576 .80819 L
.94509 .83284 L
.93146 .85622 L
.93059 .8575 L
.9101 .88215 L
.9068 .88532 L
.88215 .90401 L
.87748 .9068 L
.8575 .91583 L
.83284 .92254 L
.80819 .92521 L
.78353 .92449 L
.75888 .92086 L
.73422 .91464 L
.71132 .9068 L
.70957 .90609 L
.68491 .89535 L
.66026 .88261 L
.65942 .88215 L
.6356 .86792 L
.61972 .8575 L
.61095 .85138 L
.58629 .83304 L
.58603 .83284 L
.56164 .8129 L
.55615 .80819 L
.53698 .79098 L
.52902 .78353 L
.51233 .76728 L
.50401 .75888 L
.48767 .74176 L
.48072 .73422 L
.46302 .71436 L
.45888 .70957 L
.43836 .68501 L
.43829 .68491 L
.41882 .66026 L
.41371 .65358 L
.40034 .6356 L
.38905 .61994 L
.38276 .61095 L
.36599 .58629 L
.3644 .5839 L
.35003 .56164 L
.33974 .54518 L
.33477 .53698 L
.3202 .51233 L
.31509 .50342 L
.30631 .48767 L
.29301 .46302 L
.29043 .45811 L
.28038 .43836 L
.26828 .41371 L
.26578 .40848 L
.25681 .38905 L
.24587 .3644 L
.24112 .35331 L
.23553 .33974 L
.22573 .31509 L
.21647 .29047 L
.21646 .29043 L
.20782 .26578 L
.1997 .24112 L
.19213 .21647 L
.19181 .2154 L
.18521 .19181 L
.17885 .16716 L
.1731 .1425 L
.16797 .11785 L
.16716 .11364 L
.16355 .0932 L
.15982 .06854 L
.15683 .04389 L
.15461 .01923 L
F
0 g
.74284 .01923 m
.75888 .04243 L
.75985 .04389 L
.77604 .06854 L
.78353 .08031 L
.79149 .0932 L
.80628 .11785 L
.80819 .1211 L
.82035 .1425 L
.83284 .16527 L
.83384 .16716 L
.84666 .19181 L
.8575 .2135 L
.85893 .21647 L
.87056 .24112 L
.88169 .26578 L
.88215 .26683 L
.89217 .29043 L
.90216 .31509 L
.9068 .32703 L
.91156 .33974 L
.92039 .3644 L
.9287 .38905 L
.93146 .39764 L
.93639 .41371 L
.94351 .43836 L
.95006 .46302 L
.95601 .48767 L
.95611 .48813 L
.96133 .51233 L
.96598 .53698 L
.96993 .56164 L
.97315 .58629 L
.97559 .61095 L
.9772 .6356 L
.97791 .66026 L
.97763 .68491 L
.97625 .70957 L
.97361 .73422 L
.96952 .75888 L
.9637 .78353 L
.95611 .80724 L
.95576 .80819 L
.94509 .83284 L
.93146 .85622 L
.93059 .8575 L
.9101 .88215 L
.9068 .88532 L
.88215 .90401 L
.87748 .9068 L
Mistroke
.8575 .91583 L
.83284 .92254 L
.80819 .92521 L
.78353 .92449 L
.75888 .92086 L
.73422 .91464 L
.71132 .9068 L
.70957 .90609 L
.68491 .89535 L
.66026 .88261 L
.65942 .88215 L
.6356 .86792 L
.61972 .8575 L
.61095 .85138 L
.58629 .83304 L
.58603 .83284 L
.56164 .8129 L
.55615 .80819 L
.53698 .79098 L
.52902 .78353 L
.51233 .76728 L
.50401 .75888 L
.48767 .74176 L
.48072 .73422 L
.46302 .71436 L
.45888 .70957 L
.43836 .68501 L
.43829 .68491 L
.41882 .66026 L
.41371 .65358 L
.40034 .6356 L
.38905 .61994 L
.38276 .61095 L
.36599 .58629 L
.3644 .5839 L
.35003 .56164 L
.33974 .54518 L
.33477 .53698 L
.3202 .51233 L
.31509 .50342 L
.30631 .48767 L
.29301 .46302 L
.29043 .45811 L
.28038 .43836 L
.26828 .41371 L
.26578 .40848 L
.25681 .38905 L
.24587 .3644 L
.24112 .35331 L
.23553 .33974 L
Mistroke
.22573 .31509 L
.21647 .29047 L
.21646 .29043 L
.20782 .26578 L
.1997 .24112 L
.19213 .21647 L
.19181 .2154 L
.18521 .19181 L
.17885 .16716 L
.1731 .1425 L
.16797 .11785 L
.16716 .11364 L
.16355 .0932 L
.15982 .06854 L
.15683 .04389 L
.15461 .01923 L
Mfstroke
.3 g
.68866 .01923 m
.70727 .04389 L
.70957 .04702 L
.72482 .06854 L
.73422 .08231 L
.74143 .0932 L
.75716 .11785 L
.75888 .12062 L
.77205 .1425 L
.78353 .16241 L
.78619 .16716 L
.79957 .19181 L
.80819 .20839 L
.81225 .21647 L
.82424 .24112 L
.83284 .25966 L
.83558 .26578 L
.84624 .29043 L
.85628 .31509 L
.8575 .31819 L
.86563 .33974 L
.87436 .3644 L
.88215 .3881 L
.88245 .38905 L
.88983 .41371 L
.89656 .43836 L
.9026 .46302 L
.9068 .48224 L
.9079 .48767 L
.91242 .51233 L
.91615 .53698 L
.91901 .56164 L
.92095 .58629 L
.92187 .61095 L
.92166 .6356 L
.92016 .66026 L
.91718 .68491 L
.91242 .70957 L
.9068 .73012 L
.90546 .73422 L
.89561 .75888 L
.88215 .78274 L
.88162 .78353 L
.86076 .80819 L
.8575 .81114 L
.83284 .82816 L
.82377 .83284 L
.80819 .83792 L
.78353 .84239 L
.75888 .84267 L
.73422 .83947 L
.70957 .83325 L
.70817 .83284 L
.68491 .82433 L
.66026 .81296 L
.65111 .80819 L
.6356 .79928 L
.6111 .78353 L
.61095 .78343 L
.58629 .76545 L
.5779 .75888 L
.56164 .74541 L
.54885 .73422 L
.53698 .72332 L
.52269 .70957 L
.51233 .69915 L
.49873 .68491 L
.48767 .67285 L
.47654 .66026 L
.46302 .64433 L
.45584 .6356 L
.43836 .61348 L
.43642 .61095 L
.41814 .58629 L
.41371 .5801 L
.40088 .56164 L
.38905 .54394 L
.38454 .53698 L
.36907 .51233 L
.3644 .50464 L
.35441 .48767 L
.34048 .46302 L
.33974 .46167 L
.32733 .43836 L
.31509 .41424 L
.31483 .41371 L
.30306 .38905 L
.29191 .3644 L
.29043 .36104 L
.28145 .33974 L
.27161 .31509 L
.26578 .29967 L
.26243 .29043 L
.25391 .26578 L
.24602 .24112 L
.24112 .22468 L
.23881 .21647 L
.2323 .19181 L
.22649 .16716 L
.22141 .1425 L
.2171 .11785 L
.21647 .11395 L
.21363 .0932 L
.21103 .06854 L
.20939 .04389 L
.20879 .01923 L
F
0 g
.68866 .01923 m
.70727 .04389 L
.70957 .04702 L
.72482 .06854 L
.73422 .08231 L
.74143 .0932 L
.75716 .11785 L
.75888 .12062 L
.77205 .1425 L
.78353 .16241 L
.78619 .16716 L
.79957 .19181 L
.80819 .20839 L
.81225 .21647 L
.82424 .24112 L
.83284 .25966 L
.83558 .26578 L
.84624 .29043 L
.85628 .31509 L
.8575 .31819 L
.86563 .33974 L
.87436 .3644 L
.88215 .3881 L
.88245 .38905 L
.88983 .41371 L
.89656 .43836 L
.9026 .46302 L
.9068 .48224 L
.9079 .48767 L
.91242 .51233 L
.91615 .53698 L
.91901 .56164 L
.92095 .58629 L
.92187 .61095 L
.92166 .6356 L
.92016 .66026 L
.91718 .68491 L
.91242 .70957 L
.9068 .73012 L
.90546 .73422 L
.89561 .75888 L
.88215 .78274 L
.88162 .78353 L
.86076 .80819 L
.8575 .81114 L
.83284 .82816 L
.82377 .83284 L
.80819 .83792 L
.78353 .84239 L
.75888 .84267 L
Mistroke
.73422 .83947 L
.70957 .83325 L
.70817 .83284 L
.68491 .82433 L
.66026 .81296 L
.65111 .80819 L
.6356 .79928 L
.6111 .78353 L
.61095 .78343 L
.58629 .76545 L
.5779 .75888 L
.56164 .74541 L
.54885 .73422 L
.53698 .72332 L
.52269 .70957 L
.51233 .69915 L
.49873 .68491 L
.48767 .67285 L
.47654 .66026 L
.46302 .64433 L
.45584 .6356 L
.43836 .61348 L
.43642 .61095 L
.41814 .58629 L
.41371 .5801 L
.40088 .56164 L
.38905 .54394 L
.38454 .53698 L
.36907 .51233 L
.3644 .50464 L
.35441 .48767 L
.34048 .46302 L
.33974 .46167 L
.32733 .43836 L
.31509 .41424 L
.31483 .41371 L
.30306 .38905 L
.29191 .3644 L
.29043 .36104 L
.28145 .33974 L
.27161 .31509 L
.26578 .29967 L
.26243 .29043 L
.25391 .26578 L
.24602 .24112 L
.24112 .22468 L
.23881 .21647 L
.2323 .19181 L
.22649 .16716 L
.22141 .1425 L
Mistroke
.2171 .11785 L
.21647 .11395 L
.21363 .0932 L
.21103 .06854 L
.20939 .04389 L
.20879 .01923 L
Mfstroke
.4 g
.64301 .01923 m
.66026 .03972 L
.66363 .04389 L
.68281 .06854 L
.68491 .07135 L
.70073 .0932 L
.70957 .10595 L
.71754 .11785 L
.73334 .1425 L
.73422 .14393 L
.74818 .16716 L
.75888 .18587 L
.76216 .19181 L
.7753 .21647 L
.78353 .23271 L
.78765 .24112 L
.79922 .26578 L
.80819 .28605 L
.81005 .29043 L
.82012 .31509 L
.82947 .33974 L
.83284 .34913 L
.83807 .3644 L
.84592 .38905 L
.85301 .41371 L
.8575 .43089 L
.85931 .43836 L
.86478 .46302 L
.86939 .48767 L
.87309 .51233 L
.8758 .53698 L
.87742 .56164 L
.87783 .58629 L
.87687 .61095 L
.87428 .6356 L
.86975 .66026 L
.86272 .68491 L
.8575 .69846 L
.85228 .70957 L
.83656 .73422 L
.83284 .73869 L
.81033 .75888 L
.80819 .76026 L
.78353 .7721 L
.75888 .77742 L
.73422 .77785 L
.70957 .77432 L
.68491 .76742 L
.66302 .75888 L
.66026 .75753 L
.6356 .74492 L
.61771 .73422 L
.61095 .72978 L
.58629 .71221 L
.58284 .70957 L
.56164 .69227 L
.55319 .68491 L
.53698 .66999 L
.52696 .66026 L
.51233 .64533 L
.50322 .6356 L
.48767 .61821 L
.48144 .61095 L
.46302 .58851 L
.46126 .58629 L
.44247 .56164 L
.43836 .55602 L
.4249 .53698 L
.41371 .52044 L
.4084 .51233 L
.39289 .48767 L
.38905 .48134 L
.37831 .46302 L
.36457 .43836 L
.3644 .43804 L
.35168 .41371 L
.33974 .38945 L
.33955 .38905 L
.32822 .3644 L
.31761 .33974 L
.31509 .33364 L
.30775 .31509 L
.29863 .29043 L
.29043 .26638 L
.29024 .26578 L
.28262 .24112 L
.27577 .21647 L
.2697 .19181 L
.26578 .17378 L
.26447 .16716 L
.26013 .1425 L
.25672 .11785 L
.25433 .0932 L
.25305 .06854 L
.25303 .04389 L
.25444 .01923 L
F
0 g
.64301 .01923 m
.66026 .03972 L
.66363 .04389 L
.68281 .06854 L
.68491 .07135 L
.70073 .0932 L
.70957 .10595 L
.71754 .11785 L
.73334 .1425 L
.73422 .14393 L
.74818 .16716 L
.75888 .18587 L
.76216 .19181 L
.7753 .21647 L
.78353 .23271 L
.78765 .24112 L
.79922 .26578 L
.80819 .28605 L
.81005 .29043 L
.82012 .31509 L
.82947 .33974 L
.83284 .34913 L
.83807 .3644 L
.84592 .38905 L
.85301 .41371 L
.8575 .43089 L
.85931 .43836 L
.86478 .46302 L
.86939 .48767 L
.87309 .51233 L
.8758 .53698 L
.87742 .56164 L
.87783 .58629 L
.87687 .61095 L
.87428 .6356 L
.86975 .66026 L
.86272 .68491 L
.8575 .69846 L
.85228 .70957 L
.83656 .73422 L
.83284 .73869 L
.81033 .75888 L
.80819 .76026 L
.78353 .7721 L
.75888 .77742 L
.73422 .77785 L
.70957 .77432 L
.68491 .76742 L
.66302 .75888 L
.66026 .75753 L
Mistroke
.6356 .74492 L
.61771 .73422 L
.61095 .72978 L
.58629 .71221 L
.58284 .70957 L
.56164 .69227 L
.55319 .68491 L
.53698 .66999 L
.52696 .66026 L
.51233 .64533 L
.50322 .6356 L
.48767 .61821 L
.48144 .61095 L
.46302 .58851 L
.46126 .58629 L
.44247 .56164 L
.43836 .55602 L
.4249 .53698 L
.41371 .52044 L
.4084 .51233 L
.39289 .48767 L
.38905 .48134 L
.37831 .46302 L
.36457 .43836 L
.3644 .43804 L
.35168 .41371 L
.33974 .38945 L
.33955 .38905 L
.32822 .3644 L
.31761 .33974 L
.31509 .33364 L
.30775 .31509 L
.29863 .29043 L
.29043 .26638 L
.29024 .26578 L
.28262 .24112 L
.27577 .21647 L
.2697 .19181 L
.26578 .17378 L
.26447 .16716 L
.26013 .1425 L
.25672 .11785 L
.25433 .0932 L
.25305 .06854 L
.25303 .04389 L
.25444 .01923 L
Mfstroke
.5 g
.59924 .01923 m
.61095 .03117 L
.62281 .04389 L
.6356 .05836 L
.64422 .06854 L
.66026 .08851 L
.66387 .0932 L
.68205 .11785 L
.68491 .1219 L
.69893 .1425 L
.70957 .15899 L
.71465 .16716 L
.72932 .19181 L
.73422 .20045 L
.74299 .21647 L
.75575 .24112 L
.75888 .24745 L
.7676 .26578 L
.7786 .29043 L
.78353 .30215 L
.78874 .31509 L
.79805 .33974 L
.80651 .3644 L
.80819 .36957 L
.81411 .38905 L
.82083 .41371 L
.82664 .43836 L
.83147 .46302 L
.83284 .47072 L
.83528 .48767 L
.83795 .51233 L
.83938 .53698 L
.83939 .56164 L
.83773 .58629 L
.83405 .61095 L
.83284 .61689 L
.82778 .6356 L
.81788 .66026 L
.80819 .67674 L
.80215 .68491 L
.78353 .70265 L
.77376 .70957 L
.75888 .71584 L
.73422 .72133 L
.70957 .72129 L
.68491 .71686 L
.6617 .70957 L
.66026 .70875 L
.6356 .69739 L
.61379 .68491 L
.61095 .68307 L
.58629 .66594 L
.57883 .66026 L
.56164 .64612 L
.54971 .6356 L
.53698 .62362 L
.52424 .61095 L
.51233 .5984 L
.50136 .58629 L
.48767 .57035 L
.48051 .56164 L
.46302 .53925 L
.46131 .53698 L
.44354 .51233 L
.43836 .50479 L
.42702 .48767 L
.41371 .46648 L
.41161 .46302 L
.39725 .43836 L
.38905 .42349 L
.38385 .41371 L
.37137 .38905 L
.3644 .37447 L
.35977 .3644 L
.34903 .33974 L
.33974 .31669 L
.33913 .31509 L
.33008 .29043 L
.32187 .26578 L
.31509 .24315 L
.31452 .24112 L
.30807 .21647 L
.30255 .19181 L
.29801 .16716 L
.29453 .1425 L
.29221 .11785 L
.29118 .0932 L
.29164 .06854 L
.29385 .04389 L
.29822 .01923 L
F
0 g
.59924 .01923 m
.61095 .03117 L
.62281 .04389 L
.6356 .05836 L
.64422 .06854 L
.66026 .08851 L
.66387 .0932 L
.68205 .11785 L
.68491 .1219 L
.69893 .1425 L
.70957 .15899 L
.71465 .16716 L
.72932 .19181 L
.73422 .20045 L
.74299 .21647 L
.75575 .24112 L
.75888 .24745 L
.7676 .26578 L
.7786 .29043 L
.78353 .30215 L
.78874 .31509 L
.79805 .33974 L
.80651 .3644 L
.80819 .36957 L
.81411 .38905 L
.82083 .41371 L
.82664 .43836 L
.83147 .46302 L
.83284 .47072 L
.83528 .48767 L
.83795 .51233 L
.83938 .53698 L
.83939 .56164 L
.83773 .58629 L
.83405 .61095 L
.83284 .61689 L
.82778 .6356 L
.81788 .66026 L
.80819 .67674 L
.80215 .68491 L
.78353 .70265 L
.77376 .70957 L
.75888 .71584 L
.73422 .72133 L
.70957 .72129 L
.68491 .71686 L
.6617 .70957 L
.66026 .70875 L
.6356 .69739 L
.61379 .68491 L
Mistroke
.61095 .68307 L
.58629 .66594 L
.57883 .66026 L
.56164 .64612 L
.54971 .6356 L
.53698 .62362 L
.52424 .61095 L
.51233 .5984 L
.50136 .58629 L
.48767 .57035 L
.48051 .56164 L
.46302 .53925 L
.46131 .53698 L
.44354 .51233 L
.43836 .50479 L
.42702 .48767 L
.41371 .46648 L
.41161 .46302 L
.39725 .43836 L
.38905 .42349 L
.38385 .41371 L
.37137 .38905 L
.3644 .37447 L
.35977 .3644 L
.34903 .33974 L
.33974 .31669 L
.33913 .31509 L
.33008 .29043 L
.32187 .26578 L
.31509 .24315 L
.31452 .24112 L
.30807 .21647 L
.30255 .19181 L
.29801 .16716 L
.29453 .1425 L
.29221 .11785 L
.29118 .0932 L
.29164 .06854 L
.29385 .04389 L
.29822 .01923 L
Mfstroke
.6 g
.55106 .01923 m
.56164 .02773 L
.58025 .04389 L
.58629 .04955 L
.60536 .06854 L
.61095 .07449 L
.62764 .0932 L
.6356 .10268 L
.64776 .11785 L
.66026 .13441 L
.66611 .1425 L
.68298 .16716 L
.68491 .17012 L
.69852 .19181 L
.70957 .21061 L
.71287 .21647 L
.72612 .24112 L
.73422 .25726 L
.73832 .26578 L
.74953 .29043 L
.75888 .31287 L
.75975 .31509 L
.76901 .33974 L
.7773 .3644 L
.78353 .38518 L
.7846 .38905 L
.79087 .41371 L
.79606 .43836 L
.80008 .46302 L
.80283 .48767 L
.80414 .51233 L
.80378 .53698 L
.8014 .56164 L
.79643 .58629 L
.7878 .61095 L
.78353 .61965 L
.77338 .6356 L
.75888 .65043 L
.74537 .66026 L
.73422 .66452 L
.70957 .66966 L
.68491 .66864 L
.66026 .66285 L
.65172 .66026 L
.6356 .65306 L
.61095 .63975 L
.60421 .6356 L
.58629 .62318 L
.57046 .61095 L
.56164 .60349 L
.54267 .58629 L
.53698 .58073 L
.5185 .56164 L
.51233 .55483 L
.49691 .53698 L
.48767 .52561 L
.47735 .51233 L
.46302 .49274 L
.45946 .48767 L
.443 .46302 L
.43836 .45569 L
.42783 .43836 L
.41381 .41371 L
.41371 .41352 L
.40088 .38905 L
.38905 .36457 L
.38898 .3644 L
.37806 .33974 L
.36812 .31509 L
.3644 .3052 L
.35915 .29043 L
.35115 .26578 L
.34415 .24112 L
.33974 .22341 L
.3382 .21647 L
.33335 .19181 L
.32969 .16716 L
.32734 .1425 L
.3265 .11785 L
.32742 .0932 L
.3305 .06854 L
.33643 .04389 L
.33974 .03489 L
.3464 .01923 L
F
0 g
.55106 .01923 m
.56164 .02773 L
.58025 .04389 L
.58629 .04955 L
.60536 .06854 L
.61095 .07449 L
.62764 .0932 L
.6356 .10268 L
.64776 .11785 L
.66026 .13441 L
.66611 .1425 L
.68298 .16716 L
.68491 .17012 L
.69852 .19181 L
.70957 .21061 L
.71287 .21647 L
.72612 .24112 L
.73422 .25726 L
.73832 .26578 L
.74953 .29043 L
.75888 .31287 L
.75975 .31509 L
.76901 .33974 L
.7773 .3644 L
.78353 .38518 L
.7846 .38905 L
.79087 .41371 L
.79606 .43836 L
.80008 .46302 L
.80283 .48767 L
.80414 .51233 L
.80378 .53698 L
.8014 .56164 L
.79643 .58629 L
.7878 .61095 L
.78353 .61965 L
.77338 .6356 L
.75888 .65043 L
.74537 .66026 L
.73422 .66452 L
.70957 .66966 L
.68491 .66864 L
.66026 .66285 L
.65172 .66026 L
.6356 .65306 L
.61095 .63975 L
.60421 .6356 L
.58629 .62318 L
.57046 .61095 L
.56164 .60349 L
Mistroke
.54267 .58629 L
.53698 .58073 L
.5185 .56164 L
.51233 .55483 L
.49691 .53698 L
.48767 .52561 L
.47735 .51233 L
.46302 .49274 L
.45946 .48767 L
.443 .46302 L
.43836 .45569 L
.42783 .43836 L
.41381 .41371 L
.41371 .41352 L
.40088 .38905 L
.38905 .36457 L
.38898 .3644 L
.37806 .33974 L
.36812 .31509 L
.3644 .3052 L
.35915 .29043 L
.35115 .26578 L
.34415 .24112 L
.33974 .22341 L
.3382 .21647 L
.33335 .19181 L
.32969 .16716 L
.32734 .1425 L
.3265 .11785 L
.32742 .0932 L
.3305 .06854 L
.33643 .04389 L
.33974 .03489 L
.3464 .01923 L
Mfstroke
.7 g
.46361 .01923 m
.48767 .0253 L
.51233 .036 L
.52678 .04389 L
.53698 .0507 L
.56096 .06854 L
.56164 .06911 L
.58629 .09112 L
.58844 .0932 L
.61095 .11678 L
.6119 .11785 L
.63261 .1425 L
.6356 .14633 L
.65117 .16716 L
.66026 .18023 L
.66795 .19181 L
.68322 .21647 L
.68491 .21935 L
.69714 .24112 L
.70957 .26531 L
.70979 .26578 L
.72128 .29043 L
.73161 .31509 L
.73422 .32176 L
.74081 .33974 L
.74888 .3644 L
.75578 .38905 L
.75888 .40161 L
.76144 .41371 L
.76579 .43836 L
.76868 .46302 L
.76989 .48767 L
.76909 .51233 L
.76574 .53698 L
.75888 .56144 L
.7588 .56164 L
.74635 .58629 L
.73422 .60002 L
.72093 .61095 L
.70957 .61497 L
.68491 .61942 L
.66026 .61702 L
.63957 .61095 L
.6356 .60942 L
.61095 .59746 L
.59273 .58629 L
.58629 .58161 L
.56164 .5621 L
.56109 .56164 L
.53698 .53901 L
.53498 .53698 L
.51243 .51233 L
.51233 .5122 L
.49241 .48767 L
.48767 .48141 L
.47441 .46302 L
.46302 .44604 L
.45809 .43836 L
.44323 .41371 L
.43836 .40509 L
.4297 .38905 L
.4174 .3644 L
.41371 .35651 L
.40626 .33974 L
.39626 .31509 L
.38905 .2953 L
.3874 .29043 L
.37967 .26578 L
.37313 .24112 L
.36784 .21647 L
.3644 .19577 L
.36392 .19181 L
.36151 .16716 L
.36086 .1425 L
.36235 .11785 L
.3644 .10155 L
.36661 .0932 L
.37479 .06854 L
.38905 .04536 L
.39017 .04389 L
.41371 .02574 L
.43386 .01923 L
F
0 g
.46361 .01923 m
.48767 .0253 L
.51233 .036 L
.52678 .04389 L
.53698 .0507 L
.56096 .06854 L
.56164 .06911 L
.58629 .09112 L
.58844 .0932 L
.61095 .11678 L
.6119 .11785 L
.63261 .1425 L
.6356 .14633 L
.65117 .16716 L
.66026 .18023 L
.66795 .19181 L
.68322 .21647 L
.68491 .21935 L
.69714 .24112 L
.70957 .26531 L
.70979 .26578 L
.72128 .29043 L
.73161 .31509 L
.73422 .32176 L
.74081 .33974 L
.74888 .3644 L
.75578 .38905 L
.75888 .40161 L
.76144 .41371 L
.76579 .43836 L
.76868 .46302 L
.76989 .48767 L
.76909 .51233 L
.76574 .53698 L
.75888 .56144 L
.7588 .56164 L
.74635 .58629 L
.73422 .60002 L
.72093 .61095 L
.70957 .61497 L
.68491 .61942 L
.66026 .61702 L
.63957 .61095 L
.6356 .60942 L
.61095 .59746 L
.59273 .58629 L
.58629 .58161 L
.56164 .5621 L
.56109 .56164 L
.53698 .53901 L
Mistroke
.53498 .53698 L
.51243 .51233 L
.51233 .5122 L
.49241 .48767 L
.48767 .48141 L
.47441 .46302 L
.46302 .44604 L
.45809 .43836 L
.44323 .41371 L
.43836 .40509 L
.4297 .38905 L
.4174 .3644 L
.41371 .35651 L
.40626 .33974 L
.39626 .31509 L
.38905 .2953 L
.3874 .29043 L
.37967 .26578 L
.37313 .24112 L
.36784 .21647 L
.3644 .19577 L
.36392 .19181 L
.36151 .16716 L
.36086 .1425 L
.36235 .11785 L
.3644 .10155 L
.36661 .0932 L
.37479 .06854 L
.38905 .04536 L
.39017 .04389 L
.41371 .02574 L
.43386 .01923 L
Mfstroke
.8 g
.43836 .07655 m
.46302 .06977 L
.48767 .07179 L
.51233 .08007 L
.53667 .0932 L
.53698 .09346 L
.56164 .11138 L
.56945 .11785 L
.58629 .13364 L
.59502 .1425 L
.61095 .16037 L
.61663 .16716 L
.63549 .19181 L
.6356 .19197 L
.65226 .21647 L
.66026 .22937 L
.66718 .24112 L
.68052 .26578 L
.68491 .27457 L
.69239 .29043 L
.70288 .31509 L
.70957 .33278 L
.71199 .33974 L
.71975 .3644 L
.72606 .38905 L
.73081 .41371 L
.73382 .43836 L
.73422 .44369 L
.73482 .46302 L
.73422 .47809 L
.73329 .48767 L
.72837 .51233 L
.71767 .53698 L
.70957 .54752 L
.69384 .56164 L
.68491 .56417 L
.66026 .56788 L
.6356 .56378 L
.62901 .56164 L
.61095 .55387 L
.58629 .53908 L
.58321 .53698 L
.56164 .51984 L
.55316 .51233 L
.53698 .49625 L
.52895 .48767 L
.51233 .46812 L
.50825 .46302 L
.49004 .43836 L
.48767 .4349 L
.47386 .41371 L
.46302 .39542 L
.45944 .38905 L
.44653 .3644 L
.43836 .34712 L
.43509 .33974 L
.42499 .31509 L
.41629 .29043 L
.41371 .28241 L
.40896 .26578 L
.40308 .24112 L
.3988 .21647 L
.39633 .19181 L
.396 .16716 L
.39841 .1425 L
.40479 .11785 L
.41371 .09976 L
.41775 .0932 L
F
0 g
.43836 .07655 m
.46302 .06977 L
.48767 .07179 L
.51233 .08007 L
.53667 .0932 L
.53698 .09346 L
.56164 .11138 L
.56945 .11785 L
.58629 .13364 L
.59502 .1425 L
.61095 .16037 L
.61663 .16716 L
.63549 .19181 L
.6356 .19197 L
.65226 .21647 L
.66026 .22937 L
.66718 .24112 L
.68052 .26578 L
.68491 .27457 L
.69239 .29043 L
.70288 .31509 L
.70957 .33278 L
.71199 .33974 L
.71975 .3644 L
.72606 .38905 L
.73081 .41371 L
.73382 .43836 L
.73422 .44369 L
.73482 .46302 L
.73422 .47809 L
.73329 .48767 L
.72837 .51233 L
.71767 .53698 L
.70957 .54752 L
.69384 .56164 L
.68491 .56417 L
.66026 .56788 L
.6356 .56378 L
.62901 .56164 L
.61095 .55387 L
.58629 .53908 L
.58321 .53698 L
.56164 .51984 L
.55316 .51233 L
.53698 .49625 L
.52895 .48767 L
.51233 .46812 L
.50825 .46302 L
.49004 .43836 L
.48767 .4349 L
Mistroke
.47386 .41371 L
.46302 .39542 L
.45944 .38905 L
.44653 .3644 L
.43836 .34712 L
.43509 .33974 L
.42499 .31509 L
.41629 .29043 L
.41371 .28241 L
.40896 .26578 L
.40308 .24112 L
.3988 .21647 L
.39633 .19181 L
.396 .16716 L
.39841 .1425 L
.40479 .11785 L
.41371 .09976 L
.41775 .0932 L
.43836 .07655 L
Mfstroke
.9 g
.46302 .13362 m
.48767 .12591 L
.51233 .12947 L
.53698 .14049 L
.54082 .1425 L
.56164 .15755 L
.57321 .16716 L
.58629 .18026 L
.59708 .19181 L
.61095 .20885 L
.61677 .21647 L
.63362 .24112 L
.6356 .24433 L
.64822 .26578 L
.66026 .28948 L
.66071 .29043 L
.67152 .31509 L
.68049 .33974 L
.68491 .35391 L
.68764 .3644 L
.69294 .38905 L
.69605 .41371 L
.69646 .43836 L
.69313 .46302 L
.68491 .48483 L
.68384 .48767 L
.66026 .50783 L
.6356 .5114 L
.61095 .50539 L
.58629 .49245 L
.57869 .48767 L
.56164 .47367 L
.54987 .46302 L
.53698 .44923 L
.52745 .43836 L
.51233 .41872 L
.50871 .41371 L
.49253 .38905 L
.48767 .38078 L
.4786 .3644 L
.4666 .33974 L
.46302 .33159 L
.45638 .31509 L
.44789 .29043 L
.44129 .26578 L
.43836 .254 L
.43668 .24112 L
.43432 .21647 L
.43492 .19181 L
.43836 .17234 L
.43967 .16716 L
.4514 .1425 L
F
0 g
.46302 .13362 m
.48767 .12591 L
.51233 .12947 L
.53698 .14049 L
.54082 .1425 L
.56164 .15755 L
.57321 .16716 L
.58629 .18026 L
.59708 .19181 L
.61095 .20885 L
.61677 .21647 L
.63362 .24112 L
.6356 .24433 L
.64822 .26578 L
.66026 .28948 L
.66071 .29043 L
.67152 .31509 L
.68049 .33974 L
.68491 .35391 L
.68764 .3644 L
.69294 .38905 L
.69605 .41371 L
.69646 .43836 L
.69313 .46302 L
.68491 .48483 L
.68384 .48767 L
.66026 .50783 L
.6356 .5114 L
.61095 .50539 L
.58629 .49245 L
.57869 .48767 L
.56164 .47367 L
.54987 .46302 L
.53698 .44923 L
.52745 .43836 L
.51233 .41872 L
.50871 .41371 L
.49253 .38905 L
.48767 .38078 L
.4786 .3644 L
.4666 .33974 L
.46302 .33159 L
.45638 .31509 L
.44789 .29043 L
.44129 .26578 L
.43836 .254 L
.43668 .24112 L
.43432 .21647 L
.43492 .19181 L
.43836 .17234 L
Mistroke
.43967 .16716 L
.4514 .1425 L
.46302 .13362 L
Mfstroke
1 g
.51233 .19643 m
.53698 .20032 L
.56164 .2153 L
.56335 .21647 L
.58629 .23917 L
.58806 .24112 L
.60691 .26578 L
.61095 .27287 L
.62114 .29043 L
.63251 .31509 L
.6356 .32268 L
.64099 .33974 L
.64698 .3644 L
.64954 .38905 L
.6472 .41371 L
.6356 .4331 L
.62649 .43836 L
.61095 .44119 L
.5974 .43836 L
.58629 .43364 L
.56164 .41593 L
.55892 .41371 L
.53698 .38924 L
.53683 .38905 L
.51916 .3644 L
.51233 .35178 L
.50605 .33974 L
.49523 .31509 L
.48787 .29043 L
.48767 .28952 L
.48296 .26578 L
.48191 .24112 L
.48767 .21717 L
.48799 .21647 L
F
0 g
.51233 .19643 m
.53698 .20032 L
.56164 .2153 L
.56335 .21647 L
.58629 .23917 L
.58806 .24112 L
.60691 .26578 L
.61095 .27287 L
.62114 .29043 L
.63251 .31509 L
.6356 .32268 L
.64099 .33974 L
.64698 .3644 L
.64954 .38905 L
.6472 .41371 L
.6356 .4331 L
.62649 .43836 L
.61095 .44119 L
.5974 .43836 L
.58629 .43364 L
.56164 .41593 L
.55892 .41371 L
.53698 .38924 L
.53683 .38905 L
.51916 .3644 L
.51233 .35178 L
.50605 .33974 L
.49523 .31509 L
.48787 .29043 L
.48767 .28952 L
.48296 .26578 L
.48191 .24112 L
.48767 .21717 L
.48799 .21647 L
.51233 .19643 L
s
.98077 .33008 m
.97505 .31509 L
.96515 .29043 L
.95611 .26904 L
.9547 .26578 L
.94381 .24112 L
.93259 .21647 L
.93146 .21404 L
.92076 .19181 L
.90857 .16716 L
.9068 .16365 L
.89578 .1425 L
.88261 .11785 L
.88215 .11701 L
.86879 .0932 L
.8575 .07352 L
.85455 .06854 L
.83967 .04389 L
.83284 .03274 L
.82426 .01923 L
.98077 .01923 L
F
.98077 .33008 m
.97505 .31509 L
.96515 .29043 L
.95611 .26904 L
.9547 .26578 L
.94381 .24112 L
.93259 .21647 L
.93146 .21404 L
.92076 .19181 L
.90857 .16716 L
.9068 .16365 L
.89578 .1425 L
.88261 .11785 L
.88215 .11701 L
.86879 .0932 L
.8575 .07352 L
.85455 .06854 L
.83967 .04389 L
.83284 .03274 L
.82426 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.62402 .98077 m
.61095 .97513 L
.58629 .96349 L
.57192 .95611 L
.56164 .95059 L
.53698 .9366 L
.52834 .93146 L
.51233 .92145 L
.49 .9068 L
.48767 .90521 L
.46302 .88774 L
.4554 .88215 L
.43836 .86913 L
.42364 .8575 L
.41371 .84935 L
.39418 .83284 L
.38905 .82835 L
.36666 .80819 L
.3644 .80609 L
.34081 .78353 L
.33974 .78248 L
.31644 .75888 L
.31509 .75747 L
.2934 .73422 L
.29043 .73095 L
.27158 .70957 L
.26578 .70281 L
.25088 .68491 L
.24112 .67289 L
.23121 .66026 L
.21647 .641 L
.21249 .6356 L
.19471 .61095 L
.19181 .60684 L
.17789 .58629 L
.16716 .57001 L
.16187 .56164 L
.14669 .53698 L
.1425 .52999 L
.13239 .51233 L
.11879 .48767 L
.11785 .48591 L
.10614 .46302 L
.09415 .43836 L
.0932 .43634 L
.0831 .41371 L
.07275 .38905 L
.06854 .37849 L
.06328 .3644 L
.05464 .33974 L
.04681 .31509 L
.04389 .30514 L
.03986 .29043 L
.03386 .26578 L
.02887 .24112 L
.02493 .21647 L
.02211 .19181 L
.02047 .16716 L
.02013 .1425 L
.02124 .11785 L
.024 .0932 L
.02866 .06854 L
.03559 .04389 L
.04389 .02247 L
.04531 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62402 .98077 m
.61095 .97513 L
.58629 .96349 L
.57192 .95611 L
.56164 .95059 L
.53698 .9366 L
.52834 .93146 L
.51233 .92145 L
.49 .9068 L
.48767 .90521 L
.46302 .88774 L
.4554 .88215 L
.43836 .86913 L
.42364 .8575 L
.41371 .84935 L
.39418 .83284 L
.38905 .82835 L
.36666 .80819 L
.3644 .80609 L
.34081 .78353 L
.33974 .78248 L
.31644 .75888 L
.31509 .75747 L
.2934 .73422 L
.29043 .73095 L
.27158 .70957 L
.26578 .70281 L
.25088 .68491 L
.24112 .67289 L
.23121 .66026 L
.21647 .641 L
.21249 .6356 L
.19471 .61095 L
.19181 .60684 L
.17789 .58629 L
.16716 .57001 L
.16187 .56164 L
.14669 .53698 L
.1425 .52999 L
.13239 .51233 L
.11879 .48767 L
.11785 .48591 L
.10614 .46302 L
.09415 .43836 L
.0932 .43634 L
.0831 .41371 L
.07275 .38905 L
.06854 .37849 L
.06328 .3644 L
.05464 .33974 L
Mistroke
.04681 .31509 L
.04389 .30514 L
.03986 .29043 L
.03386 .26578 L
.02887 .24112 L
.02493 .21647 L
.02211 .19181 L
.02047 .16716 L
.02013 .1425 L
.02124 .11785 L
.024 .0932 L
.02866 .06854 L
.03559 .04389 L
.04389 .02247 L
.04531 .01923 L
Mfstroke
.2 g
.38366 .01923 m
.38905 .021 L
.41371 .02991 L
.43836 .0404 L
.44588 .04389 L
.46302 .05237 L
.48767 .06572 L
.49259 .06854 L
.51233 .08051 L
.5319 .0932 L
.53698 .09665 L
.56164 .11422 L
.56651 .11785 L
.58629 .13322 L
.59773 .1425 L
.61095 .15367 L
.62631 .16716 L
.6356 .17563 L
.65272 .19181 L
.66026 .1992 L
.67728 .21647 L
.68491 .22449 L
.70022 .24112 L
.70957 .25164 L
.72172 .26578 L
.73422 .28085 L
.7419 .29043 L
.75888 .3124 L
.76088 .31509 L
.77869 .33974 L
.78353 .3467 L
.7954 .3644 L
.80819 .38431 L
.81111 .38905 L
.82578 .41371 L
.83284 .42616 L
.83946 .43836 L
.85218 .46302 L
.8575 .47388 L
.8639 .48767 L
.87467 .51233 L
.88215 .5309 L
.88445 .53698 L
.89318 .56164 L
.9009 .58629 L
.9068 .60799 L
.90753 .61095 L
.91297 .6356 L
.91719 .66026 L
.92009 .68491 L
.92153 .70957 L
.92134 .73422 L
.91926 .75888 L
.91497 .78353 L
.90797 .80819 L
.9068 .81147 L
.89746 .83284 L
.88215 .85736 L
.88204 .8575 L
.85873 .88215 L
.8575 .88318 L
.83284 .8997 L
.81791 .9068 L
.80819 .91036 L
.78353 .91677 L
.75888 .91986 L
.73422 .92022 L
.70957 .91823 L
.68491 .91418 L
.66026 .90828 L
.65492 .9068 L
.6356 .90064 L
.61095 .8914 L
.58945 .88215 L
.58629 .88068 L
.56164 .86844 L
.54159 .8575 L
.53698 .85483 L
.51233 .83977 L
.50163 .83284 L
.48767 .82334 L
.46656 .80819 L
.46302 .80553 L
.43836 .78626 L
.435 .78353 L
.41371 .76552 L
.40616 .75888 L
.38905 .74324 L
.37953 .73422 L
.3644 .71936 L
.35478 .70957 L
.33974 .69373 L
.33166 .68491 L
.31509 .66621 L
.31 .66026 L
.29043 .63658 L
.28965 .6356 L
.27057 .61095 L
.26578 .60453 L
.25264 .58629 L
.24112 .56965 L
.23579 .56164 L
.21997 .53698 L
.21647 .53132 L
.20521 .51233 L
.19181 .4885 L
.19137 .48767 L
.17859 .46302 L
.16716 .43936 L
.1667 .43836 L
.15587 .41371 L
.14597 .38905 L
.1425 .37982 L
.13711 .3644 L
.1293 .33974 L
.12254 .31509 L
.11785 .29495 L
.11694 .29043 L
.11258 .26578 L
.10953 .24112 L
.10792 .21647 L
.10792 .19181 L
.10977 .16716 L
.11379 .1425 L
.11785 .12601 L
.12045 .11785 L
.13051 .0932 L
.1425 .07248 L
.14527 .06854 L
.16716 .04413 L
.16744 .04389 L
.19181 .02619 L
.20508 .01923 L
F
0 g
.38366 .01923 m
.38905 .021 L
.41371 .02991 L
.43836 .0404 L
.44588 .04389 L
.46302 .05237 L
.48767 .06572 L
.49259 .06854 L
.51233 .08051 L
.5319 .0932 L
.53698 .09665 L
.56164 .11422 L
.56651 .11785 L
.58629 .13322 L
.59773 .1425 L
.61095 .15367 L
.62631 .16716 L
.6356 .17563 L
.65272 .19181 L
.66026 .1992 L
.67728 .21647 L
.68491 .22449 L
.70022 .24112 L
.70957 .25164 L
.72172 .26578 L
.73422 .28085 L
.7419 .29043 L
.75888 .3124 L
.76088 .31509 L
.77869 .33974 L
.78353 .3467 L
.7954 .3644 L
.80819 .38431 L
.81111 .38905 L
.82578 .41371 L
.83284 .42616 L
.83946 .43836 L
.85218 .46302 L
.8575 .47388 L
.8639 .48767 L
.87467 .51233 L
.88215 .5309 L
.88445 .53698 L
.89318 .56164 L
.9009 .58629 L
.9068 .60799 L
.90753 .61095 L
.91297 .6356 L
.91719 .66026 L
.92009 .68491 L
Mistroke
.92153 .70957 L
.92134 .73422 L
.91926 .75888 L
.91497 .78353 L
.90797 .80819 L
.9068 .81147 L
.89746 .83284 L
.88215 .85736 L
.88204 .8575 L
.85873 .88215 L
.8575 .88318 L
.83284 .8997 L
.81791 .9068 L
.80819 .91036 L
.78353 .91677 L
.75888 .91986 L
.73422 .92022 L
.70957 .91823 L
.68491 .91418 L
.66026 .90828 L
.65492 .9068 L
.6356 .90064 L
.61095 .8914 L
.58945 .88215 L
.58629 .88068 L
.56164 .86844 L
.54159 .8575 L
.53698 .85483 L
.51233 .83977 L
.50163 .83284 L
.48767 .82334 L
.46656 .80819 L
.46302 .80553 L
.43836 .78626 L
.435 .78353 L
.41371 .76552 L
.40616 .75888 L
.38905 .74324 L
.37953 .73422 L
.3644 .71936 L
.35478 .70957 L
.33974 .69373 L
.33166 .68491 L
.31509 .66621 L
.31 .66026 L
.29043 .63658 L
.28965 .6356 L
.27057 .61095 L
.26578 .60453 L
.25264 .58629 L
Mistroke
.24112 .56965 L
.23579 .56164 L
.21997 .53698 L
.21647 .53132 L
.20521 .51233 L
.19181 .4885 L
.19137 .48767 L
.17859 .46302 L
.16716 .43936 L
.1667 .43836 L
.15587 .41371 L
.14597 .38905 L
.1425 .37982 L
.13711 .3644 L
.1293 .33974 L
.12254 .31509 L
.11785 .29495 L
.11694 .29043 L
.11258 .26578 L
.10953 .24112 L
.10792 .21647 L
.10792 .19181 L
.10977 .16716 L
.11379 .1425 L
.11785 .12601 L
.12045 .11785 L
.13051 .0932 L
.1425 .07248 L
.14527 .06854 L
.16716 .04413 L
.16744 .04389 L
.19181 .02619 L
.20508 .01923 L
Mfstroke
.3 g
.29043 .06692 m
.31509 .06513 L
.33974 .06625 L
.35707 .06854 L
.3644 .06985 L
.38905 .07564 L
.41371 .08342 L
.43836 .09301 L
.43881 .0932 L
.46302 .10437 L
.48767 .11736 L
.48855 .11785 L
.51233 .13201 L
.52855 .1425 L
.53698 .14826 L
.56164 .16613 L
.563 .16716 L
.58629 .18567 L
.59364 .19181 L
.61095 .20693 L
.62139 .21647 L
.6356 .23 L
.64682 .24112 L
.66026 .25502 L
.67027 .26578 L
.68491 .28218 L
.69201 .29043 L
.70957 .31175 L
.71221 .31509 L
.73101 .33974 L
.73422 .34414 L
.74848 .3644 L
.75888 .37993 L
.76473 .38905 L
.7798 .41371 L
.78353 .42011 L
.7937 .43836 L
.80649 .46302 L
.80819 .46644 L
.81812 .48767 L
.82865 .51233 L
.83284 .52292 L
.83801 .53698 L
.84618 .56164 L
.85312 .58629 L
.8575 .60477 L
.85873 .61095 L
.86291 .6356 L
.86555 .66026 L
.86644 .68491 L
.86534 .70957 L
.86184 .73422 L
.8575 .75247 L
.85538 .75888 L
.84498 .78353 L
.83284 .80294 L
.82874 .80819 L
.80819 .82822 L
.80195 .83284 L
.78353 .84336 L
.75888 .85233 L
.73422 .85693 L
.72836 .8575 L
.70957 .85812 L
.6953 .8575 L
.68491 .8565 L
.66026 .85246 L
.6356 .84628 L
.61095 .83815 L
.59713 .83284 L
.58629 .82821 L
.56164 .81653 L
.54579 .80819 L
.53698 .80322 L
.51233 .78827 L
.505 .78353 L
.48767 .7717 L
.47004 .75888 L
.46302 .75352 L
.43902 .73422 L
.43836 .73367 L
.41371 .71207 L
.41097 .70957 L
.38905 .68864 L
.3853 .68491 L
.3644 .66323 L
.36164 .66026 L
.33974 .63564 L
.33971 .6356 L
.31936 .61095 L
.31509 .60555 L
.30042 .58629 L
.29043 .57256 L
.28279 .56164 L
.26639 .53698 L
.26578 .53603 L
.25122 .51233 L
.24112 .49485 L
.23717 .48767 L
.22427 .46302 L
.21647 .447 L
.21249 .43836 L
.20185 .41371 L
.19234 .38905 L
.19181 .38762 L
.18405 .3644 L
.17697 .33974 L
.1712 .31509 L
.16716 .29276 L
.16684 .29043 L
.16403 .26578 L
.16293 .24112 L
.16379 .21647 L
.16699 .19181 L
.16716 .19083 L
.17308 .16716 L
.18298 .1425 L
.19181 .12705 L
.1984 .11785 L
.21647 .09889 L
.22354 .0932 L
.24112 .08224 L
.26578 .07226 L
.27803 .06854 L
F
0 g
.29043 .06692 m
.31509 .06513 L
.33974 .06625 L
.35707 .06854 L
.3644 .06985 L
.38905 .07564 L
.41371 .08342 L
.43836 .09301 L
.43881 .0932 L
.46302 .10437 L
.48767 .11736 L
.48855 .11785 L
.51233 .13201 L
.52855 .1425 L
.53698 .14826 L
.56164 .16613 L
.563 .16716 L
.58629 .18567 L
.59364 .19181 L
.61095 .20693 L
.62139 .21647 L
.6356 .23 L
.64682 .24112 L
.66026 .25502 L
.67027 .26578 L
.68491 .28218 L
.69201 .29043 L
.70957 .31175 L
.71221 .31509 L
.73101 .33974 L
.73422 .34414 L
.74848 .3644 L
.75888 .37993 L
.76473 .38905 L
.7798 .41371 L
.78353 .42011 L
.7937 .43836 L
.80649 .46302 L
.80819 .46644 L
.81812 .48767 L
.82865 .51233 L
.83284 .52292 L
.83801 .53698 L
.84618 .56164 L
.85312 .58629 L
.8575 .60477 L
.85873 .61095 L
.86291 .6356 L
.86555 .66026 L
.86644 .68491 L
Mistroke
.86534 .70957 L
.86184 .73422 L
.8575 .75247 L
.85538 .75888 L
.84498 .78353 L
.83284 .80294 L
.82874 .80819 L
.80819 .82822 L
.80195 .83284 L
.78353 .84336 L
.75888 .85233 L
.73422 .85693 L
.72836 .8575 L
.70957 .85812 L
.6953 .8575 L
.68491 .8565 L
.66026 .85246 L
.6356 .84628 L
.61095 .83815 L
.59713 .83284 L
.58629 .82821 L
.56164 .81653 L
.54579 .80819 L
.53698 .80322 L
.51233 .78827 L
.505 .78353 L
.48767 .7717 L
.47004 .75888 L
.46302 .75352 L
.43902 .73422 L
.43836 .73367 L
.41371 .71207 L
.41097 .70957 L
.38905 .68864 L
.3853 .68491 L
.3644 .66323 L
.36164 .66026 L
.33974 .63564 L
.33971 .6356 L
.31936 .61095 L
.31509 .60555 L
.30042 .58629 L
.29043 .57256 L
.28279 .56164 L
.26639 .53698 L
.26578 .53603 L
.25122 .51233 L
.24112 .49485 L
.23717 .48767 L
.22427 .46302 L
Mistroke
.21647 .447 L
.21249 .43836 L
.20185 .41371 L
.19234 .38905 L
.19181 .38762 L
.18405 .3644 L
.17697 .33974 L
.1712 .31509 L
.16716 .29276 L
.16684 .29043 L
.16403 .26578 L
.16293 .24112 L
.16379 .21647 L
.16699 .19181 L
.16716 .19083 L
.17308 .16716 L
.18298 .1425 L
.19181 .12705 L
.1984 .11785 L
.21647 .09889 L
.22354 .0932 L
.24112 .08224 L
.26578 .07226 L
.27803 .06854 L
.29043 .06692 L
Mfstroke
.4 g
.31509 .11617 m
.33974 .11415 L
.3644 .11545 L
.38065 .11785 L
.38905 .11952 L
.41371 .12603 L
.43836 .13472 L
.45681 .1425 L
.46302 .14543 L
.48767 .15807 L
.50352 .16716 L
.51233 .17257 L
.53698 .18892 L
.54109 .19181 L
.56164 .20712 L
.57341 .21647 L
.58629 .22723 L
.60206 .24112 L
.61095 .24934 L
.6279 .26578 L
.6356 .27361 L
.65145 .29043 L
.66026 .30024 L
.67304 .31509 L
.68491 .32958 L
.6929 .33974 L
.70957 .36211 L
.7112 .3644 L
.72804 .38905 L
.73422 .39864 L
.7435 .41371 L
.75766 .43836 L
.75888 .44059 L
.77049 .46302 L
.78207 .48767 L
.78353 .49099 L
.79232 .51233 L
.80126 .53698 L
.80819 .55932 L
.80882 .56164 L
.81491 .58629 L
.81941 .61095 L
.82217 .6356 L
.82294 .66026 L
.82137 .68491 L
.81691 .70957 L
.80866 .73422 L
.80819 .73533 L
.79488 .75888 L
.78353 .77249 L
.77119 .78353 L
.75888 .79167 L
.73422 .80243 L
.70957 .80776 L
.70593 .80819 L
.68491 .8091 L
.66862 .80819 L
.66026 .80723 L
.6356 .80267 L
.61095 .79573 L
.58629 .78665 L
.57882 .78353 L
.56164 .77555 L
.53698 .76256 L
.53055 .75888 L
.51233 .7477 L
.4922 .73422 L
.48767 .73101 L
.46302 .71245 L
.4594 .70957 L
.43836 .69196 L
.43039 .68491 L
.41371 .66945 L
.40426 .66026 L
.38905 .64475 L
.38047 .6356 L
.3644 .61763 L
.35867 .61095 L
.33974 .58773 L
.33862 .58629 L
.32015 .56164 L
.31509 .55451 L
.30316 .53698 L
.29043 .51708 L
.28753 .51233 L
.27325 .48767 L
.26578 .47383 L
.26025 .46302 L
.24855 .43836 L
.24112 .42116 L
.23813 .41371 L
.22905 .38905 L
.22133 .3644 L
.21647 .34602 L
.21506 .33974 L
.21038 .31509 L
.20741 .29043 L
.20641 .26578 L
.20769 .24112 L
.21178 .21647 L
.21647 .19968 L
.21954 .19181 L
.23256 .16716 L
.24112 .15592 L
.25471 .1425 L
.26578 .13446 L
.29043 .1224 L
.30368 .11785 L
F
0 g
.31509 .11617 m
.33974 .11415 L
.3644 .11545 L
.38065 .11785 L
.38905 .11952 L
.41371 .12603 L
.43836 .13472 L
.45681 .1425 L
.46302 .14543 L
.48767 .15807 L
.50352 .16716 L
.51233 .17257 L
.53698 .18892 L
.54109 .19181 L
.56164 .20712 L
.57341 .21647 L
.58629 .22723 L
.60206 .24112 L
.61095 .24934 L
.6279 .26578 L
.6356 .27361 L
.65145 .29043 L
.66026 .30024 L
.67304 .31509 L
.68491 .32958 L
.6929 .33974 L
.70957 .36211 L
.7112 .3644 L
.72804 .38905 L
.73422 .39864 L
.7435 .41371 L
.75766 .43836 L
.75888 .44059 L
.77049 .46302 L
.78207 .48767 L
.78353 .49099 L
.79232 .51233 L
.80126 .53698 L
.80819 .55932 L
.80882 .56164 L
.81491 .58629 L
.81941 .61095 L
.82217 .6356 L
.82294 .66026 L
.82137 .68491 L
.81691 .70957 L
.80866 .73422 L
.80819 .73533 L
.79488 .75888 L
.78353 .77249 L
Mistroke
.77119 .78353 L
.75888 .79167 L
.73422 .80243 L
.70957 .80776 L
.70593 .80819 L
.68491 .8091 L
.66862 .80819 L
.66026 .80723 L
.6356 .80267 L
.61095 .79573 L
.58629 .78665 L
.57882 .78353 L
.56164 .77555 L
.53698 .76256 L
.53055 .75888 L
.51233 .7477 L
.4922 .73422 L
.48767 .73101 L
.46302 .71245 L
.4594 .70957 L
.43836 .69196 L
.43039 .68491 L
.41371 .66945 L
.40426 .66026 L
.38905 .64475 L
.38047 .6356 L
.3644 .61763 L
.35867 .61095 L
.33974 .58773 L
.33862 .58629 L
.32015 .56164 L
.31509 .55451 L
.30316 .53698 L
.29043 .51708 L
.28753 .51233 L
.27325 .48767 L
.26578 .47383 L
.26025 .46302 L
.24855 .43836 L
.24112 .42116 L
.23813 .41371 L
.22905 .38905 L
.22133 .3644 L
.21647 .34602 L
.21506 .33974 L
.21038 .31509 L
.20741 .29043 L
.20641 .26578 L
.20769 .24112 L
.21178 .21647 L
Mistroke
.21647 .19968 L
.21954 .19181 L
.23256 .16716 L
.24112 .15592 L
.25471 .1425 L
.26578 .13446 L
.29043 .1224 L
.30368 .11785 L
.31509 .11617 L
Mfstroke
.5 g
.31509 .16501 m
.33974 .15846 L
.3644 .15672 L
.38905 .15866 L
.41371 .16363 L
.42689 .16716 L
.43836 .17124 L
.46302 .18124 L
.48466 .19181 L
.48767 .19345 L
.51233 .2078 L
.52575 .21647 L
.53698 .22425 L
.55951 .24112 L
.56164 .24282 L
.58629 .26359 L
.58875 .26578 L
.61095 .28671 L
.61469 .29043 L
.6356 .3124 L
.63804 .31509 L
.6592 .33974 L
.66026 .34104 L
.67845 .3644 L
.68491 .37321 L
.69598 .38905 L
.70957 .40991 L
.71191 .41371 L
.72632 .43836 L
.73422 .45307 L
.73925 .46302 L
.75071 .48767 L
.75888 .50751 L
.76069 .51233 L
.76914 .53698 L
.77598 .56164 L
.78108 .58629 L
.78353 .60375 L
.78424 .61095 L
.78518 .6356 L
.78353 .65973 L
.78346 .66026 L
.77835 .68491 L
.7685 .70957 L
.75888 .7248 L
.75085 .73422 L
.73422 .748 L
.71288 .75888 L
.70957 .75995 L
.68491 .76546 L
.66026 .76643 L
.6356 .76387 L
.61177 .75888 L
.61095 .75837 L
.58629 .75028 L
.56164 .73985 L
.55002 .73422 L
.53698 .72723 L
.51233 .71248 L
.50782 .70957 L
.48767 .69562 L
.4734 .68491 L
.46302 .67664 L
.44373 .66026 L
.43836 .65544 L
.41746 .6356 L
.41371 .63185 L
.39384 .61095 L
.38905 .60563 L
.37245 .58629 L
.3644 .57637 L
.353 .56164 L
.33974 .54343 L
.33528 .53698 L
.31917 .51233 L
.31509 .50569 L
.3046 .48767 L
.2915 .46302 L
.29043 .46089 L
.27988 .43836 L
.26972 .41371 L
.26578 .4031 L
.2611 .38905 L
.25408 .3644 L
.24877 .33974 L
.24538 .31509 L
.24416 .29043 L
.24555 .26578 L
.25023 .24112 L
.25946 .21647 L
.26578 .2052 L
.27594 .19181 L
.29043 .17858 L
.30964 .16716 L
F
0 g
.31509 .16501 m
.33974 .15846 L
.3644 .15672 L
.38905 .15866 L
.41371 .16363 L
.42689 .16716 L
.43836 .17124 L
.46302 .18124 L
.48466 .19181 L
.48767 .19345 L
.51233 .2078 L
.52575 .21647 L
.53698 .22425 L
.55951 .24112 L
.56164 .24282 L
.58629 .26359 L
.58875 .26578 L
.61095 .28671 L
.61469 .29043 L
.6356 .3124 L
.63804 .31509 L
.6592 .33974 L
.66026 .34104 L
.67845 .3644 L
.68491 .37321 L
.69598 .38905 L
.70957 .40991 L
.71191 .41371 L
.72632 .43836 L
.73422 .45307 L
.73925 .46302 L
.75071 .48767 L
.75888 .50751 L
.76069 .51233 L
.76914 .53698 L
.77598 .56164 L
.78108 .58629 L
.78353 .60375 L
.78424 .61095 L
.78518 .6356 L
.78353 .65973 L
.78346 .66026 L
.77835 .68491 L
.7685 .70957 L
.75888 .7248 L
.75085 .73422 L
.73422 .748 L
.71288 .75888 L
.70957 .75995 L
.68491 .76546 L
Mistroke
.66026 .76643 L
.6356 .76387 L
.61177 .75888 L
.61095 .75837 L
.58629 .75028 L
.56164 .73985 L
.55002 .73422 L
.53698 .72723 L
.51233 .71248 L
.50782 .70957 L
.48767 .69562 L
.4734 .68491 L
.46302 .67664 L
.44373 .66026 L
.43836 .65544 L
.41746 .6356 L
.41371 .63185 L
.39384 .61095 L
.38905 .60563 L
.37245 .58629 L
.3644 .57637 L
.353 .56164 L
.33974 .54343 L
.33528 .53698 L
.31917 .51233 L
.31509 .50569 L
.3046 .48767 L
.2915 .46302 L
.29043 .46089 L
.27988 .43836 L
.26972 .41371 L
.26578 .4031 L
.2611 .38905 L
.25408 .3644 L
.24877 .33974 L
.24538 .31509 L
.24416 .29043 L
.24555 .26578 L
.25023 .24112 L
.25946 .21647 L
.26578 .2052 L
.27594 .19181 L
.29043 .17858 L
.30964 .16716 L
.31509 .16501 L
Mfstroke
.6 g
.33974 .20367 m
.3644 .19724 L
.38905 .19618 L
.41371 .19913 L
.43836 .20538 L
.46302 .21448 L
.46773 .21647 L
.48767 .22618 L
.51233 .24034 L
.51359 .24112 L
.53698 .25692 L
.5489 .26578 L
.56164 .27594 L
.57854 .29043 L
.58629 .29752 L
.60436 .31509 L
.61095 .3219 L
.62725 .33974 L
.6356 .34947 L
.64774 .3644 L
.66026 .38088 L
.66613 .38905 L
.68263 .41371 L
.68491 .41734 L
.69735 .43836 L
.70957 .46137 L
.71038 .46302 L
.72172 .48767 L
.73135 .51233 L
.73422 .52043 L
.7392 .53698 L
.74514 .56164 L
.74896 .58629 L
.75033 .61095 L
.74869 .6356 L
.74309 .66026 L
.73422 .68058 L
.73152 .68491 L
.70957 .7085 L
.70823 .70957 L
.68491 .72134 L
.66026 .72659 L
.6356 .7268 L
.61095 .72317 L
.58629 .71635 L
.56783 .70957 L
.56164 .70674 L
.53698 .69456 L
.52019 .68491 L
.51233 .67994 L
.48767 .6629 L
.48413 .66026 L
.46302 .6434 L
.45396 .6356 L
.43836 .6213 L
.42776 .61095 L
.41371 .59635 L
.40457 .58629 L
.38905 .56811 L
.38383 .56164 L
.36521 .53698 L
.3644 .53584 L
.34851 .51233 L
.33974 .49822 L
.33359 .48767 L
.32037 .46302 L
.31509 .45223 L
.30884 .43836 L
.29901 .41371 L
.29095 .38905 L
.29043 .38746 L
.28479 .3644 L
.28072 .33974 L
.27906 .31509 L
.28032 .29043 L
.28541 .26578 L
.29043 .25179 L
.29611 .24112 L
.31509 .21849 L
.31741 .21647 L
F
0 g
.33974 .20367 m
.3644 .19724 L
.38905 .19618 L
.41371 .19913 L
.43836 .20538 L
.46302 .21448 L
.46773 .21647 L
.48767 .22618 L
.51233 .24034 L
.51359 .24112 L
.53698 .25692 L
.5489 .26578 L
.56164 .27594 L
.57854 .29043 L
.58629 .29752 L
.60436 .31509 L
.61095 .3219 L
.62725 .33974 L
.6356 .34947 L
.64774 .3644 L
.66026 .38088 L
.66613 .38905 L
.68263 .41371 L
.68491 .41734 L
.69735 .43836 L
.70957 .46137 L
.71038 .46302 L
.72172 .48767 L
.73135 .51233 L
.73422 .52043 L
.7392 .53698 L
.74514 .56164 L
.74896 .58629 L
.75033 .61095 L
.74869 .6356 L
.74309 .66026 L
.73422 .68058 L
.73152 .68491 L
.70957 .7085 L
.70823 .70957 L
.68491 .72134 L
.66026 .72659 L
.6356 .7268 L
.61095 .72317 L
.58629 .71635 L
.56783 .70957 L
.56164 .70674 L
.53698 .69456 L
.52019 .68491 L
.51233 .67994 L
Mistroke
.48767 .6629 L
.48413 .66026 L
.46302 .6434 L
.45396 .6356 L
.43836 .6213 L
.42776 .61095 L
.41371 .59635 L
.40457 .58629 L
.38905 .56811 L
.38383 .56164 L
.36521 .53698 L
.3644 .53584 L
.34851 .51233 L
.33974 .49822 L
.33359 .48767 L
.32037 .46302 L
.31509 .45223 L
.30884 .43836 L
.29901 .41371 L
.29095 .38905 L
.29043 .38746 L
.28479 .3644 L
.28072 .33974 L
.27906 .31509 L
.28032 .29043 L
.28541 .26578 L
.29043 .25179 L
.29611 .24112 L
.31509 .21849 L
.31741 .21647 L
.33974 .20367 L
Mfstroke
.7 g
.3644 .24096 m
.38905 .23485 L
.41371 .23478 L
.43836 .23911 L
.44719 .24112 L
.46302 .24699 L
.48767 .25801 L
.50222 .26578 L
.51233 .27193 L
.53698 .28867 L
.53937 .29043 L
.56164 .30828 L
.56943 .31509 L
.58629 .33097 L
.59498 .33974 L
.61095 .35711 L
.61722 .3644 L
.6356 .38746 L
.63679 .38905 L
.65406 .41371 L
.66026 .42337 L
.66921 .43836 L
.68236 .46302 L
.68491 .46821 L
.69354 .48767 L
.70272 .51233 L
.70957 .53612 L
.70976 .53698 L
.71446 .56164 L
.71644 .58629 L
.71501 .61095 L
.70957 .63491 L
.70888 .6356 L
.69511 .66026 L
.68491 .67046 L
.66026 .68407 L
.6576 .68491 L
.6356 .68881 L
.61095 .68795 L
.59417 .68491 L
.58629 .6829 L
.56164 .67439 L
.53698 .6628 L
.53218 .66026 L
.51233 .64835 L
.49371 .6356 L
.48767 .63106 L
.46309 .61095 L
.46302 .61088 L
.43836 .58757 L
.4371 .58629 L
.41451 .56164 L
.41371 .56069 L
.39465 .53698 L
.38905 .52944 L
.37714 .51233 L
.3644 .49214 L
.36177 .48767 L
.34839 .46302 L
.33974 .4448 L
.33699 .43836 L
.32758 .41371 L
.32028 .38905 L
.31531 .3644 L
.31509 .36288 L
.31301 .33974 L
.31401 .31509 L
.31509 .30782 L
.31946 .29043 L
.33215 .26578 L
.33974 .25707 L
.36394 .24112 L
F
0 g
.3644 .24096 m
.38905 .23485 L
.41371 .23478 L
.43836 .23911 L
.44719 .24112 L
.46302 .24699 L
.48767 .25801 L
.50222 .26578 L
.51233 .27193 L
.53698 .28867 L
.53937 .29043 L
.56164 .30828 L
.56943 .31509 L
.58629 .33097 L
.59498 .33974 L
.61095 .35711 L
.61722 .3644 L
.6356 .38746 L
.63679 .38905 L
.65406 .41371 L
.66026 .42337 L
.66921 .43836 L
.68236 .46302 L
.68491 .46821 L
.69354 .48767 L
.70272 .51233 L
.70957 .53612 L
.70976 .53698 L
.71446 .56164 L
.71644 .58629 L
.71501 .61095 L
.70957 .63491 L
.70888 .6356 L
.69511 .66026 L
.68491 .67046 L
.66026 .68407 L
.6576 .68491 L
.6356 .68881 L
.61095 .68795 L
.59417 .68491 L
.58629 .6829 L
.56164 .67439 L
.53698 .6628 L
.53218 .66026 L
.51233 .64835 L
.49371 .6356 L
.48767 .63106 L
.46309 .61095 L
.46302 .61088 L
.43836 .58757 L
Mistroke
.4371 .58629 L
.41451 .56164 L
.41371 .56069 L
.39465 .53698 L
.38905 .52944 L
.37714 .51233 L
.3644 .49214 L
.36177 .48767 L
.34839 .46302 L
.33974 .4448 L
.33699 .43836 L
.32758 .41371 L
.32028 .38905 L
.31531 .3644 L
.31509 .36288 L
.31301 .33974 L
.31401 .31509 L
.31509 .30782 L
.31946 .29043 L
.33215 .26578 L
.33974 .25707 L
.36394 .24112 L
.3644 .24096 L
Mfstroke
.8 g
.38905 .27916 m
.41371 .2734 L
.43836 .27456 L
.46302 .2806 L
.48738 .29043 L
.48767 .29063 L
.51233 .30418 L
.52887 .31509 L
.53698 .32116 L
.55954 .33974 L
.56164 .34165 L
.5848 .3644 L
.58629 .366 L
.60625 .38905 L
.61095 .39499 L
.62466 .41371 L
.6356 .43038 L
.64041 .43836 L
.65375 .46302 L
.66026 .4768 L
.66469 .48767 L
.67322 .51233 L
.67906 .53698 L
.68178 .56164 L
.68059 .58629 L
.67364 .61095 L
.66026 .63068 L
.65577 .6356 L
.6356 .6459 L
.61095 .65008 L
.58629 .64789 L
.56164 .64103 L
.54703 .6356 L
.53698 .63031 L
.51233 .61609 L
.50451 .61095 L
.48767 .59846 L
.47292 .58629 L
.46302 .57728 L
.44717 .56164 L
.43836 .55212 L
.42536 .53698 L
.41371 .52207 L
.40665 .51233 L
.39061 .48767 L
.38905 .48509 L
.377 .46302 L
.36579 .43836 L
.3644 .4352 L
.35699 .41371 L
.35082 .38905 L
.3477 .3644 L
.34838 .33974 L
.35458 .31509 L
.3644 .29775 L
.3707 .29043 L
F
0 g
.38905 .27916 m
.41371 .2734 L
.43836 .27456 L
.46302 .2806 L
.48738 .29043 L
.48767 .29063 L
.51233 .30418 L
.52887 .31509 L
.53698 .32116 L
.55954 .33974 L
.56164 .34165 L
.5848 .3644 L
.58629 .366 L
.60625 .38905 L
.61095 .39499 L
.62466 .41371 L
.6356 .43038 L
.64041 .43836 L
.65375 .46302 L
.66026 .4768 L
.66469 .48767 L
.67322 .51233 L
.67906 .53698 L
.68178 .56164 L
.68059 .58629 L
.67364 .61095 L
.66026 .63068 L
.65577 .6356 L
.6356 .6459 L
.61095 .65008 L
.58629 .64789 L
.56164 .64103 L
.54703 .6356 L
.53698 .63031 L
.51233 .61609 L
.50451 .61095 L
.48767 .59846 L
.47292 .58629 L
.46302 .57728 L
.44717 .56164 L
.43836 .55212 L
.42536 .53698 L
.41371 .52207 L
.40665 .51233 L
.39061 .48767 L
.38905 .48509 L
.377 .46302 L
.36579 .43836 L
.3644 .4352 L
.35699 .41371 L
Mistroke
.35082 .38905 L
.3477 .3644 L
.34838 .33974 L
.35458 .31509 L
.3644 .29775 L
.3707 .29043 L
.38905 .27916 L
Mfstroke
.9 g
.41371 .32195 m
.43836 .31585 L
.46302 .31823 L
.48767 .32644 L
.51233 .33945 L
.51282 .33974 L
.53698 .3568 L
.54626 .3644 L
.56164 .3788 L
.57154 .38905 L
.58629 .40633 L
.59201 .41371 L
.60885 .43836 L
.61095 .44171 L
.62253 .46302 L
.63306 .48767 L
.6356 .49149 L
.64038 .51233 L
.644 .53698 L
.64258 .56164 L
.6356 .5811 L
.63317 .58629 L
.61095 .60344 L
.58629 .60754 L
.56164 .60388 L
.53698 .59468 L
.52013 .58629 L
.51233 .58087 L
.48767 .56259 L
.48652 .56164 L
.46302 .53962 L
.46049 .53698 L
.4395 .51233 L
.43836 .51085 L
.42221 .48767 L
.41371 .47347 L
.40826 .46302 L
.3973 .43836 L
.38966 .41371 L
.38905 .41104 L
.38561 .38905 L
.38639 .3644 L
.38905 .35326 L
.39435 .33974 L
F
0 g
.41371 .32195 m
.43836 .31585 L
.46302 .31823 L
.48767 .32644 L
.51233 .33945 L
.51282 .33974 L
.53698 .3568 L
.54626 .3644 L
.56164 .3788 L
.57154 .38905 L
.58629 .40633 L
.59201 .41371 L
.60885 .43836 L
.61095 .44171 L
.62253 .46302 L
.63306 .48767 L
.6356 .49149 L
.64038 .51233 L
.644 .53698 L
.64258 .56164 L
.6356 .5811 L
.63317 .58629 L
.61095 .60344 L
.58629 .60754 L
.56164 .60388 L
.53698 .59468 L
.52013 .58629 L
.51233 .58087 L
.48767 .56259 L
.48652 .56164 L
.46302 .53962 L
.46049 .53698 L
.4395 .51233 L
.43836 .51085 L
.42221 .48767 L
.41371 .47347 L
.40826 .46302 L
.3973 .43836 L
.38966 .41371 L
.38905 .41104 L
.38561 .38905 L
.38639 .3644 L
.38905 .35326 L
.39435 .33974 L
.41371 .32195 L
s
1 g
.43836 .38495 m
.46302 .3686 L
.48767 .37177 L
.51233 .38339 L
.52232 .38905 L
.53698 .40166 L
.54973 .41371 L
.56164 .42797 L
.5692 .43836 L
.58367 .46302 L
.58629 .46936 L
.59317 .48767 L
.59752 .51233 L
.59283 .53698 L
.58629 .54655 L
.56164 .55489 L
.53698 .54983 L
.51267 .53698 L
.51233 .53678 L
.48767 .51706 L
.48274 .51233 L
.46302 .48858 L
.46237 .48767 L
.44692 .46302 L
.43836 .44349 L
.43724 .43836 L
.4323 .41371 L
.43601 .38905 L
F
0 g
.43836 .38495 m
.46302 .3686 L
.48767 .37177 L
.51233 .38339 L
.52232 .38905 L
.53698 .40166 L
.54973 .41371 L
.56164 .42797 L
.5692 .43836 L
.58367 .46302 L
.58629 .46936 L
.59317 .48767 L
.59752 .51233 L
.59283 .53698 L
.58629 .54655 L
.56164 .55489 L
.53698 .54983 L
.51267 .53698 L
.51233 .53678 L
.48767 .51706 L
.48274 .51233 L
.46302 .48858 L
.46237 .48767 L
.44692 .46302 L
.43836 .44349 L
.43724 .43836 L
.4323 .41371 L
.43601 .38905 L
.43836 .38495 L
s
.98077 .60216 m
.97578 .58629 L
.96724 .56164 L
.95778 .53698 L
.95611 .53285 L
.94748 .51233 L
.93646 .48767 L
.93146 .47692 L
.92463 .46302 L
.91199 .43836 L
.9068 .42856 L
.89855 .41371 L
.88434 .38905 L
.88215 .38534 L
.86923 .3644 L
.8575 .34598 L
.85336 .33974 L
.83659 .31509 L
.83284 .30971 L
.8189 .29043 L
.80819 .27601 L
.80032 .26578 L
.78353 .24449 L
.78079 .24112 L
.7602 .21647 L
.75888 .21493 L
.73847 .19181 L
.73422 .18713 L
.71556 .16716 L
.70957 .16093 L
.69135 .1425 L
.68491 .13619 L
.66568 .11785 L
.66026 .11284 L
.63838 .0932 L
.6356 .09079 L
.61095 .07 L
.60917 .06854 L
.58629 .05047 L
.57768 .04389 L
.56164 .03199 L
.54343 .01923 L
.98077 .01923 L
F
.98077 .60216 m
.97578 .58629 L
.96724 .56164 L
.95778 .53698 L
.95611 .53285 L
.94748 .51233 L
.93646 .48767 L
.93146 .47692 L
.92463 .46302 L
.91199 .43836 L
.9068 .42856 L
.89855 .41371 L
.88434 .38905 L
.88215 .38534 L
.86923 .3644 L
.8575 .34598 L
.85336 .33974 L
.83659 .31509 L
.83284 .30971 L
.8189 .29043 L
.80819 .27601 L
.80032 .26578 L
.78353 .24449 L
.78079 .24112 L
.7602 .21647 L
.75888 .21493 L
.73847 .19181 L
.73422 .18713 L
.71556 .16716 L
.70957 .16093 L
.69135 .1425 L
.68491 .13619 L
.66568 .11785 L
.66026 .11284 L
.63838 .0932 L
.6356 .09079 L
.61095 .07 L
.60917 .06854 L
.58629 .05047 L
.57768 .04389 L
.56164 .03199 L
.54343 .01923 L
s
.98077 .91089 m
.96898 .93146 L
.95611 .949 L
.94995 .95611 L
.93146 .97374 L
.92241 .98077 L
.98077 .98077 L
F
.98077 .91089 m
.96898 .93146 L
.95611 .949 L
.94995 .95611 L
.93146 .97374 L
.92241 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.663 .741 .908 r
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58845 Mtetra
.42372 .58845 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58784 .4504 .5804 Mtetra
.4504 .5804 .45807 .58784 .47147 .58382 .46385 .57636 Mtetra
.46385 .57636 .47147 .58382 .48494 .57979 .47736 .57229 Mtetra
.47736 .57229 .48494 .57979 .49847 .57575 .49093 .56822 Mtetra
.663 .741 .909 r
.49093 .56822 .49847 .57575 .51207 .5717 .50458 .56414 Mtetra
.662 .742 .909 r
.50458 .56414 .51207 .5717 .52574 .56764 .51829 .56006 Mtetra
.661 .742 .91 r
.51829 .56006 .52574 .56764 .53948 .56358 .53207 .55598 Mtetra
.66 .742 .911 r
.53207 .55598 .53948 .56358 .55329 .55953 .54593 .55193 Mtetra
.659 .742 .912 r
.54593 .55193 .55329 .55953 .56717 .5555 .55985 .5479 Mtetra
.657 .743 .914 r
.55985 .5479 .56717 .5555 .58112 .5515 .57385 .54393 Mtetra
.654 .744 .916 r
.57385 .54393 .58112 .5515 .59514 .54755 .58792 .54002 Mtetra
.65 .745 .919 r
.58792 .54002 .59514 .54755 .60924 .54367 .60207 .53621 Mtetra
.646 .746 .922 r
.60207 .53621 .60924 .54367 .62341 .53989 .6163 .53253 Mtetra
.64 .748 .927 r
.6163 .53253 .62341 .53989 .63767 .53622 .63061 .52898 Mtetra
.634 .751 .933 r
.63061 .52898 .63767 .53622 .65201 .53268 .64501 .52562 Mtetra
.625 .754 .939 r
.64501 .52562 .65201 .53268 .66644 .5293 .6595 .52244 Mtetra
.616 .758 .946 r
.6595 .52244 .66644 .5293 .68096 .52609 .67409 .51948 Mtetra
.605 .762 .954 r
.67409 .51948 .68096 .52609 .69557 .52306 .68877 .51673 Mtetra
.593 .768 .963 r
.68877 .51673 .69557 .52306 .71028 .52021 .70356 .51417 Mtetra
.58 .774 .971 r
.70356 .51417 .71028 .52021 .72509 .5175 .71845 .5118 Mtetra
.567 .78 .979 r
.71845 .5118 .72509 .5175 .74 .51493 .73344 .50955 Mtetra
.555 .788 .986 r
.73344 .50955 .74 .51493 .75501 .51242 .74854 .50736 Mtetra
.546 .796 .991 r
.74854 .50736 .75501 .51242 .77012 .50992 .76374 .50515 Mtetra
.541 .805 .994 r
.76374 .50515 .77012 .50992 .78533 .50736 .77904 .50284 Mtetra
.542 .815 .997 r
.77904 .50284 .78533 .50736 .80062 .50465 .79441 .50031 Mtetra
.549 .826 .997 r
.79441 .50031 .80062 .50465 .81598 .5017 .80987 .49747 Mtetra
.563 .836 .996 r
.80987 .49747 .81598 .5017 .83142 .49844 .82539 .49424 Mtetra
.583 .846 .994 r
.82539 .49424 .83142 .49844 .84691 .49479 .84095 .49052 Mtetra
.606 .854 .991 r
.84095 .49052 .84691 .49479 .86245 .4907 .85656 .48627 Mtetra
.631 .859 .985 r
.85656 .48627 .86245 .4907 .87804 .48614 .87221 .48148 Mtetra
.654 .861 .978 r
.87221 .48148 .87804 .48614 .89365 .48111 .88787 .47613 Mtetra
.675 .859 .969 r
.88787 .47613 .89365 .48111 .9093 .47562 .90356 .47027 Mtetra
.692 .853 .96 r
.90356 .47027 .9093 .47562 .92497 .46972 .91928 .46397 Mtetra
.704 .845 .95 r
.91928 .46397 .92497 .46972 .94068 .46348 .93502 .4573 Mtetra
.712 .836 .941 r
.93502 .4573 .94068 .46348 .95643 .45698 .9508 .45036 Mtetra
.716 .825 .933 r
.9508 .45036 .95643 .45698 .97222 .45029 .96662 .44325 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.663 .741 .908 r
.40261 .58505 .41047 .59244 .42372 .58845 .41589 .58102 Mtetra
.41589 .58102 .42372 .58845 .43703 .58443 .42925 .57697 Mtetra
.42925 .57697 .43703 .58443 .4504 .5804 .44266 .5729 Mtetra
.44266 .5729 .4504 .5804 .46385 .57636 .45615 .56882 Mtetra
.45615 .56882 .46385 .57636 .47736 .57229 .4697 .56473 Mtetra
.663 .741 .909 r
.4697 .56473 .47736 .57229 .49093 .56822 .48332 .56063 Mtetra
.662 .742 .909 r
.48332 .56063 .49093 .56822 .50458 .56414 .49701 .55652 Mtetra
.661 .742 .91 r
.49701 .55652 .50458 .56414 .51829 .56006 .51077 .55242 Mtetra
.66 .742 .91 r
.51077 .55242 .51829 .56006 .53207 .55598 .5246 .54834 Mtetra
.659 .742 .912 r
.5246 .54834 .53207 .55598 .54593 .55193 .5385 .54428 Mtetra
.657 .743 .913 r
.5385 .54428 .54593 .55193 .55985 .5479 .55247 .54028 Mtetra
.654 .744 .915 r
.55247 .54028 .55985 .5479 .57385 .54393 .56651 .53634 Mtetra
.651 .745 .918 r
.56651 .53634 .57385 .54393 .58792 .54002 .58064 .53251 Mtetra
.646 .746 .922 r
.58064 .53251 .58792 .54002 .60207 .53621 .59484 .52879 Mtetra
.64 .748 .927 r
.59484 .52879 .60207 .53621 .6163 .53253 .60912 .52524 Mtetra
.633 .75 .932 r
.60912 .52524 .6163 .53253 .63061 .52898 .62349 .52187 Mtetra
.624 .753 .939 r
.62349 .52187 .63061 .52898 .64501 .52562 .63795 .51871 Mtetra
.614 .757 .947 r
.63795 .51871 .64501 .52562 .6595 .52244 .6525 .5158 Mtetra
.601 .761 .955 r
.6525 .5158 .6595 .52244 .67409 .51948 .66716 .51313 Mtetra
.586 .766 .965 r
.66716 .51313 .67409 .51948 .68877 .51673 .68191 .51071 Mtetra
.57 .772 .974 r
.68191 .51071 .68877 .51673 .70356 .51417 .69678 .50852 Mtetra
.553 .778 .982 r
.69678 .50852 .70356 .51417 .71845 .5118 .71176 .50652 Mtetra
.536 .784 .989 r
.71176 .50652 .71845 .5118 .73344 .50955 .72684 .50464 Mtetra
.521 .792 .995 r
.72684 .50464 .73344 .50955 .74854 .50736 .74203 .50281 Mtetra
.509 .8 .998 r
.74203 .50281 .74854 .50736 .76374 .50515 .75732 .50092 Mtetra
.504 .81 1 r
.75732 .50092 .76374 .50515 .77904 .50284 .77271 .49886 Mtetra
.508 .821 1 r
.77271 .49886 .77904 .50284 .79441 .50031 .78818 .49651 Mtetra
.52 .833 1 r
.78818 .49651 .79441 .50031 .80987 .49747 .80372 .49376 Mtetra
.541 .847 .999 r
.80372 .49376 .80987 .49747 .82539 .49424 .81932 .49051 Mtetra
.569 .859 .996 r
.81932 .49051 .82539 .49424 .84095 .49052 .83497 .48668 Mtetra
.6 .868 .993 r
.83497 .48668 .84095 .49052 .85656 .48627 .85064 .48222 Mtetra
.632 .874 .987 r
.85064 .48222 .85656 .48627 .87221 .48148 .86634 .47711 Mtetra
.66 .875 .979 r
.86634 .47711 .87221 .48148 .88787 .47613 .88206 .47139 Mtetra
.684 .871 .969 r
.88206 .47139 .88787 .47613 .90356 .47027 .89779 .46509 Mtetra
.703 .864 .959 r
.89779 .46509 .90356 .47027 .91928 .46397 .91353 .45832 Mtetra
.715 .854 .948 r
.91353 .45832 .91928 .46397 .93502 .4573 .9293 .45116 Mtetra
.723 .843 .938 r
.9293 .45116 .93502 .4573 .9508 .45036 .9451 .44374 Mtetra
.726 .831 .929 r
.9451 .44374 .9508 .45036 .96662 .44325 .96095 .43617 Mtetra
.663 .741 .908 r
.38141 .58164 .38939 .58906 .40261 .58505 .39467 .57759 Mtetra
.39467 .57759 .40261 .58505 .41589 .58102 .408 .57352 Mtetra
.408 .57352 .41589 .58102 .42925 .57697 .42139 .56944 Mtetra
.42139 .56944 .42925 .57697 .44266 .5729 .43485 .56534 Mtetra
.43485 .56534 .44266 .5729 .45615 .56882 .44838 .56122 Mtetra
.663 .741 .909 r
.44838 .56122 .45615 .56882 .4697 .56473 .46198 .5571 Mtetra
.662 .742 .909 r
.46198 .5571 .4697 .56473 .48332 .56063 .47564 .55297 Mtetra
.47564 .55297 .48332 .56063 .49701 .55652 .48938 .54885 Mtetra
.661 .742 .91 r
.48938 .54885 .49701 .55652 .51077 .55242 .50318 .54473 Mtetra
.659 .742 .911 r
.50318 .54473 .51077 .55242 .5246 .54834 .51705 .54065 Mtetra
.657 .743 .913 r
.51705 .54065 .5246 .54834 .5385 .54428 .531 .53661 Mtetra
.655 .743 .915 r
.531 .53661 .5385 .54428 .55247 .54028 .54502 .53264 Mtetra
.651 .744 .918 r
.54502 .53264 .55247 .54028 .56651 .53634 .55911 .52877 Mtetra
.647 .745 .921 r
.55911 .52877 .56651 .53634 .58064 .53251 .57328 .52502 Mtetra
.641 .747 .926 r
.57328 .52502 .58064 .53251 .59484 .52879 .58753 .52144 Mtetra
.633 .749 .932 r
.58753 .52144 .59484 .52879 .60912 .52524 .60187 .51805 Mtetra
.624 .752 .939 r
.60187 .51805 .60912 .52524 .62349 .52187 .6163 .5149 Mtetra
.612 .755 .947 r
.6163 .5149 .62349 .52187 .63795 .51871 .63082 .51201 Mtetra
.598 .759 .956 r
.63082 .51201 .63795 .51871 .6525 .5158 .64544 .50941 Mtetra
.581 .764 .966 r
.64544 .50941 .6525 .5158 .66716 .51313 .66017 .5071 Mtetra
.562 .769 .975 r
.66017 .5071 .66716 .51313 .68191 .51071 .675 .50508 Mtetra
.54 .774 .985 r
.675 .50508 .68191 .51071 .69678 .50852 .68995 .50331 Mtetra
.517 .78 .992 r
.68995 .50331 .69678 .50852 .71176 .50652 .70502 .50173 Mtetra
.494 .785 .997 r
.70502 .50173 .71176 .50652 .72684 .50464 .72019 .50028 Mtetra
.475 .792 .999 r
.72019 .50028 .72684 .50464 .74203 .50281 .73548 .49883 Mtetra
.462 .799 .999 r
.73548 .49883 .74203 .50281 .75732 .50092 .75087 .49727 Mtetra
.458 .809 .998 r
.75087 .49727 .75732 .50092 .77271 .49886 .76636 .49547 Mtetra
.466 .822 .996 r
.76636 .49547 .77271 .49886 .78818 .49651 .78192 .49329 Mtetra
.486 .838 .995 r
.78192 .49329 .78818 .49651 .80372 .49376 .79755 .49059 Mtetra
.517 .855 .995 r
.79755 .49059 .80372 .49376 .81932 .49051 .81323 .48728 Mtetra
.555 .87 .995 r
.81323 .48728 .81932 .49051 .83497 .48668 .82895 .48327 Mtetra
.596 .882 .992 r
.82895 .48327 .83497 .48668 .85064 .48222 .84469 .47852 Mtetra
.635 .889 .986 r
.84469 .47852 .85064 .48222 .86634 .47711 .86044 .47303 Mtetra
.669 .889 .978 r
.86044 .47303 .86634 .47711 .88206 .47139 .8762 .46685 Mtetra
.696 .884 .967 r
.8762 .46685 .88206 .47139 .89779 .46509 .89196 .46004 Mtetra
.715 .874 .956 r
.89196 .46004 .89779 .46509 .91353 .45832 .90773 .45273 Mtetra
.728 .862 .944 r
.90773 .45273 .91353 .45832 .9293 .45116 .92353 .44502 Mtetra
.735 .848 .934 r
.92353 .44502 .9293 .45116 .9451 .44374 .93935 .43707 Mtetra
.737 .835 .925 r
.93935 .43707 .9451 .44374 .96095 .43617 .95522 .429 Mtetra
.663 .741 .908 r
.37336 .57414 .38141 .58164 .39467 .57759 .38666 .57006 Mtetra
.38666 .57006 .39467 .57759 .408 .57352 .40003 .56596 Mtetra
.40003 .56596 .408 .57352 .42139 .56944 .41347 .56184 Mtetra
.41347 .56184 .42139 .56944 .43485 .56534 .42697 .5577 Mtetra
.42697 .5577 .43485 .56534 .44838 .56122 .44054 .55356 Mtetra
.662 .741 .909 r
.44054 .55356 .44838 .56122 .46198 .5571 .45418 .54941 Mtetra
.662 .742 .909 r
.45418 .54941 .46198 .5571 .47564 .55297 .46789 .54525 Mtetra
.661 .742 .91 r
.46789 .54525 .47564 .55297 .48938 .54885 .48167 .54111 Mtetra
.66 .742 .911 r
.48167 .54111 .48938 .54885 .50318 .54473 .49551 .537 Mtetra
.658 .742 .912 r
.49551 .537 .50318 .54473 .51705 .54065 .50943 .53293 Mtetra
.655 .743 .914 r
.50943 .53293 .51705 .54065 .531 .53661 .52343 .52892 Mtetra
.652 .744 .917 r
.52343 .52892 .531 .53661 .54502 .53264 .53749 .525 Mtetra
.648 .745 .92 r
.53749 .525 .54502 .53264 .55911 .52877 .55163 .52122 Mtetra
.642 .746 .925 r
.55163 .52122 .55911 .52877 .57328 .52502 .56586 .51759 Mtetra
.634 .748 .931 r
.56586 .51759 .57328 .52502 .58753 .52144 .58016 .51418 Mtetra
.624 .751 .938 r
.58016 .51418 .58753 .52144 .60187 .51805 .59456 .51101 Mtetra
.612 .754 .946 r
.59456 .51101 .60187 .51805 .6163 .5149 .60904 .50813 Mtetra
.596 .758 .956 r
.60904 .50813 .6163 .5149 .63082 .51201 .62363 .50556 Mtetra
.577 .762 .966 r
.62363 .50556 .63082 .51201 .64544 .50941 .63832 .50334 Mtetra
.555 .766 .976 r
.63832 .50334 .64544 .50941 .66017 .5071 .65312 .50145 Mtetra
.528 .77 .986 r
.65312 .50145 .66017 .5071 .675 .50508 .66804 .49989 Mtetra
.499 .774 .993 r
.66804 .49989 .675 .50508 .68995 .50331 .68308 .4986 Mtetra
.468 .777 .997 r
.68308 .4986 .68995 .50331 .70502 .50173 .69823 .49751 Mtetra
.438 .78 .998 r
.69823 .49751 .70502 .50173 .72019 .50028 .71351 .49652 Mtetra
.414 .784 .994 r
.71351 .49652 .72019 .50028 .73548 .49883 .72889 .49549 Mtetra
.4 .79 .989 r
.72889 .49549 .73548 .49883 .75087 .49727 .74438 .49427 Mtetra
.399 .801 .984 r
.74438 .49427 .75087 .49727 .76636 .49547 .75997 .49272 Mtetra
.415 .817 .982 r
.75997 .49272 .76636 .49547 .78192 .49329 .77563 .49066 Mtetra
.447 .838 .983 r
.77563 .49066 .78192 .49329 .79755 .49059 .79134 .48798 Mtetra
.491 .86 .986 r
.79134 .48798 .79755 .49059 .81323 .48728 .8071 .48454 Mtetra
.543 .881 .988 r
.8071 .48454 .81323 .48728 .82895 .48327 .82289 .48027 Mtetra
.595 .896 .988 r
.82289 .48027 .82895 .48327 .84469 .47852 .83869 .47515 Mtetra
.642 .903 .983 r
.83869 .47515 .84469 .47852 .86044 .47303 .85449 .4692 Mtetra
.681 .902 .975 r
.85449 .4692 .86044 .47303 .8762 .46685 .87028 .46247 Mtetra
.71 .895 .963 r
.87028 .46247 .8762 .46685 .89196 .46004 .88608 .45508 Mtetra
.73 .883 .951 r
.88608 .45508 .89196 .46004 .90773 .45273 .90188 .44715 Mtetra
.741 .868 .939 r
.90188 .44715 .90773 .45273 .92353 .44502 .91769 .43885 Mtetra
.747 .853 .929 r
.91769 .43885 .92353 .44502 .93935 .43707 .93353 .43032 Mtetra
.747 .838 .92 r
.93353 .43032 .93935 .43707 .95522 .429 .94942 .42172 Mtetra
.663 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57006 .37858 .56246 Mtetra
.37858 .56246 .38666 .57006 .40003 .56596 .39199 .55832 Mtetra
.39199 .55832 .40003 .56596 .41347 .56184 .40547 .55417 Mtetra
.40547 .55417 .41347 .56184 .42697 .5577 .41902 .55 Mtetra
.663 .741 .909 r
.41902 .55 .42697 .5577 .44054 .55356 .43263 .54583 Mtetra
.662 .742 .909 r
.43263 .54583 .44054 .55356 .45418 .54941 .44631 .54165 Mtetra
.661 .742 .91 r
.44631 .54165 .45418 .54941 .46789 .54525 .46006 .53748 Mtetra
.66 .742 .911 r
.46006 .53748 .46789 .54525 .48167 .54111 .47389 .53333 Mtetra
.658 .742 .912 r
.47389 .53333 .48167 .54111 .49551 .537 .48778 .52922 Mtetra
.656 .743 .914 r
.48778 .52922 .49551 .537 .50943 .53293 .50174 .52518 Mtetra
.653 .743 .916 r
.50174 .52518 .50943 .53293 .52343 .52892 .51578 .52122 Mtetra
.648 .744 .92 r
.51578 .52122 .52343 .52892 .53749 .525 .52989 .51738 Mtetra
.643 .746 .924 r
.52989 .51738 .53749 .525 .55163 .52122 .54409 .51371 Mtetra
.635 .748 .93 r
.54409 .51371 .55163 .52122 .56586 .51759 .55836 .51025 Mtetra
.625 .75 .937 r
.55836 .51025 .56586 .51759 .58016 .51418 .57272 .50704 Mtetra
.612 .753 .945 r
.57272 .50704 .58016 .51418 .59456 .51101 .58717 .50415 Mtetra
.596 .756 .955 r
.58717 .50415 .59456 .51101 .60904 .50813 .60172 .50159 Mtetra
.575 .759 .965 r
.60172 .50159 .60904 .50813 .62363 .50556 .61637 .49942 Mtetra
.55 .763 .977 r
.61637 .49942 .62363 .50556 .63832 .50334 .63113 .49764 Mtetra
.519 .766 .987 r
.63113 .49764 .63832 .50334 .65312 .50145 .64601 .49625 Mtetra
.483 .768 .994 r
.64601 .49625 .65312 .50145 .66804 .49989 .66102 .49522 Mtetra
.443 .768 .997 r
.66102 .49522 .66804 .49989 .68308 .4986 .67614 .49447 Mtetra
.402 .766 .994 r
.67614 .49447 .68308 .4986 .69823 .49751 .6914 .49392 Mtetra
.364 .763 .985 r
.6914 .49392 .69823 .49751 .71351 .49652 .70677 .49342 Mtetra
.336 .763 .973 r
.70677 .49342 .71351 .49652 .72889 .49549 .72226 .49282 Mtetra
.323 .768 .961 r
.72226 .49282 .72889 .49549 .74438 .49427 .73785 .49195 Mtetra
.33 .781 .954 r
.73785 .49195 .74438 .49427 .75997 .49272 .75354 .49061 Mtetra
.358 .803 .954 r
.75354 .49061 .75997 .49272 .77563 .49066 .76929 .48865 Mtetra
.405 .832 .96 r
.76929 .48865 .77563 .49066 .79134 .48798 .7851 .48591 Mtetra
.466 .863 .97 r
.7851 .48591 .79134 .48798 .8071 .48454 .80094 .48226 Mtetra
.534 .89 .978 r
.80094 .48226 .8071 .48454 .82289 .48027 .81679 .47766 Mtetra
.599 .909 .981 r
.81679 .47766 .82289 .48027 .83869 .47515 .83264 .47208 Mtetra
.654 .917 .978 r
.83264 .47208 .83869 .47515 .85449 .4692 .84848 .46556 Mtetra
.697 .914 .969 r
.84848 .46556 .85449 .4692 .87028 .46247 .86431 .4582 Mtetra
.727 .904 .957 r
.86431 .4582 .87028 .46247 .88608 .45508 .88013 .45014 Mtetra
.746 .889 .944 r
.88013 .45014 .88608 .45508 .90188 .44715 .89595 .44154 Mtetra
.756 .873 .932 r
.89595 .44154 .90188 .44715 .91769 .43885 .91178 .43258 Mtetra
.759 .856 .922 r
.91178 .43258 .91769 .43885 .93353 .43032 .92764 .42344 Mtetra
.758 .839 .913 r
.92764 .42344 .93353 .43032 .94942 .42172 .94355 .41429 Mtetra
.663 .741 .908 r
.35704 .55895 .36524 .56658 .37858 .56246 .37043 .55479 Mtetra
.37043 .55479 .37858 .56246 .39199 .55832 .38388 .55062 Mtetra
.38388 .55062 .39199 .55832 .40547 .55417 .3974 .54643 Mtetra
.3974 .54643 .40547 .55417 .41902 .55 .41099 .54223 Mtetra
.662 .741 .909 r
.41099 .54223 .41902 .55 .43263 .54583 .42464 .53803 Mtetra
.662 .742 .909 r
.42464 .53803 .43263 .54583 .44631 .54165 .43837 .53384 Mtetra
.66 .742 .91 r
.43837 .53384 .44631 .54165 .46006 .53748 .45216 .52965 Mtetra
.659 .742 .911 r
.45216 .52965 .46006 .53748 .47389 .53333 .46603 .52551 Mtetra
.657 .742 .913 r
.46603 .52551 .47389 .53333 .48778 .52922 .47997 .52142 Mtetra
.654 .743 .915 r
.47997 .52142 .48778 .52922 .50174 .52518 .49398 .51741 Mtetra
.65 .744 .919 r
.49398 .51741 .50174 .52518 .51578 .52122 .50806 .51352 Mtetra
.644 .745 .923 r
.50806 .51352 .51578 .52122 .52989 .51738 .52222 .50979 Mtetra
.636 .747 .928 r
.52222 .50979 .52989 .51738 .54409 .51371 .53646 .50627 Mtetra
.626 .749 .935 r
.53646 .50627 .54409 .51371 .55836 .51025 .55079 .50302 Mtetra
.613 .751 .943 r
.55079 .50302 .55836 .51025 .57272 .50704 .5652 .50008 Mtetra
.596 .754 .953 r
.5652 .50008 .57272 .50704 .58717 .50415 .57971 .49751 Mtetra
.575 .757 .964 r
.57971 .49751 .58717 .50415 .60172 .50159 .59432 .49535 Mtetra
.547 .76 .976 r
.59432 .49535 .60172 .50159 .61637 .49942 .60904 .49364 Mtetra
.512 .762 .986 r
.60904 .49364 .61637 .49942 .63113 .49764 .62388 .49239 Mtetra
.47 .761 .994 r
.62388 .49239 .63113 .49764 .64601 .49625 .63884 .49157 Mtetra
.421 .758 .995 r
.63884 .49157 .64601 .49625 .66102 .49522 .65393 .49113 Mtetra
.367 .75 .989 r
.65393 .49113 .66102 .49522 .67614 .49447 .66915 .49099 Mtetra
.314 .74 .973 r
.66915 .49099 .67614 .49447 .6914 .49392 .68451 .49101 Mtetra
.269 .73 .951 r
.68451 .49101 .6914 .49392 .70677 .49342 .69999 .49103 Mtetra
.24 .725 .929 r
.69999 .49103 .70677 .49342 .72226 .49282 .71558 .49087 Mtetra
.233 .73 .913 r
.71558 .49087 .72226 .49282 .73785 .49195 .73128 .49032 Mtetra
.252 .748 .907 r
.73128 .49032 .73785 .49195 .75354 .49061 .74707 .48918 Mtetra
.297 .78 .913 r
.74707 .48918 .75354 .49061 .76929 .48865 .76291 .48724 Mtetra
.364 .821 .929 r
.76291 .48724 .76929 .48865 .7851 .48591 .77881 .48436 Mtetra
.446 .864 .949 r
.77881 .48436 .7851 .48591 .80094 .48226 .79472 .48042 Mtetra
.531 .899 .965 r
.79472 .48042 .80094 .48226 .81679 .47766 .81063 .47538 Mtetra
.608 .922 .973 r
.81063 .47538 .81679 .47766 .83264 .47208 .82653 .46923 Mtetra
.671 .929 .971 r
.82653 .46923 .83264 .47208 .84848 .46556 .84241 .46205 Mtetra
.716 .924 .962 r
.84241 .46205 .84848 .46556 .86431 .4582 .85827 .45398 Mtetra
.745 .911 .949 r
.85827 .45398 .86431 .4582 .88013 .45014 .87411 .44517 Mtetra
.762 .894 .936 r
.87411 .44517 .88013 .45014 .89595 .44154 .88994 .43583 Mtetra
.77 .875 .924 r
.88994 .43583 .89595 .44154 .91178 .43258 .90579 .42617 Mtetra
.771 .856 .914 r
.90579 .42617 .91178 .43258 .92764 .42344 .92166 .41639 Mtetra
.768 .839 .906 r
.92166 .41639 .92764 .42344 .94355 .41429 .93759 .40666 Mtetra
.663 .741 .908 r
.34877 .55125 .35704 .55895 .37043 .55479 .36219 .54706 Mtetra
.36219 .54706 .37043 .55479 .38388 .55062 .37569 .54285 Mtetra
.37569 .54285 .38388 .55062 .3974 .54643 .38925 .53863 Mtetra
.662 .741 .909 r
.38925 .53863 .3974 .54643 .41099 .54223 .40288 .5344 Mtetra
.662 .742 .909 r
.40288 .5344 .41099 .54223 .42464 .53803 .41658 .53018 Mtetra
.661 .742 .91 r
.41658 .53018 .42464 .53803 .43837 .53384 .43035 .52596 Mtetra
.659 .742 .911 r
.43035 .52596 .43837 .53384 .45216 .52965 .44419 .52178 Mtetra
.657 .742 .912 r
.44419 .52178 .45216 .52965 .46603 .52551 .4581 .51764 Mtetra
.655 .743 .915 r
.4581 .51764 .46603 .52551 .47997 .52142 .47208 .51358 Mtetra
.651 .744 .918 r
.47208 .51358 .47997 .52142 .49398 .51741 .48614 .50964 Mtetra
.645 .745 .921 r
.48614 .50964 .49398 .51741 .50806 .51352 .50027 .50585 Mtetra
.638 .746 .927 r
.50027 .50585 .50806 .51352 .52222 .50979 .51448 .50226 Mtetra
.628 .748 .933 r
.51448 .50226 .52222 .50979 .53646 .50627 .52877 .49893 Mtetra
.615 .75 .942 r
.52877 .49893 .53646 .50627 .55079 .50302 .54314 .49593 Mtetra
.598 .753 .951 r
.54314 .49593 .55079 .50302 .5652 .50008 .55761 .49332 Mtetra
.576 .755 .963 r
.55761 .49332 .5652 .50008 .57971 .49751 .57218 .49115 Mtetra
.547 .757 .975 r
.57218 .49115 .57971 .49751 .59432 .49535 .58686 .48946 Mtetra
.509 .758 .986 r
.58686 .48946 .59432 .49535 .60904 .49364 .60165 .48829 Mtetra
.462 .756 .993 r
.60165 .48829 .60904 .49364 .62388 .49239 .61656 .48764 Mtetra
.404 .748 .994 r
.61656 .48764 .62388 .49239 .63884 .49157 .63161 .48746 Mtetra
.338 .735 .983 r
.63161 .48746 .63884 .49157 .65393 .49113 .64679 .48768 Mtetra
.269 .715 .96 r
.64679 .48768 .65393 .49113 .66915 .49099 .66211 .48819 Mtetra
.205 .693 .927 r
.66211 .48819 .66915 .49099 .68451 .49101 .67756 .48883 Mtetra
.157 .674 .89 r
.67756 .48883 .68451 .49101 .69999 .49103 .69315 .4894 Mtetra
.132 .666 .859 r
.69315 .4894 .69999 .49103 .71558 .49087 .70885 .48967 Mtetra
.137 .676 .842 r
.70885 .48967 .71558 .49087 .73128 .49032 .72466 .48941 Mtetra
.173 .705 .844 r
.72466 .48941 .73128 .49032 .74707 .48918 .74054 .48839 Mtetra
.239 .751 .863 r
.74054 .48839 .74707 .48918 .76291 .48724 .75648 .48641 Mtetra
.33 .809 .894 r
.75648 .48641 .76291 .48724 .77881 .48436 .77246 .4833 Mtetra
.434 .865 .927 r
.77246 .4833 .77881 .48436 .79472 .48042 .78844 .47896 Mtetra
.537 .91 .952 r
.78844 .47896 .79472 .48042 .81063 .47538 .80441 .47336 Mtetra
.626 .935 .964 r
.80441 .47336 .81063 .47538 .82653 .46923 .82036 .46653 Mtetra
.692 .94 .963 r
.82036 .46653 .82653 .46923 .84241 .46205 .83627 .4586 Mtetra
.738 .932 .953 r
.83627 .4586 .84241 .46205 .85827 .45398 .85215 .44971 Mtetra
.765 .915 .939 r
.85215 .44971 .85827 .45398 .87411 .44517 .86801 .44009 Mtetra
.779 .895 .926 r
.86801 .44009 .87411 .44517 .88994 .43583 .88385 .42996 Mtetra
.784 .875 .914 r
.88385 .42996 .88994 .43583 .90579 .42617 .89971 .41956 Mtetra
.783 .855 .905 r
.89971 .41956 .90579 .42617 .92166 .41639 .9156 .40911 Mtetra
.777 .837 .898 r
.9156 .40911 .92166 .41639 .93759 .40666 .93155 .39879 Mtetra
.663 .741 .908 r
.34042 .54348 .34877 .55125 .36219 .54706 .35388 .53925 Mtetra
.35388 .53925 .36219 .54706 .37569 .54285 .36742 .53501 Mtetra
.663 .741 .909 r
.36742 .53501 .37569 .54285 .38925 .53863 .38102 .53076 Mtetra
.662 .741 .909 r
.38102 .53076 .38925 .53863 .40288 .5344 .3947 .5265 Mtetra
.661 .742 .91 r
.3947 .5265 .40288 .5344 .41658 .53018 .40844 .52226 Mtetra
.66 .742 .911 r
.40844 .52226 .41658 .53018 .43035 .52596 .42225 .51804 Mtetra
.658 .742 .912 r
.42225 .51804 .43035 .52596 .44419 .52178 .43613 .51386 Mtetra
.656 .743 .914 r
.43613 .51386 .44419 .52178 .4581 .51764 .45009 .50975 Mtetra
.652 .743 .916 r
.45009 .50975 .4581 .51764 .47208 .51358 .46412 .50574 Mtetra
.647 .744 .92 r
.46412 .50574 .47208 .51358 .48614 .50964 .47822 .50188 Mtetra
.64 .745 .925 r
.47822 .50188 .48614 .50964 .50027 .50585 .49239 .49821 Mtetra
.631 .747 .931 r
.49239 .49821 .50027 .50585 .51448 .50226 .50665 .49481 Mtetra
.618 .749 .939 r
.50665 .49481 .51448 .50226 .52877 .49893 .52099 .49173 Mtetra
.601 .751 .949 r
.52099 .49173 .52877 .49893 .54314 .49593 .53542 .48904 Mtetra
.579 .753 .961 r
.53542 .48904 .54314 .49593 .55761 .49332 .54994 .48681 Mtetra
.549 .755 .973 r
.54994 .48681 .55761 .49332 .57218 .49115 .56457 .48511 Mtetra
.509 .755 .984 r
.56457 .48511 .57218 .49115 .58686 .48946 .57931 .48398 Mtetra
.458 .751 .992 r
.57931 .48398 .58686 .48946 .60165 .48829 .59417 .48342 Mtetra
.393 .74 .992 r
.59417 .48342 .60165 .48829 .61656 .48764 .60917 .48345 Mtetra
.316 .721 .979 r
.60917 .48345 .61656 .48764 .63161 .48746 .6243 .48398 Mtetra
.231 .692 .948 r
.6243 .48398 .63161 .48746 .64679 .48768 .63957 .48493 Mtetra
.148 .656 .902 r
.63957 .48493 .64679 .48768 .66211 .48819 .65499 .48615 Mtetra
.079 .621 .848 r
.65499 .48615 .66211 .48819 .67756 .48883 .67056 .48743 Mtetra
.035 .597 .8 r
.67056 .48743 .67756 .48883 .69315 .4894 .68625 .48854 Mtetra
.022 .592 .767 r
.68625 .48854 .69315 .4894 .70885 .48967 .70206 .48922 Mtetra
.044 .612 .757 r
.70206 .48922 .70885 .48967 .72466 .48941 .71798 .4892 Mtetra
.101 .656 .773 r
.71798 .4892 .72466 .48941 .74054 .48839 .73396 .48823 Mtetra
.191 .722 .81 r
.73396 .48823 .74054 .48839 .75648 .48641 .74999 .4861 Mtetra
.307 .799 .859 r
.74999 .4861 .75648 .48641 .77246 .4833 .76605 .48265 Mtetra
.435 .87 .908 r
.76605 .48265 .77246 .4833 .78844 .47896 .7821 .47779 Mtetra
.554 .922 .941 r
.7821 .47779 .78844 .47896 .80441 .47336 .79812 .47151 Mtetra
.651 .947 .955 r
.79812 .47151 .80441 .47336 .82036 .46653 .8141 .4639 Mtetra
.719 .949 .953 r
.8141 .4639 .82036 .46653 .83627 .4586 .83004 .4551 Mtetra
.761 .936 .942 r
.83004 .4551 .83627 .4586 .85215 .44971 .84594 .44532 Mtetra
.785 .916 .928 r
.84594 .44532 .85215 .44971 .86801 .44009 .86181 .43482 Mtetra
.795 .894 .914 r
.86181 .43482 .86801 .44009 .88385 .42996 .87767 .42385 Mtetra
.797 .872 .903 r
.87767 .42385 .88385 .42996 .89971 .41956 .89354 .41268 Mtetra
.793 .852 .895 r
.89354 .41268 .89971 .41956 .9156 .40911 .90945 .40155 Mtetra
.785 .834 .89 r
.90945 .40155 .9156 .40911 .93155 .39879 .92542 .39066 Mtetra
.663 .741 .908 r
.33199 .53564 .34042 .54348 .35388 .53925 .34549 .53137 Mtetra
.34549 .53137 .35388 .53925 .36742 .53501 .35907 .5271 Mtetra
.662 .741 .909 r
.35907 .5271 .36742 .53501 .38102 .53076 .37272 .52282 Mtetra
.662 .742 .909 r
.37272 .52282 .38102 .53076 .3947 .5265 .38644 .51854 Mtetra
.66 .742 .91 r
.38644 .51854 .3947 .5265 .40844 .52226 .40022 .51428 Mtetra
.659 .742 .911 r
.40022 .51428 .40844 .52226 .42225 .51804 .41408 .51006 Mtetra
.657 .742 .913 r
.41408 .51006 .42225 .51804 .43613 .51386 .428 .5059 Mtetra
.653 .743 .915 r
.428 .5059 .43613 .51386 .45009 .50975 .442 .50183 Mtetra
.649 .744 .919 r
.442 .50183 .45009 .50975 .46412 .50574 .45607 .49789 Mtetra
.642 .745 .923 r
.45607 .49789 .46412 .50574 .47822 .50188 .47022 .49415 Mtetra
.633 .746 .929 r
.47022 .49415 .47822 .50188 .49239 .49821 .48444 .49065 Mtetra
.621 .748 .937 r
.48444 .49065 .49239 .49821 .50665 .49481 .49874 .48747 Mtetra
.605 .75 .947 r
.49874 .48747 .50665 .49481 .52099 .49173 .51313 .48468 Mtetra
.583 .751 .958 r
.51313 .48468 .52099 .49173 .53542 .48904 .52761 .48237 Mtetra
.553 .753 .97 r
.52761 .48237 .53542 .48904 .54994 .48681 .54219 .48061 Mtetra
.513 .752 .982 r
.54219 .48061 .54994 .48681 .56457 .48511 .55688 .47945 Mtetra
.459 .747 .991 r
.55688 .47945 .56457 .48511 .57931 .48398 .57168 .47895 Mtetra
.389 .734 .991 r
.57168 .47895 .57931 .48398 .59417 .48342 .58662 .4791 Mtetra
.302 .71 .976 r
.58662 .4791 .59417 .48342 .60917 .48345 .60169 .47988 Mtetra
.202 .672 .939 r
.60169 .47988 .60917 .48345 .6243 .48398 .61691 .4812 Mtetra
.1 .622 .881 r
.61691 .4812 .6243 .48398 .63957 .48493 .63229 .48293 Mtetra
.011 .57 .81 r
.63229 .48293 .63957 .48493 .65499 .48615 .64781 .48488 Mtetra
0 .528 .742 r
.64781 .48488 .65499 .48615 .67056 .48743 .66348 .48681 Mtetra
.083 0 0 r
.66348 .48681 .67056 .48743 .68625 .48854 .67929 .48845 Mtetra
.078 0 0 r
.67929 .48845 .68625 .48854 .70206 .48922 .69521 .48949 Mtetra
.037 0 0 r
.69521 .48949 .70206 .48922 .71798 .4892 .71123 .48964 Mtetra
0 0 0 r
.71123 .48964 .71798 .4892 .73396 .48823 .72731 .48863 Mtetra
.158 .699 .762 r
.72731 .48863 .73396 .48823 .74999 .4861 .74343 .48624 Mtetra
.301 .796 .832 r
.74343 .48624 .74999 .4861 .76605 .48265 .75956 .48232 Mtetra
.451 .881 .894 r
.75956 .48232 .76605 .48265 .7821 .47779 .77567 .47681 Mtetra
.583 .937 .933 r
.77567 .47681 .7821 .47779 .79812 .47151 .79174 .46973 Mtetra
.683 .958 .947 r
.79174 .46973 .79812 .47151 .8141 .4639 .80776 .46122 Mtetra
.747 .954 .942 r
.80776 .46122 .8141 .4639 .83004 .4551 .82372 .45146 Mtetra
.785 .936 .929 r
.82372 .45146 .83004 .4551 .84594 .44532 .83964 .44071 Mtetra
.803 .913 .914 r
.83964 .44071 .84594 .44532 .86181 .43482 .85552 .42927 Mtetra
.81 .89 .901 r
.85552 .42927 .86181 .43482 .87767 .42385 .87139 .41743 Mtetra
.808 .867 .891 r
.87139 .41743 .87767 .42385 .89354 .41268 .88727 .40548 Mtetra
.802 .847 .885 r
.88727 .40548 .89354 .41268 .90945 .40155 .90319 .39367 Mtetra
.792 .83 .881 r
.90319 .39367 .90945 .40155 .92542 .39066 .91918 .38221 Mtetra
.663 .741 .908 r
.32348 .52772 .33199 .53564 .34549 .53137 .33703 .52342 Mtetra
.663 .741 .909 r
.33703 .52342 .34549 .53137 .35907 .5271 .35065 .51912 Mtetra
.662 .741 .909 r
.35065 .51912 .35907 .5271 .37272 .52282 .36434 .51481 Mtetra
.661 .742 .91 r
.36434 .51481 .37272 .52282 .38644 .51854 .37809 .51052 Mtetra
.66 .742 .911 r
.37809 .51052 .38644 .51854 .40022 .51428 .39192 .50625 Mtetra
.657 .742 .912 r
.39192 .50625 .40022 .51428 .41408 .51006 .40582 .50204 Mtetra
.654 .743 .914 r
.40582 .50204 .41408 .51006 .428 .5059 .41979 .4979 Mtetra
.65 .743 .918 r
.41979 .4979 .428 .5059 .442 .50183 .43383 .4939 Mtetra
.644 .744 .922 r
.43383 .4939 .442 .50183 .45607 .49789 .44795 .49006 Mtetra
.636 .745 .927 r
.44795 .49006 .45607 .49789 .47022 .49415 .46214 .48646 Mtetra
.625 .747 .934 r
.46214 .48646 .47022 .49415 .48444 .49065 .4764 .48317 Mtetra
.609 .748 .944 r
.4764 .48317 .48444 .49065 .49874 .48747 .49075 .48027 Mtetra
.588 .75 .955 r
.49075 .48027 .49874 .48747 .51313 .48468 .50519 .47784 Mtetra
.559 .751 .967 r
.50519 .47784 .51313 .48468 .52761 .48237 .51972 .47597 Mtetra
.519 .75 .98 r
.51972 .47597 .52761 .48237 .54219 .48061 .53435 .47475 Mtetra
.464 .744 .989 r
.53435 .47475 .54219 .48061 .55688 .47945 .5491 .47422 Mtetra
.391 .73 .991 r
.5491 .47422 .55688 .47945 .57168 .47895 .56397 .47443 Mtetra
.297 .703 .975 r
.56397 .47443 .57168 .47895 .58662 .4791 .57898 .47537 Mtetra
.185 .658 .934 r
.57898 .47537 .58662 .4791 .60169 .47988 .59414 .47698 Mtetra
.066 .596 .866 r
.59414 .47698 .60169 .47988 .61691 .4812 .60945 .47915 Mtetra
0 .528 .779 r
.60945 .47915 .61691 .4812 .63229 .48293 .62492 .4817 Mtetra
.125 0 0 r
.62492 .4817 .63229 .48293 .64781 .48488 .64055 .48441 Mtetra
.173 0 0 r
.64055 .48441 .64781 .48488 .66348 .48681 .65633 .48699 Mtetra
.185 0 0 r
.65633 .48699 .66348 .48681 .67929 .48845 .67225 .48911 Mtetra
.161 0 0 r
.67225 .48911 .67929 .48845 .69521 .48949 .68828 .49045 Mtetra
.099 0 0 r
.68828 .49045 .69521 .48949 .71123 .48964 .7044 .49068 Mtetra
0 0 0 r
.7044 .49068 .71123 .48964 .72731 .48863 .72058 .48951 Mtetra
.145 .688 .727 r
.72058 .48951 .72731 .48863 .74343 .48624 .73679 .48673 Mtetra
.314 .805 .816 r
.73679 .48673 .74343 .48624 .75956 .48232 .75299 .4822 Mtetra
.484 .899 .888 r
.75299 .4822 .75956 .48232 .77567 .47681 .76915 .4759 Mtetra
.623 .952 .928 r
.76915 .4759 .77567 .47681 .79174 .46973 .78526 .4679 Mtetra
.719 .966 .938 r
.78526 .4679 .79174 .46973 .80776 .46122 .80131 .45837 Mtetra
.777 .955 .929 r
.80131 .45837 .80776 .46122 .82372 .45146 .81729 .44756 Mtetra
.807 .933 .915 r
.81729 .44756 .82372 .45146 .83964 .44071 .83322 .43578 Mtetra
.82 .907 .9 r
.83322 .43578 .83964 .44071 .85552 .42927 .84911 .42336 Mtetra
.822 .883 .888 r
.84911 .42336 .85552 .42927 .87139 .41743 .86499 .41063 Mtetra
.818 .86 .879 r
.86499 .41063 .87139 .41743 .88727 .40548 .88089 .39789 Mtetra
.809 .841 .874 r
.88089 .39789 .88727 .40548 .90319 .39367 .89683 .38542 Mtetra
.798 .824 .872 r
.89683 .38542 .90319 .39367 .91918 .38221 .91285 .37341 Mtetra
.663 .741 .908 r
.31489 .51974 .32348 .52772 .33703 .52342 .32848 .51541 Mtetra
.662 .741 .909 r
.32848 .51541 .33703 .52342 .35065 .51912 .34214 .51107 Mtetra
.661 .742 .909 r
.34214 .51107 .35065 .51912 .36434 .51481 .35587 .50674 Mtetra
.66 .742 .91 r
.35587 .50674 .36434 .51481 .37809 .51052 .36967 .50243 Mtetra
.658 .742 .912 r
.36967 .50243 .37809 .51052 .39192 .50625 .38354 .49817 Mtetra
.656 .742 .914 r
.38354 .49817 .39192 .50625 .40582 .50204 .39749 .49398 Mtetra
.652 .743 .916 r
.39749 .49398 .40582 .50204 .41979 .4979 .4115 .48989 Mtetra
.646 .744 .92 r
.4115 .48989 .41979 .4979 .43383 .4939 .42558 .48597 Mtetra
.639 .744 .925 r
.42558 .48597 .43383 .4939 .44795 .49006 .43974 .48226 Mtetra
.628 .746 .932 r
.43974 .48226 .44795 .49006 .46214 .48646 .45397 .47884 Mtetra
.614 .747 .94 r
.45397 .47884 .46214 .48646 .4764 .48317 .46828 .47581 Mtetra
.594 .748 .951 r
.46828 .47581 .4764 .48317 .49075 .48027 .48267 .47324 Mtetra
.566 .749 .963 r
.48267 .47324 .49075 .48027 .50519 .47784 .49715 .47123 Mtetra
.527 .748 .976 r
.49715 .47123 .50519 .47784 .51972 .47597 .51173 .46988 Mtetra
.474 .742 .987 r
.51173 .46988 .51972 .47597 .53435 .47475 .52642 .46928 Mtetra
.4 .728 .99 r
.52642 .46928 .53435 .47475 .5491 .47422 .54123 .46947 Mtetra
.302 .699 .977 r
.54123 .46947 .5491 .47422 .56397 .47443 .55617 .47048 Mtetra
.18 .65 .935 r
.55617 .47048 .56397 .47443 .57898 .47537 .57125 .47228 Mtetra
.046 .578 .86 r
.57125 .47228 .57898 .47537 .59414 .47698 .58649 .47479 Mtetra
0 .495 .759 r
.58649 .47479 .59414 .47698 .60945 .47915 .6019 .47785 Mtetra
.181 0 0 r
.6019 .47785 .60945 .47915 .62492 .4817 .61747 .48126 Mtetra
.245 0 0 r
.61747 .48126 .62492 .4817 .64055 .48441 .6332 .48473 Mtetra
.273 0 0 r
.6332 .48473 .64055 .48441 .65633 .48699 .6491 .48793 Mtetra
.266 0 0 r
.6491 .48793 .65633 .48699 .67225 .48911 .66512 .49048 Mtetra
.223 0 0 r
.66512 .49048 .67225 .48911 .68828 .49045 .68127 .49202 Mtetra
.141 0 0 r
.68127 .49202 .68828 .49045 .7044 .49068 .69749 .49221 Mtetra
.015 0 0 r
.69749 .49221 .7044 .49068 .72058 .48951 .71376 .49075 Mtetra
.155 .692 .709 r
.71376 .49075 .72058 .48951 .73679 .48673 .73005 .48743 Mtetra
.35 .826 .815 r
.73005 .48743 .73679 .48673 .75299 .4822 .74631 .48214 Mtetra
.533 .923 .891 r
.74631 .48214 .75299 .4822 .76915 .4759 .76253 .47491 Mtetra
.671 .967 .925 r
.76253 .47491 .76915 .4759 .78526 .4679 .77868 .46586 Mtetra
.757 .969 .928 r
.77868 .46586 .78526 .4679 .80131 .45837 .79475 .45521 Mtetra
.805 .951 .915 r
.79475 .45521 .80131 .45837 .81729 .44756 .81075 .44328 Mtetra
.827 .924 .899 r
.81075 .44328 .81729 .44756 .83322 .43578 .82669 .43042 Mtetra
.834 .898 .884 r
.82669 .43042 .83322 .43578 .84911 .42336 .84259 .41699 Mtetra
.832 .873 .874 r
.84259 .41699 .84911 .42336 .86499 .41063 .85848 .40337 Mtetra
.825 .852 .867 r
.85848 .40337 .86499 .41063 .88089 .39789 .87439 .38987 Mtetra
.815 .833 .864 r
.87439 .38987 .88089 .39789 .89683 .38542 .89036 .37676 Mtetra
.802 .818 .864 r
.89036 .37676 .89683 .38542 .91285 .37341 .90642 .36425 Mtetra
.662 .741 .909 r
.30621 .51168 .31489 .51974 .32848 .51541 .31985 .50732 Mtetra
.31985 .50732 .32848 .51541 .34214 .51107 .33355 .50295 Mtetra
.661 .742 .91 r
.33355 .50295 .34214 .51107 .35587 .50674 .34733 .49861 Mtetra
.659 .742 .911 r
.34733 .49861 .35587 .50674 .36967 .50243 .36117 .49429 Mtetra
.657 .742 .913 r
.36117 .49429 .36967 .50243 .38354 .49817 .37508 .49004 Mtetra
.653 .742 .915 r
.37508 .49004 .38354 .49817 .39749 .49398 .38907 .48588 Mtetra
.649 .743 .918 r
.38907 .48588 .39749 .49398 .4115 .48989 .40312 .48187 Mtetra
.642 .744 .923 r
.40312 .48187 .4115 .48989 .42558 .48597 .41724 .47805 Mtetra
.632 .745 .929 r
.41724 .47805 .42558 .48597 .43974 .48226 .43144 .47451 Mtetra
.619 .746 .937 r
.43144 .47451 .43974 .48226 .45397 .47884 .44571 .47132 Mtetra
.6 .747 .947 r
.44571 .47132 .45397 .47884 .46828 .47581 .46007 .46859 Mtetra
.574 .748 .959 r
.46007 .46859 .46828 .47581 .48267 .47324 .4745 .46641 Mtetra
.538 .747 .972 r
.4745 .46641 .48267 .47324 .49715 .47123 .48903 .4649 Mtetra
.486 .742 .984 r
.48903 .4649 .49715 .47123 .51173 .46988 .50366 .46415 Mtetra
.414 .728 .99 r
.50366 .46415 .51173 .46988 .52642 .46928 .5184 .46425 Mtetra
.315 .7 .979 r
.5184 .46425 .52642 .46928 .54123 .46947 .53327 .46524 Mtetra
.188 .648 .94 r
.53327 .46524 .54123 .46947 .55617 .47048 .54827 .46712 Mtetra
.042 .57 .862 r
.54827 .46712 .55617 .47048 .57125 .47228 .56343 .46986 Mtetra
0 .475 .751 r
.56343 .46986 .57125 .47228 .58649 .47479 .57875 .47333 Mtetra
.22 0 0 r
.57875 .47333 .58649 .47479 .6019 .47785 .59425 .47733 Mtetra
.3 0 0 r
.59425 .47733 .6019 .47785 .61747 .48126 .60992 .4816 Mtetra
.342 0 0 r
.60992 .4816 .61747 .48126 .6332 .48473 .62576 .48581 Mtetra
.349 0 0 r
.62576 .48581 .6332 .48473 .6491 .48793 .64177 .48957 Mtetra
.324 0 0 r
.64177 .48957 .6491 .48793 .66512 .49048 .65791 .49247 Mtetra
.263 0 0 r
.65791 .49247 .66512 .49048 .68127 .49202 .67416 .49411 Mtetra
.161 0 0 r
.67416 .49411 .68127 .49202 .69749 .49221 .69048 .49412 Mtetra
.009 0 0 r
.69048 .49412 .69749 .49221 .71376 .49075 .70684 .4922 Mtetra
.19 .716 .712 r
.70684 .4922 .71376 .49075 .73005 .48743 .7232 .48818 Mtetra
.407 .859 .827 r
.7232 .48818 .73005 .48743 .74631 .48214 .73952 .48199 Mtetra
.594 .948 .899 r
.73952 .48199 .74631 .48214 .76253 .47491 .75579 .47369 Mtetra
.721 .976 .922 r
.75579 .47369 .76253 .47491 .77868 .46586 .77197 .46347 Mtetra
.794 .966 .915 r
.77197 .46347 .77868 .46586 .79475 .45521 .78806 .45162 Mtetra
.829 .941 .899 r
.78806 .45162 .79475 .45521 .81075 .44328 .80407 .4385 Mtetra
.843 .912 .882 r
.80407 .4385 .81075 .44328 .82669 .43042 .82002 .42452 Mtetra
.845 .886 .869 r
.82002 .42452 .82669 .43042 .84259 .41699 .83593 .41009 Mtetra
.84 .862 .86 r
.83593 .41009 .84259 .41699 .85848 .40337 .85184 .3956 Mtetra
.831 .842 .855 r
.85184 .3956 .85848 .40337 .87439 .38987 .86778 .38137 Mtetra
.819 .825 .854 r
.86778 .38137 .87439 .38987 .89036 .37676 .88378 .36767 Mtetra
.804 .81 .856 r
.88378 .36767 .89036 .37676 .90642 .36425 .89988 .3547 Mtetra
.662 .741 .909 r
.29746 .50355 .30621 .51168 .31985 .50732 .31113 .49916 Mtetra
.661 .742 .91 r
.31113 .49916 .31985 .50732 .33355 .50295 .32488 .49477 Mtetra
.66 .742 .911 r
.32488 .49477 .33355 .50295 .34733 .49861 .3387 .49041 Mtetra
.658 .742 .912 r
.3387 .49041 .34733 .49861 .36117 .49429 .35258 .4861 Mtetra
.655 .742 .914 r
.35258 .4861 .36117 .49429 .37508 .49004 .36654 .48187 Mtetra
.651 .743 .917 r
.36654 .48187 .37508 .49004 .38907 .48588 .38056 .47777 Mtetra
.645 .743 .921 r
.38056 .47777 .38907 .48588 .40312 .48187 .39465 .47384 Mtetra
.636 .744 .927 r
.39465 .47384 .40312 .48187 .41724 .47805 .40882 .47017 Mtetra
.624 .745 .934 r
.40882 .47017 .41724 .47805 .43144 .47451 .42306 .46682 Mtetra
.607 .746 .943 r
.42306 .46682 .43144 .47451 .44571 .47132 .43737 .46391 Mtetra
.583 .747 .955 r
.43737 .46391 .44571 .47132 .46007 .46859 .45176 .46154 Mtetra
.549 .746 .968 r
.45176 .46154 .46007 .46859 .4745 .46641 .46624 .45983 Mtetra
.501 .741 .981 r
.46624 .45983 .4745 .46641 .48903 .4649 .48081 .45888 Mtetra
.432 .73 .989 r
.48081 .45888 .48903 .4649 .50366 .46415 .49548 .45881 Mtetra
.336 .703 .983 r
.49548 .45881 .50366 .46415 .5184 .46425 .51027 .45969 Mtetra
.208 .653 .949 r
.51027 .45969 .5184 .46425 .53327 .46524 .5252 .46156 Mtetra
.053 .572 .873 r
.5252 .46156 .53327 .46524 .54827 .46712 .54027 .46441 Mtetra
0 .467 .757 r
.54027 .46441 .54827 .46712 .56343 .46986 .5555 .46814 Mtetra
.241 0 0 r
.5555 .46814 .56343 .46986 .57875 .47333 .57091 .47261 Mtetra
.337 0 0 r
.57091 .47261 .57875 .47333 .59425 .47733 .5865 .47757 Mtetra
.393 0 0 r
.5865 .47757 .59425 .47733 .60992 .4816 .60227 .48269 Mtetra
.414 0 0 r
.60227 .48269 .60992 .4816 .62576 .48581 .61822 .4876 Mtetra
.403 0 0 r
.61822 .4876 .62576 .48581 .64177 .48957 .63433 .49184 Mtetra
.362 0 0 r
.63433 .49184 .64177 .48957 .65791 .49247 .65058 .49497 Mtetra
.284 0 0 r
.65058 .49497 .65791 .49247 .67416 .49411 .66694 .49656 Mtetra
.159 0 0 r
.66694 .49656 .67416 .49411 .69048 .49412 .68336 .49624 Mtetra
0 0 0 r
.68336 .49624 .69048 .49412 .70684 .4922 .6998 .49371 Mtetra
.252 .759 .736 r
.6998 .49371 .70684 .4922 .7232 .48818 .71623 .48883 Mtetra
.484 .901 .851 r
.71623 .48883 .7232 .48818 .73952 .48199 .73261 .48157 Mtetra
.662 .969 .907 r
.73261 .48157 .73952 .48199 .75579 .47369 .74891 .47207 Mtetra
.77 .978 .915 r
.74891 .47207 .75579 .47369 .77197 .46347 .76512 .46058 Mtetra
.824 .957 .9 r
.76512 .46058 .77197 .46347 .78806 .45162 .78123 .44745 Mtetra
.848 .927 .881 r
.78123 .44745 .78806 .45162 .80407 .4385 .79726 .43311 Mtetra
.855 .897 .865 r
.79726 .43311 .80407 .4385 .82002 .42452 .81322 .418 Mtetra
.853 .871 .853 r
.81322 .418 .82002 .42452 .83593 .41009 .82915 .40259 Mtetra
.845 .849 .847 r
.82915 .40259 .83593 .41009 .85184 .3956 .84508 .38725 Mtetra
.834 .831 .844 r
.84508 .38725 .85184 .3956 .86778 .38137 .86105 .37234 Mtetra
.821 .816 .845 r
.86105 .37234 .86778 .38137 .88378 .36767 .87709 .35811 Mtetra
.806 .803 .848 r
.87709 .35811 .88378 .36767 .89988 .3547 .89323 .34475 Mtetra
.662 .741 .909 r
.28862 .49535 .29746 .50355 .31113 .49916 .30234 .49093 Mtetra
.66 .742 .91 r
.30234 .49093 .31113 .49916 .32488 .49477 .31612 .48652 Mtetra
.659 .742 .911 r
.31612 .48652 .32488 .49477 .3387 .49041 .32998 .48216 Mtetra
.656 .742 .913 r
.32998 .48216 .3387 .49041 .35258 .4861 .34391 .47786 Mtetra
.653 .742 .916 r
.34391 .47786 .35258 .4861 .36654 .48187 .3579 .47367 Mtetra
.647 .743 .919 r
.3579 .47367 .36654 .48187 .38056 .47777 .37197 .46964 Mtetra
.64 .744 .924 r
.37197 .46964 .38056 .47777 .39465 .47384 .3861 .46583 Mtetra
.629 .744 .931 r
.3861 .46583 .39465 .47384 .40882 .47017 .4003 .46233 Mtetra
.614 .745 .939 r
.4003 .46233 .40882 .47017 .42306 .46682 .41458 .45923 Mtetra
.592 .746 .95 r
.41458 .45923 .42306 .46682 .43737 .46391 .42893 .45664 Mtetra
.561 .745 .963 r
.42893 .45664 .43737 .46391 .45176 .46154 .44336 .4547 Mtetra
.517 .742 .976 r
.44336 .4547 .45176 .46154 .46624 .45983 .45787 .45351 Mtetra
.454 .731 .986 r
.45787 .45351 .46624 .45983 .48081 .45888 .47248 .45321 Mtetra
.363 .708 .986 r
.47248 .45321 .48081 .45888 .49548 .45881 .4872 .4539 Mtetra
.237 .662 .959 r
.4872 .4539 .49548 .45881 .51027 .45969 .50204 .45565 Mtetra
.079 .582 .891 r
.50204 .45565 .51027 .45969 .5252 .46156 .51702 .45847 Mtetra
0 .472 .775 r
.51702 .45847 .5252 .46156 .54027 .46441 .53216 .46234 Mtetra
.246 0 0 r
.53216 .46234 .54027 .46441 .5555 .46814 .54747 .46712 Mtetra
.359 0 0 r
.54747 .46712 .5555 .46814 .57091 .47261 .56296 .47261 Mtetra
.428 0 0 r
.56296 .47261 .57091 .47261 .5865 .47757 .57864 .47852 Mtetra
.462 0 0 r
.57864 .47852 .5865 .47757 .60227 .48269 .59451 .48446 Mtetra
.464 0 0 r
.59451 .48446 .60227 .48269 .61822 .4876 .61057 .48999 Mtetra
.439 0 0 r
.61057 .48999 .61822 .4876 .63433 .49184 .62678 .49461 Mtetra
.383 0 0 r
.62678 .49461 .63433 .49184 .65058 .49497 .64314 .49784 Mtetra
.286 0 0 r
.64314 .49784 .65058 .49497 .66694 .49656 .65959 .49923 Mtetra
.134 0 0 r
.65959 .49923 .66694 .49656 .68336 .49624 .67611 .49839 Mtetra
0 0 0 r
.67611 .49839 .68336 .49624 .6998 .49371 .69263 .49506 Mtetra
.341 .817 .778 r
.69263 .49506 .6998 .49371 .71623 .48883 .70912 .48915 Mtetra
.574 .941 .879 r
.70912 .48915 .71623 .48883 .73261 .48157 .72555 .48068 Mtetra
.729 .981 .911 r
.72555 .48068 .73261 .48157 .74891 .47207 .74189 .46986 Mtetra
.811 .97 .903 r
.74189 .46986 .74891 .47207 .76512 .46058 .75813 .45701 Mtetra
.849 .941 .883 r
.75813 .45701 .76512 .46058 .78123 .44745 .77426 .44256 Mtetra
.862 .909 .863 r
.77426 .44256 .78123 .44745 .79726 .43311 .7903 .42698 Mtetra
.863 .88 .848 r
.7903 .42698 .79726 .43311 .81322 .418 .80628 .41077 Mtetra
.858 .856 .838 r
.80628 .41077 .81322 .418 .82915 .40259 .82223 .39441 Mtetra
.848 .836 .834 r
.82223 .39441 .82915 .40259 .84508 .38725 .83819 .37829 Mtetra
.836 .82 .834 r
.83819 .37829 .84508 .38725 .86105 .37234 .85419 .36277 Mtetra
.822 .806 .837 r
.85419 .36277 .86105 .37234 .87709 .35811 .87028 .34808 Mtetra
.806 .795 .842 r
.87028 .34808 .87709 .35811 .89323 .34475 .88648 .33438 Mtetra
.661 .741 .91 r
.27969 .48707 .28862 .49535 .30234 .49093 .29345 .48263 Mtetra
.66 .742 .911 r
.29345 .48263 .30234 .49093 .31612 .48652 .30728 .47821 Mtetra
.657 .742 .912 r
.30728 .47821 .31612 .48652 .32998 .48216 .32118 .47385 Mtetra
.654 .742 .914 r
.32118 .47385 .32998 .48216 .34391 .47786 .33514 .46958 Mtetra
.65 .743 .917 r
.33514 .46958 .34391 .47786 .3579 .47367 .34918 .46545 Mtetra
.643 .743 .922 r
.34918 .46545 .3579 .47367 .37197 .46964 .36328 .46151 Mtetra
.634 .744 .928 r
.36328 .46151 .37197 .46964 .3861 .46583 .37745 .45785 Mtetra
.62 .745 .935 r
.37745 .45785 .3861 .46583 .4003 .46233 .39169 .45455 Mtetra
.601 .745 .946 r
.39169 .45455 .4003 .46233 .41458 .45923 .406 .45174 Mtetra
.573 .745 .958 r
.406 .45174 .41458 .45923 .42893 .45664 .42039 .44954 Mtetra
.534 .742 .971 r
.42039 .44954 .42893 .45664 .44336 .4547 .43485 .44808 Mtetra
.476 .734 .983 r
.43485 .44808 .44336 .4547 .45787 .45351 .4494 .4475 Mtetra
.393 .714 .987 r
.4494 .4475 .45787 .45351 .47248 .45321 .46405 .44792 Mtetra
.274 .673 .97 r
.46405 .44792 .47248 .45321 .4872 .4539 .47881 .44944 Mtetra
.117 .6 .913 r
.47881 .44944 .4872 .4539 .50204 .45565 .4937 .45213 Mtetra
0 .489 .803 r
.4937 .45213 .50204 .45565 .51702 .45847 .50873 .45598 Mtetra
.233 0 0 r
.50873 .45598 .51702 .45847 .53216 .46234 .52393 .46091 Mtetra
.365 0 0 r
.52393 .46091 .53216 .46234 .54747 .46712 .53931 .46677 Mtetra
.45 0 0 r
.53931 .46677 .54747 .46712 .56296 .47261 .55488 .4733 Mtetra
.495 0 0 r
.55488 .4733 .56296 .47261 .57864 .47852 .57065 .48013 Mtetra
.51 0 0 r
.57065 .48013 .57864 .47852 .59451 .48446 .58663 .48682 Mtetra
.498 0 0 r
.58663 .48682 .59451 .48446 .61057 .48999 .60278 .49287 Mtetra
.46 0 0 r
.60278 .49287 .61057 .48999 .62678 .49461 .61911 .49773 Mtetra
.388 0 0 r
.61911 .49773 .62678 .49461 .64314 .49784 .63557 .5009 Mtetra
.269 0 0 r
.63557 .5009 .64314 .49784 .65959 .49923 .65212 .50189 Mtetra
.083 0 0 r
.65212 .50189 .65959 .49923 .67611 .49839 .66872 .50035 Mtetra
0 0 0 r
.66872 .50035 .67611 .49839 .69263 .49506 .68532 .49606 Mtetra
.45 .882 .83 r
.68532 .49606 .69263 .49506 .70912 .48915 .70187 .48895 Mtetra
.664 .971 .901 r
.70187 .48895 .70912 .48915 .72555 .48068 .71835 .47914 Mtetra
.785 .98 .907 r
.71835 .47914 .72555 .48068 .74189 .46986 .73472 .4669 Mtetra
.842 .953 .887 r
.73472 .4669 .74189 .46986 .75813 .45701 .75098 .45263 Mtetra
.865 .92 .863 r
.75098 .45263 .75813 .45701 .77426 .44256 .76713 .43683 Mtetra
.871 .888 .844 r
.76713 .43683 .77426 .44256 .7903 .42698 .7832 .42003 Mtetra
.868 .862 .831 r
.7832 .42003 .7903 .42698 .80628 .41077 .7992 .40276 Mtetra
.86 .84 .824 r
.7992 .40276 .80628 .41077 .82223 .39441 .81518 .38551 Mtetra
.849 .823 .822 r
.81518 .38551 .82223 .39441 .83819 .37829 .83117 .36869 Mtetra
.836 .809 .824 r
.83117 .36869 .83819 .37829 .85419 .36277 .84722 .35263 Mtetra
.821 .797 .829 r
.84722 .35263 .85419 .36277 .87028 .34808 .86336 .33756 Mtetra
.805 .788 .836 r
.86336 .33756 .87028 .34808 .88648 .33438 .87962 .32361 Mtetra
.66 .742 .91 r
.27068 .47873 .27969 .48707 .29345 .48263 .28448 .47426 Mtetra
.659 .742 .911 r
.28448 .47426 .29345 .48263 .30728 .47821 .29835 .46984 Mtetra
.656 .742 .913 r
.29835 .46984 .30728 .47821 .32118 .47385 .31229 .4655 Mtetra
.652 .742 .916 r
.31229 .4655 .32118 .47385 .33514 .46958 .32629 .46126 Mtetra
.646 .743 .92 r
.32629 .46126 .33514 .46958 .34918 .46545 .34037 .4572 Mtetra
.638 .743 .925 r
.34037 .4572 .34918 .46545 .36328 .46151 .35451 .45338 Mtetra
.626 .744 .932 r
.35451 .45338 .36328 .46151 .37745 .45785 .36871 .4499 Mtetra
.609 .744 .941 r
.36871 .4499 .37745 .45785 .39169 .45455 .38299 .44686 Mtetra
.585 .744 .952 r
.38299 .44686 .39169 .45455 .406 .45174 .39733 .44439 Mtetra
.55 .742 .965 r
.39733 .44439 .406 .45174 .42039 .44954 .41175 .44262 Mtetra
.499 .736 .979 r
.41175 .44262 .42039 .44954 .43485 .44808 .42624 .44171 Mtetra
.424 .72 .986 r
.42624 .44171 .43485 .44808 .4494 .4475 .44082 .4418 Mtetra
.315 .686 .978 r
.44082 .4418 .4494 .4475 .46405 .44792 .4555 .44302 Mtetra
.166 .621 .935 r
.4555 .44302 .46405 .44792 .47881 .44944 .4703 .44545 Mtetra
0 .516 .838 r
.4703 .44545 .47881 .44944 .4937 .45213 .48523 .44914 Mtetra
0 .381 .692 r
.48523 .44914 .4937 .45213 .50873 .45598 .50032 .45407 Mtetra
.355 0 0 r
.50032 .45407 .50873 .45598 .52393 .46091 .51558 .46011 Mtetra
.457 0 0 r
.51558 .46011 .52393 .46091 .53931 .46677 .53103 .46706 Mtetra
.517 0 0 r
.53103 .46706 .53931 .46677 .55488 .4733 .54668 .47459 Mtetra
.543 0 0 r
.54668 .47459 .55488 .4733 .57065 .48013 .56254 .48228 Mtetra
.56254 .48228 .57065 .48013 .58663 .48682 .57861 .48963 Mtetra
.519 0 0 r
.57861 .48963 .58663 .48682 .60278 .49287 .59487 .49607 Mtetra
.467 0 0 r
.59487 .49607 .60278 .49287 .61911 .49773 .6113 .50102 Mtetra
.377 0 0 r
.6113 .50102 .61911 .49773 .63557 .5009 .62786 .50393 Mtetra
.229 0 0 r
.62786 .50393 .63557 .5009 .65212 .50189 .6445 .50434 Mtetra
.001 0 0 r
.6445 .50434 .65212 .50189 .66872 .50035 .66118 .50191 Mtetra
.294 .787 .755 r
.66118 .50191 .66872 .50035 .68532 .49606 .67785 .49646 Mtetra
.568 .939 .879 r
.67785 .49646 .68532 .49606 .70187 .48895 .69446 .488 Mtetra
.742 .982 .911 r
.69446 .488 .70187 .48895 .71835 .47914 .71098 .47673 Mtetra
.828 .965 .895 r
.71098 .47673 .71835 .47914 .73472 .4669 .72739 .463 Mtetra
.864 .93 .867 r
.72739 .463 .73472 .4669 .75098 .45263 .74367 .44728 Mtetra
.875 .896 .844 r
.74367 .44728 .75098 .45263 .76713 .43683 .75985 .43015 Mtetra
.875 .867 .827 r
.75985 .43015 .76713 .43683 .7832 .42003 .77593 .41217 Mtetra
.87 .843 .816 r
.77593 .41217 .7832 .42003 .7992 .40276 .79197 .3939 Mtetra
.86 .825 .812 r
.79197 .3939 .7992 .40276 .81518 .38551 .80798 .37585 Mtetra
.848 .81 .812 r
.80798 .37585 .81518 .38551 .83117 .36869 .82402 .35843 Mtetra
.835 .798 .816 r
.82402 .35843 .83117 .36869 .84722 .35263 .84012 .34193 Mtetra
.82 .788 .823 r
.84012 .34193 .84722 .35263 .86336 .33756 .85632 .32657 Mtetra
.803 .78 .831 r
.85632 .32657 .86336 .33756 .87962 .32361 .87266 .31245 Mtetra
.66 .742 .911 r
.26158 .47031 .27068 .47873 .28448 .47426 .27542 .46583 Mtetra
.657 .742 .912 r
.27542 .46583 .28448 .47426 .29835 .46984 .28933 .46142 Mtetra
.654 .742 .914 r
.28933 .46142 .29835 .46984 .31229 .4655 .30331 .45709 Mtetra
.649 .742 .918 r
.30331 .45709 .31229 .4655 .32629 .46126 .31735 .45292 Mtetra
.642 .743 .922 r
.31735 .45292 .32629 .46126 .34037 .4572 .33146 .44895 Mtetra
.632 .743 .928 r
.33146 .44895 .34037 .4572 .35451 .45338 .34564 .44528 Mtetra
.617 .744 .936 r
.34564 .44528 .35451 .45338 .36871 .4499 .35988 .44201 Mtetra
.596 .744 .947 r
.35988 .44201 .36871 .4499 .38299 .44686 .37418 .43926 Mtetra
.566 .742 .959 r
.37418 .43926 .38299 .44686 .39733 .44439 .38855 .43718 Mtetra
.521 .737 .973 r
.38855 .43718 .39733 .44439 .41175 .44262 .403 .43591 Mtetra
.455 .725 .984 r
.403 .43591 .41175 .44262 .42624 .44171 .41752 .43562 Mtetra
.358 .698 .983 r
.41752 .43562 .42624 .44171 .44082 .4418 .43213 .43645 Mtetra
.22 .644 .955 r
.43213 .43645 .44082 .4418 .4555 .44302 .44684 .43853 Mtetra
.041 .549 .876 r
.44684 .43853 .4555 .44302 .4703 .44545 .46167 .44194 Mtetra
0 .416 .74 r
.46167 .44194 .4703 .44545 .48523 .44914 .47664 .44669 Mtetra
.327 0 0 r
.47664 .44669 .48523 .44914 .50032 .45407 .49178 .45273 Mtetra
.451 0 0 r
.49178 .45273 .50032 .45407 .51558 .46011 .50709 .45989 Mtetra
.526 0 0 r
.50709 .45989 .51558 .46011 .53103 .46706 .52261 .46791 Mtetra
.564 0 0 r
.52261 .46791 .53103 .46706 .54668 .47459 .53834 .47639 Mtetra
.575 .017 0 r
.53834 .47639 .54668 .47459 .56254 .48228 .55429 .48485 Mtetra
.564 .011 0 r
.55429 .48485 .56254 .48228 .57861 .48963 .57045 .49273 Mtetra
.528 0 0 r
.57045 .49273 .57861 .48963 .59487 .49607 .58681 .4994 Mtetra
.462 0 0 r
.58681 .4994 .59487 .49607 .6113 .50102 .60334 .50424 Mtetra
.349 0 0 r
.60334 .50424 .6113 .50102 .62786 .50393 .61999 .5067 Mtetra
.162 0 0 r
.61999 .5067 .62786 .50393 .6445 .50434 .63673 .50632 Mtetra
0 0 0 r
.63673 .50632 .6445 .50434 .66118 .50191 .65349 .5028 Mtetra
.437 .876 .837 r
.65349 .5028 .66118 .50191 .67785 .49646 .67022 .49603 Mtetra
.676 .972 .911 r
.67022 .49603 .67785 .49646 .69446 .488 .68688 .48609 Mtetra
.802 .973 .906 r
.68688 .48609 .69446 .488 .71098 .47673 .70344 .47327 Mtetra
.856 .94 .876 r
.70344 .47327 .71098 .47673 .72739 .463 .71988 .458 Mtetra
.876 .903 .846 r
.71988 .458 .72739 .463 .74367 .44728 .7362 .44085 Mtetra
.88 .871 .824 r
.7362 .44085 .74367 .44728 .75985 .43015 .7524 .42242 Mtetra
.876 .845 .81 r
.7524 .42242 .75985 .43015 .77593 .41217 .76852 .40333 Mtetra
.869 .825 .803 r
.76852 .40333 .77593 .41217 .79197 .3939 .78459 .38417 Mtetra
.858 .809 .801 r
.78459 .38417 .79197 .3939 .80798 .37585 .80064 .36543 Mtetra
.846 .797 .803 r
.80064 .36543 .80798 .37585 .82402 .35843 .81673 .3475 Mtetra
.832 .787 .809 r
.81673 .3475 .82402 .35843 .84012 .34193 .8329 .33068 Mtetra
.817 .779 .817 r
.8329 .33068 .84012 .34193 .85632 .32657 .84918 .31512 Mtetra
.801 .773 .828 r
.84918 .31512 .85632 .32657 .87266 .31245 .86559 .30091 Mtetra
.658 .742 .911 r
.25238 .46182 .26158 .47031 .27542 .46583 .26626 .45734 Mtetra
.656 .742 .913 r
.26626 .45734 .27542 .46583 .28933 .46142 .28021 .45293 Mtetra
.652 .742 .916 r
.28021 .45293 .28933 .46142 .30331 .45709 .29423 .44865 Mtetra
.646 .742 .92 r
.29423 .44865 .30331 .45709 .31735 .45292 .30831 .44454 Mtetra
.637 .743 .925 r
.30831 .44454 .31735 .45292 .33146 .44895 .32246 .44069 Mtetra
.624 .743 .932 r
.32246 .44069 .33146 .44895 .34564 .44528 .33667 .4372 Mtetra
.606 .743 .942 r
.33667 .4372 .34564 .44528 .35988 .44201 .35094 .43418 Mtetra
.58 .742 .953 r
.35094 .43418 .35988 .44201 .37418 .43926 .36527 .43177 Mtetra
.542 .739 .967 r
.36527 .43177 .37418 .43926 .38855 .43718 .37967 .43013 Mtetra
.485 .73 .979 r
.37967 .43013 .38855 .43718 .403 .43591 .39413 .42943 Mtetra
.401 .709 .985 r
.39413 .42943 .403 .43591 .41752 .43562 .40868 .42981 Mtetra
.278 .666 .97 r
.40868 .42981 .41752 .43562 .43213 .43645 .42331 .43145 Mtetra
.109 .584 .912 r
.42331 .43145 .43213 .43645 .44684 .43853 .43805 .43445 Mtetra
0 .46 .794 r
.43805 .43445 .44684 .43853 .46167 .44194 .45291 .43888 Mtetra
.282 0 0 r
.45291 .43888 .46167 .44194 .47664 .44669 .46792 .44473 Mtetra
.428 0 0 r
.46792 .44473 .47664 .44669 .49178 .45273 .48309 .4519 Mtetra
.523 0 0 r
.48309 .4519 .49178 .45273 .50709 .45989 .49846 .46017 Mtetra
.575 .005 0 r
.49846 .46017 .50709 .45989 .52261 .46791 .51405 .46921 Mtetra
.598 .041 0 r
.51405 .46921 .52261 .46791 .53834 .47639 .52985 .47856 Mtetra
.597 .048 0 r
.52985 .47856 .53834 .47639 .55429 .48485 .54589 .48768 Mtetra
.575 .027 0 r
.54589 .48768 .55429 .48485 .57045 .49273 .56214 .49593 Mtetra
.528 0 0 r
.56214 .49593 .57045 .49273 .58681 .4994 .5786 .50264 Mtetra
.443 0 0 r
.5786 .50264 .58681 .4994 .60334 .50424 .59522 .50717 Mtetra
.298 0 0 r
.59522 .50717 .60334 .50424 .61999 .5067 .61197 .50896 Mtetra
.058 0 0 r
.61197 .50896 .61999 .5067 .63673 .50632 .62879 .50758 Mtetra
.273 .776 .769 r
.62879 .50758 .63673 .50632 .65349 .5028 .64562 .50279 Mtetra
.579 .942 .901 r
.64562 .50279 .65349 .5028 .67022 .49603 .66242 .49454 Mtetra
.76 .976 .919 r
.66242 .49454 .67022 .49603 .68688 .48609 .67913 .48301 Mtetra
.841 .949 .889 r
.67913 .48301 .68688 .48609 .70344 .47327 .69573 .46859 Mtetra
.872 .91 .853 r
.69573 .46859 .70344 .47327 .71988 .458 .71221 .45178 Mtetra
.881 .875 .826 r
.71221 .45178 .71988 .458 .7362 .44085 .72856 .43323 Mtetra
.88 .847 .807 r
.72856 .43323 .7362 .44085 .7524 .42242 .74479 .41358 Mtetra
.875 .825 .796 r
.74479 .41358 .7524 .42242 .76852 .40333 .76095 .39349 Mtetra
.866 .808 .791 r
.76095 .39349 .76852 .40333 .78459 .38417 .77706 .37355 Mtetra
.855 .795 .791 r
.77706 .37355 .78459 .38417 .80064 .36543 .79317 .35424 Mtetra
.843 .785 .796 r
.79317 .35424 .80064 .36543 .81673 .3475 .80933 .33593 Mtetra
.829 .777 .803 r
.80933 .33593 .81673 .3475 .8329 .33068 .82557 .31889 Mtetra
.814 .771 .813 r
.82557 .31889 .8329 .33068 .84918 .31512 .84193 .30324 Mtetra
.797 .766 .825 r
.84193 .30324 .84918 .31512 .86559 .30091 .85843 .28902 Mtetra
.657 .742 .912 r
.2431 .45327 .25238 .46182 .26626 .45734 .25702 .44879 Mtetra
.654 .742 .914 r
.25702 .44879 .26626 .45734 .28021 .45293 .27101 .4444 Mtetra
.649 .742 .918 r
.27101 .4444 .28021 .45293 .29423 .44865 .28506 .44017 Mtetra
.641 .742 .922 r
.28506 .44017 .29423 .44865 .30831 .44454 .29918 .43615 Mtetra
.631 .743 .928 r
.29918 .43615 .30831 .44454 .32246 .44069 .31336 .43245 Mtetra
.615 .743 .937 r
.31336 .43245 .32246 .44069 .33667 .4372 .3276 .42916 Mtetra
.593 .742 .947 r
.3276 .42916 .33667 .4372 .35094 .43418 .34189 .42643 Mtetra
.561 .74 .96 r
.34189 .42643 .35094 .43418 .36527 .43177 .35625 .42441 Mtetra
.513 .733 .974 r
.35625 .42441 .36527 .43177 .37967 .43013 .37067 .42327 Mtetra
.441 .718 .983 r
.37067 .42327 .37967 .43013 .39413 .42943 .38515 .42317 Mtetra
.334 .685 .98 r
.38515 .42317 .39413 .42943 .40868 .42981 .39972 .4243 Mtetra
.182 .619 .942 r
.39972 .4243 .40868 .42981 .42331 .43145 .41437 .4268 Mtetra
0 .509 .849 r
.41437 .4268 .42331 .43145 .43805 .43445 .42913 .43077 Mtetra
0 .361 .695 r
.42913 .43077 .43805 .43445 .45291 .43888 .44401 .43626 Mtetra
.389 0 0 r
.44401 .43626 .45291 .43888 .46792 .44473 .45905 .44323 Mtetra
.506 0 0 r
.45905 .44323 .46792 .44473 .48309 .4519 .47427 .45152 Mtetra
.575 .001 0 r
.47427 .45152 .48309 .4519 .49846 .46017 .48969 .46085 Mtetra
.61 .052 0 r
.48969 .46085 .49846 .46017 .51405 .46921 .50533 .47084 Mtetra
.62 .073 0 r
.50533 .47084 .51405 .46921 .52985 .47856 .52121 .48095 Mtetra
.61 .066 0 r
.52121 .48095 .52985 .47856 .54589 .48768 .53733 .49056 Mtetra
.578 .03 0 r
.53733 .49056 .54589 .48768 .56214 .49593 .55368 .49899 Mtetra
.516 0 0 r
.55368 .49899 .56214 .49593 .5786 .50264 .57023 .50553 Mtetra
.406 0 0 r
.57023 .50553 .5786 .50264 .59522 .50717 .58695 .50953 Mtetra
.215 0 0 r
.58695 .50953 .59522 .50717 .61197 .50896 .60378 .51043 Mtetra
0 0 0 r
.60378 .51043 .61197 .50896 .62879 .50758 .62068 .50785 Mtetra
.446 .88 .873 r
.62068 .50785 .62879 .50758 .64562 .50279 .63759 .50161 Mtetra
.696 .969 .932 r
.63759 .50161 .64562 .50279 .66242 .49454 .65444 .49176 Mtetra
.815 .956 .907 r
.65444 .49176 .66242 .49454 .67913 .48301 .67121 .47858 Mtetra
.862 .917 .865 r
.67121 .47858 .67913 .48301 .69573 .46859 .68785 .46254 Mtetra
.878 .879 .831 r
.68785 .46254 .69573 .46859 .71221 .45178 .70436 .44423 Mtetra
.881 .848 .806 r
.70436 .44423 .71221 .45178 .72856 .43323 .72075 .42434 Mtetra
.878 .824 .791 r
.72075 .42434 .72856 .43323 .74479 .41358 .73703 .40358 Mtetra
.871 .805 .783 r
.73703 .40358 .74479 .41358 .76095 .39349 .75323 .38262 Mtetra
.862 .792 .781 r
.75323 .38262 .76095 .39349 .77706 .37355 .7694 .36204 Mtetra
.851 .781 .783 r
.7694 .36204 .77706 .37355 .79317 .35424 .78557 .3423 Mtetra
.839 .774 .79 r
.78557 .3423 .79317 .35424 .80933 .33593 .8018 .32374 Mtetra
.825 .768 .799 r
.8018 .32374 .80933 .33593 .82557 .31889 .81813 .30659 Mtetra
.809 .764 .81 r
.81813 .30659 .82557 .31889 .84193 .30324 .83457 .29095 Mtetra
.793 .76 .823 r
.83457 .29095 .84193 .30324 .85843 .28902 .85118 .2768 Mtetra
.656 .742 .913 r
.23372 .44464 .2431 .45327 .25702 .44879 .24768 .44017 Mtetra
.651 .742 .916 r
.24768 .44017 .25702 .44879 .27101 .4444 .26171 .43582 Mtetra
.645 .742 .92 r
.26171 .43582 .27101 .4444 .28506 .44017 .2758 .43165 Mtetra
.636 .742 .925 r
.2758 .43165 .28506 .44017 .29918 .43615 .28995 .42775 Mtetra
.623 .743 .932 r
.28995 .42775 .29918 .43615 .31336 .43245 .30416 .42422 Mtetra
.605 .742 .942 r
.30416 .42422 .31336 .43245 .3276 .42916 .31842 .42118 Mtetra
.577 .741 .953 r
.31842 .42118 .3276 .42916 .34189 .42643 .33274 .41878 Mtetra
.537 .736 .967 r
.33274 .41878 .34189 .42643 .35625 .42441 .34712 .41719 Mtetra
.477 .725 .979 r
.34712 .41719 .35625 .42441 .37067 .42327 .36155 .41658 Mtetra
.387 .701 .983 r
.36155 .41658 .37067 .42327 .38515 .42317 .37605 .41716 Mtetra
.255 .65 .964 r
.37605 .41716 .38515 .42317 .39972 .4243 .39063 .41908 Mtetra
.075 .559 .898 r
.39063 .41908 .39972 .4243 .41437 .4268 .40529 .42248 Mtetra
0 .421 .767 r
.40529 .42248 .41437 .4268 .42913 .43077 .42007 .42746 Mtetra
.329 0 0 r
.42007 .42746 .42913 .43077 .44401 .43626 .43498 .43403 Mtetra
.473 0 0 r
.43498 .43403 .44401 .43626 .45905 .44323 .45004 .44211 Mtetra
.563 0 0 r
.45004 .44211 .45905 .44323 .47427 .45152 .4653 .45147 Mtetra
.613 .051 0 r
.4653 .45147 .47427 .45152 .48969 .46085 .48077 .4618 Mtetra
.634 .086 0 r
.48077 .4618 .48969 .46085 .50533 .47084 .49647 .47262 Mtetra
.634 .093 0 r
.49647 .47262 .50533 .47084 .52121 .48095 .51242 .48334 Mtetra
.615 .073 0 r
.51242 .48334 .52121 .48095 .53733 .49056 .52862 .49327 Mtetra
.571 .02 0 r
.52862 .49327 .53733 .49056 .55368 .49899 .54505 .50167 Mtetra
.49 0 0 r
.54505 .50167 .55368 .49899 .57023 .50553 .5617 .50781 Mtetra
.344 0 0 r
.5617 .50781 .57023 .50553 .58695 .50953 .5785 .51104 Mtetra
.088 0 0 r
.5785 .51104 .58695 .50953 .60378 .51043 .59543 .51083 Mtetra
.278 .781 .819 r
.59543 .51083 .60378 .51043 .62068 .50785 .6124 .50686 Mtetra
.602 .942 .938 r
.6124 .50686 .62068 .50785 .63759 .50161 .62937 .49904 Mtetra
.775 .959 .929 r
.62937 .49904 .63759 .50161 .65444 .49176 .64629 .48751 Mtetra
.846 .923 .883 r
.64629 .48751 .65444 .49176 .67121 .47858 .6631 .47264 Mtetra
.871 .882 .84 r
.6631 .47264 .67121 .47858 .68785 .46254 .67979 .45499 Mtetra
.879 .848 .809 r
.67979 .45499 .68785 .46254 .70436 .44423 .69635 .43525 Mtetra
.878 .822 .789 r
.69635 .43525 .70436 .44423 .72075 .42434 .71278 .41415 Mtetra
.873 .802 .777 r
.71278 .41415 .72075 .42434 .73703 .40358 .7291 .39242 Mtetra
.866 .788 .772 r
.7291 .39242 .73703 .40358 .75323 .38262 .74536 .37074 Mtetra
.857 .777 .772 r
.74536 .37074 .75323 .38262 .7694 .36204 .7616 .34967 Mtetra
.846 .769 .777 r
.7616 .34967 .7694 .36204 .78557 .3423 .77785 .32964 Mtetra
.834 .764 .785 r
.77785 .32964 .78557 .3423 .8018 .32374 .79416 .31098 Mtetra
.82 .76 .796 r
.79416 .31098 .8018 .32374 .81813 .30659 .81058 .29384 Mtetra
.805 .757 .809 r
.81058 .29384 .81813 .30659 .83457 .29095 .82713 .27829 Mtetra
.789 .755 .822 r
.82713 .27829 .83457 .29095 .85118 .2768 .84383 .2643 Mtetra
.654 .742 .914 r
.22424 .43596 .23372 .44464 .24768 .44017 .23824 .4315 Mtetra
.649 .742 .917 r
.23824 .4315 .24768 .44017 .26171 .43582 .25231 .4272 Mtetra
.641 .742 .922 r
.25231 .4272 .26171 .43582 .2758 .43165 .26643 .42311 Mtetra
.631 .742 .928 r
.26643 .42311 .2758 .43165 .28995 .42775 .28061 .41935 Mtetra
.615 .742 .936 r
.28061 .41935 .28995 .42775 .30416 .42422 .29485 .41601 Mtetra
.592 .741 .947 r
.29485 .41601 .30416 .42422 .31842 .42118 .30914 .41324 Mtetra
.559 .738 .96 r
.30914 .41324 .31842 .42118 .33274 .41878 .32348 .41121 Mtetra
.509 .73 .973 r
.32348 .41121 .33274 .41878 .34712 .41719 .33787 .4101 Mtetra
.435 .713 .982 r
.33787 .4101 .34712 .41719 .36155 .41658 .35232 .41009 Mtetra
.324 .676 .977 r
.35232 .41009 .36155 .41658 .37605 .41716 .36682 .41137 Mtetra
.165 .604 .936 r
.36682 .41137 .37605 .41716 .39063 .41908 .38141 .41413 Mtetra
0 .486 .836 r
.38141 .41413 .39063 .41908 .40529 .42248 .39608 .41847 Mtetra
0 .33 .676 r
.39608 .41847 .40529 .42248 .42007 .42746 .41087 .42448 Mtetra
.42 0 0 r
.41087 .42448 .42007 .42746 .43498 .43403 .42579 .43212 Mtetra
.536 0 0 r
.42579 .43212 .43498 .43403 .45004 .44211 .44088 .44127 Mtetra
.604 .036 0 r
.44088 .44127 .45004 .44211 .4653 .45147 .45617 .45165 Mtetra
.639 .087 0 r
.45617 .45165 .4653 .45147 .48077 .4618 .47169 .46287 Mtetra
.65 .108 0 r
.47169 .46287 .48077 .4618 .49647 .47262 .48745 .47438 Mtetra
.642 .102 0 r
.48745 .47438 .49647 .47262 .51242 .48334 .50347 .48553 Mtetra
.612 .067 0 r
.50347 .48553 .51242 .48334 .52862 .49327 .51975 .49556 Mtetra
.554 0 0 r
.51975 .49556 .52862 .49327 .54505 .50167 .53627 .5037 Mtetra
.445 0 0 r
.53627 .5037 .54505 .50167 .5617 .50781 .553 .5092 Mtetra
.244 0 0 r
.553 .5092 .5617 .50781 .5785 .51104 .56989 .51143 Mtetra
.091 .649 .738 r
.56989 .51143 .5785 .51104 .59543 .51083 .5869 .50991 Mtetra
.471 .886 .927 r
.5869 .50991 .59543 .51083 .6124 .50686 .60395 .50439 Mtetra
.714 .951 .952 r
.60395 .50439 .6124 .50686 .62937 .49904 .62099 .49487 Mtetra
.819 .926 .905 r
.62099 .49487 .62937 .49904 .64629 .48751 .63796 .4816 Mtetra
.859 .884 .854 r
.63796 .4816 .64629 .48751 .6631 .47264 .65483 .46506 Mtetra
.873 .848 .816 r
.65483 .46506 .6631 .47264 .67979 .45499 .67157 .44588 Mtetra
.875 .819 .79 r
.67157 .44588 .67979 .45499 .69635 .43525 .68817 .42482 Mtetra
.873 .798 .774 r
.68817 .42482 .69635 .43525 .71278 .41415 .70465 .40265 Mtetra
.867 .783 .765 r
.70465 .40265 .71278 .41415 .7291 .39242 .72104 .38011 Mtetra
.86 .771 .763 r
.72104 .38011 .7291 .39242 .74536 .37074 .73736 .35788 Mtetra
.851 .764 .765 r
.73736 .35788 .74536 .37074 .7616 .34967 .75367 .33648 Mtetra
.84 .758 .772 r
.75367 .33648 .7616 .34967 .77785 .32964 .77001 .31633 Mtetra
.828 .755 .782 r
.77001 .31633 .77785 .32964 .79416 .31098 .78641 .29768 Mtetra
.815 .752 .794 r
.78641 .29768 .79416 .31098 .81058 .29384 .80293 .28067 Mtetra
.8 .751 .808 r
.80293 .28067 .81058 .29384 .82713 .27829 .81958 .26531 Mtetra
.783 .75 .823 r
.81958 .26531 .82713 .27829 .84383 .2643 .8364 .25155 Mtetra
.652 .742 .916 r
.21467 .4272 .22424 .43596 .23824 .4315 .22871 .42277 Mtetra
.646 .742 .919 r
.22871 .42277 .23824 .4315 .25231 .4272 .24281 .41853 Mtetra
.637 .742 .924 r
.24281 .41853 .25231 .4272 .26643 .42311 .25696 .41455 Mtetra
.624 .742 .932 r
.25696 .41455 .26643 .42311 .28061 .41935 .27117 .41094 Mtetra
.605 .741 .941 r
.27117 .41094 .28061 .41935 .29485 .41601 .28543 .40783 Mtetra
.578 .739 .952 r
.28543 .40783 .29485 .41601 .30914 .41324 .29974 .40538 Mtetra
.537 .734 .966 r
.29974 .40538 .30914 .41324 .32348 .41121 .3141 .40375 Mtetra
.476 .722 .978 r
.3141 .40375 .32348 .41121 .33787 .4101 .3285 .40315 Mtetra
.385 .696 .982 r
.3285 .40315 .33787 .4101 .35232 .41009 .34295 .40377 Mtetra
.25 .643 .962 r
.34295 .40377 .35232 .41009 .36682 .41137 .35747 .40581 Mtetra
.066 .547 .895 r
.35747 .40581 .36682 .41137 .38141 .41413 .37205 .40942 Mtetra
0 .405 .763 r
.37205 .40942 .38141 .41413 .39608 .41847 .38673 .41472 Mtetra
.345 0 0 r
.38673 .41472 .39608 .41847 .41087 .42448 .40152 .42175 Mtetra
.491 0 0 r
.40152 .42175 .41087 .42448 .42579 .43212 .41646 .43043 Mtetra
.583 .007 0 r
.41646 .43043 .42579 .43212 .44088 .44127 .43157 .44059 Mtetra
.633 .075 0 r
.43157 .44059 .44088 .44127 .45617 .45165 .4469 .45189 Mtetra
.657 .111 0 r
.4469 .45189 .45617 .45165 .47169 .46287 .46246 .46387 Mtetra
.659 .119 0 r
.46246 .46387 .47169 .46287 .48745 .47438 .47827 .4759 Mtetra
.642 .1 0 r
.47827 .4759 .48745 .47438 .50347 .48553 .49436 .48726 Mtetra
.601 .047 0 r
.49436 .48726 .50347 .48553 .51975 .49556 .51072 .49716 Mtetra
.521 0 0 r
.51072 .49716 .51975 .49556 .53627 .5037 .52732 .50479 Mtetra
.37 0 0 r
.52732 .50479 .53627 .5037 .553 .5092 .54414 .50941 Mtetra
.091 0 0 r
.54414 .50941 .553 .5092 .56989 .51143 .56112 .51042 Mtetra
.305 .792 .89 r
.56112 .51042 .56989 .51143 .5869 .50991 .57821 .50741 Mtetra
.625 .927 .972 r
.57821 .50741 .5869 .50991 .60395 .50439 .59533 .50021 Mtetra
.779 .924 .932 r
.59533 .50021 .60395 .50439 .62099 .49487 .61244 .48893 Mtetra
.84 .885 .874 r
.61244 .48893 .62099 .49487 .63796 .4816 .62947 .47392 Mtetra
.862 .847 .827 r
.62947 .47392 .63796 .4816 .65483 .46506 .64639 .45576 Mtetra
.87 .816 .794 r
.64639 .45576 .65483 .46506 .67157 .44588 .66318 .43516 Mtetra
.87 .794 .773 r
.66318 .43516 .67157 .44588 .68817 .42482 .67984 .41293 Mtetra
.866 .777 .761 r
.67984 .41293 .68817 .42482 .70465 .40265 .69638 .38986 Mtetra
.861 .765 .756 r
.69638 .38986 .70465 .40265 .72104 .38011 .71283 .36671 Mtetra
.854 .757 .756 r
.71283 .36671 .72104 .38011 .73736 .35788 .72923 .3441 Mtetra
.845 .752 .76 r
.72923 .3441 .73736 .35788 .75367 .33648 .74562 .32256 Mtetra
.834 .748 .769 r
.74562 .32256 .75367 .33648 .77001 .31633 .76205 .30243 Mtetra
.822 .747 .78 r
.76205 .30243 .77001 .31633 .78641 .29768 .77856 .28393 Mtetra
.809 .746 .794 r
.77856 .28393 .78641 .29768 .80293 .28067 .79519 .26714 Mtetra
.794 .746 .808 r
.79519 .26714 .80293 .28067 .81958 .26531 .81195 .25206 Mtetra
.778 .746 .824 r
.81195 .25206 .81958 .26531 .8364 .25155 .82888 .23858 Mtetra
.649 .742 .917 r
.205 .41839 .21467 .4272 .22871 .42277 .21907 .414 Mtetra
.642 .742 .921 r
.21907 .414 .22871 .42277 .24281 .41853 .2332 .40983 Mtetra
.631 .742 .927 r
.2332 .40983 .24281 .41853 .25696 .41455 .24739 .40597 Mtetra
.616 .741 .935 r
.24739 .40597 .25696 .41455 .27117 .41094 .26162 .40254 Mtetra
.593 .74 .946 r
.26162 .40254 .27117 .41094 .28543 .40783 .27591 .39968 Mtetra
.56 .736 .958 r
.27591 .39968 .28543 .40783 .29974 .40538 .29023 .39757 Mtetra
.511 .728 .971 r
.29023 .39757 .29974 .40538 .3141 .40375 .3046 .39639 Mtetra
.437 .71 .981 r
.3046 .39639 .3141 .40375 .3285 .40315 .31901 .39634 Mtetra
.327 .672 .976 r
.31901 .39634 .3285 .40315 .34295 .40377 .33346 .39762 Mtetra
.169 .6 .938 r
.33346 .39762 .34295 .40377 .35747 .40581 .34797 .40043 Mtetra
0 .481 .841 r
.34797 .40043 .35747 .40581 .37205 .40942 .36256 .40492 Mtetra
0 .325 .684 r
.36256 .40492 .37205 .40942 .38673 .41472 .37723 .41117 Mtetra
.424 0 0 r
.37723 .41117 .38673 .41472 .40152 .42175 .39203 .41919 Mtetra
.544 0 0 r
.39203 .41919 .40152 .42175 .41646 .43043 .40698 .42886 Mtetra
.616 .049 0 r
.40698 .42886 .41646 .43043 .43157 .44059 .42211 .43994 Mtetra
.653 .101 0 r
.42211 .43994 .43157 .44059 .4469 .45189 .43746 .45203 Mtetra
.667 .124 0 r
.43746 .45203 .4469 .45189 .46246 .46387 .45307 .46459 Mtetra
.661 .12 0 r
.45307 .46459 .46246 .46387 .47827 .4759 .46894 .47693 Mtetra
.634 .085 0 r
.46894 .47693 .47827 .4759 .49436 .48726 .4851 .48828 Mtetra
.577 .011 0 r
.4851 .48828 .49436 .48726 .51072 .49716 .50153 .4978 Mtetra
.465 0 0 r
.50153 .4978 .51072 .49716 .52732 .50479 .51822 .50467 Mtetra
.247 0 0 r
.51822 .50467 .52732 .50479 .54414 .50941 .53512 .50818 Mtetra
.118 .664 .822 r
.53512 .50818 .54414 .50941 .56112 .51042 .55219 .50777 Mtetra
.501 .876 .976 r
.55219 .50777 .56112 .51042 .57821 .50741 .56935 .50311 Mtetra
.72 .914 .961 r
.56935 .50311 .57821 .50741 .59533 .50021 .58655 .49415 Mtetra
.811 .883 .897 r
.58655 .49415 .59533 .50021 .61244 .48893 .60372 .48108 Mtetra
.846 .844 .842 r
.60372 .48108 .61244 .48893 .62947 .47392 .62081 .46438 Mtetra
.86 .813 .802 r
.62081 .46438 .62947 .47392 .64639 .45576 .63779 .44471 Mtetra
.864 .789 .775 r
.63779 .44471 .64639 .45576 .66318 .43516 .65464 .42284 Mtetra
.863 .771 .759 r
.65464 .42284 .66318 .43516 .67984 .41293 .67136 .39962 Mtetra
.859 .759 .75 r
.67136 .39962 .67984 .41293 .69638 .38986 .68797 .37585 Mtetra
.854 .75 .748 r
.68797 .37585 .69638 .38986 .71283 .36671 .70449 .35227 Mtetra
.847 .745 .75 r
.70449 .35227 .71283 .36671 .72923 .3441 .72098 .32949 Mtetra
.838 .741 .757 r
.72098 .32949 .72923 .3441 .74562 .32256 .73747 .30796 Mtetra
.828 .74 .767 r
.73747 .30796 .74562 .32256 .76205 .30243 .754 .288 Mtetra
.816 .74 .78 r
.754 .288 .76205 .30243 .77856 .28393 .77062 .26977 Mtetra
.803 .74 .794 r
.77062 .26977 .77856 .28393 .79519 .26714 .78736 .25332 Mtetra
.788 .741 .81 r
.78736 .25332 .79519 .26714 .81195 .25206 .80424 .23858 Mtetra
.772 .742 .826 r
.80424 .23858 .81195 .25206 .82888 .23858 .82128 .22543 Mtetra
.646 .742 .919 r
.19523 .40951 .205 .41839 .21907 .414 .20933 .40517 Mtetra
.638 .742 .924 r
.20933 .40517 .21907 .414 .2332 .40983 .22349 .40109 Mtetra
.625 .741 .93 r
.22349 .40109 .2332 .40983 .24739 .40597 .23771 .39737 Mtetra
.607 .74 .939 r
.23771 .39737 .24739 .40597 .26162 .40254 .25197 .39414 Mtetra
.58 .738 .951 r
.25197 .39414 .26162 .40254 .27591 .39968 .26627 .39157 Mtetra
.541 .732 .963 r
.26627 .39157 .27591 .39968 .29023 .39757 .2806 .38982 Mtetra
.482 .72 .976 r
.2806 .38982 .29023 .39757 .3046 .39639 .29498 .38911 Mtetra
.393 .694 .981 r
.29498 .38911 .3046 .39639 .31901 .39634 .30939 .38964 Mtetra
.263 .643 .964 r
.30939 .38964 .31901 .39634 .33346 .39762 .32384 .39161 Mtetra
.083 .551 .904 r
.32384 .39161 .33346 .39762 .34797 .40043 .33835 .39521 Mtetra
0 .412 .78 r
.33835 .39521 .34797 .40043 .36256 .40492 .35292 .40057 Mtetra
.332 0 0 r
.35292 .40057 .36256 .40492 .37723 .41117 .36759 .40775 Mtetra
.485 0 0 r
.36759 .40775 .37723 .41117 .39203 .41919 .38239 .4167 Mtetra
.583 .007 0 r
.38239 .4167 .39203 .41919 .40698 .42886 .39734 .42728 Mtetra
.639 .079 0 r
.39734 .42728 .40698 .42886 .42211 .43994 .4125 .43915 Mtetra
.666 .117 0 r
.4125 .43915 .42211 .43994 .43746 .45203 .42788 .45187 Mtetra
.671 .128 0 r
.42788 .45187 .43746 .45203 .45307 .46459 .44353 .46481 Mtetra
.656 .109 0 r
.44353 .46481 .45307 .46459 .46894 .47693 .45946 .47724 Mtetra
.616 .056 0 r
.45946 .47724 .46894 .47693 .4851 .48828 .47568 .48832 Mtetra
.534 0 0 r
.47568 .48832 .4851 .48828 .50153 .4978 .4922 .49721 Mtetra
.37 0 0 r
.4922 .49721 .50153 .4978 .51822 .50467 .50897 .50308 Mtetra
0 .519 .734 r
.50897 .50308 .51822 .50467 .53512 .50818 .52595 .50526 Mtetra
.344 .791 .956 r
.52595 .50526 .53512 .50818 .55219 .50777 .5431 .50326 Mtetra
.636 .888 .986 r
.5431 .50326 .55219 .50777 .56935 .50311 .56034 .49685 Mtetra
.769 .876 .925 r
.56034 .49685 .56935 .50311 .58655 .49415 .57761 .48607 Mtetra
.823 .84 .861 r
.57761 .48607 .58655 .49415 .60372 .48108 .59485 .47125 Mtetra
.846 .808 .813 r
.59485 .47125 .60372 .48108 .62081 .46438 .61201 .45295 Mtetra
.854 .783 .781 r
.61201 .45295 .62081 .46438 .63779 .44471 .62905 .43191 Mtetra
.857 .765 .76 r
.62905 .43191 .63779 .44471 .65464 .42284 .64596 .40896 Mtetra
.856 .752 .748 r
.64596 .40896 .65464 .42284 .67136 .39962 .66275 .38495 Mtetra
.852 .743 .742 r
.66275 .38495 .67136 .39962 .68797 .37585 .67943 .3607 Mtetra
.847 .737 .742 r
.67943 .3607 .68797 .37585 .70449 .35227 .69604 .33691 Mtetra
.84 .734 .747 r
.69604 .33691 .70449 .35227 .72098 .32949 .71262 .31414 Mtetra
.832 .732 .755 r
.71262 .31414 .72098 .32949 .73747 .30796 .72921 .29279 Mtetra
.822 .733 .766 r
.72921 .29279 .73747 .30796 .754 .288 .74585 .27314 Mtetra
.81 .734 .78 r
.74585 .27314 .754 .288 .77062 .26977 .76258 .25529 Mtetra
.796 .736 .796 r
.76258 .25529 .77062 .26977 .78736 .25332 .77944 .23924 Mtetra
.782 .737 .812 r
.77944 .23924 .78736 .25332 .80424 .23858 .79644 .22491 Mtetra
.766 .739 .829 r
.79644 .22491 .80424 .23858 .82128 .22543 .81361 .21214 Mtetra
.643 .741 .92 r
.18535 .40057 .19523 .40951 .20933 .40517 .19949 .39629 Mtetra
.633 .741 .926 r
.19949 .39629 .20933 .40517 .22349 .40109 .21368 .39232 Mtetra
.618 .741 .934 r
.21368 .39232 .22349 .40109 .23771 .39737 .22792 .38875 Mtetra
.597 .739 .943 r
.22792 .38875 .23771 .39737 .25197 .39414 .2422 .38575 Mtetra
.565 .735 .955 r
.2422 .38575 .25197 .39414 .26627 .39157 .25651 .38348 Mtetra
.518 .727 .968 r
.25651 .38348 .26627 .39157 .2806 .38982 .27086 .38213 Mtetra
.448 .71 .978 r
.27086 .38213 .2806 .38982 .29498 .38911 .28523 .38192 Mtetra
.344 .674 .977 r
.28523 .38192 .29498 .38911 .30939 .38964 .29964 .38304 Mtetra
.193 .607 .946 r
.29964 .38304 .30939 .38964 .32384 .39161 .31408 .38571 Mtetra
0 .495 .862 r
.31408 .38571 .32384 .39161 .33835 .39521 .32858 .39009 Mtetra
0 .344 .717 r
.32858 .39009 .33835 .39521 .35292 .40057 .34314 .3963 Mtetra
.4 0 0 r
.34314 .3963 .35292 .40057 .36759 .40775 .35781 .40435 Mtetra
.53 0 0 r
.35781 .40435 .36759 .40775 .38239 .4167 .3726 .41417 Mtetra
.61 .04 0 r
.3726 .41417 .38239 .4167 .39734 .42728 .38757 .42553 Mtetra
.653 .097 0 r
.38757 .42553 .39734 .42728 .4125 .43915 .40274 .43805 Mtetra
.671 .123 0 r
.40274 .43805 .4125 .43915 .42788 .45187 .41815 .4512 Mtetra
.668 .12 0 r
.41815 .4512 .42788 .45187 .44353 .46481 .43384 .46431 Mtetra
.642 .086 0 r
.43384 .46431 .44353 .46481 .45946 .47724 .44983 .47658 Mtetra
.582 .008 0 r
.44983 .47658 .45946 .47724 .47568 .48832 .46613 .48714 Mtetra
.46 0 0 r
.46613 .48714 .47568 .48832 .4922 .49721 .48272 .49513 Mtetra
.219 0 0 r
.48272 .49513 .4922 .49721 .50897 .50308 .49957 .49977 Mtetra
.166 .673 .904 r
.49957 .49977 .50897 .50308 .52595 .50526 .51665 .50044 Mtetra
.523 .84 .999 r
.51665 .50044 .52595 .50526 .5431 .50326 .53388 .49672 Mtetra
.711 .86 .953 r
.53388 .49672 .5431 .50326 .56034 .49685 .5512 .48849 Mtetra
.792 .832 .883 r
.5512 .48849 .56034 .49685 .57761 .48607 .56854 .47591 Mtetra
.826 .801 .828 r
.56854 .47591 .57761 .48607 .59485 .47125 .58584 .45942 Mtetra
.841 .776 .789 r
.58584 .45942 .59485 .47125 .61201 .45295 .60306 .43966 Mtetra
.848 .758 .763 r
.60306 .43966 .61201 .45295 .62905 .43191 .62017 .41743 Mtetra
.849 .744 .747 r
.62017 .41743 .62905 .43191 .64596 .40896 .63715 .39361 Mtetra
.848 .735 .739 r
.63715 .39361 .64596 .40896 .66275 .38495 .65401 .36905 Mtetra
.845 .729 .736 r
.65401 .36905 .66275 .38495 .67943 .3607 .67077 .34453 Mtetra
.84 .726 .738 r
.67077 .34453 .67943 .3607 .69604 .33691 .68748 .32073 Mtetra
.833 .724 .745 r
.68748 .32073 .69604 .33691 .71262 .31414 .70416 .29815 Mtetra
.825 .725 .754 r
.70416 .29815 .71262 .31414 .72921 .29279 .72085 .27715 Mtetra
.815 .726 .767 r
.72085 .27715 .72921 .29279 .74585 .27314 .73761 .25792 Mtetra
.803 .729 .782 r
.73761 .25792 .74585 .27314 .76258 .25529 .75447 .24055 Mtetra
.79 .732 .799 r
.75447 .24055 .76258 .25529 .77944 .23924 .77145 .22498 Mtetra
.775 .734 .815 r
.77145 .22498 .77944 .23924 .79644 .22491 .78857 .2111 Mtetra
.759 .737 .832 r
.78857 .2111 .79644 .22491 .81361 .21214 .80586 .19873 Mtetra
.639 .741 .922 r
.17537 .39158 .18535 .40057 .19949 .39629 .18954 .38737 Mtetra
.628 .741 .929 r
.18954 .38737 .19949 .39629 .21368 .39232 .20376 .38351 Mtetra
.61 .74 .937 r
.20376 .38351 .21368 .39232 .22792 .38875 .21801 .38012 Mtetra
.585 .737 .948 r
.21801 .38012 .22792 .38875 .2422 .38575 .23231 .37737 Mtetra
.548 .732 .96 r
.23231 .37737 .2422 .38575 .25651 .38348 .24663 .37542 Mtetra
.493 .72 .972 r
.24663 .37542 .25651 .38348 .27086 .38213 .26098 .37449 Mtetra
.412 .697 .979 r
.26098 .37449 .27086 .38213 .28523 .38192 .27536 .37478 Mtetra
.291 .65 .969 r
.27536 .37478 .28523 .38192 .29964 .38304 .28976 .37651 Mtetra
.122 .567 .921 r
.28976 .37651 .29964 .38304 .31408 .38571 .30419 .37987 Mtetra
0 .439 .815 r
.30419 .37987 .31408 .38571 .32858 .39009 .31867 .38501 Mtetra
0 .282 .658 r
.31867 .38501 .32858 .39009 .34314 .3963 .33323 .39202 Mtetra
.452 0 0 r
.33323 .39202 .34314 .3963 .35781 .40435 .34788 .40088 Mtetra
.561 0 0 r
.34788 .40088 .35781 .40435 .3726 .41417 .36267 .41145 Mtetra
.626 .061 0 r
.36267 .41145 .3726 .41417 .38757 .42553 .37764 .42345 Mtetra
.659 .105 0 r
.37764 .42345 .38757 .42553 .40274 .43805 .39283 .43643 Mtetra
.668 .118 0 r
.39283 .43643 .40274 .43805 .41815 .4512 .40828 .44981 Mtetra
.655 .101 0 r
.40828 .44981 .41815 .4512 .43384 .46431 .42402 .46285 Mtetra
.614 .046 0 r
.42402 .46285 .43384 .46431 .44983 .47658 .44008 .4747 Mtetra
.523 0 0 r
.44008 .4747 .44983 .47658 .46613 .48714 .45645 .48448 Mtetra
.339 0 0 r
.45645 .48448 .46613 .48714 .48272 .49513 .47312 .49135 Mtetra
0 .539 .828 r
.47312 .49135 .48272 .49513 .49957 .49977 .49006 .49455 Mtetra
.381 .764 .99 r
.49006 .49455 .49957 .49977 .51665 .50044 .50721 .49354 Mtetra
.632 .831 .977 r
.50721 .49354 .51665 .50044 .53388 .49672 .52453 .48802 Mtetra
.748 .819 .907 r
.52453 .48802 .53388 .49672 .5512 .48849 .54192 .47797 Mtetra
.8 .792 .845 r
.54192 .47797 .5512 .48849 .56854 .47591 .55934 .46366 Mtetra
.824 .768 .8 r
.55934 .46366 .56854 .47591 .58584 .45942 .57671 .44562 Mtetra
.835 .75 .769 r
.57671 .44562 .58584 .45942 .60306 .43966 .594 .42457 Mtetra
.84 .736 .749 r
.594 .42457 .60306 .43966 .62017 .41743 .61117 .40138 Mtetra
.842 .727 .737 r
.61117 .40138 .62017 .41743 .63715 .39361 .62823 .37692 Mtetra
.84 .721 .732 r
.62823 .37692 .63715 .39361 .65401 .36905 .64517 .35203 Mtetra
.837 .717 .732 r
.64517 .35203 .65401 .36905 .67077 .34453 .66202 .32748 Mtetra
.833 .716 .736 r
.66202 .32748 .67077 .34453 .68748 .32073 .67882 .30386 Mtetra
.826 .717 .744 r
.67882 .30386 .68748 .32073 .70416 .29815 .6956 .28165 Mtetra
.818 .718 .755 r
.6956 .28165 .70416 .29815 .72085 .27715 .71242 .26112 Mtetra
.808 .721 .769 r
.71242 .26112 .72085 .27715 .73761 .25792 .72929 .24244 Mtetra
.796 .725 .785 r
.72929 .24244 .73761 .25792 .75447 .24055 .74627 .22562 Mtetra
.783 .729 .802 r
.74627 .22562 .75447 .24055 .77145 .22498 .76338 .21059 Mtetra
.768 .732 .819 r
.76338 .21059 .77145 .22498 .78857 .2111 .78063 .19719 Mtetra
.753 .735 .836 r
.78063 .19719 .78857 .2111 .80586 .19873 .79804 .18525 Mtetra
.635 .741 .925 r
.16528 .38252 .17537 .39158 .18954 .38737 .17948 .3784 Mtetra
.622 .74 .932 r
.17948 .3784 .18954 .38737 .20376 .38351 .19372 .37467 Mtetra
.602 .738 .941 r
.19372 .37467 .20376 .38351 .21801 .38012 .208 .37147 Mtetra
.573 .735 .952 r
.208 .37147 .21801 .38012 .23231 .37737 .22231 .36898 Mtetra
.53 .727 .964 r
.22231 .36898 .23231 .37737 .24663 .37542 .23664 .36737 Mtetra
.466 .712 .975 r
.23664 .36737 .24663 .37542 .26098 .37449 .25099 .36686 Mtetra
.372 .681 .978 r
.25099 .36686 .26098 .37449 .27536 .37478 .26536 .36767 Mtetra
.235 .622 .957 r
.26536 .36767 .27536 .37478 .28976 .37651 .27974 .37 Mtetra
.053 .524 .891 r
.27974 .37 .28976 .37651 .30419 .37987 .29416 .37403 Mtetra
0 .384 .769 r
.29416 .37403 .30419 .37987 .31867 .38501 .30863 .3799 Mtetra
.345 0 0 r
.30863 .3799 .31867 .38501 .33323 .39202 .32317 .38764 Mtetra
.489 0 0 r
.32317 .38764 .33323 .39202 .34788 .40088 .33782 .3972 Mtetra
.581 .008 0 r
.33782 .3972 .34788 .40088 .36267 .41145 .35261 .4084 Mtetra
.634 .071 0 r
.35261 .4084 .36267 .41145 .37764 .42345 .36759 .42087 Mtetra
.657 .102 0 r
.36759 .42087 .37764 .42345 .39283 .43643 .3828 .43412 Mtetra
.657 .101 0 r
.3828 .43412 .39283 .43643 .40828 .44981 .39829 .44749 Mtetra
.63 .066 0 r
.39829 .44749 .40828 .44981 .42402 .46285 .41408 .4602 Mtetra
.564 0 0 r
.41408 .4602 .42402 .46285 .44008 .4747 .4302 .47138 Mtetra
.424 0 0 r
.4302 .47138 .44008 .4747 .45645 .48448 .44665 .48014 Mtetra
0 .41 .745 r
.44665 .48014 .45645 .48448 .47312 .49135 .4634 .48566 Mtetra
.223 .663 .954 r
.4634 .48566 .47312 .49135 .49006 .49455 .48043 .48726 Mtetra
.53 .784 .991 r
.48043 .48726 .49006 .49455 .50721 .49354 .49767 .48448 Mtetra
.691 .799 .931 r
.49767 .48448 .50721 .49354 .52453 .48802 .51506 .47712 Mtetra
.766 .78 .865 r
.51506 .47712 .52453 .48802 .54192 .47797 .53254 .46528 Mtetra
.801 .759 .814 r
.53254 .46528 .54192 .47797 .55934 .46366 .55003 .44934 Mtetra
.819 .741 .778 r
.55003 .44934 .55934 .46366 .57671 .44562 .56747 .42992 Mtetra
.829 .728 .753 r
.56747 .42992 .57671 .44562 .594 .42457 .58483 .40782 Mtetra
.833 .719 .738 r
.58483 .40782 .594 .42457 .61117 .40138 .60207 .38389 Mtetra
.834 .712 .73 r
.60207 .38389 .61117 .40138 .62823 .37692 .6192 .35904 Mtetra
.833 .709 .727 r
.6192 .35904 .62823 .37692 .64517 .35203 .63623 .33407 Mtetra
.83 .708 .729 r
.63623 .33407 .64517 .35203 .66202 .32748 .65317 .30968 Mtetra
.826 .708 .735 r
.65317 .30968 .66202 .32748 .67882 .30386 .67007 .28645 Mtetra
.819 .71 .745 r
.67007 .28645 .67882 .30386 .6956 .28165 .68697 .26475 Mtetra
.811 .713 .757 r
.68697 .26475 .6956 .28165 .71242 .26112 .7039 .24482 Mtetra
.801 .717 .772 r
.7039 .24482 .71242 .26112 .72929 .24244 .7209 .22676 Mtetra
.789 .722 .789 r
.7209 .22676 .72929 .24244 .74627 .22562 .738 .21056 Mtetra
.776 .726 .807 r
.738 .21056 .74627 .22562 .76338 .21059 .75523 .1961 Mtetra
.761 .73 .824 r
.75523 .1961 .76338 .21059 .78063 .19719 .77261 .18322 Mtetra
.746 .734 .841 r
.77261 .18322 .78063 .19719 .79804 .18525 .79014 .1717 Mtetra
.631 .74 .927 r
.15508 .3734 .16528 .38252 .17948 .3784 .1693 .36937 Mtetra
.615 .739 .934 r
.1693 .36937 .17948 .3784 .19372 .37467 .18357 .36579 Mtetra
.592 .737 .944 r
.18357 .36579 .19372 .37467 .208 .37147 .19786 .3628 Mtetra
.559 .732 .956 r
.19786 .3628 .208 .37147 .22231 .36898 .21218 .36058 Mtetra
.51 .722 .968 r
.21218 .36058 .22231 .36898 .23664 .36737 .22652 .35932 Mtetra
.437 .701 .977 r
.22652 .35932 .23664 .36737 .25099 .36686 .24087 .35924 Mtetra
.33 .662 .973 r
.24087 .35924 .25099 .36686 .26536 .36767 .25522 .36056 Mtetra
.18 .592 .941 r
.25522 .36056 .26536 .36767 .27974 .37 .2696 .36347 Mtetra
0 .48 .86 r
.2696 .36347 .27974 .37 .29416 .37403 .284 .36814 Mtetra
0 .336 .727 r
.284 .36814 .29416 .37403 .30863 .3799 .29845 .37466 Mtetra
.387 0 0 r
.29845 .37466 .30863 .3799 .32317 .38764 .31298 .38305 Mtetra
.512 0 0 r
.31298 .38305 .32317 .38764 .33782 .3972 .32762 .3932 Mtetra
.59 .02 0 r
.32762 .3932 .33782 .3972 .35261 .4084 .34241 .40486 Mtetra
.632 .07 0 r
.34241 .40486 .35261 .4084 .36759 .42087 .35741 .41762 Mtetra
.646 .087 0 r
.35741 .41762 .36759 .42087 .3828 .43412 .37265 .43091 Mtetra
.633 .071 0 r
.37265 .43091 .3828 .43412 .39829 .44749 .38818 .44403 Mtetra
.586 .013 0 r
.38818 .44403 .39829 .44749 .41408 .4602 .40403 .45616 Mtetra
.48 0 0 r
.40403 .45616 .41408 .4602 .4302 .47138 .42022 .46642 Mtetra
0 .302 .67 r
.42022 .46642 .4302 .47138 .44665 .48014 .43675 .47393 Mtetra
.068 .549 .896 r
.43675 .47393 .44665 .48014 .4634 .48566 .45359 .47792 Mtetra
.408 .718 .987 r
.45359 .47792 .4634 .48566 .48043 .48726 .4707 .47779 Mtetra
.618 .767 .952 r
.4707 .47779 .48043 .48726 .49767 .48448 .48803 .47318 Mtetra
.722 .763 .886 r
.48803 .47318 .49767 .48448 .51506 .47712 .50551 .464 Mtetra
.773 .747 .829 r
.50551 .464 .51506 .47712 .53254 .46528 .52306 .45047 Mtetra
.8 .731 .788 r
.52306 .45047 .53254 .46528 .55003 .44934 .54062 .43307 Mtetra
.814 .719 .76 r
.54062 .43307 .55003 .44934 .56747 .42992 .55813 .41248 Mtetra
.822 .71 .741 r
.55813 .41248 .56747 .42992 .58483 .40782 .57556 .38955 Mtetra
.826 .704 .73 r
.57556 .38955 .58483 .40782 .60207 .38389 .59288 .36515 Mtetra
.827 .7 .724 r
.59288 .36515 .60207 .38389 .6192 .35904 .61009 .34014 Mtetra
.826 .699 .724 r
.61009 .34014 .6192 .35904 .63623 .33407 .6272 .31531 Mtetra
.823 .699 .728 r
.6272 .31531 .63623 .33407 .65317 .30968 .64424 .29131 Mtetra
.819 .702 .736 r
.64424 .29131 .65317 .30968 .67007 .28645 .66125 .26861 Mtetra
.812 .705 .747 r
.66125 .26861 .67007 .28645 .68697 .26475 .67826 .24756 Mtetra
.804 .709 .761 r
.67826 .24756 .68697 .26475 .7039 .24482 .69531 .22833 Mtetra
.794 .714 .777 r
.69531 .22833 .7039 .24482 .7209 .22676 .71243 .21098 Mtetra
.782 .72 .794 r
.71243 .21098 .7209 .22676 .738 .21056 .72966 .19543 Mtetra
.769 .725 .812 r
.72966 .19543 .738 .21056 .75523 .1961 .74702 .18157 Mtetra
.754 .729 .829 r
.74702 .18157 .75523 .1961 .77261 .18322 .76452 .1692 Mtetra
.739 .733 .845 r
.76452 .1692 .77261 .18322 .79014 .1717 .78217 .15812 Mtetra
.626 .74 .929 r
.14477 .36422 .15508 .3734 .1693 .36937 .15902 .3603 Mtetra
.608 .738 .937 r
.15902 .3603 .1693 .36937 .18357 .36579 .1733 .35687 Mtetra
.582 .735 .948 r
.1733 .35687 .18357 .36579 .19786 .3628 .18761 .35409 Mtetra
.544 .728 .96 r
.18761 .35409 .19786 .3628 .21218 .36058 .20194 .35215 Mtetra
.488 .715 .971 r
.20194 .35215 .21218 .36058 .22652 .35932 .21627 .35125 Mtetra
.406 .689 .977 r
.21627 .35125 .22652 .35932 .24087 .35924 .23062 .3516 Mtetra
.288 .642 .966 r
.23062 .3516 .24087 .35924 .25522 .36056 .24496 .35341 Mtetra
.128 .56 .922 r
.24496 .35341 .25522 .36056 .2696 .36347 .25932 .35687 Mtetra
0 .44 .829 r
.25932 .35687 .2696 .36347 .284 .36814 .27371 .36212 Mtetra
0 .297 .694 r
.27371 .36212 .284 .36814 .29845 .37466 .28815 .36922 Mtetra
.415 0 0 r
.28815 .36922 .29845 .37466 .31298 .38305 .30266 .37815 Mtetra
.523 0 0 r
.30266 .37815 .31298 .38305 .32762 .3932 .3173 .38874 Mtetra
.589 .02 0 r
.3173 .38874 .32762 .3932 .34241 .40486 .3321 .40068 Mtetra
.62 .057 0 r
.3321 .40068 .34241 .40486 .35741 .41762 .34712 .41351 Mtetra
.622 .059 0 r
.34712 .41351 .35741 .41762 .37265 .43091 .36239 .42662 Mtetra
.591 .023 0 r
.36239 .42662 .37265 .43091 .38818 .44403 .37797 .43925 Mtetra
.512 0 0 r
.37797 .43925 .38818 .44403 .40403 .45616 .39389 .45055 Mtetra
.349 0 0 r
.39389 .45055 .40403 .45616 .42022 .46642 .41016 .45966 Mtetra
0 .44 .829 r
.41016 .45966 .42022 .46642 .43675 .47393 .42677 .46572 Mtetra
.275 .635 .964 r
.42677 .46572 .43675 .47393 .45359 .47792 .4437 .46805 Mtetra
.528 .724 .963 r
.4437 .46805 .45359 .47792 .4707 .47779 .4609 .46611 Mtetra
.666 .74 .905 r
.4609 .46611 .4707 .47779 .48803 .47318 .47831 .45967 Mtetra
.737 .732 .846 r
.47831 .45967 .48803 .47318 .50551 .464 .49587 .44875 Mtetra
.775 .72 .801 r
.49587 .44875 .50551 .464 .52306 .45047 .5135 .43367 Mtetra
.796 .709 .768 r
.5135 .43367 .52306 .45047 .54062 .43307 .53113 .41499 Mtetra
.808 .7 .746 r
.53113 .41499 .54062 .43307 .55813 .41248 .54871 .39348 Mtetra
.815 .695 .732 r
.54871 .39348 .55813 .41248 .57556 .38955 .56621 .36996 Mtetra
.819 .692 .724 r
.56621 .36996 .57556 .38955 .59288 .36515 .5836 .34534 Mtetra
.82 .69 .721 r
.5836 .34534 .59288 .36515 .61009 .34014 .6009 .32043 Mtetra
.819 .691 .723 r
.6009 .32043 .61009 .34014 .6272 .31531 .6181 .29595 Mtetra
.816 .693 .729 r
.6181 .29595 .6272 .31531 .64424 .29131 .63524 .2725 Mtetra
.812 .697 .738 r
.63524 .2725 .64424 .29131 .66125 .26861 .65236 .25049 Mtetra
.805 .701 .75 r
.65236 .25049 .66125 .26861 .67826 .24756 .66948 .2302 Mtetra
.797 .707 .765 r
.66948 .2302 .67826 .24756 .69531 .22833 .68665 .21175 Mtetra
.787 .712 .782 r
.68665 .21175 .69531 .22833 .71243 .21098 .7039 .19514 Mtetra
.775 .718 .8 r
.7039 .19514 .71243 .21098 .72966 .19543 .72125 .18029 Mtetra
.761 .724 .818 r
.72125 .18029 .72966 .19543 .74702 .18157 .73873 .16703 Mtetra
.747 .728 .835 r
.73873 .16703 .74702 .18157 .76452 .1692 .75635 .15517 Mtetra
.733 .732 .85 r
.75635 .15517 .76452 .1692 .78217 .15812 .77412 .1445 Mtetra
.62 .739 .931 r
.13434 .35498 .14477 .36422 .15902 .3603 .14862 .35117 Mtetra
.6 .737 .94 r
.14862 .35117 .15902 .3603 .1733 .35687 .16292 .3479 Mtetra
.571 .732 .951 r
.16292 .3479 .1733 .35687 .18761 .35409 .17724 .34534 Mtetra
.528 .724 .963 r
.17724 .34534 .18761 .35409 .20194 .35215 .19157 .34368 Mtetra
.466 .707 .973 r
.19157 .34368 .20194 .35215 .21627 .35125 .20591 .34313 Mtetra
.376 .676 .975 r
.20591 .34313 .21627 .35125 .23062 .3516 .22024 .34389 Mtetra
.248 .62 .958 r
.22024 .34389 .23062 .3516 .24496 .35341 .23458 .34616 Mtetra
.081 .53 .904 r
.23458 .34616 .24496 .35341 .25932 .35687 .24892 .35012 Mtetra
0 .406 .804 r
.24892 .35012 .25932 .35687 .27371 .36212 .26329 .35588 Mtetra
0 .268 .671 r
.26329 .35588 .27371 .36212 .28815 .36922 .27771 .36347 Mtetra
.428 0 0 r
.27771 .36347 .28815 .36922 .30266 .37815 .29222 .3728 Mtetra
.522 0 0 r
.29222 .3728 .30266 .37815 .3173 .38874 .30686 .38367 Mtetra
.576 .009 0 r
.30686 .38367 .3173 .38874 .3321 .40068 .32168 .39571 Mtetra
.595 .031 0 r
.32168 .39571 .3321 .40068 .34712 .41351 .33672 .40841 Mtetra
.581 .015 0 r
.33672 .40841 .34712 .41351 .36239 .42662 .35204 .42109 Mtetra
.523 0 0 r
.35204 .42109 .36239 .42662 .37797 .43925 .36769 .43298 Mtetra
.397 0 0 r
.36769 .43298 .37797 .43925 .39389 .45055 .38367 .44323 Mtetra
0 .349 .768 r
.38367 .44323 .39389 .45055 .41016 .45966 .40002 .45098 Mtetra
.146 .546 .924 r
.40002 .45098 .41016 .45966 .42677 .46572 .41672 .45545 Mtetra
.425 .668 .963 r
.41672 .45545 .42677 .46572 .4437 .46805 .43374 .45601 Mtetra
.599 .709 .921 r
.43374 .45601 .4437 .46805 .4609 .46611 .45103 .45225 Mtetra
.694 .713 .863 r
.45103 .45225 .4609 .46611 .47831 .45967 .46853 .44402 Mtetra
.745 .706 .815 r
.46853 .44402 .47831 .45967 .49587 .44875 .48617 .43148 Mtetra
.775 .698 .778 r
.48617 .43148 .49587 .44875 .5135 .43367 .50387 .41503 Mtetra
.792 .691 .752 r
.50387 .41503 .5135 .43367 .53113 .41499 .52157 .39531 Mtetra
.803 .686 .735 r
.52157 .39531 .53113 .41499 .54871 .39348 .53922 .37311 Mtetra
.809 .683 .725 r
.53922 .37311 .54871 .39348 .56621 .36996 .55679 .34928 Mtetra
.812 .682 .72 r
.55679 .34928 .56621 .36996 .5836 .34534 .57426 .32468 Mtetra
.813 .682 .719 r
.57426 .32468 .5836 .34534 .6009 .32043 .59164 .30008 Mtetra
.812 .684 .723 r
.59164 .30008 .6009 .32043 .6181 .29595 .60893 .27616 Mtetra
.81 .688 .73 r
.60893 .27616 .6181 .29595 .63524 .2725 .62617 .25342 Mtetra
.805 .693 .741 r
.62617 .25342 .63524 .2725 .65236 .25049 .6434 .23222 Mtetra
.798 .698 .755 r
.6434 .23222 .65236 .25049 .66948 .2302 .66064 .21277 Mtetra
.79 .705 .771 r
.66064 .21277 .66948 .2302 .68665 .21175 .67792 .19515 Mtetra
.779 .711 .788 r
.67792 .19515 .68665 .21175 .7039 .19514 .6953 .17932 Mtetra
.767 .718 .806 r
.6953 .17932 .7039 .19514 .72125 .18029 .71277 .16516 Mtetra
.754 .723 .824 r
.71277 .16516 .72125 .18029 .73873 .16703 .73038 .1525 Mtetra
.74 .728 .841 r
.73038 .1525 .73873 .16703 .75635 .15517 .74812 .14115 Mtetra
.726 .732 .856 r
.74812 .14115 .75635 .15517 .77412 .1445 .766 .13087 Mtetra
.615 .738 .934 r
.1238 .34566 .13434 .35498 .14862 .35117 .1381 .34197 Mtetra
.592 .735 .943 r
.1381 .34197 .14862 .35117 .16292 .3479 .15241 .33887 Mtetra
.559 .729 .954 r
.15241 .33887 .16292 .3479 .17724 .34534 .16675 .33653 Mtetra
.512 .718 .966 r
.16675 .33653 .17724 .34534 .19157 .34368 .18108 .33515 Mtetra
.444 .698 .974 r
.18108 .33515 .19157 .34368 .20591 .34313 .19541 .33493 Mtetra
.346 .661 .972 r
.19541 .33493 .20591 .34313 .22024 .34389 .20974 .33608 Mtetra
.212 .599 .948 r
.20974 .33608 .22024 .34389 .23458 .34616 .22406 .33878 Mtetra
.043 .503 .887 r
.22406 .33878 .23458 .34616 .24892 .35012 .23839 .34317 Mtetra
0 .38 .785 r
.23839 .34317 .24892 .35012 .26329 .35588 .25275 .34935 Mtetra
0 .25 .661 r
.25275 .34935 .26329 .35588 .27771 .36347 .26717 .3573 Mtetra
.428 0 0 r
.26717 .3573 .27771 .36347 .29222 .3728 .28168 .3669 Mtetra
.508 0 0 r
.28168 .3669 .29222 .3728 .30686 .38367 .29632 .37787 Mtetra
.548 0 0 r
.29632 .37787 .30686 .38367 .32168 .39571 .31116 .38981 Mtetra
.552 0 0 r
.31116 .38981 .32168 .39571 .33672 .40841 .32624 .40214 Mtetra
.515 0 0 r
.32624 .40214 .33672 .40841 .35204 .42109 .34162 .41417 Mtetra
.419 0 0 r
.34162 .41417 .35204 .42109 .36769 .43298 .35733 .42511 Mtetra
0 .281 .721 r
.35733 .42511 .36769 .43298 .38367 .44323 .3734 .4341 Mtetra
.034 .462 .878 r
.3734 .4341 .38367 .44323 .40002 .45098 .38984 .44033 Mtetra
.318 .603 .949 r
.38984 .44033 .40002 .45098 .41672 .45545 .40663 .44309 Mtetra
.522 .67 .93 r
.40663 .44309 .41672 .45545 .43374 .45601 .42374 .44184 Mtetra
.642 .69 .879 r
.42374 .44184 .43374 .45601 .45103 .45225 .44113 .43628 Mtetra
.71 .69 .829 r
.44113 .43628 .45103 .45225 .46853 .44402 .45871 .42637 Mtetra
.749 .685 .79 r
.45871 .42637 .46853 .44402 .48617 .43148 .47642 .41237 Mtetra
.773 .68 .761 r
.47642 .41237 .48617 .43148 .50387 .41503 .49419 .39477 Mtetra
.788 .676 .741 r
.49419 .39477 .50387 .41503 .52157 .39531 .51196 .37425 Mtetra
.797 .674 .727 r
.51196 .37425 .52157 .39531 .53922 .37311 .52968 .35162 Mtetra
.803 .673 .72 r
.52968 .35162 .53922 .37311 .55679 .34928 .54732 .32773 Mtetra
.806 .674 .718 r
.54732 .32773 .55679 .34928 .57426 .32468 .56486 .30338 Mtetra
.807 .676 .719 r
.56486 .30338 .57426 .32468 .59164 .30008 .58232 .27931 Mtetra
.806 .68 .725 r
.58232 .27931 .59164 .30008 .60893 .27616 .5997 .2561 Mtetra
.803 .684 .734 r
.5997 .2561 .60893 .27616 .62617 .25342 .61704 .2342 Mtetra
.798 .69 .746 r
.61704 .2342 .62617 .25342 .6434 .23222 .63437 .2139 Mtetra
.791 .697 .761 r
.63437 .2139 .6434 .23222 .66064 .21277 .65173 .19536 Mtetra
.782 .704 .777 r
.65173 .19536 .66064 .21277 .67792 .19515 .66914 .1786 Mtetra
.772 .711 .795 r
.66914 .1786 .67792 .19515 .6953 .17932 .68663 .16356 Mtetra
.759 .717 .813 r
.68663 .16356 .6953 .17932 .71277 .16516 .70422 .15009 Mtetra
.746 .723 .831 r
.70422 .15009 .71277 .16516 .73038 .1525 .72195 .13802 Mtetra
.733 .728 .847 r
.72195 .13802 .73038 .1525 .74812 .14115 .73981 .12713 Mtetra
.719 .732 .861 r
.73981 .12713 .74812 .14115 .766 .13087 .75781 .11723 Mtetra
.609 .737 .936 r
.11314 .33628 .1238 .34566 .1381 .34197 .12746 .3327 Mtetra
.584 .733 .946 r
.12746 .3327 .1381 .34197 .15241 .33887 .14179 .32976 Mtetra
.548 .726 .957 r
.14179 .32976 .15241 .33887 .16675 .33653 .15613 .32764 Mtetra
.496 .713 .968 r
.15613 .32764 .16675 .33653 .18108 .33515 .17047 .32653 Mtetra
.422 .689 .974 r
.17047 .32653 .18108 .33515 .19541 .33493 .1848 .32662 Mtetra
.319 .647 .968 r
.1848 .32662 .19541 .33493 .20974 .33608 .19911 .32812 Mtetra
.181 .579 .939 r
.19911 .32812 .20974 .33608 .22406 .33878 .21343 .33119 Mtetra
.015 .481 .873 r
.21343 .33119 .22406 .33878 .23839 .34317 .22775 .33595 Mtetra
0 .362 .775 r
.22775 .33595 .23839 .34317 .25275 .34935 .2421 .34245 Mtetra
0 .243 .663 r
.2421 .34245 .25275 .34935 .26717 .3573 .25651 .35063 Mtetra
.414 0 0 r
.25651 .35063 .26717 .3573 .28168 .3669 .27103 .36033 Mtetra
.479 0 0 r
.27103 .36033 .28168 .3669 .29632 .37787 .28569 .37122 Mtetra
.504 0 0 r
.28569 .37122 .29632 .37787 .31116 .38981 .30057 .38285 Mtetra
.487 0 0 r
.30057 .38285 .31116 .38981 .32624 .40214 .3157 .3946 Mtetra
.418 0 0 r
.3157 .3946 .32624 .40214 .34162 .41417 .33114 .40577 Mtetra
0 .239 .693 r
.33114 .40577 .34162 .41417 .35733 .42511 .34693 .41554 Mtetra
0 .393 .835 r
.34693 .41554 .35733 .42511 .3734 .4341 .36308 .4231 Mtetra
.215 .537 .925 r
.36308 .4231 .3734 .4341 .38984 .44033 .37962 .4277 Mtetra
.437 .625 .932 r
.37962 .4277 .38984 .44033 .40663 .44309 .39651 .42868 Mtetra
.582 .661 .892 r
.39651 .42868 .40663 .44309 .42374 .44184 .41371 .42563 Mtetra
.668 .671 .844 r
.41371 .42563 .42374 .44184 .44113 .43628 .43118 .41835 Mtetra
.719 .671 .802 r
.43118 .41835 .44113 .43628 .45871 .42637 .44885 .40691 Mtetra
.751 .669 .771 r
.44885 .40691 .45871 .42637 .47642 .41237 .46663 .39164 Mtetra
.771 .666 .748 r
.46663 .39164 .47642 .41237 .49419 .39477 .48447 .37312 Mtetra
.784 .665 .732 r
.48447 .37312 .49419 .39477 .51196 .37425 .5023 .35206 Mtetra
.792 .664 .722 r
.5023 .35206 .51196 .37425 .52968 .35162 .52008 .32926 Mtetra
.798 .665 .718 r
.52008 .32926 .52968 .35162 .54732 .32773 .53779 .30554 Mtetra
.8 .668 .717 r
.53779 .30554 .54732 .32773 .56486 .30338 .55541 .28166 Mtetra
.801 .671 .721 r
.55541 .28166 .56486 .30338 .58232 .27931 .57294 .25828 Mtetra
.799 .676 .728 r
.57294 .25828 .58232 .27931 .5997 .2561 .59042 .23593 Mtetra
.796 .682 .738 r
.59042 .23593 .5997 .2561 .61704 .2342 .60786 .21497 Mtetra
.791 .689 .752 r
.60786 .21497 .61704 .2342 .63437 .2139 .62529 .19564 Mtetra
.784 .696 .767 r
.62529 .19564 .63437 .2139 .65173 .19536 .64276 .17804 Mtetra
.775 .704 .785 r
.64276 .17804 .65173 .19536 .66914 .1786 .66028 .16216 Mtetra
.764 .711 .803 r
.66028 .16216 .66914 .1786 .68663 .16356 .67789 .14789 Mtetra
.752 .718 .821 r
.67789 .14789 .68663 .16356 .70422 .15009 .69561 .13509 Mtetra
.739 .724 .838 r
.69561 .13509 .70422 .15009 .72195 .13802 .71345 .12357 Mtetra
.725 .729 .853 r
.71345 .12357 .72195 .13802 .73981 .12713 .73142 .11313 Mtetra
.713 .732 .866 r
.73142 .11313 .73981 .12713 .75781 .11723 .74953 .10357 Mtetra
.603 .736 .938 r
.10237 .32681 .11314 .33628 .12746 .3327 .1167 .32335 Mtetra
.575 .731 .948 r
.1167 .32335 .12746 .3327 .14179 .32976 .13105 .32058 Mtetra
.536 .722 .959 r
.13105 .32058 .14179 .32976 .15613 .32764 .14539 .31866 Mtetra
.481 .707 .969 r
.14539 .31866 .15613 .32764 .17047 .32653 .15973 .31779 Mtetra
.403 .679 .973 r
.15973 .31779 .17047 .32653 .1848 .32662 .17406 .31817 Mtetra
.296 .634 .964 r
.17406 .31817 .1848 .32662 .19911 .32812 .18837 .31997 Mtetra
.158 .563 .931 r
.18837 .31997 .19911 .32812 .21343 .33119 .20268 .32334 Mtetra
0 .465 .865 r
.20268 .32334 .21343 .33119 .22775 .33595 .21699 .32837 Mtetra
0 .354 .774 r
.21699 .32837 .22775 .33595 .2421 .34245 .23134 .33508 Mtetra
0 .248 .677 r
.23134 .33508 .2421 .34245 .25651 .35063 .24576 .34335 Mtetra
0 .167 .597 r
.24576 .34335 .25651 .35063 .27103 .36033 .26029 .35299 Mtetra
.433 0 0 r
.26029 .35299 .27103 .36033 .28569 .37122 .27499 .36361 Mtetra
.439 0 0 r
.27499 .36361 .28569 .37122 .30057 .38285 .28991 .37472 Mtetra
0 .141 .594 r
.28991 .37472 .30057 .38285 .3157 .3946 .3051 .3857 Mtetra
0 .221 .685 r
.3051 .3857 .3157 .3946 .33114 .40577 .32061 .39579 Mtetra
0 .344 .803 r
.32061 .39579 .33114 .40577 .34693 .41554 .33649 .40423 Mtetra
.129 .478 .897 r
.33649 .40423 .34693 .41554 .36308 .4231 .35274 .41024 Mtetra
.353 .577 .926 r
.35274 .41024 .36308 .4231 .37962 .4277 .36938 .41312 Mtetra
.516 .629 .901 r
.36938 .41312 .37962 .4277 .39651 .42868 .38636 .41233 Mtetra
.62 .65 .858 r
.38636 .41233 .39651 .42868 .41371 .42563 .40366 .40753 Mtetra
.685 .656 .816 r
.40366 .40753 .41371 .42563 .43118 .41835 .42122 .39865 Mtetra
.725 .657 .782 r
.42122 .39865 .43118 .41835 .44885 .40691 .43896 .38585 Mtetra
.751 .656 .756 r
.43896 .38585 .44885 .40691 .46663 .39164 .45681 .36955 Mtetra
.768 .656 .738 r
.45681 .36955 .46663 .39164 .48447 .37312 .47471 .35036 Mtetra
.78 .656 .726 r
.47471 .35036 .48447 .37312 .5023 .35206 .4926 .32901 Mtetra
.787 .657 .719 r
.4926 .32901 .5023 .35206 .52008 .32926 .51044 .30628 Mtetra
.792 .66 .717 r
.51044 .30628 .52008 .32926 .53779 .30554 .52821 .28295 Mtetra
.794 .663 .719 r
.52821 .28295 .53779 .30554 .55541 .28166 .5459 .25972 Mtetra
.795 .668 .724 r
.5459 .25972 .55541 .28166 .57294 .25828 .56351 .23719 Mtetra
.793 .674 .733 r
.56351 .23719 .57294 .25828 .59042 .23593 .58108 .21579 Mtetra
.79 .681 .744 r
.58108 .21579 .59042 .23593 .60786 .21497 .59861 .19584 Mtetra
.784 .688 .759 r
.59861 .19584 .60786 .21497 .62529 .19564 .61615 .17752 Mtetra
.776 .696 .775 r
.61615 .17752 .62529 .19564 .64276 .17804 .63372 .16087 Mtetra
.767 .704 .793 r
.63372 .16087 .64276 .17804 .66028 .16216 .65136 .14585 Mtetra
.756 .712 .811 r
.65136 .14585 .66028 .16216 .67789 .14789 .66908 .13234 Mtetra
.744 .719 .828 r
.66908 .13234 .67789 .14789 .69561 .13509 .68692 .12018 Mtetra
.731 .725 .845 r
.68692 .12018 .69561 .13509 .71345 .12357 .70487 .10919 Mtetra
.719 .729 .859 r
.70487 .10919 .71345 .12357 .73142 .11313 .72295 .09916 Mtetra
.707 .733 .871 r
.72295 .09916 .73142 .11313 .74953 .10357 .74117 .0899 Mtetra
.596 .734 .94 r
.09147 .31725 .10237 .32681 .1167 .32335 .10582 .31391 Mtetra
.567 .728 .95 r
.10582 .31391 .1167 .32335 .13105 .32058 .12018 .31129 Mtetra
.525 .718 .961 r
.12018 .31129 .13105 .32058 .14539 .31866 .13453 .30956 Mtetra
.467 .7 .97 r
.13453 .30956 .14539 .31866 .15973 .31779 .14888 .30892 Mtetra
.386 .67 .972 r
.14888 .30892 .15973 .31779 .17406 .31817 .1632 .30954 Mtetra
.277 .622 .96 r
.1632 .30954 .17406 .31817 .18837 .31997 .17751 .31158 Mtetra
.143 .55 .925 r
.17751 .31158 .18837 .31997 .20268 .32334 .19181 .31518 Mtetra
0 .457 .863 r
.19181 .31518 .20268 .32334 .21699 .32837 .20613 .32038 Mtetra
0 .356 .782 r
.20613 .32038 .21699 .32837 .23134 .33508 .22048 .32716 Mtetra
0 .264 .702 r
.22048 .32716 .23134 .33508 .24576 .34335 .23492 .33539 Mtetra
0 .198 .642 r
.23492 .33539 .24576 .34335 .26029 .35299 .24948 .34478 Mtetra
0 .167 .618 r
.24948 .34478 .26029 .35299 .27499 .36361 .26422 .35496 Mtetra
0 .175 .635 r
.26422 .35496 .27499 .36361 .28991 .37472 .27919 .36537 Mtetra
0 .225 .695 r
.27919 .36537 .28991 .37472 .3051 .3857 .29446 .37537 Mtetra
0 .317 .786 r
.29446 .37537 .3051 .3857 .32061 .39579 .31006 .38423 Mtetra
.064 .431 .872 r
.31006 .38423 .32061 .39579 .33649 .40423 .32603 .39121 Mtetra
.275 .531 .914 r
.32603 .39121 .33649 .40423 .35274 .41024 .34239 .39557 Mtetra
.448 .595 .905 r
.34239 .39557 .35274 .41024 .36938 .41312 .35912 .3967 Mtetra
.568 .626 .869 r
.35912 .3967 .36938 .41312 .38636 .41233 .37621 .39417 Mtetra
.646 .639 .829 r
.37621 .39417 .38636 .41233 .40366 .40753 .3936 .38773 Mtetra
.696 .644 .794 r
.3936 .38773 .40366 .40753 .42122 .39865 .41124 .37741 Mtetra
.728 .645 .766 r
.41124 .37741 .42122 .39865 .43896 .38585 .42905 .36346 Mtetra
.75 .646 .745 r
.42905 .36346 .43896 .38585 .45681 .36955 .44697 .34637 Mtetra
.765 .647 .731 r
.44697 .34637 .45681 .36955 .47471 .35036 .46493 .32675 Mtetra
.776 .649 .722 r
.46493 .32675 .47471 .35036 .4926 .32901 .48287 .30535 Mtetra
.783 .652 .718 r
.48287 .30535 .4926 .32901 .51044 .30628 .50076 .28291 Mtetra
.787 .656 .718 r
.50076 .28291 .51044 .30628 .52821 .28295 .51859 .26017 Mtetra
.789 .66 .721 r
.51859 .26017 .52821 .28295 .5459 .25972 .53634 .23775 Mtetra
.789 .666 .728 r
.53634 .23775 .5459 .25972 .56351 .23719 .55403 .21616 Mtetra
.787 .673 .738 r
.55403 .21616 .56351 .23719 .58108 .21579 .57168 .1958 Mtetra
.783 .681 .751 r
.57168 .1958 .58108 .21579 .59861 .19584 .58931 .17691 Mtetra
.777 .689 .767 r
.58931 .17691 .59861 .19584 .61615 .17752 .60695 .1596 Mtetra
.769 .697 .783 r
.60695 .1596 .61615 .17752 .63372 .16087 .62463 .1439 Mtetra
.759 .706 .801 r
.62463 .1439 .63372 .16087 .65136 .14585 .64237 .12972 Mtetra
.748 .713 .819 r
.64237 .12972 .65136 .14585 .66908 .13234 .66021 .11693 Mtetra
.736 .72 .836 r
.66021 .11693 .66908 .13234 .68692 .12018 .67815 .10537 Mtetra
.724 .726 .852 r
.67815 .10537 .68692 .12018 .70487 .10919 .69621 .09485 Mtetra
.712 .73 .865 r
.69621 .09485 .70487 .10919 .72295 .09916 .7144 .08519 Mtetra
.701 .734 .876 r
.7144 .08519 .72295 .09916 .74117 .0899 .73273 .07621 Mtetra
.59 .732 .942 r
.08045 .30759 .09147 .31725 .10582 .31391 .09482 .30436 Mtetra
.559 .726 .952 r
.09482 .30436 .10582 .31391 .12018 .31129 .10919 .30188 Mtetra
.515 .714 .962 r
.10919 .30188 .12018 .31129 .13453 .30956 .12355 .30032 Mtetra
.455 .694 .97 r
.12355 .30032 .13453 .30956 .14888 .30892 .1379 .29987 Mtetra
.372 .662 .97 r
.1379 .29987 .14888 .30892 .1632 .30954 .15223 .30068 Mtetra
.265 .612 .956 r
.15223 .30068 .1632 .30954 .17751 .31158 .16654 .30291 Mtetra
.137 .542 .922 r
.16654 .30291 .17751 .31158 .19181 .31518 .18084 .30664 Mtetra
.001 .456 .866 r
.18084 .30664 .19181 .31518 .20613 .32038 .19517 .31191 Mtetra
0 .366 .798 r
.19517 .31191 .20613 .32038 .22048 .32716 .20954 .31864 Mtetra
0 .29 .735 r
.20954 .31864 .22048 .32716 .23492 .33539 .224 .32665 Mtetra
0 .241 .696 r
.224 .32665 .23492 .33539 .24948 .34478 .2386 .33565 Mtetra
0 .226 .69 r
.2386 .33565 .24948 .34478 .26422 .35496 .2534 .34519 Mtetra
0 .249 .721 r
.2534 .34519 .26422 .35496 .27919 .36537 .26844 .35473 Mtetra
0 .312 .784 r
.26844 .35473 .27919 .36537 .29446 .37537 .28379 .3636 Mtetra
.024 .401 .854 r
.28379 .3636 .29446 .37537 .31006 .38423 .29949 .37109 Mtetra
.211 .492 .9 r
.29949 .37109 .31006 .38423 .32603 .39121 .31557 .37651 Mtetra
.383 .561 .904 r
.31557 .37651 .32603 .39121 .34239 .39557 .33203 .37918 Mtetra
.514 .601 .878 r
.33203 .37918 .34239 .39557 .35912 .3967 .34887 .37859 Mtetra
.604 .621 .841 r
.34887 .37859 .35912 .3967 .37621 .39417 .36606 .3744 Mtetra
.663 .63 .806 r
.36606 .3744 .37621 .39417 .3936 .38773 .38354 .36646 Mtetra
.703 .634 .777 r
.38354 .36646 .3936 .38773 .41124 .37741 .40125 .35489 Mtetra
.73 .637 .754 r
.40125 .35489 .41124 .37741 .42905 .36346 .41913 .34002 Mtetra
.749 .639 .738 r
.41913 .34002 .42905 .36346 .44697 .34637 .4371 .32237 Mtetra
.763 .641 .727 r
.4371 .32237 .44697 .34637 .46493 .32675 .45511 .30257 Mtetra
.772 .644 .721 r
.45511 .30257 .46493 .32675 .48287 .30535 .4731 .28134 Mtetra
.778 .648 .719 r
.4731 .28134 .48287 .30535 .50076 .28291 .49104 .25939 Mtetra
.782 .653 .72 r
.49104 .25939 .50076 .28291 .51859 .26017 .50892 .23739 Mtetra
.783 .659 .726 r
.50892 .23739 .51859 .26017 .53634 .23775 .52674 .21589 Mtetra
.783 .666 .734 r
.52674 .21589 .53634 .23775 .55403 .21616 .5445 .19535 Mtetra
.78 .673 .745 r
.5445 .19535 .55403 .21616 .57168 .1958 .56223 .17607 Mtetra
.776 .682 .759 r
.56223 .17607 .57168 .1958 .58931 .17691 .57994 .15824 Mtetra
.77 .69 .775 r
.57994 .15824 .58931 .17691 .60695 .1596 .59768 .14194 Mtetra
.761 .699 .793 r
.59768 .14194 .60695 .1596 .62463 .1439 .61546 .12715 Mtetra
.751 .707 .81 r
.61546 .12715 .62463 .1439 .64237 .12972 .63331 .11377 Mtetra
.74 .715 .828 r
.63331 .11377 .64237 .12972 .66021 .11693 .65125 .10166 Mtetra
.729 .722 .844 r
.65125 .10166 .66021 .11693 .67815 .10537 .6693 .09065 Mtetra
.717 .727 .858 r
.6693 .09065 .67815 .10537 .69621 .09485 .68747 .08057 Mtetra
.706 .731 .87 r
.68747 .08057 .69621 .09485 .7144 .08519 .70577 .07123 Mtetra
.696 .734 .88 r
.70577 .07123 .7144 .08519 .73273 .07621 .7242 .06248 Mtetra
.585 .731 .944 r
.06931 .29783 .08045 .30759 .09482 .30436 .0837 .2947 Mtetra
.552 .723 .953 r
.0837 .2947 .09482 .30436 .10919 .30188 .09808 .29234 Mtetra
.507 .71 .963 r
.09808 .29234 .10919 .30188 .12355 .30032 .11245 .29092 Mtetra
.445 .689 .969 r
.11245 .29092 .12355 .30032 .1379 .29987 .12681 .29061 Mtetra
.363 .655 .968 r
.12681 .29061 .1379 .29987 .15223 .30068 .14114 .29156 Mtetra
.26 .605 .954 r
.14114 .29156 .15223 .30068 .16654 .30291 .15546 .29389 Mtetra
.142 .539 .922 r
.15546 .29389 .16654 .30291 .18084 .30664 .16978 .29767 Mtetra
.02 .461 .873 r
.16978 .29767 .18084 .30664 .19517 .31191 .18412 .30289 Mtetra
0 .385 .819 r
.18412 .30289 .19517 .31191 .20954 .31864 .19852 .30944 Mtetra
0 .324 .774 r
.19852 .30944 .20954 .31864 .224 .32665 .21302 .3171 Mtetra
0 .291 .752 r
.21302 .3171 .224 .32665 .2386 .33565 .22767 .32554 Mtetra
0 .29 .759 r
.22767 .32554 .2386 .33565 .2534 .34519 .24254 .33429 Mtetra
0 .325 .796 r
.24254 .33429 .2534 .34519 .26844 .35473 .25767 .34279 Mtetra
.009 .389 .847 r
.25767 .34279 .26844 .35473 .28379 .3636 .27311 .3504 Mtetra
.166 .464 .888 r
.27311 .3504 .28379 .3636 .29949 .37109 .28892 .35643 Mtetra
.326 .531 .901 r
.28892 .35643 .29949 .37109 .31557 .37651 .30511 .36023 Mtetra
.46 .576 .884 r
.30511 .36023 .31557 .37651 .33203 .37918 .32168 .36123 Mtetra
.559 .602 .853 r
.32168 .36123 .33203 .37918 .34887 .37859 .33862 .35898 Mtetra
.628 .616 .819 r
.33862 .35898 .34887 .37859 .36606 .3744 .35591 .35324 Mtetra
.676 .623 .789 r
.35591 .35324 .36606 .3744 .38354 .36646 .37347 .34398 Mtetra
.708 .627 .764 r
.37347 .34398 .38354 .36646 .40125 .35489 .39125 .33137 Mtetra
.732 .63 .746 r
.39125 .33137 .40125 .35489 .41913 .34002 .40919 .31581 Mtetra
.748 .633 .733 r
.40919 .31581 .41913 .34002 .4371 .32237 .42721 .29782 Mtetra
.76 .637 .725 r
.42721 .29782 .4371 .32237 .45511 .30257 .44526 .27807 Mtetra
.768 .641 .721 r
.44526 .27807 .45511 .30257 .4731 .28134 .46329 .25721 Mtetra
.774 .646 .721 r
.46329 .25721 .4731 .28134 .49104 .25939 .48128 .23592 Mtetra
.777 .652 .724 r
.48128 .23592 .49104 .25939 .50892 .23739 .49921 .21478 Mtetra
.778 .659 .731 r
.49921 .21478 .50892 .23739 .52674 .21589 .51708 .1943 Mtetra
.777 .666 .741 r
.51708 .1943 .52674 .21589 .5445 .19535 .53491 .17484 Mtetra
.774 .675 .754 r
.53491 .17484 .5445 .19535 .56223 .17607 .55271 .15666 Mtetra
.769 .683 .768 r
.55271 .15666 .56223 .17607 .57994 .15824 .57052 .13989 Mtetra
.762 .693 .785 r
.57052 .13989 .57994 .15824 .59768 .14194 .58834 .12457 Mtetra
.754 .701 .802 r
.58834 .12457 .59768 .14194 .61546 .12715 .60622 .11065 Mtetra
.744 .71 .82 r
.60622 .11065 .61546 .12715 .63331 .11377 .62418 .09802 Mtetra
.733 .717 .836 r
.62418 .09802 .63331 .11377 .65125 .10166 .64222 .08653 Mtetra
.721 .723 .851 r
.64222 .08653 .65125 .10166 .6693 .09065 .66038 .07602 Mtetra
.71 .728 .865 r
.66038 .07602 .6693 .09065 .68747 .08057 .67865 .06632 Mtetra
.7 .732 .876 r
.67865 .06632 .68747 .08057 .70577 .07123 .69705 .05727 Mtetra
.691 .735 .884 r
.69705 .05727 .70577 .07123 .7242 .06248 .71558 .04871 Mtetra
.58 .729 .945 r
.05805 .28795 .06931 .29783 .0837 .2947 .07246 .2849 Mtetra
.546 .72 .954 r
.07246 .2849 .0837 .2947 .09808 .29234 .08685 .28263 Mtetra
.499 .706 .963 r
.08685 .28263 .09808 .29234 .11245 .29092 .10124 .28132 Mtetra
.438 .684 .968 r
.10124 .28132 .11245 .29092 .12681 .29061 .1156 .28112 Mtetra
.358 .65 .966 r
.1156 .28112 .12681 .29061 .14114 .29156 .12995 .28215 Mtetra
.262 .601 .952 r
.12995 .28215 .14114 .29156 .15546 .29389 .14428 .28451 Mtetra
.155 .54 .924 r
.14428 .28451 .15546 .29389 .16978 .29767 .15861 .28823 Mtetra
.05 .472 .885 r
.15861 .28823 .16978 .29767 .18412 .30289 .17298 .29329 Mtetra
0 .41 .844 r
.17298 .29329 .18412 .30289 .19852 .30944 .18742 .29952 Mtetra
0 .364 .814 r
.18742 .29952 .19852 .30944 .21302 .3171 .20198 .30669 Mtetra
0 .344 .805 r
.20198 .30669 .21302 .3171 .22767 .32554 .2167 .31442 Mtetra
0 .355 .819 r
.2167 .31442 .22767 .32554 .24254 .33429 .23165 .32224 Mtetra
.017 .394 .85 r
.23165 .32224 .24254 .33429 .25767 .34279 .24687 .32959 Mtetra
.141 .45 .882 r
.24687 .32959 .25767 .34279 .27311 .3504 .26243 .33583 Mtetra
.281 .508 .897 r
.26243 .33583 .27311 .3504 .28892 .35643 .27835 .34034 Mtetra
.411 .554 .888 r
.27835 .34034 .28892 .35643 .30511 .36023 .29465 .34253 Mtetra
.515 .584 .862 r
.29465 .34253 .30511 .36023 .32168 .36123 .31133 .34189 Mtetra
.591 .602 .831 r
.31133 .34189 .32168 .36123 .33862 .35898 .32838 .33808 Mtetra
.646 .612 .801 r
.32838 .33808 .33862 .35898 .35591 .35324 .34575 .33095 Mtetra
.685 .618 .775 r
.34575 .33095 .35591 .35324 .37347 .34398 .36339 .32055 Mtetra
.712 .622 .755 r
.36339 .32055 .37347 .34398 .39125 .33137 .38124 .30712 Mtetra
.732 .626 .741 r
.38124 .30712 .39125 .33137 .40919 .31581 .39922 .29109 Mtetra
.747 .63 .731 r
.39922 .29109 .40919 .31581 .42721 .29782 .41728 .273 Mtetra
.757 .634 .725 r
.41728 .273 .42721 .29782 .44526 .27807 .43537 .25348 Mtetra
.764 .639 .723 r
.43537 .25348 .44526 .27807 .46329 .25721 .45344 .23317 Mtetra
.769 .645 .725 r
.45344 .23317 .46329 .25721 .48128 .23592 .47146 .21266 Mtetra
.772 .652 .73 r
.47146 .21266 .48128 .23592 .49921 .21478 .48944 .19249 Mtetra
.772 .659 .738 r
.48944 .19249 .49921 .21478 .51708 .1943 .50737 .17307 Mtetra
.771 .668 .749 r
.50737 .17307 .51708 .1943 .53491 .17484 .52526 .15472 Mtetra
.767 .677 .763 r
.52526 .15472 .53491 .17484 .55271 .15666 .54314 .13763 Mtetra
.762 .686 .778 r
.54314 .13763 .55271 .15666 .57052 .13989 .56102 .12189 Mtetra
.755 .695 .795 r
.56102 .12189 .57052 .13989 .58834 .12457 .57894 .1075 Mtetra
.746 .704 .812 r
.57894 .1075 .58834 .12457 .60622 .11065 .59691 .09439 Mtetra
.736 .712 .829 r
.59691 .09439 .60622 .11065 .62418 .09802 .61496 .08245 Mtetra
.725 .719 .845 r
.61496 .08245 .62418 .09802 .64222 .08653 .63311 .07153 Mtetra
.714 .725 .859 r
.63311 .07153 .64222 .08653 .66038 .07602 .65136 .06146 Mtetra
.704 .73 .871 r
.65136 .06146 .66038 .07602 .67865 .06632 .66974 .0521 Mtetra
.695 .733 .88 r
.66974 .0521 .67865 .06632 .69705 .05727 .68824 .04328 Mtetra
.687 .736 .888 r
.68824 .04328 .69705 .05727 .71558 .04871 .70687 .03489 Mtetra
.575 .727 .946 r
.04667 .27793 .05805 .28795 .07246 .2849 .06109 .27494 Mtetra
.541 .717 .954 r
.06109 .27494 .07246 .2849 .08685 .28263 .07551 .27276 Mtetra
.494 .702 .962 r
.07551 .27276 .08685 .28263 .10124 .28132 .08991 .27151 Mtetra
.434 .679 .967 r
.08991 .27151 .10124 .28132 .1156 .28112 .10428 .27136 Mtetra
.359 .646 .964 r
.10428 .27136 .1156 .28112 .12995 .28215 .11865 .2724 Mtetra
.27 .601 .952 r
.11865 .2724 .12995 .28215 .14428 .28451 .133 .2747 Mtetra
.176 .546 .928 r
.133 .2747 .14428 .28451 .15861 .28823 .14737 .27828 Mtetra
.089 .488 .898 r
.14737 .27828 .15861 .28823 .17298 .29329 .16178 .28306 Mtetra
.022 .438 .869 r
.16178 .28306 .17298 .29329 .18742 .29952 .17627 .28885 Mtetra
0 .406 .85 r
.17627 .28885 .18742 .29952 .20198 .30669 .19089 .29539 Mtetra
0 .397 .849 r
.19089 .29539 .20198 .30669 .2167 .31442 .20569 .30229 Mtetra
.047 .414 .862 r
.20569 .30229 .2167 .31442 .23165 .32224 .22073 .30906 Mtetra
.138 .45 .882 r
.22073 .30906 .23165 .32224 .24687 .32959 .23607 .31516 Mtetra
.253 .495 .894 r
.23607 .31516 .24687 .32959 .26243 .33583 .25174 .31999 Mtetra
.37 .537 .89 r
.25174 .31999 .26243 .33583 .27835 .34034 .26777 .32296 Mtetra
.473 .568 .87 r
.26777 .32296 .27835 .34034 .29465 .34253 .28419 .32355 Mtetra
.555 .588 .842 r
.28419 .32355 .29465 .34253 .31133 .34189 .30099 .32136 Mtetra
.615 .601 .813 r
.30099 .32136 .31133 .34189 .32838 .33808 .31814 .31613 Mtetra
.659 .609 .787 r
.31814 .31613 .32838 .33808 .34575 .33095 .33559 .30779 Mtetra
.691 .615 .766 r
.33559 .30779 .34575 .33095 .36339 .32055 .3533 .29645 Mtetra
.715 .619 .749 r
.3533 .29645 .36339 .32055 .38124 .30712 .3712 .28242 Mtetra
.732 .624 .738 r
.3712 .28242 .38124 .30712 .39922 .29109 .38923 .26613 Mtetra
.745 .628 .73 r
.38923 .26613 .39922 .29109 .41728 .273 .40732 .24814 Mtetra
.754 .633 .727 r
.40732 .24814 .41728 .273 .43537 .25348 .42543 .22903 Mtetra
.761 .639 .727 r
.42543 .22903 .43537 .25348 .45344 .23317 .44353 .2094 Mtetra
.765 .646 .73 r
.44353 .2094 .45344 .23317 .47146 .21266 .46159 .18978 Mtetra
.767 .653 .737 r
.46159 .18978 .47146 .21266 .48944 .19249 .47961 .17062 Mtetra
.767 .662 .746 r
.47961 .17062 .48944 .19249 .50737 .17307 .49759 .15229 Mtetra
.765 .67 .758 r
.49759 .15229 .50737 .17307 .52526 .15472 .51554 .13504 Mtetra
.761 .68 .773 r
.51554 .13504 .52526 .15472 .54314 .13763 .53349 .11901 Mtetra
.755 .689 .789 r
.53349 .11901 .54314 .13763 .56102 .12189 .55145 .10425 Mtetra
.747 .699 .805 r
.55145 .10425 .56102 .12189 .57894 .1075 .56945 .09073 Mtetra
.738 .707 .822 r
.56945 .09073 .57894 .1075 .59691 .09439 .58752 .07838 Mtetra
.728 .715 .838 r
.58752 .07838 .59691 .09439 .61496 .08245 .60566 .06706 Mtetra
.718 .721 .853 r
.60566 .06706 .61496 .08245 .63311 .07153 .62391 .05664 Mtetra
.707 .727 .865 r
.62391 .05664 .63311 .07153 .65136 .06146 .64226 .04696 Mtetra
.698 .731 .876 r
.64226 .04696 .65136 .06146 .66974 .0521 .66073 .03788 Mtetra
.69 .734 .885 r
.66073 .03788 .66974 .0521 .68824 .04328 .67933 .02926 Mtetra
.683 .736 .891 r
.67933 .02926 .68824 .04328 .70687 .03489 .69806 .021 Mtetra
.571 .725 .946 r
.03516 .26777 .04667 .27793 .06109 .27494 .0496 .26483 Mtetra
.537 .715 .954 r
.0496 .26483 .06109 .27494 .07551 .27276 .06404 .26268 Mtetra
.491 .699 .961 r
.06404 .26268 .07551 .27276 .08991 .27151 .07846 .26147 Mtetra
.434 .676 .965 r
.07846 .26147 .08991 .27151 .10428 .27136 .09286 .26131 Mtetra
.364 .644 .963 r
.09286 .26131 .10428 .27136 .11865 .2724 .10725 .26229 Mtetra
.285 .603 .952 r
.10725 .26229 .11865 .2724 .133 .2747 .12163 .26446 Mtetra
.205 .555 .933 r
.12163 .26446 .133 .2747 .14737 .27828 .13604 .26779 Mtetra
.135 .507 .91 r
.13604 .26779 .14737 .27828 .16178 .28306 .1505 .27218 Mtetra
.087 .469 .89 r
.1505 .27218 .16178 .28306 .17627 .28885 .16506 .27742 Mtetra
.072 .447 .88 r
.16506 .27742 .17627 .28885 .19089 .29539 .17975 .28322 Mtetra
.094 .445 .88 r
.17975 .28322 .19089 .29539 .20569 .30229 .19465 .28917 Mtetra
.153 .463 .889 r
.19465 .28917 .20569 .30229 .22073 .30906 .2098 .29481 Mtetra
.241 .494 .896 r
.2098 .29481 .22073 .30906 .23607 .31516 .22525 .2996 Mtetra
.342 .527 .893 r
.22525 .2996 .23607 .31516 .25174 .31999 .24105 .30298 Mtetra
.438 .556 .877 r
.24105 .30298 .25174 .31999 .26777 .32296 .25721 .30443 Mtetra
.52 .577 .853 r
.25721 .30443 .26777 .32296 .28419 .32355 .27374 .30351 Mtetra
.584 .591 .826 r
.27374 .30351 .28419 .32355 .30099 .32136 .29065 .29988 Mtetra
.633 .601 .8 r
.29065 .29988 .30099 .32136 .31814 .31613 .30789 .29338 Mtetra
.669 .608 .777 r
.30789 .29338 .31814 .31613 .33559 .30779 .32542 .284 Mtetra
.696 .613 .759 r
.32542 .284 .33559 .30779 .3533 .29645 .34319 .27194 Mtetra
.717 .618 .746 r
.34319 .27194 .3533 .29645 .3712 .28242 .36113 .25751 Mtetra
.732 .623 .737 r
.36113 .25751 .3712 .28242 .38923 .26613 .37919 .24117 Mtetra
.743 .628 .732 r
.37919 .24117 .38923 .26613 .40732 .24814 .39731 .22345 Mtetra
.751 .634 .73 r
.39731 .22345 .40732 .24814 .42543 .22903 .41545 .20489 Mtetra
.757 .64 .732 r
.41545 .20489 .42543 .22903 .44353 .2094 .43357 .18604 Mtetra
.76 .648 .737 r
.43357 .18604 .44353 .2094 .46159 .18978 .45166 .16737 Mtetra
.762 .656 .745 r
.45166 .16737 .46159 .18978 .47961 .17062 .46971 .14927 Mtetra
.761 .665 .756 r
.46971 .14927 .47961 .17062 .49759 .15229 .48774 .13202 Mtetra
.758 .674 .769 r
.48774 .13202 .49759 .15229 .51554 .13504 .50575 .11584 Mtetra
.754 .683 .783 r
.50575 .11584 .51554 .13504 .53349 .11901 .52376 .10082 Mtetra
.747 .693 .799 r
.52376 .10082 .53349 .11901 .55145 .10425 .5418 .08698 Mtetra
.739 .702 .816 r
.5418 .08698 .55145 .10425 .56945 .09073 .55988 .07426 Mtetra
.73 .71 .832 r
.55988 .07426 .56945 .09073 .58752 .07838 .57804 .06259 Mtetra
.72 .718 .847 r
.57804 .06259 .58752 .07838 .60566 .06706 .59627 .05183 Mtetra
.711 .724 .86 r
.59627 .05183 .60566 .06706 .62391 .05664 .61461 .04184 Mtetra
.701 .729 .872 r
.61461 .04184 .62391 .05664 .64226 .04696 .63306 .0325 Mtetra
.693 .732 .881 r
.63306 .0325 .64226 .04696 .66073 .03788 .65163 .02365 Mtetra
.685 .735 .888 r
.65163 .02365 .66073 .03788 .67933 .02926 .67032 .0152 Mtetra
.679 .737 .894 r
.67032 .0152 .67933 .02926 .69806 .021 .68914 .00702 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.663 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59245 Mtetra
.41047 .59245 .41826 .59977 .43147 .59581 .42372 .58845 Mtetra
.42372 .58845 .43147 .59581 .44474 .59184 .43703 .58445 Mtetra
.43703 .58445 .44474 .59184 .45807 .58785 .4504 .58042 Mtetra
.4504 .58042 .45807 .58785 .47147 .58384 .46385 .57639 Mtetra
.663 .742 .909 r
.46385 .57639 .47147 .58384 .48494 .57982 .47736 .57234 Mtetra
.662 .742 .909 r
.47736 .57234 .48494 .57982 .49847 .5758 .49093 .5683 Mtetra
.661 .742 .91 r
.49093 .5683 .49847 .5758 .51207 .57177 .50458 .56426 Mtetra
.66 .742 .911 r
.50458 .56426 .51207 .57177 .52574 .56774 .51829 .56023 Mtetra
.659 .743 .912 r
.51829 .56023 .52574 .56774 .53948 .56373 .53207 .55624 Mtetra
.657 .744 .914 r
.53207 .55624 .53948 .56373 .55329 .55975 .54593 .55228 Mtetra
.655 .745 .916 r
.54593 .55228 .55329 .55975 .56717 .5558 .55986 .54839 Mtetra
.651 .747 .919 r
.55986 .54839 .56717 .5558 .58112 .55191 .57386 .54459 Mtetra
.647 .749 .923 r
.57386 .54459 .58112 .55191 .59515 .54809 .58794 .5409 Mtetra
.642 .752 .928 r
.58794 .5409 .59515 .54809 .60925 .54437 .6021 .53734 Mtetra
.635 .755 .935 r
.6021 .53734 .60925 .54437 .62344 .54076 .61634 .53393 Mtetra
.627 .76 .942 r
.61634 .53393 .62344 .54076 .63771 .53728 .63067 .53071 Mtetra
.618 .765 .95 r
.63067 .53071 .63771 .53728 .65206 .53395 .64508 .52767 Mtetra
.606 .771 .959 r
.64508 .52767 .65206 .53395 .6665 .53076 .6596 .52482 Mtetra
.594 .779 .968 r
.6596 .52482 .6665 .53076 .68103 .52772 .6742 .52214 Mtetra
.579 .787 .978 r
.6742 .52214 .68103 .52772 .69566 .52481 .68891 .51962 Mtetra
.565 .795 .986 r
.68891 .51962 .69566 .52481 .71038 .52201 .70372 .51721 Mtetra
.55 .804 .992 r
.70372 .51721 .71038 .52201 .7252 .51926 .71862 .51485 Mtetra
.537 .813 .997 r
.71862 .51485 .7252 .51926 .74011 .51652 .73362 .51246 Mtetra
.529 .823 .999 r
.73362 .51246 .74011 .51652 .7551 .51371 .74872 .50996 Mtetra
.526 .833 1 r
.74872 .50996 .7551 .51371 .77019 .51078 .76389 .50726 Mtetra
.53 .843 .999 r
.76389 .50726 .77019 .51078 .78535 .50764 .77914 .50426 Mtetra
.543 .854 .998 r
.77914 .50426 .78535 .50764 .80058 .50423 .79446 .50089 Mtetra
.562 .865 .996 r
.79446 .50089 .80058 .50423 .81588 .50048 .80983 .49707 Mtetra
.587 .873 .994 r
.80983 .49707 .81588 .50048 .83123 .49635 .82525 .49277 Mtetra
.614 .879 .99 r
.82525 .49277 .83123 .49635 .84662 .49182 .84071 .48797 Mtetra
.64 .881 .985 r
.84071 .48797 .84662 .49182 .86207 .48688 .8562 .48267 Mtetra
.663 .878 .978 r
.8562 .48267 .86207 .48688 .87755 .48155 .87173 .47692 Mtetra
.683 .871 .97 r
.87173 .47692 .87755 .48155 .89307 .47587 .88728 .47077 Mtetra
.697 .861 .96 r
.88728 .47077 .89307 .47587 .90863 .46989 .90288 .46429 Mtetra
.706 .849 .951 r
.90288 .46429 .90863 .46989 .92424 .46369 .91851 .45759 Mtetra
.711 .836 .942 r
.91851 .45759 .92424 .46369 .9399 .45733 .9342 .45074 Mtetra
.712 .823 .934 r
.9342 .45074 .9399 .45733 .95563 .45088 .94995 .44384 Mtetra
.711 .81 .927 r
.94995 .44384 .95563 .45088 .97142 .44443 .96577 .43697 Mtetra
.663 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59245 .40261 .58506 Mtetra
.40261 .58506 .41047 .59245 .42372 .58845 .41589 .58103 Mtetra
.41589 .58103 .42372 .58845 .43703 .58445 .42925 .57699 Mtetra
.42925 .57699 .43703 .58445 .4504 .58042 .44266 .57294 Mtetra
.663 .742 .909 r
.44266 .57294 .4504 .58042 .46385 .57639 .45615 .56888 Mtetra
.662 .742 .909 r
.45615 .56888 .46385 .57639 .47736 .57234 .4697 .56481 Mtetra
.661 .742 .91 r
.4697 .56481 .47736 .57234 .49093 .5683 .48332 .56075 Mtetra
.66 .742 .911 r
.48332 .56075 .49093 .5683 .50458 .56426 .49701 .55671 Mtetra
.659 .743 .912 r
.49701 .55671 .50458 .56426 .51829 .56023 .51077 .5527 Mtetra
.657 .744 .914 r
.51077 .5527 .51829 .56023 .53207 .55624 .5246 .54874 Mtetra
.654 .745 .916 r
.5246 .54874 .53207 .55624 .54593 .55228 .5385 .54485 Mtetra
.65 .747 .92 r
.5385 .54485 .54593 .55228 .55986 .54839 .55247 .54106 Mtetra
.646 .749 .924 r
.55247 .54106 .55986 .54839 .57386 .54459 .56653 .53738 Mtetra
.64 .751 .93 r
.56653 .53738 .57386 .54459 .58794 .5409 .58066 .53387 Mtetra
.632 .755 .936 r
.58066 .53387 .58794 .5409 .6021 .53734 .59487 .53053 Mtetra
.623 .76 .944 r
.59487 .53053 .6021 .53734 .61634 .53393 .60917 .52741 Mtetra
.611 .765 .953 r
.60917 .52741 .61634 .53393 .63067 .53071 .62357 .52451 Mtetra
.597 .772 .964 r
.62357 .52451 .63067 .53071 .64508 .52767 .63805 .52186 Mtetra
.58 .779 .974 r
.63805 .52186 .64508 .52767 .6596 .52482 .65264 .51943 Mtetra
.56 .787 .984 r
.65264 .51943 .6596 .52482 .6742 .52214 .66733 .51722 Mtetra
.538 .795 .992 r
.66733 .51722 .6742 .52214 .68891 .51962 .68213 .51518 Mtetra
.515 .802 .998 r
.68213 .51518 .68891 .51962 .70372 .51721 .69702 .51324 Mtetra
.492 .81 1 r
.69702 .51324 .70372 .51721 .71862 .51485 .71203 .51132 Mtetra
.474 .817 .998 r
.71203 .51132 .71862 .51485 .73362 .51246 .72712 .50933 Mtetra
.462 .825 .995 r
.72712 .50933 .73362 .51246 .74872 .50996 .74231 .50715 Mtetra
.461 .835 .99 r
.74231 .50715 .74872 .50996 .76389 .50726 .75759 .50466 Mtetra
.472 .847 .987 r
.75759 .50466 .76389 .50726 .77914 .50426 .77293 .50177 Mtetra
.494 .862 .986 r
.77293 .50177 .77914 .50426 .79446 .50089 .78833 .49838 Mtetra
.527 .877 .987 r
.78833 .49838 .79446 .50089 .80983 .49707 .80378 .49442 Mtetra
.565 .89 .988 r
.80378 .49442 .80983 .49707 .82525 .49277 .81927 .48986 Mtetra
.605 .898 .987 r
.81927 .48986 .82525 .49277 .84071 .48797 .83478 .48468 Mtetra
.641 .901 .984 r
.83478 .48468 .84071 .48797 .8562 .48267 .85032 .47892 Mtetra
.672 .897 .977 r
.85032 .47892 .8562 .48267 .87173 .47692 .86588 .47263 Mtetra
.695 .888 .969 r
.86588 .47263 .87173 .47692 .88728 .47077 .88146 .4659 Mtetra
.71 .875 .959 r
.88146 .4659 .88728 .47077 .90288 .46429 .89708 .45884 Mtetra
.719 .86 .948 r
.89708 .45884 .90288 .46429 .91851 .45759 .91273 .45155 Mtetra
.723 .844 .939 r
.91273 .45155 .91851 .45759 .9342 .45074 .92844 .44416 Mtetra
.723 .829 .93 r
.92844 .44416 .9342 .45074 .94995 .44384 .94421 .43675 Mtetra
.721 .815 .923 r
.94421 .43675 .94995 .44384 .96577 .43697 .96005 .42942 Mtetra
.663 .741 .908 r
.38141 .58164 .38939 .58906 .40261 .58506 .39467 .5776 Mtetra
.39467 .5776 .40261 .58506 .41589 .58103 .408 .57354 Mtetra
.408 .57354 .41589 .58103 .42925 .57699 .42139 .56947 Mtetra
.663 .742 .909 r
.42139 .56947 .42925 .57699 .44266 .57294 .43485 .56539 Mtetra
.662 .742 .909 r
.43485 .56539 .44266 .57294 .45615 .56888 .44838 .56131 Mtetra
.661 .742 .91 r
.44838 .56131 .45615 .56888 .4697 .56481 .46198 .55723 Mtetra
.66 .742 .911 r
.46198 .55723 .4697 .56481 .48332 .56075 .47564 .55318 Mtetra
.659 .743 .912 r
.47564 .55318 .48332 .56075 .49701 .55671 .48937 .54915 Mtetra
.657 .744 .914 r
.48937 .54915 .49701 .55671 .51077 .5527 .50318 .54518 Mtetra
.654 .745 .917 r
.50318 .54518 .51077 .5527 .5246 .54874 .51705 .54128 Mtetra
.65 .746 .92 r
.51705 .54128 .5246 .54874 .5385 .54485 .531 .53748 Mtetra
.645 .748 .925 r
.531 .53748 .5385 .54485 .55247 .54106 .54502 .53383 Mtetra
.638 .751 .93 r
.54502 .53383 .55247 .54106 .56653 .53738 .55913 .53034 Mtetra
.629 .755 .938 r
.55913 .53034 .56653 .53738 .58066 .53387 .57331 .52707 Mtetra
.618 .76 .946 r
.57331 .52707 .58066 .53387 .59487 .53053 .58758 .52404 Mtetra
.604 .765 .956 r
.58758 .52404 .59487 .53053 .60917 .52741 .60195 .52128 Mtetra
.587 .771 .967 r
.60195 .52128 .60917 .52741 .62357 .52451 .61641 .51882 Mtetra
.565 .778 .979 r
.61641 .51882 .62357 .52451 .63805 .52186 .63097 .51665 Mtetra
.538 .785 .989 r
.63097 .51665 .63805 .52186 .65264 .51943 .64564 .51475 Mtetra
.507 .791 .997 r
.64564 .51475 .65264 .51943 .66733 .51722 .66041 .5131 Mtetra
.472 .796 .999 r
.66041 .5131 .66733 .51722 .68213 .51518 .6753 .51162 Mtetra
.435 .798 .996 r
.6753 .51162 .68213 .51518 .69702 .51324 .6903 .51023 Mtetra
.402 .799 .986 r
.6903 .51023 .69702 .51324 .71203 .51132 .7054 .50881 Mtetra
.376 .8 .972 r
.7054 .50881 .71203 .51132 .72712 .50933 .7206 .50724 Mtetra
.364 .804 .958 r
.7206 .50724 .72712 .50933 .74231 .50715 .7359 .50538 Mtetra
.369 .814 .949 r
.7359 .50538 .74231 .50715 .75759 .50466 .75127 .50309 Mtetra
.392 .832 .946 r
.75127 .50309 .75759 .50466 .77293 .50177 .7667 .50025 Mtetra
.432 .855 .951 r
.7667 .50025 .77293 .50177 .78833 .49838 .78219 .49675 Mtetra
.485 .88 .96 r
.78219 .49675 .78833 .49838 .80378 .49442 .79771 .49255 Mtetra
.543 .901 .97 r
.79771 .49255 .80378 .49442 .81927 .48986 .81326 .4876 Mtetra
.599 .915 .977 r
.81326 .4876 .81927 .48986 .83478 .48468 .82882 .48191 Mtetra
.647 .92 .977 r
.82882 .48191 .83478 .48468 .85032 .47892 .8444 .47556 Mtetra
.684 .915 .973 r
.8444 .47556 .85032 .47892 .86588 .47263 .85999 .46862 Mtetra
.71 .903 .964 r
.85999 .46862 .86588 .47263 .88146 .4659 .87559 .46121 Mtetra
.727 .886 .954 r
.87559 .46121 .88146 .4659 .89708 .45884 .89122 .45346 Mtetra
.735 .868 .943 r
.89122 .45346 .89708 .45884 .91273 .45155 .90689 .44552 Mtetra
.737 .85 .933 r
.90689 .44552 .91273 .45155 .92844 .44416 .92261 .43751 Mtetra
.735 .833 .925 r
.92261 .43751 .92844 .44416 .94421 .43675 .9384 .42956 Mtetra
.731 .817 .918 r
.9384 .42956 .94421 .43675 .96005 .42942 .95426 .42175 Mtetra
.663 .741 .908 r
.37336 .57415 .38141 .58164 .39467 .5776 .38666 .57008 Mtetra
.38666 .57008 .39467 .5776 .408 .57354 .40003 .56599 Mtetra
.663 .742 .909 r
.40003 .56599 .408 .57354 .42139 .56947 .41347 .56189 Mtetra
.662 .742 .909 r
.41347 .56189 .42139 .56947 .43485 .56539 .42697 .55779 Mtetra
.661 .742 .91 r
.42697 .55779 .43485 .56539 .44838 .56131 .44054 .55369 Mtetra
.66 .742 .911 r
.44054 .55369 .44838 .56131 .46198 .55723 .45418 .54962 Mtetra
.659 .743 .912 r
.45418 .54962 .46198 .55723 .47564 .55318 .46788 .54557 Mtetra
.657 .743 .914 r
.46788 .54557 .47564 .55318 .48937 .54915 .48166 .54158 Mtetra
.654 .745 .917 r
.48166 .54158 .48937 .54915 .50318 .54518 .49551 .53767 Mtetra
.65 .746 .92 r
.49551 .53767 .50318 .54518 .51705 .54128 .50943 .53387 Mtetra
.644 .748 .925 r
.50943 .53387 .51705 .54128 .531 .53748 .52342 .53022 Mtetra
.637 .751 .931 r
.52342 .53022 .531 .53748 .54502 .53383 .5375 .52676 Mtetra
.627 .755 .939 r
.5375 .52676 .54502 .53383 .55913 .53034 .55165 .52354 Mtetra
.615 .759 .948 r
.55165 .52354 .55913 .53034 .57331 .52707 .56589 .52059 Mtetra
.598 .764 .959 r
.56589 .52059 .57331 .52707 .58758 .52404 .58023 .51796 Mtetra
.577 .77 .971 r
.58023 .51796 .58758 .52404 .60195 .52128 .59465 .51567 Mtetra
.55 .777 .983 r
.59465 .51567 .60195 .52128 .61641 .51882 .60919 .51375 Mtetra
.515 .782 .993 r
.60919 .51375 .61641 .51882 .63097 .51665 .62383 .51218 Mtetra
.473 .785 .998 r
.62383 .51218 .63097 .51665 .64564 .51475 .63858 .51092 Mtetra
.423 .783 .996 r
.63858 .51092 .64564 .51475 .66041 .5131 .65345 .50993 Mtetra
.368 .776 .982 r
.65345 .50993 .66041 .5131 .6753 .51162 .66844 .50911 Mtetra
.314 .764 .958 r
.66844 .50911 .6753 .51162 .6903 .51023 .68354 .50833 Mtetra
.268 .751 .926 r
.68354 .50833 .6903 .51023 .7054 .50881 .69875 .50745 Mtetra
.24 .743 .895 r
.69875 .50745 .7054 .50881 .7206 .50724 .71406 .50631 Mtetra
.233 .745 .872 r
.71406 .50631 .7206 .50724 .7359 .50538 .72946 .50474 Mtetra
.253 .761 .864 r
.72946 .50474 .7359 .50538 .75127 .50309 .74493 .50258 Mtetra
.297 .791 .871 r
.74493 .50258 .75127 .50309 .7667 .50025 .76046 .4997 Mtetra
.363 .83 .891 r
.76046 .4997 .7667 .50025 .78219 .49675 .77603 .49599 Mtetra
.442 .873 .918 r
.77603 .49599 .78219 .49675 .79771 .49255 .79162 .49141 Mtetra
.525 .908 .943 r
.79162 .49141 .79771 .49255 .81326 .4876 .80722 .48593 Mtetra
.6 .93 .96 r
.80722 .48593 .81326 .4876 .82882 .48191 .82283 .4796 Mtetra
.66 .937 .967 r
.82283 .4796 .82882 .48191 .8444 .47556 .83844 .47251 Mtetra
.703 .93 .965 r
.83844 .47251 .8444 .47556 .85999 .46862 .85405 .46479 Mtetra
.73 .915 .957 r
.85405 .46479 .85999 .46862 .87559 .46121 .86966 .45659 Mtetra
.745 .895 .946 r
.86966 .45659 .87559 .46121 .89122 .45346 .88531 .44807 Mtetra
.751 .874 .936 r
.88531 .44807 .89122 .45346 .90689 .44552 .90098 .4394 Mtetra
.751 .853 .926 r
.90098 .4394 .90689 .44552 .92261 .43751 .91671 .43074 Mtetra
.747 .834 .918 r
.91671 .43074 .92261 .43751 .9384 .42956 .93251 .4222 Mtetra
.74 .818 .912 r
.93251 .4222 .9384 .42956 .95426 .42175 .9484 .41389 Mtetra
.663 .741 .908 r
.36524 .5666 .37336 .57415 .38666 .57008 .37858 .56249 Mtetra
.663 .741 .909 r
.37858 .56249 .38666 .57008 .40003 .56599 .39199 .55838 Mtetra
.662 .742 .909 r
.39199 .55838 .40003 .56599 .41347 .56189 .40547 .55425 Mtetra
.662 .742 .91 r
.40547 .55425 .41347 .56189 .42697 .55779 .41901 .55014 Mtetra
.66 .742 .91 r
.41901 .55014 .42697 .55779 .44054 .55369 .43262 .54604 Mtetra
.659 .743 .912 r
.43262 .54604 .44054 .55369 .45418 .54962 .4463 .54197 Mtetra
.657 .743 .914 r
.4463 .54197 .45418 .54962 .46788 .54557 .46005 .53796 Mtetra
.654 .744 .916 r
.46005 .53796 .46788 .54557 .48166 .54158 .47387 .53403 Mtetra
.649 .746 .92 r
.47387 .53403 .48166 .54158 .49551 .53767 .48777 .53022 Mtetra
.644 .748 .925 r
.48777 .53022 .49551 .53767 .50943 .53387 .50173 .52657 Mtetra
.636 .75 .931 r
.50173 .52657 .50943 .53387 .52342 .53022 .51578 .52312 Mtetra
.625 .754 .939 r
.51578 .52312 .52342 .53022 .5375 .52676 .5299 .51993 Mtetra
.612 .758 .949 r
.5299 .51993 .5375 .52676 .55165 .52354 .54411 .51705 Mtetra
.593 .763 .96 r
.54411 .51705 .55165 .52354 .56589 .52059 .5584 .51452 Mtetra
.568 .769 .973 r
.5584 .51452 .56589 .52059 .58023 .51796 .5728 .5124 Mtetra
.536 .774 .986 r
.5728 .5124 .58023 .51796 .59465 .51567 .58729 .5107 Mtetra
.493 .777 .995 r
.58729 .5107 .59465 .51567 .60919 .51375 .6019 .50944 Mtetra
.437 .775 .997 r
.6019 .50944 .60919 .51375 .62383 .51218 .61662 .50859 Mtetra
.369 .764 .987 r
.61662 .50859 .62383 .51218 .63858 .51092 .63147 .50809 Mtetra
.292 .743 .958 r
.63147 .50809 .63858 .51092 .65345 .50993 .64644 .50786 Mtetra
.213 .713 .912 r
.64644 .50786 .65345 .50993 .66844 .50911 .66153 .50777 Mtetra
.145 .679 .854 r
.66153 .50777 .66844 .50911 .68354 .50833 .67674 .50765 Mtetra
.097 .651 .799 r
.67674 .50765 .68354 .50833 .69875 .50745 .69207 .50733 Mtetra
.077 .638 .757 r
.69207 .50733 .69875 .50745 .71406 .50631 .70749 .5066 Mtetra
.088 .647 .737 r
.70749 .5066 .71406 .50631 .72946 .50474 .723 .50526 Mtetra
.13 .678 .741 r
.723 .50526 .72946 .50474 .74493 .50258 .73857 .50315 Mtetra
.202 .73 .77 r
.73857 .50315 .74493 .50258 .76046 .4997 .75419 .50011 Mtetra
.298 .795 .815 r
.75419 .50011 .76046 .4997 .77603 .49599 .76984 .49605 Mtetra
.409 .86 .867 r
.76984 .49605 .77603 .49599 .79162 .49141 .78549 .49092 Mtetra
.518 .913 .912 r
.78549 .49092 .79162 .49141 .80722 .48593 .80114 .48475 Mtetra
.612 .944 .942 r
.80114 .48475 .80722 .48593 .82283 .4796 .81678 .47762 Mtetra
.682 .951 .955 r
.81678 .47762 .82283 .4796 .83844 .47251 .83241 .46965 Mtetra
.727 .942 .954 r
.83241 .46965 .83844 .47251 .85405 .46479 .84803 .46103 Mtetra
.753 .923 .946 r
.84803 .46103 .85405 .46479 .86966 .45659 .86366 .45193 Mtetra
.765 .899 .936 r
.86366 .45193 .86966 .45659 .88531 .44807 .87931 .44256 Mtetra
.768 .876 .926 r
.87931 .44256 .88531 .44807 .90098 .4394 .89499 .43311 Mtetra
.765 .854 .917 r
.89499 .43311 .90098 .4394 .91671 .43074 .91073 .42375 Mtetra
.758 .834 .91 r
.91073 .42375 .91671 .43074 .93251 .4222 .92654 .41461 Mtetra
.749 .816 .905 r
.92654 .41461 .93251 .4222 .9484 .41389 .94245 .4058 Mtetra
.663 .741 .908 r
.35704 .55898 .36524 .5666 .37858 .56249 .37042 .55484 Mtetra
.662 .742 .909 r
.37042 .55484 .37858 .56249 .39199 .55838 .38387 .5507 Mtetra
.38387 .5507 .39199 .55838 .40547 .55425 .39739 .54656 Mtetra
.661 .742 .91 r
.39739 .54656 .40547 .55425 .41901 .55014 .41098 .54244 Mtetra
.659 .742 .912 r
.41098 .54244 .41901 .55014 .43262 .54604 .42463 .53835 Mtetra
.657 .743 .913 r
.42463 .53835 .43262 .54604 .4463 .54197 .43836 .53432 Mtetra
.654 .744 .916 r
.43836 .53432 .4463 .54197 .46005 .53796 .45215 .53036 Mtetra
.649 .745 .92 r
.45215 .53036 .46005 .53796 .47387 .53403 .46601 .52653 Mtetra
.644 .747 .924 r
.46601 .52653 .47387 .53403 .48777 .53022 .47995 .52287 Mtetra
.635 .75 .931 r
.47995 .52287 .48777 .53022 .50173 .52657 .49396 .51941 Mtetra
.624 .753 .939 r
.49396 .51941 .50173 .52657 .51578 .52312 .50805 .51624 Mtetra
.609 .757 .949 r
.50805 .51624 .51578 .52312 .5299 .51993 .52222 .5134 Mtetra
.589 .762 .961 r
.52222 .5134 .5299 .51993 .54411 .51705 .53648 .51096 Mtetra
.561 .767 .975 r
.53648 .51096 .54411 .51705 .5584 .51452 .55084 .50897 Mtetra
.523 .77 .987 r
.55084 .50897 .5584 .51452 .5728 .5124 .56529 .50748 Mtetra
.471 .77 .996 r
.56529 .50748 .5728 .5124 .58729 .5107 .57986 .5065 Mtetra
.402 .762 .994 r
.57986 .5065 .58729 .5107 .6019 .50944 .59455 .50603 Mtetra
.315 .741 .973 r
.59455 .50603 .6019 .50944 .61662 .50859 .60936 .50603 Mtetra
.213 .702 .925 r
.60936 .50603 .61662 .50859 .63147 .50809 .6243 .5064 Mtetra
.108 .648 .852 r
.6243 .5064 .63147 .50809 .64644 .50786 .63937 .50702 Mtetra
.018 .589 .764 r
.63937 .50702 .64644 .50786 .66153 .50777 .65458 .50772 Mtetra
.047 0 0 r
.65458 .50772 .66153 .50777 .67674 .50765 .66991 .50829 Mtetra
.079 0 0 r
.66991 .50829 .67674 .50765 .69207 .50733 .68535 .50851 Mtetra
.078 0 0 r
.68535 .50851 .69207 .50733 .70749 .5066 .70089 .50814 Mtetra
.043 0 0 r
.70089 .50814 .70749 .5066 .723 .50526 .71651 .50695 Mtetra
0 0 0 r
.71651 .50695 .723 .50526 .73857 .50315 .73218 .50475 Mtetra
.73218 .50475 .73857 .50315 .75419 .50011 .74788 .5014 Mtetra
.253 .76 .74 r
.74788 .5014 .75419 .50011 .76984 .49605 .7636 .4968 Mtetra
.396 .853 .821 r
.7636 .4968 .76984 .49605 .78549 .49092 .77931 .49095 Mtetra
.531 .922 .886 r
.77931 .49095 .78549 .49092 .80114 .48475 .795 .48391 Mtetra
.639 .958 .926 r
.795 .48391 .80114 .48475 .81678 .47762 .81067 .47581 Mtetra
.712 .963 .942 r
.81067 .47581 .81678 .47762 .83241 .46965 .82631 .46682 Mtetra
.756 .949 .941 r
.82631 .46682 .83241 .46965 .84803 .46103 .84194 .45717 Mtetra
.777 .925 .933 r
.84194 .45717 .84803 .46103 .86366 .45193 .85757 .44709 Mtetra
.785 .899 .923 r
.85757 .44709 .86366 .45193 .87931 .44256 .87322 .4368 Mtetra
.784 .873 .914 r
.87322 .4368 .87931 .44256 .89499 .43311 .8889 .42653 Mtetra
.777 .85 .906 r
.8889 .42653 .89499 .43311 .91073 .42375 .90465 .41646 Mtetra
.768 .83 .901 r
.90465 .41646 .91073 .42375 .92654 .41461 .92048 .40673 Mtetra
.756 .813 .897 r
.92048 .40673 .92654 .41461 .94245 .4058 .93641 .39743 Mtetra
.662 .742 .909 r
.34876 .5513 .35704 .55898 .37042 .55484 .36219 .54713 Mtetra
.36219 .54713 .37042 .55484 .38387 .5507 .37568 .54297 Mtetra
.661 .742 .91 r
.37568 .54297 .38387 .5507 .39739 .54656 .38924 .53883 Mtetra
.659 .742 .911 r
.38924 .53883 .39739 .54656 .41098 .54244 .40287 .53471 Mtetra
.657 .743 .913 r
.40287 .53471 .41098 .54244 .42463 .53835 .41656 .53065 Mtetra
.654 .744 .916 r
.41656 .53065 .42463 .53835 .43836 .53432 .43033 .52667 Mtetra
.65 .745 .919 r
.43033 .52667 .43836 .53432 .45215 .53036 .44416 .52281 Mtetra
.644 .747 .924 r
.44416 .52281 .45215 .53036 .46601 .52653 .45807 .51911 Mtetra
.635 .749 .93 r
.45807 .51911 .46601 .52653 .47995 .52287 .47205 .51565 Mtetra
.624 .752 .939 r
.47205 .51565 .47995 .52287 .49396 .51941 .4861 .51247 Mtetra
.608 .756 .949 r
.4861 .51247 .49396 .51941 .50805 .51624 .50024 .50965 Mtetra
.586 .76 .961 r
.50024 .50965 .50805 .51624 .52222 .5134 .51446 .50727 Mtetra
.556 .764 .975 r
.51446 .50727 .52222 .5134 .53648 .51096 .52877 .50538 Mtetra
.513 .767 .988 r
.52877 .50538 .53648 .51096 .55084 .50897 .54319 .50406 Mtetra
.453 .763 .996 r
.54319 .50406 .55084 .50897 .56529 .50748 .55771 .50333 Mtetra
.371 .749 .989 r
.55771 .50333 .56529 .50748 .57986 .5065 .57235 .50321 Mtetra
.263 .715 .957 r
.57235 .50321 .57986 .5065 .59455 .50603 .58712 .50366 Mtetra
.137 .656 .888 r
.58712 .50366 .59455 .50603 .60936 .50603 .60202 .50463 Mtetra
.009 .577 .785 r
.60202 .50463 .60936 .50603 .6243 .5064 .61707 .50597 Mtetra
.099 0 0 r
.61707 .50597 .6243 .5064 .63937 .50702 .63225 .50751 Mtetra
.175 0 0 r
.63225 .50751 .63937 .50702 .65458 .50772 .64757 .50904 Mtetra
.215 0 0 r
.64757 .50904 .65458 .50772 .66991 .50829 .66302 .5103 Mtetra
.221 0 0 r
.66302 .5103 .66991 .50829 .68535 .50851 .67858 .51101 Mtetra
.197 0 0 r
.67858 .51101 .68535 .50851 .70089 .50814 .69424 .5109 Mtetra
.14 0 0 r
.69424 .5109 .70089 .50814 .71651 .50695 .70997 .50972 Mtetra
.049 0 0 r
.70997 .50972 .71651 .50695 .73218 .50475 .72573 .50727 Mtetra
0 0 0 r
.72573 .50727 .73218 .50475 .74788 .5014 .74152 .50341 Mtetra
.239 .742 .685 r
.74152 .50341 .74788 .5014 .7636 .4968 .7573 .49808 Mtetra
.412 .858 .791 r
.7573 .49808 .7636 .4968 .77931 .49095 .77306 .49131 Mtetra
.566 .938 .871 r
.77306 .49131 .77931 .49095 .795 .48391 .78878 .48322 Mtetra
.68 .972 .915 r
.78878 .48322 .795 .48391 .81067 .47581 .80446 .47398 Mtetra
.749 .97 .929 r
.80446 .47398 .81067 .47581 .82631 .46682 .82012 .46384 Mtetra
.786 .949 .927 r
.82012 .46384 .82631 .46682 .84194 .45717 .83574 .45306 Mtetra
.801 .921 .918 r
.83574 .45306 .84194 .45717 .85757 .44709 .85137 .44191 Mtetra
.803 .893 .908 r
.85137 .44191 .85757 .44709 .87322 .4368 .86702 .43068 Mtetra
.797 .867 .9 r
.86702 .43068 .87322 .4368 .8889 .42653 .88271 .41957 Mtetra
.788 .844 .894 r
.88271 .41957 .8889 .42653 .90465 .41646 .89847 .4088 Mtetra
.775 .824 .891 r
.89847 .4088 .90465 .41646 .92048 .40673 .91432 .39848 Mtetra
.762 .808 .889 r
.91432 .39848 .92048 .40673 .93641 .39743 .93028 .38873 Mtetra
.662 .742 .909 r
.34041 .54355 .34876 .5513 .36219 .54713 .35388 .53937 Mtetra
.661 .742 .91 r
.35388 .53937 .36219 .54713 .37568 .54297 .36741 .53519 Mtetra
.66 .742 .911 r
.36741 .53519 .37568 .54297 .38924 .53883 .38101 .53105 Mtetra
.658 .743 .913 r
.38101 .53105 .38924 .53883 .40287 .53471 .39468 .52696 Mtetra
.655 .744 .915 r
.39468 .52696 .40287 .53471 .41656 .53065 .40842 .52294 Mtetra
.65 .745 .919 r
.40842 .52294 .41656 .53065 .43033 .52667 .42222 .51905 Mtetra
.644 .746 .923 r
.42222 .51905 .43033 .52667 .44416 .52281 .4361 .51532 Mtetra
.636 .748 .929 r
.4361 .51532 .44416 .52281 .45807 .51911 .45004 .51182 Mtetra
.624 .751 .938 r
.45004 .51182 .45807 .51911 .47205 .51565 .46406 .50862 Mtetra
.608 .755 .948 r
.46406 .50862 .47205 .51565 .4861 .51247 .47816 .5058 Mtetra
.585 .758 .961 r
.47816 .5058 .4861 .51247 .50024 .50965 .49234 .50343 Mtetra
.553 .762 .975 r
.49234 .50343 .50024 .50965 .51446 .50727 .50661 .50161 Mtetra
.506 .763 .988 r
.50661 .50161 .51446 .50727 .52877 .50538 .52098 .50041 Mtetra
.439 .757 .995 r
.52098 .50041 .52877 .50538 .54319 .50406 .53545 .49989 Mtetra
.345 .736 .985 r
.53545 .49989 .54319 .50406 .55771 .50333 .55004 .50007 Mtetra
.219 .689 .941 r
.55004 .50007 .55771 .50333 .57235 .50321 .56476 .50094 Mtetra
.07 .611 .851 r
.56476 .50094 .57235 .50321 .58712 .50366 .57961 .50245 Mtetra
0 .508 .722 r
.57961 .50245 .58712 .50366 .60202 .50463 .59461 .50449 Mtetra
.199 0 0 r
.59461 .50449 .60202 .50463 .61707 .50597 .60976 .50688 Mtetra
.28 0 0 r
.60976 .50688 .61707 .50597 .63225 .50751 .62506 .5094 Mtetra
.324 0 0 r
.62506 .5094 .63225 .50751 .64757 .50904 .6405 .51176 Mtetra
.336 0 0 r
.6405 .51176 .64757 .50904 .66302 .5103 .65607 .51366 Mtetra
.319 0 0 r
.65607 .51366 .66302 .5103 .67858 .51101 .67176 .51477 Mtetra
.274 0 0 r
.67176 .51477 .67858 .51101 .69424 .5109 .68753 .51478 Mtetra
.198 0 0 r
.68753 .51478 .69424 .5109 .70997 .50972 .70336 .51344 Mtetra
.085 0 0 r
.70336 .51344 .70997 .50972 .72573 .50727 .71922 .51053 Mtetra
0 0 0 r
.71922 .51053 .72573 .50727 .74152 .50341 .73508 .50594 Mtetra
.263 .752 .66 r
.73508 .50594 .74152 .50341 .7573 .49808 .75092 .49966 Mtetra
.461 .883 .784 r
.75092 .49966 .7573 .49808 .77306 .49131 .76671 .49176 Mtetra
.624 .961 .869 r
.76671 .49176 .77306 .49131 .78878 .48322 .78246 .48243 Mtetra
.731 .983 .907 r
.78246 .48243 .78878 .48322 .80446 .47398 .79815 .4719 Mtetra
.789 .97 .915 r
.79815 .4719 .80446 .47398 .82012 .46384 .8138 .46049 Mtetra
.814 .942 .91 r
.8138 .46049 .82012 .46384 .83574 .45306 .82943 .4485 Mtetra
.821 .912 .9 r
.82943 .4485 .83574 .45306 .85137 .44191 .84505 .43626 Mtetra
.817 .882 .892 r
.84505 .43626 .85137 .44191 .86702 .43068 .8607 .42406 Mtetra
.808 .857 .886 r
.8607 .42406 .86702 .43068 .88271 .41957 .8764 .41213 Mtetra
.795 .835 .882 r
.8764 .41213 .88271 .41957 .89847 .4088 .89217 .40068 Mtetra
.781 .816 .88 r
.89217 .40068 .89847 .4088 .91432 .39848 .90805 .38984 Mtetra
.767 .801 .881 r
.90805 .38984 .91432 .39848 .93028 .38873 .92405 .37967 Mtetra
.661 .742 .91 r
.33198 .53574 .34041 .54355 .35388 .53937 .34549 .53154 Mtetra
.66 .742 .911 r
.34549 .53154 .35388 .53937 .36741 .53519 .35906 .52737 Mtetra
.658 .743 .912 r
.35906 .52737 .36741 .53519 .38101 .53105 .3727 .52324 Mtetra
.655 .743 .915 r
.3727 .52324 .38101 .53105 .39468 .52696 .38641 .51919 Mtetra
.651 .744 .918 r
.38641 .51919 .39468 .52696 .40842 .52294 .40018 .51525 Mtetra
.645 .746 .922 r
.40018 .51525 .40842 .52294 .42222 .51905 .41403 .51148 Mtetra
.637 .748 .928 r
.41403 .51148 .42222 .51905 .4361 .51532 .42794 .50794 Mtetra
.625 .75 .936 r
.42794 .50794 .4361 .51532 .45004 .51182 .44193 .5047 Mtetra
.609 .753 .947 r
.44193 .5047 .45004 .51182 .46406 .50862 .45599 .50184 Mtetra
.586 .757 .96 r
.45599 .50184 .46406 .50862 .47816 .5058 .47013 .49947 Mtetra
.552 .759 .974 r
.47013 .49947 .47816 .5058 .49234 .50343 .48435 .49767 Mtetra
.503 .759 .988 r
.48435 .49767 .49234 .50343 .50661 .50161 .49867 .49654 Mtetra
.431 .751 .994 r
.49867 .49654 .50661 .50161 .52098 .50041 .51309 .49616 Mtetra
.327 .725 .981 r
.51309 .49616 .52098 .50041 .53545 .49989 .52762 .49658 Mtetra
.186 .668 .929 r
.52762 .49658 .53545 .49989 .55004 .50007 .54228 .4978 Mtetra
.018 .572 .821 r
.54228 .4978 .55004 .50007 .56476 .50094 .55707 .49981 Mtetra
.147 0 0 r
.55707 .49981 .56476 .50094 .57961 .50245 .57202 .50249 Mtetra
.277 0 0 r
.57202 .50249 .57961 .50245 .59461 .50449 .58712 .5057 Mtetra
.362 0 0 r
.58712 .5057 .59461 .50449 .60976 .50688 .60237 .50919 Mtetra
.407 0 0 r
.60237 .50919 .60976 .50688 .62506 .5094 .61779 .51269 Mtetra
.422 0 0 r
.61779 .51269 .62506 .5094 .6405 .51176 .63335 .51584 Mtetra
.412 0 0 r
.63335 .51584 .6405 .51176 .65607 .51366 .64905 .51828 Mtetra
.377 0 0 r
.64905 .51828 .65607 .51366 .67176 .51477 .66486 .51964 Mtetra
.316 0 0 r
.66486 .51964 .67176 .51477 .68753 .51478 .68074 .5196 Mtetra
.222 0 0 r
.68074 .5196 .68753 .51478 .70336 .51344 .69667 .51786 Mtetra
.083 0 0 r
.69667 .51786 .70336 .51344 .71922 .51053 .71261 .51426 Mtetra
0 0 0 r
.71261 .51426 .71922 .51053 .73508 .50594 .72854 .5087 Mtetra
.33 .792 .671 r
.72854 .5087 .73508 .50594 .75092 .49966 .74442 .50123 Mtetra
.542 .923 .801 r
.74442 .50123 .75092 .49966 .76671 .49176 .76025 .492 Mtetra
.696 .982 .874 r
.76025 .492 .76671 .49176 .78246 .48243 .77601 .48126 Mtetra
.784 .985 .899 r
.77601 .48126 .78246 .48243 .79815 .4719 .79171 .46932 Mtetra
.824 .96 .899 r
.79171 .46932 .79815 .4719 .8138 .46049 .80736 .45655 Mtetra
.837 .928 .891 r
.80736 .45655 .8138 .46049 .82943 .4485 .82298 .44332 Mtetra
.836 .896 .882 r
.82298 .44332 .82943 .4485 .84505 .43626 .8386 .42997 Mtetra
.828 .868 .875 r
.8386 .42997 .84505 .43626 .8607 .42406 .85425 .41683 Mtetra
.815 .844 .871 r
.85425 .41683 .8607 .42406 .8764 .41213 .86996 .40413 Mtetra
.801 .824 .87 r
.86996 .40413 .8764 .41213 .89217 .40068 .88576 .39206 Mtetra
.785 .807 .87 r
.88576 .39206 .89217 .40068 .90805 .38984 .90167 .38074 Mtetra
.769 .793 .873 r
.90167 .38074 .90805 .38984 .92405 .37967 .91771 .37022 Mtetra
.66 .742 .91 r
.32347 .52788 .33198 .53574 .34549 .53154 .33701 .52367 Mtetra
.658 .742 .912 r
.33701 .52367 .34549 .53154 .35906 .52737 .35063 .51951 Mtetra
.656 .743 .914 r
.35063 .51951 .35906 .52737 .3727 .52324 .36431 .51542 Mtetra
.652 .744 .917 r
.36431 .51542 .3727 .52324 .38641 .51919 .37805 .51143 Mtetra
.646 .745 .921 r
.37805 .51143 .38641 .51919 .40018 .51525 .39187 .50761 Mtetra
.638 .747 .927 r
.39187 .50761 .40018 .51525 .41403 .51148 .40575 .50401 Mtetra
.627 .749 .935 r
.40575 .50401 .41403 .51148 .42794 .50794 .4197 .5007 Mtetra
.611 .752 .945 r
.4197 .5007 .42794 .50794 .44193 .5047 .43373 .49779 Mtetra
.588 .755 .958 r
.43373 .49779 .44193 .5047 .45599 .50184 .44782 .49537 Mtetra
.554 .757 .972 r
.44782 .49537 .45599 .50184 .47013 .49947 .462 .49356 Mtetra
.504 .756 .986 r
.462 .49356 .47013 .49947 .48435 .49767 .47627 .49245 Mtetra
.43 .746 .993 r
.47627 .49245 .48435 .49767 .49867 .49654 .49063 .49214 Mtetra
.319 .717 .98 r
.49063 .49214 .49867 .49654 .51309 .49616 .5051 .49272 Mtetra
.166 .653 .923 r
.5051 .49272 .51309 .49616 .52762 .49658 .51969 .49422 Mtetra
0 .543 .803 r
.51969 .49422 .52762 .49658 .54228 .4978 .53441 .49663 Mtetra
.197 0 0 r
.53441 .49663 .54228 .4978 .55707 .49981 .54929 .49988 Mtetra
.335 0 0 r
.54929 .49988 .55707 .49981 .57202 .50249 .56432 .50384 Mtetra
.423 0 0 r
.56432 .50384 .57202 .50249 .58712 .5057 .57952 .50826 Mtetra
.47 0 0 r
.57952 .50826 .58712 .5057 .60237 .50919 .59489 .51287 Mtetra
.487 0 0 r
.59489 .51287 .60237 .50919 .61779 .51269 .61043 .51731 Mtetra
.482 0 0 r
.61043 .51731 .61779 .51269 .63335 .51584 .62611 .52115 Mtetra
.456 0 0 r
.62611 .52115 .63335 .51584 .64905 .51828 .64193 .52399 Mtetra
.407 0 0 r
.64193 .52399 .64905 .51828 .66486 .51964 .65786 .52541 Mtetra
.33 0 0 r
.65786 .52541 .66486 .51964 .68074 .5196 .67385 .52507 Mtetra
.213 0 0 r
.67385 .52507 .68074 .5196 .69667 .51786 .68987 .52269 Mtetra
.042 0 0 r
.68987 .52269 .69667 .51786 .71261 .51426 .70589 .51813 Mtetra
0 0 0 r
.70589 .51813 .71261 .51426 .72854 .5087 .72187 .51135 Mtetra
.437 .859 .716 r
.72187 .51135 .72854 .5087 .74442 .50123 .7378 .50247 Mtetra
.644 .966 .831 r
.7378 .50247 .74442 .50123 .76025 .492 .75364 .49172 Mtetra
.769 .993 .88 r
.75364 .49172 .76025 .492 .77601 .48126 .76941 .47943 Mtetra
.829 .974 .888 r
.76941 .47943 .77601 .48126 .79171 .46932 .78511 .46599 Mtetra
.851 .941 .88 r
.78511 .46599 .79171 .46932 .80736 .45655 .80076 .45182 Mtetra
.853 .907 .871 r
.80076 .45182 .80736 .45655 .82298 .44332 .81638 .43734 Mtetra
.846 .876 .863 r
.81638 .43734 .82298 .44332 .8386 .42997 .832 .42292 Mtetra
.834 .85 .858 r
.832 .42292 .8386 .42997 .85425 .41683 .84767 .40889 Mtetra
.819 .829 .857 r
.84767 .40889 .85425 .41683 .86996 .40413 .8634 .39548 Mtetra
.803 .812 .858 r
.8634 .39548 .86996 .40413 .88576 .39206 .87923 .38288 Mtetra
.787 .797 .861 r
.87923 .38288 .88576 .39206 .90167 .38074 .89518 .37117 Mtetra
.77 .785 .866 r
.89518 .37117 .90167 .38074 .91771 .37022 .91127 .36038 Mtetra
.659 .742 .911 r
.31487 .51996 .32347 .52788 .33701 .52367 .32846 .51576 Mtetra
.657 .743 .913 r
.32846 .51576 .33701 .52367 .35063 .51951 .34211 .51163 Mtetra
.653 .743 .916 r
.34211 .51163 .35063 .51951 .36431 .51542 .35583 .50759 Mtetra
.648 .745 .92 r
.35583 .50759 .36431 .51542 .37805 .51143 .36961 .5037 Mtetra
.64 .746 .926 r
.36961 .5037 .37805 .51143 .39187 .50761 .38346 .50003 Mtetra
.629 .748 .933 r
.38346 .50003 .39187 .50761 .40575 .50401 .39738 .49666 Mtetra
.614 .75 .943 r
.39738 .49666 .40575 .50401 .4197 .5007 .41137 .49366 Mtetra
.591 .753 .955 r
.41137 .49366 .4197 .5007 .43373 .49779 .42542 .49117 Mtetra
.558 .755 .969 r
.42542 .49117 .43373 .49779 .44782 .49537 .43956 .48928 Mtetra
.509 .754 .984 r
.43956 .48928 .44782 .49537 .462 .49356 .45377 .48813 Mtetra
.434 .743 .992 r
.45377 .48813 .462 .49356 .47627 .49245 .46807 .48784 Mtetra
.322 .713 .981 r
.46807 .48784 .47627 .49245 .49063 .49214 .48248 .48849 Mtetra
.161 .645 .923 r
.48248 .48849 .49063 .49214 .5051 .49272 .49699 .49017 Mtetra
0 .527 .797 r
.49699 .49017 .5051 .49272 .51969 .49422 .51164 .49289 Mtetra
.228 0 0 r
.51164 .49289 .51969 .49422 .53441 .49663 .52644 .4966 Mtetra
.375 0 0 r
.52644 .4966 .53441 .49663 .54929 .49988 .54139 .5012 Mtetra
.467 0 0 r
.54139 .5012 .54929 .49988 .56432 .50384 .55651 .50648 Mtetra
.516 0 0 r
.55651 .50648 .56432 .50384 .57952 .50826 .57182 .51214 Mtetra
.536 .002 0 r
.57182 .51214 .57952 .50826 .59489 .51287 .5873 .51783 Mtetra
.535 .016 0 r
.5873 .51783 .59489 .51287 .61043 .51731 .60295 .5231 Mtetra
.516 .006 0 r
.60295 .5231 .61043 .51731 .62611 .52115 .61876 .52749 Mtetra
.477 0 0 r
.61876 .52749 .62611 .52115 .64193 .52399 .6347 .53052 Mtetra
.415 0 0 r
.6347 .53052 .64193 .52399 .65786 .52541 .65074 .53176 Mtetra
.318 0 0 r
.65074 .53176 .65786 .52541 .67385 .52507 .66683 .53084 Mtetra
.17 0 0 r
.66683 .53084 .67385 .52507 .68987 .52269 .68294 .52753 Mtetra
0 0 0 r
.68294 .52753 .68987 .52269 .70589 .51813 .69903 .52173 Mtetra
.69903 .52173 .70589 .51813 .72187 .51135 .71506 .51349 Mtetra
.575 .934 .78 r
.71506 .51349 .72187 .51135 .7378 .50247 .73101 .50299 Mtetra
.746 .993 .858 r
.73101 .50299 .7378 .50247 .75364 .49172 .74688 .49057 Mtetra
.829 .984 .876 r
.74688 .49057 .75364 .49172 .76941 .47943 .76265 .47663 Mtetra
.861 .951 .87 r
.76265 .47663 .76941 .47943 .78511 .46599 .77835 .46164 Mtetra
.867 .914 .859 r
.77835 .46164 .78511 .46599 .80076 .45182 .794 .44608 Mtetra
.862 .881 .85 r
.794 .44608 .80076 .45182 .81638 .43734 .80962 .4304 Mtetra
.85 .854 .844 r
.80962 .4304 .81638 .43734 .832 .42292 .82525 .41499 Mtetra
.836 .831 .842 r
.82525 .41499 .832 .42292 .84767 .40889 .84094 .40017 Mtetra
.82 .813 .844 r
.84094 .40017 .84767 .40889 .8634 .39548 .8567 .38616 Mtetra
.803 .799 .847 r
.8567 .38616 .8634 .39548 .87923 .38288 .87257 .37313 Mtetra
.786 .787 .853 r
.87257 .37313 .87923 .38288 .89518 .37117 .88857 .36112 Mtetra
.769 .777 .859 r
.88857 .36112 .89518 .37117 .91127 .36038 .90473 .35014 Mtetra
.657 .742 .913 r
.30619 .512 .31487 .51996 .32846 .51576 .31982 .50782 Mtetra
.654 .743 .915 r
.31982 .50782 .32846 .51576 .34211 .51163 .33351 .50373 Mtetra
.649 .744 .919 r
.33351 .50373 .34211 .51163 .35583 .50759 .34726 .49978 Mtetra
.642 .745 .924 r
.34726 .49978 .35583 .50759 .36961 .5037 .36108 .49603 Mtetra
.632 .747 .931 r
.36108 .49603 .36961 .5037 .38346 .50003 .37497 .49256 Mtetra
.617 .749 .94 r
.37497 .49256 .38346 .50003 .39738 .49666 .38892 .48947 Mtetra
.596 .751 .952 r
.38892 .48947 .39738 .49666 .41137 .49366 .40293 .48686 Mtetra
.564 .753 .966 r
.40293 .48686 .41137 .49366 .42542 .49117 .41702 .48487 Mtetra
.517 .752 .981 r
.41702 .48487 .42542 .49117 .43956 .48928 .43118 .48363 Mtetra
.444 .742 .991 r
.43118 .48363 .43956 .48928 .45377 .48813 .44543 .48327 Mtetra
.333 .713 .983 r
.44543 .48327 .45377 .48813 .46807 .48784 .45976 .48392 Mtetra
.171 .646 .93 r
.45976 .48392 .46807 .48784 .48248 .48849 .47421 .48566 Mtetra
0 .523 .805 r
.47421 .48566 .48248 .48849 .49699 .49017 .48877 .48857 Mtetra
.24 0 0 r
.48877 .48857 .49699 .49017 .51164 .49289 .50347 .49262 Mtetra
.398 0 0 r
.50347 .49262 .51164 .49289 .52644 .4966 .51833 .49773 Mtetra
.497 0 0 r
.51833 .49773 .52644 .4966 .54139 .5012 .53336 .50373 Mtetra
.55 0 0 r
.53336 .50373 .54139 .5012 .55651 .50648 .54858 .51035 Mtetra
.574 .047 0 r
.54858 .51035 .55651 .50648 .57182 .51214 .56399 .51721 Mtetra
.576 .067 .006 r
.56399 .51721 .57182 .51214 .5873 .51783 .57958 .52388 Mtetra
.563 .064 .028 r
.57958 .52388 .5873 .51783 .60295 .5231 .59535 .52983 Mtetra
.532 .038 .027 r
.59535 .52983 .60295 .5231 .61876 .52749 .61128 .53455 Mtetra
.482 0 0 r
.61128 .53455 .61876 .52749 .6347 .53052 .62734 .53751 Mtetra
.402 0 0 r
.62734 .53751 .6347 .53052 .65074 .53176 .64348 .53826 Mtetra
.277 0 0 r
.64348 .53826 .65074 .53176 .66683 .53084 .65967 .53647 Mtetra
.084 0 0 r
.65967 .53647 .66683 .53084 .68294 .52753 .67586 .53194 Mtetra
0 0 0 r
.67586 .53194 .68294 .52753 .69903 .52173 .692 .52463 Mtetra
.49 .886 .725 r
.692 .52463 .69903 .52173 .71506 .51349 .70808 .51469 Mtetra
.712 .986 .837 r
.70808 .51469 .71506 .51349 .73101 .50299 .72405 .50241 Mtetra
.824 .991 .868 r
.72405 .50241 .73101 .50299 .74688 .49057 .73993 .48821 Mtetra
.868 .957 .862 r
.73993 .48821 .74688 .49057 .76265 .47663 .75571 .47259 Mtetra
.878 .918 .849 r
.75571 .47259 .76265 .47663 .77835 .46164 .77141 .45607 Mtetra
.874 .883 .838 r
.77141 .45607 .77835 .46164 .794 .44608 .78706 .43918 Mtetra
.864 .854 .83 r
.78706 .43918 .794 .44608 .80962 .4304 .80269 .42239 Mtetra
.85 .831 .827 r
.80269 .42239 .80962 .4304 .82525 .41499 .81835 .4061 Mtetra
.835 .812 .828 r
.81835 .4061 .82525 .41499 .84094 .40017 .83406 .39062 Mtetra
.819 .798 .832 r
.83406 .39062 .84094 .40017 .8567 .38616 .84987 .37614 Mtetra
.802 .786 .838 r
.84987 .37614 .8567 .38616 .87257 .37313 .86579 .36279 Mtetra
.784 .776 .846 r
.86579 .36279 .87257 .37313 .88857 .36112 .88186 .3506 Mtetra
.767 .769 .854 r
.88186 .3506 .88857 .36112 .90473 .35014 .89809 .33952 Mtetra
.655 .743 .914 r
.29743 .50399 .30619 .512 .31982 .50782 .31109 .49985 Mtetra
.651 .744 .918 r
.31109 .49985 .31982 .50782 .33351 .50373 .32482 .49583 Mtetra
.644 .745 .922 r
.32482 .49583 .33351 .50373 .34726 .49978 .33861 .49199 Mtetra
.635 .746 .929 r
.33861 .49199 .34726 .49978 .36108 .49603 .35246 .48842 Mtetra
.621 .748 .937 r
.35246 .48842 .36108 .49603 .37497 .49256 .36638 .48521 Mtetra
.601 .75 .948 r
.36638 .48521 .37497 .49256 .38892 .48947 .38035 .48247 Mtetra
.572 .751 .962 r
.38035 .48247 .38892 .48947 .40293 .48686 .3944 .48034 Mtetra
.527 .75 .977 r
.3944 .48034 .40293 .48686 .41702 .48487 .40851 .47895 Mtetra
.459 .742 .989 r
.40851 .47895 .41702 .48487 .43118 .48363 .4227 .47846 Mtetra
.353 .716 .986 r
.4227 .47846 .43118 .48363 .44543 .48327 .43697 .47901 Mtetra
.195 .653 .942 r
.43697 .47901 .44543 .48327 .45976 .48392 .45133 .48073 Mtetra
0 .533 .825 r
.45133 .48073 .45976 .48392 .47421 .48566 .46581 .48369 Mtetra
.233 0 0 r
.46581 .48369 .47421 .48566 .48877 .48857 .48042 .48793 Mtetra
.405 0 0 r
.48042 .48793 .48877 .48857 .50347 .49262 .49517 .4934 Mtetra
.514 0 0 r
.49517 .4934 .50347 .49262 .51833 .49773 .5101 .49996 Mtetra
.574 .026 0 r
.5101 .49996 .51833 .49773 .53336 .50373 .5252 .50737 Mtetra
.602 .079 0 r
.5252 .50737 .53336 .50373 .54858 .51035 .54051 .51529 Mtetra
.609 .105 .029 r
.54051 .51529 .54858 .51035 .56399 .51721 .55602 .52325 Mtetra
.6 .108 .058 r
.55602 .52325 .56399 .51721 .57958 .52388 .57172 .53073 Mtetra
.576 .09 .063 r
.57172 .53073 .57958 .52388 .59535 .52983 .58761 .53715 Mtetra
.535 .048 .045 r
.58761 .53715 .59535 .52983 .61128 .53455 .60366 .54192 Mtetra
.47 0 0 r
.60366 .54192 .61128 .53455 .62734 .53751 .61983 .5445 Mtetra
.365 0 0 r
.61983 .5445 .62734 .53751 .64348 .53826 .63607 .54445 Mtetra
.197 0 0 r
.63607 .54445 .64348 .53826 .65967 .53647 .65234 .54146 Mtetra
0 0 0 r
.65234 .54146 .65967 .53647 .67586 .53194 .6686 .53541 Mtetra
.394 .826 .67 r
.6686 .53541 .67586 .53194 .692 .52463 .68479 .52635 Mtetra
.669 .973 .819 r
.68479 .52635 .692 .52463 .70808 .51469 .7009 .51453 Mtetra
.815 .994 .864 r
.7009 .51453 .70808 .51469 .72405 .50241 .7169 .50036 Mtetra
.871 .961 .858 r
.7169 .50036 .72405 .50241 .73993 .48821 .73278 .48434 Mtetra
.886 .919 .841 r
.73278 .48434 .73993 .48821 .75571 .47259 .74857 .46705 Mtetra
.884 .881 .826 r
.74857 .46705 .75571 .47259 .77141 .45607 .76428 .44908 Mtetra
.874 .851 .817 r
.76428 .44908 .77141 .45607 .78706 .43918 .77994 .43098 Mtetra
.861 .827 .812 r
.77994 .43098 .78706 .43918 .80269 .42239 .7956 .41323 Mtetra
.847 .808 .812 r
.7956 .41323 .80269 .42239 .81835 .4061 .81128 .39622 Mtetra
.831 .794 .816 r
.81128 .39622 .81835 .4061 .83406 .39062 .82704 .38023 Mtetra
.815 .782 .822 r
.82704 .38023 .83406 .39062 .84987 .37614 .8429 .36543 Mtetra
.798 .773 .831 r
.8429 .36543 .84987 .37614 .86579 .36279 .8589 .3519 Mtetra
.781 .766 .84 r
.8589 .3519 .86579 .36279 .88186 .3506 .87504 .33963 Mtetra
.764 .761 .85 r
.87504 .33963 .88186 .3506 .89809 .33952 .89135 .32855 Mtetra
.652 .743 .916 r
.28857 .49595 .29743 .50399 .31109 .49985 .30227 .49186 Mtetra
.646 .744 .92 r
.30227 .49186 .31109 .49985 .32482 .49583 .31603 .48794 Mtetra
.638 .745 .926 r
.31603 .48794 .32482 .49583 .33861 .49199 .32986 .48426 Mtetra
.625 .747 .934 r
.32986 .48426 .33861 .49199 .35246 .48842 .34374 .48092 Mtetra
.607 .749 .945 r
.34374 .48092 .35246 .48842 .36638 .48521 .35768 .47803 Mtetra
.58 .75 .958 r
.35768 .47803 .36638 .48521 .38035 .48247 .37168 .47572 Mtetra
.54 .749 .973 r
.37168 .47572 .38035 .48247 .3944 .48034 .38575 .47414 Mtetra
.477 .742 .986 r
.38575 .47414 .3944 .48034 .40851 .47895 .39988 .47346 Mtetra
.379 .72 .988 r
.39988 .47346 .40851 .47895 .4227 .47846 .41409 .47383 Mtetra
.229 .664 .956 r
.41409 .47383 .4227 .47846 .43697 .47901 .42838 .4754 Mtetra
.022 .553 .854 r
.42838 .4754 .43697 .47901 .45133 .48073 .44277 .47829 Mtetra
.207 0 0 r
.44277 .47829 .45133 .48073 .46581 .48369 .45728 .48257 Mtetra
.397 0 0 r
.45728 .48257 .46581 .48369 .48042 .48793 .47192 .48822 Mtetra
.52 0 0 r
.47192 .48822 .48042 .48793 .49517 .4934 .48673 .49516 Mtetra
.588 .038 0 r
.48673 .49516 .49517 .4934 .5101 .49996 .50171 .50318 Mtetra
.622 .099 0 r
.50171 .50318 .5101 .49996 .5252 .50737 .5169 .51195 Mtetra
.633 .132 .04 r
.5169 .51195 .5252 .50737 .54051 .51529 .53229 .52105 Mtetra
.63 .141 .074 r
.53229 .52105 .54051 .51529 .55602 .52325 .5479 .52994 Mtetra
.612 .13 .086 r
.5479 .52994 .55602 .52325 .57172 .53073 .56371 .538 Mtetra
.579 .097 .075 r
.56371 .538 .57172 .53073 .58761 .53715 .57971 .5446 Mtetra
.526 .036 .037 r
.57971 .5446 .58761 .53715 .60366 .54192 .59587 .5491 Mtetra
.439 0 0 r
.59587 .5491 .60366 .54192 .61983 .5445 .61214 .55096 Mtetra
.294 0 0 r
.61214 .55096 .61983 .5445 .63607 .54445 .62848 .54976 Mtetra
.054 0 0 r
.62848 .54976 .63607 .54445 .65234 .54146 .64483 .54526 Mtetra
0 0 0 r
.64483 .54526 .65234 .54146 .6686 .53541 .66114 .53742 Mtetra
.618 .954 .808 r
.66114 .53742 .6686 .53541 .68479 .52635 .67738 .52642 Mtetra
.8 .995 .866 r
.67738 .52642 .68479 .52635 .7009 .51453 .69352 .51261 Mtetra
.87 .962 .858 r
.69352 .51261 .7009 .51453 .7169 .50036 .70953 .4965 Mtetra
.889 .916 .836 r
.70953 .4965 .7169 .50036 .73278 .48434 .72543 .47869 Mtetra
.889 .876 .817 r
.72543 .47869 .73278 .48434 .74857 .46705 .74123 .45983 Mtetra
.88 .844 .804 r
.74123 .45983 .74857 .46705 .76428 .44908 .75696 .44055 Mtetra
.869 .82 .798 r
.75696 .44055 .76428 .44908 .77994 .43098 .77264 .42141 Mtetra
.856 .801 .797 r
.77264 .42141 .77994 .43098 .7956 .41323 .78833 .40289 Mtetra
.841 .787 .8 r
.78833 .40289 .7956 .41323 .81128 .39622 .80407 .38534 Mtetra
.826 .776 .806 r
.80407 .38534 .81128 .39622 .82704 .38023 .81989 .36903 Mtetra
.81 .768 .814 r
.81989 .36903 .82704 .38023 .8429 .36543 .83582 .35406 Mtetra
.793 .762 .825 r
.83582 .35406 .8429 .36543 .8589 .3519 .85189 .34049 Mtetra
.776 .757 .836 r
.85189 .34049 .8589 .3519 .87504 .33963 .86812 .32825 Mtetra
.759 .754 .848 r
.86812 .32825 .87504 .33963 .89135 .32855 .88452 .31726 Mtetra
.649 .744 .919 r
.27963 .48789 .28857 .49595 .30227 .49186 .29336 .48388 Mtetra
.641 .745 .924 r
.29336 .48388 .30227 .49186 .31603 .48794 .30716 .48009 Mtetra
.63 .746 .931 r
.30716 .48009 .31603 .48794 .32986 .48426 .32101 .4766 Mtetra
.614 .747 .941 r
.32101 .4766 .32986 .48426 .34374 .48092 .33492 .47354 Mtetra
.589 .748 .953 r
.33492 .47354 .34374 .48092 .35768 .47803 .34888 .47103 Mtetra
.553 .748 .968 r
.34888 .47103 .35768 .47803 .37168 .47572 .3629 .46923 Mtetra
.497 .743 .982 r
.3629 .46923 .37168 .47572 .38575 .47414 .37699 .46829 Mtetra
.409 .725 .989 r
.37699 .46829 .38575 .47414 .39988 .47346 .39113 .46841 Mtetra
.272 .679 .969 r
.39113 .46841 .39988 .47346 .41409 .47383 .40535 .46974 Mtetra
.075 .581 .889 r
.40535 .46974 .41409 .47383 .42838 .4754 .41966 .47243 Mtetra
0 .42 .721 r
.41966 .47243 .42838 .4754 .44277 .47829 .43407 .47659 Mtetra
.369 0 0 r
.43407 .47659 .44277 .47829 .45728 .48257 .4486 .48225 Mtetra
.512 0 0 r
.4486 .48225 .45728 .48257 .47192 .48822 .46328 .48935 Mtetra
.593 .038 0 r
.46328 .48935 .47192 .48822 .48673 .49516 .47813 .49776 Mtetra
.635 .109 0 r
.47813 .49776 .48673 .49516 .50171 .50318 .49318 .50717 Mtetra
.652 .149 .039 r
.49318 .50717 .50171 .50318 .5169 .51195 .50843 .5172 Mtetra
.653 .165 .079 r
.50843 .5172 .5169 .51195 .53229 .52105 .52391 .52731 Mtetra
.641 .161 .097 r
.52391 .52731 .53229 .52105 .5479 .52994 .53962 .53688 Mtetra
.616 .136 .092 r
.53962 .53688 .5479 .52994 .56371 .538 .55554 .54523 Mtetra
.572 .086 .063 r
.55554 .54523 .56371 .538 .57971 .5446 .57165 .55166 Mtetra
.5 0 0 r
.57165 .55166 .57971 .5446 .59587 .5491 .58791 .55553 Mtetra
.377 0 0 r
.58791 .55553 .59587 .5491 .61214 .55096 .60427 .55631 Mtetra
.163 0 0 r
.60427 .55631 .61214 .55096 .62848 .54976 .6207 .55362 Mtetra
0 0 0 r
.6207 .55362 .62848 .54976 .64483 .54526 .63711 .54733 Mtetra
.557 .93 .804 r
.63711 .54733 .64483 .54526 .66114 .53742 .65348 .5375 Mtetra
.781 .993 .877 r
.65348 .5375 .66114 .53742 .67738 .52642 .66976 .52442 Mtetra
.865 .96 .864 r
.66976 .52442 .67738 .52642 .69352 .51261 .68592 .50857 Mtetra
.889 .911 .835 r
.68592 .50857 .69352 .51261 .70953 .4965 .70196 .49056 Mtetra
.89 .868 .811 r
.70196 .49056 .70953 .4965 .72543 .47869 .71787 .47108 Mtetra
.883 .835 .794 r
.71787 .47108 .72543 .47869 .74123 .45983 .73369 .45081 Mtetra
.872 .81 .785 r
.73369 .45081 .74123 .45983 .75696 .44055 .74945 .43042 Mtetra
.86 .792 .782 r
.74945 .43042 .75696 .44055 .77264 .42141 .76517 .41046 Mtetra
.847 .778 .784 r
.76517 .41046 .77264 .42141 .78833 .40289 .78091 .39139 Mtetra
.834 .768 .789 r
.78091 .39139 .78833 .40289 .80407 .38534 .79671 .37352 Mtetra
.819 .761 .798 r
.79671 .37352 .80407 .38534 .81989 .36903 .8126 .35706 Mtetra
.803 .756 .809 r
.8126 .35706 .81989 .36903 .83582 .35406 .82862 .3421 Mtetra
.787 .752 .821 r
.82862 .3421 .83582 .35406 .85189 .34049 .84478 .32861 Mtetra
.771 .749 .834 r
.84478 .32861 .85189 .34049 .86812 .32825 .8611 .31653 Mtetra
.754 .748 .846 r
.8611 .31653 .86812 .32825 .88452 .31726 .8776 .3057 Mtetra
.644 .744 .922 r
.27059 .47981 .27963 .48789 .29336 .48388 .28436 .4759 Mtetra
.634 .745 .928 r
.28436 .4759 .29336 .48388 .30716 .48009 .29818 .47228 Mtetra
.62 .746 .937 r
.29818 .47228 .30716 .48009 .32101 .4766 .31206 .46903 Mtetra
.598 .747 .948 r
.31206 .46903 .32101 .4766 .33492 .47354 .32599 .46631 Mtetra
.566 .747 .962 r
.32599 .46631 .33492 .47354 .34888 .47103 .33997 .46425 Mtetra
.517 .743 .977 r
.33997 .46425 .34888 .47103 .3629 .46923 .35401 .46302 Mtetra
.44 .73 .988 r
.35401 .46302 .3629 .46923 .37699 .46829 .3681 .46282 Mtetra
.32 .694 .98 r
.3681 .46282 .37699 .46829 .39113 .46841 .38225 .46382 Mtetra
.139 .612 .922 r
.38225 .46382 .39113 .46841 .40535 .46974 .39648 .4662 Mtetra
0 .467 .781 r
.39648 .4662 .40535 .46974 .41966 .47243 .41079 .47009 Mtetra
.322 0 0 r
.41079 .47009 .41966 .47243 .43407 .47659 .42522 .47556 Mtetra
.488 0 0 r
.42522 .47556 .43407 .47659 .4486 .48225 .43977 .48263 Mtetra
.588 .024 0 r
.43977 .48263 .4486 .48225 .46328 .48935 .45448 .49118 Mtetra
.64 .107 0 r
.45448 .49118 .46328 .48935 .47813 .49776 .46938 .50098 Mtetra
.665 .156 .026 r
.46938 .50098 .47813 .49776 .49318 .50717 .48448 .51167 Mtetra
.671 .18 .074 r
.48448 .51167 .49318 .50717 .50843 .5172 .4998 .52277 Mtetra
.665 .183 .097 r
.4998 .52277 .50843 .5172 .52391 .52731 .51537 .53364 Mtetra
.645 .166 .099 r
.51537 .53364 .52391 .52731 .53962 .53688 .53117 .54359 Mtetra
.61 .125 .076 r
.53117 .54359 .53962 .53688 .55554 .54523 .54719 .55187 Mtetra
.551 .052 .022 r
.54719 .55187 .55554 .54523 .57165 .55166 .5634 .55776 Mtetra
.448 0 0 r
.5634 .55776 .57165 .55166 .58791 .55553 .57976 .56061 Mtetra
.26 0 0 r
.57976 .56061 .58791 .55553 .60427 .55631 .59622 .55994 Mtetra
0 0 0 r
.59622 .55994 .60427 .55631 .6207 .55362 .61271 .55547 Mtetra
.486 .898 .807 r
.61271 .55547 .6207 .55362 .63711 .54733 .62919 .54716 Mtetra
.755 .988 .895 r
.62919 .54716 .63711 .54733 .65348 .5375 .64561 .53519 Mtetra
.855 .954 .875 r
.64561 .53519 .65348 .5375 .66976 .52442 .66192 .51999 Mtetra
.883 .901 .837 r
.66192 .51999 .66976 .52442 .68592 .50857 .67811 .50215 Mtetra
.887 .857 .807 r
.67811 .50215 .68592 .50857 .70196 .49056 .69417 .48237 Mtetra
.881 .823 .786 r
.69417 .48237 .70196 .49056 .71787 .47108 .71011 .46139 Mtetra
.872 .798 .774 r
.71011 .46139 .71787 .47108 .73369 .45081 .72597 .43995 Mtetra
.862 .78 .769 r
.72597 .43995 .73369 .45081 .74945 .43042 .74176 .4187 Mtetra
.851 .767 .769 r
.74176 .4187 .74945 .43042 .76517 .41046 .75754 .39818 Mtetra
.838 .758 .774 r
.75754 .39818 .76517 .41046 .78091 .39139 .77334 .3788 Mtetra
.825 .751 .782 r
.77334 .3788 .78091 .39139 .79671 .37352 .78922 .36083 Mtetra
.811 .747 .793 r
.78922 .36083 .79671 .37352 .8126 .35706 .8052 .34442 Mtetra
.796 .745 .805 r
.8052 .34442 .8126 .35706 .82862 .3421 .82131 .32962 Mtetra
.78 .743 .819 r
.82131 .32962 .82862 .3421 .84478 .32861 .83757 .31635 Mtetra
.764 .743 .833 r
.83757 .31635 .84478 .32861 .8611 .31653 .854 .3045 Mtetra
.748 .742 .846 r
.854 .3045 .8611 .31653 .8776 .3057 .8706 .29392 Mtetra
.638 .744 .925 r
.26146 .47172 .27059 .47981 .28436 .4759 .27526 .46795 Mtetra
.626 .745 .933 r
.27526 .46795 .28436 .4759 .29818 .47228 .2891 .46452 Mtetra
.607 .746 .943 r
.2891 .46452 .29818 .47228 .31206 .46903 .303 .46157 Mtetra
.579 .746 .956 r
.303 .46157 .31206 .46903 .32599 .46631 .31695 .45923 Mtetra
.537 .744 .971 r
.31695 .45923 .32599 .46631 .33997 .46425 .33094 .45769 Mtetra
.472 .734 .984 r
.33094 .45769 .33997 .46425 .35401 .46302 .34499 .45711 Mtetra
.368 .707 .985 r
.34499 .45711 .35401 .46302 .3681 .46282 .35908 .45771 Mtetra
.209 .643 .951 r
.35908 .45771 .3681 .46282 .38225 .46382 .37324 .45967 Mtetra
0 .519 .843 r
.37324 .45967 .38225 .46382 .39648 .4662 .38747 .46316 Mtetra
.252 0 0 r
.38747 .46316 .39648 .4662 .41079 .47009 .40179 .46828 Mtetra
.446 0 0 r
.40179 .46828 .41079 .47009 .42522 .47556 .41622 .4751 Mtetra
.569 0 0 r
.41622 .4751 .42522 .47556 .43977 .48263 .43079 .48355 Mtetra
.637 .093 0 r
.43079 .48355 .43977 .48263 .45448 .49118 .44552 .49347 Mtetra
.671 .154 0 r
.44552 .49347 .45448 .49118 .46938 .50098 .46046 .50454 Mtetra
.684 .186 .057 r
.46046 .50454 .46938 .50098 .48448 .51167 .47562 .51632 Mtetra
.683 .197 .088 r
.47562 .51632 .48448 .51167 .4998 .52277 .49101 .52822 Mtetra
.67 .187 .096 r
.49101 .52822 .4998 .52277 .51537 .53364 .50666 .53953 Mtetra
.642 .155 .079 r
.50666 .53953 .51537 .53364 .53117 .54359 .52255 .5495 Mtetra
.594 .093 .032 r
.52255 .5495 .53117 .54359 .54719 .55187 .53867 .55732 Mtetra
.508 0 0 r
.53867 .55732 .54719 .55187 .5634 .55776 .55497 .56226 Mtetra
.346 0 0 r
.55497 .56226 .5634 .55776 .57976 .56061 .57143 .56373 Mtetra
.037 0 0 r
.57143 .56373 .57976 .56061 .59622 .55994 .58796 .5613 Mtetra
.406 .858 .816 r
.58796 .5613 .59622 .55994 .61271 .55547 .60453 .55479 Mtetra
.721 .976 .921 r
.60453 .55479 .61271 .55547 .62919 .54716 .62107 .5443 Mtetra
.839 .944 .89 r
.62107 .5443 .62919 .54716 .64561 .53519 .63753 .53014 Mtetra
.873 .889 .842 r
.63753 .53014 .64561 .53519 .66192 .51999 .65387 .51287 Mtetra
.879 .843 .805 r
.65387 .51287 .66192 .51999 .67811 .50215 .67009 .49317 Mtetra
.875 .809 .78 r
.67009 .49317 .67811 .50215 .69417 .48237 .68618 .47183 Mtetra
.868 .784 .765 r
.68618 .47183 .69417 .48237 .71011 .46139 .70216 .44963 Mtetra
.86 .766 .758 r
.70216 .44963 .71011 .46139 .72597 .43995 .71806 .4273 Mtetra
.85 .754 .756 r
.71806 .4273 .72597 .43995 .74176 .4187 .73391 .40548 Mtetra
.84 .746 .76 r
.73391 .40548 .74176 .4187 .75754 .39818 .74975 .38467 Mtetra
.829 .74 .767 r
.74975 .38467 .75754 .39818 .77334 .3788 .76564 .36523 Mtetra
.816 .737 .777 r
.76564 .36523 .77334 .3788 .78922 .36083 .78161 .34738 Mtetra
.803 .736 .789 r
.78161 .34738 .78922 .36083 .8052 .34442 .79768 .33121 Mtetra
.789 .735 .804 r
.79768 .33121 .8052 .34442 .82131 .32962 .8139 .31671 Mtetra
.773 .736 .819 r
.8139 .31671 .82131 .32962 .83757 .31635 .83027 .30377 Mtetra
.758 .737 .834 r
.83027 .30377 .83757 .31635 .854 .3045 .84681 .29225 Mtetra
.742 .738 .848 r
.84681 .29225 .854 .3045 .8706 .29392 .86353 .28196 Mtetra
.631 .744 .929 r
.25223 .46363 .26146 .47172 .27526 .46795 .26605 .46003 Mtetra
.615 .745 .938 r
.26605 .46003 .27526 .46795 .2891 .46452 .27992 .45684 Mtetra
.592 .745 .95 r
.27992 .45684 .2891 .46452 .303 .46157 .29384 .45422 Mtetra
.556 .744 .964 r
.29384 .45422 .303 .46157 .31695 .45923 .3078 .45233 Mtetra
.501 .737 .979 r
.3078 .45233 .31695 .45923 .33094 .45769 .3218 .45135 Mtetra
.414 .718 .987 r
.3218 .45135 .33094 .45769 .34499 .45711 .33584 .45149 Mtetra
.279 .671 .971 r
.33584 .45149 .34499 .45711 .35908 .45771 .34993 .45295 Mtetra
.081 .572 .898 r
.34993 .45295 .35908 .45771 .37324 .45967 .36409 .45592 Mtetra
0 .411 .738 r
.36409 .45592 .37324 .45967 .38747 .46316 .37831 .46054 Mtetra
.38 0 0 r
.37831 .46054 .38747 .46316 .40179 .46828 .39263 .46691 Mtetra
.533 0 0 r
.39263 .46691 .40179 .46828 .41622 .4751 .40706 .47503 Mtetra
.622 .065 0 r
.40706 .47503 .41622 .4751 .43079 .48355 .42165 .48479 Mtetra
.669 .14 0 r
.42165 .48479 .43079 .48355 .44552 .49347 .43641 .49593 Mtetra
.69 .183 .028 r
.43641 .49593 .44552 .49347 .46046 .50454 .45138 .50808 Mtetra
.696 .202 .068 r
.45138 .50808 .46046 .50454 .47562 .51632 .46659 .52068 Mtetra
.689 .2 .082 r
.46659 .52068 .47562 .51632 .49101 .52822 .48206 .53306 Mtetra
.668 .176 .072 r
.48206 .53306 .49101 .52822 .50666 .53953 .49779 .54445 Mtetra
.629 .125 .031 r
.49779 .54445 .50666 .53953 .52255 .5495 .51377 .55402 Mtetra
.558 .029 0 r
.51377 .55402 .52255 .5495 .53867 .55732 .52997 .56096 Mtetra
.419 0 0 r
.52997 .56096 .53867 .55732 .55497 .56226 .54637 .56457 Mtetra
.138 0 0 r
.54637 .56457 .55497 .56226 .57143 .56373 .56291 .56431 Mtetra
.316 .806 .829 r
.56291 .56431 .57143 .56373 .58796 .5613 .57952 .55985 Mtetra
.675 .955 .949 r
.57952 .55985 .58796 .5613 .60453 .55479 .59615 .55114 Mtetra
.815 .928 .908 r
.59615 .55114 .60453 .55479 .62107 .5443 .61274 .53841 Mtetra
.857 .872 .85 r
.61274 .53841 .62107 .5443 .63753 .53014 .62924 .52212 Mtetra
.867 .826 .806 r
.62924 .52212 .63753 .53014 .65387 .51287 .64563 .50293 Mtetra
.866 .792 .777 r
.64563 .50293 .65387 .51287 .67009 .49317 .66188 .4816 Mtetra
.861 .769 .759 r
.66188 .4816 .67009 .49317 .68618 .47183 .67801 .45899 Mtetra
.855 .752 .749 r
.67801 .45899 .68618 .47183 .70216 .44963 .69404 .43587 Mtetra
.847 .74 .745 r
.69404 .43587 .70216 .44963 .71806 .4273 .70999 .41298 Mtetra
.839 .732 .747 r
.70999 .41298 .71806 .4273 .73391 .40548 .72591 .3909 Mtetra
.829 .728 .753 r
.72591 .3909 .73391 .40548 .74975 .38467 .74184 .37009 Mtetra
.819 .725 .762 r
.74184 .37009 .74975 .38467 .76564 .36523 .75782 .35084 Mtetra
.807 .725 .774 r
.75782 .35084 .76564 .36523 .78161 .34738 .77389 .33332 Mtetra
.794 .726 .788 r
.77389 .33332 .78161 .34738 .79768 .33121 .79007 .31755 Mtetra
.78 .728 .804 r
.79007 .31755 .79768 .33121 .8139 .31671 .80641 .30347 Mtetra
.766 .73 .82 r
.80641 .30347 .8139 .31671 .83027 .30377 .82289 .29095 Mtetra
.751 .732 .835 r
.82289 .29095 .83027 .30377 .84681 .29225 .83955 .27982 Mtetra
.736 .734 .85 r
.83955 .27982 .84681 .29225 .86353 .28196 .85638 .26986 Mtetra
.623 .744 .934 r
.2429 .45555 .25223 .46363 .26605 .46003 .25674 .45214 Mtetra
.603 .745 .944 r
.25674 .45214 .26605 .46003 .27992 .45684 .27063 .44924 Mtetra
.573 .744 .957 r
.27063 .44924 .27992 .45684 .29384 .45422 .28456 .44699 Mtetra
.528 .739 .972 r
.28456 .44699 .29384 .45422 .3078 .45233 .29853 .44559 Mtetra
.457 .726 .984 r
.29853 .44559 .3078 .45233 .3218 .45135 .31253 .44524 Mtetra
.345 .693 .982 r
.31253 .44524 .3218 .45135 .33584 .45149 .32657 .44614 Mtetra
.177 .62 .94 r
.32657 .44614 .33584 .45149 .34993 .45295 .34065 .44849 Mtetra
0 .486 .823 r
.34065 .44849 .34993 .45295 .36409 .45592 .35479 .45248 Mtetra
.288 0 0 r
.35479 .45248 .36409 .45592 .37831 .46054 .36901 .45824 Mtetra
.474 0 0 r
.36901 .45824 .37831 .46054 .39263 .46691 .38332 .46581 Mtetra
.591 .02 0 r
.38332 .46581 .39263 .46691 .40706 .47503 .39776 .47514 Mtetra
.656 .113 0 r
.39776 .47514 .40706 .47503 .42165 .48479 .41235 .48606 Mtetra
.689 .169 0 r
.41235 .48606 .42165 .48479 .43641 .49593 .42714 .49823 Mtetra
.702 .198 .036 r
.42714 .49823 .43641 .49593 .45138 .50808 .44215 .51118 Mtetra
.702 .204 .058 r
.44215 .51118 .45138 .50808 .46659 .52068 .45742 .52427 Mtetra
.688 .189 .054 r
.45742 .52427 .46659 .52068 .48206 .53306 .47295 .53676 Mtetra
.657 .147 .019 r
.47295 .53676 .48206 .53306 .49779 .54445 .48876 .5478 Mtetra
.598 .064 0 r
.48876 .5478 .49779 .54445 .51377 .55402 .50483 .55656 Mtetra
.479 0 0 r
.50483 .55656 .51377 .55402 .52997 .56096 .52112 .56222 Mtetra
.228 0 0 r
.52112 .56222 .52997 .56096 .54637 .56457 .53761 .56415 Mtetra
.221 .741 .839 r
.53761 .56415 .54637 .56457 .56291 .56431 .55422 .56187 Mtetra
.618 .921 .976 r
.55422 .56187 .56291 .56431 .57952 .55985 .57091 .5552 Mtetra
.782 .903 .926 r
.57091 .5552 .57952 .55985 .59615 .55114 .58759 .54423 Mtetra
.834 .85 .858 r
.58759 .54423 .59615 .55114 .61274 .53841 .60423 .52931 Mtetra
.849 .806 .808 r
.60423 .52931 .61274 .53841 .62924 .52212 .62077 .51104 Mtetra
.852 .774 .775 r
.62077 .51104 .62924 .52212 .64563 .50293 .6372 .49016 Mtetra
.851 .752 .754 r
.6372 .49016 .64563 .50293 .66188 .4816 .65349 .46752 Mtetra
.846 .736 .742 r
.65349 .46752 .66188 .4816 .67801 .45899 .66967 .44397 Mtetra
.841 .725 .736 r
.66967 .44397 .67801 .45899 .69404 .43587 .68576 .42029 Mtetra
.834 .718 .736 r
.68576 .42029 .69404 .43587 .70999 .41298 .70178 .39718 Mtetra
.827 .714 .74 r
.70178 .39718 .70999 .41298 .72591 .3909 .71778 .37516 Mtetra
.819 .713 .749 r
.71778 .37516 .72591 .3909 .74184 .37009 .73381 .35462 Mtetra
.809 .713 .76 r
.73381 .35462 .74184 .37009 .75782 .35084 .74989 .3358 Mtetra
.798 .715 .774 r
.74989 .3358 .75782 .35084 .77389 .33332 .76607 .31878 Mtetra
.786 .718 .789 r
.76607 .31878 .77389 .33332 .79007 .31755 .78238 .30355 Mtetra
.772 .722 .806 r
.78238 .30355 .79007 .31755 .80641 .30347 .79883 .29 Mtetra
.758 .726 .823 r
.79883 .29 .80641 .30347 .82289 .29095 .81544 .27798 Mtetra
.743 .729 .839 r
.81544 .27798 .82289 .29095 .83955 .27982 .83222 .26728 Mtetra
.729 .732 .853 r
.83222 .26728 .83955 .27982 .85638 .26986 .84916 .25768 Mtetra
.613 .744 .939 r
.23347 .44748 .2429 .45555 .25674 .45214 .24733 .4443 Mtetra
.589 .743 .95 r
.24733 .4443 .25674 .45214 .27063 .44924 .26123 .4417 Mtetra
.551 .74 .964 r
.26123 .4417 .27063 .44924 .28456 .44699 .27517 .43987 Mtetra
.494 .731 .978 r
.27517 .43987 .28456 .44699 .29853 .44559 .28913 .439 Mtetra
.405 .709 .985 r
.28913 .439 .29853 .44559 .31253 .44524 .30313 .4393 Mtetra
.266 .658 .967 r
.30313 .4393 .31253 .44524 .32657 .44614 .31716 .44098 Mtetra
.068 .556 .894 r
.31716 .44098 .32657 .44614 .34065 .44849 .33123 .44425 Mtetra
0 .395 .739 r
.33123 .44425 .34065 .44849 .35479 .45248 .34536 .44925 Mtetra
.387 0 0 r
.34536 .44925 .35479 .45248 .36901 .45824 .35956 .45609 Mtetra
.538 0 0 r
.35956 .45609 .36901 .45824 .38332 .46581 .37387 .46476 Mtetra
.629 .068 0 r
.37387 .46476 .38332 .46581 .39776 .47514 .3883 .47516 Mtetra
.677 .142 0 r
.3883 .47516 .39776 .47514 .41235 .48606 .40291 .48703 Mtetra
.701 .183 0 r
.40291 .48703 .41235 .48606 .42714 .49823 .41773 .49997 Mtetra
.708 .199 .021 r
.41773 .49997 .42714 .49823 .44215 .51118 .43278 .51339 Mtetra
.7 .192 .024 r
.43278 .51339 .44215 .51118 .45742 .52427 .44811 .5266 Mtetra
.677 .159 0 r
.44811 .5266 .45742 .52427 .47295 .53676 .46371 .53877 Mtetra
.628 .088 0 r
.46371 .53877 .47295 .53676 .48876 .5478 .4796 .54905 Mtetra
.525 0 0 r
.4796 .54905 .48876 .5478 .50483 .55656 .49575 .55657 Mtetra
.301 0 0 r
.49575 .55657 .50483 .55656 .52112 .56222 .51213 .56059 Mtetra
.126 .666 .844 r
.51213 .56059 .52112 .56222 .53761 .56415 .5287 .56053 Mtetra
.548 .87 .994 r
.5287 .56053 .53761 .56415 .55422 .56187 .54538 .55605 Mtetra
.738 .869 .941 r
.54538 .55605 .55422 .56187 .57091 .5552 .56213 .54709 Mtetra
.804 .824 .866 r
.56213 .54709 .57091 .5552 .58759 .54423 .57887 .5339 Mtetra
.828 .784 .811 r
.57887 .5339 .58759 .54423 .60423 .52931 .59556 .51695 Mtetra
.835 .755 .774 r
.59556 .51695 .60423 .52931 .62077 .51104 .61214 .49695 Mtetra
.837 .734 .75 r
.61214 .49695 .62077 .51104 .6372 .49016 .62861 .47471 Mtetra
.836 .72 .736 r
.62861 .47471 .6372 .49016 .65349 .46752 .64495 .45112 Mtetra
.833 .71 .729 r
.64495 .45112 .65349 .46752 .66967 .44397 .66119 .42701 Mtetra
.828 .704 .727 r
.66119 .42701 .66967 .44397 .68576 .42029 .67734 .40315 Mtetra
.823 .701 .73 r
.67734 .40315 .68576 .42029 .70178 .39718 .69345 .38015 Mtetra
.816 .7 .737 r
.69345 .38015 .70178 .39718 .71778 .37516 .70955 .35849 Mtetra
.808 .701 .747 r
.70955 .35849 .71778 .37516 .73381 .35462 .72568 .33848 Mtetra
.799 .704 .76 r
.72568 .33848 .73381 .35462 .74989 .3358 .74188 .32028 Mtetra
.789 .708 .775 r
.74188 .32028 .74989 .3358 .76607 .31878 .75818 .30392 Mtetra
.777 .713 .792 r
.75818 .30392 .76607 .31878 .78238 .30355 .77461 .28934 Mtetra
.764 .718 .809 r
.77461 .28934 .78238 .30355 .79883 .29 .79119 .27641 Mtetra
.75 .722 .827 r
.79119 .27641 .79883 .29 .81544 .27798 .80793 .26492 Mtetra
.736 .727 .843 r
.80793 .26492 .81544 .27798 .83222 .26728 .82482 .25467 Mtetra
.722 .73 .857 r
.82482 .25467 .83222 .26728 .84916 .25768 .84188 .24545 Mtetra
.602 .743 .944 r
.22392 .43942 .23347 .44748 .24733 .4443 .2378 .43649 Mtetra
.572 .741 .956 r
.2378 .43649 .24733 .4443 .26123 .4417 .25171 .43424 Mtetra
.526 .735 .97 r
.25171 .43424 .26123 .4417 .27517 .43987 .26565 .43285 Mtetra
.455 .72 .982 r
.26565 .43285 .27517 .43987 .28913 .439 .27962 .43253 Mtetra
.346 .686 .98 r
.27962 .43253 .28913 .439 .30313 .4393 .29361 .4335 Mtetra
.182 .615 .943 r
.29361 .4335 .30313 .4393 .31716 .44098 .30762 .43597 Mtetra
0 .487 .838 r
.30762 .43597 .31716 .44098 .33123 .44425 .32168 .44011 Mtetra
0 .312 .66 r
.32168 .44011 .33123 .44425 .34536 .44925 .33579 .44607 Mtetra
.457 0 0 r
.33579 .44607 .34536 .44925 .35956 .45609 .34998 .45389 Mtetra
.58 .003 0 r
.34998 .45389 .35956 .45609 .37387 .46476 .36428 .46352 Mtetra
.651 .097 0 r
.36428 .46352 .37387 .46476 .3883 .47516 .37872 .47479 Mtetra
.689 .154 0 r
.37872 .47479 .3883 .47516 .40291 .48703 .39334 .48735 Mtetra
.705 .182 0 r
.39334 .48735 .40291 .48703 .41773 .49997 .40819 .50072 Mtetra
.705 .185 0 r
.40819 .50072 .41773 .49997 .43278 .51339 .42329 .51424 Mtetra
.688 .161 0 r
.42329 .51424 .43278 .51339 .44811 .5266 .43867 .52715 Mtetra
.647 .1 0 r
.43867 .52715 .44811 .5266 .46371 .53877 .45435 .53859 Mtetra
.557 0 0 r
.45435 .53859 .46371 .53877 .4796 .54905 .47032 .54768 Mtetra
.355 0 0 r
.47032 .54768 .4796 .54905 .49575 .55657 .48655 .5536 Mtetra
.041 .586 .841 r
.48655 .5536 .49575 .55657 .51213 .56059 .50302 .55566 Mtetra
.469 .805 .999 r
.50302 .55566 .51213 .56059 .5287 .56053 .51966 .55341 Mtetra
.686 .827 .951 r
.51966 .55341 .5287 .56053 .54538 .55605 .53642 .54664 Mtetra
.768 .793 .873 r
.53642 .54664 .54538 .55605 .56213 .54709 .55322 .53543 Mtetra
.801 .759 .814 r
.55322 .53543 .56213 .54709 .57887 .5339 .57001 .52017 Mtetra
.815 .734 .774 r
.57001 .52017 .57887 .5339 .59556 .51695 .58674 .50144 Mtetra
.821 .715 .749 r
.58674 .50144 .59556 .51695 .61214 .49695 .60337 .48005 Mtetra
.823 .703 .732 r
.60337 .48005 .61214 .49695 .62861 .47471 .61989 .45684 Mtetra
.822 .694 .724 r
.61989 .45684 .62861 .47471 .64495 .45112 .63629 .43269 Mtetra
.82 .689 .72 r
.63629 .43269 .64495 .45112 .66119 .42701 .65259 .40842 Mtetra
.816 .687 .722 r
.65259 .40842 .66119 .42701 .67734 .40315 .66882 .38474 Mtetra
.812 .687 .727 r
.66882 .38474 .67734 .40315 .69345 .38015 .68502 .36218 Mtetra
.806 .689 .736 r
.68502 .36218 .69345 .38015 .70955 .35849 .70122 .34115 Mtetra
.798 .692 .748 r
.70122 .34115 .70955 .35849 .72568 .33848 .71747 .32188 Mtetra
.79 .697 .762 r
.71747 .32188 .72568 .33848 .74188 .32028 .73379 .30446 Mtetra
.779 .703 .779 r
.73379 .30446 .74188 .32028 .75818 .30392 .75022 .28889 Mtetra
.768 .709 .797 r
.75022 .28889 .75818 .30392 .77461 .28934 .76678 .27504 Mtetra
.755 .715 .815 r
.76678 .27504 .77461 .28934 .79119 .27641 .78349 .26276 Mtetra
.742 .72 .832 r
.78349 .26276 .79119 .27641 .80793 .26492 .80035 .25183 Mtetra
.728 .725 .848 r
.80035 .25183 .80793 .26492 .82482 .25467 .81736 .24204 Mtetra
.715 .73 .862 r
.81736 .24204 .82482 .25467 .84188 .24545 .83454 .23319 Mtetra
.589 .741 .949 r
.21428 .43136 .22392 .43942 .2378 .43649 .22817 .42871 Mtetra
.553 .738 .962 r
.22817 .42871 .2378 .43649 .25171 .43424 .24208 .42682 Mtetra
.497 .728 .975 r
.24208 .42682 .25171 .43424 .26565 .43285 .25602 .42589 Mtetra
.413 .706 .983 r
.25602 .42589 .26565 .43285 .27962 .43253 .26998 .42613 Mtetra
.284 .658 .97 r
.26998 .42613 .27962 .43253 .29361 .4335 .28395 .42777 Mtetra
.1 .566 .911 r
.28395 .42777 .29361 .4335 .30762 .43597 .29796 .43099 Mtetra
0 .42 .781 r
.29796 .43099 .30762 .43597 .32168 .44011 .31199 .43595 Mtetra
.34 0 0 r
.31199 .43595 .32168 .44011 .33579 .44607 .32609 .44276 Mtetra
.501 0 0 r
.32609 .44276 .33579 .44607 .34998 .45389 .34027 .45142 Mtetra
.603 .031 0 r
.34027 .45142 .34998 .45389 .36428 .46352 .35456 .46181 Mtetra
.66 .108 0 r
.35456 .46181 .36428 .46352 .37872 .47479 .36901 .47369 Mtetra
.689 .15 0 r
.36901 .47369 .37872 .47479 .39334 .48735 .38366 .48663 Mtetra
.698 .165 0 r
.38366 .48663 .39334 .48735 .40819 .50072 .39854 .50006 Mtetra
.688 .15 0 r
.39854 .50006 .40819 .50072 .42329 .51424 .4137 .51329 Mtetra
.653 .1 0 r
.4137 .51329 .42329 .51424 .43867 .52715 .42915 .52548 Mtetra
.571 0 0 r
.42915 .52548 .43867 .52715 .45435 .53859 .4449 .53577 Mtetra
.388 0 0 r
.4449 .53577 .45435 .53859 .47032 .54768 .46095 .54329 Mtetra
0 .511 .832 r
.46095 .54329 .47032 .54768 .48655 .5536 .47727 .54729 Mtetra
.389 .731 .991 r
.47727 .54729 .48655 .5536 .50302 .55566 .49381 .54719 Mtetra
.626 .776 .953 r
.49381 .54719 .50302 .55566 .51966 .55341 .51052 .54265 Mtetra
.727 .758 .877 r
.51052 .54265 .51966 .55341 .53642 .54664 .52734 .53361 Mtetra
.771 .732 .817 r
.52734 .53361 .53642 .54664 .55322 .53543 .5442 .5203 Mtetra
.792 .711 .776 r
.5442 .5203 .55322 .53543 .57001 .52017 .56104 .50322 Mtetra
.802 .696 .748 r
.56104 .50322 .57001 .52017 .58674 .50144 .57782 .48306 Mtetra
.808 .686 .73 r
.57782 .48306 .58674 .50144 .60337 .48005 .59449 .46066 Mtetra
.81 .679 .72 r
.59449 .46066 .60337 .48005 .61989 .45684 .61106 .43689 Mtetra
.81 .675 .715 r
.61106 .43689 .61989 .45684 .63629 .43269 .62752 .4126 Mtetra
.808 .673 .715 r
.62752 .4126 .63629 .43269 .65259 .40842 .6439 .38856 Mtetra
.805 .674 .719 r
.6439 .38856 .65259 .40842 .66882 .38474 .66022 .36539 Mtetra
.801 .676 .726 r
.66022 .36539 .66882 .38474 .68502 .36218 .67652 .34356 Mtetra
.796 .68 .737 r
.67652 .34356 .68502 .36218 .70122 .34115 .69283 .32338 Mtetra
.789 .686 .751 r
.69283 .32338 .70122 .34115 .71747 .32188 .70919 .30502 Mtetra
.78 .692 .767 r
.70919 .30502 .71747 .32188 .73379 .30446 .72564 .28852 Mtetra
.77 .699 .784 r
.72564 .28852 .73379 .30446 .75022 .28889 .7422 .27381 Mtetra
.759 .706 .803 r
.7422 .27381 .75022 .28889 .76678 .27504 .75889 .26074 Mtetra
.746 .713 .821 r
.75889 .26074 .76678 .27504 .78349 .26276 .77572 .24912 Mtetra
.733 .72 .838 r
.77572 .24912 .78349 .26276 .80035 .25183 .7927 .23876 Mtetra
.721 .725 .854 r
.7927 .23876 .80035 .25183 .81736 .24204 .80984 .22943 Mtetra
.709 .729 .867 r
.80984 .22943 .81736 .24204 .83454 .23319 .82713 .22092 Mtetra
.575 .739 .954 r
.20452 .42331 .21428 .43136 .22817 .42871 .21842 .42094 Mtetra
.532 .733 .967 r
.21842 .42094 .22817 .42871 .24208 .42682 .23234 .41942 Mtetra
.467 .719 .979 r
.23234 .41942 .24208 .42682 .25602 .42589 .24627 .41895 Mtetra
.368 .688 .98 r
.24627 .41895 .25602 .42589 .26998 .42613 .26022 .41975 Mtetra
.223 .626 .955 r
.26022 .41975 .26998 .42613 .28395 .42777 .27418 .42201 Mtetra
.027 .518 .877 r
.27418 .42201 .28395 .42777 .29796 .43099 .28817 .42592 Mtetra
0 .365 .735 r
.28817 .42592 .29796 .43099 .31199 .43595 .30219 .43161 Mtetra
.386 0 0 r
.30219 .43161 .31199 .43595 .32609 .44276 .31627 .43914 Mtetra
.524 0 0 r
.31627 .43914 .32609 .44276 .34027 .45142 .33044 .44844 Mtetra
.609 .039 0 r
.33044 .44844 .34027 .45142 .35456 .46181 .34474 .45935 Mtetra
.656 .1 0 r
.34474 .45935 .35456 .46181 .36901 .47369 .35921 .47152 Mtetra
.676 .128 0 r
.35921 .47152 .36901 .47369 .38366 .48663 .37389 .48449 Mtetra
.674 .125 0 r
.37389 .48449 .38366 .48663 .39854 .50006 .38881 .49762 Mtetra
.644 .085 0 r
.38881 .49762 .39854 .50006 .4137 .51329 .40403 .51013 Mtetra
.568 0 0 r
.40403 .51013 .4137 .51329 .42915 .52548 .41955 .5212 Mtetra
.398 0 0 r
.41955 .5212 .42915 .52548 .4449 .53577 .43538 .52997 Mtetra
0 .447 .822 r
.43538 .52997 .4449 .53577 .46095 .54329 .45152 .53561 Mtetra
.315 .656 .972 r
.45152 .53561 .46095 .54329 .47727 .54729 .46792 .53748 Mtetra
.564 .722 .948 r
.46792 .53748 .47727 .54729 .49381 .54719 .48454 .5351 Mtetra
.682 .72 .878 r
.48454 .5351 .49381 .54719 .51052 .54265 .50132 .52829 Mtetra
.738 .704 .819 r
.50132 .52829 .51052 .54265 .52734 .53361 .51819 .51712 Mtetra
.766 .689 .777 r
.51819 .51712 .52734 .53361 .5442 .5203 .5351 .50195 Mtetra
.782 .677 .748 r
.5351 .50195 .5442 .5203 .56104 .50322 .55199 .48339 Mtetra
.791 .669 .729 r
.55199 .48339 .56104 .50322 .57782 .48306 .5688 .4622 Mtetra
.796 .664 .717 r
.5688 .4622 .57782 .48306 .59449 .46066 .58553 .43922 Mtetra
.798 .661 .711 r
.58553 .43922 .59449 .46066 .61106 .43689 .60215 .41531 Mtetra
.799 .66 .71 r
.60215 .41531 .61106 .43689 .62752 .4126 .61868 .39128 Mtetra
.798 .661 .712 r
.61868 .39128 .62752 .4126 .6439 .38856 .63513 .3678 Mtetra
.795 .664 .719 r
.63513 .3678 .6439 .38856 .66022 .36539 .65155 .34544 Mtetra
.792 .669 .728 r
.65155 .34544 .66022 .36539 .67652 .34356 .66795 .32457 Mtetra
.786 .675 .741 r
.66795 .32457 .67652 .34356 .69283 .32338 .68437 .30543 Mtetra
.78 .682 .756 r
.68437 .30543 .69283 .32338 .70919 .30502 .70086 .28811 Mtetra
.771 .689 .773 r
.70086 .28811 .70919 .30502 .72564 .28852 .71744 .2726 Mtetra
.761 .698 .791 r
.71744 .2726 .72564 .28852 .7422 .27381 .73413 .25879 Mtetra
.75 .706 .81 r
.73413 .25879 .7422 .27381 .75889 .26074 .75094 .24651 Mtetra
.738 .713 .828 r
.75094 .24651 .75889 .26074 .77572 .24912 .7679 .23557 Mtetra
.725 .72 .845 r
.7679 .23557 .77572 .24912 .7927 .23876 .785 .22575 Mtetra
.713 .725 .859 r
.785 .22575 .7927 .23876 .80984 .22943 .80225 .21684 Mtetra
.702 .73 .872 r
.80225 .21684 .80984 .22943 .82713 .22092 .81965 .20865 Mtetra
.56 .736 .958 r
.19464 .41523 .20452 .42331 .21842 .42094 .20855 .41315 Mtetra
.51 .727 .971 r
.20855 .41315 .21842 .42094 .23234 .41942 .22247 .412 Mtetra
.436 .707 .98 r
.22247 .412 .23234 .41942 .24627 .41895 .2364 .41198 Mtetra
.325 .668 .975 r
.2364 .41198 .24627 .41895 .26022 .41975 .25034 .41329 Mtetra
.169 .594 .938 r
.25034 .41329 .26022 .41975 .27418 .42201 .26429 .41612 Mtetra
0 .476 .848 r
.26429 .41612 .27418 .42201 .28817 .42592 .27826 .42064 Mtetra
0 .326 .705 r
.27826 .42064 .28817 .42592 .30219 .43161 .29227 .42692 Mtetra
.406 0 0 r
.29227 .42692 .30219 .43161 .31627 .43914 .30635 .43497 Mtetra
.525 0 0 r
.30635 .43497 .31627 .43914 .33044 .44844 .32052 .44469 Mtetra
.597 .027 0 r
.32052 .44469 .33044 .44844 .34474 .45935 .33483 .45583 Mtetra
.634 .071 0 r
.33483 .45583 .34474 .45935 .35921 .47152 .34932 .46799 Mtetra
.641 .081 0 r
.34932 .46799 .35921 .47152 .37389 .48449 .36404 .48062 Mtetra
.617 .052 0 r
.36404 .48062 .37389 .48449 .38881 .49762 .37903 .49304 Mtetra
.545 0 0 r
.37903 .49304 .38881 .49762 .40403 .51013 .39432 .50446 Mtetra
.386 0 0 r
.39432 .50446 .40403 .51013 .41955 .5212 .40992 .51405 Mtetra
0 .399 .814 r
.40992 .51405 .41955 .5212 .43538 .52997 .42583 .52098 Mtetra
.254 .589 .947 r
.42583 .52098 .43538 .52997 .45152 .53561 .44205 .52453 Mtetra
.503 .668 .937 r
.44205 .52453 .45152 .53561 .46792 .53748 .45853 .52415 Mtetra
.634 .682 .877 r
.45853 .52415 .46792 .53748 .48454 .5351 .47522 .5195 Mtetra
.702 .675 .821 r
.47522 .5195 .48454 .5351 .50132 .52829 .49206 .51053 Mtetra
.738 .666 .779 r
.49206 .51053 .50132 .52829 .51819 .51712 .50899 .49747 Mtetra
.76 .658 .75 r
.50899 .49747 .51819 .51712 .5351 .50195 .52595 .48079 Mtetra
.773 .652 .729 r
.52595 .48079 .5351 .50195 .55199 .48339 .54287 .46114 Mtetra
.781 .649 .716 r
.54287 .46114 .55199 .48339 .5688 .4622 .55973 .43933 Mtetra
.786 .647 .709 r
.55973 .43933 .5688 .4622 .58553 .43922 .5765 .41619 Mtetra
.788 .647 .706 r
.5765 .41619 .58553 .43922 .60215 .41531 .59318 .39255 Mtetra
.789 .649 .708 r
.59318 .39255 .60215 .41531 .61868 .39128 .60978 .36913 Mtetra
.788 .652 .712 r
.60978 .36913 .61868 .39128 .63513 .3678 .62632 .34654 Mtetra
.786 .657 .721 r
.62632 .34654 .63513 .3678 .65155 .34544 .64282 .32523 Mtetra
.782 .664 .732 r
.64282 .32523 .65155 .34544 .66795 .32457 .65933 .3055 Mtetra
.777 .671 .746 r
.65933 .3055 .66795 .32457 .68437 .30543 .67587 .28752 Mtetra
.771 .679 .763 r
.67587 .28752 .68437 .30543 .70086 .28811 .69248 .27131 Mtetra
.762 .688 .781 r
.69248 .27131 .70086 .28811 .71744 .2726 .70919 .25683 Mtetra
.752 .697 .8 r
.70919 .25683 .71744 .2726 .73413 .25879 .726 .24392 Mtetra
.741 .706 .818 r
.726 .24392 .73413 .25879 .75094 .24651 .74294 .23242 Mtetra
.729 .714 .836 r
.74294 .23242 .75094 .24651 .7679 .23557 .76002 .22212 Mtetra
.717 .721 .852 r
.76002 .22212 .7679 .23557 .785 .22575 .77724 .21281 Mtetra
.706 .726 .866 r
.77724 .21281 .785 .22575 .80225 .21684 .79461 .20429 Mtetra
.696 .73 .877 r
.79461 .20429 .80225 .21684 .81965 .20865 .81211 .19639 Mtetra
.545 .732 .962 r
.18466 .40711 .19464 .41523 .20855 .41315 .19858 .40532 Mtetra
.489 .719 .973 r
.19858 .40532 .20855 .41315 .22247 .412 .2125 .40452 Mtetra
.406 .694 .979 r
.2125 .40452 .22247 .412 .2364 .41198 .22642 .40491 Mtetra
.288 .647 .968 r
.22642 .40491 .2364 .41198 .25034 .41329 .24035 .40668 Mtetra
.127 .566 .922 r
.24035 .40668 .25034 .41329 .26429 .41612 .25429 .40999 Mtetra
0 .446 .829 r
.25429 .40999 .26429 .41612 .27826 .42064 .26825 .41498 Mtetra
0 .305 .696 r
.26825 .41498 .27826 .42064 .29227 .42692 .28226 .42169 Mtetra
.402 0 0 r
.28226 .42169 .29227 .42692 .30635 .43497 .29633 .43006 Mtetra
.504 0 0 r
.29633 .43006 .30635 .43497 .32052 .44469 .31052 .43994 Mtetra
.562 0 0 r
.31052 .43994 .32052 .44469 .33483 .45583 .32486 .451 Mtetra
.583 .017 0 r
.32486 .451 .33483 .45583 .34932 .46799 .33939 .4628 Mtetra
.567 .001 0 r
.33939 .4628 .34932 .46799 .36404 .48062 .35416 .47473 Mtetra
.5 0 0 r
.35416 .47473 .36404 .48062 .37903 .49304 .36922 .48608 Mtetra
0 .189 .627 r
.36922 .48608 .37903 .49304 .39432 .50446 .38458 .49606 Mtetra
0 .37 .812 r
.38458 .49606 .39432 .50446 .40992 .51405 .40027 .50387 Mtetra
.21 .533 .923 r
.40027 .50387 .40992 .51405 .42583 .52098 .41627 .50876 Mtetra
.447 .618 .923 r
.41627 .50876 .42583 .52098 .44205 .52453 .43258 .51009 Mtetra
.587 .644 .874 r
.43258 .51009 .44205 .52453 .45853 .52415 .44913 .50745 Mtetra
.665 .647 .823 r
.44913 .50745 .45853 .52415 .47522 .5195 .46589 .50065 Mtetra
.71 .644 .782 r
.46589 .50065 .47522 .5195 .49206 .51053 .48279 .48977 Mtetra
.736 .639 .752 r
.48279 .48977 .49206 .51053 .50899 .49747 .49976 .47513 Mtetra
.753 .636 .731 r
.49976 .47513 .50899 .49747 .52595 .48079 .51675 .4573 Mtetra
.765 .634 .717 r
.51675 .4573 .52595 .48079 .54287 .46114 .53371 .43699 Mtetra
.772 .634 .708 r
.53371 .43699 .54287 .46114 .55973 .43933 .55061 .41499 Mtetra
.777 .635 .704 r
.55061 .41499 .55973 .43933 .5765 .41619 .56743 .39211 Mtetra
.779 .637 .704 r
.56743 .39211 .5765 .41619 .59318 .39255 .58417 .36909 Mtetra
.78 .641 .708 r
.58417 .36909 .59318 .39255 .60978 .36913 .60083 .34659 Mtetra
.779 .646 .715 r
.60083 .34659 .60978 .36913 .62632 .34654 .61746 .32511 Mtetra
.777 .653 .725 r
.61746 .32511 .62632 .34654 .64282 .32523 .63406 .30503 Mtetra
.774 .661 .738 r
.63406 .30503 .64282 .32523 .65933 .3055 .65067 .28657 Mtetra
.769 .67 .754 r
.65067 .28657 .65933 .3055 .67587 .28752 .66733 .26981 Mtetra
.762 .679 .771 r
.66733 .26981 .67587 .28752 .69248 .27131 .68406 .25475 Mtetra
.753 .689 .79 r
.68406 .25475 .69248 .27131 .70919 .25683 .70089 .24129 Mtetra
.743 .699 .809 r
.70089 .24129 .70919 .25683 .726 .24392 .71783 .22927 Mtetra
.732 .708 .827 r
.71783 .22927 .726 .24392 .74294 .23242 .73489 .21851 Mtetra
.721 .715 .844 r
.73489 .21851 .74294 .23242 .76002 .22212 .75209 .2088 Mtetra
.71 .722 .859 r
.75209 .2088 .76002 .22212 .77724 .21281 .76942 .19995 Mtetra
.7 .727 .872 r
.76942 .19995 .77724 .21281 .79461 .20429 .78689 .19178 Mtetra
.691 .731 .882 r
.78689 .19178 .79461 .20429 .81211 .19639 .8045 .18412 Mtetra
.53 .727 .964 r
.17457 .39893 .18466 .40711 .19858 .40532 .18849 .39741 Mtetra
.469 .711 .975 r
.18849 .39741 .19858 .40532 .2125 .40452 .20241 .39692 Mtetra
.381 .682 .977 r
.20241 .39692 .2125 .40452 .22642 .40491 .21633 .39767 Mtetra
.259 .629 .961 r
.21633 .39767 .22642 .40491 .24035 .40668 .23026 .39981 Mtetra
.101 .545 .912 r
.23026 .39981 .24035 .40668 .25429 .40999 .24419 .4035 Mtetra
0 .431 .824 r
.24419 .4035 .25429 .40999 .26825 .41498 .25815 .40881 Mtetra
0 .305 .709 r
.25815 .40881 .26825 .41498 .28226 .42169 .27216 .41575 Mtetra
.371 0 0 r
.27216 .41575 .28226 .42169 .29633 .43006 .28625 .42421 Mtetra
.454 0 0 r
.28625 .42421 .29633 .43006 .31052 .43994 .30046 .43396 Mtetra
.494 0 0 r
.30046 .43396 .31052 .43994 .32486 .451 .31484 .44464 Mtetra
.489 0 0 r
.31484 .44464 .32486 .451 .33939 .4628 .32943 .45574 Mtetra
.431 0 0 r
.32943 .45574 .33939 .4628 .35416 .47473 .34427 .46663 Mtetra
0 .216 .676 r
.34427 .46663 .35416 .47473 .36922 .48608 .35941 .47659 Mtetra
0 .358 .816 r
.35941 .47659 .36922 .48608 .38458 .49606 .37486 .48486 Mtetra
.182 .493 .904 r
.37486 .48486 .38458 .49606 .40027 .50387 .39064 .49068 Mtetra
.401 .575 .909 r
.39064 .49068 .40027 .50387 .41627 .50876 .40673 .49341 Mtetra
.543 .61 .869 r
.40673 .49341 .41627 .50876 .43258 .51009 .42311 .49252 Mtetra
.629 .621 .823 r
.42311 .49252 .43258 .51009 .44913 .50745 .43974 .48773 Mtetra
.68 .622 .784 r
.43974 .48773 .44913 .50745 .46589 .50065 .45656 .47898 Mtetra
.712 .622 .755 r
.45656 .47898 .46589 .50065 .48279 .48977 .47351 .46648 Mtetra
.733 .621 .733 r
.47351 .46648 .48279 .48977 .49976 .47513 .49052 .45064 Mtetra
.748 .621 .718 r
.49052 .45064 .49976 .47513 .51675 .4573 .50754 .43209 Mtetra
.758 .621 .709 r
.50754 .43209 .51675 .4573 .53371 .43699 .52453 .41153 Mtetra
.764 .623 .704 r
.52453 .41153 .53371 .43699 .55061 .41499 .54147 .38974 Mtetra
.769 .626 .703 r
.54147 .38974 .55061 .41499 .56743 .39211 .55833 .36746 Mtetra
.771 .631 .705 r
.55833 .36746 .56743 .39211 .58417 .36909 .57512 .34537 Mtetra
.772 .636 .711 r
.57512 .34537 .58417 .36909 .60083 .34659 .59186 .32403 Mtetra
.771 .643 .72 r
.59186 .32403 .60083 .34659 .61746 .32511 .60856 .30384 Mtetra
.769 .651 .732 r
.60856 .30384 .61746 .32511 .63406 .30503 .62526 .28511 Mtetra
.765 .66 .747 r
.62526 .28511 .63406 .30503 .65067 .28657 .64198 .26797 Mtetra
.76 .67 .763 r
.64198 .26797 .65067 .28657 .66733 .26981 .65875 .25246 Mtetra
.753 .681 .781 r
.65875 .25246 .66733 .26981 .68406 .25475 .6756 .23853 Mtetra
.744 .691 .8 r
.6756 .23853 .68406 .25475 .70089 .24129 .69255 .22606 Mtetra
.734 .701 .819 r
.69255 .22606 .70089 .24129 .71783 .22927 .7096 .21487 Mtetra
.724 .71 .837 r
.7096 .21487 .71783 .22927 .73489 .21851 .72678 .20479 Mtetra
.713 .718 .853 r
.72678 .20479 .73489 .21851 .75209 .2088 .74409 .19562 Mtetra
.703 .724 .866 r
.74409 .19562 .75209 .2088 .76942 .19995 .76154 .18718 Mtetra
.694 .729 .877 r
.76154 .18718 .76942 .19995 .78689 .19178 .77911 .1793 Mtetra
.686 .732 .886 r
.77911 .1793 .78689 .19178 .8045 .18412 .79682 .17185 Mtetra
.516 .722 .966 r
.16437 .39064 .17457 .39893 .18849 .39741 .17829 .38936 Mtetra
.452 .703 .975 r
.17829 .38936 .18849 .39741 .20241 .39692 .19222 .38914 Mtetra
.362 .67 .974 r
.19222 .38914 .20241 .39692 .21633 .39767 .20614 .39017 Mtetra
.241 .615 .956 r
.20614 .39017 .21633 .39767 .23026 .39981 .22007 .39259 Mtetra
.094 .533 .909 r
.22007 .39259 .23026 .39981 .24419 .4035 .234 .39651 Mtetra
0 .43 .832 r
.234 .39651 .24419 .4035 .25815 .40881 .24797 .40198 Mtetra
0 .324 .741 r
.24797 .40198 .25815 .40881 .27216 .41575 .262 .40893 Mtetra
0 .234 .66 r
.262 .40893 .27216 .41575 .28625 .42421 .27612 .41723 Mtetra
0 .177 .611 r
.27612 .41723 .28625 .42421 .30046 .43396 .29037 .42658 Mtetra
0 .159 .603 r
.29037 .42658 .30046 .43396 .31484 .44464 .3048 .43658 Mtetra
0 .184 .645 r
.3048 .43658 .31484 .44464 .32943 .45574 .31946 .44667 Mtetra
0 .256 .728 r
.31946 .44667 .32943 .45574 .34427 .46663 .33439 .45623 Mtetra
0 .362 .826 r
.33439 .45623 .34427 .46663 .35941 .47659 .34961 .46455 Mtetra
.171 .468 .89 r
.34961 .46455 .35941 .47659 .37486 .48486 .36516 .47091 Mtetra
.366 .542 .896 r
.36516 .47091 .37486 .48486 .39064 .49068 .38103 .47464 Mtetra
.504 .58 .865 r
.38103 .47464 .39064 .49068 .40673 .49341 .39722 .47519 Mtetra
.594 .596 .824 r
.39722 .47519 .40673 .49341 .42311 .49252 .41368 .47217 Mtetra
.651 .603 .787 r
.41368 .47217 .42311 .49252 .43974 .48773 .43037 .46542 Mtetra
.688 .605 .758 r
.43037 .46542 .43974 .48773 .45656 .47898 .44724 .45502 Mtetra
.713 .607 .736 r
.44724 .45502 .45656 .47898 .47351 .46648 .46423 .44125 Mtetra
.73 .608 .721 r
.46423 .44125 .47351 .46648 .49052 .45064 .48127 .42461 Mtetra
.743 .61 .71 r
.48127 .42461 .49052 .45064 .50754 .43209 .49832 .40573 Mtetra
.751 .613 .705 r
.49832 .40573 .50754 .43209 .52453 .41153 .51534 .38532 Mtetra
.757 .616 .703 r
.51534 .38532 .52453 .41153 .54147 .38974 .5323 .36409 Mtetra
.762 .621 .704 r
.5323 .36409 .54147 .38974 .55833 .36746 .54921 .34272 Mtetra
.764 .627 .709 r
.54921 .34272 .55833 .36746 .57512 .34537 .56605 .32179 Mtetra
.764 .634 .717 r
.56605 .32179 .57512 .34537 .59186 .32403 .58286 .30177 Mtetra
.764 .642 .727 r
.58286 .30177 .59186 .32403 .60856 .30384 .59964 .28299 Mtetra
.761 .652 .741 r
.59964 .28299 .60856 .30384 .62526 .28511 .61643 .26565 Mtetra
.757 .662 .757 r
.61643 .26565 .62526 .28511 .64198 .26797 .63326 .24984 Mtetra
.751 .673 .774 r
.63326 .24984 .64198 .26797 .65875 .25246 .65014 .23556 Mtetra
.744 .684 .793 r
.65014 .23556 .65875 .25246 .6756 .23853 .6671 .22271 Mtetra
.735 .694 .812 r
.6671 .22271 .6756 .23853 .69255 .22606 .68416 .21116 Mtetra
.726 .704 .83 r
.68416 .21116 .69255 .22606 .7096 .21487 .70133 .20074 Mtetra
.715 .713 .846 r
.70133 .20074 .7096 .21487 .72678 .20479 .71862 .19127 Mtetra
.705 .72 .861 r
.71862 .19127 .72678 .20479 .74409 .19562 .73604 .18257 Mtetra
.696 .726 .873 r
.73604 .18257 .74409 .19562 .76154 .18718 .75358 .17448 Mtetra
.688 .73 .883 r
.75358 .17448 .76154 .18718 .77911 .1793 .77126 .16685 Mtetra
.681 .734 .89 r
.77126 .16685 .77911 .1793 .79682 .17185 .78906 .15956 Mtetra
.505 .716 .967 r
.15406 .38221 .16437 .39064 .17829 .38936 .16799 .38112 Mtetra
.439 .695 .974 r
.16799 .38112 .17829 .38936 .19222 .38914 .18193 .38112 Mtetra
.351 .66 .971 r
.18193 .38112 .19222 .38914 .20614 .39017 .19586 .38234 Mtetra
.237 .606 .953 r
.19586 .38234 .20614 .39017 .22007 .39259 .20979 .38492 Mtetra
.106 .531 .912 r
.20979 .38492 .22007 .39259 .234 .39651 .22374 .38893 Mtetra
0 .443 .852 r
.22374 .38893 .234 .39651 .24797 .40198 .23773 .39436 Mtetra
0 .358 .786 r
.23773 .39436 .24797 .40198 .262 .40893 .25179 .40112 Mtetra
0 .293 .735 r
.25179 .40112 .262 .40893 .27612 .41723 .26595 .40901 Mtetra
0 .259 .714 r
.26595 .40901 .27612 .41723 .29037 .42658 .28026 .41769 Mtetra
0 .263 .731 r
.28026 .41769 .29037 .42658 .3048 .43658 .29477 .42672 Mtetra
0 .306 .78 r
.29477 .42672 .3048 .43658 .31946 .44667 .30951 .43556 Mtetra
0 .379 .841 r
.30951 .43556 .31946 .44667 .33439 .45623 .32453 .44356 Mtetra
.176 .458 .883 r
.32453 .44356 .33439 .45623 .34961 .46455 .33986 .45006 Mtetra
.343 .519 .886 r
.33986 .45006 .34961 .46455 .36516 .47091 .35551 .4544 Mtetra
.472 .557 .861 r
.35551 .4544 .36516 .47091 .38103 .47464 .37148 .45602 Mtetra
.562 .576 .825 r
.37148 .45602 .38103 .47464 .39722 .47519 .38775 .45447 Mtetra
.623 .586 .791 r
.38775 .45447 .39722 .47519 .41368 .47217 .40428 .44951 Mtetra
.664 .591 .763 r
.40428 .44951 .41368 .47217 .43037 .46542 .42103 .44107 Mtetra
.693 .594 .741 r
.42103 .44107 .43037 .46542 .44724 .45502 .43794 .42935 Mtetra
.713 .597 .725 r
.43794 .42935 .44724 .45502 .46423 .44125 .45495 .41469 Mtetra
.727 .6 .714 r
.45495 .41469 .46423 .44125 .48127 .42461 .47202 .39764 Mtetra
.738 .603 .707 r
.47202 .39764 .48127 .42461 .49832 .40573 .48908 .37882 Mtetra
.746 .607 .704 r
.48908 .37882 .49832 .40573 .51534 .38532 .50613 .35889 Mtetra
.751 .612 .704 r
.50613 .35889 .51534 .38532 .5323 .36409 .52312 .33851 Mtetra
.755 .619 .708 r
.52312 .33851 .5323 .36409 .54921 .34272 .54006 .31828 Mtetra
.757 .626 .715 r
.54006 .31828 .54921 .34272 .56605 .32179 .55696 .29867 Mtetra
.757 .634 .724 r
.55696 .29867 .56605 .32179 .58286 .30177 .57383 .28008 Mtetra
.756 .644 .737 r
.57383 .28008 .58286 .30177 .59964 .28299 .59069 .26274 Mtetra
.753 .654 .751 r
.59069 .26274 .59964 .28299 .61643 .26565 .60757 .2468 Mtetra
.749 .665 .768 r
.60757 .2468 .61643 .26565 .63326 .24984 .62449 .23229 Mtetra
.743 .677 .786 r
.62449 .23229 .63326 .24984 .65014 .23556 .64148 .21916 Mtetra
.735 .688 .805 r
.64148 .21916 .65014 .23556 .6671 .22271 .65855 .20731 Mtetra
.727 .698 .823 r
.65855 .20731 .6671 .22271 .68416 .21116 .67571 .1966 Mtetra
.717 .708 .841 r
.67571 .1966 .68416 .21116 .70133 .20074 .69299 .18686 Mtetra
.707 .716 .856 r
.69299 .18686 .70133 .20074 .71862 .19127 .71039 .17793 Mtetra
.698 .723 .869 r
.71039 .17793 .71862 .19127 .73604 .18257 .72791 .16963 Mtetra
.69 .728 .879 r
.72791 .16963 .73604 .18257 .75358 .17448 .74556 .16183 Mtetra
.683 .732 .887 r
.74556 .16183 .75358 .17448 .77126 .16685 .76333 .1544 Mtetra
.678 .735 .894 r
.76333 .1544 .77126 .16685 .78906 .15956 .78123 .14724 Mtetra
.497 .711 .966 r
.14365 .37361 .15406 .38221 .16799 .38112 .1576 .37266 Mtetra
.432 .688 .972 r
.1576 .37266 .16799 .38112 .18193 .38112 .17154 .37278 Mtetra
.349 .653 .969 r
.17154 .37278 .18193 .38112 .19586 .38234 .18549 .3741 Mtetra
.247 .602 .952 r
.18549 .3741 .19586 .38234 .20979 .38492 .19944 .37671 Mtetra
.135 .538 .92 r
.19944 .37671 .20979 .38492 .22374 .38893 .21342 .38065 Mtetra
.028 .467 .877 r
.21342 .38065 .22374 .38893 .23773 .39436 .22744 .38586 Mtetra
0 .403 .835 r
.22744 .38586 .23773 .39436 .25179 .40112 .24154 .39221 Mtetra
0 .36 .808 r
.24154 .39221 .25179 .40112 .26595 .40901 .25577 .39945 Mtetra
0 .346 .806 r
.25577 .39945 .26595 .40901 .28026 .41769 .27015 .40723 Mtetra
0 .364 .827 r
.27015 .40723 .28026 .41769 .29477 .42672 .28474 .41508 Mtetra
.059 .407 .859 r
.28474 .41508 .29477 .42672 .30951 .43556 .29959 .42244 Mtetra
.194 .46 .882 r
.29959 .42244 .30951 .43556 .32453 .44356 .31471 .42872 Mtetra
.332 .508 .881 r
.31471 .42872 .32453 .44356 .33986 .45006 .33015 .43331 Mtetra
.448 .541 .859 r
.33015 .43331 .33986 .45006 .35551 .4544 .3459 .43563 Mtetra
.535 .56 .827 r
.3459 .43563 .35551 .4544 .37148 .45602 .36196 .43521 Mtetra
.597 .572 .796 r
.36196 .43521 .37148 .45602 .38775 .45447 .37831 .43174 Mtetra
.641 .578 .768 r
.37831 .43174 .38775 .45447 .40428 .44951 .39491 .42508 Mtetra
.673 .583 .746 r
.39491 .42508 .40428 .44951 .42103 .44107 .41171 .41528 Mtetra
.695 .587 .73 r
.41171 .41528 .42103 .44107 .43794 .42935 .42865 .40258 Mtetra
.712 .59 .718 r
.42865 .40258 .43794 .42935 .45495 .41469 .44569 .38742 Mtetra
.725 .595 .71 r
.44569 .38742 .45495 .41469 .47202 .39764 .46276 .37032 Mtetra
.734 .599 .706 r
.46276 .37032 .47202 .39764 .48908 .37882 .47984 .35188 Mtetra
.741 .605 .706 r
.47984 .35188 .48908 .37882 .50613 .35889 .4969 .33272 Mtetra
.746 .611 .709 r
.4969 .33272 .50613 .35889 .52312 .33851 .51392 .31341 Mtetra
.749 .619 .714 r
.51392 .31341 .52312 .33851 .54006 .31828 .5309 .29446 Mtetra
.751 .627 .723 r
.5309 .29446 .54006 .31828 .55696 .29867 .54784 .27627 Mtetra
.751 .637 .734 r
.54784 .27627 .55696 .29867 .57383 .28008 .56478 .25914 Mtetra
.749 .647 .748 r
.56478 .25914 .57383 .28008 .59069 .26274 .58171 .24323 Mtetra
.746 .658 .764 r
.58171 .24323 .59069 .26274 .60757 .2468 .59868 .22863 Mtetra
.741 .67 .781 r
.59868 .22863 .60757 .2468 .62449 .23229 .61569 .21534 Mtetra
.734 .682 .8 r
.61569 .21534 .62449 .23229 .64148 .21916 .63277 .20329 Mtetra
.727 .693 .818 r
.63277 .20329 .64148 .21916 .65855 .20731 .64994 .19235 Mtetra
.718 .703 .835 r
.64994 .19235 .65855 .20731 .67571 .1966 .66722 .18238 Mtetra
.709 .712 .851 r
.66722 .18238 .67571 .1966 .69299 .18686 .6846 .17323 Mtetra
.7 .719 .864 r
.6846 .17323 .69299 .18686 .71039 .17793 .70209 .16475 Mtetra
.692 .725 .876 r
.70209 .16475 .71039 .17793 .72791 .16963 .71971 .15678 Mtetra
.685 .73 .885 r
.71971 .15678 .72791 .16963 .74556 .16183 .73746 .14922 Mtetra
.679 .733 .891 r
.73746 .14922 .74556 .16183 .76333 .1544 .75532 .14194 Mtetra
.674 .736 .897 r
.75532 .14194 .76333 .1544 .78123 .14724 .77331 .13487 Mtetra
.493 .706 .965 r
.13314 .3648 .14365 .37361 .1576 .37266 .1471 .36392 Mtetra
.432 .683 .969 r
.1471 .36392 .1576 .37266 .17154 .37278 .16107 .36409 Mtetra
.356 .65 .966 r
.16107 .36409 .17154 .37278 .18549 .3741 .17504 .36539 Mtetra
.268 .604 .953 r
.17504 .36539 .18549 .3741 .19944 .37671 .18902 .3679 Mtetra
.178 .551 .93 r
.18902 .3679 .19944 .37671 .21342 .38065 .20304 .3716 Mtetra
.099 .496 .902 r
.20304 .3716 .21342 .38065 .22744 .38586 .21711 .37641 Mtetra
.045 .451 .877 r
.21711 .37641 .22744 .38586 .24154 .39221 .23128 .38215 Mtetra
.028 .425 .865 r
.23128 .38215 .24154 .39221 .25577 .39945 .24558 .38855 Mtetra
.055 .423 .867 r
.24558 .38855 .25577 .39945 .27015 .40723 .26005 .39522 Mtetra
.124 .442 .878 r
.26005 .39522 .27015 .40723 .28474 .41508 .27475 .4017 Mtetra
.223 .474 .885 r
.27475 .4017 .28474 .41508 .29959 .42244 .2897 .40746 Mtetra
.332 .506 .879 r
.2897 .40746 .29959 .42244 .31471 .42872 .30494 .41195 Mtetra
.432 .532 .859 r
.30494 .41195 .31471 .42872 .33015 .43331 .32048 .41461 Mtetra
.513 .55 .831 r
.32048 .41461 .33015 .43331 .3459 .43563 .33634 .41498 Mtetra
.575 .561 .801 r
.33634 .41498 .3459 .43563 .36196 .43521 .35249 .41269 Mtetra
.62 .569 .775 r
.35249 .41269 .36196 .43521 .37831 .43174 .36891 .40752 Mtetra
.654 .574 .753 r
.36891 .40752 .37831 .43174 .39491 .42508 .38557 .39945 Mtetra
.678 .579 .736 r
.38557 .39945 .39491 .42508 .41171 .41528 .4024 .38862 Mtetra
.697 .583 .724 r
.4024 .38862 .41171 .41528 .42865 .40258 .41937 .37532 Mtetra
.711 .588 .715 r
.41937 .37532 .42865 .40258 .44569 .38742 .43641 .35999 Mtetra
.722 .593 .71 r
.43641 .35999 .44569 .38742 .46276 .37032 .45349 .34316 Mtetra
.73 .598 .709 r
.45349 .34316 .46276 .37032 .47984 .35188 .47058 .32538 Mtetra
.737 .605 .711 r
.47058 .32538 .47984 .35188 .4969 .33272 .48765 .30719 Mtetra
.741 .612 .715 r
.48765 .30719 .4969 .33272 .51392 .31341 .50469 .2891 Mtetra
.743 .621 .723 r
.50469 .2891 .51392 .31341 .5309 .29446 .5217 .27152 Mtetra
.745 .63 .733 r
.5217 .27152 .5309 .29446 .54784 .27627 .53869 .25477 Mtetra
.744 .641 .746 r
.53869 .25477 .54784 .27627 .56478 .25914 .55568 .23907 Mtetra
.742 .652 .761 r
.55568 .23907 .56478 .25914 .58171 .24323 .57269 .22453 Mtetra
.738 .664 .777 r
.57269 .22453 .58171 .24323 .59868 .22863 .58974 .2112 Mtetra
.733 .676 .795 r
.58974 .2112 .59868 .22863 .61569 .21534 .60684 .19902 Mtetra
.726 .688 .813 r
.60684 .19902 .61569 .21534 .63277 .20329 .62402 .18793 Mtetra
.718 .699 .831 r
.62402 .18793 .63277 .20329 .64994 .19235 .64128 .17778 Mtetra
.71 .708 .846 r
.64128 .17778 .64994 .19235 .66722 .18238 .65865 .16846 Mtetra
.701 .716 .861 r
.65865 .16846 .66722 .18238 .6846 .17323 .67613 .15981 Mtetra
.693 .723 .872 r
.67613 .15981 .6846 .17323 .70209 .16475 .69373 .1517 Mtetra
.686 .728 .882 r
.69373 .1517 .70209 .16475 .71971 .15678 .71144 .144 Mtetra
.68 .732 .889 r
.71144 .144 .71971 .15678 .73746 .14922 .72928 .13662 Mtetra
.675 .735 .895 r
.72928 .13662 .73746 .14922 .75532 .14194 .74724 .12945 Mtetra
.672 .737 .899 r
.74724 .12945 .75532 .14194 .77331 .13487 .76531 .12243 Mtetra
.493 .702 .963 r
.12253 .35573 .13314 .3648 .1471 .36392 .13652 .35486 Mtetra
.437 .68 .966 r
.13652 .35486 .1471 .36392 .16107 .36409 .15052 .35498 Mtetra
.371 .649 .964 r
.15052 .35498 .16107 .36409 .17504 .36539 .16452 .35616 Mtetra
.299 .61 .954 r
.16452 .35616 .17504 .36539 .18902 .3679 .17855 .35843 Mtetra
.231 .567 .938 r
.17855 .35843 .18902 .3679 .20304 .3716 .19261 .36174 Mtetra
.177 .526 .92 r
.19261 .36174 .20304 .3716 .21711 .37641 .20675 .36598 Mtetra
.148 .495 .906 r
.20675 .36598 .21711 .37641 .23128 .38215 .221 .37094 Mtetra
.153 .48 .898 r
.221 .37094 .23128 .38215 .24558 .38855 .23539 .37632 Mtetra
.193 .481 .896 r
.23539 .37632 .24558 .38855 .26005 .39522 .24997 .38174 Mtetra
.261 .495 .892 r
.24997 .38174 .26005 .39522 .27475 .4017 .26478 .38675 Mtetra
.343 .514 .881 r
.26478 .38675 .27475 .4017 .2897 .40746 .27985 .39084 Mtetra
.426 .531 .862 r
.27985 .39084 .2897 .40746 .30494 .41195 .29521 .39352 Mtetra
.498 .545 .836 r
.29521 .39352 .30494 .41195 .32048 .41461 .31086 .39433 Mtetra
.556 .555 .808 r
.31086 .39433 .32048 .41461 .33634 .41498 .32681 .39289 Mtetra
.601 .562 .783 r
.32681 .39289 .33634 .41498 .35249 .41269 .34305 .38894 Mtetra
.636 .568 .761 r
.34305 .38894 .35249 .41269 .36891 .40752 .35954 .38236 Mtetra
.662 .573 .744 r
.35954 .38236 .36891 .40752 .38557 .39945 .37623 .3732 Mtetra
.683 .577 .731 r
.37623 .3732 .38557 .39945 .4024 .38862 .39309 .36166 Mtetra
.698 .582 .722 r
.39309 .36166 .4024 .38862 .41937 .37532 .41007 .34808 Mtetra
.71 .587 .716 r
.41007 .34808 .41937 .37532 .43641 .35999 .42712 .3329 Mtetra
.72 .593 .714 r
.42712 .3329 .43641 .35999 .45349 .34316 .4442 .31659 Mtetra
.727 .6 .714 r
.4442 .31659 .45349 .34316 .47058 .32538 .46129 .29967 Mtetra
.732 .607 .718 r
.46129 .29967 .47058 .32538 .48765 .30719 .47836 .2826 Mtetra
.736 .616 .724 r
.47836 .2826 .48765 .30719 .50469 .2891 .49542 .2658 Mtetra
.738 .625 .734 r
.49542 .2658 .50469 .2891 .5217 .27152 .51246 .24961 Mtetra
.739 .636 .745 r
.51246 .24961 .5217 .27152 .53869 .25477 .5295 .23427 Mtetra
.737 .647 .759 r
.5295 .23427 .53869 .25477 .55568 .23907 .54655 .21993 Mtetra
.735 .659 .775 r
.54655 .21993 .55568 .23907 .57269 .22453 .56362 .20667 Mtetra
.73 .671 .792 r
.56362 .20667 .57269 .22453 .58974 .2112 .58075 .19448 Mtetra
.725 .683 .81 r
.58075 .19448 .58974 .2112 .60684 .19902 .59793 .1833 Mtetra
.718 .694 .827 r
.59793 .1833 .60684 .19902 .62402 .18793 .6152 .17304 Mtetra
.71 .704 .843 r
.6152 .17304 .62402 .18793 .64128 .17778 .63256 .16359 Mtetra
.702 .713 .857 r
.63256 .16359 .64128 .17778 .65865 .16846 .65002 .1548 Mtetra
.694 .72 .869 r
.65002 .1548 .65865 .16846 .67613 .15981 .66759 .14656 Mtetra
.687 .726 .879 r
.66759 .14656 .67613 .15981 .69373 .1517 .68528 .13875 Mtetra
.681 .73 .887 r
.68528 .13875 .69373 .1517 .71144 .144 .70309 .13126 Mtetra
.676 .734 .893 r
.70309 .13126 .71144 .144 .72928 .13662 .72101 .124 Mtetra
.673 .736 .898 r
.72101 .124 .72928 .13662 .74724 .12945 .73906 .1169 Mtetra
.67 .738 .901 r
.73906 .1169 .74724 .12945 .76531 .12243 .75723 .10991 Mtetra
.496 .699 .96 r
.11183 .34638 .12253 .35573 .13652 .35486 .12585 .34545 Mtetra
.447 .678 .963 r
.12585 .34545 .13652 .35486 .15052 .35498 .13989 .34543 Mtetra
.392 .65 .961 r
.13989 .34543 .15052 .35498 .16452 .35616 .15394 .34637 Mtetra
.337 .618 .954 r
.15394 .34637 .16452 .35616 .17855 .35843 .16802 .34828 Mtetra
.287 .584 .943 r
.16802 .34828 .17855 .35843 .19261 .36174 .18216 .35107 Mtetra
.254 .553 .93 r
.18216 .35107 .19261 .36174 .20675 .36598 .19638 .3546 Mtetra
.245 .532 .919 r
.19638 .3546 .20675 .36598 .221 .37094 .21072 .35864 Mtetra
.262 .521 .91 r
.21072 .35864 .221 .37094 .23539 .37632 .22522 .36288 Mtetra
.304 .521 .9 r
.22522 .36288 .23539 .37632 .24997 .38174 .23991 .36695 Mtetra
.363 .528 .886 r
.23991 .36695 .24997 .38174 .26478 .38675 .25484 .37042 Mtetra
.427 .538 .866 r
.25484 .37042 .26478 .38675 .27985 .39084 .27003 .37285 Mtetra
.489 .547 .842 r
.27003 .37285 .27985 .39084 .29521 .39352 .2855 .37379 Mtetra
.542 .554 .817 r
.2855 .37379 .29521 .39352 .31086 .39433 .30126 .37288 Mtetra
.585 .56 .792 r
.30126 .37288 .31086 .39433 .32681 .39289 .31731 .36983 Mtetra
.62 .565 .771 r
.31731 .36983 .32681 .39289 .34305 .38894 .33362 .36447 Mtetra
.647 .569 .753 r
.33362 .36447 .34305 .38894 .35954 .38236 .35016 .35676 Mtetra
.669 .574 .739 r
.35016 .35676 .35954 .38236 .37623 .3732 .36689 .34683 Mtetra
.686 .579 .729 r
.36689 .34683 .37623 .3732 .39309 .36166 .38376 .3349 Mtetra
.699 .584 .723 r
.38376 .3349 .39309 .36166 .41007 .34808 .40075 .32133 Mtetra
.709 .59 .72 r
.40075 .32133 .41007 .34808 .42712 .3329 .41779 .30653 Mtetra
.718 .596 .719 r
.41779 .30653 .42712 .3329 .4442 .31659 .43487 .29095 Mtetra
.724 .604 .722 r
.43487 .29095 .4442 .31659 .46129 .29967 .45195 .27502 Mtetra
.728 .612 .728 r
.45195 .27502 .46129 .29967 .47836 .2826 .46903 .25914 Mtetra
.731 .621 .736 r
.46903 .25914 .47836 .2826 .49542 .2658 .48611 .24365 Mtetra
.733 .632 .746 r
.48611 .24365 .49542 .2658 .51246 .24961 .50318 .22881 Mtetra
.732 .643 .759 r
.50318 .22881 .51246 .24961 .5295 .23427 .52026 .21481 Mtetra
.731 .655 .774 r
.52026 .21481 .5295 .23427 .54655 .21993 .53736 .20173 Mtetra
.727 .667 .79 r
.53736 .20173 .54655 .21993 .56362 .20667 .5545 .18962 Mtetra
.723 .679 .807 r
.5545 .18962 .56362 .20667 .58075 .19448 .5717 .17844 Mtetra
.717 .69 .824 r
.5717 .17844 .58075 .19448 .59793 .1833 .58896 .16813 Mtetra
.71 .701 .84 r
.58896 .16813 .59793 .1833 .6152 .17304 .60632 .15859 Mtetra
.702 .71 .854 r
.60632 .15859 .6152 .17304 .63256 .16359 .62376 .1497 Mtetra
.695 .718 .867 r
.62376 .1497 .63256 .16359 .65002 .1548 .64132 .14135 Mtetra
.688 .724 .877 r
.64132 .14135 .65002 .1548 .66759 .14656 .65898 .13344 Mtetra
.682 .729 .886 r
.65898 .13344 .66759 .14656 .68528 .13875 .67675 .12585 Mtetra
.677 .733 .892 r
.67675 .12585 .68528 .13875 .70309 .13126 .69465 .11851 Mtetra
.673 .735 .897 r
.69465 .11851 .70309 .13126 .72101 .124 .71266 .11134 Mtetra
.67 .737 .9 r
.71266 .11134 .72101 .124 .73906 .1169 .7308 .10429 Mtetra
.668 .739 .903 r
.7308 .10429 .73906 .1169 .75723 .10991 .74905 .0973 Mtetra
.504 .697 .956 r
.10104 .33673 .11183 .34638 .12585 .34545 .1151 .33565 Mtetra
.462 .678 .958 r
.1151 .33565 .12585 .34545 .13989 .34543 .12919 .33541 Mtetra
.418 .654 .956 r
.12919 .33541 .13989 .34543 .15394 .34637 .1433 .33602 Mtetra
.376 .626 .951 r
.1433 .33602 .15394 .34637 .16802 .34828 .15745 .33745 Mtetra
.344 .599 .942 r
.15745 .33745 .16802 .34828 .18216 .35107 .17166 .3396 Mtetra
.326 .576 .932 r
.17166 .3396 .18216 .35107 .19638 .3546 .18598 .3423 Mtetra
.328 .559 .92 r
.18598 .3423 .19638 .3546 .21072 .35864 .20043 .34532 Mtetra
.351 .551 .908 r
.20043 .34532 .21072 .35864 .22522 .36288 .21504 .34835 Mtetra
.389 .548 .892 r
.21504 .34835 .22522 .36288 .23991 .36695 .22986 .35103 Mtetra
.437 .55 .873 r
.22986 .35103 .23991 .36695 .25484 .37042 .24491 .35298 Mtetra
.487 .554 .85 r
.24491 .35298 .25484 .37042 .27003 .37285 .26022 .3538 Mtetra
.533 .558 .826 r
.26022 .3538 .27003 .37285 .2855 .37379 .27581 .35314 Mtetra
.573 .561 .803 r
.27581 .35314 .2855 .37379 .30126 .37288 .29167 .35069 Mtetra
.607 .565 .782 r
.29167 .35069 .30126 .37288 .31731 .36983 .3078 .34626 Mtetra
.634 .569 .764 r
.3078 .34626 .31731 .36983 .33362 .36447 .32417 .33976 Mtetra
.656 .573 .75 r
.32417 .33976 .33362 .36447 .35016 .35676 .34075 .33122 Mtetra
.674 .577 .739 r
.34075 .33122 .35016 .35676 .36689 .34683 .35751 .3208 Mtetra
.688 .582 .731 r
.35751 .3208 .36689 .34683 .38376 .3349 .37439 .30876 Mtetra
.699 .588 .727 r
.37439 .30876 .38376 .3349 .40075 .32133 .39137 .29543 Mtetra
.708 .594 .726 r
.39137 .29543 .40075 .32133 .41779 .30653 .40841 .2812 Mtetra
.715 .601 .728 r
.40841 .2812 .41779 .30653 .43487 .29095 .42547 .26647 Mtetra
.721 .61 .732 r
.42547 .26647 .43487 .29095 .45195 .27502 .44256 .2516 Mtetra
.724 .619 .739 r
.44256 .2516 .45195 .27502 .46903 .25914 .45964 .23692 Mtetra
.727 .629 .749 r
.45964 .23692 .46903 .25914 .48611 .24365 .47673 .2227 Mtetra
.727 .64 .761 r
.47673 .2227 .48611 .24365 .50318 .22881 .49383 .20915 Mtetra
.726 .652 .775 r
.49383 .20915 .50318 .22881 .52026 .21481 .51095 .19637 Mtetra
.724 .664 .79 r
.51095 .19637 .52026 .21481 .53736 .20173 .52811 .18443 Mtetra
.72 .676 .806 r
.52811 .18443 .53736 .20173 .5545 .18962 .54531 .17333 Mtetra
.715 .687 .822 r
.54531 .17333 .5545 .18962 .5717 .17844 .56258 .16303 Mtetra
.709 .698 .838 r
.56258 .16303 .5717 .17844 .58896 .16813 .57992 .15345 Mtetra
.702 .707 .852 r
.57992 .15345 .58896 .16813 .60632 .15859 .59736 .1445 Mtetra
.695 .716 .865 r
.59736 .1445 .60632 .15859 .62376 .1497 .61489 .13607 Mtetra
.689 .722 .875 r
.61489 .13607 .62376 .1497 .64132 .14135 .63253 .12807 Mtetra
.683 .727 .884 r
.63253 .12807 .64132 .14135 .65898 .13344 .65028 .12041 Mtetra
.678 .731 .891 r
.65028 .12041 .65898 .13344 .67675 .12585 .66814 .11299 Mtetra
.674 .734 .896 r
.66814 .11299 .67675 .12585 .69465 .11851 .68612 .10575 Mtetra
.671 .737 .9 r
.68612 .10575 .69465 .11851 .71266 .11134 .70422 .09863 Mtetra
.668 .738 .902 r
.70422 .09863 .71266 .11134 .7308 .10429 .72244 .09158 Mtetra
.667 .739 .904 r
.72244 .09158 .7308 .10429 .74905 .0973 .74078 .08457 Mtetra
.514 .696 .951 r
.09016 .32675 .10104 .33673 .1151 .33565 .10428 .32546 Mtetra
.48 .678 .953 r
.10428 .32546 .1151 .33565 .12919 .33541 .11842 .32492 Mtetra
.446 .657 .951 r
.11842 .32492 .12919 .33541 .1433 .33602 .1326 .3251 Mtetra
.416 .635 .945 r
.1326 .3251 .1433 .33602 .15745 .33745 .14683 .32596 Mtetra
.396 .613 .937 r
.14683 .32596 .15745 .33745 .17166 .3396 .16114 .32738 Mtetra
.389 .594 .927 r
.16114 .32738 .17166 .3396 .18598 .3423 .17556 .32918 Mtetra
.397 .58 .914 r
.17556 .32918 .18598 .3423 .20043 .34532 .19012 .33112 Mtetra
.42 .571 .898 r
.19012 .33112 .20043 .34532 .21504 .34835 .20486 .33291 Mtetra
.453 .567 .88 r
.20486 .33291 .21504 .34835 .22986 .35103 .2198 .33422 Mtetra
.491 .566 .859 r
.2198 .33422 .22986 .35103 .24491 .35298 .23498 .33471 Mtetra
.529 .566 .836 r
.23498 .33471 .24491 .35298 .26022 .3538 .25041 .33404 Mtetra
.565 .567 .814 r
.25041 .33404 .26022 .3538 .27581 .35314 .26611 .33193 Mtetra
.596 .569 .794 r
.26611 .33193 .27581 .35314 .29167 .35069 .28206 .32816 Mtetra
.623 .571 .776 r
.28206 .32816 .29167 .35069 .3078 .34626 .29826 .32259 Mtetra
.645 .574 .761 r
.29826 .32259 .3078 .34626 .32417 .33976 .31468 .31522 Mtetra
.663 .578 .75 r
.31468 .31522 .32417 .33976 .34075 .33122 .3313 .30611 Mtetra
.678 .582 .741 r
.3313 .30611 .34075 .33122 .35751 .3208 .34807 .29547 Mtetra
.69 .588 .736 r
.34807 .29547 .35751 .3208 .37439 .30876 .36495 .28353 Mtetra
.699 .594 .734 r
.36495 .28353 .37439 .30876 .39137 .29543 .38192 .27063 Mtetra
.707 .601 .735 r
.38192 .27063 .39137 .29543 .40841 .2812 .39895 .2571 Mtetra
.713 .609 .739 r
.39895 .2571 .40841 .2812 .42547 .26647 .416 .24329 Mtetra
.718 .618 .745 r
.416 .24329 .42547 .26647 .44256 .2516 .43308 .2295 Mtetra
.72 .627 .753 r
.43308 .2295 .44256 .2516 .45964 .23692 .45017 .21598 Mtetra
.722 .638 .764 r
.45017 .21598 .45964 .23692 .47673 .2227 .46728 .20296 Mtetra
.722 .649 .777 r
.46728 .20296 .47673 .2227 .49383 .20915 .48441 .19057 Mtetra
.72 .661 .791 r
.48441 .19057 .49383 .20915 .51095 .19637 .50157 .17889 Mtetra
.717 .673 .806 r
.50157 .17889 .51095 .19637 .52811 .18443 .51878 .16794 Mtetra
.713 .685 .822 r
.51878 .16794 .52811 .18443 .54531 .17333 .53604 .15771 Mtetra
.707 .695 .837 r
.53604 .15771 .54531 .17333 .56258 .16303 .55338 .14815 Mtetra
.701 .705 .851 r
.55338 .14815 .56258 .16303 .57992 .15345 .5708 .13917 Mtetra
.695 .714 .863 r
.5708 .13917 .57992 .15345 .59736 .1445 .58831 .1307 Mtetra
.689 .72 .874 r
.58831 .1307 .59736 .1445 .61489 .13607 .60593 .12264 Mtetra
.683 .726 .882 r
.60593 .12264 .61489 .13607 .63253 .12807 .62365 .11491 Mtetra
.678 .73 .889 r
.62365 .11491 .63253 .12807 .65028 .12041 .64148 .10742 Mtetra
.674 .734 .895 r
.64148 .10742 .65028 .12041 .66814 .11299 .65943 .10012 Mtetra
.671 .736 .899 r
.65943 .10012 .66814 .11299 .68612 .10575 .6775 .09294 Mtetra
.669 .738 .902 r
.6775 .09294 .68612 .10575 .70422 .09863 .69568 .08584 Mtetra
.667 .739 .904 r
.69568 .08584 .70422 .09863 .72244 .09158 .71399 .07878 Mtetra
.666 .74 .905 r
.71399 .07878 .72244 .09158 .74078 .08457 .73241 .07173 Mtetra
.527 .696 .946 r
.0792 .31645 .09016 .32675 .10428 .32546 .09337 .31489 Mtetra
.499 .68 .946 r
.09337 .31489 .10428 .32546 .11842 .32492 .10758 .31396 Mtetra
.474 .662 .944 r
.10758 .31396 .11842 .32492 .1326 .3251 .12184 .31365 Mtetra
.453 .642 .938 r
.12184 .31365 .1326 .3251 .14683 .32596 .13616 .31388 Mtetra
.442 .624 .93 r
.13616 .31388 .14683 .32596 .16114 .32738 .15058 .31451 Mtetra
.441 .608 .918 r
.15058 .31451 .16114 .32738 .17556 .32918 .16511 .31536 Mtetra
.452 .596 .904 r
.16511 .31536 .17556 .32918 .19012 .33112 .17979 .31621 Mtetra
.473 .587 .887 r
.17979 .31621 .19012 .33112 .20486 .33291 .19466 .31677 Mtetra
.5 .581 .868 r
.19466 .31677 .20486 .33291 .2198 .33422 .20973 .31677 Mtetra
.531 .578 .847 r
.20973 .31677 .2198 .33422 .23498 .33471 .22503 .3159 Mtetra
.561 .576 .826 r
.22503 .3159 .23498 .33471 .25041 .33404 .24057 .31389 Mtetra
.589 .576 .807 r
.24057 .31389 .25041 .33404 .26611 .33193 .25637 .31052 Mtetra
.614 .577 .789 r
.25637 .31052 .26611 .33193 .28206 .32816 .27241 .30565 Mtetra
.635 .579 .774 r
.27241 .30565 .28206 .32816 .29826 .32259 .28867 .2992 Mtetra
.653 .581 .762 r
.28867 .2992 .29826 .32259 .31468 .31522 .30513 .2912 Mtetra
.668 .585 .753 r
.30513 .2912 .31468 .31522 .3313 .30611 .32177 .28177 Mtetra
.681 .59 .747 r
.32177 .28177 .3313 .30611 .34807 .29547 .33854 .27111 Mtetra
.691 .595 .744 r
.33854 .27111 .34807 .29547 .36495 .28353 .35542 .25946 Mtetra
.699 .602 .744 r
.35542 .25946 .36495 .28353 .38192 .27063 .37238 .2471 Mtetra
.706 .609 .746 r
.37238 .2471 .38192 .27063 .39895 .2571 .38939 .23435 Mtetra
.711 .618 .751 r
.38939 .23435 .39895 .2571 .416 .24329 .40644 .22147 Mtetra
.714 .627 .759 r
.40644 .22147 .416 .24329 .43308 .2295 .42352 .20872 Mtetra
.716 .637 .769 r
.42352 .20872 .43308 .2295 .45017 .21598 .44062 .1963 Mtetra
.717 .649 .78 r
.44062 .1963 .45017 .21598 .46728 .20296 .45775 .18436 Mtetra
.716 .66 .793 r
.45775 .18436 .46728 .20296 .48441 .19057 .47491 .17301 Mtetra
.713 .672 .808 r
.47491 .17301 .48441 .19057 .50157 .17889 .49211 .16228 Mtetra
.71 .683 .822 r
.49211 .16228 .50157 .17889 .51878 .16794 .50937 .15218 Mtetra
.705 .694 .836 r
.50937 .15218 .51878 .16794 .53604 .15771 .5267 .14268 Mtetra
.7 .703 .85 r
.5267 .14268 .53604 .15771 .55338 .14815 .5441 .13372 Mtetra
.694 .712 .862 r
.5441 .13372 .55338 .14815 .5708 .13917 .56159 .12523 Mtetra
.688 .719 .873 r
.56159 .12523 .5708 .13917 .58831 .1307 .57918 .11713 Mtetra
.683 .725 .881 r
.57918 .11713 .58831 .1307 .60593 .12264 .59688 .10934 Mtetra
.678 .729 .888 r
.59688 .10934 .60593 .12264 .62365 .11491 .61468 .1018 Mtetra
.675 .733 .894 r
.61468 .1018 .62365 .11491 .64148 .10742 .6326 .09444 Mtetra
.671 .735 .898 r
.6326 .09444 .64148 .10742 .65943 .10012 .65063 .08721 Mtetra
.669 .737 .901 r
.65063 .08721 .65943 .10012 .6775 .09294 .66878 .08005 Mtetra
.667 .739 .903 r
.66878 .08005 .6775 .09294 .69568 .08584 .68705 .07294 Mtetra
.666 .74 .905 r
.68705 .07294 .69568 .08584 .71399 .07878 .70544 .06585 Mtetra
.665 .74 .906 r
.70544 .06585 .71399 .07878 .73241 .07173 .72395 .05876 Mtetra
.54 .696 .941 r
.06815 .30583 .0792 .31645 .09337 .31489 .08239 .30394 Mtetra
.519 .682 .94 r
.08239 .30394 .09337 .31489 .10758 .31396 .09668 .30258 Mtetra
.5 .666 .936 r
.09668 .30258 .10758 .31396 .12184 .31365 .11102 .30172 Mtetra
.487 .649 .93 r
.11102 .30172 .12184 .31365 .13616 .31388 .12545 .30126 Mtetra
.481 .634 .921 r
.12545 .30126 .13616 .31388 .15058 .31451 .13997 .30107 Mtetra
.484 .62 .909 r
.13997 .30107 .15058 .31451 .16511 .31536 .15462 .30097 Mtetra
.496 .608 .894 r
.15462 .30097 .16511 .31536 .17979 .31621 .16943 .30074 Mtetra
.514 .6 .877 r
.16943 .30074 .17979 .31621 .19466 .31677 .18442 .30014 Mtetra
.537 .593 .858 r
.18442 .30014 .19466 .31677 .20973 .31677 .19961 .29891 Mtetra
.561 .589 .839 r
.19961 .29891 .20973 .31677 .22503 .3159 .21503 .29682 Mtetra
.585 .586 .82 r
.21503 .29682 .22503 .3159 .24057 .31389 .23068 .29364 Mtetra
.607 .585 .803 r
.23068 .29364 .24057 .31389 .25637 .31052 .24657 .28922 Mtetra
.627 .586 .788 r
.24657 .28922 .25637 .31052 .27241 .30565 .26268 .28347 Mtetra
.645 .587 .775 r
.26268 .28347 .27241 .30565 .28867 .2992 .27899 .27637 Mtetra
.66 .59 .766 r
.27899 .27637 .28867 .2992 .30513 .2912 .29549 .26797 Mtetra
.672 .594 .759 r
.29549 .26797 .30513 .2912 .32177 .28177 .31214 .25842 Mtetra
.683 .599 .755 r
.31214 .25842 .32177 .28177 .33854 .27111 .32891 .2479 Mtetra
.692 .605 .754 r
.32891 .2479 .33854 .27111 .35542 .25946 .34579 .23665 Mtetra
.699 .611 .756 r
.34579 .23665 .35542 .25946 .37238 .2471 .36273 .22492 Mtetra
.704 .619 .76 r
.36273 .22492 .37238 .2471 .38939 .23435 .37973 .21295 Mtetra
.708 .628 .766 r
.37973 .21295 .38939 .23435 .40644 .22147 .39678 .20099 Mtetra
.711 .638 .775 r
.39678 .20099 .40644 .22147 .42352 .20872 .41385 .18921 Mtetra
.712 .649 .785 r
.41385 .18921 .42352 .20872 .44062 .1963 .43096 .17779 Mtetra
.711 .66 .797 r
.43096 .17779 .44062 .1963 .45775 .18436 .44811 .16681 Mtetra
.71 .671 .81 r
.44811 .16681 .45775 .18436 .47491 .17301 .46531 .15636 Mtetra
.707 .682 .824 r
.46531 .15636 .47491 .17301 .49211 .16228 .48255 .14644 Mtetra
.703 .693 .837 r
.48255 .14644 .49211 .16228 .50937 .15218 .49987 .13704 Mtetra
.698 .702 .85 r
.49987 .13704 .50937 .15218 .5267 .14268 .51725 .12813 Mtetra
.693 .711 .862 r
.51725 .12813 .5267 .14268 .5441 .13372 .53473 .11965 Mtetra
.688 .718 .872 r
.53473 .11965 .5441 .13372 .56159 .12523 .55229 .11153 Mtetra
.683 .724 .881 r
.55229 .11153 .56159 .12523 .57918 .11713 .56996 .10372 Mtetra
.678 .728 .888 r
.56996 .10372 .57918 .11713 .59688 .10934 .58773 .09613 Mtetra
.675 .732 .893 r
.58773 .09613 .59688 .10934 .61468 .1018 .60562 .08872 Mtetra
.672 .735 .898 r
.60562 .08872 .61468 .1018 .6326 .09444 .62361 .08144 Mtetra
.669 .737 .901 r
.62361 .08144 .6326 .09444 .65063 .08721 .64173 .07423 Mtetra
.667 .738 .903 r
.64173 .07423 .65063 .08721 .66878 .08005 .65996 .06708 Mtetra
.666 .739 .905 r
.65996 .06708 .66878 .08005 .68705 .07294 .67831 .05994 Mtetra
.665 .74 .906 r
.67831 .05994 .68705 .07294 .70544 .06585 .69678 .0528 Mtetra
.665 .74 .907 r
.69678 .0528 .70544 .06585 .72395 .05876 .71538 .04565 Mtetra
.554 .697 .935 r
.05701 .29489 .06815 .30583 .08239 .30394 .07133 .29263 Mtetra
.538 .684 .933 r
.07133 .29263 .08239 .30394 .09668 .30258 .0857 .29081 Mtetra
.525 .67 .929 r
.0857 .29081 .09668 .30258 .11102 .30172 .10014 .28936 Mtetra
.517 .656 .922 r
.10014 .28936 .11102 .30172 .12545 .30126 .11467 .2882 Mtetra
.515 .642 .912 r
.11467 .2882 .12545 .30126 .13997 .30107 .1293 .28719 Mtetra
.52 .63 .9 r
.1293 .28719 .13997 .30107 .15462 .30097 .14408 .28616 Mtetra
.531 .619 .885 r
.14408 .28616 .15462 .30097 .16943 .30074 .15901 .2849 Mtetra
.546 .611 .869 r
.15901 .2849 .16943 .30074 .18442 .30014 .17412 .28322 Mtetra
.565 .604 .851 r
.17412 .28322 .18442 .30014 .19961 .29891 .18944 .28089 Mtetra
.585 .6 .834 r
.18944 .28089 .19961 .29891 .21503 .29682 .20496 .27773 Mtetra
.604 .597 .817 r
.20496 .27773 .21503 .29682 .23068 .29364 .22071 .27357 Mtetra
.622 .596 .802 r
.22071 .27357 .23068 .29364 .24657 .28922 .23668 .2683 Mtetra
.638 .596 .79 r
.23668 .2683 .24657 .28922 .26268 .28347 .25284 .26188 Mtetra
.653 .597 .78 r
.25284 .26188 .26268 .28347 .27899 .27637 .2692 .25432 Mtetra
.665 .6 .772 r
.2692 .25432 .27899 .27637 .29549 .26797 .28572 .24572 Mtetra
.676 .604 .768 r
.28572 .24572 .29549 .26797 .31214 .25842 .30238 .2362 Mtetra
.684 .609 .766 r
.30238 .2362 .31214 .25842 .32891 .2479 .31916 .22595 Mtetra
.692 .615 .766 r
.31916 .22595 .32891 .2479 .34579 .23665 .33602 .21517 Mtetra
.698 .623 .769 r
.33602 .21517 .34579 .23665 .36273 .22492 .35296 .20408 Mtetra
.702 .631 .774 r
.35296 .20408 .36273 .22492 .37973 .21295 .36995 .19289 Mtetra
.705 .64 .782 r
.36995 .19289 .37973 .21295 .39678 .20099 .38699 .18177 Mtetra
.707 .65 .791 r
.38699 .18177 .39678 .20099 .41385 .18921 .40407 .17088 Mtetra
.707 .661 .802 r
.40407 .17088 .41385 .18921 .43096 .17779 .4212 .16033 Mtetra
.706 .671 .814 r
.4212 .16033 .43096 .17779 .44811 .16681 .43837 .15018 Mtetra
.703 .682 .826 r
.43837 .15018 .44811 .16681 .46531 .15636 .4556 .14049 Mtetra
.7 .692 .839 r
.4556 .14049 .46531 .15636 .48255 .14644 .4729 .13123 Mtetra
.696 .701 .851 r
.4729 .13123 .48255 .14644 .49987 .13704 .49026 .12241 Mtetra
.692 .71 .862 r
.49026 .12241 .49987 .13704 .51725 .12813 .50771 .11396 Mtetra
.687 .717 .872 r
.50771 .11396 .51725 .12813 .53473 .11965 .52525 .10585 Mtetra
.682 .723 .88 r
.52525 .10585 .53473 .11965 .55229 .11153 .54289 .09802 Mtetra
.678 .728 .887 r
.54289 .09802 .55229 .11153 .56996 .10372 .56063 .0904 Mtetra
.675 .732 .893 r
.56063 .0904 .56996 .10372 .58773 .09613 .57848 .08295 Mtetra
.672 .734 .897 r
.57848 .08295 .58773 .09613 .60562 .08872 .59645 .07563 Mtetra
.669 .737 .9 r
.59645 .07563 .60562 .08872 .62361 .08144 .61452 .06838 Mtetra
.668 .738 .903 r
.61452 .06838 .62361 .08144 .64173 .07423 .63272 .06117 Mtetra
.666 .739 .904 r
.63272 .06117 .64173 .07423 .65996 .06708 .65104 .05399 Mtetra
.665 .74 .906 r
.65104 .05399 .65996 .06708 .67831 .05994 .66947 .04681 Mtetra
.66947 .04681 .67831 .05994 .69678 .0528 .68803 .03961 Mtetra
.664 .741 .907 r
.68803 .03961 .69678 .0528 .71538 .04565 .70671 .03239 Mtetra
.568 .698 .929 r
.04578 .28367 .05701 .29489 .07133 .29263 .06018 .28101 Mtetra
.556 .687 .927 r
.06018 .28101 .07133 .29263 .0857 .29081 .07464 .2787 Mtetra
.547 .674 .922 r
.07464 .2787 .0857 .29081 .10014 .28936 .08918 .27666 Mtetra
.543 .662 .914 r
.08918 .27666 .10014 .28936 .11467 .2882 .10382 .27479 Mtetra
.543 .65 .904 r
.10382 .27479 .11467 .2882 .1293 .28719 .11857 .27298 Mtetra
.548 .639 .892 r
.11857 .27298 .1293 .28719 .14408 .28616 .13346 .27106 Mtetra
.558 .629 .878 r
.13346 .27106 .14408 .28616 .15901 .2849 .14851 .26886 Mtetra
.572 .621 .863 r
.14851 .26886 .15901 .2849 .17412 .28322 .16375 .26621 Mtetra
.587 .615 .847 r
.16375 .26621 .17412 .28322 .18944 .28089 .17917 .26292 Mtetra
.603 .61 .832 r
.17917 .26292 .18944 .28089 .20496 .27773 .1948 .25884 Mtetra
.619 .608 .817 r
.1948 .25884 .20496 .27773 .22071 .27357 .21064 .25387 Mtetra
.634 .606 .805 r
.21064 .25387 .22071 .27357 .23668 .2683 .22667 .24795 Mtetra
.647 .607 .795 r
.22667 .24795 .23668 .2683 .25284 .26188 .24289 .24104 Mtetra
.659 .608 .787 r
.24289 .24104 .25284 .26188 .2692 .25432 .25928 .23321 Mtetra
.669 .611 .781 r
.25928 .23321 .2692 .25432 .28572 .24572 .27582 .22454 Mtetra
.678 .616 .778 r
.27582 .22454 .28572 .24572 .30238 .2362 .29249 .21517 Mtetra
.685 .621 .778 r
.29249 .21517 .30238 .2362 .31916 .22595 .30926 .20526 Mtetra
.691 .628 .78 r
.30926 .20526 .31916 .22595 .33602 .21517 .32612 .19499 Mtetra
.696 .635 .784 r
.32612 .19499 .33602 .21517 .35296 .20408 .34305 .18454 Mtetra
.699 .644 .79 r
.34305 .18454 .35296 .20408 .36995 .19289 .36003 .17407 Mtetra
.701 .653 .798 r
.36003 .17407 .36995 .19289 .38699 .18177 .37708 .16372 Mtetra
.702 .663 .808 r
.37708 .16372 .38699 .18177 .40407 .17088 .39417 .1536 Mtetra
.702 .673 .819 r
.39417 .1536 .40407 .17088 .4212 .16033 .41132 .1438 Mtetra
.7 .683 .83 r
.41132 .1438 .4212 .16033 .43837 .15018 .42852 .13435 Mtetra
.697 .692 .842 r
.42852 .13435 .43837 .15018 .4556 .14049 .44579 .12527 Mtetra
.694 .701 .853 r
.44579 .12527 .4556 .14049 .4729 .13123 .46313 .11655 Mtetra
.69 .71 .863 r
.46313 .11655 .4729 .13123 .49026 .12241 .48056 .10817 Mtetra
.686 .717 .872 r
.48056 .10817 .49026 .12241 .50771 .11396 .49807 .10008 Mtetra
.682 .722 .881 r
.49807 .10008 .50771 .11396 .52525 .10585 .51568 .09225 Mtetra
.678 .727 .887 r
.51568 .09225 .52525 .10585 .54289 .09802 .53339 .08461 Mtetra
.674 .731 .893 r
.53339 .08461 .54289 .09802 .56063 .0904 .5512 .07714 Mtetra
.672 .734 .897 r
.5512 .07714 .56063 .0904 .57848 .08295 .56913 .06977 Mtetra
.669 .736 .9 r
.56913 .06977 .57848 .08295 .59645 .07563 .58717 .06248 Mtetra
.668 .738 .903 r
.58717 .06248 .59645 .07563 .61452 .06838 .60533 .05523 Mtetra
.666 .739 .904 r
.60533 .05523 .61452 .06838 .63272 .06117 .62361 .04801 Mtetra
.665 .74 .905 r
.62361 .04801 .63272 .06117 .65104 .05399 .64201 .04078 Mtetra
.665 .74 .906 r
.64201 .04078 .65104 .05399 .66947 .04681 .66053 .03354 Mtetra
.664 .741 .907 r
.66053 .03354 .66947 .04681 .68803 .03961 .67917 .02628 Mtetra
.67917 .02628 .68803 .03961 .70671 .03239 .69793 .01898 Mtetra
.581 .7 .924 r
.03446 .27219 .04578 .28367 .06018 .28101 .04894 .26912 Mtetra
.573 .69 .92 r
.04894 .26912 .06018 .28101 .07464 .2787 .0635 .26631 Mtetra
.567 .679 .915 r
.0635 .26631 .07464 .2787 .08918 .27666 .07814 .26367 Mtetra
.565 .668 .907 r
.07814 .26367 .08918 .27666 .10382 .27479 .09288 .26113 Mtetra
.566 .657 .898 r
.09288 .26113 .10382 .27479 .11857 .27298 .10775 .25856 Mtetra
.572 .647 .886 r
.10775 .25856 .11857 .27298 .13346 .27106 .12276 .25583 Mtetra
.581 .638 .873 r
.12276 .25583 .13346 .27106 .14851 .26886 .13793 .25278 Mtetra
.592 .631 .859 r
.13793 .25278 .14851 .26886 .16375 .26621 .15327 .24926 Mtetra
.605 .625 .845 r
.15327 .24926 .16375 .26621 .17917 .26292 .1688 .24515 Mtetra
.618 .621 .832 r
.1688 .24515 .17917 .26292 .1948 .25884 .18452 .24033 Mtetra
.631 .619 .82 r
.18452 .24033 .1948 .25884 .21064 .25387 .20043 .23472 Mtetra
.643 .618 .81 r
.20043 .23472 .21064 .25387 .22667 .24795 .21652 .2283 Mtetra
.654 .618 .802 r
.21652 .2283 .22667 .24795 .24289 .24104 .23279 .22108 Mtetra
.664 .62 .796 r
.23279 .22108 .24289 .24104 .25928 .23321 .24921 .2131 Mtetra
.672 .624 .792 r
.24921 .2131 .25928 .23321 .27582 .22454 .26576 .20448 Mtetra
.68 .628 .791 r
.26576 .20448 .27582 .22454 .29249 .21517 .28243 .19533 Mtetra
.686 .634 .792 r
.28243 .19533 .29249 .21517 .30926 .20526 .2992 .1858 Mtetra
.691 .641 .795 r
.2992 .1858 .30926 .20526 .32612 .19499 .31606 .17603 Mtetra
.694 .648 .8 r
.31606 .17603 .32612 .19499 .34305 .18454 .33299 .16617 Mtetra
.696 .657 .807 r
.33299 .16617 .34305 .18454 .36003 .17407 .34998 .15636 Mtetra
.698 .666 .815 r
.34998 .15636 .36003 .17407 .37708 .16372 .36703 .14668 Mtetra
.697 .675 .825 r
.36703 .14668 .37708 .16372 .39417 .1536 .38414 .13722 Mtetra
.696 .684 .835 r
.38414 .13722 .39417 .1536 .41132 .1438 .40131 .12804 Mtetra
.694 .694 .845 r
.40131 .12804 .41132 .1438 .42852 .13435 .41855 .11916 Mtetra
.691 .702 .855 r
.41855 .11916 .42852 .13435 .44579 .12527 .43586 .11057 Mtetra
.688 .71 .865 r
.43586 .11057 .44579 .12527 .46313 .11655 .45325 .10227 Mtetra
.684 .717 .873 r
.45325 .10227 .46313 .11655 .48056 .10817 .47074 .09423 Mtetra
.681 .722 .881 r
.47074 .09423 .48056 .10817 .49807 .10008 .48831 .08641 Mtetra
.677 .727 .887 r
.48831 .08641 .49807 .10008 .51568 .09225 .50599 .07877 Mtetra
.674 .731 .893 r
.50599 .07877 .51568 .09225 .53339 .08461 .52377 .07127 Mtetra
.671 .734 .897 r
.52377 .07127 .53339 .08461 .5512 .07714 .54166 .06387 Mtetra
.669 .736 .9 r
.54166 .06387 .5512 .07714 .56913 .06977 .55967 .05654 Mtetra
.668 .738 .902 r
.55967 .05654 .56913 .06977 .58717 .06248 .57779 .04925 Mtetra
.666 .739 .904 r
.57779 .04925 .58717 .06248 .60533 .05523 .59603 .04199 Mtetra
.665 .74 .905 r
.59603 .04199 .60533 .05523 .62361 .04801 .61439 .03472 Mtetra
.665 .74 .906 r
.61439 .03472 .62361 .04801 .64201 .04078 .63287 .02744 Mtetra
.664 .741 .907 r
.63287 .02744 .64201 .04078 .66053 .03354 .65147 .02013 Mtetra
.65147 .02013 .66053 .03354 .67917 .02628 .6702 .01279 Mtetra
.6702 .01279 .67917 .02628 .69793 .01898 .68905 .00541 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`006P3ooonDo`0003<0ooooU?l0000K0?ooo`006P3o
ool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0T03o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0T03oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`8000000`3oool3000000X0oooo0P0000050?ooo`8000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00ol0
0000oooo0?ooo`0G0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0103oool00ol0
0000oooo0?ooo`0C0?ooo`8000006@3oool4o`0001@0oooo00?o00000?ooo`3oool0@03oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`08o`0000030000000I6AT06ATI00T0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0
IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@<00000202c/k<4000000P0
VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6@03o`0000000000000001@0
00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00Co000000<0000001TI6@0I
6AT04@0I6AT2000001l0<c<c0ol0000B01TI6@03o`0000000000000003`000000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`08o`0000030000000I6AT06ATI00T06ATI
00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV
00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@8000003`2c/k<2000000L0VIVI
00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6@03o`0000000000000001<00000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00?o000000<0000001TI6@0I6AT0
4@0I6AT00`000000<c<c03<c<`0R03<c<`03o`00000I6AT06ATI01006ATI0ol0000k000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool02?l000000`0000006ATI01TI
6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT0102IVIT00`000000/k>c0;>c
/`0A0;>c/`8000001P2IVIT00ol00000Ogmo07moO`0407moO`030000001VIVH0IVIV0080IVIV00?o
00000000001<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI00?o
00000000000000004P0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool00_l0
00000`0000006ATI01TI6@0A01TI6@030000000c<c<0<c<c02@0<c<c1?l0000A01TI6@03o`000000
0000000003P000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`08
o`0000030000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@04
09VIV@030000002c/k<0/k>c01<0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`03
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`05
03<c<`030000000I6AT06ATI00P06ATI00?o00000000000000004P0000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool00_l000000`0000006ATI01TI6@0@01TI6@030000000c<c<0
<c<c02T0<c<c0_l0000@01TI6@03o`0000000000000003L000000`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`08o`0000030000000I6AT06ATI00T06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007mo
O`1oOgl0101oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c01D0/k>c00<0000009VI
V@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<
C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI00?o00000000
000000004@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool00_l000000`00
00006ATI01TI6@0?01TI6@030000000c<c<0<c<c02`0<c<c0_l0000?01TI6@03o`00000000000000
03H000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`09o`000003
0000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C003
0000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c01H0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`03
0000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`03
0000000I6AT06ATI00T06ATI00?o0000000000000000400000030?ooo`03o`00003oool0oooo0340
oooo00Go00000?ooo`3ooooo00000000000A01TI6@030000000c<c<0<c<c01@0<c<c1000000G03<c
<`03o`00000I6AT06ATI00d06ATI00?o0000000000000000=@0000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo00Wo000000<0000001TI6@0I6AT02@0I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000
Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0202c/k<8000000P0
/k>c00?o00000000002IVIT0102IVIT00ol00000Ogmo07moO`0307moO`030000001VIVH0IVIV0080
IVIV00?o00000000001<C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00T0
6ATI00?o00000000000000003`0000030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3o
oooo00000000000@01TI6@030000000c<c<0<c<c00h0<c<c1`00000404a<C0P000003`0c<c<2o`00
00l06ATI0_l0000e000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3o
ool02Ol000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`050;>c/`<00000203<c<`00`000000/k>c0;>c/`070;>c/`03
0000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP03
0000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@03
o`0000000000000000l000000`3oool00ol00000oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`00
00000000400I6AT00`000000<c<c03<c<`0<03<c<`8000004`1<C4`3000000h0<c<c00?o000001TI
6@0I6AT03P0I6AT00ol0000000000000000b000000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool02_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080
Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00X0
c<c<0`0000070;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000
IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol00000
6ATI01TI6@0901TI6@03o`0000000000000000h000000`3oool00ol00000oooo0?ooo`0a0?ooo`05
o`00003oool0ooooo`00000000003`0I6AT00`000000<c<c03<c<`0;03<c<`800000601<C4`40000
00/0<c<c0ol0000>01TI6@03o`00000000000000034000000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`0:o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c
<c<01@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<
c<`03P3<c<`00`00003o00000;>c/`050;>c/`03o`0000000000VIVI00<0VIVI00<0000007moO`1o
Ogl00P1oOgl00ol00000000006IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c
<c<0100c<c<00`0000006ATI01TI6@0901TI6@03o`0000000000000000d000000`3oool00ol00000
oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`00000000003P0I6AT00`000000<c<c03<c<`0;03<c
<`030000001<C4`0C4a<01`0C4a<0P00000<03<c<`03o`00000I6AT06ATI00`06ATI0_l0000a0000
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool02_l000000`000000
6ATI01TI6@0801TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000
/k>c0;>c/`040;>c/`03o`00003<c<`0c<c<00l0c<c<0P0000060;>c/`030000002IVIT0VIVI0080
VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@03o`0000000000000000d0
00000`3oool00ol00000oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`00000000003P0I6AT00`00
0000<c<c03<c<`0:03<c<`03o`00001<C4`0C4a<01l0C4a<0P00000;03<c<`03o`00000I6AT06ATI
00d06ATI00?o0000000000000000;P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo00[o000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`03
0000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`03
0000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c00A0<c<c080
00001@2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1V
IVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT02@0I6AT00ol0000000000000000<000000<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000
oooo0?ooool00000000000h06ATI00<0000003<c<`0c<c<02@0c<c<00`000000C4a<04a<C00R04a<
C08000002P0c<c<00ol000006ATI01TI6@0=01TI6@03o`0000000000000002d000000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0;o`0000030000000I6AT06ATI00P0
6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080
IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0
/k>c00<000000<c<c03<c<`0503<c<`00ol00000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@03o`0000000000000000`0
00000`3oool00ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo000000h06ATI00<0000003<c
<`0c<c<02@0c<c<00`000000C4a<04a<C00U04a<C08000002@0c<c<00ol000006ATI01TI6@0=01TI
6@03o`0000000000000002`000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`0;o`0000030000000I6AT06ATI00P06ATI00?o000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000
VIVI09VIV@0209VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`05@3<c<`00`000000
/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00ol00000
IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol00000
6ATI01TI6@0901TI6@03o`0000000000000000/000000`3oool00ol00000oooo0?ooo`0a0?ooo`04
o`00003oool0oooo000000h06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<C00<04a<
C00300000?l0003o000000T0000000Co00000000000000000000301<C4`2000000P0<c<c0ol0000=
01TI6@03o`0000000000000002/000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`0<o`0000X06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01`3<c<`5000000X0c<c<00<000000;>c
/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00D0000006IV
IP1VIVH0IVIV0000000604a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT0
0ol0000000000000000;000000<0oooo00?o00000?ooo`3oool0<@3oool01?l00000oooo0?ooo`00
000=01TI6@03o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`02`1<C4`200000100IVIV0`00
000;04a<C0030000000c<c<0<c<c00P0<c<c00?o000001TI6@0I6AT02`0I6AT00ol0000000000000
000Z000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool02ol00000
0`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<0P0000050>KViP<00000203<c<`0
0`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl0
0`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0901TI6@03o`0000000000000000X000000`3oool00ol00000oooo0?ooo`0a
0?ooo`04o`00003oool0oooo000000d06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<
C00904a<C08000005@1VIVH00`000000C4a<04a<C00904a<C08000002@0c<c<00ol000006ATI01TI
6@0;01TI6@03o`0000000000000002T000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0<o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl0
0`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`0
0`000000i^KV0>KViP080>KViP0300000?l00000c<c<00D0c<c<00<000000;>c/`2c/k<00`2c/k<0
0`000000VIVI09VIV@0209VIV@03o`00001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH0
0`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT0
0ol0000000000000000:000000<0oooo00?o00000?ooo`3oool0<@3oool01?l00000oooo0?ooo`00
000=01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0201<C4`2000001P0IVIV0`00
000:04a<C0030000000c<c<0<c<c00L0<c<c00?o000001TI6@0I6AT02`0I6AT00ol0000000000000
000X000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool03?l00000
0`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`0
0`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H02`3Vi^H2
000000D0c<c<0P0000040;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl0
0`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<01@0c<c<0
0`0000006ATI01TI6@0801TI6@03o`0000000000000000T000000`3oool00ol00000oooo0?ooo`0a
0?ooo`04o`00003oool0oooo000000d06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<
C00704a<C0030000001VIVH0IVIV01/0IVIV00?o0000000000000000201<C4`00ol00000<c<c03<c
<`0703<c<`;o0000300I6AT00ol0000000000000000W000000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool03?l000000`0000006ATI01TI6@0801TI6@030000000c<c<0
<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00@0c<c<00<000000>KViP3Vi^H03@3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0
/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV0080IVIV00<0
000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI00?o
00000000000000002@0000030?ooo`03o`00003oool0oooo0340oooo00Co00000?ooo`3oool00000
3@0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH0
7`1VIVH2000000L0C4a<0P00000903<c<`03o`00000I6AT06ATI00X06ATI00?o0000000000000000
9P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00co000000<0
000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0
000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000
102c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00l0i^KV00?o00000<c<c03<c<`0
103<c<`00ol00000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@000000101oOgl00ol00000
IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0801TI6@03o`0000000000000000P000000`3oool00ol00000oooo0?ooo`0a0?ooo`04
o`00003oool0oooo000000`06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00604a<
C0030000001VIVH0IVIV00X0IVIV3000000<06IVIP8000001`1<C4`00`000000<c<c03<c<`0703<c
<`03o`00000I6AT06ATI00X06ATI00?o00000000000000009@0000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo00co000000<0000001TI6@0I6AT0200I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000
Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0040<c<
c0030000003Vi^H0i^KV0100i^KV00<000000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`020;>c
/`050000002IVIT0VIVI09VIVOl00000101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<0080C4a<00?o00000000000c<c<0100c<c<00ol00000000001TI6@0801TI6@03o`0000000000
000000P000000`3oool00ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo000000`06ATI00<0
000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C003o`00001VIVH0IVIV00P0IVIV00<0
0000o`0000000000301oOgl300000003o`00001VIVH0IVIV00P0IVIV00?o000004a<C01<C4`01@1<
C4`00ol00000000003<c<`0703<c<`03o`00000I6AT06ATI00X06ATI00?o00000000000000009000
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00co000000<00000
01TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00?o0000
06IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c
/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV0180i^KV00<000000<c<c03<c<`00`3<
c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo
0000000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI
01TI6@0701TI6@03o`0000000000000000P000000`3oool00ol00000oooo0?ooo`0a0?ooo`04o`00
003oool0oooo000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C003
0000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl04@1oOgl3000000P0IVIV0P00000704a<C003
0000000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT02`0I6AT00ol0000000000000000S000000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool03?l000000`0000006ATI
01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`03
0000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H04`3Vi^H00`000000c<c<0<c<c0030<c<c003
0000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV
0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI
00P06ATI00?o00000000000000001`0000030?ooo`03o`00003oool0oooo0340oooo00Co00000?oo
o`3oool00000300I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<00000
06IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0E07moO`<000001`1VIVH00`000000C4a<04a<C005
04a<C0030000000c<c<0<c<c00D0<c<c0_l0000<01TI6@03o`00000000000000028000000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0=o`0000030000000I6AT06ATI
00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@050000002c/k<0/k>c0;>c/`0000001@3<
c<`00`000000i^KV0>KViP0D0>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c
/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`0000001@1VIVH00ol00000C4a<
04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01`0I6AT00ol000000000
00000007000000<0oooo00?o00000?ooo`3oool0<@3oool01?l00000oooo0?ooo`00000<01TI6@03
0000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IVIP03
0000001oOgl0Ogmo01T0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C003
o`00000c<c<0<c<c00H0<c<c00?o000001TI6@0I6AT02P0I6AT00ol0000000000000000Q000000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool03Ol000000`0000006ATI
01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT01@000000/k>c0;>c/`2c/k<00000
00D0c<c<00<000000>KViP3Vi^H05@3Vi^H00`000000c<c<0<c<c0020<c<c00300000?l00000/k>c
0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgoo000000@0IVIV00<00000
04a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI00?o0000
0000000000001P0000030?ooo`03o`00003oool0oooo0340oooo00Co00000?ooo`3oool00000300I
6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01P1V
IVH00`000000Ogmo07moO`0K07moO`03o`0000000000000000D0IVIV0P00000604a<C08000001`0c
<c<00ol000006ATI01TI6@0901TI6@03o`00000000000000024000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0=o`0000030000000I6AT06ATI00P06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D00000
07moO`1oOgl0Ogmo0000000409VIV@05o`00002c/k<0/k>c0;>c/`0000001@3<c<`00`000000i^KV
0>KViP080>KViPKo0000203Vi^H01@000000c<c<0<c<c03<c<`0000000@0/k>c00<0000009VIV@2I
VIT00P2IVIT00`000000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`00
0000<c<c03<c<`0303<c<`030000000I6AT06ATI00P06ATI00?o00000000000000001P0000030?oo
o`03o`00003oool0oooo0340oooo00Co00000?ooo`3oool00000300I6AT00`000000<c<c03<c<`06
03<c<`030000001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`09
07moO``000002P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<00000
03<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0901TI6@03o`00000000000000020000000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0>o`0000030000000I6AT06ATI
00P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@050000002c/k<0/k>c0;>c/`0000001@3<
c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo00@0oooo0_l000070>KViP050000003<
c<`0c<c<0<c<c0000000102c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`00
0000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I
6AT0200I6AT00ol00000000000000005000000<0oooo00?o00000?ooo`3oool0<@3oool01?l00000
oooo0?ooo`00000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`00
0000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00L0Ogmo0`00000<09VIV@<00000201oOgl00`00
0000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0100c<c<00ol0
00006ATI01TI6@0:01TI6@03o`0000000000000001l000000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`0>o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl01@00
0000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP06
0>KViP03o`00003oool0oooo00L0oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c002
0<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT00ol00000Ogmo07moO`0207moO`050000001V
IVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI
00?o0000000000000000100000030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3ooooo
00000000000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0506IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0402IVIT00`00003o
000007moO`0607moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0503<c<`03o`00000I6AT06ATI00X06ATI00?o00000000000000007P0000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo013o00002@0I6AT00ol00000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`05
0000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV
00D0i^KV00?o00000?ooo`3oool0203oool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<
0080c<c<00Ko00000;>c/`2c/k<0/k>co`000000000309VIV@050000001oOgl0Ogmo07moO`000000
101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0
200I6AT00ol00000000000000004000000<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000oooo
0?ooool00000000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00ol00000000009VIV@0D09VIV@<0
00001@1oOgl2000000D0IVIV0P00000504a<C0030000000c<c<0<c<c00D0<c<c0_l0000;01TI6@03
o`0000000000000001d000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0?o`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<
04a<C00204a<C0050000001VIVH0IVIV06IVIP000000101oOgl01Ol00000VIVI09VIV@2IVIT00000
00@0/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo
00T0oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0030<c<c0050000002c/k<0/k>c
0;>c/`0000000`2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI00?o00000000000000001000
00030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3ooooo00000000000;01TI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000
001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT05`2IVIT2000000D0Ogmo0P00000506IVIP030000
001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c<c<00ol000006ATI01TI6@0901TI6@03o`00
00000000000001`000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?oo
o`0@o`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00304a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl00`000000VIVI09VIV@0209VIV@050000
002c/k<0/k>c0;>c/`000000103<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0oooo00/0
oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080
/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV0080IVIV00?o000004a<
C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI00?o00000000
000000000`0000030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3ooooo00000000000;
01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0202IVIT8000000X0VIVI00<00000
07moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<0P000007
03<c<`03o`00000I6AT06ATI00T06ATI00?o00000000000000006`0000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo013o000000<0000001TI6@0I6AT01`0I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV00000004
07moO`050000002IVIT0VIVI09VIV@0000000`2c/k<00`000000c<c<0<c<c0020<c<c0030000003V
i^H0i^KV00@0i^KV00?o00000?ooo`3oool0303oool00ol00000i^KV0>KViP040>KViP03o`00003<
c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000409VIV@050000001oOgl0Ogmo07moOol0
0000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT0200I6AT00ol00000000000000002000000<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000
oooo0?ooool00000000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<
C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VI
V@;o000000<000000;>c/`2c/k<01P2c/k<4000000L0VIVI0P00000507moO`800000101VIVH20000
00D0C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0901TI6@03o`00000000000000
01X000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0@o`000003
0000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C005
0000001VIVH0IVIV06IVIP000000101oOgl01@000000VIVI09VIV@2IVIT0000000<0/k>c00<00000
0<c<c03<c<`00P3<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0oooo00`0oooo00?o0000
0>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000102I
VIT00`000000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000<c<c
03<c<`0403<c<`030000000I6AT06ATI00P06ATI00?o00000000000000000P0000030?ooo`03o`00
003oool0oooo0340oooo00Go00000?ooo`3ooooo00000000000;01TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0
Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`0=0;>c/`8000001`2IVIT2000000D0
Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0
<c<c00?o000001TI6@0I6AT02@0I6AT00ol0000000000000000J000000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool04?l000000`0000006ATI01TI6@0801TI6@030000
000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH0000000@0
Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`030000003<c<`0c<c<0080c<c<00<000000>KV
iP3Vi^H0103Vi^H00ol00000oooo0?ooo`0=0?ooo`03o`00003Vi^H0i^KV00<0i^KV00<000000<c<
c03<c<`00`3<c<`01@000000/k>c0;>c/`2c/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo0000
000306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0701TI6@03o`00000000000000008000000`3oool00ol00000oooo0?ooo`0a0?ooo`05o`00003o
ool0ooooo`00000000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00D0VIVI
00<000000;>c/`2c/k<0402c/k<2000000L0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV
06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI
01TI6@0801TI6@03o`0000000000000001X000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00ol00000oooo0?ooo`0Ao`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl01@000000VIVI
09VIV@2IVIT0000000<0/k>c00D000000<c<c03<c<`0c<c<000000060>KViP03o`00003oool0oooo
00h0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0/k>c
0;>c/`000000102IVIT00ol00000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP000000101<
C4`00ol00000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI00Co00000000000000000000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00;o000000<0000001TI6@0I6AT0
2@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
0`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0
4`2c/k<2000000H0VIVI00<0000007moO`1oOgl00`1oOgl00ol00000IVIV06IVIP0206IVIP030000
001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0801TI6@03o`00
00000000000001T000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?oo
o`0Ao`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<
C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl01@000000VIVI09VIV@2IVIT0000000<0
/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP030>KViP03o`00003oool0oooo00l0
oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c
/`0000000`2IVIT00`000000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP0000001@1<C4`0
0`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00Co000000000000000000000`3o
ool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00;o000000<0000001TI6@0I6AT02@0I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00?o00000;>c/`2c/k<05P2c
/k<00ol00000VIVI09VIV@0409VIV@03o`00001oOgl0Ogmo0080Ogmo0P00000406IVIP03o`00001<
C4`0C4a<00<0C4a<0P00000603<c<`03o`00000I6AT06ATI00P06ATI0_l0000I000000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool04Ol000000`0000006ATI01TI6@08
01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1V
IVH0000000@0Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`030000003<c<`0c<c<0080c<c<
00<000000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV0080i^KV
00<000000<c<c03<c<`00`3<c<`010000000/k>c0;>c/`00000309VIV@030000001oOgl0Ogmo0080
Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI
6@0I6AT01`0I6AT01?l0000000000000000000030?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool00_l000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<00000
09VIV@2IVIT0102IVIT00`000000/k>c0;>c/`070;>c/`P00000202c/k<2000000D0VIVI0P000004
07moO`030000001VIVH0IVIV0080IVIV0P00000504a<C0030000000c<c<0<c<c00@0<c<c00?o0000
01TI6@0I6AT02@0I6AT00ol0000000000000000F000000<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool04_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c
00<0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00D00000
09VIV@2IVIT0VIVI000000030;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H00`3V
i^H00ol00000oooo0?ooo`0?0?ooo`03o`00003Vi^H0i^KV00<0i^KV00<000000<c<c03<c<`00P3<
c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00<0000007moO`1oOgl00P1oOgl01@000000IVIV
06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@03
o`0000000000000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`03o`000003
0000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C003
0000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00D0/k>c0`0000080<c<c0@000001P2c/k<2000000D0VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c
<c<0100c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000001H000000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Bo`0000030000000I6AT06ATI00P06ATI
00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV
00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/ol00000103<c<`00`00
0000i^KV0>KViP030>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H00`3Vi^H00`00
0000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1o
Ogl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I
6AT06ATI00P06ATI00?o00000000003oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo00?o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<2000000l0c<c<0`0000050;>c/`030000002I
VIT0VIVI00<0VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<
C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0801TI6@03o`000000
0000000001D000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0B
o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@05o`00002c
/k<0/k>c0;>c/`000000103<c<`00`000000i^KV0>KViP030>KViP03o`00003oool0oooo0100oooo
00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`00
00000`2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`00
0000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI00?o00000000003oool00P3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00?o000000<0000001TI6@0I6AT0200I6AT00ol0
0000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00ol0
0000c<c<0<c<c00A0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT01@00
0000Ogmo07moO`1oOgl0000000D0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`04
03<c<`03o`00000I6AT06ATI00P06ATI00?o00000000000000005@0000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo01?o000000<0000001TI6@0I6AT01`0I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`040000002IVIT0VIVI000000@0/k>c00D000000<c<c03<c<`0c<c<0000
00050>KViP03o`00003oool0oooo0140oooo00?o00000>KViP3Vi^H00`3Vi^H01@000000c<c<0<c<
c03<c<`0000000@0/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`050000001VIVH0IVIV06IV
IP0000001@1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00?o00000000
003oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00Co000000<0000001TI
6@0I6AT01`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<01@2c/k<00`000000c<c<0<c<c00B0<c<c0800000102c/k<00`000000VIVI09VIV@0309VI
V@050000001oOgl0Ogmo07moO`0000001@1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000000000D000000<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool04ol000000`0000006ATI01TI6@0801TI
6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IV
IP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k<0000000@0c<c<00<0
00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00<0i^KV00<0
00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00D0000007moO`1oOgl0
Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`000000
6ATI01TI6@0801TI6@05o`00003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`04o`00
00030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`05@3<c<`00`000000/k>c0;>c/`020;>c
/`800000102IVIT01@000000Ogmo07moO`1oOgl0000000D0IVIV00<0000004a<C01<C4`00P1<C4`0
0`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00T06ATI00?o00000000000000004`000003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01Co000000<0000001TI
6@0I6AT01`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IV
IP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgoo000000<0VIVI00<000000;>c/`2c/k<00P2c/k<0
1@000000c<c<0<c<c03<c<`0000000D0i^KV00?o00000?ooo`3oool04@3oool00ol00000i^KV0>KV
iP030>KViP050000003<c<`0c<c<0<c<c0000000102c/k<01Ol00000VIVI09VIV@2IVIT0000000<0
Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI
6@0I6AT01`0I6AT01Ol00000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool01Ol0000:
01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP02
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`03
0;>c/`030000003<c<`0c<c<00P0c<c<1ol000080<c<c003o`00002c/k<0/k>c00<0/k>c00<00000
09VIV@2IVIT00P2IVIT01_l00000Ogmo07moO`1oOgoo0000000000@0IVIV00<0000004a<C01<C4`0
0P1<C4`00ol00000000003<c<`0403<c<`;o00002P0I6AT00ol0000000000000000B000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool05?l000000`0000006ATI01TI
6@0701TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IV
IP0206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`050000
003<c<`0c<c<0<c<c00000001@3Vi^H00ol00000oooo0?ooo`0A0?ooo`03o`00003Vi^H0i^KV00<0
i^KV00D000000<c<c03<c<`0c<c<000000040;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl0
1@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0701TI6@05o`00003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`04o`0000030000
000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000
002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01P3<c<`2o`0000L0i^KV0_l000070<c<c0030000
002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000D0
IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P0
6ATI00?o00000000000000004P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo01Co000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0303<c<`030000
001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`050000002IVIT0VIVI09VI
V@0000000`2c/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV0080i^KV00?o00000?oo
o`3oool04@3oool00ol00000i^KV0>KViP030>KViP030000003<c<`0c<c<0080c<c<00D000000;>c
/`2c/k<0/k>c0000000309VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT01?l00000oooo0?oo
ool0000c0?ooo`03o`00003oool0oooo00Co000000<0000001TI6@0I6AT0200I6AT00`000000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo
07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<
0<c<c0050<c<c003o`00003Vi^H0i^KV00T0i^KV0_l000060<c<c0030000002c/k<0/k>c00<0/k>c
00D0000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`00P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI00?o000000000000
00004@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01Go0000
00<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<
00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c
/k<00P2c/k<01@000000c<c<0<c<c03<c<`0000000D0i^KV00?o00000?ooo`3oool04@3oool00ol0
0000i^KV0>KViP030>KViP050000003<c<`0c<c<0<c<c?l00000102c/k<01@000000VIVI09VIV@2I
VIT0000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00<0<c<c
00<0000001TI6@0I6AT0200I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
1Ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0
0`1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000
/k>c0;>c/`020;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H0303Vi^H00ol00000
c<c<0<c<c0040<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000
Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000
<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI00?o00000000000000004@0000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01Go000000<0000001TI6@0I6AT0
200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00<0C4a<00Go000006IVIP1VIVH0
IVIV0000000407moO`050000002IVIT0VIVI09VIV@0000000`2c/k<00`000000c<c<0<c<c0020<c<
c0030000003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool04@3oool00ol00000i^KV0>KViP030>KV
iP030000003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@050000001oOgl0
Ogmo07moO`000000101VIVH00ol00000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT01`0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool01Ol0
00000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<
C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c
0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H03P3Vi^H2o`0000D0c<c<
0P0000030;>c/`8000000`2IVIT00ol00000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV
00<0000004a<C01<C4`00P1<C4`00ol00000000003<c<`0403<c<`03o`00000I6AT06ATI00P06ATI
00?o0000000000000000400000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo01Oo00002@0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00<0C4a<00D0
000006IVIP1VIVH0IVIV0000000407moO`050000002IVIT0VIVI09VIV@0000000`2c/k<00ol00000
c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool0403oool00ol00000
i^KV0>KViP030>KViP030000003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000309VI
V@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT01`0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool01Ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102I
VIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H0403V
i^H2o`0000D0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo
00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I
6AT0200I6AT00ol0000000000000000?000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo
00?o00000?ooo`3oool05_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0<c<c
00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2I
VIT0VIVI000000030;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H00P3Vi^H00ol0
0000oooo0?ooo`0A0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00P3<c<`01@00
0000/k>c0;>c/`2c/k<0000000<0VIVI00D0000007moO`1oOgl0Ogmo0000000306IVIP030000001<
C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`06o`0000030000000I6AT06ATI00P06ATI00<0
000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`0
0`3<c<`00ol00000i^KV0>KViP0C0>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<0
0P2c/k<01Ol00000VIVI09VIV@2IVIT0000000@0Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<
C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000000000>0000
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool05ol000000`000000
6ATI01TI6@0701TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000
IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT00ol00000/k>c0;>c/`020;>c
/`050000003<c<`0c<c<0<c<c00000001@3Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0
i^KV00<0i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00D0
000007moO`1oOgl0Ogmoo`00000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
100c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo
0?ooo`06o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl01@000000VIVI09VIV@2IVIT00000
00@0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP0D0>KViP03o`00003<c<`0c<c<
00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00D00000
06IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I
6AT00ol0000000000000000=000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool05ol000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2I
VIT00`000000/k>c0;>c/`020;>c/`050000003<c<`0c<c<0<c<c00000001@3Vi^H00ol00000oooo
0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00<0i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c
0;>c/`2c/k<0000000<0VIVI00<0000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH00000
00@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`06o`0000030000000I6AT06ATI00P06ATI00<0000003<c
<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl0
1@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KV
iP070>KViPOo00001`3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00D0
000009VIV@2IVIT0VIVI0000000407moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000
<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI00?o00000000000000003@0000030?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01Oo000000<0000001TI6@0I6AT0
200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<00P2c/k<01@000000
c<c<0<c<c03<c<`0000000D0i^KV00?o00000?ooo`3oool03`3oool00ol00000i^KV0>KViP030>KV
iP030000003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000409VIV@050000001oOgl0
Ogmo07moO`0000000`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00<0
000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool01ol0
00000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<
C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`03
0000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H01@3Vi^H2o`0000L0oooo00?o00000>KViP3V
i^H01@3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00D0000009VIV@2I
VIT0VIVI0000000407moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`04
03<c<`03o`00000I6AT06ATI00P06ATI00?o0000000000000000300000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo01So000000<0000001TI6@0I6AT01`0I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@00
0000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c002
0<c<c0030000003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool03P3oool00ol00000i^KV0>KViP04
0>KViP030000003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@03o`00001o
Ogl0Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c<0<c<c00@0<c<c
00<0000001TI6@0I6AT01@0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
1ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0
0`1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c
/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`080?oo
o`;o00001P3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT0
1Ol00000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00ol00000<c<c03<c
<`0503<c<`03o`00000I6AT06ATI00L06ATI00?o0000000000000000300000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01So000000<0000001TI6@0I6AT0200I6AT0
0`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH0
1@000000Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<00P2c/k<01@000000c<c<0<c<
c03<c<co000000H0i^KV00?o00000?ooo`3oool03@3oool00ol00000i^KV0>KViP040>KViP030000
003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@030000001oOgl0Ogmo0080
Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00<0<c<c00?o000001TI
6@0I6AT01@0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool02?l000000`00
00006ATI01TI6@0801TI6@03o`00000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`01@00
0000IVIV06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000003<
c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0:0?ooo`03o`00003V
i^H0i^KV00@0i^KV00?o00000<c<c03<c<`00P3<c<`01_l00000/k>c0;>c/`2c/k?o0000000000<0
VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP03o`00001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<0100c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000/000000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Ho`0000030000000I6AT06ATI00P0
6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080
IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@030000002c/k<0/k>c0080/k>c00?o00000<c<
c03<c<`00P3<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0oooo00`0oooo00?o00000>KV
iP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT0
0`000000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c
<`0403<c<`030000000I6AT06ATI00@06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo00So000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0303<c<`030000001<
C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`050000002IVIT0VIVI09VIV@00
0000102c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3o
ool02`3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c
/k<0/k>c0000000309VIV@050000001oOgl0Ogmo07moO`0000001@1VIVH01@000000C4a<04a<C01<
C4`0000000H0<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000000000;000000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool06Ol000000`0000006ATI01TI6@08
01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP02
06IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<
c<`0c<c<0080c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0;0?ooo`03o`00003V
i^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`05o`00002I
VIT0VIVI09VIV@000000101oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c
<c<00`0c<c<00`0000006ATI01TI6@0401TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`09o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000
C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl01@000000VIVI09VIV@2IVIT0
000000<0/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0
oooo00`0oooo0_l000050>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000
000309VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C0030000
000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000000000:000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool06Ol000000`00003o000001TI
6@0801TI6@0300000?l00000<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IV
IP1VIVH0000000@0Ogmo00D0000009VIV@2IVIT0VIVIo`0000040;>c/`030000003<c<`0c<c<0080
c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0:0?ooo`03o`00003Vi^H0i^KV00@0
i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VI
V@000000101oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0301TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`09
o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV00Go000007moO`1oOgl0Ogmo0000000309VIV@050000002c
/k<0/k>c0;>c/`000000103<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo00h0oooo
00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`00
00000`2IVIT01_l00000Ogmo07moO`1oOgoo0000000000<0IVIV00<0000004a<C01<C4`00P1<C4`0
0ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI00?o00000000000000002@000003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01[o000000<0000001TI
6@0I6AT0200I6AT00`000000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00D0000006IV
IP1VIVH0IVIV0000000407moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<
c0020<c<c003o`00003Vi^H0i^KV00D0i^KV0_l0000:0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<0
00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@000000
101oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<0100c<c<00`000000
6ATI01TI6@0301TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`09o`000003
0000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C003
0000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c
0;>c/`000000103<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo00h0oooo00?o0000
0>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000102I
VIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c
03<c<`0303<c<`03o`00000I6AT06ATI00P06ATI00?o00000000000000002@0000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01[o000000<0000001TI6@0I6AT0200I
6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00@0C4a<00D0000006IVIP1VIVH0IVIV
0000000407moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0020<c<c003
0000003Vi^H0i^KV00H0i^KV00?o00000?ooo`3oool01P3oool00ol00000i^KV0>KViP050>KViP03
0000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT00000
00@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT00`0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool02_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<
C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT0
1@000000/k>c0;>c/`2c/k<0000000<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?oo
o`0?0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c
/`2c/k<0000000<0VIVI00<0000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH0000000@0
C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000P0
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Ko`0000030000
000I6AT06ATI00P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C0050000
001VIVH0IVIV06IVIP000000101oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<
c03<c<`00`3<c<`00`000000i^KV0>KViP060>KViP;o00001@3oool00ol00000i^KV0>KViP060>KV
iP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0
000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT00P0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool02_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2I
VIT01@000000/k>c0;>c/`2c/k<0000000@0c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo
0?ooo`0?0?ooo`;o0000103Vi^H00ol00000c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c/`00
0000102IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00P06ATI00?o0000000000000000200000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01_o000000<0000001TI6@0I
6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1V
IVH0IVIV0000000407moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c003
0<c<c0030000003Vi^H0i^KV00L0i^KV0_l000000`3ooooo0000o`0000090>KViP030000003<c<`0
c<c<00<0c<c<00?o00000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0
000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT00P0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool02ol0
00000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<
C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT01@000000/k>c
0;>c/`2c/k<0000000<0c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0A0?ooo`03
o`00003Vi^H0i^KV0080i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<00000
00<0VIVI00<0000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<00000
03<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000L000000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Ko`0000030000000I6AT06ATI
00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV
06IVIP000000101oOgl00`000000VIVI09VIV@0209VIV@05o`00002c/k<0/k>c0;>c/`0000001@3<
c<`00`000000i^KV0>KViP090>KViP03o`00003Vi^H0i^KV00T0i^KV00<000000<c<c03<c<`00`3<
c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV
06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI
01TI6@0201TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0;o`0000030000
000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00204a<C0050000
001VIVH0IVIV06IVIP0000000`1oOgl00`000000VIVI09VIV@0209VIV@05o`00002c/k<0/k>c0;>c
/`0000000`3<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo0140oooo00?o00000>KV
iP3Vi^H00`3Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00D0000009VIV@2IVIT0VIVI0000
000407moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0303<c<`03o`00
000I6AT06ATI00P06ATI00?o00000000000000001`0000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`03o`00003oool0oooo01co000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c
<`0403<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`050000
002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV01@0
i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VI
V@0000000`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c
<`0c<c<0100c<c<00`0000006ATI01TI6@0201TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol0
0000oooo0?ooo`0<o`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`00
0000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo00000003
09VIV@050000002c/k<0/k>c0;>c/`000000103<c<`00ol00000i^KV0>KViP020>KViP03o`00003o
ool0oooo0180oooo00?o00000>KViP3Vi^H00P3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c
/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP00
0000101<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI00?o000000000000
00001P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01go0000
00<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c
/k<00P2c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV01<0i^KV00<000000<c<c03<
c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00D0000007moO`1o
Ogl0Ogmo0000000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<01000
00006ATI01TI6@0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool03?l00000
0`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`0
0`000000IVIV06IVIP0206IVIP040000001oOgl0Ogmo000000@0VIVI00D000000;>c/`2c/k<0/k>c
000000030<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04@3oool00ol00000i^KV
0>KViP030>KViP05o`00003<c<`0c<c<0<c<c00000000`2c/k<00`000000VIVI09VIV@0209VIV@05
o`00001oOgl0Ogmo07moO`0000000`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c
00<0<c<c00?o000001TI6@0I6AT0200I6AT00ol00000000000000006000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool07_l0000:01TI6@03o`00000c<c<0<c<c00@0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07mo
Ool00000102IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<0P00000C0>KV
iP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VI
V@050000001oOgl0Ogmo07moOol00000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00@0000001TI6@0I6AT06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo00go000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0403<c<`030000001<
C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01Ol00000Ogmo07moO`1oOgl0000000<0VIVI
00D000000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3o
ool04@3oool00ol00000i^KV0>KViP020>KViP03o`00003<c<`0c<c<0080c<c<00H000000;>c/`2c
/k<0/k>co`000000000209VIV@030000001oOgl0Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV0000
000404a<C003o`0000000000<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000000
0005000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool07Ol00000
0`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H0403Vi^H0
0`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT0
1@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0403<c<`040000000I6AT06ATI01TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo
0?ooo`0=o`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00304a<C005o`00001VIVH0IVIV06IVIP0000000`1oOgl01@000000VIVI09VIV@2IVIT00000
00<0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP020>KViP03o`00003oool0oooo
0140oooo00?o00000>KViP3Vi^H00P3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c
0080/k>c00@0000009VIV@2IVIT00000101oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0
000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`0000000000000000D000000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0No`0000030000000I6AT0
6ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0
IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0
/k>c0080/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP0>0>KViP030000003<c<`0
c<c<00@0c<c<00?o00000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0
Ogmo07moO`0000001@1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00@0
000001TI6@0I6AT06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00ko0000
00<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<
00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00D000000;>c/`2c
/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool0403oool00ol0
0000i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c/k<01000
0000VIVI09VIV@00000407moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c
<`0303<c<`03o`00000I6AT06ATI00P06ATI00?o0000000000000000100000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01oo000000<0000001TI6@0I6AT0200I6AT0
0`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH0
0`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIVOl000001@2c/k<00`000000c<c<0<c<
c0040<c<c0030000003Vi^H0i^KV00`0i^KV00<00000o`00003<c<`01@3<c<`00`000000/k>c0;>c
/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<0100000006ATI01TI
6@0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool03_l000000`00003o0000
01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV
06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k<00000
00@0c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV
00<0i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00D00000
07moO`1oOgl0Ogmo0000000406IVIP03o`00001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c
<c<00ol000006ATI01TI6@0701TI6@03o`0000000000000000@000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Oo`0000030000000I6AT06ATI00P06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<00000
07moO`1oOgl00P1oOgl01Ol00000VIVI09VIV@2IVIT0000000D0/k>c00<000000<c<c03<c<`01@3<
c<`00ol0000000000>KViP0:0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<00P2c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1V
IVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00@0000001TI6@0I6AT06ATI
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00oo000000<0000001TI6@0I6AT0
1`0I6AT00`000000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00Co00000;>c/`2c/k<00000103<c<`00ol0
0000i^KV0>KViP030>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H00`3Vi^H00ol0
0000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1o
Ogl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I
6AT06ATI00L06ATI00?o0000000000000000100000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo023o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`04
03<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1o
Ogl0000000@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0060<c<c0800000203V
i^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2I
VIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0403<c<`040000000I6AT06ATI01TI6@<0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`0@o`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0
0`0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0
Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/`000000103<c<`00ol00000i^KV0>KViP030>KV
iP03o`00003oool0oooo00l0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<
c0050000002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207moO`050000001VIVH0
IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00P06ATI00?o
00000000000000000`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0
oooo027o000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0
VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0070<c<c0<000000P3Vi^H3
000000T0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0
Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT00`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo013o000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0
C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00D0
00000;>c/`2c/k<0/k>c000000030<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0
3`3oool00ol00000i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0
/k>c0000000309VIV@050000001oOgl0Ogmo07moOol00000101VIVH00`000000C4a<04a<C00204a<
C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT00ol000000000000000030000
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool08_l0000:01TI6@03
o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP03
o`00001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT2000000@0/k>c0P00000:0<c<c080
0000303<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c
<c<0100c<c<00`0000006ATI01TI6@030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3o
ool04Ol000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<
C4`00P1<C4`00`000000IVIV06IVIP0206IVIP05o`00001oOgl0Ogmo07moO`0000000`2IVIT00`00
0000/k>c0;>c/`020;>c/`040000003<c<`0c<c<0<c<c0;o00001@3Vi^H00ol00000oooo0?ooo`0>
0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c
/k<0000000<0VIVI00?o000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<
00<0000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000800000
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Qo`0000030000000I
6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C005o`00001V
IVH0IVIV06IVIP0000001@1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00@0/k>c
00<000000<c<c03<c<`05@3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@030?ooo`03o`00003oool0oooo0340oooo
00?o00000?ooo`3oool04Ol000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c
00<0000004a<C01<C4`00`1<C4`01Ol00000IVIV06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2I
VIT0VIVI000000040;>c/`05o`00003<c<`0c<c<0<c<c?l000001P3Vi^H00ol00000oooo0?ooo`0=
0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c
/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo0000000306IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000800000
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Ro`0000030000000I
6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001V
IVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c
/k<0/k>c00@0/k>c00<000000<c<c03<c<`04`3<c<`00`000000/k>c0;>c/`040;>c/`030000002I
VIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<
C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool04_l000000`0000006ATI01TI6@0701TI6@030000000c
<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`030000003<c<`0c<c<0080c<c<
00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0<0?ooo`03o`00003Vi^H0i^KV00<0i^KV
00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@00
00000`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c
<c<0100c<c<00ol000006ATI01TI6@0801TI6@04o`00000000000000000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool08_l000000`0000006ATI01TI6@0801TI6@03
0000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`03
0000003<c<`0c<c<0180c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0209VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C003
0000000c<c<0<c<c00@0<c<c00<0000001TI6@3oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03
o`00003oool0oooo01;o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`03
0000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000507moO`040000002IVIT0VIVI
000000@0/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0
oooo00X0oooo00?o00000>KViP3Vi^H01@3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0
/k>c0;>c/ol00000102IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00<0000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI00Co0000000000000000
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0So`0000030000
000I6AT06ATI00P06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000
002c/k<0/k>c00@0/k>c0P00000A0<c<c003o`00002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0
0P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0
0`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT0oooo0080oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`0Do`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<
04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl01Ol00000VIVI09VIV@2IVIT00000
00<0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP040>KViP?o00002@3oool00ol0
0000i^KV0>KViP050>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c00000004
09VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C0030000000c
<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol000000000000000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02?o000000<0000001TI6@0I6AT02@0I6AT0
0ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<2
000000h0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0
Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@3oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo01?o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0
C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01Ol00000Ogmo07moO`1oOgl0000000@0VIVI00D0
00000;>c/`2c/k<0/k>c000000050<c<c003o`00003Vi^H0i^KV00H0i^KV1?l000020?ooo`?o0000
203Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT01@000000
Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c
<`03o`00000I6AT06ATI00P06ATI00?o00000000000000000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`0To`0000030000000I6AT06ATI00T06ATI00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00H0/k>c0P00000;0<c<c003
0000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`03
0000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03
0000000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0Do`000003
0000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C003
0000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@040000002c/k<0/k>c
0;>c/`800000103<c<`00ol00000i^KV0>KViP090>KViP;o00002P3Vi^H00ol00000c<c<0<c<c003
0<c<c0030000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`030000001V
IVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I
6AT06ATI00P06ATI00?o00000000003oool00P3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0Vo`0000/06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C003
04a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@03
09VIV@0300000?l00000/k>c00L0/k>c00<000000<c<c03<c<`01`3<c<`00ol00000/k>c0;>c/`06
0;>c/`0300000?l00000VIVI00@0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI0?ooo`02
0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool05Ol000000`0000006ATI01TI6@08
01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP02
06IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c0;>c/`020;>c/`030000003<
c<`0c<c<0080c<c<0_l0000E0>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c
/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol000000000
0?ooo`020?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02Go000000<0
000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0
000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0207moO`030000002IVIT0VIVI00@0VIVI00<0
00000;>c/`2c/k<01P2c/k<00ol00000000000000006000000T0/k>c00<0000009VIV@2IVIT0102I
VIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`0Go`0000T06ATI00?o000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00204a<C0030000001VIVH0IVIV00<0IVIV00D0000007moO`1oOgl0Ogmoo`00000309VIV@030000
002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP0B0>KViP03o`00
003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0
Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0
<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000?ooo`020?ooo`03o`00003oool0oooo01T0
oooo000J0?ooo`03o`00003oool0oooo02Ko000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<05`2c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<
04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@3oool00P3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo01Ko000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH010000000Ogmo
07moO`00000409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000
i^KV0>KViP0@0>KViP03o`00003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000
VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<
C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT00ol0000000000?ooo`020?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02Ko000000<0000001TI6@0I
6AT02P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1V
IVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c
/k<05@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1V
IVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00D000000?ooo`3o
ool0ooooo`00000c0?ooo`03o`00003oool0oooo01Oo000000<0000001TI6@0I6AT01`0I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH01@00
0000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c004
0<c<c003o`00003Vi^H0i^KV00l0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`02
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@08
01TI6@05o`00003oool0oooo0?ooool000006`3oool001X0oooo00?o00000?ooo`3oool09ol00000
0`0000006ATI01TI6@0901TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00?o00000000002IVIT0102IVIT0
0ol0000000000000000D0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl0
0`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<0
1@000000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool05ol000000`0000006ATI01TI
6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0206IVIP040000001oOgl0Ogmo07moO`8000000`2IVIT2000000<0/k>c0P0000050<c<c0?o0000
3@3Vi^H2o`0000H0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000
000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT01Ol00000oooo0?ooo`3ooooo000001/0
oooo000J0?ooo`03o`00003oool0oooo02Wo00002P0I6AT00`000000<c<c03<c<`0503<c<`030000
001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0507moO`030000
002IVIT0VIVI00D0VIVI0P00000A0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0
0`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0
1@0c<c<01@000000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool05ol000000`000000
6ATI01TI6@0901TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`0101<C4`01@000000
IVIV06IVIP1VIVH0000000D0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c
/`030000003<c<`0c<c<00D0c<c<0ol000090>KViP03o`00003<c<`0c<c<00H0c<c<00<000000;>c
/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI
6@0I6AT0200I6AT01Ol00000oooo0?ooo`3ooooo000001/0oooo000J0?ooo`03o`00003oool0oooo
02So000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00@0C4a<00<0000006IVIP1VIVH00P1VIVH2000000H0Ogmo00<0000009VIV@2IVIT01P2IVIT00`00
0000/k>c0;>c/`0<0;>c/`8000001`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV
00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`050000003oool0oooo
0?ooool00000<`3oool00ol00000oooo0?ooo`0Ho`0000030000000I6AT06ATI00T06ATI00<00000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00404a<C0050000001VIVH0IVIV06IVIP0000001@1o
Ogl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c0P0000080<c<c0?o00000`3V
i^H3o`0000P0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001o
Ogl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c
<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I6AT01?l00000oooo0?ooool0000K0?ooo`006P3o
ool00ol00000oooo0?ooo`0Yo`0000030000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01@0c
<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101o
Ogl00ol00000VIVI09VIV@0609VIV@0400000?l000000000000000P0/k>c0P00000909VIV@030000
001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000
000c<c<0<c<c00D0<c<c00D000000?ooo`3oool0ooooo`00000c0?ooo`03o`00003oool0oooo01Wo
000000<00000o`00000I6AT02@0I6AT00ol00000<c<c03<c<`0303<c<`0300000?l00000C4a<00@0
C4a<00H0000006IVIP1VIVH0IVIV00000?l0000407moO`030000002IVIT0VIVI0080VIVI0P000004
0;>c/`030000003<c<`0c<c<00P0c<c<0ol0000;0<c<c0030000002c/k<0/k>c00<0/k>c00<00000
09VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<00000
04a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00P06ATI0`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Yo`0000030000000I6AT06ATI
00T06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0909VIV@<000000`2c/k<20000
00/0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<
00<0C4a<00<0000003<c<`0c<c<01@0c<c<01@000000oooo0?ooo`3ooooo000003<0oooo00?o0000
0?ooo`3oool06_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`0101<C4`00ol00000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000001P2I
VIT00`000000/k>c0;>c/`020;>c/`03o`0000000000c<c<01D0c<c<00<000000;>c/`2c/k<00`2c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1V
IVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0200I
6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02[o000000<00000
01TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`800000302IVIT3000000`0VIVI00<00000
07moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<00<00000
03<c<`0c<c<01@0c<c<01@000000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool06ol0
00000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<
C4`00`000000IVIV06IVIP0306IVIP040000001oOgl0Ogmo07moO`8000001@2IVIT00`000000/k>c
0;>c/`030;>c/`8000004`3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI0080VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0801TI6@<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0:ol000000`0000006ATI01TI6@0901TI6@030000000c
<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001o
Ogl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0602IVIT00`000000Ogmo07moO`0407moO`030000001V
IVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`040000003o
ool0ooooo`0003<0oooo00?o00000?ooo`3oool06ol000000`0000006ATI01TI6@0901TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000
003<c<`0c<c<00l0c<c<00?o00000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000
000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT30?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`03o`00003oool0oooo02go00002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`030000002I
VIT0VIVI01H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0306IVIP030000001<
C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<010000000oooo0?ooool0000c0?ooo`03o`00
003oool0oooo01co000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`030000
001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0307moO`030000
002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<0102c/k<00ol0000000000<c<c00<0<c<c0800000
1`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0
1`0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02co000000<0
000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0603<c<`03o`00001<C4`0C4a<00@0C4a<00?o
000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`03o`0000000000VIVI01@0VIVI00<0
000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01P0c<c<010000000oooo0?ooool0000c0?ooo`03o`00003oool0oooo01ko0000
2P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0307moO`03o`00002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0
1@2c/k<3000000T0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0309VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000
000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT30?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`03o`00003oool0oooo02go000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07mo
O`0607moO`030000002IVIT0VIVI0140VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IV
IP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<010000000oooo0?oo
ool0000c0?ooo`03o`00003oool0oooo01go000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00<0VIVI0P0000080;>c/`T000002@2c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<
04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT30?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02go000000<0000001TI6@0I6AT02P0I
6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01@1V
IVH00`000000Ogmo07moO`0607moO`<000003`2IVIT00`000000Ogmo07moO`0707moO`030000001V
IVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`040000003o
ool0ooooo`0003<0oooo00?o00000?ooo`3oool07_l000000`0000006ATI01TI6@0901TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`0G0;>c/`030000
002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000
001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0601TI6@<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0;_l000000`0000006ATI01TI
6@0:01TI6@03o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`2000000H0IVIV00<0
0000o`0000000000201oOgl01000003o000000000000000609VIV@D000002@1oOgl00`000000IVIV
06IVIP0506IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<010000000oooo
0?ooool0000c0?ooo`03o`00003oool0oooo01oo000000<0000001TI6@0I6AT02@0I6AT00`000000
<c<c03<c<`0403<c<`0300000?l00000C4a<00<0C4a<0P00000406IVIP03o`0000000000Ogmo00<0
Ogmo00<00000o`00002IVIT0102IVIT00`00003o00000000000E0;>c/`03o`00002IVIT0VIVI00@0
VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool0<?l0000;01TI6@030000000c<c<0<c<c00H0<c<c
00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00T0Ogmo
1P00000>07moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c
03<c<`0603<c<`040000003oool0ooooo`0003<0oooo00?o00000?ooo`3oool07ol000000`000000
6ATI01TI6@0901TI6@03o`0000000000<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000
/k>c0;>c/`0@0;>c/`8000001`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00H0
6ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0`o`0000030000
000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000
001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl06`1oOgl00ol00000IVIV06IVIP0506IVIP030000
001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<010000000oooo0?ooool0000c0?ooo`03
o`00003oool0oooo023o00000P00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0306IVIP800000101oOgl00`000000VIVI09VIV@0509VIV@<0
00003@2c/k<2000000P0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP03
0000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0601TI6@<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0<Ol000000`0000006ATI
01TI6@0901TI6@0300000?l00000<c<c00H0<c<c00?o000004a<C01<C4`01@1<C4`2000000L0IVIV
0P00000J07moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c
03<c<`0603<c<`040000003oool0ooooo`0003<0oooo00?o00000?ooo`3oool08_l000000`000000
6ATI01TI6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000
IVIV06IVIP0406IVIP030000001oOgl0Ogmo0080Ogmo00<00000o`00000000001`2IVIT200000003
o`0000000000000000D0/k>c0`00000909VIV@0300000?l00000Ogmo00@0Ogmo00<0000006IVIP1V
IVH0101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I
6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo037o0000
00<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<
00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0F07moO`030000001VIVH0IVIV00L0IVIV
00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`040000003oool0ooooo`0003<0
oooo00?o00000?ooo`3oool08_l000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00D0
<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0
Ogmo00<0000009VIV@2IVIT02@2IVIT5000000`0VIVI00<0000007moO`1oOgl0101oOgl00`000000
IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
<_l000000`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0
1P1<C4`00`000000IVIV06IVIP0606IVIP8000005@1oOgl00`000000IVIV06IVIP0706IVIP030000
001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01P0c<c<010000000oooo0?ooool0000c0?ooo`03
o`00003oool0oooo02?o000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`03
0000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH2000000D0Ogmo0`00000H09VIV@03
0000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00304a<C003
0000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0
oooo000J0?ooo`03o`00003oool0oooo03?o000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c
03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01`1VIVH200000180Ogmo
00?o000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c
00D000000?ooo`3oool0ooooo`00000c0?ooo`03o`00003oool0oooo02Co000000<0000001TI6@0I
6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1V
IVH01@1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI01@0VIVI00<0000007moO`1o
Ogl01@1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo
00?o00000?ooo`3oool0=?l0000=01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0
1P1<C4`2000000T0IVIV0`00000=07moO`8000002P1VIVH00`000000C4a<04a<C00604a<C0030000
000c<c<0<c<c00H0<c<c00D000000?ooo`3oool0ooooo`00000c0?ooo`03o`00003oool0oooo02Ko
00002`0I6AT2000000H0<c<c00<00000o`00001<C4`0101<C4`00`00003o00000000000506IVIP80
00001P1oOgl00ol0000000000000000A09VIV@800000201oOgl00`000000IVIV06IVIP0406IVIP03
0000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0<ol000000`0000006ATI
01TI6@0;01TI6@03o`00000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV
06IVIP0906IVIP@000001P1oOgl3000000`0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c
03<c<`0603<c<`050000003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`0Vo`000003
0000000I6AT06ATI00X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C003
0000001VIVH0IVIV00@0IVIV0P00000707moO`<000003@2IVIT00`000000Ogmo07moO`0707moO`03
0000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`03
0000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0do`0000030000000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<
04a<C00704a<C0030000001VIVH0IVIV00`0IVIV1P00000>06IVIP030000001<C4`0C4a<00H0C4a<
00<0000003<c<`0c<c<01`0c<c<01@000000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3o
ool09ol000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<
C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00L0Ogmo3@00000907moO`03
0000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`03
0000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0eo`0000030000000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<
04a<C00704a<C0030000001VIVH0IVIV01l0IVIV00<0000004a<C01<C4`01P1<C4`00ol00000<c<c
03<c<`0703<c<`050000003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`0Xo`000003
0000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C003
0000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0701oOgl00`000000IVIV06IVIP0506IVIP03
0000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0=_l000000`0000006ATI
01TI6@0;01TI6@030000000c<c<0<c<c00L0<c<c0P00000804a<C003o`0000000000IVIV01`0IVIV
00<00000o`00001<C4`0201<C4`00`000000<c<c03<c<`0703<c<`050000003oool0oooo0?ooool0
0000<`3oool00ol00000oooo0?ooo`0Yo`0000`06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000
000004a<C00504a<C003o`0000000000000000H0IVIV00<00000o`00000000006P1oOgl00`000000
IVIV06IVIP0606IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
=ol000000`0000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`0
1`1<C4`2000001X0IVIV00<0000004a<C01<C4`02@1<C4`00`000000<c<c03<c<`0703<c<`050000
003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`0Yo`0000030000000I6AT06ATI00X0
6ATI00?o00000000000c<c<01P0c<c<2000000L0C4a<0P00000706IVIP8000005`1oOgl00`000000
IVIV06IVIP0706IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
>?l000000`0000006ATI01TI6@0;01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`0
201<C4`2000001L0IVIV00<0000004a<C01<C4`02@1<C4`00`000000<c<c03<c<`0703<c<`030000
000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0Zo`0000030000
000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C0030000
001VIVH0IVIV00H0IVIV0`00000B07moO`8000002@1VIVH00`000000C4a<04a<C00504a<C003o`00
000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`03o`00003oool0oooo03Wo000000<0000001TI6@0I6AT02`0I6AT00`000000<c<c03<c
<`0803<c<`030000001<C4`0C4a<00T0C4a<0`00000B06IVIP800000301<C4`00`000000<c<c03<c
<`0703<c<`030000000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?oo
o`0[o`00000300000?l000006ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<00ol00000000004a<
C00604a<C0030000001VIVH0IVIV00P0IVIV1000000:07moO`80000000?o00000000001VIVH02@1V
IVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT01P0I
6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo03_o00003@0I6AT0
0ol00000<c<c03<c<`0803<c<`03o`0000000000C4a<00/0C4a<1000000<06IVIP8000003P1<C4`0
0`000000<c<c03<c<`0703<c<`030000000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool0
0ol00000oooo0?ooo`0/o`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01`0c<c<0
0`000000C4a<04a<C00504a<C003o`0000000000IVIV00/0IVIV2P00000=06IVIP030000001<C4`0
C4a<00L0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0>_l000000`0000006ATI01TI6@0<01TI
6@030000000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`03@1<C4`3000000L0IVIV0P00000?04a<
C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@3oool00P3oool00ol00000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo02go000000<0000001TI6@0I6AT02`0I6AT00`000000<c<c03<c<`0703<c
<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH07`1VIVH00`000000C4a<04a<C00704a<
C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo03_o000000<0000001TI6@0I6AT0300I6AT00`000000
<c<c03<c<`0903<c<`030000001<C4`0C4a<00l0C4a<1`00000A04a<C0030000000c<c<0<c<c00P0
<c<c00<0000001TI6@3oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02ko
000000<0000001TI6@0I6AT02`0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00H0
C4a<0`00000M06IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<01P0c<c<00`000000
6ATI01TI6@0701TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
??l000000`0000006ATI01TI6@0<01TI6@030000000c<c<0<c<c00T0<c<c0P00000U04a<C0800000
2`0c<c<00`0000006ATI0?ooo`020?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
;ol00002000000`06ATI0P00000803<c<`0300000?l00000000000P0C4a<00<00000o`0000000000
601VIVH2000000X0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0701TI6@<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0??l000000`0000006ATI01TI
6@0=01TI6@03o`0000000000<c<c00X0<c<c00<0000004a<C01<C4`08@1<C4`00`000000<c<c03<c
<`0;03<c<`030000000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?oo
o`0ao`0000030000000I6AT06ATI00/06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<
C00804a<C0800000501VIVH2000000`0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI
6@0701TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0?Ol00002
000000l06ATI00<0000003<c<`0c<c<02@0c<c<3000001l0C4a<00<0000003<c<`0c<c<02`0c<c<0
0`0000006ATI01TI6@030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0<_l00000
0`0000006ATI01TI6@0;01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`02@1<C4`3
00000100IVIV00<0000004a<C01<C4`02`1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT0
6ATI00P06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0oo`00
00030000000I6AT06ATI00d06ATI00<0000003<c<`0c<c<02`0c<c<00`000000C4a<04a<C00K04a<
C003o`00000c<c<0<c<c00/0<c<c00@0000001TI6@0I6AT06ATI0`3oool00ol00000oooo0?ooo`0a
0?ooo`03o`00003oool0oooo03?o000000<0000001TI6@0I6AT02`0I6AT00`00003o000003<c<`08
03<c<`0300000?l00000C4a<00/0C4a<1@0000000ol00000000000000008000000d0C4a<00<00000
03<c<`0c<c<0200c<c<00ol000006ATI01TI6@0801TI6@<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool0?ol000000`0000006ATI01TI6@0>01TI6@03o`00000c<c<0<c<c
00/0<c<c00?o00000000001<C4`06@1<C4`2000000d0<c<c00@0000001TI6@0I6AT06ATI0`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03Co000000<0000001TI6@0I6AT0300I6AT0
0`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<02D0C4a<00<0000003<c<`0c<c<02@0c<c<0
0`0000006ATI01TI6@0801TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?oo
o`3oool0@?l000000`0000006ATI01TI6@0>01TI6@030000000c<c<0<c<c00`0<c<c0P00000F04a<
C08000003`0c<c<0100000006ATI01TI6@0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0=Ol000000`0000006ATI01TI6@0<01TI6@030000000c<c<0<c<c00P0<c<c0`00000S
04a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0200I6AT30?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo047o000000<0000001TI6@0I6AT03P0I6AT00`00
0000<c<c03<c<`0=03<c<`<000004P1<C4`00ol00000<c<c03<c<`0>03<c<`030000000I6AT06ATI
00806ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03Ko000000<0000001TI
6@0I6AT0300I6AT2000000/0<c<c0`00000O04a<C003o`00000c<c<0<c<c00X0<c<c00<0000001TI
6@0I6AT02@0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo04?o
0000400I6AT200000100<c<c0`00000=04a<C08000004@0c<c<00`0000006ATI01TI6@0201TI6@<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0ho`0000030000000I6AT06ATI00`0
6ATI00<0000003<c<`0c<c<02`0c<c<2000001/0C4a<0P00000=03<c<`030000000I6AT06ATI00T0
6ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`13o`0000030000
000I6AT06ATI00l06ATI00<0000003<c<`0c<c<0400c<c<=000001<0<c<c00<0000001TI6@0I6AT0
0P0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0>Ol000000`0000006ATI
01TI6@0<01TI6@03o`0000000000<c<c00`0<c<c0`00000G04a<C0030000000c<c<0<c<c00d0<c<c
00<0000001TI6@0I6AT02@0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo04Co000000<0000001TI6@0I6AT03`0I6AT00`000000<c<c03<c<`0^03<c<`030000000I
6AT06ATI00<06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03[o000000<0
000001TI6@0I6AT03@0I6AT2000000h0<c<c0`00000A04a<C0<000003`0c<c<00`0000006ATI01TI
6@0:01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0AOl00000
0`0000006ATI01TI6@0?01TI6@030000000c<c<0<c<c02`0<c<c00?o000001TI6@0I6AT0100I6AT3
0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0>_l000000`0000006ATI01TI6@0?
01TI6@030000000c<c<0<c<c00h0<c<c1P00000804a<C0<000004@0c<c<00`0000006ATI01TI6@0;
01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0Aol0000A01TI
6@03o`0000000000<c<c02/0<c<c00<0000001TI6@0I6AT0100I6AT30?ooo`03o`00003oool0oooo
0340oooo00?o00000?ooo`3oool0>ol00002000001006ATI00?o00000000000c<c<04`0c<c<00ol0
000000000000000300000003o`0000000000<c<c0180<c<c00<0000001TI6@0I6AT0300I6AT30?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo04Oo000000<0000001TI6@0I
6AT0400I6AT2000002T0<c<c00<0000001TI6@0I6AT01@0I6AT30?ooo`03o`00003oool0oooo0340
oooo00?o00000?ooo`3oool0?Ol00002000001006ATI0P00000/03<c<`030000000I6AT06ATI00d0
6ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`18o`0000030000
000I6AT06ATI01406ATI0P00000V03<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo03oo000000<0000001TI6@0I6AT03`0I6AT2000002T0<c<c
00<0000001TI6@0I6AT03P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo04[o0000500I6AT2000002<0<c<c00?o000001TI6@0I6AT01`0I6AT30?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool0@?l000000`0000006ATI01TI6@0@01TI6@0300000?l0
0000000002@0<c<c0P00000A01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool0B_l000000`0000006ATI01TI6@0C01TI6@8000007`0c<c<2000000X06ATI0`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo04;o000000<0000001TI6@0I6AT04@0I6AT0
0`000000<c<c03<c<`0P03<c<`030000000I6AT06ATI01406ATI0`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`1;o`0000030000000I6AT06ATI01@06ATI0P00000L03<c
<`030000000I6AT06ATI00X06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
04?o000000<0000001TI6@0I6AT04@0I6AT3000001h0<c<c00<0000001TI6@0I6AT04P0I6AT30?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo04co000000<0000001TI6@0I
6AT05@0I6AT00`000000<c<c03<c<`0H03<c<`03o`00000I6AT06ATI00/06ATI0`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo04Co000000<0000001TI6@0I6AT04`0I6AT3000001T0
<c<c0P00000E01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
C_l000000`0000006ATI01TI6@0D01TI6@0400000?l000000000000001@0<c<c0P00000>01TI6@<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`15o`00008000005P0I6AT01000003o
000000000000000A03<c<`<0000000?o000001TI6@0I6AT05@0I6AT01?l00000oooo0?ooool0000K
0?ooo`006P3oool00ol00000oooo0?ooo`1?o`0000030000000I6AT06ATI01L06ATI0`00000=03<c
<`@00000400I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0Aol000000`00
00006ATI01TI6@0G01TI6@@000002@0c<c<4000001/06ATI00Co00000?ooo`3ooooo00006`3oool0
01X0oooo00?o00000?ooo`3oool0D?l00002000001X06ATI1`00000303<c<`<00000500I6AT30?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0B?l00003000001X06ATI2@00000N01TI
6@05o`00003oool0oooo0?ooool000006`3oool001X0oooo00?o00000?ooo`3oool0D_l000000`00
00006ATI01TI6@0N01TI6@<000005`0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool0Bol000000`0000006ATI01TI6@0m01TI6@03o`0000000000oooo0080oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool0D_l000000`0000006ATI01TI6@0h01TI6@<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1=o`0000030000000I6AT06ATI03/0
6ATI00?o00000000003oool00P3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`1Co`0000800000>00I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
C_l000000`0000006ATI01TI6@0i01TI6@03o`0000000000000000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0EOl000000`0000006ATI01TI6@0e01TI6@<0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1?o`0000800000>00I6AT01?l0000000000000
000000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo05Ko000000<0
0000o`00000I6AT0=00I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0DOl0
0002000003D06ATI00?o00000000000000000P0000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo05So000000<0000001TI6@0I6AT0<P0I6AT30?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0Dol00002000003<06ATI00?o00000000000000000P000003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo05Wo000000<0000001TI
6@0I6AT0<@0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0EOl000020000
03006ATI00?o00000000000000000`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo05[o000000<0000001TI6@0I6AT0<00I6AT30?ooo`03o`00003oool0oooo0340
oooo00?o00000?ooo`3oool0Eol00002000002`06ATI0_l00006000000<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool0G?l0000a01TI6@<0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`1Io`0000030000000I6AT06ATI02P06ATI00?o0000000000000000
1P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo0900oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0oooo01T0oooo000J
0?oooiCo0000<`3ooonDo`0001/0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo00250?ooo`;o0000a@3oool2o`000480oooo00220?ooo`?o000000<0ooooo`00
003oool0`@3oool3o`0000030?ooool00000oooo0440oooo00200?ooo`;o00000`3oool00`2]_>Co
0000o`00002o0?ooo`;o00000P3oool20:Vmj0;o0000@@3oool007d0oooo0ol000030?ooo`<0[KcT
00?o00000?ooool00000^`3oool3o`0000030?ooo`2Y_NP0ZKgX00<0ZKgX00?o00000?ooool00000
@03oool007X0oooo0ol000040?ooo`80[kcS0`2]_>@00ol00000ooooo`00002h0?ooo`?o00000`3o
ool60:Vmj003o`00003ooooo00000400oooo001h0?ooo`;o0000103oool00`2a^n40[kcS0:nlh`03
0:nlh`80[KcT00Co00000:jli03ooooo0000]@3oool2o`0000<0oooo2@2Y_NP01?l00000ZKgX0?oo
ool0000o0?ooo`00M@3oool3o`0000D0oooo0`2a^n430:nlh`040;2khP2^_>@0[[cTo`000080[[cT
00<0ooooo`00003oool0/03oool3o`000080oooo0P2Z_NL:0:Vmj005o`00002Y_NP0ZKgX0?ooool0
0000?P3oool007<0oooo0_l000060?ooo`030;>jg`2a^n40/K_Q00<0/K_Q00X0[kcS0;2khP2`^n80
/;_R0:jli?l00000[[cT0:nlh`3ooooo0000[`3oool2o`000080oooo1P2Z_NL20:Vmj0030:Zmi`2Y
_NP0ZKgX00@0ZKgX00Go00000:Vmj02Y_NP0ooooo`00000n0?ooo`00L03oool3o`0000H0oooo102c
^]l30;6kh@030;:kh02`^n80/;_R00<0/;_R00Ko00000:nlh`2__><0[kcS0?ooool0002[0?ooo`?o
00000`3oool;0:Zmi`<0ZKgX00<0Z[gW0:Vmj?l000000`2Y_NP00`3ooooo00000?ooo`0l0?ooo`00
KP3oool2o`0000L0oooo0P2f^M`40;>jg`030;6kh@2b^n00/[_P0080/[_P0`2`^n800`2a^n7o0000
0:nlh`030:nlh`03o`00003oool0oooo0:L0oooo0_l000040?ooo`h0Z[gW00D0ZKgX0:Zmi`2Z_NL0
Z[gWo`0000020:Vmj0030:Zmj03ooooo000003d0oooo001[0?ooo`?o0000203oool40;Jig080/k[O
0P2d^]d40;:kh0050;2khP2a^n40/K_Q0;6khOl000000P2__><20;2lhP030?ooool00000oooo0:@0
oooo0ol000020?ooo`80ZkcV502Z_NL00ol00000ZKgX0:Zmj0020:Zmj0030?ooool00000oooo03/0
oooo001X0?ooo`?o00002@3oool20;Rgf0<0][WL00<0]kSJ0;Bjg@2d^]d00`2d^]d20;:kh080];[N
0`2a^n400ol00000/;cR0;2lhP030;2lhP030?ooool00000oooo0:00oooo0ol000020?ooo`H0ZkcV
0P2Z_NL20:^li`l0Z[gW00?o00000:Zmi`2Z_NP00`2Z_NP00`3ooooo00000?ooo`0j0?ooo`00IP3o
ool2o`0000T0oooo00<0^[GD0;Rgf02h]mP00`2h]mP0102f^M`0]kSJ0;NhfP2g^=X30;Bjg@030;Ji
f`2d^]h0];[N00<0];[N00@0/K_Q0;>kh02c^n3o00000`2`_>800`2b^n40ooooo`00002O0?ooo`;o
0000103oool70:^liPD0ZkcW0P2Z_NL00`2[_>L0Z[gW0:Zmi`0:0:Zmi`07o`00002Z_NL0Z[gX0:Zm
j02Z_NL0ooooo`00000k0?ooo`00H`3oool3o`0000X0oooo0`2j]M@30;Rgf0030;ZgeP2g^=X0]kSJ
00<0]kSJ00@0];[M0;Jif`2f^M/0][WK0`2d^]h01`2e^]d0/k_P0;>kh02c^n3o00000;>kh02`_>80
0`2b^n400`3ooooo00000?ooo`2J0?ooo`?o0000103oool20:^ki@P0ZkcV0`2[_>L00`2[_>H0ZkcW
0:^li`020:^li`<0Z[gW00<0Z[cW0:Zmi`2Z_NL01@2Z_NL00ol00000Z[gW0:Zmi`030:Zmi`030?oo
ool00000oooo03T0oooo001Q0?ooo`;o0000303oool40;Zee0030;Rgf02j]mH0^[OF0080^[OF0`2g
^=X00`2i^=P0][WK0;Jif`030;Jif`040;BjgP2e^]d0]K[M0;Fjg@80/k_P00?o00000;BkgP2b^n40
102b^n400`3ooooo00000?ooo`2G0?ooo`;o0000103oool00`2/^n@0Zk_U0:^ki@030:^ki@80ZkcV
0P2/^nD40:^liP040:^li`2[_>H0ZkcV0:^liP@0ZkcW00@0Z[gW0:Zli`2Z_>L0Z[cW1P2Z_NL00ol0
0000Z[gW0:Zmi`040:Zmi`030?ooool00000oooo03P0oooo001N0?ooo`?o0000303oool00`2m/m00
^[GD0;Zee0030;Zee0D0^[OF00<0]kSJ0;Vhf02i^=P00P2i^=P30;Jif`030;Rif@2e^]d0]K[M0080
]K[M00<0/k_P0;Bkg_l000000P2d^mh30;:kh@030;>kh03ooooo000009D0oooo0ol000030?ooo`03
0:fjh`2/^n@0[;_T0080[;_T0P2[^nD20:bki0D0[;_U0P2[_>H20:bki@@0ZkcV0P2[_>L20:^liP@0
Z[cW1@2Z_NL00ol00000Z[gW0:Zmi`050:Zmi`03o`00003oool0oooo03L0oooo001L0?ooo`;o0000
3P3oool30;fcd0<0^[GD0P2l]=830;ZgeP030;bfe02i^=P0^KSH00<0^KSH00<0][WK0;Rif@2h^MT0
0P2h^MT20;Fjg@80]k[K00D0];_No`00002d^mh0];_N0;:kh@040;>kh0030?ooool00000oooo0940
oooo0_l000040?ooo`@0[K[S0P2/^n@00`2]^^<0[;_T0:bki0030:bki080[;_U0P2/^n@50:bki@80
ZkcV00<0[;cU0:^liP2[_>H00`2[_>H20:Zli`80ZkcV102Z_NL00ol00000Z[gW0:Zmi`050:Zmi`03
0?ooool00000oooo03L0oooo001I0?ooo`?o00003P3oool00`2o/L`0_K?@0;fcd0030;fcd0030;Ze
e02l]=80_;CB0080_;CB00@0^[OF0;bfe02l]]@0_;KD0`2i^=P00`2k]mH0^;WI0;Rif@030;Rif@03
0;Fjg@2g^]/0]k[K0080]k[K00Co00000;BkgP2f^]d0][[M0`2c^n00102d^mh0oooo0?ooool0002>
0?ooo`?o0000103oool20:jhh@@0[K[S00@0[;_T0:fjh`2]^^<0[K[S0`2/^n@00`2]^^<0[;_T0:bk
i0030:bki0<0[;_U00<0[;_T0:bli@2/_>D00P2/_>D20:^liP80ZkcU1@2[_>H20:Zmi`030:^li_l0
0000Z[gW00L0Z[gW00<0ooooo`00003oool0=P3oool005L0oooo0_l0000@0?ooo`<0_k7<0`2m/m00
0`2o//h0_;CB0;bddP030;bddPD0_;KD00@0^KSH0;^geP2k]mH0^kOF0`2h^MT20;Zhf0<0]k[K00<0
^KWJo`00002f^]d00`2f^]d01P2c^n00];_N0;BkgP2d^mh0ooooo`0008`0oooo0_l000040?ooo`03
0:ngg`2^^>40[[SQ00<0[[SQ0P2]^^<20:jhh@@0[K[S00@0[;_T0:fjh`2]^^<0[K[S102/^n@00`2/
^nD0[;_T0:bki0020:bki080[;cU00<0[;_T0:^li@2[_>D00`2[_>D70:^liP03o`00002Z_NL0Z[gW
0080ZkcV102Z_NL00`3ooooo00000?ooo`0f0?ooo`00E03oool3o`000140oooo1@2o/L`0102m/m00
_k;>0;nbcP2o//h30;bddP80_[C?0`2l]]@00`2n]M40^kOF0;^geP030;^geP030;Rif@2j^=P0^[SH
0080^[SH00@0]k[K0;VifP2i^M[o00000`2f^]d00`2h^]/0];_N0;BkgP030;BkgP030?ooool00000
oooo08L0oooo0ol000050?ooo`<0[kOO0`2^^>400`2_]ml0[[SQ0:jhh@030:jhh@80[K[S0P2^^N44
0:fjh`80[;_T0P2]^^<40:bki0040:bli@2/^n@0[;_T0:bki0<0ZkcU00<0[;_U0:^liP2[_>H01@2[
_>H00ol00000ZkcV0:^liP030:^liP80Z[gW0P2[_NL00`3ooooo00000?ooo`0e0?ooo`00D@3oool3
o`0001<0oooo0P31[/P40;nac0D0_k;>00<0_;CB0;jdc`2n]<l00P2n]<l0102l]]@0_[GA0;jed@2n
]M430;^geP80_KOC0`2j^=P01`2l^=H0^KWJ0;VifP2i^M[o00000;VifP2f^]d00`2h^]/30;BkgP04
0;Jkg@3oool0ooooo`0008@0oooo0ol000060?ooo`80/;GM102_]ml0102^^>40[kOO0:ngg`2_]ml3
0:jhh@030:ngg`2^^N40[[WQ00<0[[WQ0P2]^^<20:jih@@0[K[S0P2/^n@20:fjh`@0[;_T00@0ZkcU
0:bki@2/^nD0[;_U0`2[_>H0102/^nD0ZkcV0:^li_l000060:^liP@0ZkgW00<0ooooo`00003oool0
=03oool004l0oooo0_l0000E0?ooo`<0`Jk80`2o/L`20<6`b@<0_k;>00<0`K7;0;jdc`2n]<l00`2n
]<l50;jed@030;^geP2m]m<0_KOC0080_KOC00@0^[SH0;bheP2l^=H0_;SF0P2i^MX00ol00000^kWH
0;Rjf`030;Rjf`030;BkgP2f^md0][_M0080][_M00<0ooooo`00003oool0P@3oool2o`0000H0oooo
00<0/;?J0;2eg@2`]Md00`2`]Md20:ngg`80/;GL102_]ml0102^^>40[kOO0:ngg`2_]ml30:jih@03
0;2gg`2^^N40[[WQ00<0[[WQ0P2]^^<20:jih@@0[K[S0P2/^n@20:fjh`@0[;_U00P0ZkcV0:bki@2/
^nD0[;_U0:^li_l00000ZkcV0:bli@D0ZkcV0P2[_NL00`2[_>H0ooooo`00000e0?ooo`00C03oool3
o`0001D0oooo00<0`Zc40<6^b031[/P00`31[/P00`2o/L`0`K390<6`b@020<6`b@040;nbcP31/L/0
`K7;0<6ab`<0_[C?0P31/ld30;jed@030<2dc`2m]m<0_KOC0080_KOC00<0_kKA0;bheP2l^=H00P2l
^=H00`2i^MX0^kWHo`0000020;^if080^;[K0P2i^]X30;Jkg@040;Rkg03oool0ooooo`0007h0oooo
0ol000070?ooo`<0/;?J0`2`]Md00`2a/mX0/;GL0;2eg0030;2eg080[kOO0P2a]M`40:ngg`040:ji
h@2`]ml0/;OO0;2gg`<0[[WQ00<0/;SO0:jih@2^^N400`2^^N420:fjh`030:jih@2]^^<0[K[S00<0
[K[S0P2/^nD00`2]^n@0[;_U0:bki@030:bki@04o`00002/_>D0[;cU0:bli@<0ZkcV00<0[;cU0:^l
iP2[_>H00P2[_>H00`3ooooo00000?ooo`0c0?ooo`00BP3oool2o`0001L0oooo0P32[<@40<6^b003
0<:^a@31/<T0`K390080`K3900<0`jo70<6ab`31/L/00`31/L/01@2n]<l0`K?=0<6cc@31/ld0_[GA
00@0`;C?0P2m]m<30;nfd@80_;SF00@0_[SC0;^if02k^MSo00000P2k^MP50;VjfP060;Jkg@2h^m`0
^;_L0;Rkg03ooooo0000O03oool2o`0000P0oooo0P2a/MP40;2cfP040;2eg@2a/mX0/K?J0;6cfP<0
/;GL00<0/[?I0;6eg02a]M`00`2a]M`20:ngg`030;6fg02`]ml0/;OO00<0/;OO00@0[[WQ0;2hg`2`
^=l0/;SO0`2^^N400`2`^=l0[[WQ0:jih@020:jih@80[K[S0P2^^^840:fki080[;_U0P2]^n@01Ol0
0000[;cU0:bli@2/_>D0ZkcV00@0[;cU0P2[_>H00`2/_>H0ooooo`00000d0?ooo`00A`3oool3o`00
01P0oooo1032[<@20<6^b0<0`Zk50P31/<T30<>_a`<0`K7;00<0`k780<6cc@31/ld00P31/ld50<2d
c`030;fgd`2o]]40_kKA0080_kKA00L0_;SF0;jhd`2n^=<0_[SC0;^if?l00000^kWH0080_KWF0`2i
^]X00`2k^]P0^;_L0;Rkg0030;Rkg0030?ooool00000oooo07L0oooo0ol000070?ooo`030;:_e@2a
/MP0/K7H00<0/K7H0P2`/mX00`2b/ML0/K?J0;6cfP030;6cfP040;2eg02b/mT0/[?I0;:cf@<0/KGL
00<0/[?I0;6fg02a]]`00P2a]]`20;2gg`80/KKL102`^=l00`2^^N40/;SO0;2hg`020;2hg`80[[WQ
00<0/;SO0:jjhP2^^^800`2^^^820:fki080[[[R0`2]^n@00ol00000[;cU0:bli@020:fki0@0[;cU
00H0ZkcV0:bliP2/_>H0[;cV0?ooool0000c0?ooo`00A@3oool2o`0001X0oooo1@32[<@00`31[/P0
`Zk50<:^a@020<:^a@030<6`b@33[lL0`jo70080`jo700<0`K7;0<>ab033/LP00P33/LP20<6cc@80
`[;;0`30]<l00`32]<d0_kKA0;nfd@030;nfd@D0_[SC00?o00000;fieP2m^MH00P2m^MH0102i^]X0
^k[H0;^jf02k^]P30;Rkg0040;Vkf`3oool0ooooo`0007D0oooo0_l000080?ooo`@0/ZoE0`2a/MP0
0`2c[]@0/[7G0;:ae`020;:ae`<0/K?J00<0/k7F0;:cf@2b/mT00P2b/mT00`2a]M`0/[?I0;:cf@02
0;:cf@80/KKL00<0/k?I0;6fg02a]]`00`2a]]`20;2hg`80/KKL102`^=l0102^^N40/;SO0;2hg`2`
^=l30:jjhP030;2ih02^^^80[[[R00<0[[[R0P2]^n@00ol00000[[[S0:fki0030:fki0@0[;cU102/
_>H00`3ooooo00000?ooo`0a0?ooo`00@P3oool3o`0001/0oooo0P32Z/440<:/a0D0`Zk51@33[lL5
0<>ab0030<6cc@32///0`[;;0080`[;;00@0`;C?0<:dc@32]<d0`[C=0`2o]]420<6fc`<0_[SC00<0
`;OBo`00002m^MH00P2m^MH00`2n^M@0^k[H0;^jf0020;^jf0030;Rkg02i^m/0^K_K0080^K_K00<0
ooooo`00003oool0L@3oool3o`0000P0oooo00<0/ZcC0;:_e@2b[mD00`2b[mD00`2a/MP0/jkD0;>^
e0020;>^e0<0/[7G00<0/K?J0;>aeP2c/MH00P2c/MH20;:cf@030;>aeP2b/mT0/[?I00<0/[?I00@0
/KKL0;>cf@2c/mT0/k?I0`2a]]`00`2c]=T0/KKL0;6fg0030;6fg080/;SO0P2a]md40;2hg`040:jj
hP2`^N00/;WP0;2ih0<0[[[R00@0[kWQ0:jjh`2^^^?o00000P2^^^<20:fki0030:jkh`2/_>D0[;cU
00<0[;cU0P2/_>H00`2/_>D0ooooo`00000b0?ooo`00?`3oool3o`0001d0oooo0`32Z/430<:/a080
`j_20`32[/D20<B]``<0`jo70P34[/@40<>ab0D0`[;;1@32]<d00`2o]]40`KK?0<6fc`020<6fc`05
0;jhd`30]m80`;OBo`00002m^MH0102n^M@20;^jf080_K[G0`2i^m/0102k^mT0oooo0?ooool0001^
0?ooo`?o00002P3oool30;:/d`<0/ZoE00<0/jcA0;>^e02c[]@00`2c[]@20;:ae`80/jkC102c/MH0
102b/mT0/k7F0;>aeP2c/MH30;:cf@030;BaeP2c/mT0/k?I00<0/k?I00@0/KKL0;>df@2c]=T0/kCI
0`2a]]`00`2c]=X0/KOM0;6gg@030;6gg@80/;SO0P2a]md40;2ih0080:jjhP2_^N40[kWQ0:nih@2^
^^?o00000:jjh`2_^^440:jkh`80[;cU0P2]^n@40:bli@030?ooool00000oooo0300oooo000m0?oo
o`;o00007`3oool50<:Z`@030<:/a033Zl80`j_20080`j_200<0`Zk50<B]``34[L<00P34[L<01033
[lL0a:k40<B^a034[/@30<>ab080aK360`32///20<Bbb0<0`[C=0P34]</30<6fc`050<>fc@30]m80
`;OB0<2gd_l000001@2n^M@00`2k^]P0_K[G0;fje`020;fje`040;Vkf`2k^mT0^k_I0;^kf@80oooo
00?o00000?ooo`3oool0J@3oool2o`0000/0oooo00<0/Z[@0;:/d`2b[=<00`2b[=<0102b[mD0/jcA
0;>/d@2c[=430;>^e0030;B[d02c[]<0/jkC00<0/jkC0P2c/MH20;B^dP@0/k7F00@0/[?I0;BaeP2d
/MH0];7F0`2c/mT00`2d/MH0/kCI0;>df@030;>df@040;6fg02c]=X0/kCJ0;>dfP<0/KOM00<0/kGJ
0;6gg@2a]md00`2a]md20;2ih0030;6hgP2_^N40[kWQ0080[kWQ00<0[[[So`00002_^^400P2_^^42
0:jkh`80[k[R102]^n@20:bli@80[KcT00<0ooooo`00003oool0;`3oool003X0oooo0ol0000P0?oo
o`80`jNn1032Z/450<>[`PD0a:g31@34[/@00`33/LP0aK360<F`aP020<F`aP030<:bb`34//P0a;;8
0080a;;800<0`[C=0<Bdb`34]</00P34]</01031]/l0`kK=0<>fc@33]/d20<2gdP03o`000032]m00
_[WD0080_[WD0P31^M830;fje`030;nje@2k^mT0^k_I00<0^k_I00<0ooooo`00003oool0I`3oool3
o`0000X0oooo00<0/ZS>0;:Zd02bZ]000P2bZ]030;:/d`030;>YcP2c[=40/jcA00<0/jcA00@0/jkD
0;B[d02dZm00]:_@0`2c[]<00`2eZll0]:kB0;B^dP030;B^dP80/k7F0P2e[]840;BaeP040;>cf@2d
/MH0];7F0;BaeP<0/kCI00<0]K;F0;>dfP2c]=X00`2c]=X0102a]md0/kGJ0;>efP2c]MX30;6gg@03
0;>ff`2a^=h0/KSN0080/KSN0P2_^N420;6ig`04o`00002_^^40[k[Q0;6ih0D0[k[R0P2]^n@00`2^
^n<0[KcT0:fli0030:fli003o`00003oool0oooo02h0oooo000h0?ooo`;o00008P3oool30<>W_P<0
`Z[10P34ZKh30<>[`P80aJ^o1034[L<00`36[<40a:k40<B^a0020<B^a0D0aK361@34//P40<Bdb`03
0<Jdb033]/d0`kK=0080`kK=00<0`;OB0<:gd?l000000P32]m000`2n^M@0`KWB0<6idP020<6idP04
0;fje`2o^]D0_k[E0;nje@<0^k_I00@0_K_H0?ooo`3ooooo0000I@3oool2o`0000`0oooo0`2bZ<h4
0;:Zd0040;:/d`2cZLh0/jW>0;>YcP<0/jcA00<0]:W=0;B[d02dZm000`2dZm00102c[]<0]J_?0;F[
c`2eZll30;B^dP030;J/cP2e[]80]JkB00<0]JkB0P2d/MH20;J_dP@0];7F00@0/kCI0;FbeP2e/]H0
]K;F0`2c]=X00`2e/mL0/kGJ0;>efP020;>efP030;6gg@2c]]/0/kKK0080/kKK0P2a^=h20;>gg0<0
/KWO00?o00000:njh@2a^N000P2a^N030:njhP030;2jh@2^^n<0[[_S0080[[_S0P2]_>@20:jkh`03
0?ooool00000oooo02h0oooo000e0?ooo`?o00008`3oool50<>W_P030<:Z`@34ZKh0a:Vn0080a:Vn
00@0`j_20<F[_`35Zkl0aJ^o0`34[L<20<J/`@<0a:k40P36[/830<F`aP80a[340`34//P20<JbaP80
a;C;0`36]<P20<>fc@040<Ffb`32]m00`[O@o`000080`[O@1@31^M840;nje@030;^kf@2m^mP0_K_H
0080_K_H0P3oool00ol00000oooo0?ooo`1O0?ooo`?o0000303oool00`2aYL`0/ZS>0;:XcP020;:X
cP<0/Z[@00<0/jO<0;>YcP2cZLh00`2cZLh0102c[=40]:W=0;BYc@2dZLd30;B[d0030;JXc02eZll0
]J_?00<0]J_?00@0]:kB0;J/cP2f[<h0]Zc>0`2e[]800`2g[<h0]ZoB0;J_dP030;J_dP80];7F00<0
]joB0;FbeP2e/]H00`2e/]H0102c]=X0]K?G0;Fce`2e/mL20;>efP80]KCG102c]]/00`2a^=h0/kOL
0;>gg0020;>gg080/KWO00?o00000;6ih02a^N000`2a^N00102_^^80/;[Q0;2jh@2`^^420:jkh`03
0;2jhP2^^n<0[[_S00<0[[_S00<0ooooo`00003oool0;@3oool003<0oooo0_l0000V0?ooo`030<:U
_033Ykh0`jNn0080`jNn1@34ZKh50<F[_`030<B]``36[<40aZc10080aZc100<0a:k40<J^`P36[/80
0P36[/800`35/<H0a[340<J`a0020<J`a0050<Bbb036//H0a[;60<JbaP34]</01036]<P01`33]/d0
aKK;0<Ffb`35]//0`[O@o`000032]m000P34]lh30<6idP80`[WA0P2o^]D20<6je0<0_K_H00@0_[_G
0?ooo`3ooooo0000G`3oool2o`0000h0oooo0`2aYL`40;:XcP040;:Zd02cYl`0/jO<0;>Wc0<0/jW>
00<0]:K:0;BYc@2dZLd00`2dZLd0102dZm00]ZS<0;JXc02fZ<`30;F[c`030;NXb`2f[<h0]Zc>00<0
]Zc>00@0]JkB0;N/cP2g[<h0]jc>0`2f[m800`2h[Lh0]joB0;N_dP020;N_dP80]K;F0P2g/=830;Fc
e`030;Nad`2e]=L0]KCG00<0]KCG0P2c]]/20;Fef0<0/kOL00D0]KKI0;>hg@2c^=go00000;>hg@02
0;6ih080/[WN102`^^40102^^n<0/;[R0;2jhP2`^^830:jkh`80[k_R00?o00000?ooo`3oool0;03o
ool00300oooo0ol0000W0?ooo`80`ZFl0`33Ykh20<BW_0@0a:Vn00<0aJRl0<F[_`35Zkl00P35Zkl5
0<J/`@D0aZk21@36/<@40<JbaPD0a[C81@35]//00ol00000a;O>0<BgcP020<BgcP050<6idP32^M40
`[WA0<:id@2o^]D01031^]@0102m^mP0_[_G0;jke`2n^mL20?ooo`03o`00003oool0oooo05T0oooo
0ol0000>0?ooo`030;2Tb`2aYL`0/JG<00<0/JG<0P2bZ<h00`2bY<X0/jO<0;>Wc0030;>Wc0040;>Y
cP2dY/X0]:K:0;BVbP<0]:W=00<0]ZK80;JXc02fZ<`00`2fZ<`0102eZll0]jS;0;NXb`2gZ</40;J/
cPD0]jc>00@0]ZoB0;R]cP2h[Lh0^:g>0P2g[m800`2i[Lh0]k3B0;N`dP030;N`dP040;Fce`2g/M<0
]k7C0;Nad`<0]KCG00<0]k;D0;Fef02e]MP00`2e]MP01`2c]m`0]KKI0;Fff@2e]]T0/kSMo`00002d
]m/01@2b^Mh20;2jh@80/[WO102`^^800`2^^n<0[k_R0:nkhP020:nkhP03o`00003oool0oooo02/0
oooo000]0?ooo`?o0000:@3oool40<:U_0040<>W_P34Yk`0a:Nl0<BW_0<0a:Vn0P35Z;`30<F[_`80
aZZm0`36[<400`37[;h0aZk20<J^`P020<J^`P030<R^`036/<@0a[340080a[3400<0b;320<JbaP36
//H00P36//H01038//@0a[C80<Jdb036]<P20<RdaP<0aKK;00<0akK9o`000034]lh00P34]lh01@36
]l`0`[WA0<:id@32^M40a;W?00D0`K[D102n^mL20?ooo`03o`00003oool0oooo05H0oooo0ol0000@
0?ooo`<0/:C;0`2aYL`00`2bX/P0/ZC:0;:TbP020;:TbP<0/jO<00<0]:?80;BVbP2dY/X00`2dY/X0
102dZLd0]ZK80;JVb02fY/P40;JXc0@0]jS;0`2f[<h00`2hZLX0]jc>0;N/cP020;N/cP030;VYbP2h
[Lh0^:g>0080^:g>00@0]joB0;V]cP2i[Lh0^Jg>0`2g/=800`2i[/l0]k7C0;Nad`030;Nad`040;Fd
e`2g/]@0]k;D0;Nbe0<0]KGH00<0]k?E0;Fff@2e]]T00P2e]]T0102c^=go00000;Bgf`2d]m/30;:i
gP80];SL102b^Ml20;2jhP030;6jh02_^n80[k_R0080[k_R00<0/;_Qo`00003oool0;03oool002/0
oooo0_l0000Z0?ooo`030<6S^`32YK`0`ZFl00<0`ZFl1@34Yk`00`34ZKh0aJRl0<FX_0020<FX_003
0<F[_`36Z[d0aZZm0080aZZm00@0aZc10<N/_P37[;h0ajbn0P36[/830<R^`080a[340`38/<820<Jb
aP<0b;;400<0a[C80<RdaP38]<H00P38]<H01@35]//0akK90<Nfb@37]/Wo000000@0a[O<00@0`[WA
0<Bic`34^Ll0a;W?0`31^]@20<:jdP80_[_G0P30_=H20?ooo`03o`00003oool0oooo05<0oooo0_l0
000A0?ooo`030:nRbP2`Y</0/:C;00<0/:C;00@0/JG<0;:Rb02bX/P0/Z;8102bY<X0102cYl`0]:?8
0;BSb02dXlP30;BVbP030;JSaP2fY/P0]ZK80080]ZK80`2fZ<`20;NVa`@0]jS;00@0]Zc>0;RYbP2h
ZLX0^:W:0P2g[<h20;VYbP@0^:g>1@2i[Lh0102g/=80^Jk?0;V^c`2i[/l30;Nad`030;V`d02g/]@0
]k;D00<0]k;D00@0]KGH0;Nce@2g/mD0]k?E0P2e]]T20;Nee`050;Bgfol00000];OK0;Bgf`2b^Mh0
102d^=`20;:ig`030;>ig@2a^^00/K[P0080/K[P00<0[k_R0;2kh@2`^n400P2`^n400ol00000oooo
0?ooo`0Z0?ooo`00:03oool3o`0002/0oooo0P31Xk/40<:U_0030<>U^P34Yk`0a:Nl00<0a:Nl1@35
Z;`50<JZ_@@0ajbn00<0aZk20<R^`038[/000P38[/000`36/<@0b;320<R``P020<R``P030<JbaP38
//@0b;;40080b;;41@38]<H40<Nfb@03o`000036]l`0a[O<0080a[O<1@34^Ll01@31^]@0`[[B0<:j
dP32^]80_[_G00@0`;cF0P3oool00ol00000oooo0?ooo`1?0?ooo`?o0000403oool00`2^X<X0[j;:
0:nRbP020:nRbP<0/:C;00<0/:370;:Rb02bX/P00P2bX/P30;:TbP030;>QaP2dXlP0]:?800<0]:?8
00@0]:K:0;JSaP2fXlH0]Z?6102fY/P0102fZ<`0]jK70;NVa`2gY/L30;NXb`030;RVaP2hZLX0^:W:
0080^:W:00<0]jc>0;VYbP2iZLX00P2iZLX20;R]cP80^Z[:0`2i[Lh00`2jZlX0^Jk?0;V^c`030;V^
c`040;Nad`2i/=00^K3@0;V`d0<0]k;D00<0^[7A0;Nce@2g/mD00P2g/mD00`2e]]T0]kGG0;Nee`02
0;Nee`03o`00002d]m/0]kKH00@0];SL00<0][OJ0;>ig@2c^Md00P2c^Md20;6jh080/k[O102`^n40
0`3ooooo00000?ooo`0Z0?ooo`009P3oool2o`0002d0oooo1031Xk/20<:U_0<0`jFj0`34Yk`00`35
Y[X0aJRl0<FX_0020<FX_0030<NX^`36Z[d0aZZm0080aZZm00<0b:Zk0<N/_P37[;h00P37[;h50<R^
`0D0b;321@38//@00`3://80b;C60<RdaP020<RdaP050<Zda@37]/T0akK90<Vfb?l000000`36]l`2
0<Rhb`<0a;W?00@0a[W>0<:jdP32^]80`[[B0P34^m430<2leP040<:le03oool0ooooo`0004l0oooo
0_l0000B0?ooo`<0[Z3:102_X/X0102`Y</0/:370;2Pa`2`X<L40;:Rb0040;:TbP2cXLH0/j760;>Q
aP@0]:?8102fXlH30;JVb0030;NSa02gY/L0]jK700<0]jK700@0]jS;0;RVaP2hY/H0^:K60P2hZLX0
0`2iY/H0^JW:0;VYbP030;VYbP030;R]cP2jZ/X0^Z[:0080^Z[:00@0^Jg>0;Z[bP2jZlX0^Z_:0`2i
[/l00`2k[L/0^K3@0;V`d0020;V`d0030;Nbe02j/M40^[7A0080^[7A0P2g/mD20;ZbdP<0]kGG00<0
^KCDo`00002g]]P00P2g]]P00`2d^=`0][OJ0;JgfP020;JgfP80/kWM00<0]KSK0;>jg`2c^]l00`2c
^]l20;2kh@030;:jh03ooooo000002/0oooo000S0?ooo`?o0000;P3oool50<6S^`030<:U_033YKX0
`jFj0080`jFj0P34Yk`30<FV^P80aJRl0`37Z;/20<JZ_@<0b:Zk0P37[;h20<V/_0<0b:k00P3:[[h3
0<R``P80b[300`38//@20<Zb`P<0b;C60P3:]<D01P37]/T0bKK80<Vfb?l00000bKK80<Jgc0@0b;S;
00D0a;W?0<JicP36^Lh0a[W>0<:jdP040<Bkd@040<2leP32_=@0`[cD0<:le080oooo00?o00000?oo
o`3oool0B@3oool3o`000180oooo00<0[9o:0:jPbP2^X<X00P2^X<X30:nRbP030:nNa`2`X<L0/:37
0080/:370`2bX/P00`2bWl@0/j760;>QaP020;>QaP<0]:?80P2eX<@40;JSaP040;JVb02gXl@0]j?4
0;NSa0<0]jK700<0^:?30;RVaP2hY/H00P2hY/H0102hZLX0^JK60;VVaP2iY/H30;VYbP030;^WaP2j
Z/X0^Z[:00<0^Z[:1@2jZlX0102i[/l0^jg;0;^]b`2k[L/20;V`d0030;^^c02j/M40^[7A00<0^[7A
00<0]k?E0;ZbdP2j/]800P2j/]80102g]ML0^KCD0;Vde?l000020;Nff0030;VeeP2f]mX0][OJ00<0
][OJ00@0/kWM0;Fhf`2e^=/0]KSK0`2c^]l00`2d^Md0/[[P0;:jh0020;:jh0030?ooool00000oooo
02T0oooo000Q0?ooo`;o0000<@3oool00`30X[X0`J>k0<6S^`020<6S^`D0`jFj00<0a:Nl0<FV^P35
Y[X00P35Y[X00`35Z;`0ajRk0<NX^`020<NX^`030<JZ_@38Z[/0b:Zk0080b:Zk00<0ajbn0<V/_039
[;`00P39[;`00`38[/00bZjn0<Z^_P020<Z^_P030<R``P3:/<00b[300080b[3000<0b;;40<Zb`P3:
//800P3://801038]<H0b[C50<Zda@3:]<D30<Vfb003o`000039]/P0b;S;00<0b;S;00<0bKS90<Ji
cP36^Lh00P36^Lh50<Bkd@@0`[cD0`3oool00ol00000oooo0?ooo`160?ooo`;o0000503oool30:bO
bP@0[Z3:00@0[j;:0:nNa`2_W/L0[ik7102`X<L0102bX/P0/Yo40;:Oa02bWl@40;>QaP040;BSb02e
X<@0]J340;FPa0<0]Z?600<0]Z320;NSa02gXl@00P2gXl@00`2gY/L0^:?30;RS``020;RS``80^:K6
00<0^Z?20;VVaP2iY/H00`2iY/H0102iZLX0^jO60;^WaP2kYlH30;ZZbP80_:S6102jZlX40;^]b`04
0;V`d02k[/`0^jk<0;^^c0<0^[7A0P2l/<h30;ZbdP060;bac`2i]=@0^KCD0;Vde?l00000]kKH0`2i
]MH30;JgfP030;Rgf02e^=/0]KSK00<0]KSK00@0/k[O0;Big@2d^Md0];WM0P2b^^020;>jg`030?oo
ool00000oooo02P0oooo000N0?ooo`?o0000<P3oool20<2R^P@0`J>k00<0`Z>j0<>U^P33YKX00P33
YKX50<FV^PD0ajRk1@38Z[/50<V/_0D0bZjn1@3:/<040<Zb`P030<bb`@3:]<D0b[C50080b[C500@0
c;C30<Vfb039]/So00000P3;]/H20<Rhb`<0bKS90P36^Lh20<Rjc@<0a;_A0P36^m020<:le080a;gD
0P3oool00ol00000oooo0?ooo`130?ooo`?o0000503oool00`2YW//0[9o:0:bObP020:bObP<0[Z3:
00<0[Ig70:nNa`2_W/L00P2_W/L30;2Pa`030;6Ma02bWl@0/Yo40080/Yo40`2cXLH00`2dW/80]J34
0;FPa0030;FPa0030;JSaP2fX<80]Z3200@0]j?41@2hXl<0102hY/H0^Z?20;ZS`P2jXl840;VVaPD0
^jO600@0^Z[:0;bXaP2lZ<H0_:S60`2jZlX20;bYaP80^jg;00<0_J_70;^^c02k[/`00`2k[/`00`2j
/M40_;3>0;b`cP020;b`cP040;ZbdP2l/Ll0_;7?0;bac`80^KCD00?o00000;VeeP2i]MH00`2i]MH0
102f]mX0^;OH0;Rgf02h]mP20;Fhf`80]kSJ0`2d^Md00`2f^M/0/k[O0;>jg`030;>jg`03o`00003o
ool0oooo02L0oooo000L0?ooo`;o0000=03oool30<2R^P<0`J>k0P32XkX30<>U^P80a:Fi1035Y[X0
0`36Y[T0ajRk0<NX^`020<NX^`030<RX^@38Z[/0b:Zk0080b:Zk00<0bJZj0<V/_039[;`00P39[;`0
0`3;[;/0bZjn0<Z^_P020<Z^_P040<^^_03:/<00b[300<Z``080c;2n0P3://830<bb`@80b[C50`3<
]<<01@39]/So00000<^faP3;]/H0b;S;00@0bKS900<0a[W>0<Rjc@38^/d00P38^/d01@34^m40a[_@
0<Jkd036^m00`[cD00@0a;gD0P3oool00ol00000oooo0?ooo`100?ooo`;o0000503oool00`2WW/d0
ZIk;0:VNb`020:VNb`@0[9o:00@0[Z3:0:fMa`2]WLL0[Ig7102_W/L0102`X<L0/Ig40;6Ma02aWL@4
0;:Oa0030;>QaP2dW/80]9k200@0]J3400<0]Yk00;JP`P2fX<800P2fX<820;NSa080^:30102hXl<4
0;ZS`P<0^JK60P2kY<830;^WaP030;bU`P2lZ<H0_:S600<0_:S600D0^Z_:0;bYaP2lZLH0_:W60;^]
b`030;f[a`<0^jk<00<0_Zg90;b`cP2l/<h00`2l/<h40;bac`040;Vde02k/m7o00000;^cd@<0^KGF
00D0^kGC0;Rgf02h]mP0^;OH0;ZfeP050;NhfP040;Big@2f^M/0][WK0;Jif`<0/k[O00<0]K[M0?oo
ool00000:03oool001T0oooo0ol0000e0?ooo`D0`::j00<0`J>k0<:S^P32XkX00P32XkX01033YKX0
a:Fi0<BU^@34YKT30<FV^P80aZJi0`37Z;/20<RX^@<0b:Zk0P39Z[X30<V/_080bjbk0`3:[[h30<^^
_0050<Z``03</;h0c;2n0<b`_P3://80103<//400`3:]<D0c;C30<bd``020<bd``040<^fa_l00000
bkK60<^faPD0bKS91@38^/d30<Jkd080b;c?0`34_M@01@35_M<0oooo0?ooo`3ooooo000003h0oooo
0ol0000C0?ooo`030:BNc`2WW/d0Yik=0080Yik=102YW//20:bObP030:^La`2]WLL0[Ig70080[Ig7
0`2_W/L00`2_Vl@0/Ig40;6Ma0020;6Ma0<0/Yo400<0/Yc10;BN`P2dW/800P2dW/820;FPa080]Yk0
102fX<80102gXl@0^:300;RP`02hX<030;RS``80^Z6o102jXl800`2iY/H0^jC20;^T`P020;^T`P04
0;^WaP2lYL80_:G20;bU`P<0_:S600<0_JK20;bYaP2lZLH00P2lZLH50;f[a`040;^^c02n[LT0_Zg9
0;j]b@<0_;3>0P2n[l/20;bac`040;j`c02k/m40^k?Ao`000080^k?A00D0^KGF0;^ed`2k]M<0^kGC
0;Rgf0030;ZfeP<0]kSJ00<0^KSH0;Jif`2f^M/00P2f^M/00`2c^]l0]K[M0;Fjg@020;Fjg@030?oo
ool00000oooo02H0oooo000F0?ooo`?o0000=`3oool20;jP^`@0`::j1@32XkX50<BU^@030<FV^P36
Y[T0aZJi0080aZJi00<0ajRk0<RX^@38Z;T00P38Z;T00`38Z[/0bJZj0<VZ^P020<VZ^P030<V/_03;
[;/0bjbk0080bjbk00<0bZjn0<^^_03;[[`00P3;[[`40<b`_PD0c;;11@3<]<<00`3=]L;o00000<^f
aP020<fga@<0bKS90P3;^LP30<Rjc@80b[_<00<0a[_@0<Rlc`38_<l00P38_<l01034_M@0aKgC0<Fm
d`35_M<20?ooo`03o`00003oool0oooo03T0oooo0ol0000E0?ooo`<0Y9k?0`2WW/d30:VNb`030:RK
b@2[W<L0Zic70080Zic7102]WLL00`2_W/L0[i_40:nKa0050;6Ma0030;:Oa02bW<40/Yc100@0]9k2
00<0]J340;JN`02fW/000P2fW/020;JP`P030;NN_P2hX<00^:3000<0^:3000@0^:?30;ZQ_`2jXKl0
^Z6o0`2jXl800`2kXKh0^jC20;^T`P030;^T`PD0_:G200@0_:S60;fV`P2mY/80_JK20P2lZLH20;jX
``@0_J_71@2n[LT01@2l/<h0_Zo;0;j_b`2n[l/0_;7?00<0_[3<00@0^k?Ao`00002k/m40_[;?0`2k
]M<00`2m]=40^[KF0;ZfeP030;ZfeP040;NhfP2i^=P0^KSH0;Vhf080][WK0P2h^MX30;Fjg@030;Nj
g03ooooo000002L0oooo000D0?ooo`;o0000>@3oool30;jP^`<0`::j0P31X[X40<:S^P030<>S^@34
YKT0a:Fi0080a:Fi1@36Y[T50<RX^@D0bJZj1@3;[;/50<^^_0@0c;2n00@0c[6m0<bb`@3<//40c;;1
0P3>/kl30<bd``80cKG200?o00000<fga@3=]lD00P3=]lD00`39^<T0bkW80<^ib0020<^ib0040<Rj
c@3:^l`0b[_<0<Zkc0@0b;c?00<0bKg?0<Fmd`35_M<00P35_M<30?ooo`03o`00003oool0oooo03H0
oooo0_l0000F0?ooo`030:6Nd@2TW/l0Y9k?0080Y9k?102WW/d0102YW//0Z9_90:RKb@2XVlT30:^L
a`<0[Ig700<0[I[40:nKa02_Vl@00P2_Vl@30;6Ma0030;6J`@2bW<40/Yc10080/Yc10P2dW/800`2d
Vkh0]Yk00;JN`0030;JN`0040;JP`P2gW[h0]ijn0;NN_P@0^:301@2jXKl0102jXl80^j6n0;^Q_P2k
XKh30;^T`P030;fR_P2lYL80_:G20080_:G200<0_ZBn0;fV`P2mY/800P2mY/80102lZLH0_ZS30;jX
``2nZ<<30;f[a`80_j[40`2n[LT00`30[<H0_Zo;0;j_b`020;j_b`D0_[3<00Go00000;jbc`2n//l0
_[;?0;^ed`030;fdd@<0^[KF00D0_;KC0;Vhf02i^=P0^KSH0;^heP050;RifP060;Fjg@2g^]`0]k[L
0;Njg03ooooo00009P3oool00140oooo0ol0000i0?ooo`030;^O_02nX;/0_Z2k00<0_Z2k00@0`::j
0<6R^P31X[X0`J:j0`32XkX20<>S^@@0a:Fi00<0aZFh0<JV^@36Y[T00P36Y[T00`38YkP0b:Ri0<RX
^@020<RX^@030<VX^039Z[X0bJZj0080bJZj00<0bj^i0<^/^`3;[;/00P3;[;/0103<[KX0bjjl0<^^
_03;[[`20<f_^`80c;2n0`3>/Kd00`3<//40c[>o0<jc_`020<jc_`030<bd``3=]L80cKG200;o0000
103=]lD40<^ib0040<fjb03:^l`0b[_<0<Zkc080bkc;0P38_<l30<Vmc`80aKgC0P37_]830?ooo`03
o`00003oool0oooo0380oooo0ol0000C0?ooo`0309ZOf02NW]@0WYkD00@0XIkA102TW/l20:NNc@03
0:FKb`2XVlT0Z9_90080Z9_9102[W<L00`2]WLL0[I[40:fJa0040:nKa0040;6Ma02aV/40/I[10;6J
`@@0/Yc100@0]9k20;BK_P2dVkh0]9^n102fW/040;NN_P<0^:300P2iW[d40;ZQ_`D0^j6n00@0^jC2
0;fR_P2mX[h0_J:n0P2lYL820;jT_P@0_JK21@2nZ<<00`2mZlL0_j[40;nZa0020;nZa0040;j]b@30
[<H0`:c60<2/aP80_Zo;0P30[/L30;j`c0;o00000`2n//l50;fdd@050;ZfeP2l]]<0_;KC0;bfd`2i
^=P00`2k^=H30;RifP030;Zif@2g^]`0]k[L0080]k[L0P3oool00ol00000oooo0?ooo`0S0?ooo`00
403oool2o`0003X0oooo0`2kWk`40;jP^`D0`J:j00@0`Z>j0<>S^@33XkT0`j>i0`34YKT20<JU^0<0
aZJi0P38YkP30<RX^@80bJRh0`39Z[X20<^[^@<0bjbk0`3<[KX01@3;[[`0cJnk0<f_^`3=[k/0c;2n
00@0c[6m1@3>/kl3o`0000030<fe`_l00000cKO50080cKO50P3>^<@20<^ib0<0cK[800D0b[_<0<^l
b`3;_</0bkc;0<Rlc`040<Vmc`040<Fmd`37_]80akkB0<NndP<0oooo00?o00000?ooo`3oool0<@3o
ool2o`000180oooo00@0Uj7K09ZOf02JWmP0VYoH0`2NW]@40:6Nd@80Y9k?00<0XY_>0:FKb`2UVl/0
0P2UVl/40:RKb@80Zic700<0ZYW50:fJa02]V/@00P2]V/@20:nKa0030:jI`@2aV/40/I[100<0/I[1
0P2bW<400`2bV[h0]9^n0;BK_P020;BK_P<0]Yk00P2fVkd40;NN_P040;RP`02iW[d0^Ijm0;VN_@<0
^Z6o0P2kW[`40;^Q_P@0_J:n00<0_:G20;jT_P2nY;h00P2nY;h20;fV`P80_jFo102nZ<<40;nZa003
0<6Y`@30[<H0`:c60080`:c600@0_Zo;0<2^a`30[/L0`:k70ol000001030/<[o00000;jbc`2n//l2
0<2bc0<0_KCA00D0_kC?0;bfd`2l]]<0_;KC0;jfdP050;^heP040;RifP2j^MT0^[WI0;Zif@80]k[L
0P2h^]/00`3ooooo00000?ooo`0T0?ooo`00403oool00ol00000ooooo`00000h0?ooo`@0^inl0`2n
X;/20;jP^P@0`J:j1@33XkT00`34YKT0aZFh0<JU^0020<JU^0030<JV^@38YkP0b:Nh0080b:Nh00<0
b:Ri0<VX^039Z;P00P39Z;P00`39Z[X0bj^i0<^[^@020<^[^@030<^/^`3<[KX0c:fj0080c:fj103=
[k/50<ja_@030<nb_03>/koo000000;o000000<0ckBo0<fe`P3=]L800P3?]/400ol00000cKO50<jh
a0020<jha0030<^ib03=^/P0cK[80080cK[8103;_</01@3=_L/0bKg?0<Vmc`39_Ll0bkk>00<0akkB
0P38_m830?ooo`03o`00003oool0oooo0300oooo00?o00000?ooool000002`3oool0102BYN80U:?O
09BSg`2DXml409NQf`<0VYoH0`2NW]@20:6Nd@0309jKd@2RVlh0XY_>0080XY_>102UVl/20:RKb@04
0:NHa`2ZVLD0ZYW50:ZIa@@0[I[400@0[i_40:jI`@2^VL40[YW1102aV/40102bW<40/YZn0;:J_P2b
V[h40;BK_P040;JN`02fVkd0]Y^m0;JK_@<0]ijn00<0^9bk0;VN_@2iW[d00`2iW[d0102jXKl0^ijl
0;^N_02kW[`30;^Q_P030;bO^`2mX[h0_J:n0080_J:n1@2nY;h0102mY/80_jFo0;nU_`2oYKl30;jX
``80`:O00P2oZ/@20<6Y`@@0`:c600D0`:k7o`000?l0003o00000<2^a`040<2`bP03o`000030//`0
`;;<0080`;;<00D0_KCA0;ndc`2o]<l0_kC?0;bfd`030;jfdP<0^kSF00@0_KSD0;Zif@2j^MT0^[WI
0P2l^]L40;Rjf`030?ooool00000oooo02<0oooo000@0?ooo`04o`00003oool0ooooo`000080oooo
0P1m/_H306n]m`80GJCf;03oool00`2gW[h0^inl0;^O_0040;^O_0040;jP^`2nX;X0_Z2j0;jP^P<0
`J:j0P31X[T40<>S^@D0aZFh1@38YkP50<VX^0D0bj^i1@3<[KX40<f_^`040<n`^P3>/Kd0c[6m0<ja
_@?o00000P3>/kl20<nd_`030<fe`P3?]/40ckK10080ckK100Co00000<jha03>^<@0c[S41@3=^/P0
0`3?^lL0bkc;0<^lb`030<fmb`050<Vmc`3;_/h0bkk>0<^ncP37_]801038_m820?ooo`03o`00003o
ool0oooo0300oooo00Co00000?ooo`3ooooo00001@3oool0102@ZnP0T:SU092Xi@2@Z>D309:UhP<0
U:?O102GXM/209ZOf080WYkD00<0VYcD09jKd@2NVm400P2NVm430::KcP<0YI_;00@0XiS:0:NHa`2W
V<L0YiS7102ZVLD20:fJa0030:bH`P2^VL40[YW10080[YW10`2aV/400`2`V;h0/YZn0;:J_P020;:J
_P<0]9^n00<0]9Vl0;JK_@2fVkd00`2fVkd0102gW[h0^9bk0;RL^`2hW;/40;VN_@D0^ijl00@0^j6n
0;bO^`2lWk/0_9nk0P2mX[h20;jQ^`@0_ZBn1@2oYKl01@2nZ<<0`:O00<2W`030Yl00_j[400@0`JW1
00@0`:c6o`000?l0003o00000`30[/L20<>]a@80`;3:0P33/<L01?l00000`;;<0<2bc032//X40;nd
c`D0_[KB00D0^kSF0;fhe02m^=@0_KSD0;Zif@040;bje`80^;[K00<0^[_J0?ooool00000903oool0
0100oooo00?o000009:ilP2B^O801029]o@207fbmP<0Kjgg0`1MY?H00`18V_<0=8k^03B>kP0V0?oo
o`<0]ijn1@2kWk`50;jP^P040<6R^P31X[T0`J:i0<6R^@<0`j>i0P34Y;P40<JU^0030<NU^038YkP0
b:Nh0080b:Nh00<0bJNg0<VX^039Z;P00P39Z;P00`3;ZKP0bj^i0<^[^@020<^[^@@0c:fj0P3>[[T2
0<f_^`80ck2j0ol000030<nb_0040<jc_`3?];l0ckBo0<nd_`D0ckK100<0dKO1o`00003>^<@00P3@
^L@30<fjb080ck_700<0bkc;0<fmb`3=_L/00P3=_L/40<^ncP050<c0cP38_m80b;oB0<RodP39`M80
0`3oool00ol00000oooo0?ooo`0_0?ooo`05o`00003oool0oooo0?ooo`2B/>/00`2A[NX3092[j0<0
T:SU0`2BYN8309BSg`80Uj7K00<0TYkL09JMf02FWMP0102JW=@309jKd@@0XY_>00@0YI_;0:>HbP2S
V<X0XiS:0`2WV<L30:ZIa@040:fJa02/V<80[9S20:bH`P@0[YW100@0/I[10;2H_P2`V;h0/9Rn102b
V[h0102dVkh0]9Vl0;BI_02dVK`40;JK_@@0^9bk0`2iW[d20;ZL^P@0^ijl102lWk/0102mX[h0_Z6k
0;jQ^`2nXK/30;jT_P80`:>k102oYKl40<2W`0<0`JW10ol000040<:[``050<2^a`33[LD0`jg50<>]
a@30/<X01033/<L01?l00000`[;:0<:bbP32//X20;ndc`80`[C=0`2n]]801@31]m00_KSD0;fhe02m
^=@0_kSC00@0_;[G00<0_[[F0;ZkfP2j^mX00P2j^mX00`3ooooo00000?ooo`0R0?ooo`003`3oool0
0ol00000oooo0?ooo`0209:ilP80RKOd0P2:]o@207jcmP<0Kjgg0`1KYOH01@15VO<0=8k^03B>kP0d
S^h08X7X00805WSS7`3oool00`2bW<80]ijn0;NN_P020;NN_PD0^inl1@2nX;X50<6R^@040<>S^@34
Y;P0a:Bh0<BT^0<0aZFh0P37YKP30<RW^080bJNg0`39Z;P20<^Y^0<0bj^i0P3=ZkP20<b]^P<0cZji
00D0cJnko`000?l0003o00000<n`^P050<nb_0@0ckBo00@0dKFn0<nf`@3?]/40ckK10P3A]l400ol0
0000d;W40=2ia0020=2ia0050<fjb03?^lL0ck_70<nka`3@_LL00`3=_L/20<nnb`80bkk>0`3<`<h0
1038_m80bL7B0<W1dP39`M830?ooo`03o`00003oool0oooo02d0oooo00Co000009Bck02D/n`0U;?/
0`2B/>/3096]jP<0T:_X00<0T:SU08^Vi`2<Xn@00P2<Xn@308jQh0@0TYkL0P2FWMP409ZLe0<0WY_A
0P2RVlh00`2OV<d0XiS:0:>HbP020:>HbP<0YiS70P2ZVLD00`2XUl@0[9S20:bH`P020:bH`P<0[YW1
00<0[YNo0;2H_P2`V;h00P2`V;h30;:J_P030;:H^`2dVK`0]9Vl0080]9Vl0`2fVkd20;NI^P@0^9bk
00@0^Ijm0;ZL^P2jW;X0^Ybj0`2kW[`00`2lWKT0_9nk0;bO^`020;bO^`D0_Z6k00@0_ZBn0<2S^`30
Xk/0`:>k0`2oYKl20<6T_080`:O000@0`ZJmo`000?l0003o00000P31ZL450<:[``@0`jg51@33/<L0
1Ol00000`[;:0<:bbP32//X0_kC?00@0`[C=00D0_[KB0<6gd031]m00`KO@0;fhe0030;nhd`030;bj
e`2n^]H0_[[F0080_[[F0P2j^mX0102l^mT0oooo0?ooool0000R0?ooo`003`3oool01?l00000oooo
0?ooo`3oool209>jlP@0R[Od0P1n/oH306n]m`<0FjGf00D0AIWc02f;k@0]Rnd0;H_]01Ili@0201Ih
h`804W;Q6`3oool30;:L`P@0]ijn1@2kWk`30;jP^P030;nQ^`31X[T0`J:i00<0`J:i1@34Y;P00`36
YKP0ajFh0<NU^0020<NU^0030<RW^039YkL0bJNg0080bJNg00<0bJRh0<^Y^03;ZKP00P3;ZKP01@3;
ZkT0cJ^h0<f[^03=ZkP0c:fj0080cZji0ol000040<n`^P030=2a^P3?/[`0ck:l0080ck:l00<0dK>l
0<nd_`3?];l00`3A]Kh01P3?]/40dKO10=6g`@3A]l40d;W4o`0000<0d;W40`3?^lL30=2ma`050<fm
b`3?_//0ckk;0<nnb`3;_/h0103<`<h40<W1dP<0oooo00?o00000?ooo`3oool0;@3oool00ol00000
oooo09Bck00209Bck0<0T[3[00<0TJgZ08b/k02<[>`00`2;ZNT208^Vi`<0S:?T0`2>XN0409:Ng080
UYgH0P2JW=@0102EVMD0VYSA09ZHd@2JV=4409nHc@@0XiS:00<0YiS70:FFaP2XUl@00`2XUl@40:bH
`P040:jI`@2^Ukl0[YNo0:jG_`@0/9Rn00@0/YZn0;:H^`2bV;/0/YRk102dVK`0102fVkd0]iVj0;NI
^P2gVKX40;RL^`D0^Ybj00@0^ijl0;bM^@2lWKT0_9fi0P2lWk/20;jN^@@0_Z6k1@30Xk/0102oYKl0
`JBl0<6T_031Y;`3o`0000040<:V_@31ZL40`JW10<6Y`@80`jRo0`32Zl<20<B[`@80`jg50P35[L<3
0<>`a`80aK3500Co00000<:bbP35//P0aK;80`32]<d01@34]L`0`KO@0<6gd031]m00`kO?00@0_kSC
1@2n^]H01P2j^mX0_;_I0;bkf@2l^mT0ooooo`000280oooo000?0?ooo`03o`00003oool0oooo0080
oooo0P2C^_8208Zgm080RkSd0P1o]?H3072_m`<0FjKg00D0@iWc02f;k@0]Rnd0;H_]01Ili@0200E`
gP03019bh@0HLN40677Q01L0oooo00<0Zi_60;:L`P2bW<800P2bW<840;NN_PD0^inl0P2nX;X30;nQ
^`<0`J:i00<0`Z>i0<BT^034Y;P00`34Y;P50<NU^0D0bJNg1@3;ZKP40<f[^0?o00000P3>[[T0103?
[kT0ck2j0<n`^P3?/;X20=2a^P<0ck:l0P3A/k`00`3?];l0dKFn0=6e_P020=6e_P@0dKO100@0dkW1
0=2ia?l00000d;W40P3B^l@00`3?^lL0d;g70=2ma`020=2ma`@0ckk;00@0d<3;0<c0cP3<`<h0c<3>
0P3>`Ll20<W1dP80bl;B0`3oool00ol00000oooo0?ooo`0/0?ooo`03o`00003oool0oooo00<0TK;]
0`2>[nd308b/k0<0RjWY0P2;Y^L308bSi0<0SZ7P0P2BW]`00`2;W=h0T9[I092Jf@0409FIe@<0VYSA
102OV<d20:>HbP040:2Fb@2UU/H0YIK60:FFaP<0Z9O40`2/V<800`2[UL00[YNo0:jG_`020:jG_`@0
/9Rn102bV;/40;BI_0@0]iVj0`2hW;/00`2iV[P0^Ybj0;ZL^P020;ZL^P030;^K]`2lWKT0_9fi0080
_9fi00@0_9nk0;jN^@2nW[T0_Yji0`2nXK/20<2P^@@0`:>k00@0`JBlo`000?l0003o00001@32Y[d0
0`31ZL40`jRo0<>X_`020<>X_`050<:[``34Zl40a:_10<B[`@33[LD01035[L<01P33/<L0aK350<F`
a@35/<D0`[;:o`0000<0aK;800D0`[C=0<Bec034]L`0a;G<0<6gd0030<>gc`80_kSC0P32^M830;jj
eP050<2ke@2l^mT0_;_I0;bkf@2m_=T00P3oool00ol00000oooo0?ooo`0O0?ooo`003`3oool00ol0
0000oooo0?ooo`030?ooo`<0U;[a0`2;^?@207ndmP<0L:og0`1KY_L204>Il`809h[/00D037SR00E`
gP05L=h006OI01Qah@0302Mfha<0oooo0`2[VlH30;:L`P<0]ijn0P2gW[l40;^O_0030;jP^P2oXK/0
_j6k0080_j6k0P31X[T30<:S^@<0a:Bh00<0aJBh0<NU^037YKP00P37YKP00`38Y[L0bJNg0<VW]`03
0<VW]`@0bjVh00<0c:^g0<f[^?l000000_l00000103>[KP0cZji0<j^^@3>[[T20<n_^@80ck2j103@
/KX0103?/[`0dK>l0=6c_03A/k`50=6e_P030=>g_P3A]l40dKO100<0dkW100@0d;W4o`00003B^l@0
d[_41@3@_LL00`3B_lL0ckk;0<nnb`030=30b`050<c0cP3>`Ll0c/7?0<k1c`39`M800`3;`]840?oo
o`03o`00003oool0oooo02/0oooo00Co00000?ooo`3oool0oooo0`2A/^d308j_k@0308b/k026Znd0
Q:O/0080Q:O/0P23Y>T308FQiP<0QikR102;W=h2092Jf@<0UIWE102JV=4209nHc@0409^Ec@2PU/T0
X9K90:2Fb@<0YIK6102XUl@0102/V<80ZiG00:^E`02[UL030:jG_`<0/9Rn0P2`U[`30;:H^`<0]9Vl
0P2eV;T40;NI^P040;RL^`2iV[P0^IZh0;VJ^080^Ybj0P2kVkL40;bM^@D0_Yji00@0_Z6k0<2P^@30
X;T0`:2i0P30Xk/3o`0000<0`JBl00<0`jBj0<:V_@32Y[d00P32Y[d50<>X_`@0a:_11@35[L<40<F`
a@80aK;800?o00000<Fbb035//P01034]L`40<>gc`030;nhd`32^M80`[WB0080`[WB00D0_[[F0<2k
e@30^mD0`;_E0;bkf@030;flf@80oooo00?o00000?ooo`3oool07P3oool000l0oooo00?o00000?oo
o`3oool0103oool00`2D^_40UK_a09Fkl@0308fil`<0PKGf0`1a/?P205bWm`80@Y[d0P0TRN`01@0<
N>8006SH001Xf000ImT0677Q00809gKS0`0mO^D>0?ooo`030::Ic02[VlH0Zi_60080Zi_6102bW<80
102gW[h0]ijo0;NN_`2gW[l40;^O_0D0_j6k00<0`J:i0<:S^@32XkT00P32XkT20<BT^0<0aJBh0P37
YKP30<RV]`<0bJNg0P3:Z;L20<^Y^0030<b[]ol0003o00000080cJ^h0`3>[KP00`3>[[T0cjni0<n_
^@020<n_^@030<n`^P3@/KX0d;6j0080d;6j103A/k`0103C]K`0dKFn0=6e_P3A]Kh20=>g_P030=6g
`@3C^L40dkW10080dkW100D0d[_4o`00003B^l@0d[_40=>ma0030=2ma`80d[o700<0ckk;0=30b`3@
`</00P3@`</40<k1c`<0bl;B0P3<a=<30?ooo`03o`00003oool0oooo02/0oooo00?o00000?ooo`3o
ool00P3oool308fbk`<0RJo^0P26Znd308BWk080PjCY0`25XNH308NNhP<0RicN0`2@V]T309FIe@80
VYSA00@0UIKA09^Ec@2KULd0ViG=102PU/T30:FFaP80Z9O400<0YiC30:^E`02[UL000P2[UL040:jG
_`040;2H_P2`U[`0/9Jl0;2F_0@0/YRk00@0]9Vl0;FH^@2eV;T0]IRi102gVKX40;VJ^0030;ZL^P2k
VkL0^i^g0080^i^g0`2lWKT00`2mW;L0_Yji0;jN^@020;jN^@@0`:2i0_l000030<6R^@80`JBl0P33
Y;X30<:V_@80a:Jk0`33Z;l20<JY_080a:_10P36Zkh30<F]``80ajk10P35/<D20<Naa0030<Fbb?l0
0000aK;80080ak?70P34]L`20<JfbP<0`kO?00D0aKS>0<:idP32^M80`[WB0<Bjd@030<2ke@040<:l
e@2m_=T0_KcI0;flf@80_kgH00<0ooooo`00003oool07`3oool000l0oooo00?o00000?ooo`3oool0
1@3oool309Fkl@<0SKWc00<0PKGf08>fmP23]_H00`1d/OP205nYn080@Y[d0P0TRN`01@05M]l006SH
001Xf000GM0006GI00809gKS0P0mO^D305N6i0P0oooo00<0UIOC0::Ic02RVL`00P2RVL`30:^KaP<0
/Yc200<0/9g40;NN_`2gW[l00P2gW[l30;^O_080^j2m102oXK/50<:S^@030<BT^035Y;P0aJBh0080
aJBh00<0ajFh0<RV]`38Y[L00P38Y[L20<VW]`<0bZRg0ol000020<b[]`030<f[^03>[KP0cZfh0080
cZfh1@3?[kT50=2a^P030=:b^P3A/k`0dK>l00<0dkFl00@0dKFn0=>g_P3C]kh0dkNn1@3C^L400`3D
^l40d[_4o`0000030=>ma0050=2ma`3B_lL0d[o70=:oa`3C`LP00`3@`</20=72b`80c/7?0P3?`ll0
0`3;`]80c<CC0<c4d`020<c4d`<0oooo00?o00000?ooo`3oool0:P3oool00ol00000oooo0?ooo`03
0?ooo`<0SK;_0`29[nh208J[k@<0Q:O/0P23Y>T308FQiP<0QikR00<0RicN08>Ih029Um/00P29Um/3
08nFeP@0UIKA0`2KULd30:2Fb@80YIK600<0XYC60:ND``2WU<<00P2WU<<40:^E`080[YNo00<0[IBm
0;2F_02`U[`00P2`U[`30;:H^`030;:F^P2eV;T0]IRi0080]IRi0`2gVKX00`2gV;P0^IZh0;VJ^002
0;VJ^0D0^i^g0P2lWKT20;fL]`@0_Yji00D0_ijfo`000?l0003o00000<2P^@040<6R^@030<6T_033
Y;X0`jBj0080`jBj00<0`ZJm0<BV^`34Y[/00P34Y[/01@33Z;l0aZVl0<JY_036ZK`0a:_100@0aZ^n
00D0aJg30<N^`@37[/40ajk10<F`a@040<Naa0050<Fbb?l00000ak?70<Nca`34]L`01036]/X01@33
]ll0aKS>0<FhcP35^<h0`[WB00<0a;[A00D0`;_E0<:le@32_=D0`[cE0;flf@040;nmf0030?ooool0
0000oooo01h0oooo000>0?ooo`03o`00003oool0oooo00L0oooo00<0UK_a09Nkl@2G^o40102?^O<2
08>fmP<0M;7h0`1OZOP204>Lm00602>:k005M]l006;A001Rd@00GM0006GI0P0<JM`203eni@80EhKT
0`1`S^0308FCfP@0UIOC0`2RVL`40:^KaP040;:L`P2`WL@0/9g40;2Ma0@0]ijo00@0^inl0;^P_@2k
X;d0^j2m0`2oXK/20;nR^`@0`Z>i1@35Y;P50<RV]`030<VW]`3:Z;Oo000000;o00001@3<ZkL50<j]
^0030=2^^03?[kT0cjni0080cjni00@0dK2i0=2a^P3@/KX0d;6j0P3B/[X00`3A/k`0dkFl0=>e_002
0=>e_0@0dkNn00@0eKVn0=>i`@3C^L40dkW10P3D^l400`3B^l@0dkg4o`0000020=>ma0<0d[o70`3C
`LP01@3@`</0dL;;0=72b`3A`//0c/7?00<0cl??00D0d<G@0<c4d`3<a=<0c<CC0<g5d`040?ooo`03
o`00003oool0oooo02P0oooo00?o00000?ooo`3oool01@3oool308Zbl080Q:k`0`1oZ^l307bVkP80
Nj;[0`1kW^P307jKi080PiWP0`29Um/308nFeP<0UIKA0`2KULd20:2Fb@0309fCb@2RU<H0XYC60080
XYC60`2WU<<30:^E`0030:VC_`2]U;d0[IBm0080[IBm102`U[`00`2bV;/0/YJj0;:F^P050;FH^@04
0;NI^P2gV;P0]iRh0;NH^080^IZh0P2jVKH40;^K]`040;bM^@2mW;L0_Ibg0;fL]`80_Yji0ol00004
0<2P^@@0`J:i1@33Y;X50<BV^`@0aZVl1@36Zkh40<N^`@D0ak740P37/lL00ol00000ak?70<JfbP04
0<JfbP@0aKS>0`34^]401035_=40`[cE0<:le@32_=D20<>ne@<0_kgH00@0`KoH0?ooo`3ooooo0000
7P3oool000h0oooo00?o00000?ooo`3oool02@3oool209Nkl@80SkWc0P2A^_<208JgmP<0Mk?h0`1R
ZoP204JOm@8098c/0P00H]42001BaP8036WL0P0SLn4205N6i0<0L8kP0`25TmX309FGd`@0XYW<0P2[
VlH00`2XVlT0/9g40;2Ma0020;2Ma0<0]ijo00<0]Yo10;^P_@2kX;d00`2kX;d0102oXK/0_j:k0;nR
^`2oX[/30<:S^@80`jBj1035Y;P01036Y[P0b:Jg0<RV]`38Y[L3o`0000<0bZRg00<0c:Zg0<b[]`3<
ZkL00P3<ZkL0103>[;L0cZfh0<j]^03>[KP20=2^^0<0cjni0`3A/;T0103@/KX0d[:j0=:b^P3B/[X5
0=>e_0030=Fg_03C]kh0dkNn00<0eKVn00D0dkW10=Bk`@3D^l40e;_10=Jm`@020=>ma004o`00003E
_l@0eKo40=:oa`@0dl78103A`//30<o3c`<0d<G@00@0c<CC0<g5d`3=aM<0cLGC0`3oool00ol00000
oooo0?ooo`0X0?ooo`03o`00003oool0oooo00H0oooo0`2:/_0208B^l0<0Oj[_0`1lY^h207^Rj`<0
NikX0`1nVn@208>Ih0<0RIOK0`2?U]H309FFd@0309^Ec@2FTlh0WI?900<0WI?90`2RU<H40:ND``04
0:^E`02YTkl0ZI>o0:VC_`<0[IBm0`2`U[`00`2`U;/0/YJj0;:F^P020;:F^P<0]IRi00<0]INh0;NH
^02gV;P00P2gV;P0102iV[P0^YVf0;ZI]P2jVKH40;^K]`<0_Ibg0ol000030;nN]P<0`:2i0P31X;L2
0<6R^@80`j:g1033Y;X00`35Y;P0a:Jk0<BV^`020<BV^`@0aZVl00<0b:Vk0<J[_P36Zkh00P36Zkh4
0<N^`@040<V_`037/L@0ak740<Naa080b[;30P37/lL00ol00000bKG60<JfbP020<JfbP80bKO90P35
^<h20<Njc@050<Bjd@35_=40aKcA0<Fld@32_=D01033_]D01P2o_MP0`KoH0<6of031_mP0ooooo`00
01h0oooo000>0?ooo`03o`00003oool0oooo00X0oooo0P2H^o04096jl`80Q[Of0`1g/oP306:[n080
AYoe0P0TS>`01000M=`005g<001BaP00D/H2001Jd@0402=ch@10O^@0@7kT041ni080L8kP0`25TmX4
09FGd`80XYW<00<0WIW@0:RKb@2XVlT00P2XVlT40;2Ma0040;NN_`2fWl40]Yo10;JO`@@0^j2m1@2o
X[/01032XkT0`jBj0<>T^P33Y;X30<FT^080aZJh0ol000000`38Y[L0bJRh0<ZX]`020<ZX]`80c:Zg
0`3<ZkL20<j/]`80cZfh103@[[P00`3?[kT0dK2i0=6`^@020=6`^@@0d[:j00@0e;Fj0=>e_03C]K`0
dkFl0P3E]k`00`3C]kh0eKVn0=Fi_P020=Fi_P@0e;_10P3F_L40103C_LCo00000=Foa03E_l@50=?1
b0030=G3b03A`//0dL;;0080dlC<00<0cl??0=35d03@aM000P3@aM030<g5d`030<g7e03oool0oooo
0080oooo00?o00000?ooo`3oool09`3oool00ol00000oooo0?ooo`070?ooo`<0Q[;b0P1o[_8307VY
l@<0LjC`0P1aWnh2072Kj`<0LiSW0P1iU^<307nDgP<0Qi?H0`2?Tm<309JCcP<0WI?9102RU<H20:ND
``030:FB`P2YTkl0ZI>o0080ZI>o102]U;d00`2`U[`0/9Bk0;2D^`040;:F^P040;FH^@2eUkP0]INh
0;FG^0@0]iRh102jVKH30;^K]`040;bJ]_l0003o0000o`000080_Ibg1@2oW[H01@30X;T0`J2g0<6P
]`31X;L0`J:i00<0`j:g0`33Y;X20<FT^0<0a:Jk0P36YkT20<JY_080b:Vk0`36Zkh20<V/_@80ajk1
0`39[l001`37/L@0b[;30<Zb``3://<0ak?70<Vea_l000000P39]LH01@36]/X0bKO90<Vgb@39]lT0
aKS>00<0ak[=1035_=450<>ne@<0`KoH00@0`/7I0?ooo`3ooooo00007@3oool000h0oooo00?o0000
0?ooo`3oool02`3oool209Rkl080TK[c0P2C^o8308Vhm@<0NkCh0`1W[OT204^RmP0602R@kP00M=`0
05_8001Kb000B[`005[A0P04I=T2041ni0<0GXWS0`25TmX209FGd`0308jFe`2MVM00WIW@0080WIW@
0`2XVlT30;2Ma0030:nNaP2fWl40]Yo10080]Yo10`2kX;d20;^Q_P@0_j:k1@33Y;X01035Y;So0000
o`000?l000030<RV]`80bJRh0P3:Z;L40<bZ]`030<b[]`3>[;L0cZbg0080cZbg00<0cZfh0=2^^03@
[[P00P3@[[P50=6`^@<0d[:j0`3D]KX0103C]K`0eKNl0=Fg_03E]k`50=Fi_P030=Nk_`3D^l40e;_1
00<0e[g10P3E_l@00ol00000eKo40=O2a@030=?1b080eL?800D0dL;;0=?4c03Ca<`0dlC<0=C6c@03
0=35d080dLOA00@0cLGC0<g7e03=am@0cLOD103oool00ol00000oooo0?ooo`0V0?ooo`03o`00003o
ool0oooo00P0oooo0`26/_8207n^lP<0NJWa0`1cY?02076OkP80L9_[0`1cV>L207VFh`<0OiCN0`27
TmP208nCd`<0UY?>102MTlT20::DaP0309nBaP2UT/80YI;20080YI;20`2YTkl30:fD_@030:bC_@2`
U;/0/9Bk0080/9Bk0`2bU[X50;FG^080]iRh0P2hUkH40;ZI]P?o000000@0_9Zf0;fL]`2mW;L0_Ibg
0P2nW;D40;nN]P@0`J2g1@33X[L00`33Y;X0aJBh0<FT^0020<FT^0050<BV^`36YkT0aZNi0<JW^@36
ZK`01038ZK/01@36Zkh0bJbm0<V/_@39[;d0ajk100@0bJo0103://<30<VeaP03o`000039]LH0bKO9
0080bKO900@0bkW90<Njc@37^/d0ak[=0P39_<d30<Fld@040<Nnd@33_]D0`kkE0<>ne@80aKoE00@0
`KoH0<;1f@32`MT0`/7I0P3oool00ol00000oooo0?ooo`0J0?ooo`003P3oool00ol00000oooo0?oo
o`0<0?ooo`<0V[c`0`2C^o800`29^?D0S;Wd08bim00307jfm`80K;3i0`1AYOL202jDl08005_800@0
04>c001:`P04I=T016CI0P10O^@205j9h`<0NI7N0`2>U]L409fId0@0Z9_900@0/9g40:nNaP2_W/H0
[ik6102fWl40102kX;d0^j6n0;^Q_P2kXKh40;nR^`030;nS_033Y;X0`jBj00?o00001036Y[P00`38
Y[L0bJRh0<VX^0020<VX^0030<ZX]`3<Z[L0c:Zg0080c:Zg1@3>[;L50=2^^0@0dK2i0P3C/[T00`3B
/[X0e;Fj0=Be^P020=Be^P@0eKNl00@0ekVl0=Fi_P3E^Kh0eKVn0P3G^kl00`3D^l40e[g10=Jm`@02
0=Jm`@040=S0`P3E_l@0eKo4o`000080el;500@0dl780=G3b03E`lP0eL?80`3Ca<`30=C6c@040=35
d03Aam40dLOA0=77d@<0cLOD00<0c/WF0?ooo`3oool00P3oool00ol00000oooo0?ooo`0V0?ooo`03
o`00003oool0oooo00T0oooo0`23/_<207Z]l`<0LZSc0P1ZX_4206FLk`<0HiS]0P1cV>L307VFh`80
OiCN0`27TmP308nCd`<0UY?>0P2MTlT00`2HTL/0Wi;609nBaP0209nBaP<0YI;2102YTkl00`2]U;d0
[9>m0:bC_@040;2D^`80/YJj0P2bUKT40;FG^0050;NH^02hUkH0^9Nf0;RG]P2jVKH00ol000050;bJ
]P040;fL]`2nW;D0_Ybe0;jL]@<0_ijf00<0`Ije0<6P]`31X;L00P31X;L00`33X;D0`j:g0<>R]`02
0<>R]`D0aJBh1036YkT50<RY^`@0bJbm1@39[l000`3</Kl0b[;30<Zb``020<bd`P<0bKG600?o0000
0<bgaP39]lT00`3;^LT00`37^/d0bKc=0<Vlc@020<Vlc@050<Fld@37_]40akkA0<Nnd@33_]D00`35
_mD40<;1f@80oooo00?o00000?ooo`3oool06P3oool000h0oooo00?o00000?ooo`3oool03@3oool0
0`2J_?00Vkc_09^lk`0409FklP80S;Wd0`1n]_L206b`n@<0DJGg0`0^U?000`00F/H004>c001:`P02
00ATf@8097?Q0P1NRN<307VAgP<0SYKG102MVM020:RKb@030:FLc@2_W/H0[ik60080[ik60`2fWl40
0`2eX<<0^j6n0;^Q_P020;^Q_P<0_j:k00@0_j>lo`000?l0003o00000P33Y;X00`33YK/0aZJh0<JV
^0020<JV^0D0bJRh1@3<Z[L00`3=[;P0cZbg0<j/]`020<j/]`040<n^^03@[[P0d:jh0=2^^080dK2h
0P3A/;T30=>b^@030=:b^P3D]KX0e;Fj0080e;Fj00<0e[Nk0=Fg_03E]k`00`3G^K`01@3E^Kh0ek^o
0=Nk_`3G^kl0f;jo00<0e[g10P3H`<800`3E_l@0el;5o`0000020=O2a@<0eL?80P3Fa/X00`3Ca<`0
e<K=0=C6c@020=C6c@<0dLOA0P3AbM80103=am@0c/WF0<k9eP3>bMH40?ooo`03o`00003oool0oooo
02D0oooo00?o00000?ooo`3oool02P3oool308>bl`80NZgc0`1bZ?<206ZRl@80IIc_0`1SV>d0101U
U>T0Ji;U06^Bi@1[T^D307>Ah@<0Qi?H0P2?Tm<209JCcP03092Ad02HTL/0V97;0080V97;0`2OT/H3
0:FB`P<0ZI>o00<0Yi:o0:bC_@2/Tkd00P2/Tkd30;2D^`040;:F^P2bUKT0/YFi0;:E^@@0]INh0P2h
UkH3o`000080^YVf0P2jVKD40;bJ]PD0_Ybe00@0_ijf0<6N]@31W[D0`Ije0P31X;L20<>P]@@0`j:g
00<0aJ:f0<FT^035Y;P00P35Y;P40<JW^@030<VX^038ZK/0b:Vk0080b:Vk00<0bZ^j0<V/_@39[;d0
0P3;[[`30<V_`080c;6o00<0b[;30<bd`P3<]<800P3<]<801039]LH0c;O6o`00003<]lH40<^ib@05
0<flb@39_<d0bKc=0<Vlc@3;_/h00`37_]401039`=80aKoE0<Foe@35_mD20<K1eP80`/7I00D0`l;I
0?ooo`3oool0ooooo`00000K0?ooo`003@3oool00ol00000oooo0?ooo`0?0?ooo`<0Vkc_0P2E^o82
09Nll@80Sk[d1023]oL2076bn@<0F:Wh0P0fVO800`0;P><005c6000o[@02001Cb`8097?Q00@0Ah;U
07VAgP1iTMh0NI7N0`2>U]L209fId080Ui[D0`2UW<d50:nNaP040;JO`@2eX<<0]J330;FP``@0^j6n
0ol00000102oXk`0`jBj0<>T^P33Y;X20<>U^`<0aZJh0P37YkT40<VX^0040<ZY^03<Z[L0c:Zg0<bZ
]`80cJbh0`3>[;L20<n^^080d:jh0`3A/;P00`3A/;T0dk:i0=>b^@020=>b^@@0e;Fj0P3F]k/00`3E
]k`0ekVl0=Ni_0020=Ni_0@0ek^o0P3H_[l01@3F_L40f<320=S0`P3H`<80fL?30080el;500Co0000
0=S4aP3Ha<H0eL?80`3Fa/X0103Gb</0e<K=0=C6c@3Da/d20=C9c`040=77d@3AbM80dLWB0=79dP<0
c/WF0`3>bmL20?ooo`03o`00003oool0oooo02@0oooo00?o00000?ooo`3oool0303oool3086bm080
MZge0`1[Yo@2062Pl`80F9Wa0`1SV>d0101UU>T0Ji;U06^Bi@1[T^D207>Ah@<0OI3K0P27T=H4092A
d0<0V97;0`2OT/H40:FB`P030:VC_`2WT[l0Yi:o00@0[9>m0P2`U;/00`2_U;X0/YFi0;:E^@020;:E
^@<0]INh0ol000030;RG]P040;ZI]P2jVKD0^YVe0;ZI]@@0_9Zf00<0_IZd0;jL]@2nW;D00P2nW;D4
0<6N]@040<6P]`33X;D0`j2e0<>P]@<0`j:g0P35X[H30<FT^080ajFg0P36YkT20<VX^0<0b:Vk0P3:
ZkX00`39[;d0bjjl0<^^_0020<^^_0040<V_`03</Kl0c;6o0<ba_`D0c;C20`3<]lH01?l00000c[W6
0<^ib@3;^LT30<flb@050<Vlc@3;_/h0bkk>0<^ncP37_]400`39`=801@35_mD0a/7F0<K1eP36`MH0
`/7I00<0`l;I0P3oool00ol00000oooo0?ooo`0I0?ooo`003@3oool00ol00000oooo0?ooo`0@0?oo
o`0309^lk`2M_>l0WKc_00@0Ukca0P2?^_@208>gm`80QkWf0P1g]?T3062]n@80?ike0P0;P><00`00
HLP005?;001Cb`02009Sf0<0JHgS0`23UM`409NJe0@0YIc=0`2_W/H00`2]WlT0]J330;FP``020;FP
``80^j6n0_l000050;nS_0030<>T^P33YK/0`jFk0080`jFk00@0aZJh0<NW^@37YkT0ajNi0`39Z;P2
0<ZY^080c:Zg103=[;P00`3>[;L0cjjh0<n^^0020<n^^0040=2^^03A/;P0dK2h0=6`^0D0dk:i00<0
eKFj0=Be^P3D]KX00`3F]k/50=Ni_0030=Rl_@3G^kl0ek^o00<0f;jo103H`<820=W3``050=O2a@3H
a<Ko00000=S4aP3IalP00`3Fa/X20=O8b`040=C6c@3DbLl0e<W?0=C9c`<0dLWB0P3Bc=@00`3>bMH0
c/_G0<k;e`020<k;e`<0oooo00?o00000?ooo`3oool08`3oool00ol00000oooo0?ooo`0=0?ooo`<0
PK;d0P1f[OD306^Wm080H:3c0P1HVO4305>CkP0405>?j`1[T^D0Ji;U06^Bi@80Li7Q0`1mT=/208N@
eP<0T97@0`2HTL/409nBaP80YI;200<0XY730:NB_`2WT[l00P2WT[l30:bC_@040;2D^`2_U;X0[iBj
0:nD^P@0/YFi0_l000020;FF]`@0^9Nf102jVKD30;bJ]P80_IZd102nW;D40<6N]@D0`j2e00<0`j:g
0<FR]P35X[H00P35X[H01@35Y;P0ajFg0<NU]`37YKL0aZNi00@0bJRh00@0b:Vk0<Z[^P3:ZkX0bZ^j
1@3;[[`40<ba_`040<jc_`3<]<80c;C20<bd`P80ckK20P3<]lH00`3>^LKo00000<^ib@040<flb@@0
bkk>0`39`=801@3;`m<0a/7F0<K1eP36`MH0alCG00<0`l;I0`34a=X00`3ooooo00000?ooo`0I0?oo
o`003@3oool00ol00000oooo0?ooo`0A0?ooo`<0WKc_0P2G_?400`2I_?00T[_c09:kl`0209:kl`<0
QkWf0P1g]?T3062]n@80?ike0P0DQnL01@00Ild002ZN000o^002HmP0:WKS00<0JHgS0`23UM`409NJ
e0<0YIc=00@0[ik60:fOb@2]WlT0[Io90`2eX<<3o`0000<0^Z?1102oXk`50<>U^`D0ajNi00<0bJRh
0<ZY^03:ZKP00P3:ZKP00`3<Z[L0cJbh0<f/^0020<f/^0D0cjjh103A/;P0103C/kT0dk:i0=>b^@3C
/[T30=Fe^P050=Be^P3F]k/0e[Nk0=Jg^`3H^[`00`3G^K`30=Rl_@050=Nk_`3H_[l0f;jo0=Rn_`3J
`L400P3H`<830=W3``<0f<C600Co00000=W7b03IalP0e/K:0`3Gb</30=C9c`80eLc@00D0dLWB0=;<
e03Bc=@0d/cD0=;>eP030<k;e`80c/gI0`3oool00ol00000oooo0?ooo`0R0?ooo`03o`00003oool0
oooo00l0oooo0`1n/_D207:]mP80I:Kf0P1FW_@204VEl@<0Di?^00<0Dho[05V=j01ISNP00`1SS>@2
07f@f`<0Qi3F0`2@TM0309RAb`80Wi;600@0Vi380::A``2RTL<0XY73102WT[l20:bC_@030:^B_@2_
U;X0[iBj0080[iBj00@0/YFio`000?l0003o0000102eU[L30;RG]P80^9Ne102jVKD0102lV[H0_IZd
0;fJ]02mV[@30;jL]@80`9bd0`31W[D00`33W[@0`j2e0<>P]@020<>P]@D0aJ:f1037YKL50<VX^0@0
bZ^j00<0cJfi0<^^_03;[[`00P3;[[`00`3>/;`0c;6o0<ba_`030<jc_`050<bd`P3?]/80ckK20<nf
`P3<]lH00`3>^LH01?l00000cKc90<flb@3=_<T20<nob`80bkk>0P3=`Ll01@39`=80bl?C0<_3d`3;
`m<0a/7F00<0alCG00D0`l;I0<C4fP34a=X0a<CJ0<C6f`020?ooo`03o`00003oool0oooo01L0oooo
000=0?ooo`03o`00003oool0oooo0180oooo102N_Nh209Vll080T[_c0P2D_?8308^jm@<0O;Oh0`1W
/?X204VTm`06022?k000Ild0J@00000/XP02HmP0:WKS0`1YSN<308>Eg0<0Ui[D0P2UW<d00`2PWM40
[Io90:fOb@020:fOb@?o000000<0]J330;>RaP2jXl400`2jXl430;nS_080_jFn1033YK/00`34Yk`0
ajNi0<NW^@020<NW^@D0bZVh1@3=[;P00`3?[[T0cjjh0<n^^0020<n^^0030=6a^@3A/;P0dK2h00<0
dk>i00<0dk:i0=Fe^P3E]KX00P3E]KX30=Jg^`<0f;Zl00<0ekVl0=Rl_@3H_;d00P3H_;d30=Rn_`80
f/7100<0f<320=W3``3I`l<00P3I`l<0103Ka/D0f<C60=S4a_l000020=W7b0<0elS;0P3Hc<d01@3D
bLl0eLc@0=G<d03Ec=00e/oB00<0d/cD0P3Bc]H0103>bmL0c/gI0<k=f@3>cMT30?ooo`03o`00003o
ool0oooo0280oooo00?o00000?ooo`3oool0403oool307jcmP80Kjkg0P1NY_H205JNm080BIGa0P11
SNh203j8j`80FHgX0P1SS>@206n<g`<0O8gI0`28S]<309:?c@<0Vi38102RTL<30:NB_`050:bC_@2[
T[d0Zi:m0:^B_@2_U;X00ol000020;:E^@80/YBh102eU[L0102hUkH0^9Ne0;RG]@2hUkD40;ZI]@D0
_IZd00@0_Ybe0<2L]030W;@0`9bd0P31W[D20<>N]0@0`j2e00<0aJ6d0<FR]P35X[H00P35X[H40<NU
]`030<VV]P39Z;P0bJRh0080bJRh00<0bjVh0<Z[^P3:ZkX00P3=[KT30<^^_080c[2l00<0c;6o0<jc
_`3>/kl00P3>/kl40<nf`P<0c[W600@0d;c6o`00003@_<H0cKc90`3?_l/0103;_/h0cL7?0<g1c`3=
`Ll30<_3d`80c<GD0`37a=L20<S6f0060<C4fP34a]/0a<KK0<C6f`3ooooo00006@3oool000d0oooo
00?o00000?ooo`3oool04`3oool209jmkP80X;g]0`2K_>l309BllP0308^jm@2?^o@0Sk_d00<0P[Sg
101_/oX01@1DZOT0;YO`02jGl000L=@002bR0080:WKS0P1CQnH307FChP<0Si[J102PWM43o`000003
0:fOb@2eX<<0/j;60080/j;61@2jXl40102oXk`0_jFn0;nU_P2oYKh30<>U^`80a:Nl1037YkT00`38
Z[/0bZVh0<ZY^0020<ZY^0040<b/^P3=[;P0cJbh0<f/^080cjji0`3?[[P20=6a^@030=6`^03C/kT0
dk>i0080dk>i1@3E]KX00`3G^;/0e[Nk0=Rj_0030=Rj_0D0f;bm00<0f[no0=Rn_`3J`L400P3J`L40
103LaL<0fL?30=W3``3I`l<20=_6a@070=S4aP3IalP0fLO8o`00003IalP0f/_:0=O8b`030=S<c@<0
eLc@0`3Fcm80103Bc=@0d/kF0=;>eP3Bd=P30<k=f@80cLoK0`3oool00ol00000oooo0?ooo`0Q0?oo
o`03o`00003oool0oooo0140oooo0`1n/oH206n^m`<0GZKf00<0C9cd03^Al00kTO000P11SNh203j8
j`80@hGX0P1SS>@206n<g`<0O8gI0`28S]<209:?c@@0Vi380`2RTL<20:NB_`030:FA`02[T[d0Zi:m
00?o00000`2_U;X0102bUKT0/YBh0;:D^02bU;P40;FF]`@0^9Ne0`2jVKD00`2kVK@0_IZd0;fJ]003
0;fJ]0@0`9bd00@0`Ije0<>N]033W[@0`ijd0`33X;D20<FQ]0<0aJ:f0P37Y;D20<NU]`80bJJf0`39
Z;P20<^Y^0030<Z[^P3=[KT0cJfi0080cJfi00@0bjjl0<j`_03>/;`0c[2l1@3>/kl00`3A][l0ckK2
0<nf`P020=6i``050<jiaP3@_<H0d;c60=2la_l00000103?_l/30<g1c`80clC@00<0bl?C0<c5e03<
aM@00P3<aM@01037a=L0b<KH0<S6f038a]P30<C6f`040<G8g@3oool0ooooo`0001P0oooo000=0?oo
o`03o`00003oool0oooo01@0oooo102P_Nd00`2K_>l0WKg_09fmk`0409Nll@80Sk_d0`22^?L206nc
nP0307Nfn@1O[_X0Gjkj00<0;YO`00<004ba00IVfP06I]X00P1CQnH307FChP<0Si[J0ol000030:fO
b@030:VQcP2cX/H0/j;600<0/j;60`2jXl400`2jYL@0_jFn0;nU_P030;nU_P040<>U^`34Yk`0a:Nl
0<BW_0<0ajNi0P38Z[/30<ZY^080c:bj0P3=[;P40<n^^@040<n^^03A/KT0dK6i0=6a^@D0dk>i00@0
eKJj0=Fe^P3E]KX0eKFj0P3G^;/00`3F]k/0f;Zl0=Rj_0020=Rj_0040=Zn_@3H_;d0f;bm0=Rl_@80
f[no103J`L420=c5``050=W3``3Ka/D0flK50=_6a@3Lb/L00`3IalP00ol00000f/_:0=S<c@020=S<
c@80fLo?00<0eLc@0=K?dP3Fcm800P3Fcm800`3FdMD0d/kF0=;@f0020=;@f0040<k=f@3=cm/0cLoK
0<gAg@@0oooo00?o00000?ooo`3oool0803oool00ol00000oooo0?ooo`0B0?ooo`<0O[Cg0P1^[_P3
05^Vm`0504BJl`0kTO00>i7`03^Al00]Q^/00P0UO^L204>5j00404f5iP1LQn80G8OR05b7hP80O8gI
0`28S]<309:?c@<0Vi380P2RTL<00`2NT<D0YI700:FA`003o`000080Zi:m0`2_U;X00`2^Tk/0/YBh
0;:D^0020;:D^0<0]IJg0P2fU[L40;RG]@040;ZI]@2kVK@0^iVd0;^I]0<0_IZd00<0_Y^d0<2L]030
W;@00P30W;@50<>N]0030<>P]@35XK@0aJ6d0080aJ6d00D0aJ:f0<NT]@37Y;D0ajBe0<NU]`040<VV
]P040<VX^03;ZKP0bjVh0<^Y^0D0cJfi103>/;`0103@/k`0c[>o0<jc_`3>/kl20=6f_`040<nf`P3A
^L<0dKW30=6i``D0d;c600?o00000<nob`3?_l/00P3A`/`01@3=`Ll0clC@0<o4d03?a=00d<SB00<0
c<GD00@0cLWF0<S6f038a]P0b<KH0P39bMX01034a]/0aLSM0<G8g@35b=d20?ooo`03o`00003oool0
oooo01D0oooo000<0?ooo`03o`00003oool0oooo01H0oooo0P2P_Nd20:6mk@<0WKg_0P2G_?4209Zl
l0<0T[cc0`27^_H207Nfn@<0Gjkj0`0lWo@01006I]X0=WgV03ImiP0fONH207FChP?o0000102PWM40
102]WlT0ZJ7>0:VQcP2YXLh40;>RaP040;ZS`@2jYL@0^ZG40;ZUa0@0_jFn00<0`:O10<BW_034Yk`0
0`34Yk`00`37YkT0b:Zk0<RZ^`020<RZ^`030<ZY^03<[;X0c:bj0080c:bj00<0cJbh0<n^^@3?[[T0
0P3?[[T40=6a^@040=>d^P3C/kT0dk>i0=>c^@<0eKJj00@0eKFj0=Nh^`3G^;/0ekRk103H^[`30=Zn
_@050=Rl_@3J_kl0f[no0=Zo_`3L`l400P3J`L430=c5``<0flK50`3Lb/L01P3IalP0f/_:0=[;b_l0
0000flo=0=S<c@<0fLo?00@0fM;B0=K?dP3Fcm80e/oB0P3FdMD30=;@f080dM?J00@0cLoK0<gAg@3=
dMd0cM7M0`3oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo01@0oooo0`1n]?L206j^
n0<0FjKg0P14V_<202f=kP0301UniP0UO^L09GkW00809g[U00<0CHGV05b7hP1LQn800`1]RMd308R>
d`80TXo=0P2KT<P00`2ESlX0WY3509j@a@03o`000080YI70102[T[d0102_U;X0[Y>k0:jC^`2^Tk/4
0;:D^0040;FF]`2fU[L0]YJg0;JF]`@0^9Ne102kVK@20;fJ]0<0_Y^d0`30W;@00`31WK<0`ijd0<>N
]0020<>N]0D0aJ6d1037Y;D50<VV]P@0bjVh00<0cZbh0<f]^@3=[KT00P3=[KT00`3?[kX0c[2l0<j`
_0030=2c_0040<jc_`3A][l0dKJo0=6f_`@0dKW300@0e;g40=2laP3@_<H0d;c60P3C`<P01Ol00000
dL;<0=72c03A`/`0dlK>00<0clC@0P3@b=801@3<aM@0cLWF0<g9eP3=bMH0b<KH0080bLWJ00D0bLcL
0<G8g@35b=d0aLSM0<C;g`020?ooo`03o`00003oool0oooo01D0oooo000<0?ooo`03o`00003oool0
oooo01P0oooo0`2Q_Nd0102M_Nl0Wkg^09nmkP2O_Nh309Zll00309:ll`2E_?80UKcb00@0S;_e0P1n
^?P306VbnP80BZKh00<0057903Imi_l000000_l00000101RSnL0Si[J08nJfP2?V]X20:2Md@0309ZN
e`2YXLh0ZJ7>0080ZJ7>0`2cX/H00`2bY</0^ZG40;ZUa0030;ZUa080_jFn0P30Yl440<BW_0030<FZ
_`38Z[/0b:Zk00<0b:Zk1@3<[;X40<n^^@040=2a^`3A/KT0dK6i0=6a^@80dkBj0P3C/kT40=Ff^P@0
ekRk00<0fKbm0=Rj_03H^[`0103J_[d30=Zo_`80g<?100<0f/710=c5``3LaL<00P3LaL<00`3MbLD0
flK50=c:a`030=c:a`<0f/_:00?o00000=_?c@3Ldll00`3Icll20=WBdP030=K?dP3FdMD0e]7E0080
eMCH00@0d]3H0=7CfP3AdmX0dM?J0`3=dMd20<cBg`<0oooo00?o00000?ooo`3oool07P3oool00ol0
0000oooo0?ooo`0F0?ooo`80OkKg0`1^/?P205VWn080?i[c0P0RRN/0100IO^H02g?P00]ch00WN^D2
035ki@80G8OR0P1]RMd307f<e`80RXgA0P2ESlX3o`000080WY35102UTL020:^B_@030:VB_P2^Tk/0
[Y>k0080[Y>k0`2bU;P00`2bUKT0]YJg0;JF]`020;JF]`<0^9Ne00<0^IRe0;^I]02kVK@00P2kVK@0
0`2mV[@0_Y^d0;jK]0020;jK]080`9bd0P31WK<40<>N]0030<BP/`35XK@0aJ6d0080aJ6d1037Y;D0
0`39Y[D0bJJf0<VV]P020<VV]P030<bY]P3;ZKP0bjVh0080cZbh0`3=[KT20<n_^P030<j`_03@/k`0
d;>l0080d;>l103A][l00`3D^/00dKW30=6i``030=Bma0050=2laP3C`<P0dl380=?0b?l000000P3A
`/`30=?6cP040<o4d03@b=80d<SB0=38dP<0cLWF0P3=c=P01@39bMX0bLcL0<W<g039c=`0aLSM00<0
a<_O0P3oool00ol00000oooo0?ooo`0D0?ooo`00303oool00ol00000oooo0?ooo`0I0?ooo`<0X[g/
0P2O_Nh20:2mk@<0W;g_0`2E_?8208bkm@04092lm024^_L0Q;[g08Bjm`<0L[Gj0ol0000203ImiP80
HXoW0`23VN0409ZNe`@0ZJ7>00@0/j;60;:Tb`2bY</0/ZC;102jYL@00`2oYKh0`:O10<2W`@020<2W
`@80a:Nl0P35Z[l40<RZ^`030<V]_@3<[;X0c:bj0080c:bj0P3=[k`20<n^^@<0d;6k00<0dK6i0=>d
^P3C];X00P3C];X00`3C/kT0eKJj0=Ff^P020=Ff^P030=Nj_03G^;/0ekRk00<0fKbm00<0f;Zl0=Zn
_@3J_[d00P3J_[d00`3K`[l0f[no0=c3`@020=c3`@040=g8``3LaL<0g<G30=c5``80gLW500@0g/k8
0=c:a`3Lb/L0g<[70P3Mc/X0103JblX0flo=0=_?cOl000020=cCc`030=W?c`3Id]80fM;B0080fMKE
00@0e]7E0=GDf03Ee=P0eMCH0`3AdmX20=3Eg@040<gAg@3<d]l0c=;O0<[Dh@@0oooo00?o00000?oo
o`3oool07@3oool00ol00000oooo0?ooo`0G0?ooo`80PKOg101`/OT00`1IZ?P0?9_c03bKl`0202:9
j`0500Mgh00;Ln002g?P00M/g@0aNnD00`12O^@206f9g@<0OHcG0ol0000209F?bP@0WY350P2UTL00
0`2RTL80ZI:n0:VB_P020:VB_P@0[Y>k00@0/YBh0;:E^@2bUKT0/YFi102fU[L0102hUkD0^IRe0;VH
]@2iV;D30;^I]0D0_Y^d00@0`9bd0<6M/`31WK<0`Ifc0`33W[@20<BP/`<0aJ6d0P37Xk@20<NT]@80
bJJe0`39Y[H20<bY]P030<^Y^03>[;P0cZbh0080cZbh00@0cJfi0<n_^P3?[kX0cjnj1@3@/k`00`3C
][d0dKJo0=6f_`030=Bj`0040=6i``3D_L@0e;g40=Bma0<0dl380P3Ea<T00ol00000dlK>0=?6cP02
0=?6cP<0d<SB0P3Ac=@0103=bMH0cLcH0<g<f03=c=P30<W<g0040<S>gP34bml0a<_O0<C;g`80a<gQ
0P3oool00ol00000oooo0?ooo`0C0?ooo`00303oool00ol00000oooo0?ooo`0J0?ooo`030::mk02S
_N`0Xkg/00@0X;g]00<0W;g_09jmk`2N_Nl0102H_O42092lm0<0Q;[g0_l00000101k^?T0I;7k06Ba
n`1l0002011^g`80HXoW0`23VN0409ZNe`80ZJ7>00<0YJ?D0;:Tb`2bY</00P2bY</30;ZUa0030;VX
b030Yl40`:O100<0`:O100<0a:Nl0<FZ_`35Z[l00P35Z[l20<RZ^`<0bJfm0P3<[;X30<f__0030<n^
^@3@/K/0d;6k0080d;6k00<0dK6i0=>d^P3C];X00P3C];X40=Ff^P80ekZl00<0ekRk0=Vl_@3I_;d0
0P3I_;d0103K`;l0f[jm0=Zn_@3J_[d20=_2_`040=Zo_`3L`l40g<?10=c3`@80gLS300@0g<G30=g9
a@3MbLD0gLW50P3Nc/P01P3Lb/L0gLk:0=g>bP3Mc/X0g]?=0=_?c@80g=??00Co00000=cCc`3Lem80
fM;B0`3Ie]D30=GDf080e=OJ00<0dM?J0=3Eg@3@eMd00P3?eml0103<d]l0b]CQ0<[Dh@3:e>430?oo
o`03o`00003oool0oooo01d0oooo00?o00000?ooo`3oool0603oool2086gm`80L;7i0P1c/oT01@1L
ZoT0?9_c03bKl`0lVo<06hOY0080077J00<006OE00M/g@0>K=d00P12O^@305N3h@;o00000`2:SM43
09F?bP80WY3500<0VHo80::A`P2RTL800P2RTL830:VB_P<0[Y>k00<0[IBl0;:E^@2bUKT00P2bUKT4
0;JF]`@0^IRe0P2kVK@20;bJ]0@0_Y^d1@31WK<00`33W[@0a:2c0<BP/`020<BP/`050<FQ]037Xk@0
aj>d0<NS]037Y;D01039Y[D01039Y[H0c:Vf0<bY]P3<ZKH50<j/^0@0cjnj00@0d[>j0=2c_03@/k`0
d;>l0P3C][d00`3A][l0e;[00=Bj`0020=Bj`0<0e;g40P3F`/H01P3C`<P0eLC90=G4b@3Ea<T0elW<
o`000080dlK>0P3Dbm00103@b=80dLcD0=7<e03Ad=P30<g<f080cLoK00D0bLcL0<S>gP38c]h0b<kN
0<C;g`020<C=h@040<?>h`3oool0ooooo`0001D0oooo000<0?ooo`03o`00003oool0oooo01/0oooo
0`2S_N`20:2mk@80X[g]0`2N_Nl209Rml@0309^ml02D_?<0U;cc00?o00000P2:^oH207^hn@<0I;7k
0P0@K]l204J7j@<0PiWP0P2JW]L00`2AX=h0YJ?D0:FSe0020:FSe0@0/ZC;00@0^ZG40;VXb02iZ<P0
^JS81030Yl450<FZ_`030<RZ^`39[Kd0bJfm0080bJfm00<0c:bj0<f__03=[k`00P3=[k`50=2a^`D0
dkBj00<0eKRl0=Ff^P3E][X00`3G^[`50=Vl_@80fl2o00D0f[jm0=_2_`3K`[l0fl:o0=g6`P020=c3
`@<0gLS30`3MbLD30=k>b0<0gLk:0P3Ndld01P3Nem00g=??0=cCc`3Ldloo00000=cGdP<0fMKE0P3H
fMP00`3Ee=P0e=OJ0=CGfP020=?Jg@050=3Eg@3?eml0cmOO0<oGg`3=f>800`3:e>420<SEh`80oooo
00?o00000?ooo`3oool0703oool00ol00000oooo0?ooo`0J0?ooo`80Q;Sg0`1c/oT205b[n@<0?Igd
0P00LMX01000FlT005c>00i/g@12O^@3o`000080KHOL0`1oRmH308j>cP@0VHo80`2RTL840:VB_P03
0:jC^`2]U;`0[IBl00@0/YFi0`2fU[L00`2fUkL0^IRe0;VH]@020;VH]@040;^I]02lV[@0_9Zd0;bJ
]0<0_Y^d0P30W;@40<6M/`D0a:2c1037Xk@50<VV]@@0c:Vf00<0cZbg0<j/^03>[;P00P3>[;P00`3@
[kP0cjnj0<n_^P030=:c^P050=2c_03C][d0dkJm0=>f_@3F^kl00`3D^/020=Nn`P050=Bma03F`/H0
e/;60=K2aP3HalP00`3Ea<T20=O9c006o`00003Dbm00e<_@0=C;d03Ecm<0dLcD0`3Ad=P0103=c=P0
cLoK0<g?f`3=d]h30<S>gP80am3Q00@0a<gQ0<?>h`33c^<0`lkS0P3oool00ol00000oooo0?ooo`0B
0?ooo`00303oool00ol00000oooo0?ooo`0L0?ooo`040:>mk02T_N/0Y;g[0:Bmj`<0X[g]00@0W[g_
09nmkP2O_Nh0Vkg`0ol000000`2D_?<0Ukgb09NmlP0308nlm@<0P[[h0P1_]O/2001Hc@80AXOY0P1b
V>L4096PgP<0YJ?D0`2bY</00`2_Ym00^JS80;VXb0020;VXb0<0`:O10P30ZlD40<FZ_`D0bJfm1@3=
[k`00`3>/kh0d;6k0=2a^`020=2a^`040=:e_@3C];X0dkBj0=>d^P<0eKRl00D0eKJj0=Nj_03G^[`0
ekZl0=Vn_`030=Vl_@<0fl2o103K`[l20=g6`P060=c3`@3Mb<<0gLS30=g8``3OcLH0gLW5103Nc/P0
0`3Odl/0gLk:0=kCc@020=kCc@80g]O@00<0g=??0=cGd_l000000P3KfmH00`3Ie]D0f=WH0=SIf002
0=OLg0040=CGfP3Cf]d0dm[M0=?Jg@80dMcQ00D0cmOO0<gHhP3=f>80cMSR0<[Dh@020<SEh`040<KF
i@3oool0ooooo`0001h0oooo00?o00000?ooo`3oool06P3oool408NjmP80N;Ki0`1Q[_X01012XOH0
6H_Y01V;j@00K]@3o`0000807g7P0P1GPn4206f7g0<0Oh_F0`2>S/h309V?b0<0XY720`2YT[h00`2W
T/00[IBl0:fD_0020:fD_0@0/YFi00@0]YJg0;JG]`2fUkL0]YNg0`2iV;D50;bJ]0040;jK]030W;@0
`9bd0<2L]0@0`Ifc00<0`ind0<BP/`34X;<00P34X;<40<NS]0030<VU]039Y[D0bJJe0080bJJe00<0
c:Re0<bY]P3<ZKH00P3>[;L30<j/^0<0d:nh00@0cjnj0=:c^P3B/kX0d[>j103C][d20=Jk_`040=Bj
`03G_/80ekk20=Nn`P<0e/;60`3HalP01@3Ea<T0elW<0=O9c03GbLco00000080e<_@0P3Ecm<30=7@
f080dMCK00D0cLoK0<gBgP3=d]h0cM;N0<S>gP020<O@h@050<KBi033c^<0`lkS0<?>h`31d>D00P3o
ool00ol00000oooo0?ooo`0B0?ooo`00303oool00ol00000oooo0?ooo`0M0?ooo`80Y;g[0P2U_N/3
0:>mk0?o000000@0Vkg`09fmk`2M_Nl0WKg_0`2G_O800`2?_?D0Tkgc09>ml`0408Vkm`0307VhnP00
F<d005S=00808G[U0P1bV>L3096PgP@0YJ?D00@0/ZC;0:nWd02_Ym00[jO@102iZ<P01030Yl40`:_5
0<2[a@30ZlD30<FZ_`80aJk20`39[Kd20<Z``0<0cJnl0P3>/kh30=2a^`<0d[Fm00<0dkBj0=Fh_03E
^;`00P3E^;`30=Nj_0<0fKjo00<0fKbm0=_0_`3K`;l00P3K`;l00`3LaL80fl:o0=_2_`030=g6`P<0
gLS30P3OcLH0103Pd/X0g/k80=k>b03Nc/P20=oCb`<0g]?=0`3Nem001`3Ng=@0g=OB0=_Ke_l00000
fm_F0=[NfP3HfMP00`3Gg=`20=COg`040=?Jg@3Ag>40dMcQ0=7Lh@<0cMSR0P3;f^D01038eN<0a]KU
0<KFi@36e^D20?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool06`3oool208NjmP80
Rk_f0P1m^?T306NanP?o000000@06H_Y001^dP00Bk`005S>0P0OLN000`0iNN80KHOL06f7g00307n;
eP<0SXk>0`2ISlP40::A`P030:VB_P2WT/00Yi;000@0[IBl0`2bUKT00`2aU[X0]YNg0;JG]`020;JG
]`80^IRe0P2jVKH40;bJ]0@0`9bd0`31WK<20<>O]0<0a:2c0P36X[@20<NS]080bJFd0`39Y[D20<bX
]@80c:Vf0`3>[;L00`3>[;P0d:nh0=2_^0020=2_^0@0d[>j00<0eKNl0=>f_@3C][d00`3F^kl40=Nn
`P030=W4a03F`/H0f<O800<0f<O80`3GbL`20=S>c`03o`00003Ecm<0eLoC0080e]CG00D0dM3H0=7D
f`3Ae=/0dMCK0=3HgP030<gBgP030<_Eh@37d>40a];T0080a];T00@0`lkS0<7@i@31d>D0`M3U0P3o
ool00ol00000oooo0?ooo`0A0?ooo`002`3oool00ol00000oooo0?ooo`0O0?ooo`<0YKg[0ol00000
0`2T_N/0XKg]0:6mk@020:6mk@0309fmk`2O_Nh0Wkg^00<0V[g`0`2C_O<208Vkm`0608nlm@22^_T0
P[[i08:jn@00?K408G[U0`1JTnd3096PgP80YJ?D00<0WZKK0:nWd02_Ym000P2_Ym030;VXb0030;R[
c@30ZlD0`:_500<0`:_500<0aJZo0<F^`P35[/800P35[/800`39[Kd0b[300<Z``0020<Z``0030<f_
_03>/kh0c[>n0080c[>n00<0d;6k0=:e_@3B]Kd00P3B]Kd50=Fh_0030=Nl_`3G^[`0fKjo00<0fKjo
103K`;l20=c5`P030=_2_`3Ma/80gLK20080gLK200<0glc60=g8``3OcLH00P3OcLH20>3BbP060=k>
b03Odl/0gm?;0=oCb`3Pf<l0g]?=0`3Nem020=kLe0<0fm_F00?o00000=[NfP3Gg=`00P3Gg=`30=CO
g`<0dMcQ0P3>gN@00`3=f>80bm[U0<_Ji@020<SJi`80a]KU0P34e^L20?ooo`03o`00003oool0oooo
01T0oooo00?o00000?ooo`3oool07P3oool308^kmP0507fhnOl0003o0000o`00001W/OX00P19YOL3
022@k004001be000@[H005gC001Md`<0E87Q0`1oRmH308j>cP<0VHo80P2RTL800`2NTLH0Yi;00:NB
`0020:NB`0<0[IBl00@0/YFi0;6F^P2aU[X0/IJj102fUkL0102iV;D0^YVf0;ZI]P2jVKH40;bJ]003
0;jL]@30W;@0`9bd0080`9bd00<0`Ifc0<>O]033Wk@00P33Wk@01@34X;<0aZ:d0<JR]036X[@0aj>d
00@0bJFd00<0bJJe0<bX]@3<Z;D00P3<Z;D0103<ZKH0cZbg0<j/]`3>[;L50=2_^0030=>d^P3B/kX0
d[>j0080eKNl00<0dkJm0=Jk_`3F^kl00P3F^kl00`3I`L40ekk20=Nn`P020=W4a0040=c:b03HalP0
f<O80=S7b080flg<00H0elW<0=S>c`3Hc/l0f<k?0=WDdol000030=KDe`040=GIf`3Ae=/0dMCK0=7D
f`80d=SN00<0cM;N0<_Eh@3;eN400P39f>@01@36d^@0a=CV0<CDiP34e>H0`M3U00<0_m3W00<0oooo
o`00003oool04@3oool000/0oooo00?o00000?ooo`3oool07`3oool3o`0000030:JmjP2T_N/0Y;g[
0080Y;g[0P2Q_Nd00`2S_N`0Wkg^09nmkP0209nmkP0309Zml02M_Nl0WKg_00@0Ukgb0P2?_?D308:j
n@0306nfn`00I=D0FY?]0080FY?]0P24XNH409jVf`@0[jO@00@0^JS80;R[c@2hZld0^:_=0`30ZlD0
0`2o[lX0aJk20<F^`P030<F^`PD0b[301@3>/kh50=:e_@040=Bj`03E^;`0eKRl0=Fh_080ekbo00<0
ekZl0=Vn_`3I_[l00P3I_[l00`3K`l80fl2o0=_0_`030=c5`P040=k;a@3Ma/80gLK20=g6`P80glc6
0`3OcLH30>3BbP<0gm?;0P3Pf<l20=oMd`030=kGd03Ng=@0g]cD0080g>7I00H0fm_F0=[NfP3Jg][o
00000=SRgP3Gg=`30=COg`80d^;S00<0dMcQ0<kMi03>gN@00P3<gnL0103;f^D0b=[W0<SJi`35fnT3
0<CFi`80`]KY00<0ooooo`00003oool06P3oool00ol00000oooo0?ooo`0O0?ooo`?o000000<0Skce
08:jn022^_P00`1_]?X205>[n@<0:iS`00<004:f001Md`0?J=/00P1DPN4306j8f`<0PhcD0`2CSld3
09jAaP@0Yi;00P2]U;`00`2/UKh0/IJj0;6F^P030;6F^P<0]YNg102jVKH30;bJ]080_Ybe1030W;@5
0<>O]0@0aZ:d1@39YK@50<bX]@@0cZbg00@0dK2h0=2_^03@[kP0d:nh0P3C];X01@3B/kX0eKNl0=Fg
_03E]k`0f;fn00<0e[^o0P3I`L40103G_/80fLC40=W4a03Ia<@20=c:b0040=S7b03KcL`0flg<0=_=
c0<0f<k?0P3Ie=<00`3Fe=Oo00000=KDe`030=GIf`030=7Df`3@f=h0d=SN0080c]_R00@0bmGQ0<WH
i039f>@0a]WW0`34e>H20<;Ej080_m3W0P2mdNT00ol00000oooo0?ooo`0@0?ooo`002`3oool00ol0
0000oooo0?ooo`0L0?ooo`?o00000`3oool20:JmjP80Y;g[0`2U_N/20:>mk080Wkg^0`2Q_Nd209fm
k`80Ukgb00<0V[ga09>ml`2C_O<00P2C_O<308Vlm`04001Te@1JTnd0FY?]05ZCk@80Q:7V102NY]/2
0:nWd0030:^[f02hZld0^:_=00<0^:_=00@0`:_50;n_bP2o[lX0_jo:0`35[/820<Jba`@0b[3000@0
bkG40<jc_P3>/kh0c[>n0P3@^<830=:e_@<0e;[000D0eKRl0=Nl_`3G_;l0ekbo0=W2``030=Vn_`80
fl?200<0fl2o0=c5`P3LaL800P3LaL820=k;a@060=g6`P3Oc<H0glc60=o<aP3Pd/T0glg60`3Pd/X2
0>7HcP040=oCb`3Pf<l0h=S?0>3Hc`80gmgC00@0g^?H0=kLe03LhMT0g>7I0P3JiMd0103Jg]X0f>;N
o`00003Hh]h20=GUhP030=COg`3Bh^<0d^;S0080cn?V00<0c]gT0<cOi`3<gnL00P38gnT01@38f^L0
aM_Y0<GKj@35fnT0a=KW0080`]KY00@0_mK[0?ooo`3ooooo00006P3oool00ol00000oooo0?ooo`0L
0?ooo`?o000000@0oooo08nlm@2?_?D0Tkgd1028^oL207NhnP<0G[3j0P0iX?@00`06Q>0002fL00mX
f`0205B1h@<0KXSK0`23S=@209>?c@@0WY760`2WT/00102]U;`0[9Fn0:bE_P2/UKh40;6F^P80]YNg
0P2fV;T40;ZI]P040;bJ]02nW;D0_Ybe0;jL]@<0`9bd0P32W[D40<>O]0@0aZ:d00<0bJFe0<VU]039
YK@00P39YK@00`3<ZKH0c:Re0<bX]@020<bX]@030<n/]`3>[;L0cZbg00<0dK2h00@0d:nh0=>d^P3C
];X0dkBj103E]k`20=Rm_P050=Jk_`3I`L40fL710=W1`@3Lal@00P3Ia<@30=c:b0<0flg<0P3Ldll0
0`3Hc/l0fMCC0=WDd`020=WJf004o`00003EfM/0eMWK0=GIf`80dmkO00<0d=SN0<kKhP3>fn800P3<
gNH01@39f>@0a]WW0<KIi`36fNL0a=CV0080`]GX00L0_mG[0;gAj@2mdNT0_M7Y0;_Aj`3ooooo0000
0140oooo000;0?ooo`03o`00003oool0oooo01T0oooo0ol000070?ooo`<0Y[gZ0P2U_N/00`2V_NX0
Y;g/0:Bmk0020:Bmk080XKg]00<0X[g/09nnkP2O_^h00P2O_^h209Zml@80Tkgc0P2G_O8308nmm@03
08D0000gRN`0=hW/00<0Kio^0P2NY]/00`2DZN@0Zj_H0:^[f0020:^[f0<0^:_=00<0]K3D0;n_bP2o
[lX00`2o[lX01035[/80a[;70<Jba`36//L30<Z``0<0bkG400<0c[>n0=2h`P3@^<800P3@^<800`3B
]Kd0e;[00=Bj`0020=Bj`0@0ekbo0P3I`/<01@3I_[l0fl?20=_3`P3K`l80gLW600<0g<G20`3NblD3
0=o<aP80h=;90P3QfLh0103Pd/X0hMS>0>7HcP3Qf<h20>7NdP030>3Hc`3OgM<0gmgC0080g^?H00<0
g>SL0=cQf@3JiMd00P3JiMd20=OYh@030=SRg_l00000eNGR0080dNSV00<0d^;S0<oSiP3?hnH00P3;
i>T00`3<gnL0b=oY0<SOj@020<GOk080aM_Y0P32fn`01032e^T0_mK[0;oFj`2oe^/3o`0001T0oooo
00?o00000?ooo`3oool06@3oool3o`0000H0oooo0P2C_O@208Rkm`80SKcf0`1o^_T306Vdn`0404RX
n00IT>T002RJ001>a`80<GGQ0`1^R=/208><e0<0Tho=0`2NTLH20:NB`0030:BCa02/UKh0[9Fn0080
[9Fn102aU[X0102fUkL0]YRi0;JH^@2fV;T40;ZI]PD0_Ybe00@0`9bd0<:N]@32W[D0`Yje0`33Wk@2
0<FR]@80aZ:d0P39YKD30<VU]080c:Vf0`3<Z;D20<n/]`030<j/]`3A/;P0dK2h0080dK2h103C];X0
0`3G^K`0eKNl0=Fg_0030=Rm_P@0fL710P3Lal@01P3Ia<@0g<[80=c:b03Lb/P0g]7<0=_=c0<0g=??
00<0gM[D0=WDd`3If]P00P3If]P00`3Hh=co00000=GIf`020=?Ng`80dN7T00<0c]_R0<cMiP3<gNH0
0P38gnT20<KIi`80`m[Z00D0`]GX0;oEj`2oeN/0_mG[0;gAj@030;_Aj`;o0000403oool000/0oooo
00?o00000?ooo`3oool05P3oool3o`0000/0oooo00<0Y[gZ0:Nmj@2W_NT00`2V_NX20:Bmk080YKg[
0`2R_N`209nnkP030:6nk@2M_^l0WKk_0080WKk_0`2G_O80102?_OD0U;gc09Bml`1U000203N9k0<0
Kio^0`2DZN@40:^[f0040;R[c@2e/=@0]K3D0;F`e0<0_jo:00<0_[C@0<Jba`36//L00`36//L00`3:
/<00bkG40<^ea0020<^ea0D0d;S2103D^/020=Foa080ekbo0`3I`/<40=_3`P80gLW600<0g<G20=k;
a@3NblD00P3NblD0103OdLX0glc60>3Bb@3Pd/T30>7IcP<0hMS>0`3Qg]80103OiMP0gmgC0=kSf03N
hmP20=cXg080fNgQ00<0f^GM0=OYh@3GjN400P3Ck>H00`3EiN;o00000=7XiP020<gYj@030<oSiP3;
i>T0bnCY0080anG]00<0b=oY0<GOk035gn`00P31gnh20<;Kk080_m[]0P2oe^/20;cEk0030?ooool0
0000oooo01P0oooo00?o00000?ooo`3oool05P3oool3o`0000X0oooo0`2F_O8308flmP0307njn@26
_?P0Q[ch0080M;Sk0P1H[oX00`0IT>T002RJ001>a`02035eh@80E8;Q0`1bR]/209>?c@80WY7600<0
V9;;0:BCa02TTl@00P2TTl@30:bE_P<0/IJj00<0/IRm0;JH^@2fV;T00P2fV;T30;ZI]P80^Y^h102n
W;D50<:N]@050<>O]035X[D0aJ:e0<FR]@36X[@00`39YKD20<VU]0@0c:Vf00@0c:Re0<n/]`3?[;L0
cjbg1@3A/;P00`3E]KX0dkBj0=>d^P030=Ni_0050=Fg_03H_Kh0f;fn0=Rm_P3La<800P3I`L430=c7
a0<0g<[80P3NdL`30=cCc`80gM[D0P3LhMT01P3If]P0f>3L0=SPg03FiN7o00000=?Ng`80dN7T0P3=
i>P0103<gNH0b=oY0<SOj@34h>d30<?JjP80`=[]0P2oeN/20;cEk080^m7[0P2hd>`00ol00000oooo
0?ooo`0>0?ooo`002`3oool00ol00000oooo0?ooo`0D0?ooo`;o00003P3oool40:Nmj@@0Y[gZ0`2U
_N/00`2R_N`0Y;g/0:Bmk0030:6nk@80WKk_0P2O_^h309^nl@<0U;gc00<0I@0000Qfh008M^000`1_
Wnh309BYi080Zj_H00<0Y;3Q0;F`e02e/=@00`2e/=@0102o[lX0_[C@0;jdd02n]=030<Jba`030<Jh
c@3;]L@0bkG400<0bkG400@0c;_90=2h`P3@^<80d;S20P3A_LL20=Bj`0<0eKo400<0ekbo0=W2``3I
`/<00P3I`/<00`3Jb<L0fl?20=_3`P030=g9aP040=k@b`3NblD0g/_50=k;a@80gm7:00<0hMW?0>3B
b@3QfLh00`3QfLh00`3Qgm<0hMS>0>7NdP020>7NdP80gnGH00@0gN_L0=kSf03Lj=`0g>SL0`3IkN40
103Dl>H0enWQ0=?/iP3Ck>H20<k^jP030=7Xi_l00000cNWY0080b>[]00<0bnCY0<OUk@37iNd00P33
i>l01035gn`0`Mo^0<7OkP2mg_030;oJk@80_=W_0P2leN`20;WDk@03o`00003oool0oooo01L0oooo
00?o00000?ooo`3oool0503oool2o`0000h0oooo00@0U[gb09Znl@2J__40V[ka0P2B_O@308Jln080
M;Sk0`1H[oX01@0^WO4002nU001Qe`00HML0E8;Q00<0LX[K0P28Sm<409RBb`<0Y9?4102/UKh0102a
U[X0/IRm0;6H_@2aV;d40;JH^@040;ZI]P2jVkP0^Y^h0;ZK^0@0_Ybe1@32W[D40<FR]@030<JR]039
YKD0bJFe0080bJFe00<0bJFd0<bY]P3<ZKH00P3<ZKH40<n/]`040=:a^@3A/;P0dK2h0=6`^080eKFj
00<0dkBj0=Ni_03G^K`00P3G^K`30=Rm_P80g<C200<0fL710=c7a03Lal@00P3Lal@0103OclP0g<[8
0=kAc03NdL`20=oId@040=cCc`3Mf]@0gM[D0=gJe080g>7I00L0f^SN0=SPg03FiN40e^GQ0=;Yi_l0
0000dN7T0080cNCX0P38i^`01@38gnT0a>3]0<CPk@34h>d0`m[Z0080`=[]0P2lfNh20;cEk080^MC^
0P2hd>`00`2fcngo00000?ooo`0?0?ooo`002P3oool00ol00000oooo0?ooo`0B0?ooo`?o00004@3o
ool50:Nmj@030:JmjP2W_NT0YkgY00<0Y[g[0`2T_N`0102Q_^d0Xkk/0:>nk02S_^`309nnkP0409^n
l@2M_^l0WKk_09fnk`80V;kb00<0T;ge001Ia01AV_800P1AV_8308F[kP@0Y;3Q0`2e/=@00`2a]]`0
_[C@0;jdd0030;jdd0040<Jba`36^<d0a[S=0<Jhc@<0bkG40`3<^lT01@3@^<80dKg70=6ma`3A_LL0
e;[000@0eKo400@0elK90=W2``3I`/<0fL;30P3Jb<L00`3K`l80gLW60=g9aP020=g9aP80g]3;00<0
g/_50=oAbP3OdLX00P3QfLl0103PhM@0hMW>0>7IcP3QfLh20>7Od`80h>OH00<0hMkB0=oUf03OiMP0
0P3Mjm`00`3Il>80g>SL0=W]h@020=W]h@040=C`iP3>lnX0c_?Z0=?/iP80c^kZ0P38knd00ol00000
b>[]0<SZk@020<?Zl0030<OUk@33i>l0`nC_0080_^?a00D0`Mo^0;gNl02mg_00_Mk`0;oJk@020;cI
k`060;WGl02ie>d0^MC]0;WDk@2gdnko0000603oool00ol00000oooo0?ooo`0B0?ooo`?o00004@3o
ool209Znl@0309bnl02F__<0U[kc0080U[kc0P2=_OH307jknP<0IkGl00@002nU001Qe`0]MN80E8;Q
0`1bR]/208R?d`<0V9;;102TTl@20:bE_P030:VG``2aV;d0/IRm0080/IRm0`2fV;T00`2fVk`0^Y^h
0;ZK^0020;ZK^0<0_Ybe0P2oW[L30<:N]@030<>R]`35X[D0aJ:e0080aJ:e1@39YKD50<bY]P<0cjbg
0P3B/KT20=6`^0<0eKFj1@3G^K`00`3J`;l0f;fn0=c4`P020=c4`P040=o<aP3Lal@0g<O40=c7a080
glo800<0hMS=0=kAc03OfM400P3OfM420=oReP030=gJe03LhMT0g>7I0080f^SN00L0e^gT0=KUh@3B
jNH0d^WVo`00003=jn/0cNCX0080b>K/0P33i^l20<CPk@80`=o_00@0`=[]0;cIkP2lfNh0^MS`0`2i
e>h01@2fd^l0]/o]0;K?k@2fcngo00000100oooo000:0?ooo`03o`00003oool0oooo00l0oooo0ol0
000F0?ooo`80YkgY00<0Z;gY0:Nmj@2W_NT00P2W_NT00`2V_N/0Y[gZ0:JmjP040:Fmj`030:>nk02T
_^`0Y;k/00<0XKk]0P2M_^l00`2P_^h0Vkk`09^nl00209^nl004001Ia01AV_80DI[b056JlP<0QJ_^
102T/>40102e/=@0/KKL0;6fg02a]]`30;jdd0030;bkf036^<d0a[S=00<0a[S=00D0bkG40<bkb@3<
^lT0c;_90<g2d0040=6ma`040=;4c03E_l@0eKo40=Foa0<0elK900D0fL;30=[8a`3Jb<L0f/S70=c@
c@030=g9aP<0g]3;00<0gmW@0=oAbP3QfLl00P3QfLl20>3Qe0030>7IcP3Qgm<0hMoC00<0h>OH00D0
gNkM0=oUf03Mjm`0gN_L0=W`hP030=;diP040=W]h@3Dl>H0c_?Z0<kcjP80a_C]00H0c^kZ0<S_k@38
knd0`^oa0;c^lol000020<?Zl080_^Wb00<0`nC_0;kSl@2nho400P2jh_<20;gNl080^]ca00D0_=W_
0;WGl02ieo00^MO`0;WDk@030;OCkP03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool03`3o
ool3o`0001D0oooo0`2L__0209Jnl`80V[ka0`2B__@308Nmn080M;Wk00<0F;7k001Qe`0]MN800`1b
R]/208R?d`@0V9;;0P2TTl@00`2OU/X0ZIO30:VG``020:VG``@0/IRm00@0]YRi0;JK_02fVk`0]Y^l
102jVkP0102nW;D0_ijg0;nN]`2oW[L20<:N]@<0`j:g0`35X[D00`37Y[L0bJFe0<VU]@020<VU]@04
0<^Y]`3<ZKH0c:Vf0<bY]P80cjfh00<0cjbg0=:a^@3B/KT00P3B/KT01@3A/;P0eKFj0=Fe^P3E]KX0
f;bm00<0ekVl0P3J`;l40=c4`P80glc600<0g<O40=o?b03OclP00P3Qf<d0103RhM<0gmWA0=oId@3O
fM420=oReP050=gYf`3LhMT0f^SN0=[XgP3FkN@00P3@lNP01P3BjNH0cN_[0<g[jol00000a^c^0<SV
k080`nK_0P2niO820<3Ok`80_=ka00D0_=W^0;WHl02if?00^MS`0;WDkP030;KBk`040;K?k@3oool0
ooooo`0000l0oooo000:0?ooo`03o`00003oool0oooo00`0oooo0ol0000J0?ooo`<0Z;gY0`2W_NT4
0:JmjP80YKg[00<0Y[g[0:Bnk02T_^`00P2T_^`00`2Q_^d0Xkk/0:>nk0030:2nkP80Vkk`0P2N_^l0
102I__80F@0002F;k00URn`206b[mP0408F[kP2T/>40Y;3Q09Vej`D0/KKL00@0_[C@0;bkf02l^mP0
_;_H0`36^<d01035_m@0c;_90<bkb@3<^lT30<g2d080dKg70`3Ba<`00`3E_l@0elK90=O6b@020=O6
b@<0f/S70`3Ld<d0103MbLH0g]3;0=k@b`3Nd</20=oId0<0hMW?0`3PhM@00`3Oj=X0hMoC0>3Wf002
0>3Wf080gNkM00<0eo?S0=g[g03Il>800`3Bm>H0103;mnX0`OS]0<7hk@3>lnX20<Kdk@040;odl@2h
l_<0^?;c0<;_l@80_>kc00D0]ncfo`00002njO80_^Wb0;[Wm0020;GUmP80^^;c0P2ggo@20;[Ll@80
]m[b0P2ieo020;KFl080]m?^00<0ooooo`00003oool05P3oool00ol00000oooo0?ooo`0<0?ooo`?o
00006@3oool0102L__00Wkk_09nnk`2O_^l309Znl@0309:nm02G__<0Ukkc00<0S[kf0`20_?X202ee
hP80EhCR0`1hS]`209RBb`0308nCd`2OU/X0WiK:0080WiK:0`2YUl<30;6H_@030;2J`P2fVk`0]Y^l
0080]Y^l0`2jVkP00`2kW[/0_ijg0;nN]`020;nN]`030<:N]@33X[L0`j:g0080`j:g0P35X[D20<NV
]`<0bJFe0`3;ZKL01@3<ZKH0cjfh0<n]^03?[KP0cjbg00@0d[6i0`3E]KX30=Rl_@050=Ni_03J`;l0
f/2o0=[0_`3Nb<<00P3La<830=o<aP030>;Eb`3OclP0hMS=0080hMS=0P3RhM<0103OfM40gn;F0=oR
eP3MjM/20=W`h@040=[XgP3FkN@0d?7X0=3aj080bO;]00H0cN_[0<K/kP36k>ko00000<3/lP33i^l2
0;kUlP80^^;d0P2lg_420;SLlP80^MS`0P2fe_420;KBk`@0oooo00?o00000?ooo`3oool03@3oool0
00X0oooo00?o00000?ooo`3oool02@3oool3o`0001h0oooo102X_NT20:Nmj@80Y[gZ0`2W_NT20:Jm
j`80Y;k/0P2U_^/30:>nk0040:2nkP2R_^d0X[k]0::nk@<0W[k_00@0VKkb09fnl02M__00073D0P1/
ZoH409Vej`80/KKL0P2Z_NL50;bkf0050<Jhc@35_m@0aKoD0<Foe03<^lT0103=`]000`3A_LL0d/C<
0=;4c0020=;4c0040=?=d`3Ga/T0elK90=O6b@80f<k@00<0f/S70=c@c@3Ld<d00P3Ld<d20=cHd`06
0=k@b`3OfM00gmW@0=oId03NhML0hMW?0`3PhM@20=oXfP80fo3P00@0h>OH0=g^g@3Mk]d0eo?S0P3?
n>L20<GjjP040=;diP3;mnX0`OS]0<7hk@80^?O`00@0a_C]0;odl@2hl_<0^?;c0P2al?H01P2lk_<0
]ncf0;O/m_l00000/^Wh0;[Wm0<0]NGf00<0/^;g0;OOm02ggo@00P2cgOD20;OJlP80]=Sc0P2fe_04
0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool02@3oool3o`0001h0oooo00<0Wkk_
0:6nk@2Q_^d00`2M__0309Nnl`0408jnmP2D__@0U;kd09Bnm080RKkh0P00G=<205N4hP80N8kL102?
Tm<309nFbP@0ZIO300@0/IRm0;2J`P2`V/80/9[2102fVk`00`2jVkP0^ijk0;^N^`040;nN]`D0`j:g
00<0aJ:e0<NV]`37Y[L00P37Y[L00`39YKD0bjVg0<^Y]`020<^Y]`@0cjfh1@3B/KT00`3F^;`0eKFj
0=Rl_@030=Rl_@<0f/2o0P3Nb<<0103La<80glc60=o<aP3Oc<H20>;Eb`<0hMS=0`3RhM<00`3PjmT0
gn;F0=gYf`020=W`h@040=;eiP39n>X0bOSZ0=3aj080bO;]0P31l_000`2jlO@0`>cbo`0000020;[Z
m0030;kUlP2jh_@0^^;d0080]Moe0P2hg?820;CIl`80]]Ka1`3oool00ol00000oooo0?ooo`0=0?oo
o`002P3oool00ol00000oooo0?ooo`060?ooo`?o00008P3oool70:Rmj@<0YkgY102V_NX00`2U_^/0
Y[kZ0:JnjP030:Bnk080X[k]00<0Xkk/0:6nkP2Q_^h00P2Q_^h309fnl00309Nnl`16X_H0AZ;f0080
VKG[00<0QkWf0:Zmi`2Z_NL00`2Z_NL30;bkf0050;S3hP35_m@0aKoD0<Foe034amd01@3=`]00103<
b]P0d/C<0=;4c03Ba<`30=?=d`050=O6b@3Hc]00f<k@0=S>d03Hf=L00`3Ld<d20=cHd`040=_RfP3O
fM00gmW@0=oId080g^7G0P3Lj]d00`3PhM@0gnSJ0=oXfP020=_`h080doOU00@0gNkM0=Och`3?n>L0
coSW0P35n^X0102hnN`0ZoO/0:_gk031n>d20;Sgl0030:kelP2Vl_@0Y_;d0080X>of00<0/O3f0:_]
n02[kOP00P2Wj_X01P2bjOSo00000:kVn@2^i_T0]NGf0;;Rm`<0[mkh00<0/mge0;7Jm@2af_D00P2d
f?<70?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool01P3oool3o`000280oooo0`2Q
_^d00`2M__00X;k^0:2nkP0309^nl@80U;kd0P2I_o82092omP8005cC0P0[Mn<207R>g0<0Si?C0`2O
U/X30:VG``030:JJb@2`V/80/9[20080/9[2102fVk`40;^N^`80_ijg0P30X[/40<>R]`D0ajJg1@3;
ZKL40<n]^0040=:c^`3B/KT0d[6i0=:a^@80e[Rl00<0eKFj0=Rl_@3H_;d00P3H_;d00`3La<80f/2o
0=k8``020=k8``80hM;900H0glc60>;Eb`3ReL/0h]G;0>?Pd@3Qf<d30>;Qd`060>3[f@3Llmh0g??N
0=Cih`3Il>40d_GV0P39n>X20;ohk@030<Wbk@31l_00`O;`0080^_7d0P2ck_L01?l00000]NOf0;GW
mP2ahoP20;GOm@80/]ce0P2dfO<:0?ooo`03o`00003oool0oooo00d0oooo000:0?ooo`03o`00003o
ool0oooo00<0oooo0ol0000V0?ooo`L0Z;gY0`2W_NT20:JmjP030:Nmj@2V_^X0Y[kZ0080Y[kZ00<0
Y;k/0:Fnj`2U_^/00`2S_^`20:6nkP80X[k]0`2O_^l00`2K__40AZ;f04JRmP0308NimP@0Z[gW00<0
_;_H0;S3hP2h`n800P2h`n801035_m@0a<OM0<C7g@34amd30<g2d0<0c<[H00<0d/C<0=?=d`3CcM<0
0P3CcM<30=S>d0<0f=SG00<0g=3=0=cHd`3Lf=<00`3Kh]X00`3OfM00g^7G0=kQe`020=cZg@80eo;S
00<0gnSJ0=_`h03Kl>000P3CmnD00`38n^P0^__Y0;[kj@020:Whj0050<GjjP2hnN`0ZoO/0:_gk02O
lnd00P2Eknh208g/l0040:Kbm02PkoH0X>of09_/n@80VNSk0P2Wj_X20:CWn`030:kVnOl00000Zn?j
0080Z=oj0P2_g_P20:cKn0030;7Jm@3oool0oooo00P0oooo00?o00000?ooo`3oool05@3oool00ol0
0000oooo0?ooo`030?ooo`?o00009P3oool30:>nk0<0X;k^00@0Vkka09jnk`2N_^l0W[k_0`2I_o80
1@2@_oH0U[oc09Jol`00=jd0:gOS00<0GH[U0`2?Tm<309nFbP040:VG``2VV/T0YY[90:JJb@<0/9[2
0`2fVk`00`2fWl40^ijk0;^N^`020;^N^`040;nN]`30X[/0`::k0<2R^`<0`j:g0P35Y[X40<NV]`04
0<Z[^P3;ZKL0bjVg0<^Y]`80cZnj0P3?[KP30=:c^`050=:a^@3F^;`0e[Rl0=Jh_03I`<400`3H_;d2
0=c4`P040=o?a`3Nb<<0g/S30=k8``80hM;90`3ReL/20>?Pd@80h^_G00D0h^7C0>3[f@3Llmh0g??N
0=Cih`020<SliP040;_kj039n>X0_oS]0;ohk@80]_Ka0P2^lo@00`2jlO@0/nkg0;?^m`020:oZn@03
o`00002ahoP0[]kh0080[]kh00<0/]ce0?ooo`3oool02`3oool00ol00000oooo0?ooo`0=0?ooo`00
2@3oool01?l00000oooo0?ooo`3oool3o`0002X0oooo0P2X_NT20:Rmj0<0Z;gY00@0YkgY0:Rmj@2X
_NT0Z;gY0P2W_NT20:JnjP80YkgZ0`2U_^/0102S_^`0YKk[0:Fnj`2U_^/30::nk@0609nnk`2Q_^d0
XKk]0:6nk@2N_^l04HcU0`27^OH20:Zmi`80W/Cc0`2h`n820;3<kP@0a<OM00@0cL;@0<c:f03<b]P0
c<[H0P3:e>830=?=d`80d]OL00<0f<k@0=SHe`3Hf=L00P3Hf=L00`3Gh]l0g=SC0=_RfP020=_RfP80
f>cR00<0g^7G0=cZg@3Lj]d00P3Gl^<20<gii`80_O_Y00@0doOU0<Sjj02jnnT0^__Y0P2Yn>P00`2H
l^H0R>cT07_Vh`0307?Qi00409G_kP2=k?00SNc`08WXl`80QnKg00<0Vnci09WXn`2Ij?/00P2HiO`2
0:CWn`050:;So02Qgo`0XMolo`00002XgoX00P2Wg?X20:cKn0`0oooo00?o00000?ooo`3oool0503o
ool01?l00000oooo0?ooo`3oool3o`0002X0oooo00<0Xkk/0:Bnk02T_^`0102R_^d00`2N_^l0XKk^
0:6nkP0309fol0<0U[oc00@0SKog001Kd01MR^D0GH[U0`21U=d309RHdP@0YY[9102`V/80102fVk`0
]Yo10;JO`@2fWl430;^N^`D0`::k00@0`j:g0<FV^P35Y[X0aJJj0`37Y[L30<Z[^P050<^Y]`3>[kX0
cZnj0<j_^P3?[KP0103B/k/40=Jh_080fL3100@0f;bm0=c4`P3La<80g<C20P3OclL01P3Nb<<0hM;9
0>7Bb@3Qd/T0hmk?0>;Eb`<0hn3A00H0h^_G0=kdg03Nm=`0e?_P0=ccgP3DnN<20<SliP80^o_X00@0
[_SZ0:?ek@2LlO40W?7a0P2^lo@00`2XkoL0YN_j0:G[nP020:oZn@030:cUnP2Yh?[o00000080[]kh
3`3oool00ol00000oooo0?ooo`0=0?ooo`002@3oool4o`0002l0oooo00<0Z;gX0:Vmj02Y_NP01P2X
_NT40:Nmj@030:NmjP2W_NT0YkgY00<0Y[kZ0P2U_^/20:Jnj`<0Y;k/0P2Q_^d01@2S_^`0X;k^0:2n
kP2P_^h006Rn00<0J;Ol0`2Na?<00`2h`n80/<c^0;3<kP020;3<kP80a<OM0`2odNP00`3<b]P0b]CR
0<[DhP020<[DhP030=?=d`3Bem`0d]OL0080cn;U0`3Hf=L20=ORg`80dNgW00<0fn;J0=S/hP3Hk>80
0`3@m>P01032nN/0eo;S0<gii`3=nNL20;gkj@070:WhiP2Bl>40T_3Q07_Vf@1Xfm<0FM?@053>d002
04g;e080C/cK0P1_g^P0101_gNd0L]gb07OLn01gg?P208SSnP80Rn7l0P2HiO`00`2HhOd0VMkn09WN
oP020:7Oo0040:7Ko?l00000Ymcj0:OLnPl0oooo00?o00000?ooo`3oool0503oool4o`0002l0oooo
0P2T_^`20::nk@80Y;k/0`2Q_^h0102M_o00Wko_09nok`2O_nl209^ol@0409Bom@00Fm00GH[U05f:
i@<0PICM0`2HV=840:JJb@80/9[200<0[Yo80;JO`@2fWl400P2fWl420;^N^`80_:?01030X[/50<FV
^P030<NV]`3:ZkX0bZ^j0080bZ^j103>[kX50=:c^`030=Jk_`3F^;`0e[Rl00<0fL310`3La<830=o?
a`<0hM;90P3Sg/l20>?ZeP050>?Pd@3RjmL0g_CL0=kdg03Dnn000P34o^401P2bnml0WoKN09ofgP2k
nnP0[_SZ0:?ek@80W?7a00<0VNke09WZnP2Ij_X00P2UjoX00`2Ti_/0Xn7l0:?Qo0020:WPnP03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool03@3oool000T0oooo0_l0000a0?ooo`@0ZKgX00<0
Z;gY0:Rmj02X_NP00`2X_NT20:Nmj@030:Rmj@2W_NT0YkgY0080YkgY00@0Y[kZ0:NmjP2W_NX0YkgZ
0`2V_^/0102T_^`0YKk[0:Fnj`2U_^/20:>nk080X;k^0P2R_^d00`2O_nl0>JWd03VYm00408O8o@80
/<c^0P2Qe?X30;oAj0030;KLl`3:e>80b]CR0080b]CR0P34h>`00`3Bem`0cn;U0<oRi@020<oRi@03
0=SHe`3Gh]l0en;O0080dNgW0P36mNd01@3Hk>80d?CX0=3dj03@m>P0`_W[0080[OSY0P2Al>401P2m
nnT0ZOSV09;`h@2Bl>409k6e01VWa@80;;CH0P0m`=`00`1<anT0Flgd05_=m00206ODm@80L]Kk0P1m
g?`208CJoP80S]kn0P2Afoh209WNoP80Vm[m0P2Qfo`00`3ooooo00000?ooo`0@0?ooo`03o`00003o
ool0oooo01<0oooo0_l0000a0?ooo`@0Y[k[00<0Y;k/0:Fnj`2U_^/00`2S_^d209nok`030::nk@2N
_nl0W[o_0080W[o_00<0VKob02ini`0^O^L00`21U=d309RHdP80YY[900@0XIkB0:jOb02^WlP0[Yo8
102fWl40102kW[/0_:?00;bS`02lXl030<2R^`80`ZRo1035Y[X40<Z[^P030<fb_`3>[kX0cZnj0080
cZnj00@0d[No0=:c^`3B/k/0d[>k0P3F^kl00`3F^;`0fL310=W0`@020=W0`@030=g:aP3La<80glo7
00<0glo700@0hm_>0>7Bb@3Sg/l0hmk?0`3Sj]H0103Nm]/0d_gN0=kdg03Dnn020<Cnh@070;;kg`2O
m]h0WoKN093`gP27k>80Q>WY08KXl@0208_Vn080VN[j00<0V^Gl09gQo@2MhOd00P2ShO`40?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0303oool000/0oooo00?o00000?ooo`3oool0
;`3oool40:Vmj0<0Z;gX1P2X_NT20:Nmj@80Z;gY0P2W_NX20:Nmj@<0Y[kZ0P2U_^/00`2V_^/0Y;k/
0:Bnk0020:Bnk0040::nk@2T_^`0Y;k/0::nk@8008WC0P27b?d20673o@@0XMCj00D0_m7X0;KLl`2f
g?<0]]cc0<[DhP030<CPk080^>Wf0`3?h^D20<O/kP030=ORg`3AkNL0dNgW0080a_G]0`2bn>h0103@
m>P0`_W[0:ghj@2]n>T2097`h@0307?Qe01M`o`0GL?l00<0E/?i0`1Ba?H205C7m080I/gk0P1ZdO/2
07OBoP0507cFoP25eOl0QMGo08GEo`2:f?l00P2@e_h309GHoP80Vm[m1@3oool00ol00000oooo0?oo
o`0>0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool0;`3oool20:Jnj`030:JnjP2U
_^/0YKk[0080YKk[00<0Xkk]0:Bnk02T_^`00`2R_^d209jok`040:6okP2M_o00WKo`02ini`<0IY?X
0`2;W=h30:6NdP@0[Yo80P2fWl400`2eY<P0_:?00;bS`0030;bS`0040<2R^`32Z;l0`ZRo0<:X_`<0
aJJj0P38[Kl20<Z[^P<0cK:o0P3>[kX30=:g_`050=:c^`3F^kl0e[^o0=Jk_`3Ja/H00`3I`<420=g:
aP040>7GcP3OclL0glo70=o?a`80hm_>00<0hnWE0>?Nc`3Sj]H00P3Sj]H00`3Nm]/0d_gN0;knf`02
0:Cge00608[/c@1fh/P0JM_:06GJdP1Xg=d0LMo[0P1lhOD208_Vn003093So02Fgoh0U]on0080WN7m
203oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo00`0oooo000<0?ooo`03o`00003o
ool0oooo0300oooo1P2Y_NP20:Rmj@030:Vmj02X_NT0Z;gY00D0Z;gY102W_NT00`2V_^X0YkkY0:Nn
j@030:Jnj`80Y;k/00<0Y[k[0:Bnk02T_^`00P2T_^`00`2R_^d0Xkk/0:>nk0020:6okP0402Z/i`1Q
`od0XMCj0:7DnP80QMOo0P2fg?<30:;So0030<CPk02hjOH0^>Wf0080^>Wf00<0cn;U0<O/kP37k>h0
0P2flo<209[al0050<Kek@2bn>h0/_S^0;;hkP2DlNH00P1_h=H00`1;bL40OlKn07o6oP0307O6o`80
L<Oo0P1Yb?h207W:o`<0M/co0P1ecol2087?o`<0P];o0P25eOl208cCo`03093FoP3oool0oooo00X0
oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo0300
oooo0P2V_^X20:Fnj`80Y[k[0`2T_^`0102R_^d0Y;k/0:Bnk02T_^`20:6okP80WKo`00@005k?06JC
j01VTnP0IY?X0`2;W=h30:6NdP<0[Yo800@0]Yo10;FTb02eY<P0]JC80`2lXl000`2lZ/L0`ZRo0<:X
_`030<:X_`050<FV^P38[Kl0b:fo0<R]_`3:ZkX0103=/[l00`3>[kX0d[No0=:g_`020=:g_`@0e[^o
0P3Ja/H0103I`<40gL[60=g:aP3Mb/H20>7GcP030=o?a`3Sflh0hm_>0080hnWE0P3Nm]/0103Sj]H0
g_KK0=;mgP2no]/20:Cge00403fm[`10`[d0C<[N05cDi080K][c0P1ng?`01@26h?`0Smgn08oMoP2?
gOh0U]on00`0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0<0?ooo`003@3oool0
0ol00000oooo0?ooo`0_0?ooo`X0ZKgX0P2X_NT20:Rmj0<0Z;gY0P2W_NT20:Rmj@<0YkkY00@0Y[k[
0:NnjP2W_^X0YkkZ0P2V_^/20:Bnk080YKk[0`2S_^`0102Q_nh0Xkk]0:>nk@2S_^d20:2okP<0F<[d
0P2Rho`3083Pn@80^>Wf00D0Wngh07SRk@1hh^d0N>;]0;Kcl`0209[al080L^7O00<0ALK408k4n@2>
a?T00P27aO`208o4n@<0R/Kl0`24aod207k8o`80RLSm0P25b_h208;<o`80Rl_m0`2:c_h208[@oa40
oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0G0?ooo`03o`00003oool0oooo02l0
oooo102W_^T00`2V_^/0YkkZ0:NnjP030:Jnj`80Y;k/00<0YKk[0:>nk@2S_^d00P2S_^d0102Q_nh0
Xko]03F8k00eR>`308^LgP<0XIkB0P2^WlP00`2ZYM80]JC80;FTb0030;FTb0040;bS`02lZ/L0_:[7
0;bZa`@0`ZRo1038[Kl50<fb_`D0d[No00<0eL760=Jk_`3F^kl00`3Ja/H30=g:aP<0hMO>00@0h^KF
0>?KcP3SjMD0hnWE0P3Nm]/01`3@o]d0]_cF09?_a`2CklL0Km^g0432g@1Nd?800P1feOd207SHo080
QmOo0P2;f_lA0?ooo`03o`00003oool0oooo00d0oooo00?o00000?ooo`3oool0303oool000h0oooo
0_l0000`0?ooo`/0ZKgX00<0Z;gX0:Vmj02Y_NP02P2X_NT20:NnjP040:Nnj@2V_^X0Y[kZ0:JnjP80
YKk[00<0Y[k[0:Fnj`2U_^/00P2U_^/20:>nk@030:Bnk02R_nd0X[o]0080X[o]00@0X;o_0::okP2O
_nl0Wko_0P1>b^<201NV_00309c0l@2H`O@0W<7b0080W<7b0P2H`_@209?3m`80VL;d0`2D`oL00`2?
a?T0U/Cg09K4m`030975n@<0SLOk0P29b?d20977nP<0S/Wl00<0Rl_m0?ooo`3oool05P3oool00ol0
0000oooo0?ooo`0<0?ooo`03o`00003oool0oooo01P0oooo0_l0000`0?ooo`80YkkY0P2X_NT30:Nn
jP040:Jnj`2W_^X0YkkZ0:NnjP80YKk[0P2S_^d20:Fnj`80Xko]0P0eR>`207:Nk0<0UZCO102ZYM83
0;FTb0030;>/dP2lZ/L0_:[70080_:[70`32Z;l20<B`aP80b:fo0P3:]/H30<fb_`80d;_60`3B]kl2
0=G1aP030=Jk_`3Ja/H0f/K60080f/K600<0gM?>0=g:aP3Qelh00P3Qelh20>;VeP060=geg@3SjMD0
g_KK0=kff`3@o]d0]_cF0P2CklL00`1idOl0M]?n08OBo`0208OBo`0308KEo`3oool0oooo01H0oooo
00?o00000?ooo`3oool0303oool00ol00000oooo0?ooo`0<0?ooo`00403oool00ol00000oooo0?oo
o`0_0?ooo`d0ZKgX00<0Z;gY0:Rmj02X_NP01`2X_NT30:Nnj@040:JnjP2W_^X0YkkZ0:NnjP80Y[k[
0P2U_^/20:Jnj`<0Y;k/0P2R_nd20:Bnk080X[o^0P2O_nl20::okP<0Wl3`0P2L`O8209o0l080W<7b
0P2I`_@00`2M`O80VL;d09W2m00209W2m0<0U/Cg00@0TLGi09O4mP2Ga?H0UlCf0P2Da_P20977nQh0
oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`0J0?ooo`03o`00003oool0oooo02l0
oooo0`2X_NT30:Rnj@80YkkZ00<0YkkY0:JnjP2V_^X00P2V_^X00`2U_^/0Y[k[0:Jnj`030:Fnk003
001Vd01bW^`0LYk/00<0UZCO102ZYM80102eY<P0/jcB0;>/dP2c[=840;bZa`050<:X_`34/<H0a;36
0<B`aP38[Kl0103:]/H00`3=/[l0d;_60=2kaP020=2kaP050=:g_`3E`LH0eL760=G1aP3Ic/h00`3J
a/H20=gCcP80gn?G00<0hMO>0>;VeP3Ri]H00P3MmMd00`3<o]d0ZoWA07gR^@020000000408c=o@29
d?l0RM3o08W@o`80Qm;o6`3oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo00`0oooo
000A0?ooo`03o`00003oool0oooo02l0oooo3@2Y_NP30:Rmj0X0Z;gY0P2W_^X00`2X_NT0YkkZ0:Nn
jP020:NnjP030:Jnj`2W_^X0YkkZ00<0YKk[0P2T_^`00`2U_^/0Y;k/0:Bnk0020:Bnk0030::okP2T
_nd0Y;o]00<0X[o^0P2O`?000`2R_nh0Wl3`09o0l00209o0l080WL7b0P2I`_@209g2lP<0V/?d0P2G
a?HT0?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?oo
o`0_0?ooo`<0Z;gY00@0Z;kY0:Rmj@2X_NT0Z;gY0P2W_^T20:JnjP80YkkZ0`2V_^/0102U_^`0Y[k[
0:Jnj`2V_^/2046FlP<0UZCO0P2ZYM800`2R[^00/jcB0;>/dP020;>/dP<0_:[700<0_;CA0<B`aP34
/<H00P34/<H50<ZfaPD0d;_60`3E`LH30=W>cP030=[6aP3Mdlh0gM?>00<0gn?G00P0f_CO0>;VeP3M
mMd0gOGM0<cng@2[nM400000093;o080S<gm8P3oool00ol00000oooo0?ooo`0:0?ooo`03o`00003o
ool0oooo00`0oooo000B0?ooo`03o`00003oool0oooo02l0oooo402Y_NP20:Rmj@030:Vmj02X_NT0
Z;gY00P0Z;gY0P2W_^X20:Nnj@<0YkkZ00@0YKk[0:JnjP2V_^X0Y[kZ0P2U_^/20:Bnk080YKk[0`2T
_nd0102R_nh0Xko]0:>ok@2S_nd20::okP80Wl3`0P2R`>h309o1l00309g2lP3oool0oooo02P0oooo
00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo02l0oooo
00<0Z;gY0:Rmj02X_NP00`2X_NT40:Rnj@030:NnjP2X_^T0Z;kY00<0YkkZ0P2V_^/0102W_^X0Y[k[
046FlP11U_83082[k`<0XZkP102c[=80102lZ/L0_;CA0;bdd@2l]=420<B`aP80aK_A0`3:]/H20<g2
d0<0d;_60P3Cb<l0103E`LH0fLk>0=W>cP3Ic/h20=_Of@050=gCcP3OhmL0gn?G0=oSe`3Jm=l00P37
o^000`2Nm<h0I=>[0000000W0?ooo`03o`00003oool0oooo00/0oooo00?o00000?ooo`3oool02`3o
ool001<0oooo0_l0000`0?oooa<0ZKgX0P2X_NT20:Rmj0L0Z;gY00<0YkkY0:Rmj@2X_NT00`2W_^T2
0:JnjP030:NnjP2V_^/0Y[k[0080Y[k[00<0YKk[0:Jnj`2U_^`00`2U_^`20:>ok@040:Fnk02S_nd0
Xko]0:>ok@80X/3^<03oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo01`0oooo0_l0
000`0?ooo`030:Rmj02Y_NP0ZKgX00<0Z;gY0P2X_^T00`2X_NT0Z;kY0:Rnj@020:Rnj@040:NnjP2X
_^T0Z;kY0:Rnj@80YkkZ00<0Y[k[001bdP00L]800`20Znl30::^h080/jcB00<0[[SP0;bdd@2l]=40
0P2l]=400`34/<H0aK_A0<Fkd@020<Fkd@030<ZfaP3=`]00cL;@0080cL;@00@0d;_60=?8c`3Cb<l0
dlS?0P3EfM/0103Ic/h0fmoI0=_Of@3KgmT20=Kah`050=oSe`3Jm=l0aokP0<Onh02Nm<h0:`3oool0
0ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00/0oooo000E0?ooo`03o`00003oool0oooo
02l0oooo4`2Y_NP00`2X_NP0ZKgX0:Vmj00:0:Rmj@030:Nnj@2X_^T0YkkZ00<0YkkZ0P2V_^/20:Nn
jP80Y[k[0P2U_^`20:Jnj`<0YKk/00<0Xko]0?ooo`3oool0<P3oool00ol00000oooo0?ooo`090?oo
o`03o`00003oool0oooo01h0oooo00?o00000?ooo`3oool0;`3oool20:Vmj0040:Rmj@2Y_NP0ZKgX
0:Vmj080Z;gY0P2X_^T20:Rmj@80Z;kY00<0Z;gY0:Rnj@2X_^T00P2X_^T0102W_^X0H`00052Wn01@
YoP3092hlP@0[[SP0P2l]=420;[2h0<0aK_A0P34bml30<g2d0040<gBg@3Cb<l0dlS?0=?8c`<0eMWK
0`3KgmT20=Kah`040<7li@2>k/d0S^k=000002h0oooo00?o00000?ooo`3oool02@3oool00ol00000
oooo0?ooo`0;0?ooo`005P3oool00ol00000oooo0?ooo`0^0?oooaL0ZKgX00@0Z;gY0:Vmj02Y_NP0
ZKgX1P2X_NT20:Rnj@80YkkZ0P2X_^T20:NnjP030:Rnj@2W_^X0YkkZ0080YkkZ00<0Y[k[0?ooo`3o
ool0>03oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo01l0oooo00?o00000?ooo`3o
ool0;P3oool:0:Vmj0030:Rmj@2Y_NP0ZKgX00<0Z;gY1`2X_^T01000P]@0T;Sb092hlP2@^?820:jh
h080X<Kc102j`^000`35^m40a<_O0<C;g`020<C;g`050<g2d03=d]d0cM;M0<gBg@3Cb<l00`3EfM/2
0=3]j0040=_Of@3FlN<0e_7S0<7li@80S^k=<@3oool00ol00000oooo0?ooo`080?ooo`03o`00003o
ool0oooo00/0oooo000G0?ooo`03o`00003oool0oooo02h0oooo7@2Y_NP20:Rmj@030:Rmj02X_NT0
Z;gY0080Z;gY00<0Z;kY0:Rmj@2X_NT00`2X_^T20:NnjS`0oooo00?o00000?ooo`3oool0203oool0
0ol00000oooo0?ooo`0P0?ooo`03o`00003oool0oooo02h0oooo3@2Y_NP0102X_NT0Z;gX0:Rmj02X
_NP80:Rnj@80Hk_m102Pa_<20;[2h080[m?c0`34bml0102lg_00cM;M0<gBg@3=d]d30<SWk@030=GI
f`3@kNP0d>gX0080^?W[00<0O>G>000000000000<`3oool00ol00000oooo0?ooo`080?ooo`03o`00
003oool0oooo00/0oooo000H0?ooo`;o0000<03ooolM0:Vmj080Z;gX1`2X_NT00`2X_^T0oooo0?oo
o`0n0?ooo`03o`00003oool0oooo00L0oooo00?o00000?ooo`3oool08@3oool2o`000300oooo302Y
_NP20:Rmj0030:Vmj02X_NT0Z;gY0080Z;gY00<0Z;kY0:Rmj@2X_^T00`2X_^T00`0:U]L0X<Kc0:36
l`0307S>o`<0[m?c00D0a<_O0;cNl02lg_00_=k`0<gBg@030<SWk@050:cdlP1Wfm00Im_@06OKd02h
nN/0>03oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo00/0oooo000J0?ooo`03o`00
003oool0oooo02d0oooo8@2Y_NP00`2X_NT0oooo0?ooo`140?ooo`03o`00003oool0oooo00L0oooo
00?o00000?ooo`3oool08P3oool00ol00000oooo0?ooo`0]0?oooa00ZKgX0P2X_NT20:Vmj080Z;gY
0P2X_^T20:Rmj@80Z;kY0P1hc_l2022Zf0<0S=kn0P2lg_0209k[n@80D<kD00<0[?Cb0?ooo`3oool0
?03oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo00X0oooo000K0?ooo`03o`00003o
ool0oooo02d0oooo7`2Y_NQ90?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool08`3o
ool00ol00000oooo0?ooo`0]0?oooaL0ZKgX00<0Z;gY0:Vmj02Y_NP00`2X_NT20:RnjDT0oooo00?o
00000?ooo`3oool01P3oool00ol00000oooo0?ooo`0:0?ooo`00703oool00ol00000oooo0?ooo`0^
0?oooaX0ZKgXC03oool00ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo02@0oooo00?o0000
0?ooo`3oool0;P3ooolI0:Vmj0030:Rmj@3oool0oooo04X0oooo00?o00000?ooo`3oool01P3oool0
0ol00000oooo0?ooo`0:0?ooo`007@3oool00ol00000oooo0?ooo`0^0?oooa@0ZKgXDP3oool00ol0
0000oooo0?ooo`050?ooo`03o`00003oool0oooo02D0oooo00?o00000?ooo`3oool0;P3ooolD0:Vm
j580oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0:0?ooo`007P3oool2o`0002l0
oooo4@2Y_NQE0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool09P3oool2o`0002h0
oooo4P2Y_NQE0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool02P3oool00200oooo
00?o00000?ooo`3oool0;@3oool;0:Vmj5X0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
0?ooo`0X0?ooo`03o`00003oool0oooo02`0oooo302Y_NQJ0?ooo`03o`00003oool0oooo00@0oooo
00?o00000?ooo`3oool02P3oool00240oooo00?o00000?ooo`3oool0;@3oool80:Vmj5d0oooo00?o
00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0Y0?ooo`03o`00003oool0oooo02d0oooo1`2Y
_NQN0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool02P3oool00280oooo00?o0000
0?ooo`3oool0;@3oool40:Vmj640oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0Y
0?ooo`03o`00003oool0oooo02d0oooo102Y_NQQ0?ooo`03o`00003oool0oooo00<0oooo00?o0000
0?ooo`3oool02@3oool002<0oooo0_l0000]0?ooo`03o`00003oool0oooo06<0oooo00?o00000?oo
o`3oool00P3oool00ol00000oooo0?ooo`0Z0?ooo`;o0000;@3oool00ol00000oooo0?ooo`1S0?oo
o`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool02@3oool002D0oooo00?o00000?ooo`3o
ool0:P3oool00ol00000oooo0?ooo`1S0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3o
ool0;03oool00ol00000oooo0?ooo`0Z0?ooo`03o`00003oool0oooo06<0oooo00?o00000?ooo`3o
ool00P3oool00ol00000oooo0?ooo`090?ooo`009P3oool00ol00000oooo0?ooo`0Y0?ooo`03o`00
003oool0oooo06@0oooo00Go00000?ooo`3oool0ooooo`00000_0?ooo`03o`00003oool0oooo02T0
oooo00?o00000?ooo`3oool0I03oool01Ol00000oooo0?ooo`3ooooo000000/0oooo000W0?ooo`03
o`00003oool0oooo02P0oooo00?o00000?ooo`3oool0I@3oool01?l00000oooo0?ooool0000`0?oo
o`03o`00003oool0oooo02P0oooo00?o00000?ooo`3oool0I@3oool01?l00000oooo0?ooool0000;
0?ooo`00:03oool2o`0002P0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00000a0?oo
o`;o0000:03oool00ol00000oooo0?ooo`1V0?ooo`03o`00003ooooo000000/0oooo000Z0?ooo`03
o`00003oool0oooo02D0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00000c0?ooo`03
o`00003oool0oooo02D0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00000;0?ooo`00
:`3oool00ol00000oooo0?ooo`0T0?ooo`03o`00003oool0oooo06L0oooo00?o00000?ooool00000
<`3oool00ol00000oooo0?ooo`0T0?ooo`03o`00003oool0oooo06L0oooo00?o00000?ooool00000
2P3oool002`0oooo00?o00000?ooo`3oool08`3oool00ol00000oooo0?ooo`1X0?ooo`;o0000=03o
ool00ol00000oooo0?ooo`0S0?ooo`03o`00003oool0oooo06P0oooo0_l0000:0?ooo`00;@3oool2
o`0002<0oooo00?o00000?ooo`3oool0I`3oool3o`0003D0oooo0_l0000S0?ooo`03o`00003oool0
oooo06L0oooo0ol0000:0?ooo`00;`3oool00ol00000oooo0?ooo`0P0?ooo`03o`00003oool0oooo
06<0oooo1?l0000j0?ooo`03o`00003oool0oooo0200oooo00?o00000?ooo`3oool0H`3oool4o`00
00d0oooo000`0?ooo`03o`00003oool0oooo01l0oooo00?o00000?ooo`3oool0H03oool3o`0003l0
oooo00?o00000?ooo`3oool07`3oool00ol00000oooo0?ooo`1P0?ooo`?o00004@3oool00340oooo
00?o00000?ooo`3oool07P3oool00ol00000oooo0?ooo`1L0?ooo`Co0000@`3oool00ol00000oooo
0?ooo`0N0?ooo`03o`00003oool0oooo05`0oooo1?l0000D0?ooo`00<P3oool2o`0001h0oooo00?o
00000?ooo`3oool0F03oool4o`0004P0oooo0_l0000N0?ooo`03o`00003oool0oooo05P0oooo1?l0
000H0?ooo`00=03oool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo05@0oooo1?l0001>
0?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0E03oool4o`0001`0oooo000e0?oo
o`03o`00003oool0oooo01X0oooo00?o00000?ooo`3oool0D@3oool3o`0005<0oooo00?o00000?oo
o`3oool06P3oool00ol00000oooo0?ooo`1A0?ooo`?o0000803oool003H0oooo00?o00000?ooo`3o
ool06@3oool00ol00000oooo0?ooo`1=0?ooo`Co0000E`3oool00ol00000oooo0?ooo`0I0?ooo`03
o`00003oool0oooo04d0oooo1?l0000S0?ooo`00=`3oool2o`0001T0oooo00?o00000?ooo`3oool0
B@3oool4o`0005`0oooo0_l0000I0?ooo`03o`00003oool0oooo04T0oooo1?l0000W0?ooo`00>@3o
ool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo04D0oooo1?l0001R0?ooo`03o`00003o
ool0oooo01H0oooo00?o00000?ooo`3oool0A@3oool4o`0002/0oooo000j0?ooo`03o`00003oool0
oooo01@0oooo00?o00000?ooo`3oool0@`3oool3o`0006L0oooo00?o00000?ooo`3oool0503oool0
0ol00000oooo0?ooo`130?ooo`?o0000;`3oool003/0oooo00?o00000?ooo`3oool04`3oool00ol0
0000oooo0?ooo`0o0?ooo`Co0000J`3oool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo
03l0oooo1?l0000b0?ooo`00?03oool2o`0001<0oooo00?o00000?ooo`3oool0>`3oool4o`000700
oooo0_l0000C0?ooo`03o`00003oool0oooo03/0oooo1?l0000f0?ooo`00?P3oool00ol00000oooo
0?ooo`0@0?ooo`03o`00003oool0oooo03L0oooo1?l0001f0?ooo`03o`00003oool0oooo0100oooo
00?o00000?ooo`3oool0=`3oool4o`0003X0oooo000o0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0<`3oool4o`0007/0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`0c0?ooo`Co0000?P3oool00400oooo00?o00000?ooo`3oool03P3oool00ol00000oooo0?ooo`0`
0?ooo`?o0000P03oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo0300oooo0ol00012
0?ooo`00@@3oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo02`0oooo1?l000240?oo
o`03o`00003oool0oooo00d0oooo00?o00000?ooo`3oool0;03oool4o`0004D0oooo00120?ooo`;o
00003@3oool00ol00000oooo0?ooo`0X0?ooo`Co0000R@3oool2o`0000d0oooo00?o00000?ooo`3o
ool0:03oool4o`0004T0oooo00140?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool0
903oool4o`0008l0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0T0?ooo`Co0000
C@3oool004D0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0Q0?ooo`?o0000U03o
ool00ol00000oooo0?ooo`090?ooo`03o`00003oool0oooo0240oooo0ol0001A0?ooo`00AP3oool0
0ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo01d0oooo1?l0002H0?ooo`03o`00003oool0
oooo00P0oooo00?o00000?ooo`3oool07@3oool4o`0005@0oooo00170?ooo`;o0000203oool00ol0
0000oooo0?ooo`0I0?ooo`Co0000W@3oool2o`0000P0oooo00?o00000?ooo`3oool06@3oool4o`00
05P0oooo00190?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool05@3oool4o`000:<0
oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0E0?ooo`Co0000G03oool004X0oooo
00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0B0?ooo`?o0000Z03oool00ol00000oooo
0?ooo`040?ooo`03o`00003oool0oooo0180oooo0ol0001P0?ooo`00B`3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00h0oooo1?l0002/0?ooo`03o`00003oool0oooo00<0oooo00?o
00000?ooo`3oool03P3oool4o`0006<0oooo001<0?ooo`;o00000`3oool00ol00000oooo0?ooo`0:
0?ooo`Co0000/@3oool2o`0000<0oooo00?o00000?ooo`3oool02P3oool4o`0006L0oooo001>0?oo
o`04o`00003oool0ooooo`0000P0oooo1?l0002g0?ooo`04o`00003oool0ooooo`0000P0oooo1?l0
001[0?ooo`00C`3oool00ol00000ooooo`0000050?ooo`?o0000_03oool00ol00000ooooo`000005
0?ooo`?o0000K`3oool00500oooo0_l000000`3ooooo0000o`000002o`000<00oooo0_l000000`3o
oooo0000o`000002o`000780oooo001A0?ooo`;o0000a@3oool2o`0007H0oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-53.3508, \
-19.1129, 1.80794, 1.80794}, {{208.5, 389.375}, {315.688, 169}} -> {-412.962, \
-19.1129, 1.80794, 1.80794}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification in 2d", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, 
        gbase, Axes \[Rule] False, Frame \[Rule] True, \ 
        FrameTicks \[Rule] False, yS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.89066 4e-05 m
.89072 4e-05 L
.89078 4e-05 L
.89084 4e-05 L
.8909 4e-05 L
.89096 4e-05 L
.89101 4e-05 L
.89107 4e-05 L
.89113 4e-05 L
.89119 4e-05 L
.89125 4e-05 L
.89131 4e-05 L
.89137 4e-05 L
.89144 4e-05 L
.89147 4e-05 L
.89151 4e-05 L
.89157 4e-05 L
.89164 4e-05 L
.89167 4e-05 L
.89171 4e-05 L
.89177 4e-05 L
.89181 4e-05 L
.89184 4e-05 L
.89187 4e-05 L
.89191 4e-05 L
.89195 4e-05 L
.89198 4e-05 L
.89205 4e-05 L
.89212 4e-05 L
.89217 4e-05 L
.89223 4e-05 L
.89229 4e-05 L
.89235 4e-05 L
.89241 4e-05 L
.89248 4e-05 L
.89254 4e-05 L
.8926 4e-05 L
.89266 4e-05 L
.8927 4e-05 L
.89273 4e-05 L
.89277 4e-05 L
.89281 4e-05 L
.89288 4e-05 L
.89291 4e-05 L
.89295 4e-05 L
.89301 4e-05 L
.89307 4e-05 L
.89311 4e-05 L
.89314 4e-05 L
.89321 4e-05 L
Mistroke
.89325 4e-05 L
.89329 4e-05 L
.89332 4e-05 L
.89336 4e-05 L
.89339 4e-05 L
.89344 4e-05 L
.89347 4e-05 L
.89351 4e-05 L
.89355 4e-05 L
.89358 4e-05 L
.89362 4e-05 L
.89366 4e-05 L
.89372 4e-05 L
.89376 4e-05 L
.89379 4e-05 L
.89385 4e-05 L
.89392 4e-05 L
.89398 4e-05 L
.89403 4e-05 L
.8941 4e-05 L
.89416 4e-05 L
.8942 4e-05 L
.89424 4e-05 L
.8943 4e-05 L
.89434 4e-05 L
.89437 4e-05 L
.89441 4e-05 L
.89445 4e-05 L
.89451 4e-05 L
.89455 4e-05 L
.89459 4e-05 L
.89465 4e-05 L
.89471 4e-05 L
.89478 4e-05 L
.89484 4e-05 L
.8949 4e-05 L
.89496 4e-05 L
.89502 4e-05 L
.89508 4e-05 L
.89514 4e-05 L
.89521 4e-05 L
.89524 4e-05 L
.89528 4e-05 L
.89534 4e-05 L
.89538 4e-05 L
.89541 4e-05 L
.89545 4e-05 L
.89548 4e-05 L
.89555 4e-05 L
.89558 4e-05 L
Mistroke
.89562 4e-05 L
.89568 4e-05 L
.89574 4e-05 L
.89581 4e-05 L
.89587 4e-05 L
.89593 4e-05 L
.89599 4e-05 L
.89605 4e-05 L
.89611 4e-05 L
.89616 4e-05 L
.89621 4e-05 L
.89627 4e-05 L
.89633 4e-05 L
.89639 4e-05 L
.89645 4e-05 L
.89651 4e-05 L
.89656 4e-05 L
.89663 4e-05 L
.89666 4e-05 L
.8967 4e-05 L
.89676 4e-05 L
.89682 4e-05 L
.89688 4e-05 L
.89695 4e-05 L
.89701 4e-05 L
.89708 4e-05 L
.89714 4e-05 L
.89719 4e-05 L
.89725 4e-05 L
.89731 4e-05 L
.89737 4e-05 L
.89744 4e-05 L
.8975 4e-05 L
.89756 4e-05 L
.89763 4e-05 L
.89767 4e-05 L
.8977 4e-05 L
.89777 4e-05 L
.89783 4e-05 L
.89789 4e-05 L
.89795 4e-05 L
.89801 4e-05 L
.89807 4e-05 L
.89812 4e-05 L
.89817 4e-05 L
.89823 4e-05 L
.89828 4e-05 L
.89834 4e-05 L
.89841 4e-05 L
.89847 4e-05 L
Mistroke
.89852 4e-05 L
.89858 4e-05 L
.89862 4e-05 L
.89865 4e-05 L
.89871 4e-05 L
.89878 4e-05 L
.89884 4e-05 L
.89891 4e-05 L
.89897 4e-05 L
.89903 4e-05 L
.89909 4e-05 L
.89914 4e-05 L
.89921 4e-05 L
.89926 4e-05 L
.89933 4e-05 L
.8994 4e-05 L
.89945 4e-05 L
.89952 4e-05 L
.89958 4e-05 L
.89962 4e-05 L
.89966 4e-05 L
.89972 4e-05 L
.89979 4e-05 L
.89984 4e-05 L
.8999 4e-05 L
.89996 4e-05 L
.90002 4e-05 L
.90008 4e-05 L
.90013 4e-05 L
.90018 4e-05 L
.90024 4e-05 L
.9003 4e-05 L
.90036 4e-05 L
.90042 4e-05 L
.90048 4e-05 L
.90054 4e-05 L
.90058 4e-05 L
.90061 4e-05 L
.90067 4e-05 L
.90073 4e-05 L
.9008 4e-05 L
.90087 4e-05 L
.90093 4e-05 L
.90099 4e-05 L
.90105 4e-05 L
.9011 4e-05 L
.90116 4e-05 L
.90122 4e-05 L
.90129 4e-05 L
.90135 4e-05 L
Mistroke
.90141 4e-05 L
.90147 4e-05 L
.90154 4e-05 L
.90158 4e-05 L
.90162 4e-05 L
.90168 4e-05 L
.90175 4e-05 L
.9018 4e-05 L
.90186 4e-05 L
.90192 4e-05 L
.90198 4e-05 L
.90204 4e-05 L
.90209 4e-05 L
.90214 4e-05 L
.9022 4e-05 L
.90226 4e-05 L
.90232 4e-05 L
.90238 4e-05 L
.90244 4e-05 L
.9025 4e-05 L
.90254 4e-05 L
.90257 4e-05 L
.90263 4e-05 L
.90269 4e-05 L
.90276 4e-05 L
.90283 4e-05 L
.90289 4e-05 L
.90295 4e-05 L
.903 4e-05 L
.90306 4e-05 L
.90313 4e-05 L
.90318 4e-05 L
.90325 4e-05 L
.90332 4e-05 L
.90337 4e-05 L
.90344 4e-05 L
.9035 4e-05 L
.90354 4e-05 L
.90358 4e-05 L
.90364 4e-05 L
.90371 4e-05 L
.90376 4e-05 L
.90382 4e-05 L
.90389 4e-05 L
.90395 4e-05 L
.904 4e-05 L
.90405 4e-05 L
.90411 4e-05 L
.90416 4e-05 L
.90422 4e-05 L
Mistroke
.90429 4e-05 L
.90435 4e-05 L
.9044 4e-05 L
.90446 4e-05 L
.9045 4e-05 L
.90453 4e-05 L
.90459 4e-05 L
.90466 4e-05 L
.90472 4e-05 L
.90476 4e-05 L
.90479 4e-05 L
.90485 4e-05 L
.90491 4e-05 L
.90497 4e-05 L
.90502 4e-05 L
.90508 4e-05 L
.90515 4e-05 L
.90521 4e-05 L
.90525 4e-05 L
.90528 4e-05 L
.90535 4e-05 L
.90539 4e-05 L
.90542 4e-05 L
.90548 4e-05 L
.90555 4e-05 L
.90561 4e-05 L
.90567 4e-05 L
.90573 4e-05 L
.90579 4e-05 L
.90584 4e-05 L
.90589 4e-05 L
.90595 4e-05 L
.90602 4e-05 L
.90608 4e-05 L
.90613 4e-05 L
.9062 4e-05 L
.90626 4e-05 L
.90631 4e-05 L
.90637 4e-05 L
.90643 4e-05 L
.9065 4e-05 L
.90656 4e-05 L
.90662 4e-05 L
.90669 4e-05 L
.90675 4e-05 L
.90678 4e-05 L
.90682 4e-05 L
.90686 4e-05 L
.90689 4e-05 L
.90696 4e-05 L
Mistroke
.90702 4e-05 L
.90709 4e-05 L
.90715 4e-05 L
.90721 4e-05 L
.90727 4e-05 L
.90733 4e-05 L
.90738 4e-05 L
.90744 4e-05 L
.90751 4e-05 L
.90757 4e-05 L
.90763 4e-05 L
.9077 4e-05 L
.90776 4e-05 L
.90783 4e-05 L
.90788 4e-05 L
.90795 4e-05 L
.90799 4e-05 L
.90803 4e-05 L
.90809 4e-05 L
.90812 4e-05 L
.90816 4e-05 L
.90819 4e-05 L
.90823 4e-05 L
.9083 4e-05 L
.90833 4e-05 L
.90837 4e-05 L
.90841 4e-05 L
.90845 4e-05 L
.90848 4e-05 L
.90852 4e-05 L
.90855 4e-05 L
.90859 4e-05 L
.90865 4e-05 L
.90872 4e-05 L
.90878 4e-05 L
.90885 4e-05 L
.90891 4e-05 L
.90897 4e-05 L
.90903 4e-05 L
.90908 4e-05 L
.90915 4e-05 L
.9092 4e-05 L
.90927 4e-05 L
.90933 4e-05 L
.90939 4e-05 L
.90946 4e-05 L
.90952 4e-05 L
.90956 4e-05 L
.9096 4e-05 L
.90966 4e-05 L
Mistroke
.90973 4e-05 L
.90978 4e-05 L
.90984 4e-05 L
.9099 4e-05 L
.90996 4e-05 L
.91002 4e-05 L
.91007 4e-05 L
.91012 4e-05 L
.91018 4e-05 L
.91024 4e-05 L
.9103 4e-05 L
.91036 4e-05 L
.91042 4e-05 L
.91048 4e-05 L
.91052 4e-05 L
.91055 4e-05 L
.91061 4e-05 L
.91067 4e-05 L
.91074 4e-05 L
.91081 4e-05 L
.91087 4e-05 L
.91093 4e-05 L
.91099 4e-05 L
.91104 4e-05 L
.91111 4e-05 L
.91116 4e-05 L
.91123 4e-05 L
.9113 4e-05 L
.91135 4e-05 L
.91142 4e-05 L
.91148 4e-05 L
.91152 4e-05 L
.91156 4e-05 L
.91162 4e-05 L
.91169 4e-05 L
.91174 4e-05 L
.9118 4e-05 L
.91187 4e-05 L
.91192 4e-05 L
.91198 4e-05 L
.91203 4e-05 L
.91209 4e-05 L
.91214 4e-05 L
.9122 4e-05 L
.91227 4e-05 L
.91233 4e-05 L
.91238 4e-05 L
.91244 4e-05 L
.91248 4e-05 L
.91251 4e-05 L
Mistroke
.91257 4e-05 L
.91264 4e-05 L
.9127 4e-05 L
.91274 4e-05 L
.91277 4e-05 L
.91283 4e-05 L
.91289 4e-05 L
.91295 4e-05 L
.913 4e-05 L
.91306 4e-05 L
.91313 4e-05 L
.91319 4e-05 L
.91323 4e-05 L
.91326 4e-05 L
.91333 4e-05 L
.91337 4e-05 L
.9134 4e-05 L
.91346 4e-05 L
.91353 4e-05 L
.91359 4e-05 L
.91365 4e-05 L
.91371 4e-05 L
.91377 4e-05 L
.91382 4e-05 L
.91387 4e-05 L
.91393 4e-05 L
.914 4e-05 L
.91406 4e-05 L
.91411 4e-05 L
.91418 4e-05 L
.91424 4e-05 L
.91429 4e-05 L
.91435 4e-05 L
.91441 4e-05 L
.91448 4e-05 L
.91454 4e-05 L
.9146 4e-05 L
.91467 4e-05 L
.91473 4e-05 L
.91476 4e-05 L
.9148 4e-05 L
.91484 4e-05 L
.91487 4e-05 L
.91494 4e-05 L
.915 4e-05 L
.91506 4e-05 L
.91513 4e-05 L
.91519 4e-05 L
.91525 4e-05 L
.91531 4e-05 L
Mistroke
.91536 4e-05 L
.91542 4e-05 L
.91549 4e-05 L
.91555 4e-05 L
.91561 4e-05 L
.91567 4e-05 L
.91574 4e-05 L
.9158 4e-05 L
.91586 4e-05 L
.91593 4e-05 L
.91597 4e-05 L
.916 4e-05 L
.91607 4e-05 L
.9161 4e-05 L
.91614 4e-05 L
.91617 4e-05 L
.91621 4e-05 L
.91628 4e-05 L
.91631 4e-05 L
.91635 4e-05 L
.91638 4e-05 L
.91643 4e-05 L
.91646 4e-05 L
.9165 4e-05 L
.91653 4e-05 L
.91657 4e-05 L
.91663 4e-05 L
.91669 4e-05 L
.91676 4e-05 L
.91683 4e-05 L
.91689 4e-05 L
.91695 4e-05 L
.91701 4e-05 L
.91706 4e-05 L
.91712 4e-05 L
.91718 4e-05 L
.91725 4e-05 L
.91731 4e-05 L
.91737 4e-05 L
.91743 4e-05 L
.9175 4e-05 L
.91754 4e-05 L
.91757 4e-05 L
.91764 4e-05 L
.91771 4e-05 L
.91776 4e-05 L
.91782 4e-05 L
.91788 4e-05 L
.91794 4e-05 L
.918 4e-05 L
Mistroke
.91805 4e-05 L
.9181 4e-05 L
.91816 4e-05 L
.91822 4e-05 L
.91828 4e-05 L
.91834 4e-05 L
.9184 4e-05 L
.91846 4e-05 L
.91849 4e-05 L
.91853 4e-05 L
.91859 4e-05 L
.91865 4e-05 L
.91872 4e-05 L
.91878 4e-05 L
.91885 4e-05 L
.91891 4e-05 L
.91897 4e-05 L
.91902 4e-05 L
.91908 4e-05 L
.91914 4e-05 L
.91921 4e-05 L
.91927 4e-05 L
.91933 4e-05 L
.91939 4e-05 L
.91946 4e-05 L
.9195 4e-05 L
.91953 4e-05 L
.9196 4e-05 L
.91967 4e-05 L
.91972 4e-05 L
.91978 4e-05 L
.91984 4e-05 L
.9199 4e-05 L
.91996 4e-05 L
.92001 4e-05 L
.92007 4e-05 L
.92012 4e-05 L
.92018 4e-05 L
.92024 4e-05 L
.9203 4e-05 L
.92036 4e-05 L
.92042 4e-05 L
.92046 4e-05 L
.92049 4e-05 L
.92055 4e-05 L
.92061 4e-05 L
.92068 4e-05 L
.92071 4e-05 L
.92075 4e-05 L
.92081 4e-05 L
Mistroke
.92087 4e-05 L
.92093 4e-05 L
.92098 4e-05 L
.92104 4e-05 L
.9211 4e-05 L
.92117 4e-05 L
.9212 4e-05 L
.92124 4e-05 L
.92131 4e-05 L
.92134 4e-05 L
.92138 4e-05 L
.92144 4e-05 L
.92151 4e-05 L
.92157 4e-05 L
.92163 4e-05 L
.92168 4e-05 L
.92174 4e-05 L
.9218 4e-05 L
.92185 4e-05 L
.92191 4e-05 L
.92197 4e-05 L
.92203 4e-05 L
.92209 4e-05 L
.92215 4e-05 L
.92221 4e-05 L
.92227 4e-05 L
.92233 4e-05 L
.92239 4e-05 L
.92246 4e-05 L
.92251 4e-05 L
.92258 4e-05 L
.92265 4e-05 L
.92271 4e-05 L
.92274 4e-05 L
.92278 4e-05 L
.92281 4e-05 L
.92285 4e-05 L
.92291 4e-05 L
.92297 4e-05 L
.92304 4e-05 L
.92311 4e-05 L
.92316 4e-05 L
.92323 4e-05 L
.92328 4e-05 L
.92334 4e-05 L
.9234 4e-05 L
.92347 4e-05 L
.92353 4e-05 L
.92359 4e-05 L
.92365 4e-05 L
Mistroke
.92372 4e-05 L
.92378 4e-05 L
.92384 4e-05 L
.92391 4e-05 L
.92394 4e-05 L
.92398 4e-05 L
.92405 4e-05 L
.92408 4e-05 L
.92411 4e-05 L
.92415 4e-05 L
.92419 4e-05 L
.92425 4e-05 L
.92429 4e-05 L
.92432 4e-05 L
.92436 4e-05 L
.9244 4e-05 L
.92444 4e-05 L
.92447 4e-05 L
.92451 4e-05 L
.92454 4e-05 L
.9246 4e-05 L
.92467 4e-05 L
.92473 4e-05 L
.9248 4e-05 L
.92487 4e-05 L
.92493 4e-05 L
.92498 4e-05 L
.92504 4e-05 L
.9251 4e-05 L
.92516 4e-05 L
.92522 4e-05 L
.92529 4e-05 L
.92535 4e-05 L
.92541 4e-05 L
.92548 4e-05 L
.92552 4e-05 L
.92555 4e-05 L
.92562 4e-05 L
.92568 4e-05 L
.92574 4e-05 L
.9258 4e-05 L
.92586 4e-05 L
.92592 4e-05 L
.92597 4e-05 L
.92602 4e-05 L
.92608 4e-05 L
.92614 4e-05 L
.92619 4e-05 L
.92626 4e-05 L
.92632 4e-05 L
Mistroke
.92637 4e-05 L
.92643 4e-05 L
.92647 4e-05 L
.9265 4e-05 L
.92656 4e-05 L
.92663 4e-05 L
.92669 4e-05 L
.92676 4e-05 L
.92682 4e-05 L
.92688 4e-05 L
.92694 4e-05 L
.927 4e-05 L
.92706 4e-05 L
.92712 4e-05 L
.92718 4e-05 L
.92725 4e-05 L
.92731 4e-05 L
.92737 4e-05 L
.92744 4e-05 L
.92748 4e-05 L
.92751 4e-05 L
.92758 4e-05 L
.92764 4e-05 L
.9277 4e-05 L
.92776 4e-05 L
.92782 4e-05 L
.92788 4e-05 L
.92793 4e-05 L
.92798 4e-05 L
.92804 4e-05 L
.9281 4e-05 L
.92815 4e-05 L
.92822 4e-05 L
.92828 4e-05 L
.92833 4e-05 L
.92839 4e-05 L
.92843 4e-05 L
.92846 4e-05 L
.92852 4e-05 L
.92859 4e-05 L
.92865 4e-05 L
.92869 4e-05 L
.92872 4e-05 L
.92878 4e-05 L
.92884 4e-05 L
.9289 4e-05 L
.92896 4e-05 L
.92901 4e-05 L
.92908 4e-05 L
.92914 4e-05 L
Mistroke
.92918 4e-05 L
.92921 4e-05 L
.92928 4e-05 L
.92932 4e-05 L
.92935 4e-05 L
.92941 4e-05 L
.92948 4e-05 L
.92954 4e-05 L
.9296 4e-05 L
.92966 4e-05 L
.92972 4e-05 L
.92977 4e-05 L
.92982 4e-05 L
.92988 4e-05 L
.92995 4e-05 L
.93001 4e-05 L
.93006 4e-05 L
.93013 4e-05 L
.93019 4e-05 L
.93024 4e-05 L
.9303 4e-05 L
.93036 4e-05 L
.93043 4e-05 L
.93049 4e-05 L
.93055 4e-05 L
.93062 4e-05 L
.93068 4e-05 L
.93071 4e-05 L
.93075 4e-05 L
.93079 4e-05 L
.93082 4e-05 L
.93089 4e-05 L
.93095 4e-05 L
.93101 4e-05 L
.93108 4e-05 L
.93114 4e-05 L
.9312 4e-05 L
.93126 4e-05 L
.93131 4e-05 L
.93137 4e-05 L
.93144 4e-05 L
.9315 4e-05 L
.93156 4e-05 L
.93162 4e-05 L
.93169 4e-05 L
.93175 4e-05 L
.93181 4e-05 L
.93188 4e-05 L
.93192 4e-05 L
.93195 4e-05 L
Mistroke
.93202 4e-05 L
.93205 4e-05 L
.93209 4e-05 L
.93212 4e-05 L
.93216 4e-05 L
.93223 4e-05 L
.93226 4e-05 L
.9323 4e-05 L
.93233 4e-05 L
.93237 4e-05 L
.93241 4e-05 L
.93245 4e-05 L
.93248 4e-05 L
.93252 4e-05 L
.93258 4e-05 L
.93264 4e-05 L
.93271 4e-05 L
.93277 4e-05 L
.93284 4e-05 L
.9329 4e-05 L
.93296 4e-05 L
.93301 4e-05 L
.93307 4e-05 L
.93313 4e-05 L
.93319 4e-05 L
.93326 4e-05 L
.93332 4e-05 L
.93338 4e-05 L
.93345 4e-05 L
.93349 4e-05 L
.93352 4e-05 L
.93359 4e-05 L
.93365 4e-05 L
.93371 4e-05 L
.93377 4e-05 L
.93383 4e-05 L
.93389 4e-05 L
.93394 4e-05 L
.93399 4e-05 L
.93405 4e-05 L
.93411 4e-05 L
.93417 4e-05 L
.93423 4e-05 L
.93429 4e-05 L
.93434 4e-05 L
.93441 4e-05 L
.93444 4e-05 L
.93448 4e-05 L
.93454 4e-05 L
.9346 4e-05 L
Mistroke
.93466 4e-05 L
.93473 4e-05 L
.9348 4e-05 L
.93486 4e-05 L
.93492 4e-05 L
.93497 4e-05 L
.93503 4e-05 L
.93509 4e-05 L
.93515 4e-05 L
.93522 4e-05 L
.93528 4e-05 L
.93534 4e-05 L
.93541 4e-05 L
.93545 4e-05 L
.93548 4e-05 L
.93555 4e-05 L
.93561 4e-05 L
.93567 4e-05 L
.93573 4e-05 L
.93579 4e-05 L
.93585 4e-05 L
.9359 4e-05 L
.93595 4e-05 L
.93601 4e-05 L
.93607 4e-05 L
.93613 4e-05 L
.93619 4e-05 L
.93625 4e-05 L
.9363 4e-05 L
.93637 4e-05 L
.9364 4e-05 L
.93644 4e-05 L
.9365 4e-05 L
.93656 4e-05 L
.93662 4e-05 L
.93666 4e-05 L
.93669 4e-05 L
.93675 4e-05 L
.93682 4e-05 L
.93687 4e-05 L
.93693 4e-05 L
.93699 4e-05 L
.93705 4e-05 L
.93711 4e-05 L
.93715 4e-05 L
.93718 4e-05 L
.93725 4e-05 L
.93729 4e-05 L
.93732 4e-05 L
.93739 4e-05 L
Mistroke
.93745 4e-05 L
.93752 4e-05 L
.93758 4e-05 L
.93763 4e-05 L
.93769 4e-05 L
.93774 4e-05 L
.93779 4e-05 L
.93785 4e-05 L
.93792 4e-05 L
.93798 4e-05 L
.93804 4e-05 L
.9381 4e-05 L
.93816 4e-05 L
.93821 4e-05 L
.93827 4e-05 L
.93834 4e-05 L
.9384 4e-05 L
.93846 4e-05 L
.93852 4e-05 L
.93857 4e-05 L
.93861 4e-05 L
.93866 4e-05 L
.93871 4e-05 L
.93875 4e-05 L
.93879 4e-05 L
.93883 4e-05 L
.93888 4e-05 L
.93892 4e-05 L
.93896 4e-05 L
.93901 4e-05 L
.93905 4e-05 L
.93909 4e-05 L
.93913 4e-05 L
.93917 4e-05 L
.93921 4e-05 L
.93925 4e-05 L
.93929 4e-05 L
.93934 4e-05 L
.93939 4e-05 L
.93943 4e-05 L
.93947 4e-05 L
.93951 4e-05 L
.93956 4e-05 L
.9396 4e-05 L
.93965 4e-05 L
.9397 4e-05 L
.93974 4e-05 L
.93979 4e-05 L
.93984 4e-05 L
.93989 4e-05 L
Mistroke
.93994 4e-05 L
Mfstroke
.89066 .71509 m
.89266 .71872 L
.89484 .72275 L
.89689 .7266 L
.89886 .73038 L
.90095 .73448 L
.90297 .73851 L
.90512 .7429 L
.90718 .74723 L
.90917 .7515 L
.91128 .75618 L
.91332 .76081 L
.91528 .76542 L
.91736 .77049 L
.91937 .77556 L
.9215 .7812 L
.92355 .78689 L
.92553 .79268 L
.92763 .79923 L
.92966 .80603 L
.93181 .81395 L
.93388 .82255 L
.93588 .83224 L
.93689 .83802 L
.938 .84554 L
.93848 .84946 L
.939 .85446 L
.93925 .85737 L
.93949 .86067 L
.9397 .86449 L
.93976 .86583 L
.93982 .86752 L
.93988 .8694 L
.93994 .87428 L
s
.5 1 1 r
.89066 4e-05 m
.89072 4e-05 L
.89078 4e-05 L
.89084 4e-05 L
.8909 4e-05 L
.89096 4e-05 L
.89101 4e-05 L
.89107 4e-05 L
.89113 4e-05 L
.89119 4e-05 L
.89125 4e-05 L
.89131 4e-05 L
.89137 4e-05 L
.89144 4e-05 L
.89147 4e-05 L
.89151 4e-05 L
.89157 4e-05 L
.89164 4e-05 L
.89167 4e-05 L
.89171 4e-05 L
.89177 4e-05 L
.89181 4e-05 L
.89184 4e-05 L
.89187 4e-05 L
.89191 4e-05 L
.89195 4e-05 L
.89198 4e-05 L
.89205 4e-05 L
.89212 4e-05 L
.89217 4e-05 L
.89223 4e-05 L
.89229 4e-05 L
.89235 4e-05 L
.89241 4e-05 L
.89248 4e-05 L
.89254 4e-05 L
.8926 4e-05 L
.89266 4e-05 L
.8927 4e-05 L
.89273 4e-05 L
.89277 4e-05 L
.89281 4e-05 L
.89288 4e-05 L
.89291 4e-05 L
.89295 4e-05 L
.89301 4e-05 L
.89307 4e-05 L
.89311 4e-05 L
.89314 4e-05 L
.89321 4e-05 L
.89325 4e-05 L
.89329 4e-05 L
.89332 4e-05 L
.89336 4e-05 L
.89339 4e-05 L
.89344 4e-05 L
.89347 4e-05 L
.89351 4e-05 L
.89355 4e-05 L
.89358 4e-05 L
.89362 4e-05 L
.89366 4e-05 L
.89372 4e-05 L
.89376 4e-05 L
.89379 4e-05 L
.89385 4e-05 L
.89392 4e-05 L
.89398 4e-05 L
.89403 4e-05 L
.8941 4e-05 L
.89416 4e-05 L
.8942 4e-05 L
.89424 4e-05 L
.8943 4e-05 L
.89434 4e-05 L
.89437 4e-05 L
.89441 4e-05 L
.89445 4e-05 L
.89451 4e-05 L
.89455 4e-05 L
.89459 4e-05 L
.89465 4e-05 L
.89471 4e-05 L
.89478 4e-05 L
.89484 4e-05 L
.8949 4e-05 L
.89496 4e-05 L
.89502 4e-05 L
.89508 4e-05 L
.89514 4e-05 L
.89521 4e-05 L
.89524 4e-05 L
.89528 4e-05 L
.89534 4e-05 L
.89538 4e-05 L
.89541 4e-05 L
.89545 4e-05 L
.89548 4e-05 L
.89555 4e-05 L
.89558 4e-05 L
.89562 4e-05 L
.89568 4e-05 L
.89574 4e-05 L
.89581 4e-05 L
.89587 4e-05 L
.89593 4e-05 L
.89599 4e-05 L
.89605 4e-05 L
.89611 4e-05 L
.89616 4e-05 L
.89621 4e-05 L
.89627 4e-05 L
.89633 4e-05 L
.89639 4e-05 L
.89645 4e-05 L
.89651 4e-05 L
.89656 4e-05 L
.89663 4e-05 L
.89666 4e-05 L
.8967 4e-05 L
.89676 4e-05 L
.89682 4e-05 L
.89688 4e-05 L
.89695 4e-05 L
.89701 4e-05 L
.89708 4e-05 L
.89714 4e-05 L
.89719 4e-05 L
.89725 4e-05 L
.89731 4e-05 L
.89737 4e-05 L
.89744 4e-05 L
.8975 4e-05 L
.89756 4e-05 L
.89763 4e-05 L
.89767 4e-05 L
.8977 4e-05 L
.89777 4e-05 L
.89783 4e-05 L
.89789 4e-05 L
.89795 4e-05 L
.89801 4e-05 L
.89807 4e-05 L
.89812 4e-05 L
.89817 4e-05 L
.89823 4e-05 L
.89828 4e-05 L
.89834 4e-05 L
.89841 4e-05 L
.89847 4e-05 L
.89852 4e-05 L
.89858 4e-05 L
.89862 4e-05 L
.89865 4e-05 L
.89871 4e-05 L
.89878 4e-05 L
.89884 4e-05 L
.89891 4e-05 L
.89897 4e-05 L
.89903 4e-05 L
.89909 4e-05 L
.89914 4e-05 L
.89921 4e-05 L
.89926 4e-05 L
.89933 4e-05 L
.8994 4e-05 L
.89945 4e-05 L
.89952 4e-05 L
.89958 4e-05 L
.89962 4e-05 L
.89966 4e-05 L
.89972 4e-05 L
.89979 4e-05 L
.89984 4e-05 L
.8999 4e-05 L
.89996 4e-05 L
.90002 4e-05 L
.90008 4e-05 L
.90013 4e-05 L
.90018 4e-05 L
.90024 4e-05 L
.9003 4e-05 L
.90036 4e-05 L
.90042 4e-05 L
.90048 4e-05 L
.90054 4e-05 L
.90058 4e-05 L
.90061 4e-05 L
.90067 4e-05 L
.90073 4e-05 L
.9008 4e-05 L
.90087 4e-05 L
.90093 4e-05 L
.90099 4e-05 L
.90105 4e-05 L
.9011 4e-05 L
.90116 4e-05 L
.90122 4e-05 L
.90129 4e-05 L
.90135 4e-05 L
.90141 4e-05 L
.90147 4e-05 L
.90154 4e-05 L
.90158 4e-05 L
.90162 4e-05 L
.90168 4e-05 L
.90175 4e-05 L
.9018 4e-05 L
.90186 4e-05 L
.90192 4e-05 L
.90198 4e-05 L
.90204 4e-05 L
.90209 4e-05 L
.90214 4e-05 L
.9022 4e-05 L
.90226 4e-05 L
.90232 4e-05 L
.90238 4e-05 L
.90244 4e-05 L
.9025 4e-05 L
.90254 4e-05 L
.90257 4e-05 L
.90263 4e-05 L
.90269 4e-05 L
.90276 4e-05 L
.90283 4e-05 L
.90289 4e-05 L
.90295 4e-05 L
.903 4e-05 L
.90306 4e-05 L
.90313 4e-05 L
.90318 4e-05 L
.90325 4e-05 L
.90332 4e-05 L
.90337 4e-05 L
.90344 4e-05 L
.9035 4e-05 L
.90354 4e-05 L
.90358 4e-05 L
.90364 4e-05 L
.90371 4e-05 L
.90376 4e-05 L
.90382 4e-05 L
.90389 4e-05 L
.90395 4e-05 L
.904 4e-05 L
.90405 4e-05 L
.90411 4e-05 L
.90416 4e-05 L
.90422 4e-05 L
.90429 4e-05 L
.90435 4e-05 L
.9044 4e-05 L
.90446 4e-05 L
.9045 4e-05 L
.90453 4e-05 L
.90459 4e-05 L
.90466 4e-05 L
.90472 4e-05 L
.90476 4e-05 L
.90479 4e-05 L
.90485 4e-05 L
.90491 4e-05 L
.90497 4e-05 L
.90502 4e-05 L
.90508 4e-05 L
.90515 4e-05 L
.90521 4e-05 L
.90525 4e-05 L
.90528 4e-05 L
.90535 4e-05 L
.90539 4e-05 L
.90542 4e-05 L
.90548 4e-05 L
.90555 4e-05 L
.90561 4e-05 L
.90567 4e-05 L
.90573 4e-05 L
.90579 4e-05 L
.90584 4e-05 L
.90589 4e-05 L
.90595 4e-05 L
.90602 4e-05 L
.90608 4e-05 L
.90613 4e-05 L
.9062 4e-05 L
.90626 4e-05 L
.90631 4e-05 L
.90637 4e-05 L
.90643 4e-05 L
.9065 4e-05 L
.90656 4e-05 L
.90662 4e-05 L
.90669 4e-05 L
.90675 4e-05 L
.90678 4e-05 L
.90682 4e-05 L
.90686 4e-05 L
.90689 4e-05 L
.90696 4e-05 L
.90702 4e-05 L
.90709 4e-05 L
.90715 4e-05 L
.90721 4e-05 L
.90727 4e-05 L
.90733 4e-05 L
.90738 4e-05 L
.90744 4e-05 L
.90751 4e-05 L
.90757 4e-05 L
.90763 4e-05 L
.9077 4e-05 L
.90776 4e-05 L
.90783 4e-05 L
.90788 4e-05 L
.90795 4e-05 L
.90799 4e-05 L
.90803 4e-05 L
.90809 4e-05 L
.90812 4e-05 L
.90816 4e-05 L
.90819 4e-05 L
.90823 4e-05 L
.9083 4e-05 L
.90833 4e-05 L
.90837 4e-05 L
.90841 4e-05 L
.90845 4e-05 L
.90848 4e-05 L
.90852 4e-05 L
.90855 4e-05 L
.90859 4e-05 L
.90865 4e-05 L
.90872 4e-05 L
.90878 4e-05 L
.90885 4e-05 L
.90891 4e-05 L
.90897 4e-05 L
.90903 4e-05 L
.90908 4e-05 L
.90915 4e-05 L
.9092 4e-05 L
.90927 4e-05 L
.90933 4e-05 L
.90939 4e-05 L
.90946 4e-05 L
.90952 4e-05 L
.90956 4e-05 L
.9096 4e-05 L
.90966 4e-05 L
.90973 4e-05 L
.90978 4e-05 L
.90984 4e-05 L
.9099 4e-05 L
.90996 4e-05 L
.91002 4e-05 L
.91007 4e-05 L
.91012 4e-05 L
.91018 4e-05 L
.91024 4e-05 L
.9103 4e-05 L
.91036 4e-05 L
.91042 4e-05 L
.91048 4e-05 L
.91052 4e-05 L
.91055 4e-05 L
.91061 4e-05 L
.91067 4e-05 L
.91074 4e-05 L
.91081 4e-05 L
.91087 4e-05 L
.91093 4e-05 L
.91099 4e-05 L
.91104 4e-05 L
.91111 4e-05 L
.91116 4e-05 L
.91123 4e-05 L
.9113 4e-05 L
.91135 4e-05 L
.91142 4e-05 L
.91148 4e-05 L
.91152 4e-05 L
.91156 4e-05 L
.91162 4e-05 L
.91169 4e-05 L
.91174 4e-05 L
.9118 4e-05 L
.91187 4e-05 L
.91192 4e-05 L
.91198 4e-05 L
.91203 4e-05 L
.91209 4e-05 L
.91214 4e-05 L
.9122 4e-05 L
.91227 4e-05 L
.91233 4e-05 L
.91238 4e-05 L
.91244 4e-05 L
.91248 4e-05 L
.91251 4e-05 L
.91257 4e-05 L
.91264 4e-05 L
.9127 4e-05 L
.91274 4e-05 L
.91277 4e-05 L
.91283 4e-05 L
.91289 4e-05 L
.91295 4e-05 L
.913 4e-05 L
.91306 4e-05 L
.91313 4e-05 L
.91319 4e-05 L
.91323 4e-05 L
.91326 4e-05 L
.91333 4e-05 L
.91337 4e-05 L
.9134 4e-05 L
.91346 4e-05 L
.91353 4e-05 L
.91359 4e-05 L
.91365 4e-05 L
.91371 4e-05 L
.91377 4e-05 L
.91382 4e-05 L
.91387 4e-05 L
.91393 4e-05 L
.914 4e-05 L
.91406 4e-05 L
.91411 4e-05 L
.91418 4e-05 L
.91424 4e-05 L
.91429 4e-05 L
.91435 4e-05 L
.91441 4e-05 L
.91448 4e-05 L
.91454 4e-05 L
.9146 4e-05 L
.91467 4e-05 L
.91473 4e-05 L
.91476 4e-05 L
.9148 4e-05 L
.91484 4e-05 L
.91487 4e-05 L
.91494 4e-05 L
.915 4e-05 L
.91506 4e-05 L
.91513 4e-05 L
.91519 4e-05 L
.91525 4e-05 L
.91531 4e-05 L
.91536 4e-05 L
.91542 4e-05 L
.91549 4e-05 L
.91555 4e-05 L
.91561 4e-05 L
.91567 4e-05 L
.91574 4e-05 L
.9158 4e-05 L
.91586 4e-05 L
.91593 4e-05 L
.91597 4e-05 L
.916 4e-05 L
.91607 4e-05 L
.9161 4e-05 L
.91614 4e-05 L
.91617 4e-05 L
.91621 4e-05 L
.91628 4e-05 L
.91631 4e-05 L
.91635 4e-05 L
.91638 4e-05 L
.91643 4e-05 L
.91646 4e-05 L
.9165 4e-05 L
.91653 4e-05 L
.91657 4e-05 L
.91663 4e-05 L
.91669 4e-05 L
.91676 4e-05 L
.91683 4e-05 L
.91689 4e-05 L
.91695 4e-05 L
.91701 4e-05 L
.91706 4e-05 L
.91712 4e-05 L
.91718 4e-05 L
.91725 4e-05 L
.91731 4e-05 L
.91737 4e-05 L
.91743 4e-05 L
.9175 4e-05 L
.91754 4e-05 L
.91757 4e-05 L
.91764 4e-05 L
.91771 4e-05 L
.91776 4e-05 L
.91782 4e-05 L
.91788 4e-05 L
.91794 4e-05 L
.918 4e-05 L
.91805 4e-05 L
.9181 4e-05 L
.91816 4e-05 L
.91822 4e-05 L
.91828 4e-05 L
.91834 4e-05 L
.9184 4e-05 L
.91846 4e-05 L
.91849 4e-05 L
.91853 4e-05 L
.91859 4e-05 L
.91865 4e-05 L
.91872 4e-05 L
.91878 4e-05 L
.91885 4e-05 L
.91891 4e-05 L
.91897 4e-05 L
.91902 4e-05 L
.91908 4e-05 L
.91914 4e-05 L
.91921 4e-05 L
.91927 4e-05 L
.91933 4e-05 L
.91939 4e-05 L
.91946 4e-05 L
.9195 4e-05 L
.91953 4e-05 L
.9196 4e-05 L
.91967 4e-05 L
.91972 4e-05 L
.91978 4e-05 L
.91984 4e-05 L
.9199 4e-05 L
.91996 4e-05 L
.92001 4e-05 L
.92007 4e-05 L
.92012 4e-05 L
.92018 4e-05 L
.92024 4e-05 L
.9203 4e-05 L
.92036 4e-05 L
.92042 4e-05 L
.92046 4e-05 L
.92049 4e-05 L
.92055 4e-05 L
.92061 4e-05 L
.92068 4e-05 L
.92071 4e-05 L
.92075 4e-05 L
.92081 4e-05 L
.92087 4e-05 L
.92093 4e-05 L
.92098 4e-05 L
.92104 4e-05 L
.9211 4e-05 L
.92117 4e-05 L
.9212 4e-05 L
.92124 4e-05 L
.92131 4e-05 L
.92134 4e-05 L
.92138 4e-05 L
.92144 4e-05 L
.92151 4e-05 L
.92157 4e-05 L
.92163 4e-05 L
.92168 4e-05 L
.92174 4e-05 L
.9218 4e-05 L
.92185 4e-05 L
.92191 4e-05 L
.92197 4e-05 L
.92203 4e-05 L
.92209 4e-05 L
.92215 4e-05 L
.92221 4e-05 L
.92227 4e-05 L
.92233 4e-05 L
.92239 4e-05 L
.92246 4e-05 L
.92251 4e-05 L
.92258 4e-05 L
.92265 4e-05 L
.92271 4e-05 L
.92274 4e-05 L
.92278 4e-05 L
.92281 4e-05 L
.92285 4e-05 L
.92291 4e-05 L
.92297 4e-05 L
.92304 4e-05 L
.92311 4e-05 L
.92316 4e-05 L
.92323 4e-05 L
.92328 4e-05 L
.92334 4e-05 L
.9234 4e-05 L
.92347 4e-05 L
.92353 4e-05 L
.92359 4e-05 L
.92365 4e-05 L
.92372 4e-05 L
.92378 4e-05 L
.92384 4e-05 L
.92391 4e-05 L
.92394 4e-05 L
.92398 4e-05 L
.92405 4e-05 L
.92408 4e-05 L
.92411 4e-05 L
.92415 4e-05 L
.92419 4e-05 L
.92425 4e-05 L
.92429 4e-05 L
.92432 4e-05 L
.92436 4e-05 L
.9244 4e-05 L
.92444 4e-05 L
.92447 4e-05 L
.92451 4e-05 L
.92454 4e-05 L
.9246 4e-05 L
.92467 4e-05 L
.92473 4e-05 L
.9248 4e-05 L
.92487 4e-05 L
.92493 4e-05 L
.92498 4e-05 L
.92504 4e-05 L
.9251 4e-05 L
.92516 4e-05 L
.92522 4e-05 L
.92529 4e-05 L
.92535 4e-05 L
.92541 4e-05 L
.92548 4e-05 L
.92552 4e-05 L
.92555 4e-05 L
.92562 4e-05 L
.92568 4e-05 L
.92574 4e-05 L
.9258 4e-05 L
.92586 4e-05 L
.92592 4e-05 L
.92597 4e-05 L
.92602 4e-05 L
.92608 4e-05 L
.92614 4e-05 L
.92619 4e-05 L
.92626 4e-05 L
.92632 4e-05 L
.92637 4e-05 L
.92643 4e-05 L
.92647 4e-05 L
.9265 4e-05 L
.92656 4e-05 L
.92663 4e-05 L
.92669 4e-05 L
.92676 4e-05 L
.92682 4e-05 L
.92688 4e-05 L
.92694 4e-05 L
.927 4e-05 L
.92706 4e-05 L
.92712 4e-05 L
.92718 4e-05 L
.92725 4e-05 L
.92731 4e-05 L
.92737 4e-05 L
.92744 4e-05 L
.92748 4e-05 L
.92751 4e-05 L
.92758 4e-05 L
.92764 4e-05 L
.9277 4e-05 L
.92776 4e-05 L
.92782 4e-05 L
.92788 4e-05 L
.92793 4e-05 L
.92798 4e-05 L
.92804 4e-05 L
.9281 4e-05 L
.92815 4e-05 L
.92822 4e-05 L
.92828 4e-05 L
.92833 4e-05 L
.92839 4e-05 L
.92843 4e-05 L
.92846 4e-05 L
.92852 4e-05 L
.92859 4e-05 L
.92865 4e-05 L
.92869 4e-05 L
.92872 4e-05 L
.92878 4e-05 L
.92884 4e-05 L
.9289 4e-05 L
.92896 4e-05 L
.92901 4e-05 L
.92908 4e-05 L
.92914 4e-05 L
.92918 4e-05 L
.92921 4e-05 L
.92928 4e-05 L
.92932 4e-05 L
.92935 4e-05 L
.92941 4e-05 L
.92948 4e-05 L
.92954 4e-05 L
.9296 4e-05 L
.92966 4e-05 L
.92972 4e-05 L
.92977 4e-05 L
.92982 4e-05 L
.92988 4e-05 L
.92995 4e-05 L
.93001 4e-05 L
.93006 4e-05 L
.93013 4e-05 L
.93019 4e-05 L
.93024 4e-05 L
.9303 4e-05 L
.93036 4e-05 L
.93043 4e-05 L
.93049 4e-05 L
.93055 4e-05 L
.93062 4e-05 L
.93068 4e-05 L
.93071 4e-05 L
.93075 4e-05 L
.93079 4e-05 L
.93082 4e-05 L
.93089 4e-05 L
.93095 4e-05 L
.93101 4e-05 L
.93108 4e-05 L
.93114 4e-05 L
.9312 4e-05 L
.93126 4e-05 L
.93131 4e-05 L
.93137 4e-05 L
.93144 4e-05 L
.9315 4e-05 L
.93156 4e-05 L
.93162 4e-05 L
.93169 4e-05 L
.93175 4e-05 L
.93181 4e-05 L
.93188 4e-05 L
.93192 4e-05 L
.93195 4e-05 L
.93202 4e-05 L
.93205 4e-05 L
.93209 4e-05 L
.93212 4e-05 L
.93216 4e-05 L
.93223 4e-05 L
.93226 4e-05 L
.9323 4e-05 L
.93233 4e-05 L
.93237 4e-05 L
.93241 4e-05 L
.93245 4e-05 L
.93248 4e-05 L
.93252 4e-05 L
.93258 4e-05 L
.93264 4e-05 L
.93271 4e-05 L
.93277 4e-05 L
.93284 4e-05 L
.9329 4e-05 L
.93296 4e-05 L
.93301 4e-05 L
.93307 4e-05 L
.93313 4e-05 L
.93319 4e-05 L
.93326 4e-05 L
.93332 4e-05 L
.93338 4e-05 L
.93345 4e-05 L
.93349 4e-05 L
.93352 4e-05 L
.93359 4e-05 L
.93365 4e-05 L
.93371 4e-05 L
.93377 4e-05 L
.93383 4e-05 L
.93389 4e-05 L
.93394 4e-05 L
.93399 4e-05 L
.93405 4e-05 L
.93411 4e-05 L
.93417 4e-05 L
.93423 4e-05 L
.93429 4e-05 L
.93434 4e-05 L
.93441 4e-05 L
.93444 4e-05 L
.93448 4e-05 L
.93454 4e-05 L
.9346 4e-05 L
.93466 4e-05 L
.93473 4e-05 L
.9348 4e-05 L
.93486 4e-05 L
.93492 4e-05 L
.93497 4e-05 L
.93503 4e-05 L
.93509 4e-05 L
.93515 4e-05 L
.93522 4e-05 L
.93528 4e-05 L
.93534 4e-05 L
.93541 4e-05 L
.93545 4e-05 L
.93548 4e-05 L
.93555 4e-05 L
.93561 4e-05 L
.93567 4e-05 L
.93573 4e-05 L
.93579 4e-05 L
.93585 4e-05 L
.9359 4e-05 L
.93595 4e-05 L
.93601 4e-05 L
.93607 4e-05 L
.93613 4e-05 L
.93619 4e-05 L
.93625 4e-05 L
.9363 4e-05 L
.93637 4e-05 L
.9364 4e-05 L
.93644 4e-05 L
.9365 4e-05 L
.93656 4e-05 L
.93662 4e-05 L
.93666 4e-05 L
.93669 4e-05 L
.93675 4e-05 L
.93682 4e-05 L
.93687 4e-05 L
.93693 4e-05 L
.93699 4e-05 L
.93705 4e-05 L
.93711 4e-05 L
.93715 4e-05 L
.93718 4e-05 L
.93725 4e-05 L
.93729 4e-05 L
.93732 4e-05 L
.93739 4e-05 L
.93745 4e-05 L
.93752 4e-05 L
.93758 4e-05 L
.93763 4e-05 L
.93769 4e-05 L
.93774 4e-05 L
.93779 4e-05 L
.93785 4e-05 L
.93792 4e-05 L
.93798 4e-05 L
.93804 4e-05 L
.9381 4e-05 L
.93816 4e-05 L
.93821 4e-05 L
.93827 4e-05 L
.93834 4e-05 L
.9384 4e-05 L
.93846 4e-05 L
.93852 4e-05 L
.93857 4e-05 L
.93861 4e-05 L
.93866 4e-05 L
.93871 4e-05 L
.93875 4e-05 L
.93879 4e-05 L
.93883 4e-05 L
.93888 4e-05 L
.93892 4e-05 L
.93896 4e-05 L
.93901 4e-05 L
.93905 4e-05 L
.93909 4e-05 L
.93913 4e-05 L
.93917 4e-05 L
.93921 4e-05 L
.93925 4e-05 L
.93929 4e-05 L
.93934 4e-05 L
.93939 4e-05 L
.93943 4e-05 L
.93947 4e-05 L
.93951 4e-05 L
.93956 4e-05 L
.9396 4e-05 L
.93965 4e-05 L
.9397 4e-05 L
.93974 4e-05 L
.93979 4e-05 L
.93984 4e-05 L
.93989 4e-05 L
.93994 4e-05 L
.93994 .87428 L
.93988 .8694 L
.93982 .86752 L
.93976 .86583 L
.9397 .86449 L
.93949 .86067 L
.93925 .85737 L
.939 .85446 L
.93848 .84946 L
.938 .84554 L
.93689 .83802 L
.93588 .83224 L
.93388 .82255 L
.93181 .81395 L
.92966 .80603 L
.92763 .79923 L
.92553 .79268 L
.92355 .78689 L
.9215 .7812 L
.91937 .77556 L
.91736 .77049 L
.91528 .76542 L
.91332 .76081 L
.91128 .75618 L
.90917 .7515 L
.90718 .74723 L
.90512 .7429 L
.90297 .73851 L
.90095 .73448 L
.89886 .73038 L
.89689 .7266 L
.89484 .72275 L
.89266 .71872 L
.89066 .71509 L
F
0 g
.89066 4e-05 m
.89072 4e-05 L
.89078 4e-05 L
.89084 4e-05 L
.8909 4e-05 L
.89096 4e-05 L
.89101 4e-05 L
.89107 4e-05 L
.89113 4e-05 L
.89119 4e-05 L
.89125 4e-05 L
.89131 4e-05 L
.89137 4e-05 L
.89144 4e-05 L
.89147 4e-05 L
.89151 4e-05 L
.89157 4e-05 L
.89164 4e-05 L
.89167 4e-05 L
.89171 4e-05 L
.89177 4e-05 L
.89181 4e-05 L
.89184 4e-05 L
.89187 4e-05 L
.89191 4e-05 L
.89195 4e-05 L
.89198 4e-05 L
.89205 4e-05 L
.89212 4e-05 L
.89217 4e-05 L
.89223 4e-05 L
.89229 4e-05 L
.89235 4e-05 L
.89241 4e-05 L
.89248 4e-05 L
.89254 4e-05 L
.8926 4e-05 L
.89266 4e-05 L
.8927 4e-05 L
.89273 4e-05 L
.89277 4e-05 L
.89281 4e-05 L
.89288 4e-05 L
.89291 4e-05 L
.89295 4e-05 L
.89301 4e-05 L
.89307 4e-05 L
.89311 4e-05 L
.89314 4e-05 L
.89321 4e-05 L
Mistroke
.89325 4e-05 L
.89329 4e-05 L
.89332 4e-05 L
.89336 4e-05 L
.89339 4e-05 L
.89344 4e-05 L
.89347 4e-05 L
.89351 4e-05 L
.89355 4e-05 L
.89358 4e-05 L
.89362 4e-05 L
.89366 4e-05 L
.89372 4e-05 L
.89376 4e-05 L
.89379 4e-05 L
.89385 4e-05 L
.89392 4e-05 L
.89398 4e-05 L
.89403 4e-05 L
.8941 4e-05 L
.89416 4e-05 L
.8942 4e-05 L
.89424 4e-05 L
.8943 4e-05 L
.89434 4e-05 L
.89437 4e-05 L
.89441 4e-05 L
.89445 4e-05 L
.89451 4e-05 L
.89455 4e-05 L
.89459 4e-05 L
.89465 4e-05 L
.89471 4e-05 L
.89478 4e-05 L
.89484 4e-05 L
.8949 4e-05 L
.89496 4e-05 L
.89502 4e-05 L
.89508 4e-05 L
.89514 4e-05 L
.89521 4e-05 L
.89524 4e-05 L
.89528 4e-05 L
.89534 4e-05 L
.89538 4e-05 L
.89541 4e-05 L
.89545 4e-05 L
.89548 4e-05 L
.89555 4e-05 L
.89558 4e-05 L
Mistroke
.89562 4e-05 L
.89568 4e-05 L
.89574 4e-05 L
.89581 4e-05 L
.89587 4e-05 L
.89593 4e-05 L
.89599 4e-05 L
.89605 4e-05 L
.89611 4e-05 L
.89616 4e-05 L
.89621 4e-05 L
.89627 4e-05 L
.89633 4e-05 L
.89639 4e-05 L
.89645 4e-05 L
.89651 4e-05 L
.89656 4e-05 L
.89663 4e-05 L
.89666 4e-05 L
.8967 4e-05 L
.89676 4e-05 L
.89682 4e-05 L
.89688 4e-05 L
.89695 4e-05 L
.89701 4e-05 L
.89708 4e-05 L
.89714 4e-05 L
.89719 4e-05 L
.89725 4e-05 L
.89731 4e-05 L
.89737 4e-05 L
.89744 4e-05 L
.8975 4e-05 L
.89756 4e-05 L
.89763 4e-05 L
.89767 4e-05 L
.8977 4e-05 L
.89777 4e-05 L
.89783 4e-05 L
.89789 4e-05 L
.89795 4e-05 L
.89801 4e-05 L
.89807 4e-05 L
.89812 4e-05 L
.89817 4e-05 L
.89823 4e-05 L
.89828 4e-05 L
.89834 4e-05 L
.89841 4e-05 L
.89847 4e-05 L
Mistroke
.89852 4e-05 L
.89858 4e-05 L
.89862 4e-05 L
.89865 4e-05 L
.89871 4e-05 L
.89878 4e-05 L
.89884 4e-05 L
.89891 4e-05 L
.89897 4e-05 L
.89903 4e-05 L
.89909 4e-05 L
.89914 4e-05 L
.89921 4e-05 L
.89926 4e-05 L
.89933 4e-05 L
.8994 4e-05 L
.89945 4e-05 L
.89952 4e-05 L
.89958 4e-05 L
.89962 4e-05 L
.89966 4e-05 L
.89972 4e-05 L
.89979 4e-05 L
.89984 4e-05 L
.8999 4e-05 L
.89996 4e-05 L
.90002 4e-05 L
.90008 4e-05 L
.90013 4e-05 L
.90018 4e-05 L
.90024 4e-05 L
.9003 4e-05 L
.90036 4e-05 L
.90042 4e-05 L
.90048 4e-05 L
.90054 4e-05 L
.90058 4e-05 L
.90061 4e-05 L
.90067 4e-05 L
.90073 4e-05 L
.9008 4e-05 L
.90087 4e-05 L
.90093 4e-05 L
.90099 4e-05 L
.90105 4e-05 L
.9011 4e-05 L
.90116 4e-05 L
.90122 4e-05 L
.90129 4e-05 L
.90135 4e-05 L
Mistroke
.90141 4e-05 L
.90147 4e-05 L
.90154 4e-05 L
.90158 4e-05 L
.90162 4e-05 L
.90168 4e-05 L
.90175 4e-05 L
.9018 4e-05 L
.90186 4e-05 L
.90192 4e-05 L
.90198 4e-05 L
.90204 4e-05 L
.90209 4e-05 L
.90214 4e-05 L
.9022 4e-05 L
.90226 4e-05 L
.90232 4e-05 L
.90238 4e-05 L
.90244 4e-05 L
.9025 4e-05 L
.90254 4e-05 L
.90257 4e-05 L
.90263 4e-05 L
.90269 4e-05 L
.90276 4e-05 L
.90283 4e-05 L
.90289 4e-05 L
.90295 4e-05 L
.903 4e-05 L
.90306 4e-05 L
.90313 4e-05 L
.90318 4e-05 L
.90325 4e-05 L
.90332 4e-05 L
.90337 4e-05 L
.90344 4e-05 L
.9035 4e-05 L
.90354 4e-05 L
.90358 4e-05 L
.90364 4e-05 L
.90371 4e-05 L
.90376 4e-05 L
.90382 4e-05 L
.90389 4e-05 L
.90395 4e-05 L
.904 4e-05 L
.90405 4e-05 L
.90411 4e-05 L
.90416 4e-05 L
.90422 4e-05 L
Mistroke
.90429 4e-05 L
.90435 4e-05 L
.9044 4e-05 L
.90446 4e-05 L
.9045 4e-05 L
.90453 4e-05 L
.90459 4e-05 L
.90466 4e-05 L
.90472 4e-05 L
.90476 4e-05 L
.90479 4e-05 L
.90485 4e-05 L
.90491 4e-05 L
.90497 4e-05 L
.90502 4e-05 L
.90508 4e-05 L
.90515 4e-05 L
.90521 4e-05 L
.90525 4e-05 L
.90528 4e-05 L
.90535 4e-05 L
.90539 4e-05 L
.90542 4e-05 L
.90548 4e-05 L
.90555 4e-05 L
.90561 4e-05 L
.90567 4e-05 L
.90573 4e-05 L
.90579 4e-05 L
.90584 4e-05 L
.90589 4e-05 L
.90595 4e-05 L
.90602 4e-05 L
.90608 4e-05 L
.90613 4e-05 L
.9062 4e-05 L
.90626 4e-05 L
.90631 4e-05 L
.90637 4e-05 L
.90643 4e-05 L
.9065 4e-05 L
.90656 4e-05 L
.90662 4e-05 L
.90669 4e-05 L
.90675 4e-05 L
.90678 4e-05 L
.90682 4e-05 L
.90686 4e-05 L
.90689 4e-05 L
.90696 4e-05 L
Mistroke
.90702 4e-05 L
.90709 4e-05 L
.90715 4e-05 L
.90721 4e-05 L
.90727 4e-05 L
.90733 4e-05 L
.90738 4e-05 L
.90744 4e-05 L
.90751 4e-05 L
.90757 4e-05 L
.90763 4e-05 L
.9077 4e-05 L
.90776 4e-05 L
.90783 4e-05 L
.90788 4e-05 L
.90795 4e-05 L
.90799 4e-05 L
.90803 4e-05 L
.90809 4e-05 L
.90812 4e-05 L
.90816 4e-05 L
.90819 4e-05 L
.90823 4e-05 L
.9083 4e-05 L
.90833 4e-05 L
.90837 4e-05 L
.90841 4e-05 L
.90845 4e-05 L
.90848 4e-05 L
.90852 4e-05 L
.90855 4e-05 L
.90859 4e-05 L
.90865 4e-05 L
.90872 4e-05 L
.90878 4e-05 L
.90885 4e-05 L
.90891 4e-05 L
.90897 4e-05 L
.90903 4e-05 L
.90908 4e-05 L
.90915 4e-05 L
.9092 4e-05 L
.90927 4e-05 L
.90933 4e-05 L
.90939 4e-05 L
.90946 4e-05 L
.90952 4e-05 L
.90956 4e-05 L
.9096 4e-05 L
.90966 4e-05 L
Mistroke
.90973 4e-05 L
.90978 4e-05 L
.90984 4e-05 L
.9099 4e-05 L
.90996 4e-05 L
.91002 4e-05 L
.91007 4e-05 L
.91012 4e-05 L
.91018 4e-05 L
.91024 4e-05 L
.9103 4e-05 L
.91036 4e-05 L
.91042 4e-05 L
.91048 4e-05 L
.91052 4e-05 L
.91055 4e-05 L
.91061 4e-05 L
.91067 4e-05 L
.91074 4e-05 L
.91081 4e-05 L
.91087 4e-05 L
.91093 4e-05 L
.91099 4e-05 L
.91104 4e-05 L
.91111 4e-05 L
.91116 4e-05 L
.91123 4e-05 L
.9113 4e-05 L
.91135 4e-05 L
.91142 4e-05 L
.91148 4e-05 L
.91152 4e-05 L
.91156 4e-05 L
.91162 4e-05 L
.91169 4e-05 L
.91174 4e-05 L
.9118 4e-05 L
.91187 4e-05 L
.91192 4e-05 L
.91198 4e-05 L
.91203 4e-05 L
.91209 4e-05 L
.91214 4e-05 L
.9122 4e-05 L
.91227 4e-05 L
.91233 4e-05 L
.91238 4e-05 L
.91244 4e-05 L
.91248 4e-05 L
.91251 4e-05 L
Mistroke
.91257 4e-05 L
.91264 4e-05 L
.9127 4e-05 L
.91274 4e-05 L
.91277 4e-05 L
.91283 4e-05 L
.91289 4e-05 L
.91295 4e-05 L
.913 4e-05 L
.91306 4e-05 L
.91313 4e-05 L
.91319 4e-05 L
.91323 4e-05 L
.91326 4e-05 L
.91333 4e-05 L
.91337 4e-05 L
.9134 4e-05 L
.91346 4e-05 L
.91353 4e-05 L
.91359 4e-05 L
.91365 4e-05 L
.91371 4e-05 L
.91377 4e-05 L
.91382 4e-05 L
.91387 4e-05 L
.91393 4e-05 L
.914 4e-05 L
.91406 4e-05 L
.91411 4e-05 L
.91418 4e-05 L
.91424 4e-05 L
.91429 4e-05 L
.91435 4e-05 L
.91441 4e-05 L
.91448 4e-05 L
.91454 4e-05 L
.9146 4e-05 L
.91467 4e-05 L
.91473 4e-05 L
.91476 4e-05 L
.9148 4e-05 L
.91484 4e-05 L
.91487 4e-05 L
.91494 4e-05 L
.915 4e-05 L
.91506 4e-05 L
.91513 4e-05 L
.91519 4e-05 L
.91525 4e-05 L
.91531 4e-05 L
Mistroke
.91536 4e-05 L
.91542 4e-05 L
.91549 4e-05 L
.91555 4e-05 L
.91561 4e-05 L
.91567 4e-05 L
.91574 4e-05 L
.9158 4e-05 L
.91586 4e-05 L
.91593 4e-05 L
.91597 4e-05 L
.916 4e-05 L
.91607 4e-05 L
.9161 4e-05 L
.91614 4e-05 L
.91617 4e-05 L
.91621 4e-05 L
.91628 4e-05 L
.91631 4e-05 L
.91635 4e-05 L
.91638 4e-05 L
.91643 4e-05 L
.91646 4e-05 L
.9165 4e-05 L
.91653 4e-05 L
.91657 4e-05 L
.91663 4e-05 L
.91669 4e-05 L
.91676 4e-05 L
.91683 4e-05 L
.91689 4e-05 L
.91695 4e-05 L
.91701 4e-05 L
.91706 4e-05 L
.91712 4e-05 L
.91718 4e-05 L
.91725 4e-05 L
.91731 4e-05 L
.91737 4e-05 L
.91743 4e-05 L
.9175 4e-05 L
.91754 4e-05 L
.91757 4e-05 L
.91764 4e-05 L
.91771 4e-05 L
.91776 4e-05 L
.91782 4e-05 L
.91788 4e-05 L
.91794 4e-05 L
.918 4e-05 L
Mistroke
.91805 4e-05 L
.9181 4e-05 L
.91816 4e-05 L
.91822 4e-05 L
.91828 4e-05 L
.91834 4e-05 L
.9184 4e-05 L
.91846 4e-05 L
.91849 4e-05 L
.91853 4e-05 L
.91859 4e-05 L
.91865 4e-05 L
.91872 4e-05 L
.91878 4e-05 L
.91885 4e-05 L
.91891 4e-05 L
.91897 4e-05 L
.91902 4e-05 L
.91908 4e-05 L
.91914 4e-05 L
.91921 4e-05 L
.91927 4e-05 L
.91933 4e-05 L
.91939 4e-05 L
.91946 4e-05 L
.9195 4e-05 L
.91953 4e-05 L
.9196 4e-05 L
.91967 4e-05 L
.91972 4e-05 L
.91978 4e-05 L
.91984 4e-05 L
.9199 4e-05 L
.91996 4e-05 L
.92001 4e-05 L
.92007 4e-05 L
.92012 4e-05 L
.92018 4e-05 L
.92024 4e-05 L
.9203 4e-05 L
.92036 4e-05 L
.92042 4e-05 L
.92046 4e-05 L
.92049 4e-05 L
.92055 4e-05 L
.92061 4e-05 L
.92068 4e-05 L
.92071 4e-05 L
.92075 4e-05 L
.92081 4e-05 L
Mistroke
.92087 4e-05 L
.92093 4e-05 L
.92098 4e-05 L
.92104 4e-05 L
.9211 4e-05 L
.92117 4e-05 L
.9212 4e-05 L
.92124 4e-05 L
.92131 4e-05 L
.92134 4e-05 L
.92138 4e-05 L
.92144 4e-05 L
.92151 4e-05 L
.92157 4e-05 L
.92163 4e-05 L
.92168 4e-05 L
.92174 4e-05 L
.9218 4e-05 L
.92185 4e-05 L
.92191 4e-05 L
.92197 4e-05 L
.92203 4e-05 L
.92209 4e-05 L
.92215 4e-05 L
.92221 4e-05 L
.92227 4e-05 L
.92233 4e-05 L
.92239 4e-05 L
.92246 4e-05 L
.92251 4e-05 L
.92258 4e-05 L
.92265 4e-05 L
.92271 4e-05 L
.92274 4e-05 L
.92278 4e-05 L
.92281 4e-05 L
.92285 4e-05 L
.92291 4e-05 L
.92297 4e-05 L
.92304 4e-05 L
.92311 4e-05 L
.92316 4e-05 L
.92323 4e-05 L
.92328 4e-05 L
.92334 4e-05 L
.9234 4e-05 L
.92347 4e-05 L
.92353 4e-05 L
.92359 4e-05 L
.92365 4e-05 L
Mistroke
.92372 4e-05 L
.92378 4e-05 L
.92384 4e-05 L
.92391 4e-05 L
.92394 4e-05 L
.92398 4e-05 L
.92405 4e-05 L
.92408 4e-05 L
.92411 4e-05 L
.92415 4e-05 L
.92419 4e-05 L
.92425 4e-05 L
.92429 4e-05 L
.92432 4e-05 L
.92436 4e-05 L
.9244 4e-05 L
.92444 4e-05 L
.92447 4e-05 L
.92451 4e-05 L
.92454 4e-05 L
.9246 4e-05 L
.92467 4e-05 L
.92473 4e-05 L
.9248 4e-05 L
.92487 4e-05 L
.92493 4e-05 L
.92498 4e-05 L
.92504 4e-05 L
.9251 4e-05 L
.92516 4e-05 L
.92522 4e-05 L
.92529 4e-05 L
.92535 4e-05 L
.92541 4e-05 L
.92548 4e-05 L
.92552 4e-05 L
.92555 4e-05 L
.92562 4e-05 L
.92568 4e-05 L
.92574 4e-05 L
.9258 4e-05 L
.92586 4e-05 L
.92592 4e-05 L
.92597 4e-05 L
.92602 4e-05 L
.92608 4e-05 L
.92614 4e-05 L
.92619 4e-05 L
.92626 4e-05 L
.92632 4e-05 L
Mistroke
.92637 4e-05 L
.92643 4e-05 L
.92647 4e-05 L
.9265 4e-05 L
.92656 4e-05 L
.92663 4e-05 L
.92669 4e-05 L
.92676 4e-05 L
.92682 4e-05 L
.92688 4e-05 L
.92694 4e-05 L
.927 4e-05 L
.92706 4e-05 L
.92712 4e-05 L
.92718 4e-05 L
.92725 4e-05 L
.92731 4e-05 L
.92737 4e-05 L
.92744 4e-05 L
.92748 4e-05 L
.92751 4e-05 L
.92758 4e-05 L
.92764 4e-05 L
.9277 4e-05 L
.92776 4e-05 L
.92782 4e-05 L
.92788 4e-05 L
.92793 4e-05 L
.92798 4e-05 L
.92804 4e-05 L
.9281 4e-05 L
.92815 4e-05 L
.92822 4e-05 L
.92828 4e-05 L
.92833 4e-05 L
.92839 4e-05 L
.92843 4e-05 L
.92846 4e-05 L
.92852 4e-05 L
.92859 4e-05 L
.92865 4e-05 L
.92869 4e-05 L
.92872 4e-05 L
.92878 4e-05 L
.92884 4e-05 L
.9289 4e-05 L
.92896 4e-05 L
.92901 4e-05 L
.92908 4e-05 L
.92914 4e-05 L
Mistroke
.92918 4e-05 L
.92921 4e-05 L
.92928 4e-05 L
.92932 4e-05 L
.92935 4e-05 L
.92941 4e-05 L
.92948 4e-05 L
.92954 4e-05 L
.9296 4e-05 L
.92966 4e-05 L
.92972 4e-05 L
.92977 4e-05 L
.92982 4e-05 L
.92988 4e-05 L
.92995 4e-05 L
.93001 4e-05 L
.93006 4e-05 L
.93013 4e-05 L
.93019 4e-05 L
.93024 4e-05 L
.9303 4e-05 L
.93036 4e-05 L
.93043 4e-05 L
.93049 4e-05 L
.93055 4e-05 L
.93062 4e-05 L
.93068 4e-05 L
.93071 4e-05 L
.93075 4e-05 L
.93079 4e-05 L
.93082 4e-05 L
.93089 4e-05 L
.93095 4e-05 L
.93101 4e-05 L
.93108 4e-05 L
.93114 4e-05 L
.9312 4e-05 L
.93126 4e-05 L
.93131 4e-05 L
.93137 4e-05 L
.93144 4e-05 L
.9315 4e-05 L
.93156 4e-05 L
.93162 4e-05 L
.93169 4e-05 L
.93175 4e-05 L
.93181 4e-05 L
.93188 4e-05 L
.93192 4e-05 L
.93195 4e-05 L
Mistroke
.93202 4e-05 L
.93205 4e-05 L
.93209 4e-05 L
.93212 4e-05 L
.93216 4e-05 L
.93223 4e-05 L
.93226 4e-05 L
.9323 4e-05 L
.93233 4e-05 L
.93237 4e-05 L
.93241 4e-05 L
.93245 4e-05 L
.93248 4e-05 L
.93252 4e-05 L
.93258 4e-05 L
.93264 4e-05 L
.93271 4e-05 L
.93277 4e-05 L
.93284 4e-05 L
.9329 4e-05 L
.93296 4e-05 L
.93301 4e-05 L
.93307 4e-05 L
.93313 4e-05 L
.93319 4e-05 L
.93326 4e-05 L
.93332 4e-05 L
.93338 4e-05 L
.93345 4e-05 L
.93349 4e-05 L
.93352 4e-05 L
.93359 4e-05 L
.93365 4e-05 L
.93371 4e-05 L
.93377 4e-05 L
.93383 4e-05 L
.93389 4e-05 L
.93394 4e-05 L
.93399 4e-05 L
.93405 4e-05 L
.93411 4e-05 L
.93417 4e-05 L
.93423 4e-05 L
.93429 4e-05 L
.93434 4e-05 L
.93441 4e-05 L
.93444 4e-05 L
.93448 4e-05 L
.93454 4e-05 L
.9346 4e-05 L
Mistroke
.93466 4e-05 L
.93473 4e-05 L
.9348 4e-05 L
.93486 4e-05 L
.93492 4e-05 L
.93497 4e-05 L
.93503 4e-05 L
.93509 4e-05 L
.93515 4e-05 L
.93522 4e-05 L
.93528 4e-05 L
.93534 4e-05 L
.93541 4e-05 L
.93545 4e-05 L
.93548 4e-05 L
.93555 4e-05 L
.93561 4e-05 L
.93567 4e-05 L
.93573 4e-05 L
.93579 4e-05 L
.93585 4e-05 L
.9359 4e-05 L
.93595 4e-05 L
.93601 4e-05 L
.93607 4e-05 L
.93613 4e-05 L
.93619 4e-05 L
.93625 4e-05 L
.9363 4e-05 L
.93637 4e-05 L
.9364 4e-05 L
.93644 4e-05 L
.9365 4e-05 L
.93656 4e-05 L
.93662 4e-05 L
.93666 4e-05 L
.93669 4e-05 L
.93675 4e-05 L
.93682 4e-05 L
.93687 4e-05 L
.93693 4e-05 L
.93699 4e-05 L
.93705 4e-05 L
.93711 4e-05 L
.93715 4e-05 L
.93718 4e-05 L
.93725 4e-05 L
.93729 4e-05 L
.93732 4e-05 L
.93739 4e-05 L
Mistroke
.93745 4e-05 L
.93752 4e-05 L
.93758 4e-05 L
.93763 4e-05 L
.93769 4e-05 L
.93774 4e-05 L
.93779 4e-05 L
.93785 4e-05 L
.93792 4e-05 L
.93798 4e-05 L
.93804 4e-05 L
.9381 4e-05 L
.93816 4e-05 L
.93821 4e-05 L
.93827 4e-05 L
.93834 4e-05 L
.9384 4e-05 L
.93846 4e-05 L
.93852 4e-05 L
.93857 4e-05 L
.93861 4e-05 L
.93866 4e-05 L
.93871 4e-05 L
.93875 4e-05 L
.93879 4e-05 L
.93883 4e-05 L
.93888 4e-05 L
.93892 4e-05 L
.93896 4e-05 L
.93901 4e-05 L
.93905 4e-05 L
.93909 4e-05 L
.93913 4e-05 L
.93917 4e-05 L
.93921 4e-05 L
.93925 4e-05 L
.93929 4e-05 L
.93934 4e-05 L
.93939 4e-05 L
.93943 4e-05 L
.93947 4e-05 L
.93951 4e-05 L
.93956 4e-05 L
.9396 4e-05 L
.93965 4e-05 L
.9397 4e-05 L
.93974 4e-05 L
.93979 4e-05 L
.93984 4e-05 L
.93989 4e-05 L
Mistroke
.93994 4e-05 L
Mfstroke
.89066 .71509 m
.89266 .71872 L
.89484 .72275 L
.89689 .7266 L
.89886 .73038 L
.90095 .73448 L
.90297 .73851 L
.90512 .7429 L
.90718 .74723 L
.90917 .7515 L
.91128 .75618 L
.91332 .76081 L
.91528 .76542 L
.91736 .77049 L
.91937 .77556 L
.9215 .7812 L
.92355 .78689 L
.92553 .79268 L
.92763 .79923 L
.92966 .80603 L
.93181 .81395 L
.93388 .82255 L
.93588 .83224 L
.93689 .83802 L
.938 .84554 L
.93848 .84946 L
.939 .85446 L
.93925 .85737 L
.93949 .86067 L
.9397 .86449 L
.93976 .86583 L
.93982 .86752 L
.93988 .8694 L
.93994 .87428 L
s
.16241 4e-05 m
.1633 4e-05 L
.16412 4e-05 L
.16507 4e-05 L
.16596 4e-05 L
.16678 4e-05 L
.16755 4e-05 L
.16838 4e-05 L
.16927 4e-05 L
.17016 4e-05 L
.17112 4e-05 L
.17202 4e-05 L
.17285 4e-05 L
.17381 4e-05 L
.17436 4e-05 L
.17487 4e-05 L
.1758 4e-05 L
.17679 4e-05 L
.17729 4e-05 L
.17781 4e-05 L
.17875 4e-05 L
.17928 4e-05 L
.17977 4e-05 L
.18031 4e-05 L
.18088 4e-05 L
.18138 4e-05 L
.18192 4e-05 L
.1829 4e-05 L
.18386 4e-05 L
.18474 4e-05 L
.1856 4e-05 L
.1864 4e-05 L
.18728 4e-05 L
.18824 4e-05 L
.18918 4e-05 L
.19017 4e-05 L
.19102 4e-05 L
.19195 4e-05 L
.19249 4e-05 L
.19299 4e-05 L
.19354 4e-05 L
.19412 4e-05 L
.1951 4e-05 L
.19566 4e-05 L
.19618 4e-05 L
.19714 4e-05 L
.19803 4e-05 L
.19852 4e-05 L
.19905 4e-05 L
.20002 4e-05 L
Mistroke
.2006 4e-05 L
.20116 4e-05 L
.20165 4e-05 L
.20219 4e-05 L
.20277 4e-05 L
.20339 4e-05 L
.20391 4e-05 L
.20449 4e-05 L
.20503 4e-05 L
.20553 4e-05 L
.2061 4e-05 L
.20664 4e-05 L
.2076 4e-05 L
.20814 4e-05 L
.20864 4e-05 L
.20953 4e-05 L
.21049 4e-05 L
.21139 4e-05 L
.21222 4e-05 L
.21314 4e-05 L
.21415 4e-05 L
.21466 4e-05 L
.2152 4e-05 L
.21617 4e-05 L
.21671 4e-05 L
.21721 4e-05 L
.21776 4e-05 L
.21833 4e-05 L
.2193 4e-05 L
.21985 4e-05 L
.22037 4e-05 L
.22132 4e-05 L
.2222 4e-05 L
.22321 4e-05 L
.22417 4e-05 L
.22504 4e-05 L
.22597 4e-05 L
.22686 4e-05 L
.22767 4e-05 L
.22857 4e-05 L
.22955 4e-05 L
.23005 4e-05 L
.23058 4e-05 L
.23154 4e-05 L
.23206 4e-05 L
.23255 4e-05 L
.23308 4e-05 L
.23365 4e-05 L
.2346 4e-05 L
.23514 4e-05 L
Mistroke
.23564 4e-05 L
.23658 4e-05 L
.23744 4e-05 L
.23843 4e-05 L
.23937 4e-05 L
.24026 4e-05 L
.24106 4e-05 L
.24199 4e-05 L
.24287 4e-05 L
.24368 4e-05 L
.24442 4e-05 L
.24524 4e-05 L
.24611 4e-05 L
.24698 4e-05 L
.24792 4e-05 L
.2488 4e-05 L
.24961 4e-05 L
.25056 4e-05 L
.25109 4e-05 L
.25158 4e-05 L
.25249 4e-05 L
.25345 4e-05 L
.25432 4e-05 L
.25528 4e-05 L
.25627 4e-05 L
.2572 4e-05 L
.25807 4e-05 L
.25885 4e-05 L
.25977 4e-05 L
.26063 4e-05 L
.26156 4e-05 L
.26256 4e-05 L
.2634 4e-05 L
.26433 4e-05 L
.26534 4e-05 L
.2659 4e-05 L
.26641 4e-05 L
.26741 4e-05 L
.26835 4e-05 L
.26924 4e-05 L
.27004 4e-05 L
.27096 4e-05 L
.27183 4e-05 L
.27263 4e-05 L
.27337 4e-05 L
.27419 4e-05 L
.27504 4e-05 L
.27591 4e-05 L
.27685 4e-05 L
.27772 4e-05 L
Mistroke
.27852 4e-05 L
.27946 4e-05 L
.27999 4e-05 L
.28048 4e-05 L
.28138 4e-05 L
.28234 4e-05 L
.28326 4e-05 L
.28426 4e-05 L
.28521 4e-05 L
.28609 4e-05 L
.28696 4e-05 L
.28775 4e-05 L
.28867 4e-05 L
.28953 4e-05 L
.29047 4e-05 L
.29146 4e-05 L
.29231 4e-05 L
.29324 4e-05 L
.29425 4e-05 L
.29481 4e-05 L
.29532 4e-05 L
.29632 4e-05 L
.29727 4e-05 L
.29807 4e-05 L
.29895 4e-05 L
.29988 4e-05 L
.30075 4e-05 L
.30155 4e-05 L
.3023 4e-05 L
.30311 4e-05 L
.30397 4e-05 L
.30484 4e-05 L
.30577 4e-05 L
.30665 4e-05 L
.30745 4e-05 L
.30839 4e-05 L
.30892 4e-05 L
.30941 4e-05 L
.31031 4e-05 L
.31126 4e-05 L
.31218 4e-05 L
.31319 4e-05 L
.31414 4e-05 L
.31502 4e-05 L
.3159 4e-05 L
.31669 4e-05 L
.31761 4e-05 L
.31847 4e-05 L
.31941 4e-05 L
.32041 4e-05 L
Mistroke
.32126 4e-05 L
.32219 4e-05 L
.3232 4e-05 L
.32376 4e-05 L
.32428 4e-05 L
.32527 4e-05 L
.32622 4e-05 L
.32702 4e-05 L
.32791 4e-05 L
.32884 4e-05 L
.3297 4e-05 L
.33051 4e-05 L
.33126 4e-05 L
.33207 4e-05 L
.33293 4e-05 L
.3338 4e-05 L
.33473 4e-05 L
.33561 4e-05 L
.33641 4e-05 L
.33735 4e-05 L
.33788 4e-05 L
.33837 4e-05 L
.33927 4e-05 L
.34022 4e-05 L
.34115 4e-05 L
.34216 4e-05 L
.34311 4e-05 L
.344 4e-05 L
.34479 4e-05 L
.34567 4e-05 L
.34659 4e-05 L
.34745 4e-05 L
.3484 4e-05 L
.3494 4e-05 L
.35025 4e-05 L
.35118 4e-05 L
.35219 4e-05 L
.35275 4e-05 L
.35327 4e-05 L
.35427 4e-05 L
.35521 4e-05 L
.35602 4e-05 L
.35691 4e-05 L
.35783 4e-05 L
.3587 4e-05 L
.35952 4e-05 L
.36026 4e-05 L
.36111 4e-05 L
.36193 4e-05 L
.3628 4e-05 L
Mistroke
.36374 4e-05 L
.36462 4e-05 L
.36542 4e-05 L
.36636 4e-05 L
.36689 4e-05 L
.36738 4e-05 L
.36827 4e-05 L
.36922 4e-05 L
.37015 4e-05 L
.37068 4e-05 L
.37117 4e-05 L
.37206 4e-05 L
.37301 4e-05 L
.37386 4e-05 L
.37466 4e-05 L
.37553 4e-05 L
.37647 4e-05 L
.37741 4e-05 L
.37795 4e-05 L
.37845 4e-05 L
.37945 4e-05 L
.38001 4e-05 L
.38053 4e-05 L
.38144 4e-05 L
.38244 4e-05 L
.38338 4e-05 L
.38424 4e-05 L
.38505 4e-05 L
.38592 4e-05 L
.38674 4e-05 L
.38749 4e-05 L
.38836 4e-05 L
.38932 4e-05 L
.39022 4e-05 L
.39105 4e-05 L
.392 4e-05 L
.39289 4e-05 L
.39368 4e-05 L
.39455 4e-05 L
.39549 4e-05 L
.39648 4e-05 L
.39733 4e-05 L
.39826 4e-05 L
.39926 4e-05 L
.40019 4e-05 L
.40067 4e-05 L
.40121 4e-05 L
.40176 4e-05 L
.40228 4e-05 L
.40324 4e-05 L
Mistroke
.40412 4e-05 L
.40513 4e-05 L
.40609 4e-05 L
.40694 4e-05 L
.40786 4e-05 L
.40872 4e-05 L
.4095 4e-05 L
.41041 4e-05 L
.41141 4e-05 L
.41235 4e-05 L
.41322 4e-05 L
.41414 4e-05 L
.41513 4e-05 L
.41607 4e-05 L
.41692 4e-05 L
.41792 4e-05 L
.41849 4e-05 L
.41901 4e-05 L
.41997 4e-05 L
.42046 4e-05 L
.421 4e-05 L
.42151 4e-05 L
.42206 4e-05 L
.42304 4e-05 L
.42358 4e-05 L
.42409 4e-05 L
.42464 4e-05 L
.42524 4e-05 L
.42575 4e-05 L
.42631 4e-05 L
.42684 4e-05 L
.42732 4e-05 L
.42824 4e-05 L
.42922 4e-05 L
.43014 4e-05 L
.43115 4e-05 L
.4321 4e-05 L
.43298 4e-05 L
.43386 4e-05 L
.43465 4e-05 L
.43557 4e-05 L
.43643 4e-05 L
.43737 4e-05 L
.43837 4e-05 L
.43922 4e-05 L
.44015 4e-05 L
.44115 4e-05 L
.44172 4e-05 L
.44223 4e-05 L
.44323 4e-05 L
Mistroke
.44417 4e-05 L
.44498 4e-05 L
.44586 4e-05 L
.44679 4e-05 L
.44766 4e-05 L
.44847 4e-05 L
.44921 4e-05 L
.45002 4e-05 L
.45088 4e-05 L
.45175 4e-05 L
.45269 4e-05 L
.45357 4e-05 L
.45436 4e-05 L
.4553 4e-05 L
.45584 4e-05 L
.45632 4e-05 L
.45722 4e-05 L
.45817 4e-05 L
.4591 4e-05 L
.46011 4e-05 L
.46107 4e-05 L
.46195 4e-05 L
.46283 4e-05 L
.46362 4e-05 L
.46454 4e-05 L
.4654 4e-05 L
.46635 4e-05 L
.46734 4e-05 L
.4682 4e-05 L
.46913 4e-05 L
.47014 4e-05 L
.4707 4e-05 L
.47121 4e-05 L
.47221 4e-05 L
.47316 4e-05 L
.47396 4e-05 L
.47485 4e-05 L
.47578 4e-05 L
.47665 4e-05 L
.47746 4e-05 L
.4782 4e-05 L
.47906 4e-05 L
.47987 4e-05 L
.48075 4e-05 L
.48168 4e-05 L
.48256 4e-05 L
.48336 4e-05 L
.4843 4e-05 L
.48483 4e-05 L
.48532 4e-05 L
Mistroke
.48622 4e-05 L
.48716 4e-05 L
.4881 4e-05 L
.48862 4e-05 L
.48911 4e-05 L
.49 4e-05 L
.49095 4e-05 L
.4918 4e-05 L
.4926 4e-05 L
.49347 4e-05 L
.49441 4e-05 L
.49535 4e-05 L
.49589 4e-05 L
.49638 4e-05 L
.49739 4e-05 L
.49795 4e-05 L
.49846 4e-05 L
.49938 4e-05 L
.50037 4e-05 L
.50131 4e-05 L
.50218 4e-05 L
.50299 4e-05 L
.50385 4e-05 L
.50467 4e-05 L
.50542 4e-05 L
.5063 4e-05 L
.50725 4e-05 L
.50815 4e-05 L
.50899 4e-05 L
.50993 4e-05 L
.51082 4e-05 L
.51162 4e-05 L
.51248 4e-05 L
.51342 4e-05 L
.51442 4e-05 L
.51527 4e-05 L
.5162 4e-05 L
.5172 4e-05 L
.51812 4e-05 L
.51861 4e-05 L
.51914 4e-05 L
.51969 4e-05 L
.52022 4e-05 L
.52117 4e-05 L
.52205 4e-05 L
.52301 4e-05 L
.52402 4e-05 L
.52487 4e-05 L
.52578 4e-05 L
.52664 4e-05 L
Mistroke
.52742 4e-05 L
.52834 4e-05 L
.52934 4e-05 L
.53028 4e-05 L
.53114 4e-05 L
.53207 4e-05 L
.53306 4e-05 L
.53399 4e-05 L
.53485 4e-05 L
.53585 4e-05 L
.53641 4e-05 L
.53694 4e-05 L
.5379 4e-05 L
.53838 4e-05 L
.53892 4e-05 L
.53944 4e-05 L
.53998 4e-05 L
.54096 4e-05 L
.5415 4e-05 L
.54201 4e-05 L
.54257 4e-05 L
.54316 4e-05 L
.54367 4e-05 L
.54423 4e-05 L
.54476 4e-05 L
.54525 4e-05 L
.54617 4e-05 L
.54714 4e-05 L
.54807 4e-05 L
.54907 4e-05 L
.55002 4e-05 L
.55091 4e-05 L
.55178 4e-05 L
.55257 4e-05 L
.55349 4e-05 L
.55435 4e-05 L
.55529 4e-05 L
.55628 4e-05 L
.55713 4e-05 L
.55807 4e-05 L
.55907 4e-05 L
.55964 4e-05 L
.56015 4e-05 L
.56115 4e-05 L
.56209 4e-05 L
.56289 4e-05 L
.56378 4e-05 L
.56471 4e-05 L
.56557 4e-05 L
.56638 4e-05 L
Mistroke
.56713 4e-05 L
.56794 4e-05 L
.5688 4e-05 L
.56967 4e-05 L
.5706 4e-05 L
.57148 4e-05 L
.57228 4e-05 L
.57322 4e-05 L
.57375 4e-05 L
.57424 4e-05 L
.57514 4e-05 L
.57609 4e-05 L
.57701 4e-05 L
.57802 4e-05 L
.57898 4e-05 L
.57986 4e-05 L
.58074 4e-05 L
.58153 4e-05 L
.58245 4e-05 L
.58331 4e-05 L
.58425 4e-05 L
.58525 4e-05 L
.5861 4e-05 L
.58704 4e-05 L
.58804 4e-05 L
.58861 4e-05 L
.58912 4e-05 L
.59012 4e-05 L
.59106 4e-05 L
.59187 4e-05 L
.59276 4e-05 L
.59369 4e-05 L
.59455 4e-05 L
.59537 4e-05 L
.59611 4e-05 L
.59696 4e-05 L
.59778 4e-05 L
.59865 4e-05 L
.59959 4e-05 L
.60047 4e-05 L
.60126 4e-05 L
.60221 4e-05 L
.60274 4e-05 L
.60322 4e-05 L
.60412 4e-05 L
.60507 4e-05 L
.606 4e-05 L
.60653 4e-05 L
.60701 4e-05 L
.60791 4e-05 L
Mistroke
.60886 4e-05 L
.6097 4e-05 L
.6105 4e-05 L
.61137 4e-05 L
.61231 4e-05 L
.61325 4e-05 L
.61379 4e-05 L
.61428 4e-05 L
.61529 4e-05 L
.61585 4e-05 L
.61636 4e-05 L
.61728 4e-05 L
.61827 4e-05 L
.61921 4e-05 L
.62008 4e-05 L
.62088 4e-05 L
.62175 4e-05 L
.62257 4e-05 L
.62332 4e-05 L
.62419 4e-05 L
.62515 4e-05 L
.62605 4e-05 L
.62688 4e-05 L
.62783 4e-05 L
.62872 4e-05 L
.62951 4e-05 L
.63038 4e-05 L
.63132 4e-05 L
.63231 4e-05 L
.63316 4e-05 L
.63409 4e-05 L
.63509 4e-05 L
.63602 4e-05 L
.6365 4e-05 L
.63703 4e-05 L
.63759 4e-05 L
.63811 4e-05 L
.63906 4e-05 L
.63994 4e-05 L
.6409 4e-05 L
.64191 4e-05 L
.64276 4e-05 L
.64367 4e-05 L
.64453 4e-05 L
.64531 4e-05 L
.64623 4e-05 L
.64723 4e-05 L
.64817 4e-05 L
.64903 4e-05 L
.64996 4e-05 L
Mistroke
.65095 4e-05 L
.65188 4e-05 L
.65274 4e-05 L
.65374 4e-05 L
.6543 4e-05 L
.65483 4e-05 L
.65579 4e-05 L
.65627 4e-05 L
.65681 4e-05 L
.65732 4e-05 L
.65787 4e-05 L
.65885 4e-05 L
.65939 4e-05 L
.6599 4e-05 L
.66045 4e-05 L
.66105 4e-05 L
.66156 4e-05 L
.66212 4e-05 L
.66265 4e-05 L
.66313 4e-05 L
.66405 4e-05 L
.66503 4e-05 L
.66595 4e-05 L
.66696 4e-05 L
.66791 4e-05 L
.66879 4e-05 L
.66966 4e-05 L
.67045 4e-05 L
.67137 4e-05 L
.67223 4e-05 L
.67317 4e-05 L
.67417 4e-05 L
.67502 4e-05 L
.67595 4e-05 L
.67695 4e-05 L
.67752 4e-05 L
.67803 4e-05 L
.67903 4e-05 L
.67997 4e-05 L
.68077 4e-05 L
.68166 4e-05 L
.68258 4e-05 L
.68345 4e-05 L
.68426 4e-05 L
.685 4e-05 L
.68582 4e-05 L
.68667 4e-05 L
.68755 4e-05 L
.68848 4e-05 L
.68936 4e-05 L
Mistroke
.69016 4e-05 L
.6911 4e-05 L
.69163 4e-05 L
.69212 4e-05 L
.69301 4e-05 L
.69397 4e-05 L
.69489 4e-05 L
.6959 4e-05 L
.69685 4e-05 L
.69774 4e-05 L
.69861 4e-05 L
.69941 4e-05 L
.70032 4e-05 L
.70118 4e-05 L
.70213 4e-05 L
.70312 4e-05 L
.70398 4e-05 L
.70491 4e-05 L
.70592 4e-05 L
.70648 4e-05 L
.70699 4e-05 L
.70799 4e-05 L
.70893 4e-05 L
.70974 4e-05 L
.71063 4e-05 L
.71155 4e-05 L
.71242 4e-05 L
.71323 4e-05 L
.71398 4e-05 L
.71479 4e-05 L
.71565 4e-05 L
.71652 4e-05 L
.71745 4e-05 L
.71833 4e-05 L
.71913 4e-05 L
.72007 4e-05 L
.7206 4e-05 L
.72109 4e-05 L
.72199 4e-05 L
.72294 4e-05 L
.72387 4e-05 L
.72439 4e-05 L
.72488 4e-05 L
.72577 4e-05 L
.72672 4e-05 L
.72757 4e-05 L
.72836 4e-05 L
.72923 4e-05 L
.73018 4e-05 L
.73112 4e-05 L
Mistroke
.73165 4e-05 L
.73215 4e-05 L
.73315 4e-05 L
.73371 4e-05 L
.73422 4e-05 L
.73514 4e-05 L
.73613 4e-05 L
.73707 4e-05 L
.73794 4e-05 L
.73874 4e-05 L
.73961 4e-05 L
.74043 4e-05 L
.74118 4e-05 L
.74205 4e-05 L
.74301 4e-05 L
.74391 4e-05 L
.74474 4e-05 L
.74569 4e-05 L
.74657 4e-05 L
.74737 4e-05 L
.74823 4e-05 L
.74918 4e-05 L
.75017 4e-05 L
.75102 4e-05 L
.75195 4e-05 L
.75295 4e-05 L
.75387 4e-05 L
.75436 4e-05 L
.75489 4e-05 L
.75544 4e-05 L
.75597 4e-05 L
.75692 4e-05 L
.75779 4e-05 L
.75875 4e-05 L
.75976 4e-05 L
.76062 4e-05 L
.76153 4e-05 L
.76239 4e-05 L
.76317 4e-05 L
.76408 4e-05 L
.76508 4e-05 L
.76602 4e-05 L
.76688 4e-05 L
.76781 4e-05 L
.7688 4e-05 L
.76973 4e-05 L
.77059 4e-05 L
.77159 4e-05 L
.77215 4e-05 L
.77267 4e-05 L
Mistroke
.77363 4e-05 L
.77417 4e-05 L
.77466 4e-05 L
.77517 4e-05 L
.77572 4e-05 L
.77669 4e-05 L
.77724 4e-05 L
.77774 4e-05 L
.7783 4e-05 L
.7789 4e-05 L
.77941 4e-05 L
.77997 4e-05 L
.7805 4e-05 L
.78098 4e-05 L
.7819 4e-05 L
.78288 4e-05 L
.7838 4e-05 L
.78481 4e-05 L
.78576 4e-05 L
.78664 4e-05 L
.78751 4e-05 L
.7883 4e-05 L
.78921 4e-05 L
.79007 4e-05 L
.79102 4e-05 L
.79201 4e-05 L
.79286 4e-05 L
.79379 4e-05 L
.79479 4e-05 L
.79536 4e-05 L
.79587 4e-05 L
.79687 4e-05 L
.79781 4e-05 L
.79862 4e-05 L
.7995 4e-05 L
.80043 4e-05 L
.80129 4e-05 L
.8021 4e-05 L
.80284 4e-05 L
.80366 4e-05 L
.80451 4e-05 L
.80539 4e-05 L
.80632 4e-05 L
.8072 4e-05 L
.808 4e-05 L
.80894 4e-05 L
.80947 4e-05 L
.80995 4e-05 L
.81085 4e-05 L
.81181 4e-05 L
Mistroke
.81273 4e-05 L
.81374 4e-05 L
.81469 4e-05 L
.81557 4e-05 L
.81645 4e-05 L
.81724 4e-05 L
.81816 4e-05 L
.81902 4e-05 L
.81996 4e-05 L
.82096 4e-05 L
.82181 4e-05 L
.82274 4e-05 L
.82375 4e-05 L
.82431 4e-05 L
.82483 4e-05 L
.82582 4e-05 L
.82677 4e-05 L
.82757 4e-05 L
.82846 4e-05 L
.82939 4e-05 L
.83025 4e-05 L
.83106 4e-05 L
.83181 4e-05 L
.83262 4e-05 L
.83348 4e-05 L
.83435 4e-05 L
.83528 4e-05 L
.83616 4e-05 L
.83696 4e-05 L
.8379 4e-05 L
.83843 4e-05 L
.83892 4e-05 L
.83982 4e-05 L
.84077 4e-05 L
.8417 4e-05 L
.84222 4e-05 L
.84271 4e-05 L
.8436 4e-05 L
.84455 4e-05 L
.8454 4e-05 L
.84619 4e-05 L
.84706 4e-05 L
.848 4e-05 L
.84894 4e-05 L
.84947 4e-05 L
.84997 4e-05 L
.85097 4e-05 L
.85154 4e-05 L
.85205 4e-05 L
.85296 4e-05 L
Mistroke
.85396 4e-05 L
.8549 4e-05 L
.85576 4e-05 L
.85657 4e-05 L
.85743 4e-05 L
.85825 4e-05 L
.859 4e-05 L
.85987 4e-05 L
.86083 4e-05 L
.86173 4e-05 L
.86256 4e-05 L
.86351 4e-05 L
.86439 4e-05 L
.86519 4e-05 L
.86605 4e-05 L
.867 4e-05 L
.86799 4e-05 L
.86884 4e-05 L
.86977 4e-05 L
.87045 4e-05 L
.87107 4e-05 L
.87176 4e-05 L
.87248 4e-05 L
.87311 4e-05 L
.8737 4e-05 L
.87435 4e-05 L
.87505 4e-05 L
.87563 4e-05 L
.87627 4e-05 L
.87694 4e-05 L
.87756 4e-05 L
.87814 4e-05 L
.87867 4e-05 L
.87928 4e-05 L
.87986 4e-05 L
.88048 4e-05 L
.88117 4e-05 L
.88188 4e-05 L
.88256 4e-05 L
.88318 4e-05 L
.88375 4e-05 L
.88442 4e-05 L
.88504 4e-05 L
.88572 4e-05 L
.88644 4e-05 L
.88712 4e-05 L
.88773 4e-05 L
.88846 4e-05 L
.88924 4e-05 L
.88998 4e-05 L
Mistroke
.89066 4e-05 L
Mfstroke
.16241 4e-05 m
.19195 .02347 L
.22417 .04921 L
.25443 .07359 L
.28353 .09724 L
.3145 .12263 L
.34432 .14732 L
.37601 .17383 L
.40655 .19968 L
.43592 .22485 L
.46717 .25199 L
.49726 .27852 L
.52619 .30442 L
.557 .33249 L
.58665 .36003 L
.61817 .38998 L
.64853 .41957 L
.67774 .44883 L
.70882 .481 L
.73874 .51319 L
.77054 .54904 L
.80117 .58568 L
.83065 .62357 L
.86201 .66807 L
.89066 .71509 L
s
.5 1 1 r
.16241 4e-05 m
.1633 4e-05 L
.16412 4e-05 L
.16507 4e-05 L
.16596 4e-05 L
.16678 4e-05 L
.16755 4e-05 L
.16838 4e-05 L
.16927 4e-05 L
.17016 4e-05 L
.17112 4e-05 L
.17202 4e-05 L
.17285 4e-05 L
.17381 4e-05 L
.17436 4e-05 L
.17487 4e-05 L
.1758 4e-05 L
.17679 4e-05 L
.17729 4e-05 L
.17781 4e-05 L
.17875 4e-05 L
.17928 4e-05 L
.17977 4e-05 L
.18031 4e-05 L
.18088 4e-05 L
.18138 4e-05 L
.18192 4e-05 L
.1829 4e-05 L
.18386 4e-05 L
.18474 4e-05 L
.1856 4e-05 L
.1864 4e-05 L
.18728 4e-05 L
.18824 4e-05 L
.18918 4e-05 L
.19017 4e-05 L
.19102 4e-05 L
.19195 4e-05 L
.19249 4e-05 L
.19299 4e-05 L
.19354 4e-05 L
.19412 4e-05 L
.1951 4e-05 L
.19566 4e-05 L
.19618 4e-05 L
.19714 4e-05 L
.19803 4e-05 L
.19852 4e-05 L
.19905 4e-05 L
.20002 4e-05 L
.2006 4e-05 L
.20116 4e-05 L
.20165 4e-05 L
.20219 4e-05 L
.20277 4e-05 L
.20339 4e-05 L
.20391 4e-05 L
.20449 4e-05 L
.20503 4e-05 L
.20553 4e-05 L
.2061 4e-05 L
.20664 4e-05 L
.2076 4e-05 L
.20814 4e-05 L
.20864 4e-05 L
.20953 4e-05 L
.21049 4e-05 L
.21139 4e-05 L
.21222 4e-05 L
.21314 4e-05 L
.21415 4e-05 L
.21466 4e-05 L
.2152 4e-05 L
.21617 4e-05 L
.21671 4e-05 L
.21721 4e-05 L
.21776 4e-05 L
.21833 4e-05 L
.2193 4e-05 L
.21985 4e-05 L
.22037 4e-05 L
.22132 4e-05 L
.2222 4e-05 L
.22321 4e-05 L
.22417 4e-05 L
.22504 4e-05 L
.22597 4e-05 L
.22686 4e-05 L
.22767 4e-05 L
.22857 4e-05 L
.22955 4e-05 L
.23005 4e-05 L
.23058 4e-05 L
.23154 4e-05 L
.23206 4e-05 L
.23255 4e-05 L
.23308 4e-05 L
.23365 4e-05 L
.2346 4e-05 L
.23514 4e-05 L
.23564 4e-05 L
.23658 4e-05 L
.23744 4e-05 L
.23843 4e-05 L
.23937 4e-05 L
.24026 4e-05 L
.24106 4e-05 L
.24199 4e-05 L
.24287 4e-05 L
.24368 4e-05 L
.24442 4e-05 L
.24524 4e-05 L
.24611 4e-05 L
.24698 4e-05 L
.24792 4e-05 L
.2488 4e-05 L
.24961 4e-05 L
.25056 4e-05 L
.25109 4e-05 L
.25158 4e-05 L
.25249 4e-05 L
.25345 4e-05 L
.25432 4e-05 L
.25528 4e-05 L
.25627 4e-05 L
.2572 4e-05 L
.25807 4e-05 L
.25885 4e-05 L
.25977 4e-05 L
.26063 4e-05 L
.26156 4e-05 L
.26256 4e-05 L
.2634 4e-05 L
.26433 4e-05 L
.26534 4e-05 L
.2659 4e-05 L
.26641 4e-05 L
.26741 4e-05 L
.26835 4e-05 L
.26924 4e-05 L
.27004 4e-05 L
.27096 4e-05 L
.27183 4e-05 L
.27263 4e-05 L
.27337 4e-05 L
.27419 4e-05 L
.27504 4e-05 L
.27591 4e-05 L
.27685 4e-05 L
.27772 4e-05 L
.27852 4e-05 L
.27946 4e-05 L
.27999 4e-05 L
.28048 4e-05 L
.28138 4e-05 L
.28234 4e-05 L
.28326 4e-05 L
.28426 4e-05 L
.28521 4e-05 L
.28609 4e-05 L
.28696 4e-05 L
.28775 4e-05 L
.28867 4e-05 L
.28953 4e-05 L
.29047 4e-05 L
.29146 4e-05 L
.29231 4e-05 L
.29324 4e-05 L
.29425 4e-05 L
.29481 4e-05 L
.29532 4e-05 L
.29632 4e-05 L
.29727 4e-05 L
.29807 4e-05 L
.29895 4e-05 L
.29988 4e-05 L
.30075 4e-05 L
.30155 4e-05 L
.3023 4e-05 L
.30311 4e-05 L
.30397 4e-05 L
.30484 4e-05 L
.30577 4e-05 L
.30665 4e-05 L
.30745 4e-05 L
.30839 4e-05 L
.30892 4e-05 L
.30941 4e-05 L
.31031 4e-05 L
.31126 4e-05 L
.31218 4e-05 L
.31319 4e-05 L
.31414 4e-05 L
.31502 4e-05 L
.3159 4e-05 L
.31669 4e-05 L
.31761 4e-05 L
.31847 4e-05 L
.31941 4e-05 L
.32041 4e-05 L
.32126 4e-05 L
.32219 4e-05 L
.3232 4e-05 L
.32376 4e-05 L
.32428 4e-05 L
.32527 4e-05 L
.32622 4e-05 L
.32702 4e-05 L
.32791 4e-05 L
.32884 4e-05 L
.3297 4e-05 L
.33051 4e-05 L
.33126 4e-05 L
.33207 4e-05 L
.33293 4e-05 L
.3338 4e-05 L
.33473 4e-05 L
.33561 4e-05 L
.33641 4e-05 L
.33735 4e-05 L
.33788 4e-05 L
.33837 4e-05 L
.33927 4e-05 L
.34022 4e-05 L
.34115 4e-05 L
.34216 4e-05 L
.34311 4e-05 L
.344 4e-05 L
.34479 4e-05 L
.34567 4e-05 L
.34659 4e-05 L
.34745 4e-05 L
.3484 4e-05 L
.3494 4e-05 L
.35025 4e-05 L
.35118 4e-05 L
.35219 4e-05 L
.35275 4e-05 L
.35327 4e-05 L
.35427 4e-05 L
.35521 4e-05 L
.35602 4e-05 L
.35691 4e-05 L
.35783 4e-05 L
.3587 4e-05 L
.35952 4e-05 L
.36026 4e-05 L
.36111 4e-05 L
.36193 4e-05 L
.3628 4e-05 L
.36374 4e-05 L
.36462 4e-05 L
.36542 4e-05 L
.36636 4e-05 L
.36689 4e-05 L
.36738 4e-05 L
.36827 4e-05 L
.36922 4e-05 L
.37015 4e-05 L
.37068 4e-05 L
.37117 4e-05 L
.37206 4e-05 L
.37301 4e-05 L
.37386 4e-05 L
.37466 4e-05 L
.37553 4e-05 L
.37647 4e-05 L
.37741 4e-05 L
.37795 4e-05 L
.37845 4e-05 L
.37945 4e-05 L
.38001 4e-05 L
.38053 4e-05 L
.38144 4e-05 L
.38244 4e-05 L
.38338 4e-05 L
.38424 4e-05 L
.38505 4e-05 L
.38592 4e-05 L
.38674 4e-05 L
.38749 4e-05 L
.38836 4e-05 L
.38932 4e-05 L
.39022 4e-05 L
.39105 4e-05 L
.392 4e-05 L
.39289 4e-05 L
.39368 4e-05 L
.39455 4e-05 L
.39549 4e-05 L
.39648 4e-05 L
.39733 4e-05 L
.39826 4e-05 L
.39926 4e-05 L
.40019 4e-05 L
.40067 4e-05 L
.40121 4e-05 L
.40176 4e-05 L
.40228 4e-05 L
.40324 4e-05 L
.40412 4e-05 L
.40513 4e-05 L
.40609 4e-05 L
.40694 4e-05 L
.40786 4e-05 L
.40872 4e-05 L
.4095 4e-05 L
.41041 4e-05 L
.41141 4e-05 L
.41235 4e-05 L
.41322 4e-05 L
.41414 4e-05 L
.41513 4e-05 L
.41607 4e-05 L
.41692 4e-05 L
.41792 4e-05 L
.41849 4e-05 L
.41901 4e-05 L
.41997 4e-05 L
.42046 4e-05 L
.421 4e-05 L
.42151 4e-05 L
.42206 4e-05 L
.42304 4e-05 L
.42358 4e-05 L
.42409 4e-05 L
.42464 4e-05 L
.42524 4e-05 L
.42575 4e-05 L
.42631 4e-05 L
.42684 4e-05 L
.42732 4e-05 L
.42824 4e-05 L
.42922 4e-05 L
.43014 4e-05 L
.43115 4e-05 L
.4321 4e-05 L
.43298 4e-05 L
.43386 4e-05 L
.43465 4e-05 L
.43557 4e-05 L
.43643 4e-05 L
.43737 4e-05 L
.43837 4e-05 L
.43922 4e-05 L
.44015 4e-05 L
.44115 4e-05 L
.44172 4e-05 L
.44223 4e-05 L
.44323 4e-05 L
.44417 4e-05 L
.44498 4e-05 L
.44586 4e-05 L
.44679 4e-05 L
.44766 4e-05 L
.44847 4e-05 L
.44921 4e-05 L
.45002 4e-05 L
.45088 4e-05 L
.45175 4e-05 L
.45269 4e-05 L
.45357 4e-05 L
.45436 4e-05 L
.4553 4e-05 L
.45584 4e-05 L
.45632 4e-05 L
.45722 4e-05 L
.45817 4e-05 L
.4591 4e-05 L
.46011 4e-05 L
.46107 4e-05 L
.46195 4e-05 L
.46283 4e-05 L
.46362 4e-05 L
.46454 4e-05 L
.4654 4e-05 L
.46635 4e-05 L
.46734 4e-05 L
.4682 4e-05 L
.46913 4e-05 L
.47014 4e-05 L
.4707 4e-05 L
.47121 4e-05 L
.47221 4e-05 L
.47316 4e-05 L
.47396 4e-05 L
.47485 4e-05 L
.47578 4e-05 L
.47665 4e-05 L
.47746 4e-05 L
.4782 4e-05 L
.47906 4e-05 L
.47987 4e-05 L
.48075 4e-05 L
.48168 4e-05 L
.48256 4e-05 L
.48336 4e-05 L
.4843 4e-05 L
.48483 4e-05 L
.48532 4e-05 L
.48622 4e-05 L
.48716 4e-05 L
.4881 4e-05 L
.48862 4e-05 L
.48911 4e-05 L
.49 4e-05 L
.49095 4e-05 L
.4918 4e-05 L
.4926 4e-05 L
.49347 4e-05 L
.49441 4e-05 L
.49535 4e-05 L
.49589 4e-05 L
.49638 4e-05 L
.49739 4e-05 L
.49795 4e-05 L
.49846 4e-05 L
.49938 4e-05 L
.50037 4e-05 L
.50131 4e-05 L
.50218 4e-05 L
.50299 4e-05 L
.50385 4e-05 L
.50467 4e-05 L
.50542 4e-05 L
.5063 4e-05 L
.50725 4e-05 L
.50815 4e-05 L
.50899 4e-05 L
.50993 4e-05 L
.51082 4e-05 L
.51162 4e-05 L
.51248 4e-05 L
.51342 4e-05 L
.51442 4e-05 L
.51527 4e-05 L
.5162 4e-05 L
.5172 4e-05 L
.51812 4e-05 L
.51861 4e-05 L
.51914 4e-05 L
.51969 4e-05 L
.52022 4e-05 L
.52117 4e-05 L
.52205 4e-05 L
.52301 4e-05 L
.52402 4e-05 L
.52487 4e-05 L
.52578 4e-05 L
.52664 4e-05 L
.52742 4e-05 L
.52834 4e-05 L
.52934 4e-05 L
.53028 4e-05 L
.53114 4e-05 L
.53207 4e-05 L
.53306 4e-05 L
.53399 4e-05 L
.53485 4e-05 L
.53585 4e-05 L
.53641 4e-05 L
.53694 4e-05 L
.5379 4e-05 L
.53838 4e-05 L
.53892 4e-05 L
.53944 4e-05 L
.53998 4e-05 L
.54096 4e-05 L
.5415 4e-05 L
.54201 4e-05 L
.54257 4e-05 L
.54316 4e-05 L
.54367 4e-05 L
.54423 4e-05 L
.54476 4e-05 L
.54525 4e-05 L
.54617 4e-05 L
.54714 4e-05 L
.54807 4e-05 L
.54907 4e-05 L
.55002 4e-05 L
.55091 4e-05 L
.55178 4e-05 L
.55257 4e-05 L
.55349 4e-05 L
.55435 4e-05 L
.55529 4e-05 L
.55628 4e-05 L
.55713 4e-05 L
.55807 4e-05 L
.55907 4e-05 L
.55964 4e-05 L
.56015 4e-05 L
.56115 4e-05 L
.56209 4e-05 L
.56289 4e-05 L
.56378 4e-05 L
.56471 4e-05 L
.56557 4e-05 L
.56638 4e-05 L
.56713 4e-05 L
.56794 4e-05 L
.5688 4e-05 L
.56967 4e-05 L
.5706 4e-05 L
.57148 4e-05 L
.57228 4e-05 L
.57322 4e-05 L
.57375 4e-05 L
.57424 4e-05 L
.57514 4e-05 L
.57609 4e-05 L
.57701 4e-05 L
.57802 4e-05 L
.57898 4e-05 L
.57986 4e-05 L
.58074 4e-05 L
.58153 4e-05 L
.58245 4e-05 L
.58331 4e-05 L
.58425 4e-05 L
.58525 4e-05 L
.5861 4e-05 L
.58704 4e-05 L
.58804 4e-05 L
.58861 4e-05 L
.58912 4e-05 L
.59012 4e-05 L
.59106 4e-05 L
.59187 4e-05 L
.59276 4e-05 L
.59369 4e-05 L
.59455 4e-05 L
.59537 4e-05 L
.59611 4e-05 L
.59696 4e-05 L
.59778 4e-05 L
.59865 4e-05 L
.59959 4e-05 L
.60047 4e-05 L
.60126 4e-05 L
.60221 4e-05 L
.60274 4e-05 L
.60322 4e-05 L
.60412 4e-05 L
.60507 4e-05 L
.606 4e-05 L
.60653 4e-05 L
.60701 4e-05 L
.60791 4e-05 L
.60886 4e-05 L
.6097 4e-05 L
.6105 4e-05 L
.61137 4e-05 L
.61231 4e-05 L
.61325 4e-05 L
.61379 4e-05 L
.61428 4e-05 L
.61529 4e-05 L
.61585 4e-05 L
.61636 4e-05 L
.61728 4e-05 L
.61827 4e-05 L
.61921 4e-05 L
.62008 4e-05 L
.62088 4e-05 L
.62175 4e-05 L
.62257 4e-05 L
.62332 4e-05 L
.62419 4e-05 L
.62515 4e-05 L
.62605 4e-05 L
.62688 4e-05 L
.62783 4e-05 L
.62872 4e-05 L
.62951 4e-05 L
.63038 4e-05 L
.63132 4e-05 L
.63231 4e-05 L
.63316 4e-05 L
.63409 4e-05 L
.63509 4e-05 L
.63602 4e-05 L
.6365 4e-05 L
.63703 4e-05 L
.63759 4e-05 L
.63811 4e-05 L
.63906 4e-05 L
.63994 4e-05 L
.6409 4e-05 L
.64191 4e-05 L
.64276 4e-05 L
.64367 4e-05 L
.64453 4e-05 L
.64531 4e-05 L
.64623 4e-05 L
.64723 4e-05 L
.64817 4e-05 L
.64903 4e-05 L
.64996 4e-05 L
.65095 4e-05 L
.65188 4e-05 L
.65274 4e-05 L
.65374 4e-05 L
.6543 4e-05 L
.65483 4e-05 L
.65579 4e-05 L
.65627 4e-05 L
.65681 4e-05 L
.65732 4e-05 L
.65787 4e-05 L
.65885 4e-05 L
.65939 4e-05 L
.6599 4e-05 L
.66045 4e-05 L
.66105 4e-05 L
.66156 4e-05 L
.66212 4e-05 L
.66265 4e-05 L
.66313 4e-05 L
.66405 4e-05 L
.66503 4e-05 L
.66595 4e-05 L
.66696 4e-05 L
.66791 4e-05 L
.66879 4e-05 L
.66966 4e-05 L
.67045 4e-05 L
.67137 4e-05 L
.67223 4e-05 L
.67317 4e-05 L
.67417 4e-05 L
.67502 4e-05 L
.67595 4e-05 L
.67695 4e-05 L
.67752 4e-05 L
.67803 4e-05 L
.67903 4e-05 L
.67997 4e-05 L
.68077 4e-05 L
.68166 4e-05 L
.68258 4e-05 L
.68345 4e-05 L
.68426 4e-05 L
.685 4e-05 L
.68582 4e-05 L
.68667 4e-05 L
.68755 4e-05 L
.68848 4e-05 L
.68936 4e-05 L
.69016 4e-05 L
.6911 4e-05 L
.69163 4e-05 L
.69212 4e-05 L
.69301 4e-05 L
.69397 4e-05 L
.69489 4e-05 L
.6959 4e-05 L
.69685 4e-05 L
.69774 4e-05 L
.69861 4e-05 L
.69941 4e-05 L
.70032 4e-05 L
.70118 4e-05 L
.70213 4e-05 L
.70312 4e-05 L
.70398 4e-05 L
.70491 4e-05 L
.70592 4e-05 L
.70648 4e-05 L
.70699 4e-05 L
.70799 4e-05 L
.70893 4e-05 L
.70974 4e-05 L
.71063 4e-05 L
.71155 4e-05 L
.71242 4e-05 L
.71323 4e-05 L
.71398 4e-05 L
.71479 4e-05 L
.71565 4e-05 L
.71652 4e-05 L
.71745 4e-05 L
.71833 4e-05 L
.71913 4e-05 L
.72007 4e-05 L
.7206 4e-05 L
.72109 4e-05 L
.72199 4e-05 L
.72294 4e-05 L
.72387 4e-05 L
.72439 4e-05 L
.72488 4e-05 L
.72577 4e-05 L
.72672 4e-05 L
.72757 4e-05 L
.72836 4e-05 L
.72923 4e-05 L
.73018 4e-05 L
.73112 4e-05 L
.73165 4e-05 L
.73215 4e-05 L
.73315 4e-05 L
.73371 4e-05 L
.73422 4e-05 L
.73514 4e-05 L
.73613 4e-05 L
.73707 4e-05 L
.73794 4e-05 L
.73874 4e-05 L
.73961 4e-05 L
.74043 4e-05 L
.74118 4e-05 L
.74205 4e-05 L
.74301 4e-05 L
.74391 4e-05 L
.74474 4e-05 L
.74569 4e-05 L
.74657 4e-05 L
.74737 4e-05 L
.74823 4e-05 L
.74918 4e-05 L
.75017 4e-05 L
.75102 4e-05 L
.75195 4e-05 L
.75295 4e-05 L
.75387 4e-05 L
.75436 4e-05 L
.75489 4e-05 L
.75544 4e-05 L
.75597 4e-05 L
.75692 4e-05 L
.75779 4e-05 L
.75875 4e-05 L
.75976 4e-05 L
.76062 4e-05 L
.76153 4e-05 L
.76239 4e-05 L
.76317 4e-05 L
.76408 4e-05 L
.76508 4e-05 L
.76602 4e-05 L
.76688 4e-05 L
.76781 4e-05 L
.7688 4e-05 L
.76973 4e-05 L
.77059 4e-05 L
.77159 4e-05 L
.77215 4e-05 L
.77267 4e-05 L
.77363 4e-05 L
.77417 4e-05 L
.77466 4e-05 L
.77517 4e-05 L
.77572 4e-05 L
.77669 4e-05 L
.77724 4e-05 L
.77774 4e-05 L
.7783 4e-05 L
.7789 4e-05 L
.77941 4e-05 L
.77997 4e-05 L
.7805 4e-05 L
.78098 4e-05 L
.7819 4e-05 L
.78288 4e-05 L
.7838 4e-05 L
.78481 4e-05 L
.78576 4e-05 L
.78664 4e-05 L
.78751 4e-05 L
.7883 4e-05 L
.78921 4e-05 L
.79007 4e-05 L
.79102 4e-05 L
.79201 4e-05 L
.79286 4e-05 L
.79379 4e-05 L
.79479 4e-05 L
.79536 4e-05 L
.79587 4e-05 L
.79687 4e-05 L
.79781 4e-05 L
.79862 4e-05 L
.7995 4e-05 L
.80043 4e-05 L
.80129 4e-05 L
.8021 4e-05 L
.80284 4e-05 L
.80366 4e-05 L
.80451 4e-05 L
.80539 4e-05 L
.80632 4e-05 L
.8072 4e-05 L
.808 4e-05 L
.80894 4e-05 L
.80947 4e-05 L
.80995 4e-05 L
.81085 4e-05 L
.81181 4e-05 L
.81273 4e-05 L
.81374 4e-05 L
.81469 4e-05 L
.81557 4e-05 L
.81645 4e-05 L
.81724 4e-05 L
.81816 4e-05 L
.81902 4e-05 L
.81996 4e-05 L
.82096 4e-05 L
.82181 4e-05 L
.82274 4e-05 L
.82375 4e-05 L
.82431 4e-05 L
.82483 4e-05 L
.82582 4e-05 L
.82677 4e-05 L
.82757 4e-05 L
.82846 4e-05 L
.82939 4e-05 L
.83025 4e-05 L
.83106 4e-05 L
.83181 4e-05 L
.83262 4e-05 L
.83348 4e-05 L
.83435 4e-05 L
.83528 4e-05 L
.83616 4e-05 L
.83696 4e-05 L
.8379 4e-05 L
.83843 4e-05 L
.83892 4e-05 L
.83982 4e-05 L
.84077 4e-05 L
.8417 4e-05 L
.84222 4e-05 L
.84271 4e-05 L
.8436 4e-05 L
.84455 4e-05 L
.8454 4e-05 L
.84619 4e-05 L
.84706 4e-05 L
.848 4e-05 L
.84894 4e-05 L
.84947 4e-05 L
.84997 4e-05 L
.85097 4e-05 L
.85154 4e-05 L
.85205 4e-05 L
.85296 4e-05 L
.85396 4e-05 L
.8549 4e-05 L
.85576 4e-05 L
.85657 4e-05 L
.85743 4e-05 L
.85825 4e-05 L
.859 4e-05 L
.85987 4e-05 L
.86083 4e-05 L
.86173 4e-05 L
.86256 4e-05 L
.86351 4e-05 L
.86439 4e-05 L
.86519 4e-05 L
.86605 4e-05 L
.867 4e-05 L
.86799 4e-05 L
.86884 4e-05 L
.86977 4e-05 L
.87045 4e-05 L
.87107 4e-05 L
.87176 4e-05 L
.87248 4e-05 L
.87311 4e-05 L
.8737 4e-05 L
.87435 4e-05 L
.87505 4e-05 L
.87563 4e-05 L
.87627 4e-05 L
.87694 4e-05 L
.87756 4e-05 L
.87814 4e-05 L
.87867 4e-05 L
.87928 4e-05 L
.87986 4e-05 L
.88048 4e-05 L
.88117 4e-05 L
.88188 4e-05 L
.88256 4e-05 L
.88318 4e-05 L
.88375 4e-05 L
.88442 4e-05 L
.88504 4e-05 L
.88572 4e-05 L
.88644 4e-05 L
.88712 4e-05 L
.88773 4e-05 L
.88846 4e-05 L
.88924 4e-05 L
.88998 4e-05 L
.89066 4e-05 L
.89066 .71509 L
.86201 .66807 L
.83065 .62357 L
.80117 .58568 L
.77054 .54904 L
.73874 .51319 L
.70882 .481 L
.67774 .44883 L
.64853 .41957 L
.61817 .38998 L
.58665 .36003 L
.557 .33249 L
.52619 .30442 L
.49726 .27852 L
.46717 .25199 L
.43592 .22485 L
.40655 .19968 L
.37601 .17383 L
.34432 .14732 L
.3145 .12263 L
.28353 .09724 L
.25443 .07359 L
.22417 .04921 L
.19195 .02347 L
.16241 4e-05 L
F
0 g
.16241 4e-05 m
.1633 4e-05 L
.16412 4e-05 L
.16507 4e-05 L
.16596 4e-05 L
.16678 4e-05 L
.16755 4e-05 L
.16838 4e-05 L
.16927 4e-05 L
.17016 4e-05 L
.17112 4e-05 L
.17202 4e-05 L
.17285 4e-05 L
.17381 4e-05 L
.17436 4e-05 L
.17487 4e-05 L
.1758 4e-05 L
.17679 4e-05 L
.17729 4e-05 L
.17781 4e-05 L
.17875 4e-05 L
.17928 4e-05 L
.17977 4e-05 L
.18031 4e-05 L
.18088 4e-05 L
.18138 4e-05 L
.18192 4e-05 L
.1829 4e-05 L
.18386 4e-05 L
.18474 4e-05 L
.1856 4e-05 L
.1864 4e-05 L
.18728 4e-05 L
.18824 4e-05 L
.18918 4e-05 L
.19017 4e-05 L
.19102 4e-05 L
.19195 4e-05 L
.19249 4e-05 L
.19299 4e-05 L
.19354 4e-05 L
.19412 4e-05 L
.1951 4e-05 L
.19566 4e-05 L
.19618 4e-05 L
.19714 4e-05 L
.19803 4e-05 L
.19852 4e-05 L
.19905 4e-05 L
.20002 4e-05 L
Mistroke
.2006 4e-05 L
.20116 4e-05 L
.20165 4e-05 L
.20219 4e-05 L
.20277 4e-05 L
.20339 4e-05 L
.20391 4e-05 L
.20449 4e-05 L
.20503 4e-05 L
.20553 4e-05 L
.2061 4e-05 L
.20664 4e-05 L
.2076 4e-05 L
.20814 4e-05 L
.20864 4e-05 L
.20953 4e-05 L
.21049 4e-05 L
.21139 4e-05 L
.21222 4e-05 L
.21314 4e-05 L
.21415 4e-05 L
.21466 4e-05 L
.2152 4e-05 L
.21617 4e-05 L
.21671 4e-05 L
.21721 4e-05 L
.21776 4e-05 L
.21833 4e-05 L
.2193 4e-05 L
.21985 4e-05 L
.22037 4e-05 L
.22132 4e-05 L
.2222 4e-05 L
.22321 4e-05 L
.22417 4e-05 L
.22504 4e-05 L
.22597 4e-05 L
.22686 4e-05 L
.22767 4e-05 L
.22857 4e-05 L
.22955 4e-05 L
.23005 4e-05 L
.23058 4e-05 L
.23154 4e-05 L
.23206 4e-05 L
.23255 4e-05 L
.23308 4e-05 L
.23365 4e-05 L
.2346 4e-05 L
.23514 4e-05 L
Mistroke
.23564 4e-05 L
.23658 4e-05 L
.23744 4e-05 L
.23843 4e-05 L
.23937 4e-05 L
.24026 4e-05 L
.24106 4e-05 L
.24199 4e-05 L
.24287 4e-05 L
.24368 4e-05 L
.24442 4e-05 L
.24524 4e-05 L
.24611 4e-05 L
.24698 4e-05 L
.24792 4e-05 L
.2488 4e-05 L
.24961 4e-05 L
.25056 4e-05 L
.25109 4e-05 L
.25158 4e-05 L
.25249 4e-05 L
.25345 4e-05 L
.25432 4e-05 L
.25528 4e-05 L
.25627 4e-05 L
.2572 4e-05 L
.25807 4e-05 L
.25885 4e-05 L
.25977 4e-05 L
.26063 4e-05 L
.26156 4e-05 L
.26256 4e-05 L
.2634 4e-05 L
.26433 4e-05 L
.26534 4e-05 L
.2659 4e-05 L
.26641 4e-05 L
.26741 4e-05 L
.26835 4e-05 L
.26924 4e-05 L
.27004 4e-05 L
.27096 4e-05 L
.27183 4e-05 L
.27263 4e-05 L
.27337 4e-05 L
.27419 4e-05 L
.27504 4e-05 L
.27591 4e-05 L
.27685 4e-05 L
.27772 4e-05 L
Mistroke
.27852 4e-05 L
.27946 4e-05 L
.27999 4e-05 L
.28048 4e-05 L
.28138 4e-05 L
.28234 4e-05 L
.28326 4e-05 L
.28426 4e-05 L
.28521 4e-05 L
.28609 4e-05 L
.28696 4e-05 L
.28775 4e-05 L
.28867 4e-05 L
.28953 4e-05 L
.29047 4e-05 L
.29146 4e-05 L
.29231 4e-05 L
.29324 4e-05 L
.29425 4e-05 L
.29481 4e-05 L
.29532 4e-05 L
.29632 4e-05 L
.29727 4e-05 L
.29807 4e-05 L
.29895 4e-05 L
.29988 4e-05 L
.30075 4e-05 L
.30155 4e-05 L
.3023 4e-05 L
.30311 4e-05 L
.30397 4e-05 L
.30484 4e-05 L
.30577 4e-05 L
.30665 4e-05 L
.30745 4e-05 L
.30839 4e-05 L
.30892 4e-05 L
.30941 4e-05 L
.31031 4e-05 L
.31126 4e-05 L
.31218 4e-05 L
.31319 4e-05 L
.31414 4e-05 L
.31502 4e-05 L
.3159 4e-05 L
.31669 4e-05 L
.31761 4e-05 L
.31847 4e-05 L
.31941 4e-05 L
.32041 4e-05 L
Mistroke
.32126 4e-05 L
.32219 4e-05 L
.3232 4e-05 L
.32376 4e-05 L
.32428 4e-05 L
.32527 4e-05 L
.32622 4e-05 L
.32702 4e-05 L
.32791 4e-05 L
.32884 4e-05 L
.3297 4e-05 L
.33051 4e-05 L
.33126 4e-05 L
.33207 4e-05 L
.33293 4e-05 L
.3338 4e-05 L
.33473 4e-05 L
.33561 4e-05 L
.33641 4e-05 L
.33735 4e-05 L
.33788 4e-05 L
.33837 4e-05 L
.33927 4e-05 L
.34022 4e-05 L
.34115 4e-05 L
.34216 4e-05 L
.34311 4e-05 L
.344 4e-05 L
.34479 4e-05 L
.34567 4e-05 L
.34659 4e-05 L
.34745 4e-05 L
.3484 4e-05 L
.3494 4e-05 L
.35025 4e-05 L
.35118 4e-05 L
.35219 4e-05 L
.35275 4e-05 L
.35327 4e-05 L
.35427 4e-05 L
.35521 4e-05 L
.35602 4e-05 L
.35691 4e-05 L
.35783 4e-05 L
.3587 4e-05 L
.35952 4e-05 L
.36026 4e-05 L
.36111 4e-05 L
.36193 4e-05 L
.3628 4e-05 L
Mistroke
.36374 4e-05 L
.36462 4e-05 L
.36542 4e-05 L
.36636 4e-05 L
.36689 4e-05 L
.36738 4e-05 L
.36827 4e-05 L
.36922 4e-05 L
.37015 4e-05 L
.37068 4e-05 L
.37117 4e-05 L
.37206 4e-05 L
.37301 4e-05 L
.37386 4e-05 L
.37466 4e-05 L
.37553 4e-05 L
.37647 4e-05 L
.37741 4e-05 L
.37795 4e-05 L
.37845 4e-05 L
.37945 4e-05 L
.38001 4e-05 L
.38053 4e-05 L
.38144 4e-05 L
.38244 4e-05 L
.38338 4e-05 L
.38424 4e-05 L
.38505 4e-05 L
.38592 4e-05 L
.38674 4e-05 L
.38749 4e-05 L
.38836 4e-05 L
.38932 4e-05 L
.39022 4e-05 L
.39105 4e-05 L
.392 4e-05 L
.39289 4e-05 L
.39368 4e-05 L
.39455 4e-05 L
.39549 4e-05 L
.39648 4e-05 L
.39733 4e-05 L
.39826 4e-05 L
.39926 4e-05 L
.40019 4e-05 L
.40067 4e-05 L
.40121 4e-05 L
.40176 4e-05 L
.40228 4e-05 L
.40324 4e-05 L
Mistroke
.40412 4e-05 L
.40513 4e-05 L
.40609 4e-05 L
.40694 4e-05 L
.40786 4e-05 L
.40872 4e-05 L
.4095 4e-05 L
.41041 4e-05 L
.41141 4e-05 L
.41235 4e-05 L
.41322 4e-05 L
.41414 4e-05 L
.41513 4e-05 L
.41607 4e-05 L
.41692 4e-05 L
.41792 4e-05 L
.41849 4e-05 L
.41901 4e-05 L
.41997 4e-05 L
.42046 4e-05 L
.421 4e-05 L
.42151 4e-05 L
.42206 4e-05 L
.42304 4e-05 L
.42358 4e-05 L
.42409 4e-05 L
.42464 4e-05 L
.42524 4e-05 L
.42575 4e-05 L
.42631 4e-05 L
.42684 4e-05 L
.42732 4e-05 L
.42824 4e-05 L
.42922 4e-05 L
.43014 4e-05 L
.43115 4e-05 L
.4321 4e-05 L
.43298 4e-05 L
.43386 4e-05 L
.43465 4e-05 L
.43557 4e-05 L
.43643 4e-05 L
.43737 4e-05 L
.43837 4e-05 L
.43922 4e-05 L
.44015 4e-05 L
.44115 4e-05 L
.44172 4e-05 L
.44223 4e-05 L
.44323 4e-05 L
Mistroke
.44417 4e-05 L
.44498 4e-05 L
.44586 4e-05 L
.44679 4e-05 L
.44766 4e-05 L
.44847 4e-05 L
.44921 4e-05 L
.45002 4e-05 L
.45088 4e-05 L
.45175 4e-05 L
.45269 4e-05 L
.45357 4e-05 L
.45436 4e-05 L
.4553 4e-05 L
.45584 4e-05 L
.45632 4e-05 L
.45722 4e-05 L
.45817 4e-05 L
.4591 4e-05 L
.46011 4e-05 L
.46107 4e-05 L
.46195 4e-05 L
.46283 4e-05 L
.46362 4e-05 L
.46454 4e-05 L
.4654 4e-05 L
.46635 4e-05 L
.46734 4e-05 L
.4682 4e-05 L
.46913 4e-05 L
.47014 4e-05 L
.4707 4e-05 L
.47121 4e-05 L
.47221 4e-05 L
.47316 4e-05 L
.47396 4e-05 L
.47485 4e-05 L
.47578 4e-05 L
.47665 4e-05 L
.47746 4e-05 L
.4782 4e-05 L
.47906 4e-05 L
.47987 4e-05 L
.48075 4e-05 L
.48168 4e-05 L
.48256 4e-05 L
.48336 4e-05 L
.4843 4e-05 L
.48483 4e-05 L
.48532 4e-05 L
Mistroke
.48622 4e-05 L
.48716 4e-05 L
.4881 4e-05 L
.48862 4e-05 L
.48911 4e-05 L
.49 4e-05 L
.49095 4e-05 L
.4918 4e-05 L
.4926 4e-05 L
.49347 4e-05 L
.49441 4e-05 L
.49535 4e-05 L
.49589 4e-05 L
.49638 4e-05 L
.49739 4e-05 L
.49795 4e-05 L
.49846 4e-05 L
.49938 4e-05 L
.50037 4e-05 L
.50131 4e-05 L
.50218 4e-05 L
.50299 4e-05 L
.50385 4e-05 L
.50467 4e-05 L
.50542 4e-05 L
.5063 4e-05 L
.50725 4e-05 L
.50815 4e-05 L
.50899 4e-05 L
.50993 4e-05 L
.51082 4e-05 L
.51162 4e-05 L
.51248 4e-05 L
.51342 4e-05 L
.51442 4e-05 L
.51527 4e-05 L
.5162 4e-05 L
.5172 4e-05 L
.51812 4e-05 L
.51861 4e-05 L
.51914 4e-05 L
.51969 4e-05 L
.52022 4e-05 L
.52117 4e-05 L
.52205 4e-05 L
.52301 4e-05 L
.52402 4e-05 L
.52487 4e-05 L
.52578 4e-05 L
.52664 4e-05 L
Mistroke
.52742 4e-05 L
.52834 4e-05 L
.52934 4e-05 L
.53028 4e-05 L
.53114 4e-05 L
.53207 4e-05 L
.53306 4e-05 L
.53399 4e-05 L
.53485 4e-05 L
.53585 4e-05 L
.53641 4e-05 L
.53694 4e-05 L
.5379 4e-05 L
.53838 4e-05 L
.53892 4e-05 L
.53944 4e-05 L
.53998 4e-05 L
.54096 4e-05 L
.5415 4e-05 L
.54201 4e-05 L
.54257 4e-05 L
.54316 4e-05 L
.54367 4e-05 L
.54423 4e-05 L
.54476 4e-05 L
.54525 4e-05 L
.54617 4e-05 L
.54714 4e-05 L
.54807 4e-05 L
.54907 4e-05 L
.55002 4e-05 L
.55091 4e-05 L
.55178 4e-05 L
.55257 4e-05 L
.55349 4e-05 L
.55435 4e-05 L
.55529 4e-05 L
.55628 4e-05 L
.55713 4e-05 L
.55807 4e-05 L
.55907 4e-05 L
.55964 4e-05 L
.56015 4e-05 L
.56115 4e-05 L
.56209 4e-05 L
.56289 4e-05 L
.56378 4e-05 L
.56471 4e-05 L
.56557 4e-05 L
.56638 4e-05 L
Mistroke
.56713 4e-05 L
.56794 4e-05 L
.5688 4e-05 L
.56967 4e-05 L
.5706 4e-05 L
.57148 4e-05 L
.57228 4e-05 L
.57322 4e-05 L
.57375 4e-05 L
.57424 4e-05 L
.57514 4e-05 L
.57609 4e-05 L
.57701 4e-05 L
.57802 4e-05 L
.57898 4e-05 L
.57986 4e-05 L
.58074 4e-05 L
.58153 4e-05 L
.58245 4e-05 L
.58331 4e-05 L
.58425 4e-05 L
.58525 4e-05 L
.5861 4e-05 L
.58704 4e-05 L
.58804 4e-05 L
.58861 4e-05 L
.58912 4e-05 L
.59012 4e-05 L
.59106 4e-05 L
.59187 4e-05 L
.59276 4e-05 L
.59369 4e-05 L
.59455 4e-05 L
.59537 4e-05 L
.59611 4e-05 L
.59696 4e-05 L
.59778 4e-05 L
.59865 4e-05 L
.59959 4e-05 L
.60047 4e-05 L
.60126 4e-05 L
.60221 4e-05 L
.60274 4e-05 L
.60322 4e-05 L
.60412 4e-05 L
.60507 4e-05 L
.606 4e-05 L
.60653 4e-05 L
.60701 4e-05 L
.60791 4e-05 L
Mistroke
.60886 4e-05 L
.6097 4e-05 L
.6105 4e-05 L
.61137 4e-05 L
.61231 4e-05 L
.61325 4e-05 L
.61379 4e-05 L
.61428 4e-05 L
.61529 4e-05 L
.61585 4e-05 L
.61636 4e-05 L
.61728 4e-05 L
.61827 4e-05 L
.61921 4e-05 L
.62008 4e-05 L
.62088 4e-05 L
.62175 4e-05 L
.62257 4e-05 L
.62332 4e-05 L
.62419 4e-05 L
.62515 4e-05 L
.62605 4e-05 L
.62688 4e-05 L
.62783 4e-05 L
.62872 4e-05 L
.62951 4e-05 L
.63038 4e-05 L
.63132 4e-05 L
.63231 4e-05 L
.63316 4e-05 L
.63409 4e-05 L
.63509 4e-05 L
.63602 4e-05 L
.6365 4e-05 L
.63703 4e-05 L
.63759 4e-05 L
.63811 4e-05 L
.63906 4e-05 L
.63994 4e-05 L
.6409 4e-05 L
.64191 4e-05 L
.64276 4e-05 L
.64367 4e-05 L
.64453 4e-05 L
.64531 4e-05 L
.64623 4e-05 L
.64723 4e-05 L
.64817 4e-05 L
.64903 4e-05 L
.64996 4e-05 L
Mistroke
.65095 4e-05 L
.65188 4e-05 L
.65274 4e-05 L
.65374 4e-05 L
.6543 4e-05 L
.65483 4e-05 L
.65579 4e-05 L
.65627 4e-05 L
.65681 4e-05 L
.65732 4e-05 L
.65787 4e-05 L
.65885 4e-05 L
.65939 4e-05 L
.6599 4e-05 L
.66045 4e-05 L
.66105 4e-05 L
.66156 4e-05 L
.66212 4e-05 L
.66265 4e-05 L
.66313 4e-05 L
.66405 4e-05 L
.66503 4e-05 L
.66595 4e-05 L
.66696 4e-05 L
.66791 4e-05 L
.66879 4e-05 L
.66966 4e-05 L
.67045 4e-05 L
.67137 4e-05 L
.67223 4e-05 L
.67317 4e-05 L
.67417 4e-05 L
.67502 4e-05 L
.67595 4e-05 L
.67695 4e-05 L
.67752 4e-05 L
.67803 4e-05 L
.67903 4e-05 L
.67997 4e-05 L
.68077 4e-05 L
.68166 4e-05 L
.68258 4e-05 L
.68345 4e-05 L
.68426 4e-05 L
.685 4e-05 L
.68582 4e-05 L
.68667 4e-05 L
.68755 4e-05 L
.68848 4e-05 L
.68936 4e-05 L
Mistroke
.69016 4e-05 L
.6911 4e-05 L
.69163 4e-05 L
.69212 4e-05 L
.69301 4e-05 L
.69397 4e-05 L
.69489 4e-05 L
.6959 4e-05 L
.69685 4e-05 L
.69774 4e-05 L
.69861 4e-05 L
.69941 4e-05 L
.70032 4e-05 L
.70118 4e-05 L
.70213 4e-05 L
.70312 4e-05 L
.70398 4e-05 L
.70491 4e-05 L
.70592 4e-05 L
.70648 4e-05 L
.70699 4e-05 L
.70799 4e-05 L
.70893 4e-05 L
.70974 4e-05 L
.71063 4e-05 L
.71155 4e-05 L
.71242 4e-05 L
.71323 4e-05 L
.71398 4e-05 L
.71479 4e-05 L
.71565 4e-05 L
.71652 4e-05 L
.71745 4e-05 L
.71833 4e-05 L
.71913 4e-05 L
.72007 4e-05 L
.7206 4e-05 L
.72109 4e-05 L
.72199 4e-05 L
.72294 4e-05 L
.72387 4e-05 L
.72439 4e-05 L
.72488 4e-05 L
.72577 4e-05 L
.72672 4e-05 L
.72757 4e-05 L
.72836 4e-05 L
.72923 4e-05 L
.73018 4e-05 L
.73112 4e-05 L
Mistroke
.73165 4e-05 L
.73215 4e-05 L
.73315 4e-05 L
.73371 4e-05 L
.73422 4e-05 L
.73514 4e-05 L
.73613 4e-05 L
.73707 4e-05 L
.73794 4e-05 L
.73874 4e-05 L
.73961 4e-05 L
.74043 4e-05 L
.74118 4e-05 L
.74205 4e-05 L
.74301 4e-05 L
.74391 4e-05 L
.74474 4e-05 L
.74569 4e-05 L
.74657 4e-05 L
.74737 4e-05 L
.74823 4e-05 L
.74918 4e-05 L
.75017 4e-05 L
.75102 4e-05 L
.75195 4e-05 L
.75295 4e-05 L
.75387 4e-05 L
.75436 4e-05 L
.75489 4e-05 L
.75544 4e-05 L
.75597 4e-05 L
.75692 4e-05 L
.75779 4e-05 L
.75875 4e-05 L
.75976 4e-05 L
.76062 4e-05 L
.76153 4e-05 L
.76239 4e-05 L
.76317 4e-05 L
.76408 4e-05 L
.76508 4e-05 L
.76602 4e-05 L
.76688 4e-05 L
.76781 4e-05 L
.7688 4e-05 L
.76973 4e-05 L
.77059 4e-05 L
.77159 4e-05 L
.77215 4e-05 L
.77267 4e-05 L
Mistroke
.77363 4e-05 L
.77417 4e-05 L
.77466 4e-05 L
.77517 4e-05 L
.77572 4e-05 L
.77669 4e-05 L
.77724 4e-05 L
.77774 4e-05 L
.7783 4e-05 L
.7789 4e-05 L
.77941 4e-05 L
.77997 4e-05 L
.7805 4e-05 L
.78098 4e-05 L
.7819 4e-05 L
.78288 4e-05 L
.7838 4e-05 L
.78481 4e-05 L
.78576 4e-05 L
.78664 4e-05 L
.78751 4e-05 L
.7883 4e-05 L
.78921 4e-05 L
.79007 4e-05 L
.79102 4e-05 L
.79201 4e-05 L
.79286 4e-05 L
.79379 4e-05 L
.79479 4e-05 L
.79536 4e-05 L
.79587 4e-05 L
.79687 4e-05 L
.79781 4e-05 L
.79862 4e-05 L
.7995 4e-05 L
.80043 4e-05 L
.80129 4e-05 L
.8021 4e-05 L
.80284 4e-05 L
.80366 4e-05 L
.80451 4e-05 L
.80539 4e-05 L
.80632 4e-05 L
.8072 4e-05 L
.808 4e-05 L
.80894 4e-05 L
.80947 4e-05 L
.80995 4e-05 L
.81085 4e-05 L
.81181 4e-05 L
Mistroke
.81273 4e-05 L
.81374 4e-05 L
.81469 4e-05 L
.81557 4e-05 L
.81645 4e-05 L
.81724 4e-05 L
.81816 4e-05 L
.81902 4e-05 L
.81996 4e-05 L
.82096 4e-05 L
.82181 4e-05 L
.82274 4e-05 L
.82375 4e-05 L
.82431 4e-05 L
.82483 4e-05 L
.82582 4e-05 L
.82677 4e-05 L
.82757 4e-05 L
.82846 4e-05 L
.82939 4e-05 L
.83025 4e-05 L
.83106 4e-05 L
.83181 4e-05 L
.83262 4e-05 L
.83348 4e-05 L
.83435 4e-05 L
.83528 4e-05 L
.83616 4e-05 L
.83696 4e-05 L
.8379 4e-05 L
.83843 4e-05 L
.83892 4e-05 L
.83982 4e-05 L
.84077 4e-05 L
.8417 4e-05 L
.84222 4e-05 L
.84271 4e-05 L
.8436 4e-05 L
.84455 4e-05 L
.8454 4e-05 L
.84619 4e-05 L
.84706 4e-05 L
.848 4e-05 L
.84894 4e-05 L
.84947 4e-05 L
.84997 4e-05 L
.85097 4e-05 L
.85154 4e-05 L
.85205 4e-05 L
.85296 4e-05 L
Mistroke
.85396 4e-05 L
.8549 4e-05 L
.85576 4e-05 L
.85657 4e-05 L
.85743 4e-05 L
.85825 4e-05 L
.859 4e-05 L
.85987 4e-05 L
.86083 4e-05 L
.86173 4e-05 L
.86256 4e-05 L
.86351 4e-05 L
.86439 4e-05 L
.86519 4e-05 L
.86605 4e-05 L
.867 4e-05 L
.86799 4e-05 L
.86884 4e-05 L
.86977 4e-05 L
.87045 4e-05 L
.87107 4e-05 L
.87176 4e-05 L
.87248 4e-05 L
.87311 4e-05 L
.8737 4e-05 L
.87435 4e-05 L
.87505 4e-05 L
.87563 4e-05 L
.87627 4e-05 L
.87694 4e-05 L
.87756 4e-05 L
.87814 4e-05 L
.87867 4e-05 L
.87928 4e-05 L
.87986 4e-05 L
.88048 4e-05 L
.88117 4e-05 L
.88188 4e-05 L
.88256 4e-05 L
.88318 4e-05 L
.88375 4e-05 L
.88442 4e-05 L
.88504 4e-05 L
.88572 4e-05 L
.88644 4e-05 L
.88712 4e-05 L
.88773 4e-05 L
.88846 4e-05 L
.88924 4e-05 L
.88998 4e-05 L
Mistroke
.89066 4e-05 L
Mfstroke
.16241 4e-05 m
.19195 .02347 L
.22417 .04921 L
.25443 .07359 L
.28353 .09724 L
.3145 .12263 L
.34432 .14732 L
.37601 .17383 L
.40655 .19968 L
.43592 .22485 L
.46717 .25199 L
.49726 .27852 L
.52619 .30442 L
.557 .33249 L
.58665 .36003 L
.61817 .38998 L
.64853 .41957 L
.67774 .44883 L
.70882 .481 L
.73874 .51319 L
.77054 .54904 L
.80117 .58568 L
.83065 .62357 L
.86201 .66807 L
.89066 .71509 L
s
.93994 4e-05 m
.94001 4e-05 L
.94008 4e-05 L
.94016 4e-05 L
.94023 4e-05 L
.9403 4e-05 L
.94036 4e-05 L
.94043 4e-05 L
.9405 4e-05 L
.94058 4e-05 L
.94065 4e-05 L
.94073 4e-05 L
.9408 4e-05 L
.94088 4e-05 L
.94092 4e-05 L
.94096 4e-05 L
.94104 4e-05 L
.94112 4e-05 L
.94116 4e-05 L
.94121 4e-05 L
.94128 4e-05 L
.94133 4e-05 L
.94137 4e-05 L
.94141 4e-05 L
.94146 4e-05 L
.9415 4e-05 L
.94154 4e-05 L
.94163 4e-05 L
.9417 4e-05 L
.94178 4e-05 L
.94185 4e-05 L
.94191 4e-05 L
.94199 4e-05 L
.94207 4e-05 L
.94214 4e-05 L
.94223 4e-05 L
.9423 4e-05 L
.94237 4e-05 L
.94242 4e-05 L
.94246 4e-05 L
.9425 4e-05 L
.94255 4e-05 L
.94263 4e-05 L
.94268 4e-05 L
.94272 4e-05 L
.9428 4e-05 L
.94287 4e-05 L
.94291 4e-05 L
.94296 4e-05 L
.94304 4e-05 L
Mistroke
.94309 4e-05 L
.94313 4e-05 L
.94317 4e-05 L
.94322 4e-05 L
.94326 4e-05 L
.94331 4e-05 L
.94336 4e-05 L
.94341 4e-05 L
.94345 4e-05 L
.94349 4e-05 L
.94354 4e-05 L
.94358 4e-05 L
.94366 4e-05 L
.94371 4e-05 L
.94375 4e-05 L
.94382 4e-05 L
.9439 4e-05 L
.94397 4e-05 L
.94404 4e-05 L
.94412 4e-05 L
.9442 4e-05 L
.94424 4e-05 L
.94429 4e-05 L
.94437 4e-05 L
.94441 4e-05 L
.94445 4e-05 L
.9445 4e-05 L
.94455 4e-05 L
.94463 4e-05 L
.94467 4e-05 L
.94471 4e-05 L
.94479 4e-05 L
.94487 4e-05 L
.94495 4e-05 L
.94503 4e-05 L
.9451 4e-05 L
.94518 4e-05 L
.94525 4e-05 L
.94532 4e-05 L
.94539 4e-05 L
.94547 4e-05 L
.94551 4e-05 L
.94556 4e-05 L
.94563 4e-05 L
.94568 4e-05 L
.94572 4e-05 L
.94576 4e-05 L
.94581 4e-05 L
.94589 4e-05 L
.94593 4e-05 L
Mistroke
.94597 4e-05 L
.94605 4e-05 L
.94612 4e-05 L
.9462 4e-05 L
.94628 4e-05 L
.94635 4e-05 L
.94642 4e-05 L
.9465 4e-05 L
.94657 4e-05 L
.94664 4e-05 L
.9467 4e-05 L
.94676 4e-05 L
.94684 4e-05 L
.94691 4e-05 L
.94698 4e-05 L
.94706 4e-05 L
.94712 4e-05 L
.9472 4e-05 L
.94725 4e-05 L
.94729 4e-05 L
.94736 4e-05 L
.94744 4e-05 L
.94751 4e-05 L
.94759 4e-05 L
.94767 4e-05 L
.94775 4e-05 L
.94782 4e-05 L
.94789 4e-05 L
.94796 4e-05 L
.94803 4e-05 L
.94811 4e-05 L
.94819 4e-05 L
.94826 4e-05 L
.94834 4e-05 L
.94842 4e-05 L
.94847 4e-05 L
.94851 4e-05 L
.94859 4e-05 L
.94867 4e-05 L
.94874 4e-05 L
.94881 4e-05 L
.94888 4e-05 L
.94896 4e-05 L
.94902 4e-05 L
.94908 4e-05 L
.94915 4e-05 L
.94922 4e-05 L
.94929 4e-05 L
.94937 4e-05 L
.94944 4e-05 L
Mistroke
.94951 4e-05 L
.94958 4e-05 L
.94963 4e-05 L
.94967 4e-05 L
.94974 4e-05 L
.94982 4e-05 L
.9499 4e-05 L
.94998 4e-05 L
.95006 4e-05 L
.95013 4e-05 L
.9502 4e-05 L
.95027 4e-05 L
.95034 4e-05 L
.95041 4e-05 L
.95049 4e-05 L
.95057 4e-05 L
.95064 4e-05 L
.95072 4e-05 L
.9508 4e-05 L
.95085 4e-05 L
.95089 4e-05 L
.95097 4e-05 L
.95105 4e-05 L
.95112 4e-05 L
.95119 4e-05 L
.95127 4e-05 L
.95134 4e-05 L
.95141 4e-05 L
.95147 4e-05 L
.95153 4e-05 L
.9516 4e-05 L
.95168 4e-05 L
.95175 4e-05 L
.95183 4e-05 L
.95189 4e-05 L
.95197 4e-05 L
.95201 4e-05 L
.95205 4e-05 L
.95213 4e-05 L
.95221 4e-05 L
.95228 4e-05 L
.95236 4e-05 L
.95244 4e-05 L
.95252 4e-05 L
.95259 4e-05 L
.95265 4e-05 L
.95273 4e-05 L
.9528 4e-05 L
.95288 4e-05 L
.95296 4e-05 L
Mistroke
.95303 4e-05 L
.95311 4e-05 L
.95319 4e-05 L
.95324 4e-05 L
.95328 4e-05 L
.95336 4e-05 L
.95344 4e-05 L
.9535 4e-05 L
.95358 4e-05 L
.95365 4e-05 L
.95373 4e-05 L
.95379 4e-05 L
.95385 4e-05 L
.95392 4e-05 L
.95399 4e-05 L
.95406 4e-05 L
.95414 4e-05 L
.95421 4e-05 L
.95428 4e-05 L
.95436 4e-05 L
.9544 4e-05 L
.95444 4e-05 L
.95451 4e-05 L
.95459 4e-05 L
.95467 4e-05 L
.95475 4e-05 L
.95483 4e-05 L
.9549 4e-05 L
.95497 4e-05 L
.95504 4e-05 L
.95512 4e-05 L
.95519 4e-05 L
.95527 4e-05 L
.95535 4e-05 L
.95542 4e-05 L
.9555 4e-05 L
.95558 4e-05 L
.95563 4e-05 L
.95567 4e-05 L
.95575 4e-05 L
.95583 4e-05 L
.95589 4e-05 L
.95597 4e-05 L
.95604 4e-05 L
.95612 4e-05 L
.95618 4e-05 L
.95624 4e-05 L
.95631 4e-05 L
.95638 4e-05 L
.95645 4e-05 L
Mistroke
.95653 4e-05 L
.9566 4e-05 L
.95667 4e-05 L
.95675 4e-05 L
.95679 4e-05 L
.95683 4e-05 L
.9569 4e-05 L
.95698 4e-05 L
.95706 4e-05 L
.9571 4e-05 L
.95714 4e-05 L
.95722 4e-05 L
.9573 4e-05 L
.95737 4e-05 L
.95743 4e-05 L
.9575 4e-05 L
.95758 4e-05 L
.95766 4e-05 L
.9577 4e-05 L
.95774 4e-05 L
.95783 4e-05 L
.95787 4e-05 L
.95791 4e-05 L
.95799 4e-05 L
.95807 4e-05 L
.95815 4e-05 L
.95822 4e-05 L
.95829 4e-05 L
.95836 4e-05 L
.95843 4e-05 L
.95849 4e-05 L
.95856 4e-05 L
.95864 4e-05 L
.95871 4e-05 L
.95878 4e-05 L
.95886 4e-05 L
.95893 4e-05 L
.959 4e-05 L
.95907 4e-05 L
.95915 4e-05 L
.95923 4e-05 L
.9593 4e-05 L
.95938 4e-05 L
.95946 4e-05 L
.95954 4e-05 L
.95958 4e-05 L
.95962 4e-05 L
.95966 4e-05 L
.95971 4e-05 L
.95979 4e-05 L
Mistroke
.95986 4e-05 L
.95994 4e-05 L
.96002 4e-05 L
.96009 4e-05 L
.96017 4e-05 L
.96024 4e-05 L
.9603 4e-05 L
.96038 4e-05 L
.96046 4e-05 L
.96054 4e-05 L
.96061 4e-05 L
.96068 4e-05 L
.96077 4e-05 L
.96084 4e-05 L
.96091 4e-05 L
.961 4e-05 L
.96104 4e-05 L
.96109 4e-05 L
.96117 4e-05 L
.96121 4e-05 L
.96125 4e-05 L
.96129 4e-05 L
.96134 4e-05 L
.96142 4e-05 L
.96146 4e-05 L
.9615 4e-05 L
.96155 4e-05 L
.9616 4e-05 L
.96164 4e-05 L
.96169 4e-05 L
.96173 4e-05 L
.96177 4e-05 L
.96185 4e-05 L
.96193 4e-05 L
.962 4e-05 L
.96209 4e-05 L
.96217 4e-05 L
.96224 4e-05 L
.96231 4e-05 L
.96238 4e-05 L
.96245 4e-05 L
.96252 4e-05 L
.9626 4e-05 L
.96268 4e-05 L
.96275 4e-05 L
.96283 4e-05 L
.96291 4e-05 L
.96296 4e-05 L
.963 4e-05 L
.96308 4e-05 L
Mistroke
.96316 4e-05 L
.96323 4e-05 L
.9633 4e-05 L
.96338 4e-05 L
.96345 4e-05 L
.96351 4e-05 L
.96358 4e-05 L
.96364 4e-05 L
.96371 4e-05 L
.96379 4e-05 L
.96386 4e-05 L
.96393 4e-05 L
.964 4e-05 L
.96408 4e-05 L
.96412 4e-05 L
.96416 4e-05 L
.96424 4e-05 L
.96431 4e-05 L
.96439 4e-05 L
.96447 4e-05 L
.96455 4e-05 L
.96463 4e-05 L
.9647 4e-05 L
.96476 4e-05 L
.96484 4e-05 L
.96491 4e-05 L
.96499 4e-05 L
.96507 4e-05 L
.96514 4e-05 L
.96522 4e-05 L
.9653 4e-05 L
.96535 4e-05 L
.96539 4e-05 L
.96547 4e-05 L
.96555 4e-05 L
.96562 4e-05 L
.96569 4e-05 L
.96577 4e-05 L
.96584 4e-05 L
.9659 4e-05 L
.96597 4e-05 L
.96604 4e-05 L
.9661 4e-05 L
.96617 4e-05 L
.96625 4e-05 L
.96632 4e-05 L
.96639 4e-05 L
.96647 4e-05 L
.96651 4e-05 L
.96655 4e-05 L
Mistroke
.96663 4e-05 L
.9667 4e-05 L
.96678 4e-05 L
.96682 4e-05 L
.96686 4e-05 L
.96694 4e-05 L
.96702 4e-05 L
.96709 4e-05 L
.96715 4e-05 L
.96722 4e-05 L
.9673 4e-05 L
.96738 4e-05 L
.96742 4e-05 L
.96746 4e-05 L
.96755 4e-05 L
.96759 4e-05 L
.96763 4e-05 L
.96771 4e-05 L
.96779 4e-05 L
.96787 4e-05 L
.96794 4e-05 L
.96801 4e-05 L
.96808 4e-05 L
.96815 4e-05 L
.96821 4e-05 L
.96828 4e-05 L
.96836 4e-05 L
.96843 4e-05 L
.9685 4e-05 L
.96858 4e-05 L
.96865 4e-05 L
.96872 4e-05 L
.96879 4e-05 L
.96887 4e-05 L
.96895 4e-05 L
.96902 4e-05 L
.9691 4e-05 L
.96918 4e-05 L
.96926 4e-05 L
.9693 4e-05 L
.96934 4e-05 L
.96938 4e-05 L
.96943 4e-05 L
.96951 4e-05 L
.96958 4e-05 L
.96966 4e-05 L
.96974 4e-05 L
.96981 4e-05 L
.96989 4e-05 L
.96996 4e-05 L
Mistroke
.97002 4e-05 L
.9701 4e-05 L
.97018 4e-05 L
.97026 4e-05 L
.97033 4e-05 L
.9704 4e-05 L
.97049 4e-05 L
.97056 4e-05 L
.97063 4e-05 L
.97072 4e-05 L
.97076 4e-05 L
.97081 4e-05 L
.97089 4e-05 L
.97093 4e-05 L
.97097 4e-05 L
.97101 4e-05 L
.97106 4e-05 L
.97114 4e-05 L
.97118 4e-05 L
.97122 4e-05 L
.97127 4e-05 L
.97132 4e-05 L
.97136 4e-05 L
.97141 4e-05 L
.97145 4e-05 L
.97149 4e-05 L
.97157 4e-05 L
.97165 4e-05 L
.97172 4e-05 L
.97181 4e-05 L
.97188 4e-05 L
.97196 4e-05 L
.97203 4e-05 L
.97209 4e-05 L
.97217 4e-05 L
.97224 4e-05 L
.97232 4e-05 L
.9724 4e-05 L
.97247 4e-05 L
.97255 4e-05 L
.97263 4e-05 L
.97268 4e-05 L
.97272 4e-05 L
.9728 4e-05 L
.97288 4e-05 L
.97295 4e-05 L
.97302 4e-05 L
.97309 4e-05 L
.97317 4e-05 L
.97323 4e-05 L
Mistroke
.97329 4e-05 L
.97336 4e-05 L
.97343 4e-05 L
.9735 4e-05 L
.97358 4e-05 L
.97365 4e-05 L
.97372 4e-05 L
.9738 4e-05 L
.97384 4e-05 L
.97388 4e-05 L
.97395 4e-05 L
.97403 4e-05 L
.97411 4e-05 L
.97419 4e-05 L
.97427 4e-05 L
.97434 4e-05 L
.97442 4e-05 L
.97448 4e-05 L
.97456 4e-05 L
.97463 4e-05 L
.97471 4e-05 L
.97479 4e-05 L
.97486 4e-05 L
.97494 4e-05 L
.97502 4e-05 L
.97506 4e-05 L
.97511 4e-05 L
.97519 4e-05 L
.97527 4e-05 L
.97533 4e-05 L
.97541 4e-05 L
.97548 4e-05 L
.97556 4e-05 L
.97562 4e-05 L
.97568 4e-05 L
.97575 4e-05 L
.97582 4e-05 L
.97589 4e-05 L
.97597 4e-05 L
.97604 4e-05 L
.97611 4e-05 L
.97619 4e-05 L
.97623 4e-05 L
.97627 4e-05 L
.97634 4e-05 L
.97642 4e-05 L
.9765 4e-05 L
.97654 4e-05 L
.97658 4e-05 L
.97666 4e-05 L
Mistroke
.97673 4e-05 L
.9768 4e-05 L
.97687 4e-05 L
.97694 4e-05 L
.97702 4e-05 L
.9771 4e-05 L
.97714 4e-05 L
.97718 4e-05 L
.97726 4e-05 L
.97731 4e-05 L
.97735 4e-05 L
.97743 4e-05 L
.97751 4e-05 L
.97759 4e-05 L
.97766 4e-05 L
.97773 4e-05 L
.9778 4e-05 L
.97786 4e-05 L
.97793 4e-05 L
.978 4e-05 L
.97808 4e-05 L
.97815 4e-05 L
.97822 4e-05 L
.9783 4e-05 L
.97837 4e-05 L
.97844 4e-05 L
.97851 4e-05 L
.97859 4e-05 L
.97867 4e-05 L
.97874 4e-05 L
.97881 4e-05 L
.9789 4e-05 L
.97897 4e-05 L
.97901 4e-05 L
.97906 4e-05 L
.9791 4e-05 L
.97914 4e-05 L
.97922 4e-05 L
.9793 4e-05 L
.97937 4e-05 L
.97946 4e-05 L
.97953 4e-05 L
.9796 4e-05 L
.97967 4e-05 L
.97974 4e-05 L
.97981 4e-05 L
.9799 4e-05 L
.97997 4e-05 L
.98005 4e-05 L
.98012 4e-05 L
Mistroke
.9802 4e-05 L
.98028 4e-05 L
.98035 4e-05 L
.98043 4e-05 L
.98048 4e-05 L
.98052 4e-05 L
.9806 4e-05 L
.98064 4e-05 L
.98069 4e-05 L
.98073 4e-05 L
.98077 4e-05 L
.98085 4e-05 L
.9809 4e-05 L
.98094 4e-05 L
.98099 4e-05 L
.98104 4e-05 L
.98108 4e-05 L
.98112 4e-05 L
.98117 4e-05 L
.98121 4e-05 L
.98128 4e-05 L
.98136 4e-05 L
.98144 4e-05 L
.98152 4e-05 L
.9816 4e-05 L
.98167 4e-05 L
.98175 4e-05 L
.98181 4e-05 L
.98189 4e-05 L
.98196 4e-05 L
.98203 4e-05 L
.98212 4e-05 L
.98219 4e-05 L
.98226 4e-05 L
.98235 4e-05 L
.98239 4e-05 L
.98244 4e-05 L
.98252 4e-05 L
.9826 4e-05 L
.98266 4e-05 L
.98273 4e-05 L
.98281 4e-05 L
.98288 4e-05 L
.98295 4e-05 L
.98301 4e-05 L
.98308 4e-05 L
.98315 4e-05 L
.98322 4e-05 L
.9833 4e-05 L
.98337 4e-05 L
Mistroke
.98343 4e-05 L
.98351 4e-05 L
.98356 4e-05 L
.9836 4e-05 L
.98367 4e-05 L
.98375 4e-05 L
.98382 4e-05 L
.98391 4e-05 L
.98399 4e-05 L
.98406 4e-05 L
.98413 4e-05 L
.9842 4e-05 L
.98427 4e-05 L
.98434 4e-05 L
.98442 4e-05 L
.9845 4e-05 L
.98457 4e-05 L
.98465 4e-05 L
.98473 4e-05 L
.98478 4e-05 L
.98482 4e-05 L
.9849 4e-05 L
.98498 4e-05 L
.98505 4e-05 L
.98512 4e-05 L
.9852 4e-05 L
.98527 4e-05 L
.98534 4e-05 L
.9854 4e-05 L
.98547 4e-05 L
.98554 4e-05 L
.98561 4e-05 L
.98568 4e-05 L
.98576 4e-05 L
.98582 4e-05 L
.9859 4e-05 L
.98594 4e-05 L
.98598 4e-05 L
.98606 4e-05 L
.98614 4e-05 L
.98621 4e-05 L
.98626 4e-05 L
.9863 4e-05 L
.98637 4e-05 L
.98645 4e-05 L
.98652 4e-05 L
.98658 4e-05 L
.98666 4e-05 L
.98673 4e-05 L
.98681 4e-05 L
Mistroke
.98685 4e-05 L
.9869 4e-05 L
.98698 4e-05 L
.98702 4e-05 L
.98707 4e-05 L
.98714 4e-05 L
.98722 4e-05 L
.9873 4e-05 L
.98737 4e-05 L
.98744 4e-05 L
.98751 4e-05 L
.98758 4e-05 L
.98764 4e-05 L
.98771 4e-05 L
.98779 4e-05 L
.98786 4e-05 L
.98793 4e-05 L
.98801 4e-05 L
.98808 4e-05 L
.98815 4e-05 L
.98822 4e-05 L
.9883 4e-05 L
.98838 4e-05 L
.98845 4e-05 L
.98853 4e-05 L
.98861 4e-05 L
.98869 4e-05 L
.98873 4e-05 L
.98877 4e-05 L
.98882 4e-05 L
.98886 4e-05 L
.98894 4e-05 L
.98901 4e-05 L
.98909 4e-05 L
.98917 4e-05 L
.98924 4e-05 L
.98932 4e-05 L
.98939 4e-05 L
.98945 4e-05 L
.98953 4e-05 L
.98961 4e-05 L
.98969 4e-05 L
.98976 4e-05 L
.98983 4e-05 L
.98992 4e-05 L
.98999 4e-05 L
.99006 4e-05 L
.99015 4e-05 L
.99019 4e-05 L
.99024 4e-05 L
Mistroke
.99032 4e-05 L
.99036 4e-05 L
.9904 4e-05 L
.99044 4e-05 L
.99049 4e-05 L
.99057 4e-05 L
.99061 4e-05 L
.99065 4e-05 L
.9907 4e-05 L
.99075 4e-05 L
.99079 4e-05 L
.99084 4e-05 L
.99088 4e-05 L
.99092 4e-05 L
.991 4e-05 L
.99108 4e-05 L
.99115 4e-05 L
.99124 4e-05 L
.99131 4e-05 L
.99139 4e-05 L
.99146 4e-05 L
.99152 4e-05 L
.9916 4e-05 L
.99167 4e-05 L
.99175 4e-05 L
.99183 4e-05 L
.9919 4e-05 L
.99198 4e-05 L
.99206 4e-05 L
.99211 4e-05 L
.99215 4e-05 L
.99223 4e-05 L
.99231 4e-05 L
.99237 4e-05 L
.99245 4e-05 L
.99252 4e-05 L
.99259 4e-05 L
.99266 4e-05 L
.99272 4e-05 L
.99279 4e-05 L
.99286 4e-05 L
.99293 4e-05 L
.99301 4e-05 L
.99308 4e-05 L
.99315 4e-05 L
.99322 4e-05 L
.99327 4e-05 L
.99331 4e-05 L
.99338 4e-05 L
.99346 4e-05 L
Mistroke
.99354 4e-05 L
.99362 4e-05 L
.9937 4e-05 L
.99377 4e-05 L
.99384 4e-05 L
.99391 4e-05 L
.99398 4e-05 L
.99406 4e-05 L
.99413 4e-05 L
.99422 4e-05 L
.99429 4e-05 L
.99436 4e-05 L
.99445 4e-05 L
.99449 4e-05 L
.99453 4e-05 L
.99462 4e-05 L
.99469 4e-05 L
.99476 4e-05 L
.99483 4e-05 L
.99491 4e-05 L
.99498 4e-05 L
.99505 4e-05 L
.99511 4e-05 L
.99518 4e-05 L
.99525 4e-05 L
.99532 4e-05 L
.9954 4e-05 L
.99547 4e-05 L
.99553 4e-05 L
.99561 4e-05 L
.99566 4e-05 L
.9957 4e-05 L
.99577 4e-05 L
.99585 4e-05 L
.99592 4e-05 L
.99597 4e-05 L
.99601 4e-05 L
.99608 4e-05 L
.99616 4e-05 L
.99623 4e-05 L
.9963 4e-05 L
.99637 4e-05 L
.99644 4e-05 L
.99652 4e-05 L
.99657 4e-05 L
.99661 4e-05 L
.99669 4e-05 L
.99674 4e-05 L
.99678 4e-05 L
.99685 4e-05 L
Mistroke
.99694 4e-05 L
.99701 4e-05 L
.99708 4e-05 L
.99715 4e-05 L
.99722 4e-05 L
.99729 4e-05 L
.99735 4e-05 L
.99742 4e-05 L
.9975 4e-05 L
.99758 4e-05 L
.99764 4e-05 L
.99772 4e-05 L
.9978 4e-05 L
.99786 4e-05 L
.99793 4e-05 L
.99801 4e-05 L
.99809 4e-05 L
.99816 4e-05 L
.99824 4e-05 L
.99829 4e-05 L
.99835 4e-05 L
.9984 4e-05 L
.99846 4e-05 L
.99851 4e-05 L
.99856 4e-05 L
.99862 4e-05 L
.99867 4e-05 L
.99872 4e-05 L
.99877 4e-05 L
.99883 4e-05 L
.99888 4e-05 L
.99893 4e-05 L
.99897 4e-05 L
.99902 4e-05 L
.99907 4e-05 L
.99912 4e-05 L
.99918 4e-05 L
.99924 4e-05 L
.99929 4e-05 L
.99934 4e-05 L
.99939 4e-05 L
.99945 4e-05 L
.9995 4e-05 L
.99955 4e-05 L
.99961 4e-05 L
.99967 4e-05 L
.99972 4e-05 L
.99978 4e-05 L
.99984 4e-05 L
.9999 4e-05 L
Mistroke
.99996 4e-05 L
Mfstroke
.93994 .99996 m
.94237 .99996 L
.94503 .99996 L
.94752 .99996 L
.94992 .99996 L
.95247 .99996 L
.95493 .99996 L
.95754 .99996 L
.96006 .99996 L
.96248 .99996 L
.96506 .99996 L
.96754 .99996 L
.96992 .99996 L
.97246 .99996 L
.9749 .99996 L
.9775 .99996 L
.98 .99996 L
.98241 .99996 L
.98497 .99996 L
.98744 .99996 L
.99006 .99996 L
.99258 .99996 L
.99501 .99996 L
.9976 .99996 L
.99996 .99996 L
s
.5 1 1 r
.93994 4e-05 m
.94001 4e-05 L
.94008 4e-05 L
.94016 4e-05 L
.94023 4e-05 L
.9403 4e-05 L
.94036 4e-05 L
.94043 4e-05 L
.9405 4e-05 L
.94058 4e-05 L
.94065 4e-05 L
.94073 4e-05 L
.9408 4e-05 L
.94088 4e-05 L
.94092 4e-05 L
.94096 4e-05 L
.94104 4e-05 L
.94112 4e-05 L
.94116 4e-05 L
.94121 4e-05 L
.94128 4e-05 L
.94133 4e-05 L
.94137 4e-05 L
.94141 4e-05 L
.94146 4e-05 L
.9415 4e-05 L
.94154 4e-05 L
.94163 4e-05 L
.9417 4e-05 L
.94178 4e-05 L
.94185 4e-05 L
.94191 4e-05 L
.94199 4e-05 L
.94207 4e-05 L
.94214 4e-05 L
.94223 4e-05 L
.9423 4e-05 L
.94237 4e-05 L
.94242 4e-05 L
.94246 4e-05 L
.9425 4e-05 L
.94255 4e-05 L
.94263 4e-05 L
.94268 4e-05 L
.94272 4e-05 L
.9428 4e-05 L
.94287 4e-05 L
.94291 4e-05 L
.94296 4e-05 L
.94304 4e-05 L
.94309 4e-05 L
.94313 4e-05 L
.94317 4e-05 L
.94322 4e-05 L
.94326 4e-05 L
.94331 4e-05 L
.94336 4e-05 L
.94341 4e-05 L
.94345 4e-05 L
.94349 4e-05 L
.94354 4e-05 L
.94358 4e-05 L
.94366 4e-05 L
.94371 4e-05 L
.94375 4e-05 L
.94382 4e-05 L
.9439 4e-05 L
.94397 4e-05 L
.94404 4e-05 L
.94412 4e-05 L
.9442 4e-05 L
.94424 4e-05 L
.94429 4e-05 L
.94437 4e-05 L
.94441 4e-05 L
.94445 4e-05 L
.9445 4e-05 L
.94455 4e-05 L
.94463 4e-05 L
.94467 4e-05 L
.94471 4e-05 L
.94479 4e-05 L
.94487 4e-05 L
.94495 4e-05 L
.94503 4e-05 L
.9451 4e-05 L
.94518 4e-05 L
.94525 4e-05 L
.94532 4e-05 L
.94539 4e-05 L
.94547 4e-05 L
.94551 4e-05 L
.94556 4e-05 L
.94563 4e-05 L
.94568 4e-05 L
.94572 4e-05 L
.94576 4e-05 L
.94581 4e-05 L
.94589 4e-05 L
.94593 4e-05 L
.94597 4e-05 L
.94605 4e-05 L
.94612 4e-05 L
.9462 4e-05 L
.94628 4e-05 L
.94635 4e-05 L
.94642 4e-05 L
.9465 4e-05 L
.94657 4e-05 L
.94664 4e-05 L
.9467 4e-05 L
.94676 4e-05 L
.94684 4e-05 L
.94691 4e-05 L
.94698 4e-05 L
.94706 4e-05 L
.94712 4e-05 L
.9472 4e-05 L
.94725 4e-05 L
.94729 4e-05 L
.94736 4e-05 L
.94744 4e-05 L
.94751 4e-05 L
.94759 4e-05 L
.94767 4e-05 L
.94775 4e-05 L
.94782 4e-05 L
.94789 4e-05 L
.94796 4e-05 L
.94803 4e-05 L
.94811 4e-05 L
.94819 4e-05 L
.94826 4e-05 L
.94834 4e-05 L
.94842 4e-05 L
.94847 4e-05 L
.94851 4e-05 L
.94859 4e-05 L
.94867 4e-05 L
.94874 4e-05 L
.94881 4e-05 L
.94888 4e-05 L
.94896 4e-05 L
.94902 4e-05 L
.94908 4e-05 L
.94915 4e-05 L
.94922 4e-05 L
.94929 4e-05 L
.94937 4e-05 L
.94944 4e-05 L
.94951 4e-05 L
.94958 4e-05 L
.94963 4e-05 L
.94967 4e-05 L
.94974 4e-05 L
.94982 4e-05 L
.9499 4e-05 L
.94998 4e-05 L
.95006 4e-05 L
.95013 4e-05 L
.9502 4e-05 L
.95027 4e-05 L
.95034 4e-05 L
.95041 4e-05 L
.95049 4e-05 L
.95057 4e-05 L
.95064 4e-05 L
.95072 4e-05 L
.9508 4e-05 L
.95085 4e-05 L
.95089 4e-05 L
.95097 4e-05 L
.95105 4e-05 L
.95112 4e-05 L
.95119 4e-05 L
.95127 4e-05 L
.95134 4e-05 L
.95141 4e-05 L
.95147 4e-05 L
.95153 4e-05 L
.9516 4e-05 L
.95168 4e-05 L
.95175 4e-05 L
.95183 4e-05 L
.95189 4e-05 L
.95197 4e-05 L
.95201 4e-05 L
.95205 4e-05 L
.95213 4e-05 L
.95221 4e-05 L
.95228 4e-05 L
.95236 4e-05 L
.95244 4e-05 L
.95252 4e-05 L
.95259 4e-05 L
.95265 4e-05 L
.95273 4e-05 L
.9528 4e-05 L
.95288 4e-05 L
.95296 4e-05 L
.95303 4e-05 L
.95311 4e-05 L
.95319 4e-05 L
.95324 4e-05 L
.95328 4e-05 L
.95336 4e-05 L
.95344 4e-05 L
.9535 4e-05 L
.95358 4e-05 L
.95365 4e-05 L
.95373 4e-05 L
.95379 4e-05 L
.95385 4e-05 L
.95392 4e-05 L
.95399 4e-05 L
.95406 4e-05 L
.95414 4e-05 L
.95421 4e-05 L
.95428 4e-05 L
.95436 4e-05 L
.9544 4e-05 L
.95444 4e-05 L
.95451 4e-05 L
.95459 4e-05 L
.95467 4e-05 L
.95475 4e-05 L
.95483 4e-05 L
.9549 4e-05 L
.95497 4e-05 L
.95504 4e-05 L
.95512 4e-05 L
.95519 4e-05 L
.95527 4e-05 L
.95535 4e-05 L
.95542 4e-05 L
.9555 4e-05 L
.95558 4e-05 L
.95563 4e-05 L
.95567 4e-05 L
.95575 4e-05 L
.95583 4e-05 L
.95589 4e-05 L
.95597 4e-05 L
.95604 4e-05 L
.95612 4e-05 L
.95618 4e-05 L
.95624 4e-05 L
.95631 4e-05 L
.95638 4e-05 L
.95645 4e-05 L
.95653 4e-05 L
.9566 4e-05 L
.95667 4e-05 L
.95675 4e-05 L
.95679 4e-05 L
.95683 4e-05 L
.9569 4e-05 L
.95698 4e-05 L
.95706 4e-05 L
.9571 4e-05 L
.95714 4e-05 L
.95722 4e-05 L
.9573 4e-05 L
.95737 4e-05 L
.95743 4e-05 L
.9575 4e-05 L
.95758 4e-05 L
.95766 4e-05 L
.9577 4e-05 L
.95774 4e-05 L
.95783 4e-05 L
.95787 4e-05 L
.95791 4e-05 L
.95799 4e-05 L
.95807 4e-05 L
.95815 4e-05 L
.95822 4e-05 L
.95829 4e-05 L
.95836 4e-05 L
.95843 4e-05 L
.95849 4e-05 L
.95856 4e-05 L
.95864 4e-05 L
.95871 4e-05 L
.95878 4e-05 L
.95886 4e-05 L
.95893 4e-05 L
.959 4e-05 L
.95907 4e-05 L
.95915 4e-05 L
.95923 4e-05 L
.9593 4e-05 L
.95938 4e-05 L
.95946 4e-05 L
.95954 4e-05 L
.95958 4e-05 L
.95962 4e-05 L
.95966 4e-05 L
.95971 4e-05 L
.95979 4e-05 L
.95986 4e-05 L
.95994 4e-05 L
.96002 4e-05 L
.96009 4e-05 L
.96017 4e-05 L
.96024 4e-05 L
.9603 4e-05 L
.96038 4e-05 L
.96046 4e-05 L
.96054 4e-05 L
.96061 4e-05 L
.96068 4e-05 L
.96077 4e-05 L
.96084 4e-05 L
.96091 4e-05 L
.961 4e-05 L
.96104 4e-05 L
.96109 4e-05 L
.96117 4e-05 L
.96121 4e-05 L
.96125 4e-05 L
.96129 4e-05 L
.96134 4e-05 L
.96142 4e-05 L
.96146 4e-05 L
.9615 4e-05 L
.96155 4e-05 L
.9616 4e-05 L
.96164 4e-05 L
.96169 4e-05 L
.96173 4e-05 L
.96177 4e-05 L
.96185 4e-05 L
.96193 4e-05 L
.962 4e-05 L
.96209 4e-05 L
.96217 4e-05 L
.96224 4e-05 L
.96231 4e-05 L
.96238 4e-05 L
.96245 4e-05 L
.96252 4e-05 L
.9626 4e-05 L
.96268 4e-05 L
.96275 4e-05 L
.96283 4e-05 L
.96291 4e-05 L
.96296 4e-05 L
.963 4e-05 L
.96308 4e-05 L
.96316 4e-05 L
.96323 4e-05 L
.9633 4e-05 L
.96338 4e-05 L
.96345 4e-05 L
.96351 4e-05 L
.96358 4e-05 L
.96364 4e-05 L
.96371 4e-05 L
.96379 4e-05 L
.96386 4e-05 L
.96393 4e-05 L
.964 4e-05 L
.96408 4e-05 L
.96412 4e-05 L
.96416 4e-05 L
.96424 4e-05 L
.96431 4e-05 L
.96439 4e-05 L
.96447 4e-05 L
.96455 4e-05 L
.96463 4e-05 L
.9647 4e-05 L
.96476 4e-05 L
.96484 4e-05 L
.96491 4e-05 L
.96499 4e-05 L
.96507 4e-05 L
.96514 4e-05 L
.96522 4e-05 L
.9653 4e-05 L
.96535 4e-05 L
.96539 4e-05 L
.96547 4e-05 L
.96555 4e-05 L
.96562 4e-05 L
.96569 4e-05 L
.96577 4e-05 L
.96584 4e-05 L
.9659 4e-05 L
.96597 4e-05 L
.96604 4e-05 L
.9661 4e-05 L
.96617 4e-05 L
.96625 4e-05 L
.96632 4e-05 L
.96639 4e-05 L
.96647 4e-05 L
.96651 4e-05 L
.96655 4e-05 L
.96663 4e-05 L
.9667 4e-05 L
.96678 4e-05 L
.96682 4e-05 L
.96686 4e-05 L
.96694 4e-05 L
.96702 4e-05 L
.96709 4e-05 L
.96715 4e-05 L
.96722 4e-05 L
.9673 4e-05 L
.96738 4e-05 L
.96742 4e-05 L
.96746 4e-05 L
.96755 4e-05 L
.96759 4e-05 L
.96763 4e-05 L
.96771 4e-05 L
.96779 4e-05 L
.96787 4e-05 L
.96794 4e-05 L
.96801 4e-05 L
.96808 4e-05 L
.96815 4e-05 L
.96821 4e-05 L
.96828 4e-05 L
.96836 4e-05 L
.96843 4e-05 L
.9685 4e-05 L
.96858 4e-05 L
.96865 4e-05 L
.96872 4e-05 L
.96879 4e-05 L
.96887 4e-05 L
.96895 4e-05 L
.96902 4e-05 L
.9691 4e-05 L
.96918 4e-05 L
.96926 4e-05 L
.9693 4e-05 L
.96934 4e-05 L
.96938 4e-05 L
.96943 4e-05 L
.96951 4e-05 L
.96958 4e-05 L
.96966 4e-05 L
.96974 4e-05 L
.96981 4e-05 L
.96989 4e-05 L
.96996 4e-05 L
.97002 4e-05 L
.9701 4e-05 L
.97018 4e-05 L
.97026 4e-05 L
.97033 4e-05 L
.9704 4e-05 L
.97049 4e-05 L
.97056 4e-05 L
.97063 4e-05 L
.97072 4e-05 L
.97076 4e-05 L
.97081 4e-05 L
.97089 4e-05 L
.97093 4e-05 L
.97097 4e-05 L
.97101 4e-05 L
.97106 4e-05 L
.97114 4e-05 L
.97118 4e-05 L
.97122 4e-05 L
.97127 4e-05 L
.97132 4e-05 L
.97136 4e-05 L
.97141 4e-05 L
.97145 4e-05 L
.97149 4e-05 L
.97157 4e-05 L
.97165 4e-05 L
.97172 4e-05 L
.97181 4e-05 L
.97188 4e-05 L
.97196 4e-05 L
.97203 4e-05 L
.97209 4e-05 L
.97217 4e-05 L
.97224 4e-05 L
.97232 4e-05 L
.9724 4e-05 L
.97247 4e-05 L
.97255 4e-05 L
.97263 4e-05 L
.97268 4e-05 L
.97272 4e-05 L
.9728 4e-05 L
.97288 4e-05 L
.97295 4e-05 L
.97302 4e-05 L
.97309 4e-05 L
.97317 4e-05 L
.97323 4e-05 L
.97329 4e-05 L
.97336 4e-05 L
.97343 4e-05 L
.9735 4e-05 L
.97358 4e-05 L
.97365 4e-05 L
.97372 4e-05 L
.9738 4e-05 L
.97384 4e-05 L
.97388 4e-05 L
.97395 4e-05 L
.97403 4e-05 L
.97411 4e-05 L
.97419 4e-05 L
.97427 4e-05 L
.97434 4e-05 L
.97442 4e-05 L
.97448 4e-05 L
.97456 4e-05 L
.97463 4e-05 L
.97471 4e-05 L
.97479 4e-05 L
.97486 4e-05 L
.97494 4e-05 L
.97502 4e-05 L
.97506 4e-05 L
.97511 4e-05 L
.97519 4e-05 L
.97527 4e-05 L
.97533 4e-05 L
.97541 4e-05 L
.97548 4e-05 L
.97556 4e-05 L
.97562 4e-05 L
.97568 4e-05 L
.97575 4e-05 L
.97582 4e-05 L
.97589 4e-05 L
.97597 4e-05 L
.97604 4e-05 L
.97611 4e-05 L
.97619 4e-05 L
.97623 4e-05 L
.97627 4e-05 L
.97634 4e-05 L
.97642 4e-05 L
.9765 4e-05 L
.97654 4e-05 L
.97658 4e-05 L
.97666 4e-05 L
.97673 4e-05 L
.9768 4e-05 L
.97687 4e-05 L
.97694 4e-05 L
.97702 4e-05 L
.9771 4e-05 L
.97714 4e-05 L
.97718 4e-05 L
.97726 4e-05 L
.97731 4e-05 L
.97735 4e-05 L
.97743 4e-05 L
.97751 4e-05 L
.97759 4e-05 L
.97766 4e-05 L
.97773 4e-05 L
.9778 4e-05 L
.97786 4e-05 L
.97793 4e-05 L
.978 4e-05 L
.97808 4e-05 L
.97815 4e-05 L
.97822 4e-05 L
.9783 4e-05 L
.97837 4e-05 L
.97844 4e-05 L
.97851 4e-05 L
.97859 4e-05 L
.97867 4e-05 L
.97874 4e-05 L
.97881 4e-05 L
.9789 4e-05 L
.97897 4e-05 L
.97901 4e-05 L
.97906 4e-05 L
.9791 4e-05 L
.97914 4e-05 L
.97922 4e-05 L
.9793 4e-05 L
.97937 4e-05 L
.97946 4e-05 L
.97953 4e-05 L
.9796 4e-05 L
.97967 4e-05 L
.97974 4e-05 L
.97981 4e-05 L
.9799 4e-05 L
.97997 4e-05 L
.98005 4e-05 L
.98012 4e-05 L
.9802 4e-05 L
.98028 4e-05 L
.98035 4e-05 L
.98043 4e-05 L
.98048 4e-05 L
.98052 4e-05 L
.9806 4e-05 L
.98064 4e-05 L
.98069 4e-05 L
.98073 4e-05 L
.98077 4e-05 L
.98085 4e-05 L
.9809 4e-05 L
.98094 4e-05 L
.98099 4e-05 L
.98104 4e-05 L
.98108 4e-05 L
.98112 4e-05 L
.98117 4e-05 L
.98121 4e-05 L
.98128 4e-05 L
.98136 4e-05 L
.98144 4e-05 L
.98152 4e-05 L
.9816 4e-05 L
.98167 4e-05 L
.98175 4e-05 L
.98181 4e-05 L
.98189 4e-05 L
.98196 4e-05 L
.98203 4e-05 L
.98212 4e-05 L
.98219 4e-05 L
.98226 4e-05 L
.98235 4e-05 L
.98239 4e-05 L
.98244 4e-05 L
.98252 4e-05 L
.9826 4e-05 L
.98266 4e-05 L
.98273 4e-05 L
.98281 4e-05 L
.98288 4e-05 L
.98295 4e-05 L
.98301 4e-05 L
.98308 4e-05 L
.98315 4e-05 L
.98322 4e-05 L
.9833 4e-05 L
.98337 4e-05 L
.98343 4e-05 L
.98351 4e-05 L
.98356 4e-05 L
.9836 4e-05 L
.98367 4e-05 L
.98375 4e-05 L
.98382 4e-05 L
.98391 4e-05 L
.98399 4e-05 L
.98406 4e-05 L
.98413 4e-05 L
.9842 4e-05 L
.98427 4e-05 L
.98434 4e-05 L
.98442 4e-05 L
.9845 4e-05 L
.98457 4e-05 L
.98465 4e-05 L
.98473 4e-05 L
.98478 4e-05 L
.98482 4e-05 L
.9849 4e-05 L
.98498 4e-05 L
.98505 4e-05 L
.98512 4e-05 L
.9852 4e-05 L
.98527 4e-05 L
.98534 4e-05 L
.9854 4e-05 L
.98547 4e-05 L
.98554 4e-05 L
.98561 4e-05 L
.98568 4e-05 L
.98576 4e-05 L
.98582 4e-05 L
.9859 4e-05 L
.98594 4e-05 L
.98598 4e-05 L
.98606 4e-05 L
.98614 4e-05 L
.98621 4e-05 L
.98626 4e-05 L
.9863 4e-05 L
.98637 4e-05 L
.98645 4e-05 L
.98652 4e-05 L
.98658 4e-05 L
.98666 4e-05 L
.98673 4e-05 L
.98681 4e-05 L
.98685 4e-05 L
.9869 4e-05 L
.98698 4e-05 L
.98702 4e-05 L
.98707 4e-05 L
.98714 4e-05 L
.98722 4e-05 L
.9873 4e-05 L
.98737 4e-05 L
.98744 4e-05 L
.98751 4e-05 L
.98758 4e-05 L
.98764 4e-05 L
.98771 4e-05 L
.98779 4e-05 L
.98786 4e-05 L
.98793 4e-05 L
.98801 4e-05 L
.98808 4e-05 L
.98815 4e-05 L
.98822 4e-05 L
.9883 4e-05 L
.98838 4e-05 L
.98845 4e-05 L
.98853 4e-05 L
.98861 4e-05 L
.98869 4e-05 L
.98873 4e-05 L
.98877 4e-05 L
.98882 4e-05 L
.98886 4e-05 L
.98894 4e-05 L
.98901 4e-05 L
.98909 4e-05 L
.98917 4e-05 L
.98924 4e-05 L
.98932 4e-05 L
.98939 4e-05 L
.98945 4e-05 L
.98953 4e-05 L
.98961 4e-05 L
.98969 4e-05 L
.98976 4e-05 L
.98983 4e-05 L
.98992 4e-05 L
.98999 4e-05 L
.99006 4e-05 L
.99015 4e-05 L
.99019 4e-05 L
.99024 4e-05 L
.99032 4e-05 L
.99036 4e-05 L
.9904 4e-05 L
.99044 4e-05 L
.99049 4e-05 L
.99057 4e-05 L
.99061 4e-05 L
.99065 4e-05 L
.9907 4e-05 L
.99075 4e-05 L
.99079 4e-05 L
.99084 4e-05 L
.99088 4e-05 L
.99092 4e-05 L
.991 4e-05 L
.99108 4e-05 L
.99115 4e-05 L
.99124 4e-05 L
.99131 4e-05 L
.99139 4e-05 L
.99146 4e-05 L
.99152 4e-05 L
.9916 4e-05 L
.99167 4e-05 L
.99175 4e-05 L
.99183 4e-05 L
.9919 4e-05 L
.99198 4e-05 L
.99206 4e-05 L
.99211 4e-05 L
.99215 4e-05 L
.99223 4e-05 L
.99231 4e-05 L
.99237 4e-05 L
.99245 4e-05 L
.99252 4e-05 L
.99259 4e-05 L
.99266 4e-05 L
.99272 4e-05 L
.99279 4e-05 L
.99286 4e-05 L
.99293 4e-05 L
.99301 4e-05 L
.99308 4e-05 L
.99315 4e-05 L
.99322 4e-05 L
.99327 4e-05 L
.99331 4e-05 L
.99338 4e-05 L
.99346 4e-05 L
.99354 4e-05 L
.99362 4e-05 L
.9937 4e-05 L
.99377 4e-05 L
.99384 4e-05 L
.99391 4e-05 L
.99398 4e-05 L
.99406 4e-05 L
.99413 4e-05 L
.99422 4e-05 L
.99429 4e-05 L
.99436 4e-05 L
.99445 4e-05 L
.99449 4e-05 L
.99453 4e-05 L
.99462 4e-05 L
.99469 4e-05 L
.99476 4e-05 L
.99483 4e-05 L
.99491 4e-05 L
.99498 4e-05 L
.99505 4e-05 L
.99511 4e-05 L
.99518 4e-05 L
.99525 4e-05 L
.99532 4e-05 L
.9954 4e-05 L
.99547 4e-05 L
.99553 4e-05 L
.99561 4e-05 L
.99566 4e-05 L
.9957 4e-05 L
.99577 4e-05 L
.99585 4e-05 L
.99592 4e-05 L
.99597 4e-05 L
.99601 4e-05 L
.99608 4e-05 L
.99616 4e-05 L
.99623 4e-05 L
.9963 4e-05 L
.99637 4e-05 L
.99644 4e-05 L
.99652 4e-05 L
.99657 4e-05 L
.99661 4e-05 L
.99669 4e-05 L
.99674 4e-05 L
.99678 4e-05 L
.99685 4e-05 L
.99694 4e-05 L
.99701 4e-05 L
.99708 4e-05 L
.99715 4e-05 L
.99722 4e-05 L
.99729 4e-05 L
.99735 4e-05 L
.99742 4e-05 L
.9975 4e-05 L
.99758 4e-05 L
.99764 4e-05 L
.99772 4e-05 L
.9978 4e-05 L
.99786 4e-05 L
.99793 4e-05 L
.99801 4e-05 L
.99809 4e-05 L
.99816 4e-05 L
.99824 4e-05 L
.99829 4e-05 L
.99835 4e-05 L
.9984 4e-05 L
.99846 4e-05 L
.99851 4e-05 L
.99856 4e-05 L
.99862 4e-05 L
.99867 4e-05 L
.99872 4e-05 L
.99877 4e-05 L
.99883 4e-05 L
.99888 4e-05 L
.99893 4e-05 L
.99897 4e-05 L
.99902 4e-05 L
.99907 4e-05 L
.99912 4e-05 L
.99918 4e-05 L
.99924 4e-05 L
.99929 4e-05 L
.99934 4e-05 L
.99939 4e-05 L
.99945 4e-05 L
.9995 4e-05 L
.99955 4e-05 L
.99961 4e-05 L
.99967 4e-05 L
.99972 4e-05 L
.99978 4e-05 L
.99984 4e-05 L
.9999 4e-05 L
.99996 4e-05 L
.99996 .99996 L
.9976 .99996 L
.99501 .99996 L
.99258 .99996 L
.99006 .99996 L
.98744 .99996 L
.98497 .99996 L
.98241 .99996 L
.98 .99996 L
.9775 .99996 L
.9749 .99996 L
.97246 .99996 L
.96992 .99996 L
.96754 .99996 L
.96506 .99996 L
.96248 .99996 L
.96006 .99996 L
.95754 .99996 L
.95493 .99996 L
.95247 .99996 L
.94992 .99996 L
.94752 .99996 L
.94503 .99996 L
.94237 .99996 L
.93994 .99996 L
F
0 g
.93994 4e-05 m
.94001 4e-05 L
.94008 4e-05 L
.94016 4e-05 L
.94023 4e-05 L
.9403 4e-05 L
.94036 4e-05 L
.94043 4e-05 L
.9405 4e-05 L
.94058 4e-05 L
.94065 4e-05 L
.94073 4e-05 L
.9408 4e-05 L
.94088 4e-05 L
.94092 4e-05 L
.94096 4e-05 L
.94104 4e-05 L
.94112 4e-05 L
.94116 4e-05 L
.94121 4e-05 L
.94128 4e-05 L
.94133 4e-05 L
.94137 4e-05 L
.94141 4e-05 L
.94146 4e-05 L
.9415 4e-05 L
.94154 4e-05 L
.94163 4e-05 L
.9417 4e-05 L
.94178 4e-05 L
.94185 4e-05 L
.94191 4e-05 L
.94199 4e-05 L
.94207 4e-05 L
.94214 4e-05 L
.94223 4e-05 L
.9423 4e-05 L
.94237 4e-05 L
.94242 4e-05 L
.94246 4e-05 L
.9425 4e-05 L
.94255 4e-05 L
.94263 4e-05 L
.94268 4e-05 L
.94272 4e-05 L
.9428 4e-05 L
.94287 4e-05 L
.94291 4e-05 L
.94296 4e-05 L
.94304 4e-05 L
Mistroke
.94309 4e-05 L
.94313 4e-05 L
.94317 4e-05 L
.94322 4e-05 L
.94326 4e-05 L
.94331 4e-05 L
.94336 4e-05 L
.94341 4e-05 L
.94345 4e-05 L
.94349 4e-05 L
.94354 4e-05 L
.94358 4e-05 L
.94366 4e-05 L
.94371 4e-05 L
.94375 4e-05 L
.94382 4e-05 L
.9439 4e-05 L
.94397 4e-05 L
.94404 4e-05 L
.94412 4e-05 L
.9442 4e-05 L
.94424 4e-05 L
.94429 4e-05 L
.94437 4e-05 L
.94441 4e-05 L
.94445 4e-05 L
.9445 4e-05 L
.94455 4e-05 L
.94463 4e-05 L
.94467 4e-05 L
.94471 4e-05 L
.94479 4e-05 L
.94487 4e-05 L
.94495 4e-05 L
.94503 4e-05 L
.9451 4e-05 L
.94518 4e-05 L
.94525 4e-05 L
.94532 4e-05 L
.94539 4e-05 L
.94547 4e-05 L
.94551 4e-05 L
.94556 4e-05 L
.94563 4e-05 L
.94568 4e-05 L
.94572 4e-05 L
.94576 4e-05 L
.94581 4e-05 L
.94589 4e-05 L
.94593 4e-05 L
Mistroke
.94597 4e-05 L
.94605 4e-05 L
.94612 4e-05 L
.9462 4e-05 L
.94628 4e-05 L
.94635 4e-05 L
.94642 4e-05 L
.9465 4e-05 L
.94657 4e-05 L
.94664 4e-05 L
.9467 4e-05 L
.94676 4e-05 L
.94684 4e-05 L
.94691 4e-05 L
.94698 4e-05 L
.94706 4e-05 L
.94712 4e-05 L
.9472 4e-05 L
.94725 4e-05 L
.94729 4e-05 L
.94736 4e-05 L
.94744 4e-05 L
.94751 4e-05 L
.94759 4e-05 L
.94767 4e-05 L
.94775 4e-05 L
.94782 4e-05 L
.94789 4e-05 L
.94796 4e-05 L
.94803 4e-05 L
.94811 4e-05 L
.94819 4e-05 L
.94826 4e-05 L
.94834 4e-05 L
.94842 4e-05 L
.94847 4e-05 L
.94851 4e-05 L
.94859 4e-05 L
.94867 4e-05 L
.94874 4e-05 L
.94881 4e-05 L
.94888 4e-05 L
.94896 4e-05 L
.94902 4e-05 L
.94908 4e-05 L
.94915 4e-05 L
.94922 4e-05 L
.94929 4e-05 L
.94937 4e-05 L
.94944 4e-05 L
Mistroke
.94951 4e-05 L
.94958 4e-05 L
.94963 4e-05 L
.94967 4e-05 L
.94974 4e-05 L
.94982 4e-05 L
.9499 4e-05 L
.94998 4e-05 L
.95006 4e-05 L
.95013 4e-05 L
.9502 4e-05 L
.95027 4e-05 L
.95034 4e-05 L
.95041 4e-05 L
.95049 4e-05 L
.95057 4e-05 L
.95064 4e-05 L
.95072 4e-05 L
.9508 4e-05 L
.95085 4e-05 L
.95089 4e-05 L
.95097 4e-05 L
.95105 4e-05 L
.95112 4e-05 L
.95119 4e-05 L
.95127 4e-05 L
.95134 4e-05 L
.95141 4e-05 L
.95147 4e-05 L
.95153 4e-05 L
.9516 4e-05 L
.95168 4e-05 L
.95175 4e-05 L
.95183 4e-05 L
.95189 4e-05 L
.95197 4e-05 L
.95201 4e-05 L
.95205 4e-05 L
.95213 4e-05 L
.95221 4e-05 L
.95228 4e-05 L
.95236 4e-05 L
.95244 4e-05 L
.95252 4e-05 L
.95259 4e-05 L
.95265 4e-05 L
.95273 4e-05 L
.9528 4e-05 L
.95288 4e-05 L
.95296 4e-05 L
Mistroke
.95303 4e-05 L
.95311 4e-05 L
.95319 4e-05 L
.95324 4e-05 L
.95328 4e-05 L
.95336 4e-05 L
.95344 4e-05 L
.9535 4e-05 L
.95358 4e-05 L
.95365 4e-05 L
.95373 4e-05 L
.95379 4e-05 L
.95385 4e-05 L
.95392 4e-05 L
.95399 4e-05 L
.95406 4e-05 L
.95414 4e-05 L
.95421 4e-05 L
.95428 4e-05 L
.95436 4e-05 L
.9544 4e-05 L
.95444 4e-05 L
.95451 4e-05 L
.95459 4e-05 L
.95467 4e-05 L
.95475 4e-05 L
.95483 4e-05 L
.9549 4e-05 L
.95497 4e-05 L
.95504 4e-05 L
.95512 4e-05 L
.95519 4e-05 L
.95527 4e-05 L
.95535 4e-05 L
.95542 4e-05 L
.9555 4e-05 L
.95558 4e-05 L
.95563 4e-05 L
.95567 4e-05 L
.95575 4e-05 L
.95583 4e-05 L
.95589 4e-05 L
.95597 4e-05 L
.95604 4e-05 L
.95612 4e-05 L
.95618 4e-05 L
.95624 4e-05 L
.95631 4e-05 L
.95638 4e-05 L
.95645 4e-05 L
Mistroke
.95653 4e-05 L
.9566 4e-05 L
.95667 4e-05 L
.95675 4e-05 L
.95679 4e-05 L
.95683 4e-05 L
.9569 4e-05 L
.95698 4e-05 L
.95706 4e-05 L
.9571 4e-05 L
.95714 4e-05 L
.95722 4e-05 L
.9573 4e-05 L
.95737 4e-05 L
.95743 4e-05 L
.9575 4e-05 L
.95758 4e-05 L
.95766 4e-05 L
.9577 4e-05 L
.95774 4e-05 L
.95783 4e-05 L
.95787 4e-05 L
.95791 4e-05 L
.95799 4e-05 L
.95807 4e-05 L
.95815 4e-05 L
.95822 4e-05 L
.95829 4e-05 L
.95836 4e-05 L
.95843 4e-05 L
.95849 4e-05 L
.95856 4e-05 L
.95864 4e-05 L
.95871 4e-05 L
.95878 4e-05 L
.95886 4e-05 L
.95893 4e-05 L
.959 4e-05 L
.95907 4e-05 L
.95915 4e-05 L
.95923 4e-05 L
.9593 4e-05 L
.95938 4e-05 L
.95946 4e-05 L
.95954 4e-05 L
.95958 4e-05 L
.95962 4e-05 L
.95966 4e-05 L
.95971 4e-05 L
.95979 4e-05 L
Mistroke
.95986 4e-05 L
.95994 4e-05 L
.96002 4e-05 L
.96009 4e-05 L
.96017 4e-05 L
.96024 4e-05 L
.9603 4e-05 L
.96038 4e-05 L
.96046 4e-05 L
.96054 4e-05 L
.96061 4e-05 L
.96068 4e-05 L
.96077 4e-05 L
.96084 4e-05 L
.96091 4e-05 L
.961 4e-05 L
.96104 4e-05 L
.96109 4e-05 L
.96117 4e-05 L
.96121 4e-05 L
.96125 4e-05 L
.96129 4e-05 L
.96134 4e-05 L
.96142 4e-05 L
.96146 4e-05 L
.9615 4e-05 L
.96155 4e-05 L
.9616 4e-05 L
.96164 4e-05 L
.96169 4e-05 L
.96173 4e-05 L
.96177 4e-05 L
.96185 4e-05 L
.96193 4e-05 L
.962 4e-05 L
.96209 4e-05 L
.96217 4e-05 L
.96224 4e-05 L
.96231 4e-05 L
.96238 4e-05 L
.96245 4e-05 L
.96252 4e-05 L
.9626 4e-05 L
.96268 4e-05 L
.96275 4e-05 L
.96283 4e-05 L
.96291 4e-05 L
.96296 4e-05 L
.963 4e-05 L
.96308 4e-05 L
Mistroke
.96316 4e-05 L
.96323 4e-05 L
.9633 4e-05 L
.96338 4e-05 L
.96345 4e-05 L
.96351 4e-05 L
.96358 4e-05 L
.96364 4e-05 L
.96371 4e-05 L
.96379 4e-05 L
.96386 4e-05 L
.96393 4e-05 L
.964 4e-05 L
.96408 4e-05 L
.96412 4e-05 L
.96416 4e-05 L
.96424 4e-05 L
.96431 4e-05 L
.96439 4e-05 L
.96447 4e-05 L
.96455 4e-05 L
.96463 4e-05 L
.9647 4e-05 L
.96476 4e-05 L
.96484 4e-05 L
.96491 4e-05 L
.96499 4e-05 L
.96507 4e-05 L
.96514 4e-05 L
.96522 4e-05 L
.9653 4e-05 L
.96535 4e-05 L
.96539 4e-05 L
.96547 4e-05 L
.96555 4e-05 L
.96562 4e-05 L
.96569 4e-05 L
.96577 4e-05 L
.96584 4e-05 L
.9659 4e-05 L
.96597 4e-05 L
.96604 4e-05 L
.9661 4e-05 L
.96617 4e-05 L
.96625 4e-05 L
.96632 4e-05 L
.96639 4e-05 L
.96647 4e-05 L
.96651 4e-05 L
.96655 4e-05 L
Mistroke
.96663 4e-05 L
.9667 4e-05 L
.96678 4e-05 L
.96682 4e-05 L
.96686 4e-05 L
.96694 4e-05 L
.96702 4e-05 L
.96709 4e-05 L
.96715 4e-05 L
.96722 4e-05 L
.9673 4e-05 L
.96738 4e-05 L
.96742 4e-05 L
.96746 4e-05 L
.96755 4e-05 L
.96759 4e-05 L
.96763 4e-05 L
.96771 4e-05 L
.96779 4e-05 L
.96787 4e-05 L
.96794 4e-05 L
.96801 4e-05 L
.96808 4e-05 L
.96815 4e-05 L
.96821 4e-05 L
.96828 4e-05 L
.96836 4e-05 L
.96843 4e-05 L
.9685 4e-05 L
.96858 4e-05 L
.96865 4e-05 L
.96872 4e-05 L
.96879 4e-05 L
.96887 4e-05 L
.96895 4e-05 L
.96902 4e-05 L
.9691 4e-05 L
.96918 4e-05 L
.96926 4e-05 L
.9693 4e-05 L
.96934 4e-05 L
.96938 4e-05 L
.96943 4e-05 L
.96951 4e-05 L
.96958 4e-05 L
.96966 4e-05 L
.96974 4e-05 L
.96981 4e-05 L
.96989 4e-05 L
.96996 4e-05 L
Mistroke
.97002 4e-05 L
.9701 4e-05 L
.97018 4e-05 L
.97026 4e-05 L
.97033 4e-05 L
.9704 4e-05 L
.97049 4e-05 L
.97056 4e-05 L
.97063 4e-05 L
.97072 4e-05 L
.97076 4e-05 L
.97081 4e-05 L
.97089 4e-05 L
.97093 4e-05 L
.97097 4e-05 L
.97101 4e-05 L
.97106 4e-05 L
.97114 4e-05 L
.97118 4e-05 L
.97122 4e-05 L
.97127 4e-05 L
.97132 4e-05 L
.97136 4e-05 L
.97141 4e-05 L
.97145 4e-05 L
.97149 4e-05 L
.97157 4e-05 L
.97165 4e-05 L
.97172 4e-05 L
.97181 4e-05 L
.97188 4e-05 L
.97196 4e-05 L
.97203 4e-05 L
.97209 4e-05 L
.97217 4e-05 L
.97224 4e-05 L
.97232 4e-05 L
.9724 4e-05 L
.97247 4e-05 L
.97255 4e-05 L
.97263 4e-05 L
.97268 4e-05 L
.97272 4e-05 L
.9728 4e-05 L
.97288 4e-05 L
.97295 4e-05 L
.97302 4e-05 L
.97309 4e-05 L
.97317 4e-05 L
.97323 4e-05 L
Mistroke
.97329 4e-05 L
.97336 4e-05 L
.97343 4e-05 L
.9735 4e-05 L
.97358 4e-05 L
.97365 4e-05 L
.97372 4e-05 L
.9738 4e-05 L
.97384 4e-05 L
.97388 4e-05 L
.97395 4e-05 L
.97403 4e-05 L
.97411 4e-05 L
.97419 4e-05 L
.97427 4e-05 L
.97434 4e-05 L
.97442 4e-05 L
.97448 4e-05 L
.97456 4e-05 L
.97463 4e-05 L
.97471 4e-05 L
.97479 4e-05 L
.97486 4e-05 L
.97494 4e-05 L
.97502 4e-05 L
.97506 4e-05 L
.97511 4e-05 L
.97519 4e-05 L
.97527 4e-05 L
.97533 4e-05 L
.97541 4e-05 L
.97548 4e-05 L
.97556 4e-05 L
.97562 4e-05 L
.97568 4e-05 L
.97575 4e-05 L
.97582 4e-05 L
.97589 4e-05 L
.97597 4e-05 L
.97604 4e-05 L
.97611 4e-05 L
.97619 4e-05 L
.97623 4e-05 L
.97627 4e-05 L
.97634 4e-05 L
.97642 4e-05 L
.9765 4e-05 L
.97654 4e-05 L
.97658 4e-05 L
.97666 4e-05 L
Mistroke
.97673 4e-05 L
.9768 4e-05 L
.97687 4e-05 L
.97694 4e-05 L
.97702 4e-05 L
.9771 4e-05 L
.97714 4e-05 L
.97718 4e-05 L
.97726 4e-05 L
.97731 4e-05 L
.97735 4e-05 L
.97743 4e-05 L
.97751 4e-05 L
.97759 4e-05 L
.97766 4e-05 L
.97773 4e-05 L
.9778 4e-05 L
.97786 4e-05 L
.97793 4e-05 L
.978 4e-05 L
.97808 4e-05 L
.97815 4e-05 L
.97822 4e-05 L
.9783 4e-05 L
.97837 4e-05 L
.97844 4e-05 L
.97851 4e-05 L
.97859 4e-05 L
.97867 4e-05 L
.97874 4e-05 L
.97881 4e-05 L
.9789 4e-05 L
.97897 4e-05 L
.97901 4e-05 L
.97906 4e-05 L
.9791 4e-05 L
.97914 4e-05 L
.97922 4e-05 L
.9793 4e-05 L
.97937 4e-05 L
.97946 4e-05 L
.97953 4e-05 L
.9796 4e-05 L
.97967 4e-05 L
.97974 4e-05 L
.97981 4e-05 L
.9799 4e-05 L
.97997 4e-05 L
.98005 4e-05 L
.98012 4e-05 L
Mistroke
.9802 4e-05 L
.98028 4e-05 L
.98035 4e-05 L
.98043 4e-05 L
.98048 4e-05 L
.98052 4e-05 L
.9806 4e-05 L
.98064 4e-05 L
.98069 4e-05 L
.98073 4e-05 L
.98077 4e-05 L
.98085 4e-05 L
.9809 4e-05 L
.98094 4e-05 L
.98099 4e-05 L
.98104 4e-05 L
.98108 4e-05 L
.98112 4e-05 L
.98117 4e-05 L
.98121 4e-05 L
.98128 4e-05 L
.98136 4e-05 L
.98144 4e-05 L
.98152 4e-05 L
.9816 4e-05 L
.98167 4e-05 L
.98175 4e-05 L
.98181 4e-05 L
.98189 4e-05 L
.98196 4e-05 L
.98203 4e-05 L
.98212 4e-05 L
.98219 4e-05 L
.98226 4e-05 L
.98235 4e-05 L
.98239 4e-05 L
.98244 4e-05 L
.98252 4e-05 L
.9826 4e-05 L
.98266 4e-05 L
.98273 4e-05 L
.98281 4e-05 L
.98288 4e-05 L
.98295 4e-05 L
.98301 4e-05 L
.98308 4e-05 L
.98315 4e-05 L
.98322 4e-05 L
.9833 4e-05 L
.98337 4e-05 L
Mistroke
.98343 4e-05 L
.98351 4e-05 L
.98356 4e-05 L
.9836 4e-05 L
.98367 4e-05 L
.98375 4e-05 L
.98382 4e-05 L
.98391 4e-05 L
.98399 4e-05 L
.98406 4e-05 L
.98413 4e-05 L
.9842 4e-05 L
.98427 4e-05 L
.98434 4e-05 L
.98442 4e-05 L
.9845 4e-05 L
.98457 4e-05 L
.98465 4e-05 L
.98473 4e-05 L
.98478 4e-05 L
.98482 4e-05 L
.9849 4e-05 L
.98498 4e-05 L
.98505 4e-05 L
.98512 4e-05 L
.9852 4e-05 L
.98527 4e-05 L
.98534 4e-05 L
.9854 4e-05 L
.98547 4e-05 L
.98554 4e-05 L
.98561 4e-05 L
.98568 4e-05 L
.98576 4e-05 L
.98582 4e-05 L
.9859 4e-05 L
.98594 4e-05 L
.98598 4e-05 L
.98606 4e-05 L
.98614 4e-05 L
.98621 4e-05 L
.98626 4e-05 L
.9863 4e-05 L
.98637 4e-05 L
.98645 4e-05 L
.98652 4e-05 L
.98658 4e-05 L
.98666 4e-05 L
.98673 4e-05 L
.98681 4e-05 L
Mistroke
.98685 4e-05 L
.9869 4e-05 L
.98698 4e-05 L
.98702 4e-05 L
.98707 4e-05 L
.98714 4e-05 L
.98722 4e-05 L
.9873 4e-05 L
.98737 4e-05 L
.98744 4e-05 L
.98751 4e-05 L
.98758 4e-05 L
.98764 4e-05 L
.98771 4e-05 L
.98779 4e-05 L
.98786 4e-05 L
.98793 4e-05 L
.98801 4e-05 L
.98808 4e-05 L
.98815 4e-05 L
.98822 4e-05 L
.9883 4e-05 L
.98838 4e-05 L
.98845 4e-05 L
.98853 4e-05 L
.98861 4e-05 L
.98869 4e-05 L
.98873 4e-05 L
.98877 4e-05 L
.98882 4e-05 L
.98886 4e-05 L
.98894 4e-05 L
.98901 4e-05 L
.98909 4e-05 L
.98917 4e-05 L
.98924 4e-05 L
.98932 4e-05 L
.98939 4e-05 L
.98945 4e-05 L
.98953 4e-05 L
.98961 4e-05 L
.98969 4e-05 L
.98976 4e-05 L
.98983 4e-05 L
.98992 4e-05 L
.98999 4e-05 L
.99006 4e-05 L
.99015 4e-05 L
.99019 4e-05 L
.99024 4e-05 L
Mistroke
.99032 4e-05 L
.99036 4e-05 L
.9904 4e-05 L
.99044 4e-05 L
.99049 4e-05 L
.99057 4e-05 L
.99061 4e-05 L
.99065 4e-05 L
.9907 4e-05 L
.99075 4e-05 L
.99079 4e-05 L
.99084 4e-05 L
.99088 4e-05 L
.99092 4e-05 L
.991 4e-05 L
.99108 4e-05 L
.99115 4e-05 L
.99124 4e-05 L
.99131 4e-05 L
.99139 4e-05 L
.99146 4e-05 L
.99152 4e-05 L
.9916 4e-05 L
.99167 4e-05 L
.99175 4e-05 L
.99183 4e-05 L
.9919 4e-05 L
.99198 4e-05 L
.99206 4e-05 L
.99211 4e-05 L
.99215 4e-05 L
.99223 4e-05 L
.99231 4e-05 L
.99237 4e-05 L
.99245 4e-05 L
.99252 4e-05 L
.99259 4e-05 L
.99266 4e-05 L
.99272 4e-05 L
.99279 4e-05 L
.99286 4e-05 L
.99293 4e-05 L
.99301 4e-05 L
.99308 4e-05 L
.99315 4e-05 L
.99322 4e-05 L
.99327 4e-05 L
.99331 4e-05 L
.99338 4e-05 L
.99346 4e-05 L
Mistroke
.99354 4e-05 L
.99362 4e-05 L
.9937 4e-05 L
.99377 4e-05 L
.99384 4e-05 L
.99391 4e-05 L
.99398 4e-05 L
.99406 4e-05 L
.99413 4e-05 L
.99422 4e-05 L
.99429 4e-05 L
.99436 4e-05 L
.99445 4e-05 L
.99449 4e-05 L
.99453 4e-05 L
.99462 4e-05 L
.99469 4e-05 L
.99476 4e-05 L
.99483 4e-05 L
.99491 4e-05 L
.99498 4e-05 L
.99505 4e-05 L
.99511 4e-05 L
.99518 4e-05 L
.99525 4e-05 L
.99532 4e-05 L
.9954 4e-05 L
.99547 4e-05 L
.99553 4e-05 L
.99561 4e-05 L
.99566 4e-05 L
.9957 4e-05 L
.99577 4e-05 L
.99585 4e-05 L
.99592 4e-05 L
.99597 4e-05 L
.99601 4e-05 L
.99608 4e-05 L
.99616 4e-05 L
.99623 4e-05 L
.9963 4e-05 L
.99637 4e-05 L
.99644 4e-05 L
.99652 4e-05 L
.99657 4e-05 L
.99661 4e-05 L
.99669 4e-05 L
.99674 4e-05 L
.99678 4e-05 L
.99685 4e-05 L
Mistroke
.99694 4e-05 L
.99701 4e-05 L
.99708 4e-05 L
.99715 4e-05 L
.99722 4e-05 L
.99729 4e-05 L
.99735 4e-05 L
.99742 4e-05 L
.9975 4e-05 L
.99758 4e-05 L
.99764 4e-05 L
.99772 4e-05 L
.9978 4e-05 L
.99786 4e-05 L
.99793 4e-05 L
.99801 4e-05 L
.99809 4e-05 L
.99816 4e-05 L
.99824 4e-05 L
.99829 4e-05 L
.99835 4e-05 L
.9984 4e-05 L
.99846 4e-05 L
.99851 4e-05 L
.99856 4e-05 L
.99862 4e-05 L
.99867 4e-05 L
.99872 4e-05 L
.99877 4e-05 L
.99883 4e-05 L
.99888 4e-05 L
.99893 4e-05 L
.99897 4e-05 L
.99902 4e-05 L
.99907 4e-05 L
.99912 4e-05 L
.99918 4e-05 L
.99924 4e-05 L
.99929 4e-05 L
.99934 4e-05 L
.99939 4e-05 L
.99945 4e-05 L
.9995 4e-05 L
.99955 4e-05 L
.99961 4e-05 L
.99967 4e-05 L
.99972 4e-05 L
.99978 4e-05 L
.99984 4e-05 L
.9999 4e-05 L
Mistroke
.99996 4e-05 L
Mfstroke
.93994 .99996 m
.94237 .99996 L
.94503 .99996 L
.94752 .99996 L
.94992 .99996 L
.95247 .99996 L
.95493 .99996 L
.95754 .99996 L
.96006 .99996 L
.96248 .99996 L
.96506 .99996 L
.96754 .99996 L
.96992 .99996 L
.97246 .99996 L
.9749 .99996 L
.9775 .99996 L
.98 .99996 L
.98241 .99996 L
.98497 .99996 L
.98744 .99996 L
.99006 .99996 L
.99258 .99996 L
.99501 .99996 L
.9976 .99996 L
.99996 .99996 L
s
.89066 .99996 m
.89266 .99769 L
.89484 .99515 L
.89689 .99269 L
.89886 .99025 L
.90095 .98758 L
.90297 .98492 L
.90512 .982 L
.90718 .97907 L
.90917 .97615 L
.91128 .97292 L
.91332 .96967 L
.91528 .9664 L
.91736 .96275 L
.91937 .95904 L
.9215 .95486 L
.92355 .95056 L
.92553 .94612 L
.92763 .941 L
.92966 .93558 L
.93181 .92913 L
.93388 .92194 L
.93588 .91361 L
.93689 .90852 L
.938 .90175 L
.93848 .89816 L
.939 .89352 L
.93925 .89077 L
.93949 .88764 L
.9397 .88396 L
.93976 .88267 L
.93982 .88102 L
.93988 .87917 L
.93994 .87434 L
s
.89066 .99996 m
.89266 .99996 L
.89484 .99996 L
.89689 .99996 L
.89886 .99996 L
.90095 .99996 L
.90297 .99996 L
.90512 .99996 L
.90718 .99996 L
.90917 .99996 L
.91128 .99996 L
.91332 .99996 L
.91528 .99996 L
.91736 .99996 L
.91937 .99996 L
.9215 .99996 L
.92355 .99996 L
.92553 .99996 L
.92763 .99996 L
.92966 .99996 L
.93181 .99996 L
.93388 .99996 L
.93588 .99996 L
.938 .99996 L
.93994 .99996 L
s
.5 1 1 r
.89066 .99996 m
.89266 .99769 L
.89484 .99515 L
.89689 .99269 L
.89886 .99025 L
.90095 .98758 L
.90297 .98492 L
.90512 .982 L
.90718 .97907 L
.90917 .97615 L
.91128 .97292 L
.91332 .96967 L
.91528 .9664 L
.91736 .96275 L
.91937 .95904 L
.9215 .95486 L
.92355 .95056 L
.92553 .94612 L
.92763 .941 L
.92966 .93558 L
.93181 .92913 L
.93388 .92194 L
.93588 .91361 L
.93689 .90852 L
.938 .90175 L
.93848 .89816 L
.939 .89352 L
.93925 .89077 L
.93949 .88764 L
.9397 .88396 L
.93976 .88267 L
.93982 .88102 L
.93988 .87917 L
.93994 .87434 L
.93994 .99996 L
.938 .99996 L
.93588 .99996 L
.93388 .99996 L
.93181 .99996 L
.92966 .99996 L
.92763 .99996 L
.92553 .99996 L
.92355 .99996 L
.9215 .99996 L
.91937 .99996 L
.91736 .99996 L
.91528 .99996 L
.91332 .99996 L
.91128 .99996 L
.90917 .99996 L
.90718 .99996 L
.90512 .99996 L
.90297 .99996 L
.90095 .99996 L
.89886 .99996 L
.89689 .99996 L
.89484 .99996 L
.89266 .99996 L
.89066 .99996 L
F
0 g
.89066 .99996 m
.89266 .99769 L
.89484 .99515 L
.89689 .99269 L
.89886 .99025 L
.90095 .98758 L
.90297 .98492 L
.90512 .982 L
.90718 .97907 L
.90917 .97615 L
.91128 .97292 L
.91332 .96967 L
.91528 .9664 L
.91736 .96275 L
.91937 .95904 L
.9215 .95486 L
.92355 .95056 L
.92553 .94612 L
.92763 .941 L
.92966 .93558 L
.93181 .92913 L
.93388 .92194 L
.93588 .91361 L
.93689 .90852 L
.938 .90175 L
.93848 .89816 L
.939 .89352 L
.93925 .89077 L
.93949 .88764 L
.9397 .88396 L
.93976 .88267 L
.93982 .88102 L
.93988 .87917 L
.93994 .87434 L
s
.89066 .99996 m
.89266 .99996 L
.89484 .99996 L
.89689 .99996 L
.89886 .99996 L
.90095 .99996 L
.90297 .99996 L
.90512 .99996 L
.90718 .99996 L
.90917 .99996 L
.91128 .99996 L
.91332 .99996 L
.91528 .99996 L
.91736 .99996 L
.91937 .99996 L
.9215 .99996 L
.92355 .99996 L
.92553 .99996 L
.92763 .99996 L
.92966 .99996 L
.93181 .99996 L
.93388 .99996 L
.93588 .99996 L
.938 .99996 L
.93994 .99996 L
s
4e-05 4e-05 m
.00024 4e-05 L
.00042 4e-05 L
.00063 4e-05 L
.00083 4e-05 L
.00102 4e-05 L
.00119 4e-05 L
.00137 4e-05 L
.00157 4e-05 L
.00177 4e-05 L
.00198 4e-05 L
.00218 4e-05 L
.00237 4e-05 L
.00258 4e-05 L
.0027 4e-05 L
.00282 4e-05 L
.00302 4e-05 L
.00325 4e-05 L
.00336 4e-05 L
.00347 4e-05 L
.00368 4e-05 L
.0038 4e-05 L
.00391 4e-05 L
.00403 4e-05 L
.00416 4e-05 L
.00427 4e-05 L
.00439 4e-05 L
.00461 4e-05 L
.00482 4e-05 L
.00502 4e-05 L
.00521 4e-05 L
.00539 4e-05 L
.00559 4e-05 L
.0058 4e-05 L
.00601 4e-05 L
.00623 4e-05 L
.00642 4e-05 L
.00663 4e-05 L
.00675 4e-05 L
.00686 4e-05 L
.00698 4e-05 L
.00711 4e-05 L
.00733 4e-05 L
.00745 4e-05 L
.00757 4e-05 L
.00778 4e-05 L
.00798 4e-05 L
.00809 4e-05 L
.00821 4e-05 L
.00843 4e-05 L
Mistroke
.00856 4e-05 L
.00868 4e-05 L
.00879 4e-05 L
.00891 4e-05 L
.00904 4e-05 L
.00918 4e-05 L
.00929 4e-05 L
.00942 4e-05 L
.00954 4e-05 L
.00965 4e-05 L
.00978 4e-05 L
.0099 4e-05 L
.01011 4e-05 L
.01024 4e-05 L
.01035 4e-05 L
.01055 4e-05 L
.01076 4e-05 L
.01096 4e-05 L
.01115 4e-05 L
.01135 4e-05 L
.01158 4e-05 L
.01169 4e-05 L
.01181 4e-05 L
.01203 4e-05 L
.01215 4e-05 L
.01226 4e-05 L
.01238 4e-05 L
.01251 4e-05 L
.01272 4e-05 L
.01285 4e-05 L
.01296 4e-05 L
.01318 4e-05 L
.01337 4e-05 L
.0136 4e-05 L
.01381 4e-05 L
.014 4e-05 L
.01421 4e-05 L
.01441 4e-05 L
.01459 4e-05 L
.01479 4e-05 L
.01501 4e-05 L
.01512 4e-05 L
.01524 4e-05 L
.01545 4e-05 L
.01557 4e-05 L
.01568 4e-05 L
.0158 4e-05 L
.01592 4e-05 L
.01613 4e-05 L
.01625 4e-05 L
Mistroke
.01637 4e-05 L
.01658 4e-05 L
.01677 4e-05 L
.01699 4e-05 L
.0172 4e-05 L
.0174 4e-05 L
.01758 4e-05 L
.01778 4e-05 L
.01798 4e-05 L
.01816 4e-05 L
.01833 4e-05 L
.01851 4e-05 L
.0187 4e-05 L
.0189 4e-05 L
.0191 4e-05 L
.0193 4e-05 L
.01948 4e-05 L
.01969 4e-05 L
.01981 4e-05 L
.01992 4e-05 L
.02012 4e-05 L
.02034 4e-05 L
.02053 4e-05 L
.02075 4e-05 L
.02097 4e-05 L
.02117 4e-05 L
.02137 4e-05 L
.02154 4e-05 L
.02175 4e-05 L
.02194 4e-05 L
.02215 4e-05 L
.02237 4e-05 L
.02256 4e-05 L
.02276 4e-05 L
.02299 4e-05 L
.02311 4e-05 L
.02323 4e-05 L
.02345 4e-05 L
.02366 4e-05 L
.02386 4e-05 L
.02404 4e-05 L
.02424 4e-05 L
.02443 4e-05 L
.02461 4e-05 L
.02478 4e-05 L
.02496 4e-05 L
.02515 4e-05 L
.02535 4e-05 L
.02555 4e-05 L
.02575 4e-05 L
Mistroke
.02593 4e-05 L
.02614 4e-05 L
.02626 4e-05 L
.02636 4e-05 L
.02657 4e-05 L
.02678 4e-05 L
.02698 4e-05 L
.02721 4e-05 L
.02742 4e-05 L
.02761 4e-05 L
.02781 4e-05 L
.02799 4e-05 L
.02819 4e-05 L
.02838 4e-05 L
.02859 4e-05 L
.02881 4e-05 L
.029 4e-05 L
.02921 4e-05 L
.02943 4e-05 L
.02956 4e-05 L
.02967 4e-05 L
.0299 4e-05 L
.03011 4e-05 L
.03029 4e-05 L
.03048 4e-05 L
.03069 4e-05 L
.03088 4e-05 L
.03106 4e-05 L
.03123 4e-05 L
.03141 4e-05 L
.0316 4e-05 L
.03179 4e-05 L
.032 4e-05 L
.0322 4e-05 L
.03238 4e-05 L
.03259 4e-05 L
.0327 4e-05 L
.03281 4e-05 L
.03301 4e-05 L
.03323 4e-05 L
.03343 4e-05 L
.03366 4e-05 L
.03387 4e-05 L
.03407 4e-05 L
.03426 4e-05 L
.03444 4e-05 L
.03464 4e-05 L
.03483 4e-05 L
.03504 4e-05 L
.03527 4e-05 L
Mistroke
.03546 4e-05 L
.03566 4e-05 L
.03589 4e-05 L
.03601 4e-05 L
.03613 4e-05 L
.03635 4e-05 L
.03656 4e-05 L
.03674 4e-05 L
.03694 4e-05 L
.03715 4e-05 L
.03734 4e-05 L
.03752 4e-05 L
.03768 4e-05 L
.03787 4e-05 L
.03806 4e-05 L
.03825 4e-05 L
.03846 4e-05 L
.03866 4e-05 L
.03883 4e-05 L
.03904 4e-05 L
.03916 4e-05 L
.03927 4e-05 L
.03947 4e-05 L
.03968 4e-05 L
.03989 4e-05 L
.04012 4e-05 L
.04033 4e-05 L
.04053 4e-05 L
.0407 4e-05 L
.0409 4e-05 L
.0411 4e-05 L
.0413 4e-05 L
.04151 4e-05 L
.04173 4e-05 L
.04192 4e-05 L
.04213 4e-05 L
.04235 4e-05 L
.04248 4e-05 L
.04259 4e-05 L
.04281 4e-05 L
.04303 4e-05 L
.04321 4e-05 L
.0434 4e-05 L
.04361 4e-05 L
.0438 4e-05 L
.04399 4e-05 L
.04415 4e-05 L
.04434 4e-05 L
.04452 4e-05 L
.04472 4e-05 L
Mistroke
.04493 4e-05 L
.04512 4e-05 L
.0453 4e-05 L
.04551 4e-05 L
.04563 4e-05 L
.04574 4e-05 L
.04594 4e-05 L
.04615 4e-05 L
.04636 4e-05 L
.04647 4e-05 L
.04658 4e-05 L
.04678 4e-05 L
.04699 4e-05 L
.04718 4e-05 L
.04736 4e-05 L
.04756 4e-05 L
.04777 4e-05 L
.04798 4e-05 L
.0481 4e-05 L
.04821 4e-05 L
.04843 4e-05 L
.04856 4e-05 L
.04867 4e-05 L
.04887 4e-05 L
.0491 4e-05 L
.04931 4e-05 L
.0495 4e-05 L
.04968 4e-05 L
.04987 4e-05 L
.05005 4e-05 L
.05022 4e-05 L
.05042 4e-05 L
.05063 4e-05 L
.05083 4e-05 L
.05102 4e-05 L
.05123 4e-05 L
.05143 4e-05 L
.0516 4e-05 L
.0518 4e-05 L
.05201 4e-05 L
.05223 4e-05 L
.05242 4e-05 L
.05262 4e-05 L
.05285 4e-05 L
.05305 4e-05 L
.05316 4e-05 L
.05328 4e-05 L
.0534 4e-05 L
.05352 4e-05 L
.05373 4e-05 L
Mistroke
.05393 4e-05 L
.05415 4e-05 L
.05437 4e-05 L
.05456 4e-05 L
.05476 4e-05 L
.05495 4e-05 L
.05513 4e-05 L
.05533 4e-05 L
.05556 4e-05 L
.05576 4e-05 L
.05596 4e-05 L
.05616 4e-05 L
.05639 4e-05 L
.05659 4e-05 L
.05678 4e-05 L
.05701 4e-05 L
.05713 4e-05 L
.05725 4e-05 L
.05746 4e-05 L
.05757 4e-05 L
.05769 4e-05 L
.05781 4e-05 L
.05793 4e-05 L
.05815 4e-05 L
.05827 4e-05 L
.05838 4e-05 L
.05851 4e-05 L
.05864 4e-05 L
.05875 4e-05 L
.05888 4e-05 L
.05899 4e-05 L
.0591 4e-05 L
.05931 4e-05 L
.05953 4e-05 L
.05973 4e-05 L
.05996 4e-05 L
.06017 4e-05 L
.06037 4e-05 L
.06056 4e-05 L
.06074 4e-05 L
.06094 4e-05 L
.06113 4e-05 L
.06134 4e-05 L
.06157 4e-05 L
.06175 4e-05 L
.06196 4e-05 L
.06219 4e-05 L
.06231 4e-05 L
.06243 4e-05 L
.06265 4e-05 L
Mistroke
.06286 4e-05 L
.06304 4e-05 L
.06324 4e-05 L
.06344 4e-05 L
.06364 4e-05 L
.06382 4e-05 L
.06398 4e-05 L
.06416 4e-05 L
.06436 4e-05 L
.06455 4e-05 L
.06476 4e-05 L
.06495 4e-05 L
.06513 4e-05 L
.06534 4e-05 L
.06546 4e-05 L
.06557 4e-05 L
.06577 4e-05 L
.06598 4e-05 L
.06619 4e-05 L
.06641 4e-05 L
.06663 4e-05 L
.06682 4e-05 L
.06702 4e-05 L
.0672 4e-05 L
.0674 4e-05 L
.06759 4e-05 L
.0678 4e-05 L
.06803 4e-05 L
.06822 4e-05 L
.06842 4e-05 L
.06865 4e-05 L
.06877 4e-05 L
.06889 4e-05 L
.06911 4e-05 L
.06932 4e-05 L
.0695 4e-05 L
.0697 4e-05 L
.06991 4e-05 L
.0701 4e-05 L
.07028 4e-05 L
.07045 4e-05 L
.07064 4e-05 L
.07082 4e-05 L
.07101 4e-05 L
.07122 4e-05 L
.07142 4e-05 L
.0716 4e-05 L
.07181 4e-05 L
.07192 4e-05 L
.07203 4e-05 L
Mistroke
.07223 4e-05 L
.07244 4e-05 L
.07265 4e-05 L
.07277 4e-05 L
.07288 4e-05 L
.07308 4e-05 L
.07329 4e-05 L
.07348 4e-05 L
.07366 4e-05 L
.07385 4e-05 L
.07406 4e-05 L
.07427 4e-05 L
.07439 4e-05 L
.0745 4e-05 L
.07472 4e-05 L
.07485 4e-05 L
.07496 4e-05 L
.07517 4e-05 L
.07539 4e-05 L
.0756 4e-05 L
.07579 4e-05 L
.07597 4e-05 L
.07617 4e-05 L
.07635 4e-05 L
.07652 4e-05 L
.07671 4e-05 L
.07692 4e-05 L
.07712 4e-05 L
.07731 4e-05 L
.07752 4e-05 L
.07772 4e-05 L
.0779 4e-05 L
.07809 4e-05 L
.0783 4e-05 L
.07852 4e-05 L
.07871 4e-05 L
.07892 4e-05 L
.07914 4e-05 L
.07935 4e-05 L
.07945 4e-05 L
.07957 4e-05 L
.0797 4e-05 L
.07981 4e-05 L
.08003 4e-05 L
.08022 4e-05 L
.08044 4e-05 L
.08066 4e-05 L
.08085 4e-05 L
.08105 4e-05 L
.08125 4e-05 L
Mistroke
.08142 4e-05 L
.08163 4e-05 L
.08185 4e-05 L
.08206 4e-05 L
.08225 4e-05 L
.08246 4e-05 L
.08268 4e-05 L
.08289 4e-05 L
.08308 4e-05 L
.0833 4e-05 L
.08343 4e-05 L
.08354 4e-05 L
.08376 4e-05 L
.08386 4e-05 L
.08398 4e-05 L
.0841 4e-05 L
.08422 4e-05 L
.08444 4e-05 L
.08456 4e-05 L
.08467 4e-05 L
.0848 4e-05 L
.08493 4e-05 L
.08504 4e-05 L
.08517 4e-05 L
.08529 4e-05 L
.08539 4e-05 L
.0856 4e-05 L
.08582 4e-05 L
.08602 4e-05 L
.08625 4e-05 L
.08646 4e-05 L
.08666 4e-05 L
.08685 4e-05 L
.08703 4e-05 L
.08723 4e-05 L
.08742 4e-05 L
.08763 4e-05 L
.08786 4e-05 L
.08804 4e-05 L
.08825 4e-05 L
.08848 4e-05 L
.0886 4e-05 L
.08872 4e-05 L
.08894 4e-05 L
.08915 4e-05 L
.08933 4e-05 L
.08953 4e-05 L
.08973 4e-05 L
.08993 4e-05 L
.09011 4e-05 L
Mistroke
.09027 4e-05 L
.09045 4e-05 L
.09064 4e-05 L
.09084 4e-05 L
.09105 4e-05 L
.09124 4e-05 L
.09142 4e-05 L
.09163 4e-05 L
.09175 4e-05 L
.09186 4e-05 L
.09206 4e-05 L
.09227 4e-05 L
.09248 4e-05 L
.0927 4e-05 L
.09291 4e-05 L
.09311 4e-05 L
.09331 4e-05 L
.09348 4e-05 L
.09369 4e-05 L
.09388 4e-05 L
.09409 4e-05 L
.09431 4e-05 L
.0945 4e-05 L
.09471 4e-05 L
.09494 4e-05 L
.09506 4e-05 L
.09518 4e-05 L
.0954 4e-05 L
.09561 4e-05 L
.09579 4e-05 L
.09599 4e-05 L
.09619 4e-05 L
.09639 4e-05 L
.09657 4e-05 L
.09673 4e-05 L
.09692 4e-05 L
.09711 4e-05 L
.0973 4e-05 L
.09751 4e-05 L
.09771 4e-05 L
.09788 4e-05 L
.09809 4e-05 L
.09821 4e-05 L
.09832 4e-05 L
.09852 4e-05 L
.09873 4e-05 L
.09894 4e-05 L
.09906 4e-05 L
.09917 4e-05 L
.09936 4e-05 L
Mistroke
.09958 4e-05 L
.09977 4e-05 L
.09994 4e-05 L
.10014 4e-05 L
.10035 4e-05 L
.10056 4e-05 L
.10068 4e-05 L
.10079 4e-05 L
.10101 4e-05 L
.10114 4e-05 L
.10125 4e-05 L
.10145 4e-05 L
.10168 4e-05 L
.10188 4e-05 L
.10208 4e-05 L
.10226 4e-05 L
.10245 4e-05 L
.10263 4e-05 L
.1028 4e-05 L
.103 4e-05 L
.10321 4e-05 L
.10341 4e-05 L
.1036 4e-05 L
.10381 4e-05 L
.104 4e-05 L
.10418 4e-05 L
.10437 4e-05 L
.10458 4e-05 L
.10481 4e-05 L
.105 4e-05 L
.1052 4e-05 L
.10543 4e-05 L
.10563 4e-05 L
.10574 4e-05 L
.10586 4e-05 L
.10598 4e-05 L
.1061 4e-05 L
.10631 4e-05 L
.10651 4e-05 L
.10672 4e-05 L
.10695 4e-05 L
.10714 4e-05 L
.10734 4e-05 L
.10753 4e-05 L
.1077 4e-05 L
.10791 4e-05 L
.10813 4e-05 L
.10834 4e-05 L
.10853 4e-05 L
.10874 4e-05 L
Mistroke
.10896 4e-05 L
.10917 4e-05 L
.10936 4e-05 L
.10958 4e-05 L
.10971 4e-05 L
.10983 4e-05 L
.11004 4e-05 L
.11015 4e-05 L
.11027 4e-05 L
.11038 4e-05 L
.1105 4e-05 L
.11072 4e-05 L
.11084 4e-05 L
.11096 4e-05 L
.11108 4e-05 L
.11121 4e-05 L
.11133 4e-05 L
.11145 4e-05 L
.11157 4e-05 L
.11168 4e-05 L
.11188 4e-05 L
.1121 4e-05 L
.11231 4e-05 L
.11253 4e-05 L
.11274 4e-05 L
.11294 4e-05 L
.11313 4e-05 L
.11331 4e-05 L
.11351 4e-05 L
.11371 4e-05 L
.11392 4e-05 L
.11414 4e-05 L
.11433 4e-05 L
.11453 4e-05 L
.11476 4e-05 L
.11488 4e-05 L
.115 4e-05 L
.11522 4e-05 L
.11543 4e-05 L
.11561 4e-05 L
.11581 4e-05 L
.11601 4e-05 L
.11621 4e-05 L
.11639 4e-05 L
.11655 4e-05 L
.11673 4e-05 L
.11693 4e-05 L
.11712 4e-05 L
.11733 4e-05 L
.11752 4e-05 L
Mistroke
.1177 4e-05 L
.11791 4e-05 L
.11803 4e-05 L
.11814 4e-05 L
.11834 4e-05 L
.11855 4e-05 L
.11876 4e-05 L
.11898 4e-05 L
.1192 4e-05 L
.11939 4e-05 L
.11959 4e-05 L
.11976 4e-05 L
.11997 4e-05 L
.12016 4e-05 L
.12037 4e-05 L
.12059 4e-05 L
.12078 4e-05 L
.12099 4e-05 L
.12122 4e-05 L
.12134 4e-05 L
.12146 4e-05 L
.12168 4e-05 L
.12189 4e-05 L
.12207 4e-05 L
.12227 4e-05 L
.12247 4e-05 L
.12267 4e-05 L
.12285 4e-05 L
.12301 4e-05 L
.12319 4e-05 L
.12339 4e-05 L
.12358 4e-05 L
.12379 4e-05 L
.12398 4e-05 L
.12416 4e-05 L
.12437 4e-05 L
.12449 4e-05 L
.1246 4e-05 L
.1248 4e-05 L
.12501 4e-05 L
.12522 4e-05 L
.12534 4e-05 L
.12544 4e-05 L
.12564 4e-05 L
.12585 4e-05 L
.12604 4e-05 L
.12622 4e-05 L
.12641 4e-05 L
.12662 4e-05 L
.12683 4e-05 L
Mistroke
.12695 4e-05 L
.12706 4e-05 L
.12729 4e-05 L
.12741 4e-05 L
.12753 4e-05 L
.12773 4e-05 L
.12795 4e-05 L
.12816 4e-05 L
.12836 4e-05 L
.12854 4e-05 L
.12873 4e-05 L
.12891 4e-05 L
.12908 4e-05 L
.12927 4e-05 L
.12949 4e-05 L
.12969 4e-05 L
.12987 4e-05 L
.13008 4e-05 L
.13028 4e-05 L
.13046 4e-05 L
.13065 4e-05 L
.13086 4e-05 L
.13108 4e-05 L
.13127 4e-05 L
.13148 4e-05 L
.1317 4e-05 L
.13191 4e-05 L
.13202 4e-05 L
.13213 4e-05 L
.13226 4e-05 L
.13237 4e-05 L
.13259 4e-05 L
.13278 4e-05 L
.133 4e-05 L
.13322 4e-05 L
.13341 4e-05 L
.13361 4e-05 L
.13381 4e-05 L
.13398 4e-05 L
.13418 4e-05 L
.13441 4e-05 L
.13462 4e-05 L
.13481 4e-05 L
.13501 4e-05 L
.13524 4e-05 L
.13544 4e-05 L
.13563 4e-05 L
.13586 4e-05 L
.13598 4e-05 L
.1361 4e-05 L
Mistroke
.13631 4e-05 L
.13643 4e-05 L
.13654 4e-05 L
.13666 4e-05 L
.13678 4e-05 L
.137 4e-05 L
.13712 4e-05 L
.13723 4e-05 L
.13735 4e-05 L
.13749 4e-05 L
.1376 4e-05 L
.13773 4e-05 L
.13784 4e-05 L
.13795 4e-05 L
.13816 4e-05 L
.13838 4e-05 L
.13858 4e-05 L
.1388 4e-05 L
.13902 4e-05 L
.13921 4e-05 L
.13941 4e-05 L
.13958 4e-05 L
.13979 4e-05 L
.13998 4e-05 L
.14019 4e-05 L
.14041 4e-05 L
.1406 4e-05 L
.14081 4e-05 L
.14103 4e-05 L
.14116 4e-05 L
.14127 4e-05 L
.14149 4e-05 L
.1417 4e-05 L
.14188 4e-05 L
.14208 4e-05 L
.14229 4e-05 L
.14248 4e-05 L
.14266 4e-05 L
.14283 4e-05 L
.14301 4e-05 L
.1432 4e-05 L
.14339 4e-05 L
.1436 4e-05 L
.1438 4e-05 L
.14397 4e-05 L
.14418 4e-05 L
.1443 4e-05 L
.14441 4e-05 L
.14461 4e-05 L
.14482 4e-05 L
Mistroke
.14503 4e-05 L
.14526 4e-05 L
.14547 4e-05 L
.14566 4e-05 L
.14586 4e-05 L
.14604 4e-05 L
.14624 4e-05 L
.14643 4e-05 L
.14664 4e-05 L
.14686 4e-05 L
.14705 4e-05 L
.14726 4e-05 L
.14749 4e-05 L
.14761 4e-05 L
.14773 4e-05 L
.14795 4e-05 L
.14816 4e-05 L
.14834 4e-05 L
.14854 4e-05 L
.14874 4e-05 L
.14894 4e-05 L
.14912 4e-05 L
.14928 4e-05 L
.14947 4e-05 L
.14966 4e-05 L
.14985 4e-05 L
.15006 4e-05 L
.15025 4e-05 L
.15043 4e-05 L
.15064 4e-05 L
.15076 4e-05 L
.15087 4e-05 L
.15107 4e-05 L
.15128 4e-05 L
.15149 4e-05 L
.15161 4e-05 L
.15171 4e-05 L
.15191 4e-05 L
.15212 4e-05 L
.15231 4e-05 L
.15249 4e-05 L
.15268 4e-05 L
.15289 4e-05 L
.1531 4e-05 L
.15322 4e-05 L
.15333 4e-05 L
.15356 4e-05 L
.15368 4e-05 L
.1538 4e-05 L
.154 4e-05 L
Mistroke
.15422 4e-05 L
.15443 4e-05 L
.15462 4e-05 L
.1548 4e-05 L
.155 4e-05 L
.15518 4e-05 L
.15535 4e-05 L
.15554 4e-05 L
.15575 4e-05 L
.15595 4e-05 L
.15614 4e-05 L
.15635 4e-05 L
.15655 4e-05 L
.15673 4e-05 L
.15692 4e-05 L
.15713 4e-05 L
.15735 4e-05 L
.15754 4e-05 L
.15775 4e-05 L
.1579 4e-05 L
.15804 4e-05 L
.15819 4e-05 L
.15835 4e-05 L
.15849 4e-05 L
.15862 4e-05 L
.15877 4e-05 L
.15892 4e-05 L
.15905 4e-05 L
.1592 4e-05 L
.15935 4e-05 L
.15948 4e-05 L
.15961 4e-05 L
.15973 4e-05 L
.15987 4e-05 L
.16 4e-05 L
.16014 4e-05 L
.16029 4e-05 L
.16045 4e-05 L
.1606 4e-05 L
.16074 4e-05 L
.16087 4e-05 L
.16101 4e-05 L
.16115 4e-05 L
.1613 4e-05 L
.16146 4e-05 L
.16162 4e-05 L
.16175 4e-05 L
.16191 4e-05 L
.16209 4e-05 L
.16225 4e-05 L
Mistroke
.16241 4e-05 L
Mfstroke
4e-05 .99996 m
.00663 .99996 L
.01381 .99996 L
.02056 .99996 L
.02704 .99996 L
.03395 .99996 L
.0406 .99996 L
.04766 .99996 L
.05447 .99996 L
.06102 .99996 L
.06799 .99996 L
.0747 .99996 L
.08115 .99996 L
.08801 .99996 L
.09462 .99996 L
.10165 .99996 L
.10842 .99996 L
.11493 .99996 L
.12186 .99996 L
.12853 .99996 L
.13562 .99996 L
.14245 .99996 L
.14903 .99996 L
.15602 .99996 L
.16241 .99996 L
s
1 1 .5 r
4e-05 4e-05 m
.00024 4e-05 L
.00042 4e-05 L
.00063 4e-05 L
.00083 4e-05 L
.00102 4e-05 L
.00119 4e-05 L
.00137 4e-05 L
.00157 4e-05 L
.00177 4e-05 L
.00198 4e-05 L
.00218 4e-05 L
.00237 4e-05 L
.00258 4e-05 L
.0027 4e-05 L
.00282 4e-05 L
.00302 4e-05 L
.00325 4e-05 L
.00336 4e-05 L
.00347 4e-05 L
.00368 4e-05 L
.0038 4e-05 L
.00391 4e-05 L
.00403 4e-05 L
.00416 4e-05 L
.00427 4e-05 L
.00439 4e-05 L
.00461 4e-05 L
.00482 4e-05 L
.00502 4e-05 L
.00521 4e-05 L
.00539 4e-05 L
.00559 4e-05 L
.0058 4e-05 L
.00601 4e-05 L
.00623 4e-05 L
.00642 4e-05 L
.00663 4e-05 L
.00675 4e-05 L
.00686 4e-05 L
.00698 4e-05 L
.00711 4e-05 L
.00733 4e-05 L
.00745 4e-05 L
.00757 4e-05 L
.00778 4e-05 L
.00798 4e-05 L
.00809 4e-05 L
.00821 4e-05 L
.00843 4e-05 L
.00856 4e-05 L
.00868 4e-05 L
.00879 4e-05 L
.00891 4e-05 L
.00904 4e-05 L
.00918 4e-05 L
.00929 4e-05 L
.00942 4e-05 L
.00954 4e-05 L
.00965 4e-05 L
.00978 4e-05 L
.0099 4e-05 L
.01011 4e-05 L
.01024 4e-05 L
.01035 4e-05 L
.01055 4e-05 L
.01076 4e-05 L
.01096 4e-05 L
.01115 4e-05 L
.01135 4e-05 L
.01158 4e-05 L
.01169 4e-05 L
.01181 4e-05 L
.01203 4e-05 L
.01215 4e-05 L
.01226 4e-05 L
.01238 4e-05 L
.01251 4e-05 L
.01272 4e-05 L
.01285 4e-05 L
.01296 4e-05 L
.01318 4e-05 L
.01337 4e-05 L
.0136 4e-05 L
.01381 4e-05 L
.014 4e-05 L
.01421 4e-05 L
.01441 4e-05 L
.01459 4e-05 L
.01479 4e-05 L
.01501 4e-05 L
.01512 4e-05 L
.01524 4e-05 L
.01545 4e-05 L
.01557 4e-05 L
.01568 4e-05 L
.0158 4e-05 L
.01592 4e-05 L
.01613 4e-05 L
.01625 4e-05 L
.01637 4e-05 L
.01658 4e-05 L
.01677 4e-05 L
.01699 4e-05 L
.0172 4e-05 L
.0174 4e-05 L
.01758 4e-05 L
.01778 4e-05 L
.01798 4e-05 L
.01816 4e-05 L
.01833 4e-05 L
.01851 4e-05 L
.0187 4e-05 L
.0189 4e-05 L
.0191 4e-05 L
.0193 4e-05 L
.01948 4e-05 L
.01969 4e-05 L
.01981 4e-05 L
.01992 4e-05 L
.02012 4e-05 L
.02034 4e-05 L
.02053 4e-05 L
.02075 4e-05 L
.02097 4e-05 L
.02117 4e-05 L
.02137 4e-05 L
.02154 4e-05 L
.02175 4e-05 L
.02194 4e-05 L
.02215 4e-05 L
.02237 4e-05 L
.02256 4e-05 L
.02276 4e-05 L
.02299 4e-05 L
.02311 4e-05 L
.02323 4e-05 L
.02345 4e-05 L
.02366 4e-05 L
.02386 4e-05 L
.02404 4e-05 L
.02424 4e-05 L
.02443 4e-05 L
.02461 4e-05 L
.02478 4e-05 L
.02496 4e-05 L
.02515 4e-05 L
.02535 4e-05 L
.02555 4e-05 L
.02575 4e-05 L
.02593 4e-05 L
.02614 4e-05 L
.02626 4e-05 L
.02636 4e-05 L
.02657 4e-05 L
.02678 4e-05 L
.02698 4e-05 L
.02721 4e-05 L
.02742 4e-05 L
.02761 4e-05 L
.02781 4e-05 L
.02799 4e-05 L
.02819 4e-05 L
.02838 4e-05 L
.02859 4e-05 L
.02881 4e-05 L
.029 4e-05 L
.02921 4e-05 L
.02943 4e-05 L
.02956 4e-05 L
.02967 4e-05 L
.0299 4e-05 L
.03011 4e-05 L
.03029 4e-05 L
.03048 4e-05 L
.03069 4e-05 L
.03088 4e-05 L
.03106 4e-05 L
.03123 4e-05 L
.03141 4e-05 L
.0316 4e-05 L
.03179 4e-05 L
.032 4e-05 L
.0322 4e-05 L
.03238 4e-05 L
.03259 4e-05 L
.0327 4e-05 L
.03281 4e-05 L
.03301 4e-05 L
.03323 4e-05 L
.03343 4e-05 L
.03366 4e-05 L
.03387 4e-05 L
.03407 4e-05 L
.03426 4e-05 L
.03444 4e-05 L
.03464 4e-05 L
.03483 4e-05 L
.03504 4e-05 L
.03527 4e-05 L
.03546 4e-05 L
.03566 4e-05 L
.03589 4e-05 L
.03601 4e-05 L
.03613 4e-05 L
.03635 4e-05 L
.03656 4e-05 L
.03674 4e-05 L
.03694 4e-05 L
.03715 4e-05 L
.03734 4e-05 L
.03752 4e-05 L
.03768 4e-05 L
.03787 4e-05 L
.03806 4e-05 L
.03825 4e-05 L
.03846 4e-05 L
.03866 4e-05 L
.03883 4e-05 L
.03904 4e-05 L
.03916 4e-05 L
.03927 4e-05 L
.03947 4e-05 L
.03968 4e-05 L
.03989 4e-05 L
.04012 4e-05 L
.04033 4e-05 L
.04053 4e-05 L
.0407 4e-05 L
.0409 4e-05 L
.0411 4e-05 L
.0413 4e-05 L
.04151 4e-05 L
.04173 4e-05 L
.04192 4e-05 L
.04213 4e-05 L
.04235 4e-05 L
.04248 4e-05 L
.04259 4e-05 L
.04281 4e-05 L
.04303 4e-05 L
.04321 4e-05 L
.0434 4e-05 L
.04361 4e-05 L
.0438 4e-05 L
.04399 4e-05 L
.04415 4e-05 L
.04434 4e-05 L
.04452 4e-05 L
.04472 4e-05 L
.04493 4e-05 L
.04512 4e-05 L
.0453 4e-05 L
.04551 4e-05 L
.04563 4e-05 L
.04574 4e-05 L
.04594 4e-05 L
.04615 4e-05 L
.04636 4e-05 L
.04647 4e-05 L
.04658 4e-05 L
.04678 4e-05 L
.04699 4e-05 L
.04718 4e-05 L
.04736 4e-05 L
.04756 4e-05 L
.04777 4e-05 L
.04798 4e-05 L
.0481 4e-05 L
.04821 4e-05 L
.04843 4e-05 L
.04856 4e-05 L
.04867 4e-05 L
.04887 4e-05 L
.0491 4e-05 L
.04931 4e-05 L
.0495 4e-05 L
.04968 4e-05 L
.04987 4e-05 L
.05005 4e-05 L
.05022 4e-05 L
.05042 4e-05 L
.05063 4e-05 L
.05083 4e-05 L
.05102 4e-05 L
.05123 4e-05 L
.05143 4e-05 L
.0516 4e-05 L
.0518 4e-05 L
.05201 4e-05 L
.05223 4e-05 L
.05242 4e-05 L
.05262 4e-05 L
.05285 4e-05 L
.05305 4e-05 L
.05316 4e-05 L
.05328 4e-05 L
.0534 4e-05 L
.05352 4e-05 L
.05373 4e-05 L
.05393 4e-05 L
.05415 4e-05 L
.05437 4e-05 L
.05456 4e-05 L
.05476 4e-05 L
.05495 4e-05 L
.05513 4e-05 L
.05533 4e-05 L
.05556 4e-05 L
.05576 4e-05 L
.05596 4e-05 L
.05616 4e-05 L
.05639 4e-05 L
.05659 4e-05 L
.05678 4e-05 L
.05701 4e-05 L
.05713 4e-05 L
.05725 4e-05 L
.05746 4e-05 L
.05757 4e-05 L
.05769 4e-05 L
.05781 4e-05 L
.05793 4e-05 L
.05815 4e-05 L
.05827 4e-05 L
.05838 4e-05 L
.05851 4e-05 L
.05864 4e-05 L
.05875 4e-05 L
.05888 4e-05 L
.05899 4e-05 L
.0591 4e-05 L
.05931 4e-05 L
.05953 4e-05 L
.05973 4e-05 L
.05996 4e-05 L
.06017 4e-05 L
.06037 4e-05 L
.06056 4e-05 L
.06074 4e-05 L
.06094 4e-05 L
.06113 4e-05 L
.06134 4e-05 L
.06157 4e-05 L
.06175 4e-05 L
.06196 4e-05 L
.06219 4e-05 L
.06231 4e-05 L
.06243 4e-05 L
.06265 4e-05 L
.06286 4e-05 L
.06304 4e-05 L
.06324 4e-05 L
.06344 4e-05 L
.06364 4e-05 L
.06382 4e-05 L
.06398 4e-05 L
.06416 4e-05 L
.06436 4e-05 L
.06455 4e-05 L
.06476 4e-05 L
.06495 4e-05 L
.06513 4e-05 L
.06534 4e-05 L
.06546 4e-05 L
.06557 4e-05 L
.06577 4e-05 L
.06598 4e-05 L
.06619 4e-05 L
.06641 4e-05 L
.06663 4e-05 L
.06682 4e-05 L
.06702 4e-05 L
.0672 4e-05 L
.0674 4e-05 L
.06759 4e-05 L
.0678 4e-05 L
.06803 4e-05 L
.06822 4e-05 L
.06842 4e-05 L
.06865 4e-05 L
.06877 4e-05 L
.06889 4e-05 L
.06911 4e-05 L
.06932 4e-05 L
.0695 4e-05 L
.0697 4e-05 L
.06991 4e-05 L
.0701 4e-05 L
.07028 4e-05 L
.07045 4e-05 L
.07064 4e-05 L
.07082 4e-05 L
.07101 4e-05 L
.07122 4e-05 L
.07142 4e-05 L
.0716 4e-05 L
.07181 4e-05 L
.07192 4e-05 L
.07203 4e-05 L
.07223 4e-05 L
.07244 4e-05 L
.07265 4e-05 L
.07277 4e-05 L
.07288 4e-05 L
.07308 4e-05 L
.07329 4e-05 L
.07348 4e-05 L
.07366 4e-05 L
.07385 4e-05 L
.07406 4e-05 L
.07427 4e-05 L
.07439 4e-05 L
.0745 4e-05 L
.07472 4e-05 L
.07485 4e-05 L
.07496 4e-05 L
.07517 4e-05 L
.07539 4e-05 L
.0756 4e-05 L
.07579 4e-05 L
.07597 4e-05 L
.07617 4e-05 L
.07635 4e-05 L
.07652 4e-05 L
.07671 4e-05 L
.07692 4e-05 L
.07712 4e-05 L
.07731 4e-05 L
.07752 4e-05 L
.07772 4e-05 L
.0779 4e-05 L
.07809 4e-05 L
.0783 4e-05 L
.07852 4e-05 L
.07871 4e-05 L
.07892 4e-05 L
.07914 4e-05 L
.07935 4e-05 L
.07945 4e-05 L
.07957 4e-05 L
.0797 4e-05 L
.07981 4e-05 L
.08003 4e-05 L
.08022 4e-05 L
.08044 4e-05 L
.08066 4e-05 L
.08085 4e-05 L
.08105 4e-05 L
.08125 4e-05 L
.08142 4e-05 L
.08163 4e-05 L
.08185 4e-05 L
.08206 4e-05 L
.08225 4e-05 L
.08246 4e-05 L
.08268 4e-05 L
.08289 4e-05 L
.08308 4e-05 L
.0833 4e-05 L
.08343 4e-05 L
.08354 4e-05 L
.08376 4e-05 L
.08386 4e-05 L
.08398 4e-05 L
.0841 4e-05 L
.08422 4e-05 L
.08444 4e-05 L
.08456 4e-05 L
.08467 4e-05 L
.0848 4e-05 L
.08493 4e-05 L
.08504 4e-05 L
.08517 4e-05 L
.08529 4e-05 L
.08539 4e-05 L
.0856 4e-05 L
.08582 4e-05 L
.08602 4e-05 L
.08625 4e-05 L
.08646 4e-05 L
.08666 4e-05 L
.08685 4e-05 L
.08703 4e-05 L
.08723 4e-05 L
.08742 4e-05 L
.08763 4e-05 L
.08786 4e-05 L
.08804 4e-05 L
.08825 4e-05 L
.08848 4e-05 L
.0886 4e-05 L
.08872 4e-05 L
.08894 4e-05 L
.08915 4e-05 L
.08933 4e-05 L
.08953 4e-05 L
.08973 4e-05 L
.08993 4e-05 L
.09011 4e-05 L
.09027 4e-05 L
.09045 4e-05 L
.09064 4e-05 L
.09084 4e-05 L
.09105 4e-05 L
.09124 4e-05 L
.09142 4e-05 L
.09163 4e-05 L
.09175 4e-05 L
.09186 4e-05 L
.09206 4e-05 L
.09227 4e-05 L
.09248 4e-05 L
.0927 4e-05 L
.09291 4e-05 L
.09311 4e-05 L
.09331 4e-05 L
.09348 4e-05 L
.09369 4e-05 L
.09388 4e-05 L
.09409 4e-05 L
.09431 4e-05 L
.0945 4e-05 L
.09471 4e-05 L
.09494 4e-05 L
.09506 4e-05 L
.09518 4e-05 L
.0954 4e-05 L
.09561 4e-05 L
.09579 4e-05 L
.09599 4e-05 L
.09619 4e-05 L
.09639 4e-05 L
.09657 4e-05 L
.09673 4e-05 L
.09692 4e-05 L
.09711 4e-05 L
.0973 4e-05 L
.09751 4e-05 L
.09771 4e-05 L
.09788 4e-05 L
.09809 4e-05 L
.09821 4e-05 L
.09832 4e-05 L
.09852 4e-05 L
.09873 4e-05 L
.09894 4e-05 L
.09906 4e-05 L
.09917 4e-05 L
.09936 4e-05 L
.09958 4e-05 L
.09977 4e-05 L
.09994 4e-05 L
.10014 4e-05 L
.10035 4e-05 L
.10056 4e-05 L
.10068 4e-05 L
.10079 4e-05 L
.10101 4e-05 L
.10114 4e-05 L
.10125 4e-05 L
.10145 4e-05 L
.10168 4e-05 L
.10188 4e-05 L
.10208 4e-05 L
.10226 4e-05 L
.10245 4e-05 L
.10263 4e-05 L
.1028 4e-05 L
.103 4e-05 L
.10321 4e-05 L
.10341 4e-05 L
.1036 4e-05 L
.10381 4e-05 L
.104 4e-05 L
.10418 4e-05 L
.10437 4e-05 L
.10458 4e-05 L
.10481 4e-05 L
.105 4e-05 L
.1052 4e-05 L
.10543 4e-05 L
.10563 4e-05 L
.10574 4e-05 L
.10586 4e-05 L
.10598 4e-05 L
.1061 4e-05 L
.10631 4e-05 L
.10651 4e-05 L
.10672 4e-05 L
.10695 4e-05 L
.10714 4e-05 L
.10734 4e-05 L
.10753 4e-05 L
.1077 4e-05 L
.10791 4e-05 L
.10813 4e-05 L
.10834 4e-05 L
.10853 4e-05 L
.10874 4e-05 L
.10896 4e-05 L
.10917 4e-05 L
.10936 4e-05 L
.10958 4e-05 L
.10971 4e-05 L
.10983 4e-05 L
.11004 4e-05 L
.11015 4e-05 L
.11027 4e-05 L
.11038 4e-05 L
.1105 4e-05 L
.11072 4e-05 L
.11084 4e-05 L
.11096 4e-05 L
.11108 4e-05 L
.11121 4e-05 L
.11133 4e-05 L
.11145 4e-05 L
.11157 4e-05 L
.11168 4e-05 L
.11188 4e-05 L
.1121 4e-05 L
.11231 4e-05 L
.11253 4e-05 L
.11274 4e-05 L
.11294 4e-05 L
.11313 4e-05 L
.11331 4e-05 L
.11351 4e-05 L
.11371 4e-05 L
.11392 4e-05 L
.11414 4e-05 L
.11433 4e-05 L
.11453 4e-05 L
.11476 4e-05 L
.11488 4e-05 L
.115 4e-05 L
.11522 4e-05 L
.11543 4e-05 L
.11561 4e-05 L
.11581 4e-05 L
.11601 4e-05 L
.11621 4e-05 L
.11639 4e-05 L
.11655 4e-05 L
.11673 4e-05 L
.11693 4e-05 L
.11712 4e-05 L
.11733 4e-05 L
.11752 4e-05 L
.1177 4e-05 L
.11791 4e-05 L
.11803 4e-05 L
.11814 4e-05 L
.11834 4e-05 L
.11855 4e-05 L
.11876 4e-05 L
.11898 4e-05 L
.1192 4e-05 L
.11939 4e-05 L
.11959 4e-05 L
.11976 4e-05 L
.11997 4e-05 L
.12016 4e-05 L
.12037 4e-05 L
.12059 4e-05 L
.12078 4e-05 L
.12099 4e-05 L
.12122 4e-05 L
.12134 4e-05 L
.12146 4e-05 L
.12168 4e-05 L
.12189 4e-05 L
.12207 4e-05 L
.12227 4e-05 L
.12247 4e-05 L
.12267 4e-05 L
.12285 4e-05 L
.12301 4e-05 L
.12319 4e-05 L
.12339 4e-05 L
.12358 4e-05 L
.12379 4e-05 L
.12398 4e-05 L
.12416 4e-05 L
.12437 4e-05 L
.12449 4e-05 L
.1246 4e-05 L
.1248 4e-05 L
.12501 4e-05 L
.12522 4e-05 L
.12534 4e-05 L
.12544 4e-05 L
.12564 4e-05 L
.12585 4e-05 L
.12604 4e-05 L
.12622 4e-05 L
.12641 4e-05 L
.12662 4e-05 L
.12683 4e-05 L
.12695 4e-05 L
.12706 4e-05 L
.12729 4e-05 L
.12741 4e-05 L
.12753 4e-05 L
.12773 4e-05 L
.12795 4e-05 L
.12816 4e-05 L
.12836 4e-05 L
.12854 4e-05 L
.12873 4e-05 L
.12891 4e-05 L
.12908 4e-05 L
.12927 4e-05 L
.12949 4e-05 L
.12969 4e-05 L
.12987 4e-05 L
.13008 4e-05 L
.13028 4e-05 L
.13046 4e-05 L
.13065 4e-05 L
.13086 4e-05 L
.13108 4e-05 L
.13127 4e-05 L
.13148 4e-05 L
.1317 4e-05 L
.13191 4e-05 L
.13202 4e-05 L
.13213 4e-05 L
.13226 4e-05 L
.13237 4e-05 L
.13259 4e-05 L
.13278 4e-05 L
.133 4e-05 L
.13322 4e-05 L
.13341 4e-05 L
.13361 4e-05 L
.13381 4e-05 L
.13398 4e-05 L
.13418 4e-05 L
.13441 4e-05 L
.13462 4e-05 L
.13481 4e-05 L
.13501 4e-05 L
.13524 4e-05 L
.13544 4e-05 L
.13563 4e-05 L
.13586 4e-05 L
.13598 4e-05 L
.1361 4e-05 L
.13631 4e-05 L
.13643 4e-05 L
.13654 4e-05 L
.13666 4e-05 L
.13678 4e-05 L
.137 4e-05 L
.13712 4e-05 L
.13723 4e-05 L
.13735 4e-05 L
.13749 4e-05 L
.1376 4e-05 L
.13773 4e-05 L
.13784 4e-05 L
.13795 4e-05 L
.13816 4e-05 L
.13838 4e-05 L
.13858 4e-05 L
.1388 4e-05 L
.13902 4e-05 L
.13921 4e-05 L
.13941 4e-05 L
.13958 4e-05 L
.13979 4e-05 L
.13998 4e-05 L
.14019 4e-05 L
.14041 4e-05 L
.1406 4e-05 L
.14081 4e-05 L
.14103 4e-05 L
.14116 4e-05 L
.14127 4e-05 L
.14149 4e-05 L
.1417 4e-05 L
.14188 4e-05 L
.14208 4e-05 L
.14229 4e-05 L
.14248 4e-05 L
.14266 4e-05 L
.14283 4e-05 L
.14301 4e-05 L
.1432 4e-05 L
.14339 4e-05 L
.1436 4e-05 L
.1438 4e-05 L
.14397 4e-05 L
.14418 4e-05 L
.1443 4e-05 L
.14441 4e-05 L
.14461 4e-05 L
.14482 4e-05 L
.14503 4e-05 L
.14526 4e-05 L
.14547 4e-05 L
.14566 4e-05 L
.14586 4e-05 L
.14604 4e-05 L
.14624 4e-05 L
.14643 4e-05 L
.14664 4e-05 L
.14686 4e-05 L
.14705 4e-05 L
.14726 4e-05 L
.14749 4e-05 L
.14761 4e-05 L
.14773 4e-05 L
.14795 4e-05 L
.14816 4e-05 L
.14834 4e-05 L
.14854 4e-05 L
.14874 4e-05 L
.14894 4e-05 L
.14912 4e-05 L
.14928 4e-05 L
.14947 4e-05 L
.14966 4e-05 L
.14985 4e-05 L
.15006 4e-05 L
.15025 4e-05 L
.15043 4e-05 L
.15064 4e-05 L
.15076 4e-05 L
.15087 4e-05 L
.15107 4e-05 L
.15128 4e-05 L
.15149 4e-05 L
.15161 4e-05 L
.15171 4e-05 L
.15191 4e-05 L
.15212 4e-05 L
.15231 4e-05 L
.15249 4e-05 L
.15268 4e-05 L
.15289 4e-05 L
.1531 4e-05 L
.15322 4e-05 L
.15333 4e-05 L
.15356 4e-05 L
.15368 4e-05 L
.1538 4e-05 L
.154 4e-05 L
.15422 4e-05 L
.15443 4e-05 L
.15462 4e-05 L
.1548 4e-05 L
.155 4e-05 L
.15518 4e-05 L
.15535 4e-05 L
.15554 4e-05 L
.15575 4e-05 L
.15595 4e-05 L
.15614 4e-05 L
.15635 4e-05 L
.15655 4e-05 L
.15673 4e-05 L
.15692 4e-05 L
.15713 4e-05 L
.15735 4e-05 L
.15754 4e-05 L
.15775 4e-05 L
.1579 4e-05 L
.15804 4e-05 L
.15819 4e-05 L
.15835 4e-05 L
.15849 4e-05 L
.15862 4e-05 L
.15877 4e-05 L
.15892 4e-05 L
.15905 4e-05 L
.1592 4e-05 L
.15935 4e-05 L
.15948 4e-05 L
.15961 4e-05 L
.15973 4e-05 L
.15987 4e-05 L
.16 4e-05 L
.16014 4e-05 L
.16029 4e-05 L
.16045 4e-05 L
.1606 4e-05 L
.16074 4e-05 L
.16087 4e-05 L
.16101 4e-05 L
.16115 4e-05 L
.1613 4e-05 L
.16146 4e-05 L
.16162 4e-05 L
.16175 4e-05 L
.16191 4e-05 L
.16209 4e-05 L
.16225 4e-05 L
.16241 4e-05 L
.16241 .99996 L
.15602 .99996 L
.14903 .99996 L
.14245 .99996 L
.13562 .99996 L
.12853 .99996 L
.12186 .99996 L
.11493 .99996 L
.10842 .99996 L
.10165 .99996 L
.09462 .99996 L
.08801 .99996 L
.08115 .99996 L
.0747 .99996 L
.06799 .99996 L
.06102 .99996 L
.05447 .99996 L
.04766 .99996 L
.0406 .99996 L
.03395 .99996 L
.02704 .99996 L
.02056 .99996 L
.01381 .99996 L
.00663 .99996 L
4e-05 .99996 L
F
0 g
4e-05 4e-05 m
.00024 4e-05 L
.00042 4e-05 L
.00063 4e-05 L
.00083 4e-05 L
.00102 4e-05 L
.00119 4e-05 L
.00137 4e-05 L
.00157 4e-05 L
.00177 4e-05 L
.00198 4e-05 L
.00218 4e-05 L
.00237 4e-05 L
.00258 4e-05 L
.0027 4e-05 L
.00282 4e-05 L
.00302 4e-05 L
.00325 4e-05 L
.00336 4e-05 L
.00347 4e-05 L
.00368 4e-05 L
.0038 4e-05 L
.00391 4e-05 L
.00403 4e-05 L
.00416 4e-05 L
.00427 4e-05 L
.00439 4e-05 L
.00461 4e-05 L
.00482 4e-05 L
.00502 4e-05 L
.00521 4e-05 L
.00539 4e-05 L
.00559 4e-05 L
.0058 4e-05 L
.00601 4e-05 L
.00623 4e-05 L
.00642 4e-05 L
.00663 4e-05 L
.00675 4e-05 L
.00686 4e-05 L
.00698 4e-05 L
.00711 4e-05 L
.00733 4e-05 L
.00745 4e-05 L
.00757 4e-05 L
.00778 4e-05 L
.00798 4e-05 L
.00809 4e-05 L
.00821 4e-05 L
.00843 4e-05 L
Mistroke
.00856 4e-05 L
.00868 4e-05 L
.00879 4e-05 L
.00891 4e-05 L
.00904 4e-05 L
.00918 4e-05 L
.00929 4e-05 L
.00942 4e-05 L
.00954 4e-05 L
.00965 4e-05 L
.00978 4e-05 L
.0099 4e-05 L
.01011 4e-05 L
.01024 4e-05 L
.01035 4e-05 L
.01055 4e-05 L
.01076 4e-05 L
.01096 4e-05 L
.01115 4e-05 L
.01135 4e-05 L
.01158 4e-05 L
.01169 4e-05 L
.01181 4e-05 L
.01203 4e-05 L
.01215 4e-05 L
.01226 4e-05 L
.01238 4e-05 L
.01251 4e-05 L
.01272 4e-05 L
.01285 4e-05 L
.01296 4e-05 L
.01318 4e-05 L
.01337 4e-05 L
.0136 4e-05 L
.01381 4e-05 L
.014 4e-05 L
.01421 4e-05 L
.01441 4e-05 L
.01459 4e-05 L
.01479 4e-05 L
.01501 4e-05 L
.01512 4e-05 L
.01524 4e-05 L
.01545 4e-05 L
.01557 4e-05 L
.01568 4e-05 L
.0158 4e-05 L
.01592 4e-05 L
.01613 4e-05 L
.01625 4e-05 L
Mistroke
.01637 4e-05 L
.01658 4e-05 L
.01677 4e-05 L
.01699 4e-05 L
.0172 4e-05 L
.0174 4e-05 L
.01758 4e-05 L
.01778 4e-05 L
.01798 4e-05 L
.01816 4e-05 L
.01833 4e-05 L
.01851 4e-05 L
.0187 4e-05 L
.0189 4e-05 L
.0191 4e-05 L
.0193 4e-05 L
.01948 4e-05 L
.01969 4e-05 L
.01981 4e-05 L
.01992 4e-05 L
.02012 4e-05 L
.02034 4e-05 L
.02053 4e-05 L
.02075 4e-05 L
.02097 4e-05 L
.02117 4e-05 L
.02137 4e-05 L
.02154 4e-05 L
.02175 4e-05 L
.02194 4e-05 L
.02215 4e-05 L
.02237 4e-05 L
.02256 4e-05 L
.02276 4e-05 L
.02299 4e-05 L
.02311 4e-05 L
.02323 4e-05 L
.02345 4e-05 L
.02366 4e-05 L
.02386 4e-05 L
.02404 4e-05 L
.02424 4e-05 L
.02443 4e-05 L
.02461 4e-05 L
.02478 4e-05 L
.02496 4e-05 L
.02515 4e-05 L
.02535 4e-05 L
.02555 4e-05 L
.02575 4e-05 L
Mistroke
.02593 4e-05 L
.02614 4e-05 L
.02626 4e-05 L
.02636 4e-05 L
.02657 4e-05 L
.02678 4e-05 L
.02698 4e-05 L
.02721 4e-05 L
.02742 4e-05 L
.02761 4e-05 L
.02781 4e-05 L
.02799 4e-05 L
.02819 4e-05 L
.02838 4e-05 L
.02859 4e-05 L
.02881 4e-05 L
.029 4e-05 L
.02921 4e-05 L
.02943 4e-05 L
.02956 4e-05 L
.02967 4e-05 L
.0299 4e-05 L
.03011 4e-05 L
.03029 4e-05 L
.03048 4e-05 L
.03069 4e-05 L
.03088 4e-05 L
.03106 4e-05 L
.03123 4e-05 L
.03141 4e-05 L
.0316 4e-05 L
.03179 4e-05 L
.032 4e-05 L
.0322 4e-05 L
.03238 4e-05 L
.03259 4e-05 L
.0327 4e-05 L
.03281 4e-05 L
.03301 4e-05 L
.03323 4e-05 L
.03343 4e-05 L
.03366 4e-05 L
.03387 4e-05 L
.03407 4e-05 L
.03426 4e-05 L
.03444 4e-05 L
.03464 4e-05 L
.03483 4e-05 L
.03504 4e-05 L
.03527 4e-05 L
Mistroke
.03546 4e-05 L
.03566 4e-05 L
.03589 4e-05 L
.03601 4e-05 L
.03613 4e-05 L
.03635 4e-05 L
.03656 4e-05 L
.03674 4e-05 L
.03694 4e-05 L
.03715 4e-05 L
.03734 4e-05 L
.03752 4e-05 L
.03768 4e-05 L
.03787 4e-05 L
.03806 4e-05 L
.03825 4e-05 L
.03846 4e-05 L
.03866 4e-05 L
.03883 4e-05 L
.03904 4e-05 L
.03916 4e-05 L
.03927 4e-05 L
.03947 4e-05 L
.03968 4e-05 L
.03989 4e-05 L
.04012 4e-05 L
.04033 4e-05 L
.04053 4e-05 L
.0407 4e-05 L
.0409 4e-05 L
.0411 4e-05 L
.0413 4e-05 L
.04151 4e-05 L
.04173 4e-05 L
.04192 4e-05 L
.04213 4e-05 L
.04235 4e-05 L
.04248 4e-05 L
.04259 4e-05 L
.04281 4e-05 L
.04303 4e-05 L
.04321 4e-05 L
.0434 4e-05 L
.04361 4e-05 L
.0438 4e-05 L
.04399 4e-05 L
.04415 4e-05 L
.04434 4e-05 L
.04452 4e-05 L
.04472 4e-05 L
Mistroke
.04493 4e-05 L
.04512 4e-05 L
.0453 4e-05 L
.04551 4e-05 L
.04563 4e-05 L
.04574 4e-05 L
.04594 4e-05 L
.04615 4e-05 L
.04636 4e-05 L
.04647 4e-05 L
.04658 4e-05 L
.04678 4e-05 L
.04699 4e-05 L
.04718 4e-05 L
.04736 4e-05 L
.04756 4e-05 L
.04777 4e-05 L
.04798 4e-05 L
.0481 4e-05 L
.04821 4e-05 L
.04843 4e-05 L
.04856 4e-05 L
.04867 4e-05 L
.04887 4e-05 L
.0491 4e-05 L
.04931 4e-05 L
.0495 4e-05 L
.04968 4e-05 L
.04987 4e-05 L
.05005 4e-05 L
.05022 4e-05 L
.05042 4e-05 L
.05063 4e-05 L
.05083 4e-05 L
.05102 4e-05 L
.05123 4e-05 L
.05143 4e-05 L
.0516 4e-05 L
.0518 4e-05 L
.05201 4e-05 L
.05223 4e-05 L
.05242 4e-05 L
.05262 4e-05 L
.05285 4e-05 L
.05305 4e-05 L
.05316 4e-05 L
.05328 4e-05 L
.0534 4e-05 L
.05352 4e-05 L
.05373 4e-05 L
Mistroke
.05393 4e-05 L
.05415 4e-05 L
.05437 4e-05 L
.05456 4e-05 L
.05476 4e-05 L
.05495 4e-05 L
.05513 4e-05 L
.05533 4e-05 L
.05556 4e-05 L
.05576 4e-05 L
.05596 4e-05 L
.05616 4e-05 L
.05639 4e-05 L
.05659 4e-05 L
.05678 4e-05 L
.05701 4e-05 L
.05713 4e-05 L
.05725 4e-05 L
.05746 4e-05 L
.05757 4e-05 L
.05769 4e-05 L
.05781 4e-05 L
.05793 4e-05 L
.05815 4e-05 L
.05827 4e-05 L
.05838 4e-05 L
.05851 4e-05 L
.05864 4e-05 L
.05875 4e-05 L
.05888 4e-05 L
.05899 4e-05 L
.0591 4e-05 L
.05931 4e-05 L
.05953 4e-05 L
.05973 4e-05 L
.05996 4e-05 L
.06017 4e-05 L
.06037 4e-05 L
.06056 4e-05 L
.06074 4e-05 L
.06094 4e-05 L
.06113 4e-05 L
.06134 4e-05 L
.06157 4e-05 L
.06175 4e-05 L
.06196 4e-05 L
.06219 4e-05 L
.06231 4e-05 L
.06243 4e-05 L
.06265 4e-05 L
Mistroke
.06286 4e-05 L
.06304 4e-05 L
.06324 4e-05 L
.06344 4e-05 L
.06364 4e-05 L
.06382 4e-05 L
.06398 4e-05 L
.06416 4e-05 L
.06436 4e-05 L
.06455 4e-05 L
.06476 4e-05 L
.06495 4e-05 L
.06513 4e-05 L
.06534 4e-05 L
.06546 4e-05 L
.06557 4e-05 L
.06577 4e-05 L
.06598 4e-05 L
.06619 4e-05 L
.06641 4e-05 L
.06663 4e-05 L
.06682 4e-05 L
.06702 4e-05 L
.0672 4e-05 L
.0674 4e-05 L
.06759 4e-05 L
.0678 4e-05 L
.06803 4e-05 L
.06822 4e-05 L
.06842 4e-05 L
.06865 4e-05 L
.06877 4e-05 L
.06889 4e-05 L
.06911 4e-05 L
.06932 4e-05 L
.0695 4e-05 L
.0697 4e-05 L
.06991 4e-05 L
.0701 4e-05 L
.07028 4e-05 L
.07045 4e-05 L
.07064 4e-05 L
.07082 4e-05 L
.07101 4e-05 L
.07122 4e-05 L
.07142 4e-05 L
.0716 4e-05 L
.07181 4e-05 L
.07192 4e-05 L
.07203 4e-05 L
Mistroke
.07223 4e-05 L
.07244 4e-05 L
.07265 4e-05 L
.07277 4e-05 L
.07288 4e-05 L
.07308 4e-05 L
.07329 4e-05 L
.07348 4e-05 L
.07366 4e-05 L
.07385 4e-05 L
.07406 4e-05 L
.07427 4e-05 L
.07439 4e-05 L
.0745 4e-05 L
.07472 4e-05 L
.07485 4e-05 L
.07496 4e-05 L
.07517 4e-05 L
.07539 4e-05 L
.0756 4e-05 L
.07579 4e-05 L
.07597 4e-05 L
.07617 4e-05 L
.07635 4e-05 L
.07652 4e-05 L
.07671 4e-05 L
.07692 4e-05 L
.07712 4e-05 L
.07731 4e-05 L
.07752 4e-05 L
.07772 4e-05 L
.0779 4e-05 L
.07809 4e-05 L
.0783 4e-05 L
.07852 4e-05 L
.07871 4e-05 L
.07892 4e-05 L
.07914 4e-05 L
.07935 4e-05 L
.07945 4e-05 L
.07957 4e-05 L
.0797 4e-05 L
.07981 4e-05 L
.08003 4e-05 L
.08022 4e-05 L
.08044 4e-05 L
.08066 4e-05 L
.08085 4e-05 L
.08105 4e-05 L
.08125 4e-05 L
Mistroke
.08142 4e-05 L
.08163 4e-05 L
.08185 4e-05 L
.08206 4e-05 L
.08225 4e-05 L
.08246 4e-05 L
.08268 4e-05 L
.08289 4e-05 L
.08308 4e-05 L
.0833 4e-05 L
.08343 4e-05 L
.08354 4e-05 L
.08376 4e-05 L
.08386 4e-05 L
.08398 4e-05 L
.0841 4e-05 L
.08422 4e-05 L
.08444 4e-05 L
.08456 4e-05 L
.08467 4e-05 L
.0848 4e-05 L
.08493 4e-05 L
.08504 4e-05 L
.08517 4e-05 L
.08529 4e-05 L
.08539 4e-05 L
.0856 4e-05 L
.08582 4e-05 L
.08602 4e-05 L
.08625 4e-05 L
.08646 4e-05 L
.08666 4e-05 L
.08685 4e-05 L
.08703 4e-05 L
.08723 4e-05 L
.08742 4e-05 L
.08763 4e-05 L
.08786 4e-05 L
.08804 4e-05 L
.08825 4e-05 L
.08848 4e-05 L
.0886 4e-05 L
.08872 4e-05 L
.08894 4e-05 L
.08915 4e-05 L
.08933 4e-05 L
.08953 4e-05 L
.08973 4e-05 L
.08993 4e-05 L
.09011 4e-05 L
Mistroke
.09027 4e-05 L
.09045 4e-05 L
.09064 4e-05 L
.09084 4e-05 L
.09105 4e-05 L
.09124 4e-05 L
.09142 4e-05 L
.09163 4e-05 L
.09175 4e-05 L
.09186 4e-05 L
.09206 4e-05 L
.09227 4e-05 L
.09248 4e-05 L
.0927 4e-05 L
.09291 4e-05 L
.09311 4e-05 L
.09331 4e-05 L
.09348 4e-05 L
.09369 4e-05 L
.09388 4e-05 L
.09409 4e-05 L
.09431 4e-05 L
.0945 4e-05 L
.09471 4e-05 L
.09494 4e-05 L
.09506 4e-05 L
.09518 4e-05 L
.0954 4e-05 L
.09561 4e-05 L
.09579 4e-05 L
.09599 4e-05 L
.09619 4e-05 L
.09639 4e-05 L
.09657 4e-05 L
.09673 4e-05 L
.09692 4e-05 L
.09711 4e-05 L
.0973 4e-05 L
.09751 4e-05 L
.09771 4e-05 L
.09788 4e-05 L
.09809 4e-05 L
.09821 4e-05 L
.09832 4e-05 L
.09852 4e-05 L
.09873 4e-05 L
.09894 4e-05 L
.09906 4e-05 L
.09917 4e-05 L
.09936 4e-05 L
Mistroke
.09958 4e-05 L
.09977 4e-05 L
.09994 4e-05 L
.10014 4e-05 L
.10035 4e-05 L
.10056 4e-05 L
.10068 4e-05 L
.10079 4e-05 L
.10101 4e-05 L
.10114 4e-05 L
.10125 4e-05 L
.10145 4e-05 L
.10168 4e-05 L
.10188 4e-05 L
.10208 4e-05 L
.10226 4e-05 L
.10245 4e-05 L
.10263 4e-05 L
.1028 4e-05 L
.103 4e-05 L
.10321 4e-05 L
.10341 4e-05 L
.1036 4e-05 L
.10381 4e-05 L
.104 4e-05 L
.10418 4e-05 L
.10437 4e-05 L
.10458 4e-05 L
.10481 4e-05 L
.105 4e-05 L
.1052 4e-05 L
.10543 4e-05 L
.10563 4e-05 L
.10574 4e-05 L
.10586 4e-05 L
.10598 4e-05 L
.1061 4e-05 L
.10631 4e-05 L
.10651 4e-05 L
.10672 4e-05 L
.10695 4e-05 L
.10714 4e-05 L
.10734 4e-05 L
.10753 4e-05 L
.1077 4e-05 L
.10791 4e-05 L
.10813 4e-05 L
.10834 4e-05 L
.10853 4e-05 L
.10874 4e-05 L
Mistroke
.10896 4e-05 L
.10917 4e-05 L
.10936 4e-05 L
.10958 4e-05 L
.10971 4e-05 L
.10983 4e-05 L
.11004 4e-05 L
.11015 4e-05 L
.11027 4e-05 L
.11038 4e-05 L
.1105 4e-05 L
.11072 4e-05 L
.11084 4e-05 L
.11096 4e-05 L
.11108 4e-05 L
.11121 4e-05 L
.11133 4e-05 L
.11145 4e-05 L
.11157 4e-05 L
.11168 4e-05 L
.11188 4e-05 L
.1121 4e-05 L
.11231 4e-05 L
.11253 4e-05 L
.11274 4e-05 L
.11294 4e-05 L
.11313 4e-05 L
.11331 4e-05 L
.11351 4e-05 L
.11371 4e-05 L
.11392 4e-05 L
.11414 4e-05 L
.11433 4e-05 L
.11453 4e-05 L
.11476 4e-05 L
.11488 4e-05 L
.115 4e-05 L
.11522 4e-05 L
.11543 4e-05 L
.11561 4e-05 L
.11581 4e-05 L
.11601 4e-05 L
.11621 4e-05 L
.11639 4e-05 L
.11655 4e-05 L
.11673 4e-05 L
.11693 4e-05 L
.11712 4e-05 L
.11733 4e-05 L
.11752 4e-05 L
Mistroke
.1177 4e-05 L
.11791 4e-05 L
.11803 4e-05 L
.11814 4e-05 L
.11834 4e-05 L
.11855 4e-05 L
.11876 4e-05 L
.11898 4e-05 L
.1192 4e-05 L
.11939 4e-05 L
.11959 4e-05 L
.11976 4e-05 L
.11997 4e-05 L
.12016 4e-05 L
.12037 4e-05 L
.12059 4e-05 L
.12078 4e-05 L
.12099 4e-05 L
.12122 4e-05 L
.12134 4e-05 L
.12146 4e-05 L
.12168 4e-05 L
.12189 4e-05 L
.12207 4e-05 L
.12227 4e-05 L
.12247 4e-05 L
.12267 4e-05 L
.12285 4e-05 L
.12301 4e-05 L
.12319 4e-05 L
.12339 4e-05 L
.12358 4e-05 L
.12379 4e-05 L
.12398 4e-05 L
.12416 4e-05 L
.12437 4e-05 L
.12449 4e-05 L
.1246 4e-05 L
.1248 4e-05 L
.12501 4e-05 L
.12522 4e-05 L
.12534 4e-05 L
.12544 4e-05 L
.12564 4e-05 L
.12585 4e-05 L
.12604 4e-05 L
.12622 4e-05 L
.12641 4e-05 L
.12662 4e-05 L
.12683 4e-05 L
Mistroke
.12695 4e-05 L
.12706 4e-05 L
.12729 4e-05 L
.12741 4e-05 L
.12753 4e-05 L
.12773 4e-05 L
.12795 4e-05 L
.12816 4e-05 L
.12836 4e-05 L
.12854 4e-05 L
.12873 4e-05 L
.12891 4e-05 L
.12908 4e-05 L
.12927 4e-05 L
.12949 4e-05 L
.12969 4e-05 L
.12987 4e-05 L
.13008 4e-05 L
.13028 4e-05 L
.13046 4e-05 L
.13065 4e-05 L
.13086 4e-05 L
.13108 4e-05 L
.13127 4e-05 L
.13148 4e-05 L
.1317 4e-05 L
.13191 4e-05 L
.13202 4e-05 L
.13213 4e-05 L
.13226 4e-05 L
.13237 4e-05 L
.13259 4e-05 L
.13278 4e-05 L
.133 4e-05 L
.13322 4e-05 L
.13341 4e-05 L
.13361 4e-05 L
.13381 4e-05 L
.13398 4e-05 L
.13418 4e-05 L
.13441 4e-05 L
.13462 4e-05 L
.13481 4e-05 L
.13501 4e-05 L
.13524 4e-05 L
.13544 4e-05 L
.13563 4e-05 L
.13586 4e-05 L
.13598 4e-05 L
.1361 4e-05 L
Mistroke
.13631 4e-05 L
.13643 4e-05 L
.13654 4e-05 L
.13666 4e-05 L
.13678 4e-05 L
.137 4e-05 L
.13712 4e-05 L
.13723 4e-05 L
.13735 4e-05 L
.13749 4e-05 L
.1376 4e-05 L
.13773 4e-05 L
.13784 4e-05 L
.13795 4e-05 L
.13816 4e-05 L
.13838 4e-05 L
.13858 4e-05 L
.1388 4e-05 L
.13902 4e-05 L
.13921 4e-05 L
.13941 4e-05 L
.13958 4e-05 L
.13979 4e-05 L
.13998 4e-05 L
.14019 4e-05 L
.14041 4e-05 L
.1406 4e-05 L
.14081 4e-05 L
.14103 4e-05 L
.14116 4e-05 L
.14127 4e-05 L
.14149 4e-05 L
.1417 4e-05 L
.14188 4e-05 L
.14208 4e-05 L
.14229 4e-05 L
.14248 4e-05 L
.14266 4e-05 L
.14283 4e-05 L
.14301 4e-05 L
.1432 4e-05 L
.14339 4e-05 L
.1436 4e-05 L
.1438 4e-05 L
.14397 4e-05 L
.14418 4e-05 L
.1443 4e-05 L
.14441 4e-05 L
.14461 4e-05 L
.14482 4e-05 L
Mistroke
.14503 4e-05 L
.14526 4e-05 L
.14547 4e-05 L
.14566 4e-05 L
.14586 4e-05 L
.14604 4e-05 L
.14624 4e-05 L
.14643 4e-05 L
.14664 4e-05 L
.14686 4e-05 L
.14705 4e-05 L
.14726 4e-05 L
.14749 4e-05 L
.14761 4e-05 L
.14773 4e-05 L
.14795 4e-05 L
.14816 4e-05 L
.14834 4e-05 L
.14854 4e-05 L
.14874 4e-05 L
.14894 4e-05 L
.14912 4e-05 L
.14928 4e-05 L
.14947 4e-05 L
.14966 4e-05 L
.14985 4e-05 L
.15006 4e-05 L
.15025 4e-05 L
.15043 4e-05 L
.15064 4e-05 L
.15076 4e-05 L
.15087 4e-05 L
.15107 4e-05 L
.15128 4e-05 L
.15149 4e-05 L
.15161 4e-05 L
.15171 4e-05 L
.15191 4e-05 L
.15212 4e-05 L
.15231 4e-05 L
.15249 4e-05 L
.15268 4e-05 L
.15289 4e-05 L
.1531 4e-05 L
.15322 4e-05 L
.15333 4e-05 L
.15356 4e-05 L
.15368 4e-05 L
.1538 4e-05 L
.154 4e-05 L
Mistroke
.15422 4e-05 L
.15443 4e-05 L
.15462 4e-05 L
.1548 4e-05 L
.155 4e-05 L
.15518 4e-05 L
.15535 4e-05 L
.15554 4e-05 L
.15575 4e-05 L
.15595 4e-05 L
.15614 4e-05 L
.15635 4e-05 L
.15655 4e-05 L
.15673 4e-05 L
.15692 4e-05 L
.15713 4e-05 L
.15735 4e-05 L
.15754 4e-05 L
.15775 4e-05 L
.1579 4e-05 L
.15804 4e-05 L
.15819 4e-05 L
.15835 4e-05 L
.15849 4e-05 L
.15862 4e-05 L
.15877 4e-05 L
.15892 4e-05 L
.15905 4e-05 L
.1592 4e-05 L
.15935 4e-05 L
.15948 4e-05 L
.15961 4e-05 L
.15973 4e-05 L
.15987 4e-05 L
.16 4e-05 L
.16014 4e-05 L
.16029 4e-05 L
.16045 4e-05 L
.1606 4e-05 L
.16074 4e-05 L
.16087 4e-05 L
.16101 4e-05 L
.16115 4e-05 L
.1613 4e-05 L
.16146 4e-05 L
.16162 4e-05 L
.16175 4e-05 L
.16191 4e-05 L
.16209 4e-05 L
.16225 4e-05 L
Mistroke
.16241 4e-05 L
Mfstroke
4e-05 .99996 m
.00663 .99996 L
.01381 .99996 L
.02056 .99996 L
.02704 .99996 L
.03395 .99996 L
.0406 .99996 L
.04766 .99996 L
.05447 .99996 L
.06102 .99996 L
.06799 .99996 L
.0747 .99996 L
.08115 .99996 L
.08801 .99996 L
.09462 .99996 L
.10165 .99996 L
.10842 .99996 L
.11493 .99996 L
.12186 .99996 L
.12853 .99996 L
.13562 .99996 L
.14245 .99996 L
.14903 .99996 L
.15602 .99996 L
.16241 .99996 L
s
.89066 .71509 m
.89266 .71872 L
.89484 .72275 L
.89689 .7266 L
.89886 .73038 L
.90095 .73448 L
.90297 .73851 L
.90512 .7429 L
.90718 .74723 L
.90917 .7515 L
.91128 .75618 L
.91332 .76081 L
.91528 .76542 L
.91736 .77049 L
.91937 .77556 L
.9215 .7812 L
.92355 .78689 L
.92553 .79268 L
.92763 .79923 L
.92966 .80603 L
.93181 .81395 L
.93388 .82255 L
.93588 .83224 L
.93689 .83802 L
.938 .84554 L
.93848 .84946 L
.939 .85446 L
.93925 .85737 L
.93949 .86067 L
.9397 .86449 L
.93976 .86583 L
.93982 .86752 L
.93988 .8694 L
.93994 .87428 L
s
.89066 .99996 m
.89266 .99769 L
.89484 .99515 L
.89689 .99269 L
.89886 .99025 L
.90095 .98758 L
.90297 .98492 L
.90512 .982 L
.90718 .97907 L
.90917 .97615 L
.91128 .97292 L
.91332 .96967 L
.91528 .9664 L
.91736 .96275 L
.91937 .95904 L
.9215 .95486 L
.92355 .95056 L
.92553 .94612 L
.92763 .941 L
.92966 .93558 L
.93181 .92913 L
.93388 .92194 L
.93588 .91361 L
.93689 .90852 L
.938 .90175 L
.93848 .89816 L
.939 .89352 L
.93925 .89077 L
.93949 .88764 L
.9397 .88396 L
.93976 .88267 L
.93982 .88102 L
.93988 .87917 L
.93994 .87434 L
s
1 1 .5 r
.89066 .71509 m
.89266 .71872 L
.89484 .72275 L
.89689 .7266 L
.89886 .73038 L
.90095 .73448 L
.90297 .73851 L
.90512 .7429 L
.90718 .74723 L
.90917 .7515 L
.91128 .75618 L
.91332 .76081 L
.91528 .76542 L
.91736 .77049 L
.91937 .77556 L
.9215 .7812 L
.92355 .78689 L
.92553 .79268 L
.92763 .79923 L
.92966 .80603 L
.93181 .81395 L
.93388 .82255 L
.93588 .83224 L
.93689 .83802 L
.938 .84554 L
.93848 .84946 L
.939 .85446 L
.93925 .85737 L
.93949 .86067 L
.9397 .86449 L
.93976 .86583 L
.93982 .86752 L
.93988 .8694 L
.93994 .87428 L
.93994 .87434 L
.93988 .87917 L
.93982 .88102 L
.93976 .88267 L
.9397 .88396 L
.93949 .88764 L
.93925 .89077 L
.939 .89352 L
.93848 .89816 L
.938 .90175 L
.93689 .90852 L
.93588 .91361 L
.93388 .92194 L
.93181 .92913 L
.92966 .93558 L
.92763 .941 L
.92553 .94612 L
.92355 .95056 L
.9215 .95486 L
.91937 .95904 L
.91736 .96275 L
.91528 .9664 L
.91332 .96967 L
.91128 .97292 L
.90917 .97615 L
.90718 .97907 L
.90512 .982 L
.90297 .98492 L
.90095 .98758 L
.89886 .99025 L
.89689 .99269 L
.89484 .99515 L
.89266 .99769 L
.89066 .99996 L
F
0 g
.89066 .71509 m
.89266 .71872 L
.89484 .72275 L
.89689 .7266 L
.89886 .73038 L
.90095 .73448 L
.90297 .73851 L
.90512 .7429 L
.90718 .74723 L
.90917 .7515 L
.91128 .75618 L
.91332 .76081 L
.91528 .76542 L
.91736 .77049 L
.91937 .77556 L
.9215 .7812 L
.92355 .78689 L
.92553 .79268 L
.92763 .79923 L
.92966 .80603 L
.93181 .81395 L
.93388 .82255 L
.93588 .83224 L
.93689 .83802 L
.938 .84554 L
.93848 .84946 L
.939 .85446 L
.93925 .85737 L
.93949 .86067 L
.9397 .86449 L
.93976 .86583 L
.93982 .86752 L
.93988 .8694 L
.93994 .87428 L
s
.89066 .99996 m
.89266 .99769 L
.89484 .99515 L
.89689 .99269 L
.89886 .99025 L
.90095 .98758 L
.90297 .98492 L
.90512 .982 L
.90718 .97907 L
.90917 .97615 L
.91128 .97292 L
.91332 .96967 L
.91528 .9664 L
.91736 .96275 L
.91937 .95904 L
.9215 .95486 L
.92355 .95056 L
.92553 .94612 L
.92763 .941 L
.92966 .93558 L
.93181 .92913 L
.93388 .92194 L
.93588 .91361 L
.93689 .90852 L
.938 .90175 L
.93848 .89816 L
.939 .89352 L
.93925 .89077 L
.93949 .88764 L
.9397 .88396 L
.93976 .88267 L
.93982 .88102 L
.93988 .87917 L
.93994 .87434 L
s
.16241 4e-05 m
.19195 .02347 L
.22417 .04921 L
.25443 .07359 L
.28353 .09724 L
.3145 .12263 L
.34432 .14732 L
.37601 .17383 L
.40655 .19968 L
.43592 .22485 L
.46717 .25199 L
.49726 .27852 L
.52619 .30442 L
.557 .33249 L
.58665 .36003 L
.61817 .38998 L
.64853 .41957 L
.67774 .44883 L
.70882 .481 L
.73874 .51319 L
.77054 .54904 L
.80117 .58568 L
.83065 .62357 L
.86201 .66807 L
.89066 .71509 L
s
.16241 .99996 m
.19195 .99996 L
.22417 .99996 L
.25443 .99996 L
.28353 .99996 L
.3145 .99996 L
.34432 .99996 L
.37601 .99996 L
.40655 .99996 L
.43592 .99996 L
.46717 .99996 L
.49726 .99996 L
.52619 .99996 L
.557 .99996 L
.58665 .99996 L
.61817 .99996 L
.64853 .99996 L
.67774 .99996 L
.70882 .99996 L
.73874 .99996 L
.77054 .99996 L
.80117 .99996 L
.83065 .99996 L
.86201 .99996 L
.89066 .99996 L
s
1 1 .5 r
.16241 4e-05 m
.19195 .02347 L
.22417 .04921 L
.25443 .07359 L
.28353 .09724 L
.3145 .12263 L
.34432 .14732 L
.37601 .17383 L
.40655 .19968 L
.43592 .22485 L
.46717 .25199 L
.49726 .27852 L
.52619 .30442 L
.557 .33249 L
.58665 .36003 L
.61817 .38998 L
.64853 .41957 L
.67774 .44883 L
.70882 .481 L
.73874 .51319 L
.77054 .54904 L
.80117 .58568 L
.83065 .62357 L
.86201 .66807 L
.89066 .71509 L
.89066 .99996 L
.86201 .99996 L
.83065 .99996 L
.80117 .99996 L
.77054 .99996 L
.73874 .99996 L
.70882 .99996 L
.67774 .99996 L
.64853 .99996 L
.61817 .99996 L
.58665 .99996 L
.557 .99996 L
.52619 .99996 L
.49726 .99996 L
.46717 .99996 L
.43592 .99996 L
.40655 .99996 L
.37601 .99996 L
.34432 .99996 L
.3145 .99996 L
.28353 .99996 L
.25443 .99996 L
.22417 .99996 L
.19195 .99996 L
.16241 .99996 L
F
0 g
.16241 4e-05 m
.19195 .02347 L
.22417 .04921 L
.25443 .07359 L
.28353 .09724 L
.3145 .12263 L
.34432 .14732 L
.37601 .17383 L
.40655 .19968 L
.43592 .22485 L
.46717 .25199 L
.49726 .27852 L
.52619 .30442 L
.557 .33249 L
.58665 .36003 L
.61817 .38998 L
.64853 .41957 L
.67774 .44883 L
.70882 .481 L
.73874 .51319 L
.77054 .54904 L
.80117 .58568 L
.83065 .62357 L
.86201 .66807 L
.89066 .71509 L
s
.16241 .99996 m
.19195 .99996 L
.22417 .99996 L
.25443 .99996 L
.28353 .99996 L
.3145 .99996 L
.34432 .99996 L
.37601 .99996 L
.40655 .99996 L
.43592 .99996 L
.46717 .99996 L
.49726 .99996 L
.52619 .99996 L
.557 .99996 L
.58665 .99996 L
.61817 .99996 L
.64853 .99996 L
.67774 .99996 L
.70882 .99996 L
.73874 .99996 L
.77054 .99996 L
.80117 .99996 L
.83065 .99996 L
.86201 .99996 L
.89066 .99996 L
s
1 .5 0 r
.01 w
.15689 .86272 Mdot
.30198 .71763 Mdot
.6392 .4902 Mdot
.58823 .43138 Mdot
.69018 .52549 Mdot
.3059 .72155 Mdot
.75292 .40785 Mdot
.66665 .42746 Mdot
.29413 .72155 Mdot
.54509 .251 Mdot
.44706 .05102 Mdot
.61568 .48235 Mdot
.63528 .49412 Mdot
.81174 .07454 Mdot
.63136 .24708 Mdot
.58039 .42746 Mdot
.41569 .07062 Mdot
.84703 .08239 Mdot
.49804 .06278 Mdot
.57254 .43138 Mdot
.43922 .01572 Mdot
.79606 .08239 Mdot
.57254 .02749 Mdot
.6196 .49804 Mdot
.40393 .01572 Mdot
.62744 .03533 Mdot
.52549 .02749 Mdot
.85487 .83135 Mdot
.59215 .39217 Mdot
.61176 .01572 Mdot
.87056 .16865 Mdot
.49804 .0118 Mdot
.58431 .45883 Mdot
.54117 .01965 Mdot
.64705 .02749 Mdot
.6941 .03533 Mdot
.81174 .8039 Mdot
.57254 .40393 Mdot
.59607 .00788 Mdot
.65881 .05494 Mdot
.61568 .03533 Mdot
.6745 .65097 Mdot
.39217 .0667 Mdot
.6392 .02749 Mdot
.68234 .07062 Mdot
.55686 .04317 Mdot
.76076 .74116 Mdot
.40001 .05494 Mdot
.60783 .01572 Mdot
.67057 .0667 Mdot
.24316 .03925 Mdot
.84311 .8235 Mdot
.38824 .18042 Mdot
.61176 .01572 Mdot
.6941 .06278 Mdot
.55686 .51372 Mdot
.83527 .73724 Mdot
.12944 .84703 Mdot
.55294 .01572 Mdot
.68626 .03925 Mdot
.81566 .74508 Mdot
.58431 .02357 Mdot
.79606 .81174 Mdot
.43922 .0118 Mdot
.65489 .02749 Mdot
.48628 .11768 Mdot
.91369 .87448 Mdot
.87448 .84311 Mdot
.51765 .32943 Mdot
.54902 .01965 Mdot
.68626 .03925 Mdot
.92546 .90193 Mdot
.47843 .06278 Mdot
.83135 .83527 Mdot
.30982 4e-05 Mdot
.59215 .02357 Mdot
.63528 .07062 Mdot
.90193 .89801 Mdot
.49412 .05886 Mdot
.80782 .81174 Mdot
.43922 .00788 Mdot
.63528 .01572 Mdot
.83135 .76076 Mdot
.90193 .90193 Mdot
.89409 .83135 Mdot
.65881 .62352 Mdot
.45491 4e-05 Mdot
.62744 .02357 Mdot
.90977 .89017 Mdot
.88232 .88232 Mdot
.72155 .68234 Mdot
.66273 .59999 Mdot
.56078 .01965 Mdot
.62744 .02749 Mdot
.88624 .89017 Mdot
.89017 .88232 Mdot
.76076 .67057 Mdot
.57646 .54902 Mdot
.73724 .05102 Mdot
.61176 .02357 Mdot
.89801 .89801 Mdot
.88232 .88232 Mdot
.41569 .11376 Mdot
.75292 .75684 Mdot
.74508 .05494 Mdot
.62744 .02357 Mdot
.88624 .89017 Mdot
.87448 .87448 Mdot
.52549 .01965 Mdot
.81566 .81566 Mdot
.70194 .08631 Mdot
.63136 .02357 Mdot
.87056 .86664 Mdot
.89801 .8784 Mdot
.48628 .04317 Mdot
.79998 .81566 Mdot
.60391 .00788 Mdot
.53333 .0118 Mdot
.8235 .75292 Mdot
.89017 .82743 Mdot
.87448 .85095 Mdot
.79998 .78429 Mdot
.5098 .00396 Mdot
.79213 .05494 Mdot
.56078 .07062 Mdot
.88624 .87448 Mdot
.87056 .86664 Mdot
.78821 .75292 Mdot
.34511 .14905 Mdot
.72547 .04317 Mdot
.63528 .02749 Mdot
.88232 .88624 Mdot
.61568 .05886 Mdot
.56862 .06278 Mdot
.81566 .83135 Mdot
.67842 .03533 Mdot
.8039 .05102 Mdot
.8588 .85095 Mdot
.62352 .07454 Mdot
.84703 .85487 Mdot
.81958 .80782 Mdot
.53333 .09415 Mdot
.76076 .04317 Mdot
.59607 .02749 Mdot
.88624 .78821 Mdot
.61568 .03925 Mdot
.49412 .02749 Mdot
.75292 .77253 Mdot
.65097 .02357 Mdot
.81174 .05494 Mdot
.84703 .84311 Mdot
.65097 .05102 Mdot
.84703 .84703 Mdot
.71763 .70194 Mdot
.55294 .10983 Mdot
.73332 .04317 Mdot
.58039 .02749 Mdot
.6196 .18826 Mdot
.61568 .03533 Mdot
.51372 .03925 Mdot
.79998 .81958 Mdot
.64705 .02357 Mdot
.79998 .05102 Mdot
.87056 .85095 Mdot
.65881 .07062 Mdot
.87056 .82743 Mdot
.76076 .72939 Mdot
.35687 .28629 Mdot
.72155 .03925 Mdot
.83919 .07846 Mdot
.64705 .09023 Mdot
.65489 .03925 Mdot
.64705 .19218 Mdot
.79998 .81566 Mdot
.58039 .00788 Mdot
.77645 .05102 Mdot
.84311 .83919 Mdot
.65489 .07846 Mdot
.55294 .00396 Mdot
.66665 .33727 Mdot
.54117 .47843 Mdot
.63528 .01572 Mdot
.81958 .06278 Mdot
.64705 .41961 Mdot
.16081 .03141 Mdot
.85487 .84311 Mdot
.64705 .62352 Mdot
.43922 .1412 Mdot
.74508 .04709 Mdot
.83527 .74116 Mdot
.66273 .07062 Mdot
.61568 .03925 Mdot
.65097 .15689 Mdot
.73332 .75292 Mdot
.56862 .00396 Mdot
.78821 .05886 Mdot
.86272 .85095 Mdot
.72155 .66273 Mdot
.53333 .00788 Mdot
.4353 .1765 Mdot
.36864 .29413 Mdot
.63136 .0118 Mdot
.82743 .07062 Mdot
.66273 .05494 Mdot
.89409 .84703 Mdot
.76076 .6196 Mdot
.66273 .65881 Mdot
.62744 .62744 Mdot
.73332 .04317 Mdot
.89017 .88624 Mdot
.23531 .08239 Mdot
.61176 .04317 Mdot
.68234 .0667 Mdot
.73724 .77253 Mdot
.55686 .00788 Mdot
.78037 .04709 Mdot
.83919 .65489 Mdot
.89017 .88624 Mdot
.54902 .00788 Mdot
.54509 .22355 Mdot
.47059 .45098 Mdot
.60391 .00788 Mdot
.81174 .07062 Mdot
.62744 .05102 Mdot
.8784 .8784 Mdot
.83527 .77645 Mdot
.6941 .66273 Mdot
.45883 .48235 Mdot
.71371 .03925 Mdot
.88624 .88232 Mdot
.88232 .85095 Mdot
.51765 .23924 Mdot
.75292 .03533 Mdot
.77253 .80782 Mdot
.20394 .00396 Mdot
.78037 .04709 Mdot
.749 .1216 Mdot
.87056 .8784 Mdot
.60391 .02357 Mdot
.51372 .01572 Mdot
.56078 .60783 Mdot
.56078 .00396 Mdot
.78429 .07454 Mdot
.62352 .11376 Mdot
.87056 .87448 Mdot
.86272 .83527 Mdot
.8039 .68626 Mdot
.76469 .75292 Mdot
.6392 .04709 Mdot
.8784 .88232 Mdot
.8784 .88232 Mdot
.68626 .52941 Mdot
.72547 .04709 Mdot
.8039 .83527 Mdot
.16865 .00788 Mdot
.76076 .04709 Mdot
.81958 .07846 Mdot
.89409 .88232 Mdot
.6392 .02357 Mdot
.6745 .04709 Mdot
.52549 .57646 Mdot
.47843 .00788 Mdot
.73724 .09023 Mdot
.44706 .25884 Mdot
.85487 .80782 Mdot
.83527 .81174 Mdot
.58039 .23139 Mdot
.50588 .65489 Mdot
.64313 .03141 Mdot
.8588 .8588 Mdot
.86664 .86664 Mdot
.51765 .23531 Mdot
.54117 4e-05 Mdot
.79606 .8235 Mdot
.14513 .0118 Mdot
.63136 .05886 Mdot
.77253 .05886 Mdot
.56078 .1961 Mdot
.62744 .02357 Mdot
.70587 .02357 Mdot
.79606 .83135 Mdot
.03533 4e-05 Mdot
.76469 .05102 Mdot
.4353 .1765 Mdot
.34903 .08239 Mdot
.75684 .55686 Mdot
.50588 .03533 Mdot
.21571 .21179 Mdot
.44314 .0118 Mdot
.86272 .8784 Mdot
.85095 .85095 Mdot
.8039 .71371 Mdot
.53725 .03925 Mdot
.81174 .6196 Mdot
.32158 .36864 Mdot
.6392 .03533 Mdot
.749 .06278 Mdot
.59215 .10591 Mdot
.6392 .03925 Mdot
.52549 4e-05 Mdot
.79998 .81958 Mdot
.05102 .0118 Mdot
.749 .04317 Mdot
.75292 .08631 Mdot
.29806 .07062 Mdot
.58431 .03141 Mdot
.69018 .02357 Mdot
.6941 .74508 Mdot
.16081 .00396 Mdot
.69018 .54509 Mdot
.84311 .84311 Mdot
.88232 .8235 Mdot
.83527 .8039 Mdot
.52157 .01965 Mdot
.43922 .34119 Mdot
.41177 .00788 Mdot
.61568 .22355 Mdot
.8784 .8588 Mdot
.65097 .04709 Mdot
.53725 .00396 Mdot
.73332 .63136 Mdot
.24316 .28629 Mdot
.68234 .03141 Mdot
.46275 .04317 Mdot
.28237 .17257 Mdot
.63528 .02749 Mdot
.52549 .00788 Mdot
.73724 .77253 Mdot
.00396 4e-05 Mdot
.76469 .06278 Mdot
.8588 .84311 Mdot
.86664 .86272 Mdot
.76861 .50588 Mdot
.68234 .03141 Mdot
.49804 .5647 Mdot
.21179 .00396 Mdot
.87056 .8784 Mdot
.76469 .1412 Mdot
.18826 .04317 Mdot
.51372 .03141 Mdot
.47843 .03533 Mdot
.30198 .73724 Mdot
.43138 4e-05 Mdot
.68234 .61568 Mdot
.88624 .87056 Mdot
.55294 .07454 Mdot
.51765 .00396 Mdot
.64705 .60391 Mdot
.03925 .00396 Mdot
.69018 .03533 Mdot
.66665 .40001 Mdot
.70979 .73332 Mdot
.63136 .03141 Mdot
.51372 .00396 Mdot
.78821 .83135 Mdot
.08239 .00396 Mdot
.88232 .68234 Mdot
.32943 .29021 Mdot
.86272 .81566 Mdot
.83527 .81566 Mdot
.67057 .01965 Mdot
.48628 .53333 Mdot
.23139 .00396 Mdot
.36472 .13336 Mdot
.8039 .76469 Mdot
.87056 .85487 Mdot
.56078 .00788 Mdot
.53725 .02749 Mdot
.31766 .36864 Mdot
.43138 .0118 Mdot
.86272 .84311 Mdot
.84703 .8235 Mdot
.51765 .07846 Mdot
.53725 .01572 Mdot
.65489 .65489 Mdot
.00396 .00396 Mdot
.75292 .05102 Mdot
.89409 .8039 Mdot
.86664 .86664 Mdot
.74508 .45098 Mdot
.50196 .00396 Mdot
.72939 .78429 Mdot
.15297 .00396 Mdot
.79213 .79998 Mdot
.88624 .84311 Mdot
.86664 .8588 Mdot
.44314 .09415 Mdot
.6745 .01572 Mdot
.63528 .59215 Mdot
.24708 4e-05 Mdot
.83135 .80782 Mdot
.81566 .78429 Mdot
.85095 .85095 Mdot
.56078 .00788 Mdot
.59215 .05494 Mdot
.08239 .11768 Mdot
.50588 .0118 Mdot
.75292 .04709 Mdot
.90193 .90193 Mdot
.60391 .05102 Mdot
.51372 .00396 Mdot
.65489 .69802 Mdot
4e-05 4e-05 Mdot
.76076 .04709 Mdot
.76861 .08631 Mdot
.86272 .86272 Mdot
.83135 .82743 Mdot
.51372 4e-05 Mdot
.72155 .78429 Mdot
.1765 4e-05 Mdot
.65881 .18826 Mdot
.3255 .08239 Mdot
.86272 .79998 Mdot
.58039 .01965 Mdot
.6745 .02357 Mdot
.26276 .68626 Mdot
.41177 .01572 Mdot
.76469 .05886 Mdot
.89017 .89017 Mdot
.85095 .82743 Mdot
.53333 .00788 Mdot
.50196 .04317 Mdot
.00396 4e-05 Mdot
.54117 .0118 Mdot
.75684 .05102 Mdot
.94898 .77645 Mdot
.58039 .20394 Mdot
.52549 .00396 Mdot
.72939 .78429 Mdot
.09807 .00396 Mdot
.78429 .05886 Mdot
.56862 .08239 Mdot
.75292 .09415 Mdot
.84703 .8039 Mdot
.52549 .00396 Mdot
.4353 .49412 Mdot
.34119 .00396 Mdot
.72155 .03141 Mdot
.84703 .85487 Mdot
.84703 .84311 Mdot
.5647 .00788 Mdot
.6941 .03533 Mdot
.34903 .40001 Mdot
.59215 .03925 Mdot
.749 .04709 Mdot
.8039 .38432 Mdot
.59215 .0667 Mdot
.52157 .00396 Mdot
.65489 .55294 Mdot
.02749 4e-05 Mdot
.57254 .00788 Mdot
.73724 .05102 Mdot
.8235 .08239 Mdot
.84703 .8235 Mdot
.51765 .00788 Mdot
.76861 .82743 Mdot
.28237 .00396 Mdot
.75684 .04317 Mdot
.85487 .85095 Mdot
.39217 .27453 Mdot
.45491 .37648 Mdot
.56078 .00788 Mdot
.42746 .40001 Mdot
.1961 4e-05 Mdot
.76469 .05102 Mdot
.71763 .23924 Mdot
.4353 .1961 Mdot
.53333 .00396 Mdot
.70194 .04709 Mdot
.05886 .08631 Mdot
.45098 .03141 Mdot
.74116 .03925 Mdot
.81958 .08239 Mdot
.59607 .05494 Mdot
.49804 .00396 Mdot
.56862 .41961 Mdot
.16865 4e-05 Mdot
.61568 .0118 Mdot
.8588 .82743 Mdot
.24708 .07454 Mdot
.80782 .81174 Mdot
.50588 4e-05 Mdot
.68626 .749 Mdot
.31374 .00396 Mdot
.76469 .05494 Mdot
.32943 .3608 Mdot
.77253 .77253 Mdot
.23531 .22747 Mdot
.63136 .03925 Mdot
.23924 .67842 Mdot
.59215 .36472 Mdot
.73724 .04709 Mdot
.72155 .15297 Mdot
.50196 .42354 Mdot
.51765 .00396 Mdot
.69018 .05886 Mdot
.20002 .00788 Mdot
.55686 .01572 Mdot
.70587 .25884 Mdot
.23531 .04709 Mdot
.74508 .51372 Mdot
.49804 .00396 Mdot
.62352 .63136 Mdot
.27453 .0118 Mdot
.62352 .01965 Mdot
.8235 .77645 Mdot
.86272 .8784 Mdot
.8039 .81958 Mdot
.44706 .00788 Mdot
.58431 .64705 Mdot
.27845 4e-05 Mdot
.72547 .03533 Mdot
.84311 .84703 Mdot
.83527 .84703 Mdot
.66273 .6392 Mdot
.6745 .05102 Mdot
.63528 .70587 Mdot
.50196 .0118 Mdot
.6941 .01572 Mdot
.20394 .08239 Mdot
.64313 .47843 Mdot
.51372 .00396 Mdot
.65097 .16081 Mdot
.22747 .0118 Mdot
.57646 .01572 Mdot
.8588 .83527 Mdot
.84311 .8588 Mdot
.84311 .83527 Mdot
.4902 .00396 Mdot
.61568 .66273 Mdot
.19218 .00396 Mdot
.63528 .01572 Mdot
.83527 .8235 Mdot
.83919 .8588 Mdot
.79998 .81958 Mdot
.40785 .00396 Mdot
.33335 .33335 Mdot
.38432 .00788 Mdot
.65097 .01965 Mdot
.10199 .16865 Mdot
.8235 .84703 Mdot
.47451 .09023 Mdot
.67842 .0667 Mdot
.66273 .70979 Mdot
.51372 .01572 Mdot
.71371 .03141 Mdot
.8588 .86272 Mdot
.58039 .07062 Mdot
.49804 4e-05 Mdot
.63528 .04709 Mdot
.1412 .00396 Mdot
.55686 .0118 Mdot
.65881 .13336 Mdot
.85095 .84703 Mdot
.82743 .76469 Mdot
.47843 .00396 Mdot
.6392 .69018 Mdot
.18826 .00396 Mdot
.57254 .00396 Mdot
.64705 .16081 Mdot
.47059 .22747 Mdot
.81566 .83135 Mdot
.3608 .00396 Mdot
.45098 .51372 Mdot
.3059 .00396 Mdot
.66273 .01572 Mdot
.8039 .79213 Mdot
.83919 .84703 Mdot
.50196 .04317 Mdot
.50588 .02357 Mdot
.44314 .45098 Mdot
.48628 .0118 Mdot
.70194 .02357 Mdot
.83527 .85095 Mdot
.21179 .04317 Mdot
.52157 .00396 Mdot
.69018 .04709 Mdot
.17257 .00396 Mdot
.55686 .01965 Mdot
.70587 .03533 Mdot
.67057 .21179 Mdot
.59999 .04317 Mdot
.51765 .0118 Mdot
.42354 .07454 Mdot
.14905 .00396 Mdot
.56078 .01572 Mdot
.56862 .08239 Mdot
.66273 .65881 Mdot
.80782 .8235 Mdot
.47451 .00396 Mdot
.71763 .76861 Mdot
.20002 .00396 Mdot
.56078 .01572 Mdot
.83135 .83527 Mdot
.84311 .84703 Mdot
.62352 .5098 Mdot
.85095 .70194 Mdot
.18042 .60783 Mdot
.40785 .00788 Mdot
.67842 .03533 Mdot
.83919 .74508 Mdot
.81958 .84703 Mdot
.53725 .00396 Mdot
.57646 .03141 Mdot
.16473 .08239 Mdot
.50196 .0118 Mdot
.70194 .03533 Mdot
.14905 .09807 Mdot
.58431 .07062 Mdot
.50588 4e-05 Mdot
.63136 .03533 Mdot
.13336 .00396 Mdot
.54117 .00788 Mdot
.34511 .06278 Mdot
.8588 .86664 Mdot
.55294 .05886 Mdot
.46667 .00396 Mdot
.74116 .76469 Mdot
.15689 4e-05 Mdot
.55686 .00788 Mdot
.84311 .84311 Mdot
.83527 .85095 Mdot
.79606 .81566 Mdot
.45098 .00396 Mdot
.4902 .50588 Mdot
.34511 .00788 Mdot
.6196 .01572 Mdot
.37256 .12944 Mdot
.8235 .83527 Mdot
.5098 .01965 Mdot
.45491 4e-05 Mdot
.42746 .3608 Mdot
.47451 .00788 Mdot
.68234 .02749 Mdot
.85095 .85487 Mdot
.54117 .07846 Mdot
.51765 .00788 Mdot
.58823 .01572 Mdot
.13336 .00396 Mdot
.50588 .0118 Mdot
.73332 .51372 Mdot
.84703 .86664 Mdot
.60783 .04317 Mdot
.4902 .00396 Mdot
.47451 .09023 Mdot
.18434 .00396 Mdot
.52941 .00396 Mdot
.81566 .84311 Mdot
.36472 .37648 Mdot
.52941 .05886 Mdot
.45883 .00396 Mdot
.75684 .81566 Mdot
.3255 .00788 Mdot
.57254 .00788 Mdot
.67057 .67842 Mdot
.83527 .85095 Mdot
.8039 .81174 Mdot
.45098 4e-05 Mdot
.34119 .41177 Mdot
.38432 .00788 Mdot
.69018 .03533 Mdot
.84311 .85487 Mdot
.60783 .0667 Mdot
.50588 .00396 Mdot
.59607 .01572 Mdot
.1216 .00396 Mdot
.44314 .00396 Mdot
.58431 .0667 Mdot
.81566 .68234 Mdot
.62352 .03141 Mdot
.50588 .00396 Mdot
.57254 .02749 Mdot
.13728 4e-05 Mdot
.53725 .0118 Mdot
.81174 .83135 Mdot
.61568 .61176 Mdot
.59607 .02749 Mdot
.4902 .00396 Mdot
.77645 .79606 Mdot
.26276 .00788 Mdot
.5647 .00396 Mdot
.83135 .84703 Mdot
.749 .49412 Mdot
.56078 .03533 Mdot
.45491 .00396 Mdot
.47451 .41961 Mdot
.32158 4e-05 Mdot
.62352 .02357 Mdot
.85095 .83919 Mdot
.71371 .06278 Mdot
.6392 .55294 Mdot
.5098 .00396 Mdot
.21179 .00788 Mdot
.42354 .00396 Mdot
.68626 .03925 Mdot
.70194 .1412 Mdot
.58823 .04709 Mdot
.49412 .00396 Mdot
.55294 .00788 Mdot
.12552 .00788 Mdot
.4902 4e-05 Mdot
.75292 .69802 Mdot
.85487 .8588 Mdot
.48235 .07062 Mdot
.47451 .00396 Mdot
.42746 .03925 Mdot
.24316 .00396 Mdot
.55686 4e-05 Mdot
.83919 .84703 Mdot
.75292 .08631 Mdot
.53333 .03533 Mdot
.45098 4e-05 Mdot
.47451 .52157 Mdot
.27845 .00396 Mdot
.59607 .02357 Mdot
.6745 .1412 Mdot
.15297 .02357 Mdot
.57254 .02749 Mdot
.46275 4e-05 Mdot
.21179 .0118 Mdot
.3608 .00396 Mdot
.6941 .03925 Mdot
.78037 .08631 Mdot
.56862 .59999 Mdot
.52549 .01572 Mdot
.61176 .01965 Mdot
.10591 .00788 Mdot
.4902 .00396 Mdot
.59607 .15297 Mdot
.6745 .25884 Mdot
.78821 .79606 Mdot
.4902 .00396 Mdot
.51765 4e-05 Mdot
.21963 .00396 Mdot
.54117 .00396 Mdot
.71371 .5647 Mdot
.08239 .05494 Mdot
.76076 .76469 Mdot
.44706 .00396 Mdot
.56078 .56862 Mdot
.26276 .00396 Mdot
.60391 .02749 Mdot
.65881 .21963 Mdot
.84311 .85095 Mdot
.09415 .06278 Mdot
.45098 .00396 Mdot
.33727 .28237 Mdot
.35687 .00788 Mdot
.66665 .04317 Mdot
.77253 .07062 Mdot
.8235 .83919 Mdot
.52157 .0118 Mdot
.53725 .0118 Mdot
.11768 .00396 Mdot
.43922 .00396 Mdot
.71371 .04709 Mdot
.16865 .0118 Mdot
.81958 .83135 Mdot
.47059 4e-05 Mdot
.53725 .00396 Mdot
.13728 .00788 Mdot
.37256 .00396 Mdot
.18434 .05886 Mdot
.87056 .8784 Mdot
.81174 .83919 Mdot
.46667 4e-05 Mdot
.36864 .04709 Mdot
.23924 .00396 Mdot
.57646 .00788 Mdot
.84703 .84703 Mdot
.83919 .8588 Mdot
.79998 .81566 Mdot
.37648 4e-05 Mdot
.47059 .47843 Mdot
.30198 4e-05 Mdot
.59607 .02357 Mdot
.65097 .10591 Mdot
.83527 .85487 Mdot
.46275 .34903 Mdot
.45491 4e-05 Mdot
.23924 .00396 Mdot
.40001 .00396 Mdot
.67842 .04317 Mdot
.80782 .82743 Mdot
.8039 .83527 Mdot
.49412 4e-05 Mdot
.56862 .00396 Mdot
.11768 .00396 Mdot
.4902 .00396 Mdot
.749 .54902 Mdot
.87448 .8784 Mdot
.82743 .8235 Mdot
.44314 .00396 Mdot
.51372 .0118 Mdot
.20002 .00396 Mdot
.55294 .00788 Mdot
.85095 .85095 Mdot
.8588 .87448 Mdot
.81566 .83135 Mdot
.45883 .00396 Mdot
.51765 .53725 Mdot
.13728 4e-05 Mdot
.59999 .0118 Mdot
.30982 .34903 Mdot
.81958 .72939 Mdot
.79213 .81958 Mdot
.48628 .00396 Mdot
.1216 .55294 Mdot
.36472 .00396 Mdot
.64313 .03141 Mdot
.85487 .87056 Mdot
.47451 .11768 Mdot
.40785 .10591 Mdot
.56862 .02357 Mdot
.28629 .01572 Mdot
.42746 .00788 Mdot
.70587 .04317 Mdot
.88624 .89017 Mdot
.04709 .03141 Mdot
.5098 .0118 Mdot
.57646 .00396 Mdot
.1765 4e-05 Mdot
.44706 .00788 Mdot
.68234 .05494 Mdot
.85095 .86664 Mdot
.51372 .36864 Mdot
.52157 .02357 Mdot
.53333 .00396 Mdot
.12552 .00396 Mdot
.4902 .00396 Mdot
.80782 .50196 Mdot
.86272 .66273 Mdot
.52549 .09415 Mdot
.4902 .00396 Mdot
.45883 4e-05 Mdot
.20394 .0118 Mdot
.52549 .00396 Mdot
.41961 .3804 Mdot
.72155 .11376 Mdot
.55294 .03533 Mdot
.4902 .0118 Mdot
.6196 .56078 Mdot
.12944 4e-05 Mdot
.56862 .00788 Mdot
.88624 .90193 Mdot
.41961 .42746 Mdot
.6392 .64313 Mdot
.50196 .00788 Mdot
.14905 .12552 Mdot
.14905 .00788 Mdot
.58823 .01965 Mdot
.87056 .89017 Mdot
.84703 .87056 Mdot
.79606 .83135 Mdot
.52941 .01965 Mdot
.12944 .56078 Mdot
.25492 .00396 Mdot
.59607 .03141 Mdot
.86664 .88232 Mdot
.8235 .85095 Mdot
.44706 .08239 Mdot
.35687 4e-05 Mdot
.24316 .00788 Mdot
.32943 4e-05 Mdot
.67057 .03533 Mdot
.73332 .27453 Mdot
.75684 .69018 Mdot
.49804 .00788 Mdot
.32158 .00788 Mdot
.22355 .00396 Mdot
.40393 .00396 Mdot
.58039 .09023 Mdot
.79998 .07454 Mdot
.60391 .03925 Mdot
.48628 .00396 Mdot
.58431 .0118 Mdot
.12552 4e-05 Mdot
.47451 .00788 Mdot
.83527 .84703 Mdot
.3255 .14905 Mdot
.52549 .03141 Mdot
.51372 .00788 Mdot
.51372 .00396 Mdot
.18434 4e-05 Mdot
.50196 4e-05 Mdot
.83919 .8588 Mdot
.85487 .86272 Mdot
.34903 .37648 Mdot
.49804 .00396 Mdot
.4902 .23531 Mdot
.24708 .00396 Mdot
.52157 .00396 Mdot
.8588 .87448 Mdot
.83527 .85095 Mdot
.81566 .81958 Mdot
.49804 .00396 Mdot
.41569 .40001 Mdot
.27453 .00396 Mdot
.53725 4e-05 Mdot
.64313 .27061 Mdot
.78821 .64705 Mdot
.47843 .07454 Mdot
.5098 .01572 Mdot
.15297 .05102 Mdot
.3255 .00788 Mdot
.58039 .00788 Mdot
.80782 .08239 Mdot
.60783 .05886 Mdot
.53333 .01572 Mdot
.58039 .02357 Mdot
.3059 .03533 Mdot
.27845 .00396 Mdot
.27845 .01965 Mdot
.83527 .07846 Mdot
.50588 .0667 Mdot
.51372 4e-05 Mdot
.67842 .03925 Mdot
.21179 .00396 Mdot
.47059 4e-05 Mdot
.83135 .83135 Mdot
.84703 .50196 Mdot
.34119 .38824 Mdot
.49804 .00396 Mdot
.64705 .02357 Mdot
.1765 .00396 Mdot
.4902 .02749 Mdot
.83527 .83919 Mdot
.86272 .86664 Mdot
.82743 .85095 Mdot
.47451 .00396 Mdot
.54902 .00396 Mdot
.17257 .00788 Mdot
.38432 .01572 Mdot
.78037 .64313 Mdot
.71763 .70979 Mdot
.26276 .22747 Mdot
.5098 .00788 Mdot
.44706 .02357 Mdot
.24316 .0118 Mdot
.51765 .00396 Mdot
.71371 .0667 Mdot
.09023 .01572 Mdot
.03141 .02357 Mdot
.48628 .00788 Mdot
.38824 .34903 Mdot
.22747 4e-05 Mdot
.54117 .00396 Mdot
.72155 .07062 Mdot
.39609 .44314 Mdot
.18042 .21963 Mdot
.51372 .00396 Mdot
.03925 .00396 Mdot
.16865 .00396 Mdot
.32943 .03141 Mdot
.72939 .08239 Mdot
.8039 .83527 Mdot
.03533 .01572 Mdot
.54509 .0118 Mdot
.22747 .59215 Mdot
.41569 .0118 Mdot
.81174 .81958 Mdot
.75292 .04709 Mdot
.78429 .8235 Mdot
.47059 .02749 Mdot
.64313 .03533 Mdot
.18434 4e-05 Mdot
.36472 .00788 Mdot
.81174 .82743 Mdot
.73724 .05886 Mdot
.33335 .40785 Mdot
.52157 .00396 Mdot
.65489 .04317 Mdot
.16473 .00788 Mdot
.23531 4e-05 Mdot
.57646 .18826 Mdot
.68626 .22355 Mdot
.83135 .85095 Mdot
.52157 .00396 Mdot
.59607 .00396 Mdot
.15689 .00396 Mdot
.53725 .00788 Mdot
.23139 .0118 Mdot
.72155 .36472 Mdot
.81566 .84703 Mdot
.51765 .0118 Mdot
.47451 .00788 Mdot
.24316 .0118 Mdot
.55294 .01572 Mdot
.72547 .76469 Mdot
.67057 .1216 Mdot
.80782 .83135 Mdot
.48628 .00396 Mdot
.45883 .38432 Mdot
.29021 .00396 Mdot
.54902 .06278 Mdot
.86664 .86272 Mdot
.35295 .03141 Mdot
.8039 .83919 Mdot
.48235 .0118 Mdot
.01572 4e-05 Mdot
.35295 .00788 Mdot
.78821 .80782 Mdot
.84311 .85487 Mdot
.68626 .72939 Mdot
.80782 .84311 Mdot
.56078 .01572 Mdot
.27061 .03925 Mdot
.47843 .28629 Mdot
.79998 .81958 Mdot
.79998 .65489 Mdot
.81958 .85095 Mdot
.71371 .67057 Mdot
.60783 .01965 Mdot
.15297 .00396 Mdot
.37648 .03533 Mdot
.36864 .11376 Mdot
.76076 .0667 Mdot
.81958 .85095 Mdot
.52941 .01965 Mdot
.61568 .01965 Mdot
.26276 .10983 Mdot
.47059 .00396 Mdot
.73724 .76076 Mdot
.78037 .0667 Mdot
.8039 .80782 Mdot
.48628 4e-05 Mdot
.57254 .00788 Mdot
.08631 .00396 Mdot
.51372 .0118 Mdot
.6941 .51372 Mdot
.73332 .06278 Mdot
.46667 .10983 Mdot
.49804 .0118 Mdot
.50196 4e-05 Mdot
.16865 .00396 Mdot
.54117 .01965 Mdot
.71371 .05886 Mdot
.61568 .62744 Mdot
.4353 .0667 Mdot
.43922 4e-05 Mdot
.56078 .45098 Mdot
.23924 4e-05 Mdot
.42746 .31766 Mdot
.39217 .36864 Mdot
.85487 .87056 Mdot
.71763 .76469 Mdot
.43138 4e-05 Mdot
.00396 .00396 Mdot
.28629 4e-05 Mdot
.79998 .83135 Mdot
.87448 .86272 Mdot
.83527 .86664 Mdot
.78821 .79606 Mdot
.51372 .00396 Mdot
.18434 4e-05 Mdot
.3608 .00396 Mdot
.0667 .08631 Mdot
.75684 .08631 Mdot
.36472 .40785 Mdot
.51372 .03141 Mdot
.52157 .00396 Mdot
.29806 .1216 Mdot
.41177 .00788 Mdot
.81958 .83135 Mdot
.78429 .06278 Mdot
.49804 .09415 Mdot
.49412 .00788 Mdot
.57254 .00788 Mdot
.08631 .00396 Mdot
.35295 .02357 Mdot
.59607 .07062 Mdot
.76469 .07846 Mdot
.39609 .06278 Mdot
.50196 .00788 Mdot
.57254 .00396 Mdot
.08631 .00396 Mdot
.43138 .00788 Mdot
.22355 .0118 Mdot
.40785 .30982 Mdot
.15297 .20787 Mdot
.48628 .00396 Mdot
.57254 .00788 Mdot
.09023 4e-05 Mdot
.52941 .0118 Mdot
.5647 .62744 Mdot
.83919 .8588 Mdot
.79606 .84311 Mdot
.49412 .00788 Mdot
.46667 .03141 Mdot
.07454 4e-05 Mdot
.52941 .01965 Mdot
.84311 .85095 Mdot
.86272 .85487 Mdot
.74508 .70979 Mdot
.45883 .00396 Mdot
.20787 .10199 Mdot
.20002 .00788 Mdot
.62744 .41569 Mdot
.58823 .1961 Mdot
.55686 .14905 Mdot
.4902 .0667 Mdot
.44314 4e-05 Mdot
.00396 4e-05 Mdot
.27061 .00396 Mdot
.78821 .81566 Mdot
.71763 .05494 Mdot
.3608 .05102 Mdot
.40001 .05102 Mdot
.49412 4e-05 Mdot
.04709 4e-05 Mdot
.31374 .00396 Mdot
.72939 .76469 Mdot
.71371 .05494 Mdot
.08631 .1216 Mdot
.12944 4e-05 Mdot
.48628 .00396 Mdot
.25492 .01572 Mdot
.3608 .00396 Mdot
.79998 .82743 Mdot
.70587 .05494 Mdot
.67842 .73724 Mdot
.06278 4e-05 Mdot
.4902 4e-05 Mdot
.251 .00396 Mdot
.38432 .00396 Mdot
.76469 .8039 Mdot
.68234 .03533 Mdot
.81958 .86664 Mdot
.13336 .00396 Mdot
.50588 .00396 Mdot
.37256 .16081 Mdot
.41177 4e-05 Mdot
.81566 .81174 Mdot
.71371 .05494 Mdot
.79213 .84311 Mdot
.39609 .03141 Mdot
.52941 .00396 Mdot
.11376 .00788 Mdot
.45098 .00788 Mdot
.55294 .16473 Mdot
.72547 .05494 Mdot
.68234 .74116 Mdot
.47843 .0118 Mdot
.53333 .00396 Mdot
.05886 .00396 Mdot
.48235 .0118 Mdot
.65097 .03533 Mdot
.71371 .0667 Mdot
.78037 .8235 Mdot
.44706 4e-05 Mdot
.53725 .00396 Mdot
.05102 4e-05 Mdot
.50588 .0118 Mdot
.65881 .03141 Mdot
.66665 .07062 Mdot
.8235 .85095 Mdot
.44314 4e-05 Mdot
.44706 .09023 Mdot
.05494 .00396 Mdot
.50588 .00396 Mdot
.69802 .05102 Mdot
.65097 .05886 Mdot
.8235 .85487 Mdot
.4902 .00396 Mdot
.13336 .07846 Mdot
.06278 .00396 Mdot
.5098 .01572 Mdot
.69018 .04317 Mdot
.43138 .06278 Mdot
.82743 .8588 Mdot
.54509 .00788 Mdot
.00396 4e-05 Mdot
.19218 .00788 Mdot
.54902 .31374 Mdot
.70194 .04709 Mdot
.20394 .24708 Mdot
.82743 .8588 Mdot
.52941 .00396 Mdot
.05886 .00396 Mdot
.26276 4e-05 Mdot
.79998 .83135 Mdot
.71371 .04709 Mdot
.83135 .86664 Mdot
.81566 .85487 Mdot
.54509 .0118 Mdot
.27845 .0118 Mdot
.30982 .00396 Mdot
.78429 .8235 Mdot
.71371 .05102 Mdot
.83919 .87056 Mdot
.81958 .85487 Mdot
.54117 .01572 Mdot
.30198 .00788 Mdot
.35687 .00396 Mdot
.76076 .8039 Mdot
.73724 .05886 Mdot
.83919 .87056 Mdot
.81566 .85487 Mdot
.55294 .00788 Mdot
.21179 4e-05 Mdot
.3804 4e-05 Mdot
.1412 .1412 Mdot
.74116 .05102 Mdot
.83919 .87056 Mdot
.66665 .6392 Mdot
.58431 .0118 Mdot
.32158 .1216 Mdot
.43138 .00396 Mdot
.30198 .03925 Mdot
.51372 .07454 Mdot
.8039 .76469 Mdot
.47451 .03925 Mdot
.61568 .02749 Mdot
.3608 .23531 Mdot
.45491 .00396 Mdot
.59215 .05886 Mdot
.3608 .40001 Mdot
.54902 .11376 Mdot
.47843 .0118 Mdot
.63136 .05886 Mdot
.09807 .0118 Mdot
.45883 .00788 Mdot
.62744 .05494 Mdot
.8235 .8588 Mdot
.62352 .04709 Mdot
.50588 .01572 Mdot
.58431 .21963 Mdot
.10983 .05494 Mdot
.47451 .00788 Mdot
.64313 .03925 Mdot
.85487 .87448 Mdot
.56078 .07062 Mdot
.52549 .00788 Mdot
.64705 .47843 Mdot
.04317 4e-05 Mdot
.47843 .01572 Mdot
.67842 .04709 Mdot
.83919 .86664 Mdot
.13728 .00396 Mdot
.53725 .0118 Mdot
.47059 .33335 Mdot
.03141 4e-05 Mdot
.46275 .00788 Mdot
.67842 .03925 Mdot
.84311 .87448 Mdot
.3059 .37256 Mdot
.52941 .00396 Mdot
.40001 .3059 Mdot
.03141 .00788 Mdot
.47451 .0118 Mdot
.67842 .04317 Mdot
.84311 .87056 Mdot
.72547 .78429 Mdot
.53725 .00788 Mdot
.07454 .0118 Mdot
.02357 4e-05 Mdot
.47843 .00788 Mdot
.68626 .04317 Mdot
.6745 .69018 Mdot
.81174 .85095 Mdot
.54509 .0118 Mdot
.09415 .01965 Mdot
.02357 4e-05 Mdot
.49804 .01965 Mdot
.66665 .03925 Mdot
.06278 .11376 Mdot
.79998 .83527 Mdot
.54117 .00788 Mdot
.11768 .00396 Mdot
.02749 .00396 Mdot
.50588 .0118 Mdot
.51765 .06278 Mdot
.66273 .72155 Mdot
.8039 .83919 Mdot
.54509 .01965 Mdot
.22355 .00396 Mdot
.08631 4e-05 Mdot
.54117 .0118 Mdot
.10983 .06278 Mdot
.84311 .86664 Mdot
.8039 .83919 Mdot
.56862 .02357 Mdot
.33727 .0118 Mdot
.20394 .00788 Mdot
.59215 .02357 Mdot
.6745 .72547 Mdot
.81566 .72547 Mdot
.8039 .83919 Mdot
.58039 .01965 Mdot
.41569 .00396 Mdot
.27453 .00396 Mdot
.61568 .03141 Mdot
.83527 .86272 Mdot
.53333 .17257 Mdot
.79998 .84311 Mdot
.57646 .0118 Mdot
.49804 .0118 Mdot
.29806 .00396 Mdot
.61568 .02749 Mdot
.83919 .8588 Mdot
.15297 .01965 Mdot
.67057 .72939 Mdot
.55686 .00788 Mdot
.47451 .00788 Mdot
.30198 .00396 Mdot
.60391 .04317 Mdot
.83135 .86272 Mdot
.59999 .65881 Mdot
.69802 .75292 Mdot
.55294 .00396 Mdot
.40001 .00396 Mdot
.3255 4e-05 Mdot
.57646 .05886 Mdot
.85095 .84703 Mdot
.83527 .8784 Mdot
.79998 .83527 Mdot
.54902 .00788 Mdot
.32943 .00396 Mdot
.3608 .00788 Mdot
.53333 .08631 Mdot
.59607 .3059 Mdot
.83527 .87056 Mdot
.79606 .83919 Mdot
.52941 .01572 Mdot
.29021 .00788 Mdot
.35295 4e-05 Mdot
.54117 .18042 Mdot
.63528 .06278 Mdot
.83135 .86664 Mdot
.4902 .56078 Mdot
.4902 .16081 Mdot
.27453 .00396 Mdot
.3608 .00788 Mdot
.60391 .34903 Mdot
.51765 .08239 Mdot
.81566 .84703 Mdot
.60783 .67057 Mdot
.83135 .76469 Mdot
.27845 .01572 Mdot
.33335 4e-05 Mdot
.64313 .47059 Mdot
.15297 .11376 Mdot
.83527 .8235 Mdot
.78037 .82743 Mdot
.55686 .5098 Mdot
.07062 .76076 Mdot
.34903 .00396 Mdot
.55294 .24316 Mdot
.52941 .56862 Mdot
.65489 .4902 Mdot
.78037 .8235 Mdot
.33335 .25884 Mdot
.13728 .52157 Mdot
.35687 .00396 Mdot
.49804 .09415 Mdot
.69018 .74116 Mdot
.51765 .14905 Mdot
.78037 .81958 Mdot
.20394 .11376 Mdot
.1412 .51765 Mdot
.38824 .03141 Mdot
.43922 .0667 Mdot
.81958 .86272 Mdot
.4902 .10199 Mdot
.78037 .81958 Mdot
.24316 .12944 Mdot
.14905 .52549 Mdot
.3804 .00788 Mdot
.24708 .01965 Mdot
.83527 .8588 Mdot
.19218 .01572 Mdot
.78037 .8235 Mdot
.43138 .32158 Mdot
.14513 .52157 Mdot
.39217 .00788 Mdot
.10983 .04317 Mdot
.83919 .79606 Mdot
.07454 .09023 Mdot
.77253 .8235 Mdot
.62744 .54509 Mdot
.15297 .52157 Mdot
.38432 .00788 Mdot
.29021 .31374 Mdot
.64705 .43138 Mdot
.54117 .61176 Mdot
.77645 .8235 Mdot
.72547 .67057 Mdot
.1412 .51765 Mdot
.33335 .00396 Mdot
.56862 .62352 Mdot
.58039 .14513 Mdot
.72155 .77645 Mdot
.78037 .81566 Mdot
.78429 .75684 Mdot
.14513 .52549 Mdot
.3059 4e-05 Mdot
.74508 .79606 Mdot
.6941 .09023 Mdot
.81958 .86272 Mdot
.76076 .76469 Mdot
.76076 .75684 Mdot
.1412 .52157 Mdot
.34903 .00396 Mdot
.77253 .81566 Mdot
.78821 .08239 Mdot
.84311 .8784 Mdot
.61176 .53333 Mdot
.72155 .74508 Mdot
.14513 .51372 Mdot
.39217 .00788 Mdot
.77645 .81958 Mdot
.87056 .10983 Mdot
.87056 .89801 Mdot
.47059 .23924 Mdot
.6941 .74116 Mdot
.1412 .50588 Mdot
.38432 .00396 Mdot
.77645 .81958 Mdot
.95683 .1765 Mdot
.89801 .91761 Mdot
.5098 .09415 Mdot
.70587 .76076 Mdot
.14905 .5098 Mdot
.37256 .00396 Mdot
.78821 .83135 Mdot
.99212 .251 Mdot
.92154 .9333 Mdot
.60391 .04709 Mdot
.68234 .749 Mdot
.15297 .51765 Mdot
.36864 .00396 Mdot
.8039 .82743 Mdot
.99996 .28629 Mdot
.94114 .94898 Mdot
.66665 .03533 Mdot
.63528 .70979 Mdot
.15297 .51372 Mdot
.37648 .00396 Mdot
.85095 .80782 Mdot
.97643 .25492 Mdot
.9333 .93722 Mdot
.72547 .05102 Mdot
.67057 .73724 Mdot
.15689 .51765 Mdot
.38432 .00396 Mdot
.85487 .71763 Mdot
.99212 .29413 Mdot
.94506 .93722 Mdot
.76076 .05886 Mdot
.6941 .749 Mdot
.15689 .5098 Mdot
.39609 .00396 Mdot
.71371 .53333 Mdot
.99604 .27453 Mdot
.99996 .89409 Mdot
.749 .05102 Mdot
.60783 .67057 Mdot
.15689 .5098 Mdot
.41177 .00396 Mdot
.40393 .30198 Mdot
.98428 .21179 Mdot
.87056 .40393 Mdot
.74116 .05886 Mdot
.51765 .59215 Mdot
.14513 .5098 Mdot
.43138 .00788 Mdot
.1765 .18434 Mdot
.90977 .12552 Mdot
.83135 .14513 Mdot
.69018 .0667 Mdot
.70587 .76469 Mdot
.13728 .50196 Mdot
.47059 .01572 Mdot
.24316 .30198 Mdot
.80782 .07062 Mdot
.79998 .08631 Mdot
.63528 .10591 Mdot
.73332 .79213 Mdot
.13728 .50588 Mdot
.47843 .01965 Mdot
.62352 .69018 Mdot
.75684 .06278 Mdot
.79213 .08239 Mdot
.76076 .34119 Mdot
.61568 .67057 Mdot
.27845 .01572 Mdot
.59215 .1412 Mdot
.73724 .78821 Mdot
.79606 .08239 Mdot
.83135 .09807 Mdot
.83919 .47843 Mdot
.66665 .72939 Mdot
.28237 .01965 Mdot
.59999 .10591 Mdot
.78429 .8235 Mdot
.90193 .1412 Mdot
.91369 .1412 Mdot
.65881 .28629 Mdot
.61176 .68234 Mdot
.27845 .01965 Mdot
.57254 .03533 Mdot
.78429 .76469 Mdot
.96859 .20787 Mdot
.97643 .22355 Mdot
.54509 .10591 Mdot
.57254 .64705 Mdot
.26276 .01572 Mdot
.50196 .03533 Mdot
.65881 .4353 Mdot
.99996 .28629 Mdot
.96075 .32943 Mdot
.58431 .05494 Mdot
.51765 .60783 Mdot
.27061 .01572 Mdot
.70194 .39217 Mdot
.63528 .1216 Mdot
.99996 .28629 Mdot
.97643 .60391 Mdot
.65489 .04317 Mdot
.5098 .58823 Mdot
.28629 .02749 Mdot
.48235 .25884 Mdot
.74116 .07846 Mdot
.97251 .21571 Mdot
.90977 .63136 Mdot
.71371 .04709 Mdot
.52941 .59607 Mdot
.27061 .01965 Mdot
.56862 .30982 Mdot
.79998 .10983 Mdot
.99212 .24708 Mdot
.90585 .64705 Mdot
.73332 .04317 Mdot
.51765 .58039 Mdot
.27061 .01965 Mdot
.40393 .05102 Mdot
.81174 .14905 Mdot
.99604 .24708 Mdot
.94506 .75292 Mdot
.72939 .03533 Mdot
.48235 .55294 Mdot
.26276 .01572 Mdot
.41569 4e-05 Mdot
.73724 .12552 Mdot
.95291 .15297 Mdot
.91369 .70587 Mdot
.73724 .05102 Mdot
.49412 .56862 Mdot
.26276 .01572 Mdot
.44314 .00788 Mdot
.6196 .10591 Mdot
.90977 .10199 Mdot
.73724 .49804 Mdot
.70587 .0667 Mdot
.58431 .65489 Mdot
.28237 .02357 Mdot
.46275 .00788 Mdot
.38432 .03533 Mdot
.88232 .09807 Mdot
.84311 .58039 Mdot
.61568 .05886 Mdot
.60391 .66665 Mdot
.29021 .01572 Mdot
.46667 .0118 Mdot
.16081 .00396 Mdot
.89017 .10983 Mdot
.91369 .45883 Mdot
.52941 .06278 Mdot
.54117 .60783 Mdot
.29413 .0118 Mdot
.4353 4e-05 Mdot
.15297 .10983 Mdot
.92938 .1412 Mdot
.89017 .21963 Mdot
.45491 .07846 Mdot
.60391 .66665 Mdot
.31374 .01965 Mdot
.4353 .00788 Mdot
.30982 .33727 Mdot
.98035 .21571 Mdot
.99604 .31374 Mdot
.55294 .26668 Mdot
.749 .80782 Mdot
.32943 .03141 Mdot
.42354 .00396 Mdot
.53725 .59215 Mdot
.99996 .29021 Mdot
.99996 .31766 Mdot
.78821 .58431 Mdot
.69018 .74508 Mdot
.30982 .01965 Mdot
.41177 .01965 Mdot
.71763 .76861 Mdot
.98428 .23531 Mdot
.94506 .19218 Mdot
.90193 .77253 Mdot
.58823 .63528 Mdot
.33335 .04317 Mdot
.51372 .10591 Mdot
.78429 .81566 Mdot
.97643 .18042 Mdot
.89017 .1216 Mdot
.85487 .79606 Mdot
.60783 .65097 Mdot
.34119 .05494 Mdot
.48235 .01965 Mdot
.84703 .8235 Mdot
.96859 .18826 Mdot
.94114 .18826 Mdot
.8235 .81566 Mdot
.65097 .69018 Mdot
.34903 .0667 Mdot
.45491 4e-05 Mdot
.70979 .37256 Mdot
.99604 .28237 Mdot
.98428 .24708 Mdot
.79213 .81958 Mdot
.55686 .53725 Mdot
.39609 .46275 Mdot
.43922 .00396 Mdot
.77645 .08631 Mdot
.99996 .38432 Mdot
.99604 .27453 Mdot
.78429 .81566 Mdot
.10591 .03533 Mdot
.33335 .1216 Mdot
.47451 .00396 Mdot
.83527 .08631 Mdot
.97643 .33727 Mdot
.99604 .23924 Mdot
.81958 .80782 Mdot
.10983 .02357 Mdot
.19218 .0118 Mdot
.62744 .02357 Mdot
.8784 .11376 Mdot
.98428 .29413 Mdot
.86664 .28629 Mdot
.52941 .09023 Mdot
.18826 .08631 Mdot
.21179 4e-05 Mdot
.65097 .00788 Mdot
.83135 .07454 Mdot
.99212 .25492 Mdot
.84703 .67842 Mdot
.77645 .60391 Mdot
.31766 .00396 Mdot
.39609 .03925 Mdot
.68234 .01572 Mdot
.91761 .11376 Mdot
.99212 .23531 Mdot
.64705 .12552 Mdot
.76469 .83527 Mdot
.4902 .0118 Mdot
.12552 4e-05 Mdot
.72939 .04317 Mdot
.98035 .16081 Mdot
.98428 .21179 Mdot
.68626 .02357 Mdot
.81566 .8784 Mdot
.34903 .0118 Mdot
.04709 .00788 Mdot
.70587 .07454 Mdot
.96075 .19218 Mdot
.88624 .24708 Mdot
.83527 .68234 Mdot
.85095 .90193 Mdot
.49804 .04709 Mdot
.29806 .00396 Mdot
.73724 .04709 Mdot
.85095 .67057 Mdot
.68626 .34903 Mdot
.75292 .80782 Mdot
.77645 .81958 Mdot
.29021 .37648 Mdot
.42746 .00396 Mdot
.79998 .14513 Mdot
.60783 .53725 Mdot
.51765 .46667 Mdot
.40785 .07846 Mdot
.5098 .07846 Mdot
.22747 .01572 Mdot
.66273 .03925 Mdot
.72155 .52157 Mdot
.53333 .57646 Mdot
.45883 .5098 Mdot
.71763 .78037 Mdot
.63136 .05886 Mdot
.18434 .00396 Mdot
.75292 .12552 Mdot
.6941 .73332 Mdot
.60391 .65881 Mdot
.43922 .5098 Mdot
.6941 .77645 Mdot
.59999 .02749 Mdot
.19218 .00396 Mdot
.57254 .34119 Mdot
.78037 .80782 Mdot
.81174 .84703 Mdot
.40785 .4902 Mdot
.749 .83135 Mdot
.40785 .00396 Mdot
.40785 .10591 Mdot
.47059 .55294 Mdot
.87448 .89409 Mdot
.83135 .83527 Mdot
.39609 .4902 Mdot
.65489 .749 Mdot
.44706 .23924 Mdot
.54509 .16473 Mdot
.58039 .64705 Mdot
.45491 .44314 Mdot
.54117 .52941 Mdot
.37648 .47843 Mdot
.46667 .05886 Mdot
.34511 .01572 Mdot
.45883 .52157 Mdot
.43138 .43138 Mdot
.43922 .43922 Mdot
.56862 .5647 Mdot
.3608 .46275 Mdot
.53725 .01572 Mdot
.21963 .01965 Mdot
.4902 .51372 Mdot
.45491 .45098 Mdot
.45491 .47059 Mdot
.52157 .4902 Mdot
.35687 .43922 Mdot
.27061 .67057 Mdot
.41177 .4902 Mdot
.4902 .46667 Mdot
.46275 .46667 Mdot
.58039 .59607 Mdot
.52549 .4902 Mdot
.41961 .0667 Mdot
.35295 .03533 Mdot
.37256 .40001 Mdot
.45491 .45491 Mdot
.46667 .47843 Mdot
.45098 .45491 Mdot
.5647 .58039 Mdot
.61176 .08631 Mdot
.35295 .4353 Mdot
.47451 .45098 Mdot
.46667 .44706 Mdot
.44706 .46275 Mdot
.40393 .38432 Mdot
.3608 .45883 Mdot
.43138 .08631 Mdot
.45491 .47059 Mdot
.47451 .44706 Mdot
.44314 .46275 Mdot
.50196 .47059 Mdot
.47059 .44706 Mdot
.54509 .09415 Mdot
.35687 .43138 Mdot
.5098 .48235 Mdot
.45883 .45098 Mdot
.4353 .45883 Mdot
.46275 .42354 Mdot
.50588 .45883 Mdot
.41569 .09415 Mdot
.46667 .45098 Mdot
.49412 .47451 Mdot
.43922 .46667 Mdot
.45098 .41961 Mdot
.48235 .47059 Mdot
.34119 .3804 Mdot
.37256 .40393 Mdot
.50588 .46667 Mdot
.44706 .45883 Mdot
.43138 .47059 Mdot
.48235 .45098 Mdot
.43138 .40393 Mdot
.42746 .31766 Mdot
.4902 .46667 Mdot
.47843 .46667 Mdot
.53333 .58823 Mdot
.45491 .42354 Mdot
.48235 .45883 Mdot
.32943 .38824 Mdot
.45098 .43922 Mdot
.48628 .45883 Mdot
.42746 .47843 Mdot
.40785 .46275 Mdot
.46667 .46667 Mdot
.4353 .41569 Mdot
.38824 .41177 Mdot
.47059 .45098 Mdot
.47451 .48628 Mdot
.11768 .23924 Mdot
.42354 .42746 Mdot
.47059 .45491 Mdot
.29413 .28629 Mdot
.48628 .47451 Mdot
.4902 .47059 Mdot
.24316 .35295 Mdot
.38824 .42354 Mdot
.45491 .45491 Mdot
.251 .31766 Mdot
.36472 .3804 Mdot
.4902 .46667 Mdot
.1961 .29021 Mdot
.51372 .58823 Mdot
.47843 .46275 Mdot
.47451 .45098 Mdot
.39609 .27061 Mdot
.48628 .46667 Mdot
.39609 .42746 Mdot
.54117 .55294 Mdot
.4902 .44706 Mdot
.4902 .45098 Mdot
.1961 .29021 Mdot
.3804 .42746 Mdot
.48235 .46275 Mdot
.40785 .40393 Mdot
.57646 .59607 Mdot
.43922 .44314 Mdot
.40001 .43138 Mdot
.36864 .42354 Mdot
.4902 .47059 Mdot
.19218 .30198 Mdot
.6745 .68234 Mdot
.47843 .47451 Mdot
.47843 .46667 Mdot
.41961 .38824 Mdot
.40393 .43922 Mdot
.23139 .32943 Mdot
.46667 .40393 Mdot
.46667 .40393 Mdot
.50196 .46667 Mdot
.20002 .31374 Mdot
.34511 .41569 Mdot
.51372 .49804 Mdot
.51372 .44314 Mdot
.51372 .48235 Mdot
.50196 .48628 Mdot
.39217 .41961 Mdot
.27845 .69802 Mdot
.37256 .38432 Mdot
.36864 .40393 Mdot
.37256 .40001 Mdot
.50588 .4353 Mdot
.47059 .43922 Mdot
.30982 .40785 Mdot
.43138 .4902 Mdot
.50588 .51372 Mdot
.55686 .47843 Mdot
.3059 .36472 Mdot
.52157 .50196 Mdot
.3255 .39217 Mdot
.47451 .52157 Mdot
.43922 .4353 Mdot
.51372 .47059 Mdot
.23531 .32158 Mdot
.52941 .5098 Mdot
.29806 .37648 Mdot
.55686 .42354 Mdot
.46275 .52549 Mdot
.46667 .41177 Mdot
.69018 .67842 Mdot
.53333 .50196 Mdot
.3804 .37256 Mdot
.3804 .46667 Mdot
.5098 .58431 Mdot
.51765 .43138 Mdot
.53333 .48628 Mdot
.58039 .52941 Mdot
.40785 .41569 Mdot
.39609 .47451 Mdot
.52941 .60783 Mdot
.47843 .50196 Mdot
.56862 .6196 Mdot
.63528 .58039 Mdot
.45098 .45098 Mdot
.40785 .49412 Mdot
.53725 .61176 Mdot
.50196 .5647 Mdot
.43922 .47843 Mdot
.73724 .65881 Mdot
.47843 .47843 Mdot
.44706 .52549 Mdot
.57254 .60391 Mdot
.53725 .60391 Mdot
.52941 .48235 Mdot
.82743 .78429 Mdot
.53725 .5647 Mdot
.45883 .53333 Mdot
.51765 .52941 Mdot
.56862 .63136 Mdot
.56862 .49804 Mdot
.85095 .83919 Mdot
.58431 .59999 Mdot
.45098 .53725 Mdot
.58039 .65097 Mdot
.55294 .62744 Mdot
.56862 .56078 Mdot
.87448 .88232 Mdot
.70979 .64705 Mdot
.43138 .50588 Mdot
.60783 .68626 Mdot
.61568 .67842 Mdot
.9882 .99604 Mdot
.78037 .83135 Mdot
.54117 .60783 Mdot
.31374 .749 Mdot
.61568 .69018 Mdot
.75292 .79998 Mdot
.99212 .99212 Mdot
.67057 .70979 Mdot
.46667 .54117 Mdot
.64313 .72155 Mdot
.64705 .72155 Mdot
.99604 .99604 Mdot
.75292 .81174 Mdot
.54509 .62744 Mdot
.66665 .69802 Mdot
.66273 .73724 Mdot
.94506 .95291 Mdot
.88624 .92546 Mdot
.59607 .65881 Mdot
.65881 .67057 Mdot
.6941 .76861 Mdot
.92546 .94114 Mdot
.88232 .92546 Mdot
.54117 .61568 Mdot
.6941 .76861 Mdot
.78429 .83919 Mdot
.99212 .99212 Mdot
.79998 .84311 Mdot
.1765 .88624 Mdot
.72939 .8039 Mdot
.9333 .95291 Mdot
.92154 .94898 Mdot
.45491 .41177 Mdot
.75292 .81566 Mdot
.91369 .94506 Mdot
.91369 .94114 Mdot
.3255 .76076 Mdot
.76469 .8235 Mdot
.9882 .99212 Mdot
.70194 .72547 Mdot
.67057 .59999 Mdot
.96467 .97643 Mdot
.61176 .59999 Mdot
.64705 .56078 Mdot
.75684 .72547 Mdot
.40785 .81958 Mdot
.628 .126 .941 r
.34903 .78429 Mdot
.47451 .4353 Mdot
.79998 .74508 Mdot
.74116 .75684 Mdot
.71371 .63528 Mdot
.43138 .43138 Mdot
.77253 .72155 Mdot
.76076 .70979 Mdot
.73724 .75292 Mdot
.79213 .79213 Mdot
.81174 .71763 Mdot
.83919 .83135 Mdot
.79213 .81566 Mdot
.72939 .58823 Mdot
.76861 .68626 Mdot
.61568 .63136 Mdot
.78037 .81958 Mdot
.74508 .63528 Mdot
.72547 .66273 Mdot
.71763 .749 Mdot
.76076 .79998 Mdot
.71763 .62352 Mdot
.84311 .76469 Mdot
.83919 .83135 Mdot
.78429 .81174 Mdot
.11768 .83527 Mdot
.65097 .60391 Mdot
.76861 .75684 Mdot
.16865 .3059 Mdot
.75684 .79606 Mdot
.71763 .6392 Mdot
.87448 .80782 Mdot
.73724 .70979 Mdot
.79213 .83135 Mdot
.74116 .749 Mdot
.8039 .73332 Mdot
.87056 .80782 Mdot
.73332 .73332 Mdot
.77645 .81566 Mdot
.33335 .52549 Mdot
.82743 .73724 Mdot
.84703 .78429 Mdot
.72155 .72939 Mdot
.78821 .81566 Mdot
.10199 .82743 Mdot
.8235 .74508 Mdot
.86664 .79213 Mdot
.83919 .83135 Mdot
.79606 .8235 Mdot
.44314 .49804 Mdot
.79998 .71763 Mdot
.80782 .81566 Mdot
.83527 .80782 Mdot
.78821 .83919 Mdot
.75292 .79606 Mdot
.74508 .65881 Mdot
.84703 .75684 Mdot
.81174 .76469 Mdot
.66273 .73724 Mdot
.75292 .78037 Mdot
.69018 .59215 Mdot
.79606 .70979 Mdot
.87056 .79606 Mdot
.74508 .70587 Mdot
.8039 .83919 Mdot
.72155 .75684 Mdot
.76861 .68626 Mdot
.83919 .74508 Mdot
.83135 .75684 Mdot
.38824 .44706 Mdot
.76469 .79213 Mdot
.65489 .56078 Mdot
.76076 .67842 Mdot
.84703 .76469 Mdot
.86664 .84703 Mdot
.08631 .22355 Mdot
.77253 .81174 Mdot
.69802 .61176 Mdot
.79213 .70979 Mdot
.8588 .78821 Mdot
.80782 .77645 Mdot
.8039 .83135 Mdot
.70587 .73724 Mdot
.84311 .58039 Mdot
.44314 .43922 Mdot
.85095 .76076 Mdot
.79606 .77645 Mdot
.79213 .83527 Mdot
.50588 .57646 Mdot
.70194 .1412 Mdot
.60391 .57646 Mdot
.83919 .75292 Mdot
.79998 .76861 Mdot
.78821 .83135 Mdot
.25492 .34903 Mdot
.6941 .15297 Mdot
.65097 .62352 Mdot
.83919 .76469 Mdot
.71763 .6941 Mdot
.79998 .83527 Mdot
.18434 .26276 Mdot
.61176 .26276 Mdot
.6196 .61176 Mdot
.85095 .77645 Mdot
.82743 .8235 Mdot
.8039 .83919 Mdot
.74508 .79213 Mdot
.68234 .61568 Mdot
.77253 .65881 Mdot
.85095 .76076 Mdot
.76469 .70587 Mdot
.72939 .5098 Mdot
.749 .77645 Mdot
.61568 .56862 Mdot
.75684 .6392 Mdot
.8235 .74508 Mdot
.78429 .70587 Mdot
.67057 .38824 Mdot
.77253 .81174 Mdot
.50588 .44314 Mdot
.72155 .6196 Mdot
.36472 .41569 Mdot
.83527 .749 Mdot
.70979 .64313 Mdot
.78429 .64313 Mdot
.39609 .46667 Mdot
.67842 .61176 Mdot
.74508 .61568 Mdot
.85487 .76861 Mdot
.8235 .75684 Mdot
.71763 .02749 Mdot
.73724 .72939 Mdot
.54509 .51765 Mdot
.70587 .61568 Mdot
.81174 .72547 Mdot
.8039 .73724 Mdot
.71371 .03533 Mdot
.8039 .8039 Mdot
.51765 .54509 Mdot
.68626 .62352 Mdot
.72939 .61176 Mdot
.85095 .76861 Mdot
.76076 .64313 Mdot
.69018 .01965 Mdot
.78037 .79213 Mdot
.56862 .5647 Mdot
.70194 .59999 Mdot
.79998 .70979 Mdot
.81174 .73332 Mdot
.70979 .01965 Mdot
.57646 .24316 Mdot
.61176 .66273 Mdot
.64313 .58823 Mdot
.74508 .61176 Mdot
.83527 .76076 Mdot
.83135 .6196 Mdot
.70194 .01965 Mdot
.66273 .59607 Mdot
.66273 .73332 Mdot
.68234 .59607 Mdot
.78037 .65489 Mdot
.46275 .46667 Mdot
.72939 .02749 Mdot
.67057 .02357 Mdot
.20787 .27845 Mdot
.60391 .59607 Mdot
.70979 .57254 Mdot
.79998 .72155 Mdot
.8039 .71763 Mdot
.67842 .03141 Mdot
.749 .58823 Mdot
.10591 .82743 Mdot
.6392 .58039 Mdot
.75684 .62744 Mdot
.53725 .49412 Mdot
.78037 .07454 Mdot
.40001 .3059 Mdot
.65097 .59215 Mdot
.73724 .77645 Mdot
.68626 .59999 Mdot
.77253 .65097 Mdot
.51372 .54509 Mdot
.76076 .04317 Mdot
.21963 .28629 Mdot
.68626 .62744 Mdot
.79998 .8235 Mdot
.6745 .58823 Mdot
.79606 .68234 Mdot
.81958 .76469 Mdot
.65097 .11376 Mdot
.58431 .28237 Mdot
.41177 .43922 Mdot
.57646 .56862 Mdot
.6941 .56862 Mdot
.80782 .72547 Mdot
.88624 .61176 Mdot
.15297 .23531 Mdot
.63136 .02357 Mdot
.53333 .53725 Mdot
.62744 .58823 Mdot
.71763 .59215 Mdot
.82743 .76076 Mdot
.81174 .0667 Mdot
.80782 .81958 Mdot
.66665 .67057 Mdot
.69802 .74508 Mdot
.62352 .57254 Mdot
.75292 .63528 Mdot
.86664 .78821 Mdot
.79998 .05886 Mdot
.70194 .68234 Mdot
.66665 .59215 Mdot
.70587 .77253 Mdot
.64705 .59607 Mdot
.76861 .66665 Mdot
.85095 .78821 Mdot
.70979 .34119 Mdot
.72155 .749 Mdot
.57254 .50196 Mdot
.47451 .57646 Mdot
.64705 .58039 Mdot
.78429 .69018 Mdot
.83527 .77645 Mdot
.12944 .24316 Mdot
.21179 .27845 Mdot
.51372 .46275 Mdot
.57254 .66273 Mdot
.67057 .57646 Mdot
.78037 .69802 Mdot
.84703 .76076 Mdot
.67842 .6196 Mdot
.6941 .79606 Mdot
.43138 .39217 Mdot
.77253 .81566 Mdot
.67057 .5647 Mdot
.79998 .70587 Mdot
.72155 .25884 Mdot
.74508 .45491 Mdot
.77253 .81958 Mdot
.4902 .43922 Mdot
.65881 .6941 Mdot
.67842 .5647 Mdot
.78821 .70979 Mdot
.8235 .08239 Mdot
.70979 .04317 Mdot
.78429 .8235 Mdot
.3804 .37256 Mdot
.52157 .55294 Mdot
.67842 .55686 Mdot
.80782 .72155 Mdot
.83919 .09023 Mdot
.71763 .02357 Mdot
.79213 .82743 Mdot
.29413 .30198 Mdot
.54902 .5647 Mdot
.69802 .56862 Mdot
.8039 .71371 Mdot
.81566 .09415 Mdot
.71371 .02357 Mdot
.77645 .74116 Mdot
.39217 .38432 Mdot
.5647 .56862 Mdot
.67842 .5647 Mdot
.81566 .72939 Mdot
.75684 .30198 Mdot
.70587 .02749 Mdot
.59215 .37648 Mdot
.54902 .51765 Mdot
.58431 .58431 Mdot
.70587 .59215 Mdot
.8235 .74116 Mdot
.1961 .27061 Mdot
.63136 .11768 Mdot
.52549 .07846 Mdot
.56078 .49412 Mdot
.58431 .58431 Mdot
.69802 .59999 Mdot
.80782 .73724 Mdot
.12944 .30198 Mdot
.51372 .34903 Mdot
.51765 .07062 Mdot
.52549 .44706 Mdot
.58823 .59215 Mdot
.71763 .62352 Mdot
.81174 .72939 Mdot
.46667 .58431 Mdot
.08239 .16865 Mdot
.52157 .06278 Mdot
.54509 .47451 Mdot
.58431 .58431 Mdot
.71371 .62744 Mdot
.8039 .72547 Mdot
.71371 .74116 Mdot
.3255 .41177 Mdot
.52549 .07062 Mdot
.49804 .43138 Mdot
.59215 .58823 Mdot
.70587 .6196 Mdot
.79998 .72939 Mdot
.78037 .74508 Mdot
.77645 .77253 Mdot
.52549 .0667 Mdot
.52157 .47451 Mdot
.54509 .54902 Mdot
.71371 .63528 Mdot
.79606 .72547 Mdot
.80782 .72939 Mdot
.70979 .62352 Mdot
.53725 .07454 Mdot
.59215 .55686 Mdot
.52549 .53333 Mdot
.71763 .62744 Mdot
.8039 .72155 Mdot
.8588 .6745 Mdot
.72939 .50196 Mdot
.54509 .0667 Mdot
.58431 .57254 Mdot
.52549 .52941 Mdot
.73724 .6392 Mdot
.8039 .73332 Mdot
.71371 .26276 Mdot
.63528 .16865 Mdot
.54902 .05494 Mdot
.58823 .58039 Mdot
.50196 .50588 Mdot
.73724 .6392 Mdot
.79998 .72547 Mdot
.75684 .11768 Mdot
.68234 .05494 Mdot
.5647 .05494 Mdot
.65097 .65881 Mdot
.50196 .50588 Mdot
.72547 .6392 Mdot
.8039 .72547 Mdot
.78037 .10199 Mdot
.66273 .05886 Mdot
.57646 .05494 Mdot
.60391 .63528 Mdot
.4902 .49804 Mdot
.72155 .64313 Mdot
.81566 .73332 Mdot
.73724 .10983 Mdot
.60783 .22355 Mdot
.56862 .04709 Mdot
.5098 .54509 Mdot
.48235 .48628 Mdot
.72155 .63528 Mdot
.8039 .73332 Mdot
.70587 .23531 Mdot
.32943 .18826 Mdot
.56078 .03925 Mdot
.68234 .72547 Mdot
.44314 .46275 Mdot
.69802 .61568 Mdot
.78429 .72155 Mdot
.73724 .3059 Mdot
.66273 .31374 Mdot
.49804 .0667 Mdot
.47843 .56862 Mdot
.65881 .6941 Mdot
.68234 .61568 Mdot
.78429 .70979 Mdot
.73724 .47059 Mdot
.6392 .04709 Mdot
.52941 .31374 Mdot
.30982 .41961 Mdot
.72939 .76469 Mdot
.69802 .62744 Mdot
.79213 .71763 Mdot
.50588 .47059 Mdot
.6941 .04709 Mdot
.35295 .35687 Mdot
.62744 .73332 Mdot
.70587 .76076 Mdot
.71763 .65097 Mdot
.76861 .70194 Mdot
.20787 .30982 Mdot
.63136 .07846 Mdot
.37648 .45491 Mdot
.35687 .47451 Mdot
.54902 .65097 Mdot
.70979 .64705 Mdot
.78037 .70194 Mdot
.65489 .66273 Mdot
.61568 .1765 Mdot
.5647 .63136 Mdot
.70979 .79606 Mdot
.40393 .51765 Mdot
.70194 .65489 Mdot
.77253 .69018 Mdot
.81566 .77253 Mdot
.65489 .27453 Mdot
.58039 .41961 Mdot
.72547 .79213 Mdot
.38432 .5098 Mdot
.6745 .64313 Mdot
.76076 .68234 Mdot
.81174 .78037 Mdot
.6745 .30982 Mdot
.54902 .03925 Mdot
.70587 .77645 Mdot
.33335 .45883 Mdot
.68234 .65489 Mdot
.74508 .6745 Mdot
.81566 .78037 Mdot
.66273 .30198 Mdot
.6392 .0118 Mdot
.73332 .8039 Mdot
.31766 .42354 Mdot
.68626 .65097 Mdot
.74116 .67842 Mdot
.81958 .78429 Mdot
.65489 .30198 Mdot
.65881 .01572 Mdot
.72155 .79213 Mdot
.34903 .46275 Mdot
.66665 .6392 Mdot
.74116 .66273 Mdot
.8235 .78821 Mdot
.77253 .62352 Mdot
.6392 .38824 Mdot
.72155 .79606 Mdot
.56078 .65489 Mdot
.63136 .63136 Mdot
.73332 .65489 Mdot
.79998 .76076 Mdot
.73332 .68626 Mdot
.62352 .65097 Mdot
.72547 .79213 Mdot
.53725 .54902 Mdot
.60783 .61176 Mdot
.73724 .64313 Mdot
.8039 .75684 Mdot
.73724 .72547 Mdot
.6196 .63136 Mdot
.72939 .79606 Mdot
.68626 .56078 Mdot
.55686 .56862 Mdot
.72939 .64313 Mdot
.79606 .75292 Mdot
.72939 .70979 Mdot
.61176 .60391 Mdot
.71763 .8039 Mdot
.31374 .26668 Mdot
.55686 .5647 Mdot
.71763 .6392 Mdot
.79998 .74116 Mdot
.73724 .71763 Mdot
.6196 .61176 Mdot
.6392 .74508 Mdot
.10983 .16865 Mdot
.56078 .5647 Mdot
.6941 .61568 Mdot
.8039 .73724 Mdot
.74508 .73332 Mdot
.62744 .6196 Mdot
.43922 .25492 Mdot
.52549 .59215 Mdot
.54509 .56078 Mdot
.70194 .61568 Mdot
.79998 .73724 Mdot
.75292 .72939 Mdot
.64705 .63528 Mdot
.54509 .02357 Mdot
.5647 .6392 Mdot
.65881 .6941 Mdot
.70194 .62744 Mdot
.79606 .73724 Mdot
.75684 .72939 Mdot
.61568 .61176 Mdot
.59215 .00788 Mdot
.40785 .48628 Mdot
.33335 .42746 Mdot
.68626 .62352 Mdot
.79606 .72547 Mdot
.77645 .75684 Mdot
.5647 .12944 Mdot
.50588 .26668 Mdot
.40001 .52941 Mdot
.55294 .65097 Mdot
.66273 .60783 Mdot
.77645 .70194 Mdot
.78821 .76469 Mdot
.6745 .05494 Mdot
.65097 .59215 Mdot
.6745 .76861 Mdot
.16865 .30198 Mdot
.67057 .62352 Mdot
.77253 .69802 Mdot
.78037 .749 Mdot
.70194 .04709 Mdot
.61176 .04317 Mdot
.70979 .78821 Mdot
.34511 .45098 Mdot
.67057 .64313 Mdot
.749 .6745 Mdot
.78037 .75684 Mdot
.69802 .07846 Mdot
.66273 .01572 Mdot
.69802 .77645 Mdot
.44706 .55686 Mdot
.6392 .61176 Mdot
.73332 .65881 Mdot
.76469 .749 Mdot
.62352 .28237 Mdot
.65489 .00788 Mdot
.72155 .79213 Mdot
.49804 .58039 Mdot
.6196 .6196 Mdot
.74116 .65881 Mdot
.76469 .73724 Mdot
.73332 .68626 Mdot
.66273 .01572 Mdot
.70979 .6941 Mdot
.69802 .66273 Mdot
.59607 .59999 Mdot
.71371 .64705 Mdot
.75684 .72939 Mdot
.75292 .72547 Mdot
.65097 .01572 Mdot
.52157 .01965 Mdot
.27453 .21179 Mdot
.58039 .58823 Mdot
.70979 .63528 Mdot
.77253 .74508 Mdot
.72939 .72939 Mdot
.66665 .02357 Mdot
.57646 .00396 Mdot
.01572 .08239 Mdot
.52549 .55686 Mdot
.69802 .6196 Mdot
.75292 .72939 Mdot
.74508 .75292 Mdot
.68626 .03925 Mdot
.59215 .00396 Mdot
.02357 .10983 Mdot
.76469 .81958 Mdot
.68234 .60783 Mdot
.74116 .68626 Mdot
.75292 .75684 Mdot
.70194 .02749 Mdot
.53725 .44706 Mdot
.57646 .65881 Mdot
.251 .35295 Mdot
.64313 .58039 Mdot
.6941 .6392 Mdot
.76076 .76076 Mdot
.70979 .03141 Mdot
.41569 .4353 Mdot
.16473 .29806 Mdot
.58431 .69018 Mdot
.61568 .56078 Mdot
.68626 .6196 Mdot
.76469 .76861 Mdot
.72155 .04317 Mdot
.58039 .03533 Mdot
.68626 .78037 Mdot
.23139 .34903 Mdot
.62352 .59215 Mdot
.66273 .59607 Mdot
.56862 .59215 Mdot
.70979 .05102 Mdot
.65489 .01572 Mdot
.67057 .77253 Mdot
.37256 .48628 Mdot
.60391 .58431 Mdot
.68626 .61176 Mdot
.66273 .66665 Mdot
.60783 .11376 Mdot
.6392 .00788 Mdot
.65097 .77645 Mdot
.66665 .73724 Mdot
.60783 .58823 Mdot
.69018 .60783 Mdot
.72547 .71371 Mdot
.78037 .62744 Mdot
.64705 .00396 Mdot
.29413 .45491 Mdot
.6392 .59215 Mdot
.57646 .55686 Mdot
.67057 .59607 Mdot
.66665 .6392 Mdot
.70587 .70587 Mdot
.64705 .0118 Mdot
.03533 .08239 Mdot
.33727 .32943 Mdot
.5647 .56862 Mdot
.66273 .57254 Mdot
.66273 .62352 Mdot
.70979 .70587 Mdot
.67842 .03141 Mdot
.15297 .04709 Mdot
.22355 .30198 Mdot
.52549 .54117 Mdot
.66665 .58431 Mdot
.66665 .6392 Mdot
.73332 .72939 Mdot
.67842 .02749 Mdot
.57254 .47843 Mdot
.32943 .39217 Mdot
.47059 .48628 Mdot
.64313 .55686 Mdot
.64705 .60391 Mdot
.74508 .75684 Mdot
.6941 .02749 Mdot
.60391 .72939 Mdot
.41177 .48628 Mdot
.43138 .40393 Mdot
.63136 .55294 Mdot
.64705 .58823 Mdot
.76076 .75684 Mdot
.68626 .03533 Mdot
.36864 .56078 Mdot
.64705 .73724 Mdot
.42746 .33335 Mdot
.61568 .53725 Mdot
.65881 .57646 Mdot
.77253 .77645 Mdot
.69802 .03141 Mdot
.04709 .14513 Mdot
.27453 .40393 Mdot
.44314 .45883 Mdot
.59999 .53333 Mdot
.64313 .5647 Mdot
.76861 .75292 Mdot
.71763 .04709 Mdot
.38432 .31766 Mdot
.28629 .39609 Mdot
.65881 .73724 Mdot
.59607 .55294 Mdot
.63136 .5647 Mdot
.73724 .74116 Mdot
.71371 .03533 Mdot
.5647 .30982 Mdot
.6941 .78037 Mdot
.68626 .75684 Mdot
.56078 .53725 Mdot
.63136 .54902 Mdot
.63528 .63136 Mdot
.60783 .10983 Mdot
.51765 .14513 Mdot
.3608 .37256 Mdot
.6745 .64705 Mdot
.56862 .5647 Mdot
.62352 .54117 Mdot
.62352 .61176 Mdot
.70587 .72155 Mdot
.57646 .03925 Mdot
.5647 .42746 Mdot
.1765 .23924 Mdot
.52941 .53725 Mdot
.6196 .52941 Mdot
.62352 .60391 Mdot
.70979 .72547 Mdot
.46667 .10591 Mdot
.74116 .81174 Mdot
.25884 .3608 Mdot
.45491 .47843 Mdot
.63136 .54117 Mdot
.61568 .59215 Mdot
.70979 .73724 Mdot
.56862 .62744 Mdot
.4902 .64313 Mdot
.14513 .25492 Mdot
.37648 .1216 Mdot
.6196 .54902 Mdot
.66273 .63136 Mdot
.72547 .74508 Mdot
.57254 .58431 Mdot
.20394 .31374 Mdot
.31374 .4353 Mdot
.45491 .33335 Mdot
.63528 .55686 Mdot
.6196 .58823 Mdot
.74116 .749 Mdot
.51765 .12944 Mdot
.58823 .56078 Mdot
.01572 .12552 Mdot
.43922 .18434 Mdot
.62352 .54117 Mdot
.63136 .59215 Mdot
.74508 .749 Mdot
.57646 .1216 Mdot
.58039 .37648 Mdot
.54509 .63528 Mdot
.31374 .11376 Mdot
.56862 .49412 Mdot
.6392 .59999 Mdot
.53725 .58039 Mdot
.58823 .14513 Mdot
.51372 .13336 Mdot
.30982 .43922 Mdot
.32158 .22355 Mdot
.54117 .49804 Mdot
.61568 .55294 Mdot
.53725 .5647 Mdot
.74508 .64705 Mdot
.50196 .10591 Mdot
.70587 .78821 Mdot
.30198 .70587 Mdot
.54902 .5098 Mdot
.61568 .56862 Mdot
.66273 .66665 Mdot
.69018 .71371 Mdot
.53725 .14905 Mdot
.44706 .11376 Mdot
.00396 .07062 Mdot
.4902 .48235 Mdot
.61176 .54902 Mdot
.66273 .67057 Mdot
.71371 .72939 Mdot
.53725 .12552 Mdot
.58039 .00788 Mdot
.00396 .04709 Mdot
.47451 .47451 Mdot
.6196 .54117 Mdot
.6941 .68626 Mdot
.6941 .73332 Mdot
.56862 .15297 Mdot
.56862 .00396 Mdot
.00788 .07846 Mdot
.46667 .43138 Mdot
.60391 .52941 Mdot
.66665 .65881 Mdot
.70979 .74508 Mdot
.55294 .20394 Mdot
.59607 .00788 Mdot
.3255 .39609 Mdot
.38824 .21179 Mdot
.58431 .50588 Mdot
.66273 .64705 Mdot
.70587 .72155 Mdot
.43138 .35687 Mdot
.61568 .00788 Mdot
.36864 .46275 Mdot
.32943 .08631 Mdot
.53333 .43922 Mdot
.66273 .6392 Mdot
.6941 .71763 Mdot
.21179 .23924 Mdot
.59607 .00788 Mdot
.37648 .47059 Mdot
.47451 .20787 Mdot
.50196 .42746 Mdot
.64705 .61176 Mdot
.69802 .71763 Mdot
.27061 .28629 Mdot
.55686 .02357 Mdot
.35687 .44706 Mdot
.3804 .1961 Mdot
.47451 .44314 Mdot
.65097 .61176 Mdot
.69018 .72155 Mdot
.70194 .6745 Mdot
.52941 .04317 Mdot
.33335 .18042 Mdot
.46667 .31374 Mdot
.50196 .47451 Mdot
.6196 .59215 Mdot
.68234 .70587 Mdot
.68626 .71371 Mdot
.51765 .06278 Mdot
.49804 .00396 Mdot
.26668 .31374 Mdot
.43922 .42354 Mdot
.59999 .54902 Mdot
.68626 .70979 Mdot
.65097 .69018 Mdot
.50588 .07062 Mdot
.44706 .16081 Mdot
.24708 .34119 Mdot
.40785 .40393 Mdot
.61568 .56862 Mdot
.65097 .67057 Mdot
.68234 .71371 Mdot
.57646 .03141 Mdot
.53333 .5098 Mdot
.32943 .40393 Mdot
.34511 .34903 Mdot
.60391 .54902 Mdot
.68234 .68626 Mdot
.66665 .70979 Mdot
.63528 .01965 Mdot
.55294 .03141 Mdot
.00788 .10983 Mdot
.30198 .29806 Mdot
.58431 .51765 Mdot
.69018 .6941 Mdot
.65097 .68626 Mdot
.67057 .02357 Mdot
.60783 .00396 Mdot
.36472 .44314 Mdot
.33727 .30198 Mdot
.55294 .45491 Mdot
.67842 .66273 Mdot
.70979 .72939 Mdot
.65881 .00788 Mdot
.61176 .00396 Mdot
.39609 .47843 Mdot
.39609 .1216 Mdot
.51372 .43922 Mdot
.67057 .6392 Mdot
.6941 .71371 Mdot
.70587 .03533 Mdot
.59607 .00788 Mdot
.48235 .59999 Mdot
.47451 .34511 Mdot
.4902 .45491 Mdot
.65489 .6196 Mdot
.66665 .70194 Mdot
.6941 .03925 Mdot
.50588 .04317 Mdot
.41569 .04709 Mdot
.19218 .27845 Mdot
.38432 .38432 Mdot
.65097 .59999 Mdot
.58431 .58823 Mdot
.65097 .34903 Mdot
.51765 .5647 Mdot
.55686 .42746 Mdot
.00396 .05494 Mdot
.31374 .31766 Mdot
.61568 .55294 Mdot
.53333 .54902 Mdot
.66273 .68234 Mdot
.49804 .59215 Mdot
.63136 .8039 Mdot
.01572 .08631 Mdot
.27845 .27453 Mdot
.59607 .52549 Mdot
.61176 .61568 Mdot
.63136 .66273 Mdot
.34119 .4902 Mdot
.10199 .18826 Mdot
.35295 .43922 Mdot
.29806 .27453 Mdot
.58039 .50196 Mdot
.66665 .66273 Mdot
.67057 .69802 Mdot
.03533 .18826 Mdot
.02357 .12944 Mdot
.39609 .47451 Mdot
.39609 .39609 Mdot
.5098 .44314 Mdot
.62352 .6196 Mdot
.68234 .70587 Mdot
.42746 .33335 Mdot
.02357 .12944 Mdot
.40785 .48628 Mdot
.43138 .37648 Mdot
.48235 .44314 Mdot
.60391 .57254 Mdot
.6392 .69802 Mdot
.60391 .07062 Mdot
.52941 .18042 Mdot
.62352 .749 Mdot
.20787 .27845 Mdot
.40393 .38432 Mdot
.56862 .52157 Mdot
.61176 .6196 Mdot
.66665 .02357 Mdot
.5098 .32943 Mdot
.14513 .15689 Mdot
.28629 .40393 Mdot
.3059 .29806 Mdot
.52157 .46275 Mdot
.63528 .65489 Mdot
.65881 .06278 Mdot
.54117 .58039 Mdot
.47843 .10199 Mdot
.32158 .41569 Mdot
.29413 .12552 Mdot
.55294 .45098 Mdot
.65097 .65489 Mdot
.66665 .65881 Mdot
.54902 .12552 Mdot
.52941 .03141 Mdot
.34903 .44706 Mdot
.35687 .28237 Mdot
.53333 .45491 Mdot
.54902 .55294 Mdot
.60783 .66665 Mdot
.55294 .07846 Mdot
.51765 .03533 Mdot
.38432 .46275 Mdot
.41569 .38824 Mdot
.54902 .49804 Mdot
.58431 .57254 Mdot
.64705 .68626 Mdot
.57254 .38824 Mdot
.40785 .26668 Mdot
.46275 .48628 Mdot
.1961 .26276 Mdot
.45883 .41961 Mdot
.54509 .47843 Mdot
.63136 .65097 Mdot
.1216 .22355 Mdot
.6196 .67842 Mdot
.47843 .03141 Mdot
4e-05 .07454 Mdot
.37648 .35295 Mdot
.54902 .4902 Mdot
.67842 .71371 Mdot
.58431 .24316 Mdot
.34511 .48235 Mdot
.55686 .00396 Mdot
.00396 .05494 Mdot
.3608 .30982 Mdot
.52941 .4353 Mdot
.66273 .6745 Mdot
.72155 .05102 Mdot
.56078 .04317 Mdot
.55294 .00788 Mdot
.00396 .0667 Mdot
.26668 .22355 Mdot
.4902 .39609 Mdot
.54117 .53725 Mdot
.68234 .5098 Mdot
.50196 .56862 Mdot
.50196 .03533 Mdot
.00788 .09023 Mdot
.45883 .31766 Mdot
.54902 .47059 Mdot
.58431 .58039 Mdot
.65881 .6941 Mdot
.13336 .32158 Mdot
.4902 .42746 Mdot
.41961 .31374 Mdot
.56862 .40001 Mdot
.51372 .47843 Mdot
.60783 .5647 Mdot
.67842 .70979 Mdot
.40785 .32943 Mdot
.69802 .77645 Mdot
.52549 .00396 Mdot
.30982 .40785 Mdot
.41569 .37648 Mdot
.59999 .52941 Mdot
.65881 .69018 Mdot
.67842 .0667 Mdot
.53725 .63528 Mdot
.44314 .10591 Mdot
.29413 .42354 Mdot
.35295 .3059 Mdot
.53333 .4353 Mdot
.55686 .59215 Mdot
.72547 .20787 Mdot
.06278 .15297 Mdot
.46667 .09023 Mdot
.01572 .09807 Mdot
.32158 .26668 Mdot
.47843 .3804 Mdot
.78821 .82743 Mdot
.71763 .07062 Mdot
.52941 .27453 Mdot
.48235 .02357 Mdot
.33335 .45098 Mdot
.3255 .22747 Mdot
.53333 .44706 Mdot
.48235 .51372 Mdot
.60391 .65881 Mdot
.59607 .03925 Mdot
.54902 .00396 Mdot
.06278 .17257 Mdot
.38824 .29806 Mdot
.52549 .46275 Mdot
.60391 .59607 Mdot
.65881 .70587 Mdot
.62352 .07454 Mdot
.55686 .01965 Mdot
.04317 .06278 Mdot
.10983 .18434 Mdot
.49804 .43138 Mdot
.58039 .52549 Mdot
.65097 .68234 Mdot
.54902 .10983 Mdot
.57646 .64313 Mdot
.43138 .05494 Mdot
.00788 .05494 Mdot
.39609 .33727 Mdot
.57254 .5098 Mdot
.6392 .66273 Mdot
.69018 .03925 Mdot
.42746 .49804 Mdot
.67057 .71371 Mdot
.05102 .12944 Mdot
.33335 .27453 Mdot
.51372 .41961 Mdot
.5098 .53725 Mdot
.57254 .08239 Mdot
.63136 .71371 Mdot
.45098 .04317 Mdot
.06278 .18434 Mdot
.32943 .08631 Mdot
.52157 .41569 Mdot
.52941 .54509 Mdot
.65097 .70587 Mdot
.53725 .65881 Mdot
.07062 .16081 Mdot
.31766 .41569 Mdot
.47059 .30198 Mdot
.44706 .3804 Mdot
.58823 .57646 Mdot
.66273 .69802 Mdot
.19218 .34119 Mdot
.52157 .01965 Mdot
.07454 .20002 Mdot
.17257 .27061 Mdot
.43138 .03533 Mdot
.56862 .51372 Mdot
.59215 .63136 Mdot
.251 .43138 Mdot
.46275 .55294 Mdot
.31374 .21963 Mdot
.10983 .21571 Mdot
.34119 .13728 Mdot
.53333 .45491 Mdot
.50196 .54117 Mdot
.67057 .06278 Mdot
.48628 .59999 Mdot
.47451 .05494 Mdot
.34511 .44314 Mdot
.32943 .251 Mdot
.51372 .41177 Mdot
.48628 .50588 Mdot
.58431 .29413 Mdot
.52549 .59999 Mdot
.48628 .02357 Mdot
.3804 .48235 Mdot
.33727 .28237 Mdot
.48628 .38432 Mdot
.53725 .55686 Mdot
.63528 .69018 Mdot
.64313 .71763 Mdot
.40785 .03533 Mdot
.32943 .44314 Mdot
.36864 .12944 Mdot
.38824 .3059 Mdot
.59607 .58431 Mdot
.65097 .69018 Mdot
.59999 .66273 Mdot
.65097 .6196 Mdot
.41569 .29413 Mdot
.01572 .11768 Mdot
.39609 .31374 Mdot
.57254 .52157 Mdot
.46667 .5098 Mdot
.24708 .23139 Mdot
.5098 .65489 Mdot
.42746 .02749 Mdot
.251 .37648 Mdot
.37648 .26276 Mdot
.51765 .44706 Mdot
.46275 .50196 Mdot
.72155 .05102 Mdot
.53725 .63136 Mdot
.52549 .00396 Mdot
.36472 .46667 Mdot
.3804 .0667 Mdot
.51765 .40785 Mdot
.43138 .46275 Mdot
.62744 .66273 Mdot
.57254 .66273 Mdot
.40001 .11376 Mdot
.35687 .4353 Mdot
.30198 .09807 Mdot
.36472 .29021 Mdot
.49804 .49412 Mdot
.58823 .65097 Mdot
.57646 .64313 Mdot
.58039 .5098 Mdot
.43138 4e-05 Mdot
.00396 .05886 Mdot
.37256 .27453 Mdot
.58431 .55294 Mdot
.44706 .50196 Mdot
.55686 .35295 Mdot
.74116 .80782 Mdot
.45491 .00396 Mdot
.00396 .04709 Mdot
.3608 .28237 Mdot
.57646 .50588 Mdot
.4353 .4902 Mdot
.71371 .03533 Mdot
.46667 .64705 Mdot
.5098 .00396 Mdot
.02749 .11768 Mdot
.3255 .27061 Mdot
.54117 .44706 Mdot
.36472 .4353 Mdot
.60391 .31766 Mdot
.60783 .72939 Mdot
.50588 4e-05 Mdot
.31766 .42746 Mdot
.4353 .21963 Mdot
.41961 .33727 Mdot
.28629 .33727 Mdot
.57646 .63136 Mdot
.60391 .67842 Mdot
.51765 4e-05 Mdot
.34511 .02749 Mdot
.14513 .65489 Mdot
.32943 .24708 Mdot
.4902 .49412 Mdot
.51372 .5647 Mdot
.56862 .0667 Mdot
.55686 .00396 Mdot
.32943 .26276 Mdot
.21179 .35295 Mdot
.34119 .27061 Mdot
.56078 .51765 Mdot
.42746 .4902 Mdot
.70194 .03925 Mdot
.56078 .02357 Mdot
.08239 .21179 Mdot
4e-05 .03533 Mdot
.34119 .10199 Mdot
.54509 .44706 Mdot
.40785 .47059 Mdot
.67842 .65097 Mdot
.6745 .62352 Mdot
.42746 .11376 Mdot
.32943 .42354 Mdot
.48235 .39609 Mdot
.48235 .39217 Mdot
.4902 .50196 Mdot
.50588 .57254 Mdot
.61176 .65881 Mdot
.5647 .40785 Mdot
.05102 .13728 Mdot
.05886 .80782 Mdot
.35687 .27453 Mdot
.44706 .45098 Mdot
.49412 .5647 Mdot
.6941 .03533 Mdot
.44314 .07454 Mdot
.44706 .00396 Mdot
.25492 .36864 Mdot
.35687 .27453 Mdot
.57254 .52549 Mdot
.76861 .83919 Mdot
.68234 .04709 Mdot
.58039 .00788 Mdot
.41961 .05886 Mdot
.11376 .21179 Mdot
.30982 .20002 Mdot
.51372 .40785 Mdot
.44706 .49804 Mdot
.55686 .61568 Mdot
.61176 .00396 Mdot
.28237 .3608 Mdot
.30198 .40393 Mdot
.45098 .12944 Mdot
.47451 .39609 Mdot
.47059 .50588 Mdot
.48235 .5647 Mdot
.59215 .06278 Mdot
.45883 .16473 Mdot
.31374 .0667 Mdot
.25492 .63528 Mdot
.37648 .28629 Mdot
.45098 .47451 Mdot
.53333 .59215 Mdot
.66273 .04709 Mdot
.44706 .20787 Mdot
.44706 .00788 Mdot
.28629 .38824 Mdot
.3255 .25492 Mdot
.49412 .46275 Mdot
.46667 .53333 Mdot
.53333 .26668 Mdot
.04317 .19218 Mdot
.4902 .00396 Mdot
.28629 .40393 Mdot
.31374 .16473 Mdot
.56078 .33727 Mdot
.47843 .53333 Mdot
.6745 .749 Mdot
.47451 .25492 Mdot
.51765 .00396 Mdot
.28629 .40785 Mdot
.51372 .32943 Mdot
.48235 .37648 Mdot
.45491 .47451 Mdot
.45883 .53725 Mdot
.69802 .03925 Mdot
.41961 .31374 Mdot
.32158 .0667 Mdot
.13336 .64705 Mdot
.33727 .04317 Mdot
.4353 .45098 Mdot
.50196 .57646 Mdot
.68626 .09415 Mdot
.49412 .13336 Mdot
.41569 .30198 Mdot
.251 .36864 Mdot
.33727 .24316 Mdot
.53725 .49804 Mdot
.44314 .51372 Mdot
.70587 .77645 Mdot
.5098 .11768 Mdot
.28629 .24708 Mdot
.28237 .41177 Mdot
.3059 .24708 Mdot
.51372 .42746 Mdot
.44706 .4902 Mdot
.54117 .6196 Mdot
.32943 .46667 Mdot
.42354 .02357 Mdot
.29413 .41177 Mdot
.46275 .27453 Mdot
.40001 .33335 Mdot
.46667 .48628 Mdot
.69018 .76861 Mdot
.62352 .13336 Mdot
.54902 .00788 Mdot
.31374 .18434 Mdot
.24316 .62352 Mdot
.37648 .24708 Mdot
.46667 .47843 Mdot
.52549 .60391 Mdot
.72155 .05494 Mdot
.50588 .54117 Mdot
.44706 4e-05 Mdot
.27061 .38824 Mdot
.33727 .04709 Mdot
.54902 .51372 Mdot
.38824 .46667 Mdot
.6392 .42354 Mdot
.51765 .29413 Mdot
.41961 .12944 Mdot
.29806 .41177 Mdot
.3255 .26668 Mdot
.51372 .42354 Mdot
.41569 .46275 Mdot
.55686 .63136 Mdot
.73724 .29413 Mdot
.02357 .08631 Mdot
.251 .38824 Mdot
.37256 .15297 Mdot
.35687 .27845 Mdot
.42354 .46667 Mdot
.70194 .78037 Mdot
.67057 .02357 Mdot
.56862 .00396 Mdot
.41177 .00396 Mdot
.20394 .32158 Mdot
.37648 .30198 Mdot
.55294 .54902 Mdot
.27061 .38432 Mdot
.62352 .07454 Mdot
.74116 .83527 Mdot
.44314 4e-05 Mdot
.28237 .40001 Mdot
.34119 .22747 Mdot
.51765 .46667 Mdot
.40393 .47843 Mdot
.54902 .27453 Mdot
.11376 .28629 Mdot
.51372 .00396 Mdot
.27845 .40393 Mdot
.32943 .23139 Mdot
.47451 .41177 Mdot
.42354 .47843 Mdot
.74116 .80782 Mdot
.53333 .15689 Mdot
.52549 .00788 Mdot
.20002 .33335 Mdot
.32943 .08631 Mdot
.44314 .35295 Mdot
.47059 .48628 Mdot
.50588 .58431 Mdot
.63136 .05494 Mdot
.48628 .16081 Mdot
.40785 .00788 Mdot
.27061 .37648 Mdot
.37256 .29806 Mdot
.52941 .51765 Mdot
.37256 .50588 Mdot
.20002 .21571 Mdot
.749 .8235 Mdot
.26668 .21179 Mdot
.28237 .40001 Mdot
.3059 .251 Mdot
.40393 .30198 Mdot
.42746 .49412 Mdot
.73332 .69018 Mdot
.71371 .85487 Mdot
.47843 .01572 Mdot
.29021 .41177 Mdot
.34903 .08631 Mdot
.42746 .37256 Mdot
.78037 .8235 Mdot
.70194 .77253 Mdot
.59607 .02749 Mdot
.51765 .00788 Mdot
.00788 .08631 Mdot
.23924 .33335 Mdot
.44314 .1216 Mdot
.54117 .54902 Mdot
.44706 .52549 Mdot
.73332 .48235 Mdot
.74116 .81566 Mdot
.42746 .01572 Mdot
.25492 .3804 Mdot
.36864 .13336 Mdot
.47451 .42354 Mdot
.04317 .18434 Mdot
.56862 .31374 Mdot
.74508 .83527 Mdot
.48628 .60783 Mdot
.28629 .40785 Mdot
.36864 .28237 Mdot
.44706 .40393 Mdot
.41177 .47059 Mdot
.77645 .84703 Mdot
.05886 .23139 Mdot
.15689 .17257 Mdot
.29413 .41177 Mdot
.48235 .251 Mdot
.46275 .41177 Mdot
.44706 .49804 Mdot
.49412 .56078 Mdot
.59999 .0667 Mdot
.32943 .18826 Mdot
.23139 .37256 Mdot
.24708 .3804 Mdot
.40785 .28629 Mdot
.49804 .4902 Mdot
.64705 .72939 Mdot
.10591 .30198 Mdot
.74508 .82743 Mdot
.4902 .53725 Mdot
.27845 .40393 Mdot
.39217 .08239 Mdot
.50196 .16081 Mdot
.0118 .10591 Mdot
.59215 .6941 Mdot
.76076 .83527 Mdot
.44314 .58823 Mdot
.29021 .40785 Mdot
.36864 .26668 Mdot
.47843 .34511 Mdot
.45098 .47059 Mdot
.73332 .8235 Mdot
.03141 .16865 Mdot
.49804 .61568 Mdot
.30982 .42746 Mdot
.26668 .37256 Mdot
.42354 .37648 Mdot
.55294 .56862 Mdot
.60783 .68626 Mdot
.64705 .05102 Mdot
.73332 .8235 Mdot
.48235 .57646 Mdot
.26668 .38432 Mdot
.3804 .33335 Mdot
.48235 .39217 Mdot
.40001 .48628 Mdot
.03925 .23531 Mdot
.75684 .83527 Mdot
.63136 .74508 Mdot
.29021 .41569 Mdot
.34903 .04709 Mdot
.48628 .22355 Mdot
.41961 .45883 Mdot
.77253 .85487 Mdot
.76861 .84703 Mdot
.53333 .65881 Mdot
.31766 .43138 Mdot
.29413 .3608 Mdot
.4353 .1412 Mdot
.54902 .57254 Mdot
.52157 .60783 Mdot
.03925 .20787 Mdot
.71371 .82743 Mdot
.39609 .49412 Mdot
.27845 .39217 Mdot
.38824 .30982 Mdot
.47843 .46275 Mdot
.48628 .56862 Mdot
.59215 .1216 Mdot
.74508 .83135 Mdot
.51765 .62352 Mdot
.29021 .41177 Mdot
.4353 .21571 Mdot
.52157 .47451 Mdot
.05886 .21179 Mdot
.76861 .84703 Mdot
.77253 .85487 Mdot
.23139 .37256 Mdot
.30198 .41961 Mdot
.3608 .14513 Mdot
.47059 .40393 Mdot
.57646 .62352 Mdot
.59607 .67057 Mdot
.78429 .85487 Mdot
.72547 .81958 Mdot
.43138 .53725 Mdot
.27845 .39609 Mdot
.3608 .18434 Mdot
.52941 .53333 Mdot
.76469 .84311 Mdot
.49804 .72155 Mdot
.749 .83919 Mdot
.68234 .78429 Mdot
.29021 .41569 Mdot
.40393 .25884 Mdot
.50196 .4353 Mdot
.49804 .58431 Mdot
.74508 .83135 Mdot
.77645 .85487 Mdot
.41961 .56078 Mdot
.30982 .43138 Mdot
.3804 .15297 Mdot
.47059 .40785 Mdot
.46275 .53333 Mdot
.62352 .6941 Mdot
.78429 .85487 Mdot
.74508 .83135 Mdot
.44706 .55686 Mdot
.251 .37256 Mdot
.40785 .36472 Mdot
.50588 .50588 Mdot
.5098 .61176 Mdot
.50196 .72155 Mdot
.76469 .85487 Mdot
.56078 .65881 Mdot
.29021 .40785 Mdot
.38824 .13336 Mdot
.47843 .33335 Mdot
.52941 .61568 Mdot
.56862 .78821 Mdot
.78037 .8588 Mdot
.38824 .54509 Mdot
.3255 .45883 Mdot
.36472 .13728 Mdot
.55294 .20787 Mdot
.00788 .12944 Mdot
.91369 .98035 Mdot
.8039 .87448 Mdot
.749 .83919 Mdot
.48235 .58823 Mdot
.27845 .39217 Mdot
.45491 .35687 Mdot
.55294 .56862 Mdot
.76469 .84703 Mdot
.87448 .91761 Mdot
.76469 .85095 Mdot
.69802 .79606 Mdot
.29021 .41177 Mdot
.37648 .32943 Mdot
.50588 .45491 Mdot
.67842 .76469 Mdot
.8235 .91369 Mdot
.79213 .86272 Mdot
.52157 .64705 Mdot
.3608 .47451 Mdot
.34511 .10983 Mdot
.55686 .29413 Mdot
4e-05 .14905 Mdot
.98035 .99996 Mdot
.81566 .88232 Mdot
.67842 .77253 Mdot
.60783 .68234 Mdot
.29413 .40393 Mdot
.50196 .29806 Mdot
.52157 .56078 Mdot
.92546 .94898 Mdot
.8588 .91369 Mdot
.76076 .83919 Mdot
.65097 .76469 Mdot
.33335 .44314 Mdot
.40001 .3255 Mdot
.54117 .50196 Mdot
.83527 .87448 Mdot
.75292 .92154 Mdot
.74116 .84703 Mdot
.17257 .35687 Mdot
.3804 .4902 Mdot
.34511 .18434 Mdot
.53725 .19218 Mdot
.00788 .23531 Mdot
.92938 .94506 Mdot
.76076 .84703 Mdot
.71371 .81566 Mdot
.52549 .62352 Mdot
.32943 .42354 Mdot
.42746 .31374 Mdot
.63136 .64705 Mdot
.98035 .99604 Mdot
.79213 .87448 Mdot
.74508 .82743 Mdot
.37648 .4902 Mdot
.36472 .46667 Mdot
.38824 .11376 Mdot
.59215 .57254 Mdot
.84311 .88232 Mdot
.74116 .89409 Mdot
.749 .83135 Mdot
.28629 .43138 Mdot
.35295 .46275 Mdot
.34119 .23531 Mdot
.50196 .22355 Mdot
.00788 .3059 Mdot
.39217 .52157 Mdot
.77253 .85095 Mdot
.71763 .8235 Mdot
.41961 .53333 Mdot
.34903 .44706 Mdot
.44706 .06278 Mdot
.76076 .76861 Mdot
.68234 .76861 Mdot
.79213 .86664 Mdot
.64705 .83135 Mdot
.42746 .58039 Mdot
.32158 .43922 Mdot
.42746 .18042 Mdot
.76076 .64313 Mdot
.75292 .80782 Mdot
.61176 .81174 Mdot
.32158 .64705 Mdot
.1216 .33335 Mdot
.40393 .50588 Mdot
.33727 .23531 Mdot
.49804 .15297 Mdot
.02357 .23924 Mdot
.74116 .84703 Mdot
.1961 .62352 Mdot
.07846 .18042 Mdot
.20002 .34903 Mdot
.51765 .60783 Mdot
.43138 .22747 Mdot
.70194 .69802 Mdot
.78037 .85487 Mdot
.32943 .749 Mdot
.43138 .17257 Mdot
.13728 .09807 Mdot
.3059 .42746 Mdot
.39609 .13336 Mdot
.71371 .6392 Mdot
.76861 .85095 Mdot
.28629 .71763 Mdot
.14905 .43138 Mdot
.55686 .04709 Mdot
.03141 .14905 Mdot
.3255 .12552 Mdot
.62744 .23924 Mdot
.02357 .15689 Mdot
.31374 .70979 Mdot
.0667 .66665 Mdot
.6392 .03141 Mdot
.38824 .03925 Mdot
.50588 .60391 Mdot
.55686 .37648 Mdot
.60391 .62744 Mdot
.23139 .5647 Mdot
.35687 .8588 Mdot
.68626 .03141 Mdot
.5098 .02749 Mdot
.1961 .34119 Mdot
.41569 .25884 Mdot
.62352 .60391 Mdot
.3608 .59607 Mdot
.40001 .83527 Mdot
.65881 .0667 Mdot
.5647 .32158 Mdot
.39609 .03925 Mdot
.36472 .04709 Mdot
.56078 .53333 Mdot
.33727 .54117 Mdot
.04709 .59999 Mdot
.41569 .15689 Mdot
.72939 .53725 Mdot
.44314 4e-05 Mdot
.34119 .37648 Mdot
.51765 .47451 Mdot
.50588 .62744 Mdot
.02357 .4902 Mdot
.62352 .18434 Mdot
.59999 .41961 Mdot
.70587 .57646 Mdot
.0667 .21963 Mdot
.47451 .27845 Mdot
.59999 .64705 Mdot
.01572 .45098 Mdot
.68626 .21571 Mdot
.76861 .06278 Mdot
.60783 .57254 Mdot
.48235 .0118 Mdot
.33335 .20394 Mdot
.61568 .58431 Mdot
.0118 .28237 Mdot
.69802 .27453 Mdot
.45491 .31766 Mdot
.63136 .58039 Mdot
.4353 .13728 Mdot
.44314 .22355 Mdot
.50588 .47451 Mdot
.0118 .21179 Mdot
.56862 .28237 Mdot
.03141 .57254 Mdot
.75684 .59999 Mdot
.43922 4e-05 Mdot
.3255 .6941 Mdot
.45491 .40001 Mdot
.02749 .21963 Mdot
.4353 .22747 Mdot
.02749 .54902 Mdot
.59215 .34903 Mdot
.40001 .31374 Mdot
.52941 .0667 Mdot
.40393 .37648 Mdot
.00788 .20002 Mdot
.47059 .18826 Mdot
.03533 .5098 Mdot
.75684 .05886 Mdot
.51372 .21179 Mdot
.70194 .59607 Mdot
.46667 .43138 Mdot
.00396 .16865 Mdot
.00788 .11376 Mdot
.00788 .44314 Mdot
.76469 .11768 Mdot
.65097 .10591 Mdot
.54509 .42746 Mdot
.57254 .40001 Mdot
.00788 .18042 Mdot
.32158 .1765 Mdot
4e-05 .40001 Mdot
.00396 .46667 Mdot
.749 .04317 Mdot
.67842 .47451 Mdot
.52549 .31374 Mdot
.00396 .1412 Mdot
.21963 .03925 Mdot
4e-05 .37256 Mdot
.03533 .66273 Mdot
.77645 .05886 Mdot
.52549 .00396 Mdot
.04709 .55686 Mdot
.09807 .1765 Mdot
.32943 .13336 Mdot
4e-05 .33727 Mdot
.33727 .88624 Mdot
.78037 .05102 Mdot
.53333 .00396 Mdot
.59215 .14513 Mdot
.39217 .40393 Mdot
.42746 .10199 Mdot
4e-05 .28629 Mdot
.54509 .87448 Mdot
.74508 .0667 Mdot
.59999 .01965 Mdot
.58823 .42354 Mdot
.4353 .38432 Mdot
.44314 .10199 Mdot
4e-05 .19218 Mdot
.24708 .64705 Mdot
.47059 .1412 Mdot
.50588 .06278 Mdot
.56078 .02749 Mdot
.4353 .38824 Mdot
.28237 .1216 Mdot
.01965 .23139 Mdot
.03141 .54509 Mdot
.09023 .25492 Mdot
.20002 .12552 Mdot
.58039 .01965 Mdot
.43138 .38432 Mdot
.11376 .11768 Mdot
.00396 .22747 Mdot
.00788 .48235 Mdot
.00396 .27845 Mdot
.02357 .1765 Mdot
.55294 .03141 Mdot
.43922 .36472 Mdot
.07454 .09415 Mdot
.05494 .41569 Mdot
4e-05 .41569 Mdot
.0118 .31374 Mdot
.00788 .1961 Mdot
.35295 .03141 Mdot
.41177 .35295 Mdot
.05494 .09415 Mdot
.01965 .25884 Mdot
.00396 .37648 Mdot
.01965 .31766 Mdot
.05886 .24708 Mdot
.05886 .09415 Mdot
.41177 .34903 Mdot
.0118 .10591 Mdot
.0118 .23531 Mdot
.00396 .3608 Mdot
.16865 .38432 Mdot
.35295 .4902 Mdot
.00396 .13336 Mdot
.41961 .34119 Mdot
.00396 .11768 Mdot
4e-05 .22355 Mdot
.00396 .34119 Mdot
.40785 .52157 Mdot
.6196 .70979 Mdot
.03533 .18826 Mdot
.47843 .34511 Mdot
.0118 .13728 Mdot
.0118 .26276 Mdot
.02749 .34511 Mdot
.51372 .59607 Mdot
.70587 .77253 Mdot
.21963 .35295 Mdot
.49804 .34119 Mdot
.00788 .15297 Mdot
.00788 .23139 Mdot
.18042 .41177 Mdot
.60783 .67057 Mdot
.72155 .78429 Mdot
.25884 .3804 Mdot
.35295 .23531 Mdot
.00396 .14905 Mdot
.01572 .21179 Mdot
.43922 .55294 Mdot
.85095 .8784 Mdot
.46275 .49412 Mdot
.23531 .36472 Mdot
.03141 .07454 Mdot
.00396 .16081 Mdot
.00396 .1412 Mdot
.51765 .59607 Mdot
.58823 .5647 Mdot
.47059 .41961 Mdot
.23924 .34903 Mdot
.00788 .07846 Mdot
.00396 .16081 Mdot
.07846 .21963 Mdot
.74116 .78821 Mdot
.52157 .45098 Mdot
.46275 .39609 Mdot
.25492 .34119 Mdot
.24708 .03533 Mdot
.00396 .14905 Mdot
.43138 .52157 Mdot
.56078 .54902 Mdot
.45491 .41177 Mdot
.40393 .3804 Mdot
.25492 .3255 Mdot
.00788 .09807 Mdot
4e-05 .18826 Mdot
.53725 .60783 Mdot
.48235 .43922 Mdot
.37648 .36472 Mdot
.38432 .39609 Mdot
.20394 .3059 Mdot
.00396 .13336 Mdot
.10591 .28237 Mdot
.56862 .60783 Mdot
.40393 .39217 Mdot
.37648 .37256 Mdot
.36472 .38432 Mdot
.14513 .27845 Mdot
.00396 .09415 Mdot
.4902 .56078 Mdot
.41177 .3608 Mdot
.40393 .38824 Mdot
.36472 .3608 Mdot
.35295 .36864 Mdot
.22747 .14513 Mdot
.00396 .12944 Mdot
.6941 .76076 Mdot
.42354 .40393 Mdot
.37648 .37256 Mdot
.39609 .39609 Mdot
.33727 .35687 Mdot
.01965 .07846 Mdot
.03925 .1765 Mdot
.41569 .39609 Mdot
.43138 .41569 Mdot
.38824 .36864 Mdot
.37256 .3804 Mdot
.28237 .33727 Mdot
.00396 .12552 Mdot
.4902 .56862 Mdot
.48235 .46275 Mdot
.43138 .43922 Mdot
.3804 .37256 Mdot
.3608 .37648 Mdot
.1961 .27845 Mdot
4e-05 .11768 Mdot
.6392 .68626 Mdot
.50588 .52157 Mdot
.40785 .41961 Mdot
.34511 .35687 Mdot
.39217 .41569 Mdot
.30198 .33727 Mdot
.02357 .15297 Mdot
.52549 .52549 Mdot
.55686 .55686 Mdot
.35687 .39217 Mdot
.34903 .3608 Mdot
.34511 .36864 Mdot
.23531 .1412 Mdot
.60783 .65097 Mdot
.58039 .57254 Mdot
.4353 .45098 Mdot
.34903 .40785 Mdot
.35687 .41569 Mdot
.28237 .34903 Mdot
4e-05 .16473 Mdot
.34511 .35687 Mdot
.44314 .42746 Mdot
.45098 .52157 Mdot
.24316 .34119 Mdot
.34903 .37256 Mdot
.34903 .41961 Mdot
.12944 .251 Mdot
.42746 .39609 Mdot
.43138 .41569 Mdot
.10983 .23139 Mdot
.19218 .27061 Mdot
.40785 .44706 Mdot
.35687 .38432 Mdot
.5098 .55686 Mdot
.4353 .38432 Mdot
.42354 .47059 Mdot
.23139 .33335 Mdot
.12552 .22355 Mdot
.26668 .34119 Mdot
.03533 .26668 Mdot
.43922 .40393 Mdot
.46667 .40393 Mdot
.3255 .43138 Mdot
.34511 .39217 Mdot
.36472 .41177 Mdot
.38432 .44314 Mdot
.44706 .45098 Mdot
.43922 .41177 Mdot
.36864 .39609 Mdot
.56078 .51372 Mdot
.4902 .43922 Mdot
.34119 .37648 Mdot
.18826 .65489 Mdot
.44706 .40393 Mdot
.45491 .40001 Mdot
.6196 .70979 Mdot
.52941 .41961 Mdot
.38824 .39609 Mdot
.4353 .50196 Mdot
.37648 .38824 Mdot
.43138 .41177 Mdot
.40785 .40393 Mdot
.54117 .5098 Mdot
.42354 .3804 Mdot
.3608 .42354 Mdot
.43922 .35687 Mdot
.45491 .40785 Mdot
.42354 .39217 Mdot
.45883 .44314 Mdot
.3804 .37256 Mdot
.43922 .42354 Mdot
.46275 .54902 Mdot
.30198 .3059 Mdot
.44314 .40393 Mdot
.73332 .78429 Mdot
.27845 .34511 Mdot
.37256 .43138 Mdot
.52549 .59607 Mdot
.35295 .30982 Mdot
.4353 .41569 Mdot
.45098 .40001 Mdot
.42354 .45491 Mdot
.42354 .48235 Mdot
.54902 .62352 Mdot
.40785 .38432 Mdot
.40001 .34119 Mdot
.42354 .36864 Mdot
.47059 .45883 Mdot
.44314 .44706 Mdot
.50196 .52157 Mdot
.52941 .59607 Mdot
.31766 .35687 Mdot
.46275 .43922 Mdot
.42354 .3804 Mdot
.59607 .63136 Mdot
.45883 .48628 Mdot
.67057 .71371 Mdot
.18434 .23924 Mdot
.43138 .41569 Mdot
.48235 .46275 Mdot
.57254 .59999 Mdot
.49412 .53725 Mdot
.75292 .78821 Mdot
.43922 .37256 Mdot
.41569 .40785 Mdot
.45883 .44706 Mdot
.59607 .53725 Mdot
.67842 .64705 Mdot
.87056 .89017 Mdot
.46667 .33727 Mdot
.40001 .41569 Mdot
.46667 .45883 Mdot
.54117 .45883 Mdot
.65097 .59607 Mdot
.90193 .92154 Mdot
.4902 .35687 Mdot
.3804 .39609 Mdot
.47059 .46275 Mdot
.57646 .56078 Mdot
.91761 .89017 Mdot
.81958 .8588 Mdot
.36472 .34511 Mdot
.35687 .38824 Mdot
.45098 .45491 Mdot
.60783 .63136 Mdot
.99604 .99604 Mdot
.78037 .81566 Mdot
.24708 .34903 Mdot
.43922 .4902 Mdot
.4902 .52941 Mdot
.87056 .88232 Mdot
.98428 .99212 Mdot
.69802 .73724 Mdot
.37256 .43138 Mdot
.42746 .47843 Mdot
.57646 .61176 Mdot
.99212 .99212 Mdot
.83527 .87448 Mdot
.42354 .35687 Mdot
.36472 .42746 Mdot
.50588 .57646 Mdot
.99604 .99604 Mdot
.8784 .89409 Mdot
.75292 .76861 Mdot
.40393 .47451 Mdot
.52157 .59607 Mdot
.99212 .99996 Mdot
.95291 .97251 Mdot
.77253 .8235 Mdot
.36864 .45098 Mdot
.51765 .57646 Mdot
.86664 .92154 Mdot
.97251 .97643 Mdot
.79606 .83527 Mdot
.35295 .43138 Mdot
.52941 .60783 Mdot
.8588 .90193 Mdot
.90585 .92154 Mdot
.79998 .83135 Mdot
.40001 .46275 Mdot
.59999 .67057 Mdot
.98035 .9882 Mdot
.89409 .9333 Mdot
.60783 .52549 Mdot
.47843 .53725 Mdot
.84311 .89801 Mdot
.9333 .96075 Mdot
.81566 .85095 Mdot
.42354 .48235 Mdot
.68626 .74508 Mdot
.94114 .96859 Mdot
.85487 .89017 Mdot
.41961 .38824 Mdot
.65881 .72547 Mdot
.91369 .9333 Mdot
.89801 .90193 Mdot
.46667 .4902 Mdot
.77645 .83527 Mdot
.89801 .91761 Mdot
.34119 .77253 Mdot
.61176 .69018 Mdot
.90977 .94114 Mdot
.3608 .78037 Mdot
.67057 .69802 Mdot
.74116 .65881 Mdot
.60391 .49804 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol00000oomo0?ooO`020?mo00030?ooO`3oO`00ogl000/0
ogl000<0oomo0?mo003oO`001`3oO`030?ooOa<0ogl000<0Oooo0?mo003oO`001`3oO`000`1oool0
ogl00?mo000P0?mo000307ooo`3oO`00ogl000`0ogl000<0Oooo0?mo003oO`000`3oO`020:0Pl0<0
ogl00P2P8?000`3oO`00X23`0:0Pl0040:0Pl0P0ogl00P2P8?000`3oO`00X23`0:0Pl0070:0Pl003
0?mo002P8?00X23`0080ogl0102P8?020?mo00@0X23`0`1oool20:0Pl0030?mo001oool0X23`0080
X23`201oool20:0Pl6@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0103oogl70?mo00030?oo
O`3oO`00ogl00080ogl00`3oogl40?mo00030?ooO`3oO`00ogl001H0ogl000<0Oooo0?mo003oO`00
1`3oO`000`1oool0ogl00?mo000P0?mo000307ooo`3oO`00ogl00140ogl00`2P8?080?mo00@0X23`
203oO`020:0Pl0040?mo002P8?00X23`0?mo00H0X23`00<0ogl00:0Pl02P8?000P3oO`040:0Pl080
ogl01@2P8?0207ooo`<0X23`00<0ogl00:0Pl02P8?000P2P8?0507ooo`@0X23`00@0ogl00:0Pl02P
8?00X23`H01oool1o`00007ooooo00000ol00000oomo0?ooO`050?ooO`80ogl00P3oogl30?mo00D0
oomo0P3oO`050?ooO`H0ogl00P3oogl20?mo00030?ooO`3oO`00ogl000<0ogl00`3oogl40?mo0004
0?ooOol00000Oooo07ooo`L0ogl00P1oool40?mo000307ooo`3oO`00ogl000@0Oooo0P3oO`000`1o
ool0ogl00?mo00020?mo000307ooo`3oO`00ogl000<0ogl0101oool30?mo000407ooo`3oO`00ogl0
07ooo`L0ogl00`1oool50?mo00<0Oooo0P2P8?020?mo000307ooo`3oO`00ogl000@0ogl00P2P8?08
0?mo0080X23`203oO`040:0Pl0D0ogl00`2P8?060?mo0080X23`00<0ogl007ooo`2P8?000P2P8?02
0?mo000307ooo`2P8?00X23`00<0Oooo0P3oO`040:0Pl0040?mo002P8?00X23`0:0Pl600Oooo0Ol0
0001ooooo`0000?o00000?ooO`3oogl01P3oogl20?mo0080oomo0P3oO`050?ooO`80ogl00`3oogl4
0?mo00/0oomo0P3oO`050?ooO`80ogl00`3oogl2o`000080ogl000<0Oooo0?mo003oO`000P3oO`02
07ooo`@0ogl000<0Oooo0?mo003oO`000P1oool=0?mo00X0Oooo0P3oO`00101oool0ogl00?mo003o
O`0807ooo`80ogl0101oool50?mo000507ooo`2P8?00X23`0?mo001oool00`3oO`0507ooo`<0ogl0
0`2P8?020?mo000307ooo`3oO`00ogl00180ogl00P1oool50?mo000307ooo`3oO`00ogl000H0ogl0
0P1oool20?mo00T0X23`00<0Oooo0?mo003oO`000P3oO`0207ooo`80ogl0EP1oool1o`00007ooooo
00000ol00000oomo0?ooO`060?ooO`80ogl03P3oogl30?mo00l0oomo0P3oO`090?ooO`80ogl01P1o
ool40?mo00@0Oooo203oO`000`1oool0ogl00?mo00030?mo00@0Oooo0`3oO`0707ooo`80ogl02@1o
ool20?mo00@0Oooo103oO`0207ooo`80X23`0P1oool20?mo00L0Oooo0P3oO`020:0Pl0040?mo001o
ool0Oooo07ooo`H0ogl00P2P8?080?mo0080X23`0P3oO`0207ooo`030?mo002P8?00X23`0080ogl0
00@0Oooo0?mo002P8?00X23`1`3oO`000`1oool0X23`0:0Pl00207ooo`H0X23`1@3oO`00101oool0
X23`0:0Pl03oO`040:0Pl580Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl01@3oogl20?mo0100
oomo0P3oO`020?ooO`80ogl02`3oogl20?mo00X0oomo0_l0000507ooo`80ogl01P1oool20?mo00@0
Oooo0P3oO`00101oool0ogl00?mo003oO`0607ooo`<0ogl02@1oool20?mo00l0Oooo0P3oO`000`1o
ool0X23`0:0Pl00507ooo`80ogl01`1oool0103oO`00X23`0:0Pl02P8?0207ooo`D0ogl000<0Oooo
0:0Pl02P8?000`3oO`001@1oool0ogl00:0Pl02P8?00ogl000@0X23`0P3oO`000`1oool0X23`0:0P
l0040?mo0080X23`103oO`000`1oool0ogl00?mo00030:0Pl0@0ogl00`1oool30:0Pl0040?mo001o
ool0Oooo0?mo0080X23`00<0Oooo0:0Pl02P8?001@2P8?1?07ooo`7o00000Oooool00003o`00003o
ogl0oomo00D0oomo0P3oO`0D0?ooO`80ogl02`3oogl20?mo00`0oomo00?o000007ooo`1oool0501o
ool30?mo00l0Oooo0P2P8?020?mo0180Oooo0`2P8?0407ooo`80ogl01@1oool20?mo000407ooo`2P
8?00X23`0:0Pl080ogl00P1oool0103oO`00X23`0:0Pl01oool30?mo0080Oooo0P3oO`020:0Pl003
07ooo`2P8?00X23`0080X23`1P3oO`00101oool0ogl00:0Pl02P8?050?mo000307ooo`3oO`00ogl0
0080X23`1`3oO`000`1oool0X23`0:0Pl0030:0Pl0<0ogl02@2P8?000`1oool0X23`0:0Pl01<07oo
o`7o00000Oooool00003o`00003oogl0oomo03L0oomo00?o000007ooo`1oool0501oool20?mo00l0
Oooo0P2P8?0E07ooo`80X23`2`1oool20?mo00<0Oooo0`3oO`0307ooo`80X23`0P1oool20?mo0080
Oooo0P3oO`0507ooo`80X23`00<0Oooo0?mo003oO`000P3oO`0307ooo`80X23`0P3oO`000`1oool0
ogl00?mo000207ooo`L0ogl000<0Oooo0?mo003oO`00101oool20:0Pl0030?mo001oool0Oooo00D0
X23`0P1oool20:0Pl00307ooo`2P8?00X23`04`0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
2@3oogl20?mo01l0oomo0P3oO`0<0?ooO`03o`00001oool0Oooo01l0Oooo0P3oO`0507ooo`80X23`
201oool40?mo00h0Oooo0P3oO`0307ooo`80ogl000<0Oooo0:0Pl02P8?00201oool20?mo000307oo
o`3oO`00ogl00080X23`101oool20:0Pl0D0Oooo0P2P8?020?mo0080Oooo0P3oO`0307ooo`80ogl0
00<0Oooo0?mo003oO`000P3oO`020:0Pl0040?mo001oool0Oooo07ooo`80ogl00`1oool20:0Pl004
0?mo002P8?00X23`07ooo`80X23`00D0Oooo0:0Pl02P8?00ogl007ooo`020?mo04h0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl02@3oogl20?mo00l0oomo0P3oO`0>0?ooO`80ogl03@3oogl00ol0
0000Oooo07ooo`0707ooo`80X23`3P1oool20?mo00D0Oooo0P3oO`0507ooo`80X23`1@1oool70?mo
0080Oooo0P2P8?0407ooo`80X23`101oool20?mo00<0Oooo0P3oO`000`1oool0X23`0:0Pl00507oo
o`80X23`0P3oO`020:0Pl080ogl00P2P8?00103oO`00Oooo07ooo`1oool20:0Pl00507ooo`3oO`00
ogl007ooo`3oO`000`2P8?000`3oO`00Oooo07ooo`020?mo00<0Oooo0P3oO`000`1oool0ogl00?mo
00020?mo0080X23`0`3oO`000`1oool0ogl00?mo00030?mo0080X23`00<0ogl00:0Pl02P8?001`2P
8?000`1oool0ogl00?mo00020?mo00D0Oooo0P3oO`1507ooo`7o00000Oooool00003o`00003oogl0
oomo01X0oomo0P3oO`0N0?ooO`03o`00002P8?00X23`00@0Oooo0P3oO`020:0Pl0@0Oooo0P3oO`07
07ooo`<0ogl0301oool20?mo00D0Oooo0`3oO`040:0Pl080Oooo0P2P8?0307ooo`030?mo002P8?00
X23`00/0Oooo0`3oO`0507ooo`80X23`0P3oO`020:0Pl0<0Oooo0`3oO`001@1oool0X23`0:0Pl03o
O`00Oooo0080X23`00<0Oooo0?mo002P8?000P2P8?0207ooo`030?mo002P8?00X23`0080ogl000<0
Oooo0?mo003oO`000P1ooolA0?mo00T0X23`00<0Oooo0?mo003oO`000P3oO`000`1oool0ogl00?mo
000207ooo`80ogl0A@1oool1o`00007ooooo00000ol00000oomo0?ooO`0K0?ooO`80ogl05@3oogl2
0?mo00@0oomo0P3oO`000`3oogl0X23`0:0Pl00407ooo`80ogl01P1oool20?mo00L0Oooo0P3oO`07
07ooo`030?mo002P8?00X23`00d0Oooo102P8?0707ooo`80ogl01@1oool20:0Pl00307ooo`3oO`00
ogl00080Oooo0P3oO`000`1oool0ogl00?mo000307ooo`030?mo002P8?00X23`0080ogl00`1oool2
0:0Pl080ogl000<0Oooo0:0Pl02P8?000P3oO`020:0Pl080Oooo0P2P8?0307ooo`030?mo002P8?00
X23`0080ogl00P2P8?00103oO`00Oooo07ooo`1oool50?mo0080Oooo1@3oO`00101oool0ogl00?mo
001oool80:0Pl0040?mo001oool0X23`0:0Pl0D0ogl000@0Oooo0:0Pl02P8?00ogl00P2P8?1307oo
o`7o00000Oooool00003o`00003oogl0oomo01/0oomo0P3oO`0;0?ooO`80X23`203oogl20?mo00@0
oomo0P3oO`020?ooO`03o`00001oool0Oooo0080ogl06P1oool00`3oO`00X23`0:0Pl00207ooo`80
X23`0P1oool20:0Pl0030?mo001oool0Oooo00X0Oooo0P2P8?0807ooo`80X23`00<0Oooo0?mo003o
O`001@1oool20?mo0080Oooo0P3oO`020:0Pl0D0Oooo0P2P8?0507ooo`H0X23`0`1oool20?mo0080
Oooo0`3oO`020:0Pl080Oooo0P3oO`001@1oool0ogl00:0Pl02P8?00Oooo00@0ogl00P2P8?030?mo
0080X23`0P3oO`060:0Pl0040?mo002P8?00X23`0:0Pl0H0ogl00P2P8?000`3oO`00X23`0:0Pl004
07ooo`80ogl0?@1oool1o`00007ooooo00000ol00000oomo0?ooO`0X0?ooO`80X23`4`3oogl2o`00
0080ogl06`1oool20:0Pl080Oooo0P2P8?001@1oool0ogl00:0Pl02P8?00ogl000L0Oooo103oO`00
0`1oool0X23`0:0Pl00707ooo`80ogl03@1oool20?mo00h0Oooo0P2P8?0207ooo`80X23`0`1oool2
0?mo00<0Oooo0P3oO`0407ooo`@0ogl0102P8?000`3oO`00Oooo07ooo`020:0Pl00307ooo`3oO`00
ogl00080X23`00<0Oooo0?mo002P8?001@2P8?001P3oO`00X23`0:0Pl02P8?00ogl007ooo`X0ogl0
00<0Oooo0?mo003oO`000P2P8?0307ooo`<0ogl0=`1oool1o`00007ooooo00000ol00000X23`0:0P
l00C0?ooO`80ogl01P3oogl20?mo00/0oomo0P3oO`0E0?ooO`03o`00001oool0Oooo01`0Oooo0P3o
O`0307ooo`80ogl02@1oool40?mo00D0Oooo0P2P8?0307ooo`80ogl01P1oool20:0Pl1<0Oooo0P2P
8?0307ooo`80X23`00<0Oooo0:0Pl02P8?000P3oO`000`1oool0ogl00?mo00030?mo00D0Oooo00<0
ogl00:0Pl02P8?000P1oool20:0Pl0030?mo001oool0ogl00080ogl000<0Oooo0:0Pl02P8?000P2P
8?0307ooo`<0ogl00P2P8?020?mo0080X23`00<0ogl007ooo`3oO`002@3oO`000`1oool0ogl00?mo
00020:0Pl00307ooo`3oO`00ogl000<0ogl000<0Oooo0?mo003oO`00=01oool1o`00007ooooo0000
0ol00000X23`0:0Pl00C0?ooO`80ogl01P3oogl20?mo01@0oomo0P3oO`0=0?ooO`03o`00001oool0
Oooo01/0Oooo0P3oO`0>07ooo`80ogl0101oool20:0Pl00307ooo`2P8?00X23`00T0Oooo0P3oO`02
0:0Pl0<0Oooo0P3oO`0907ooo`80ogl00`1oool20:0Pl0030?mo001oool0Oooo0080X23`00<0Oooo
0:0Pl02P8?000P3oO`001@1oool0ogl00?mo003oO`00Oooo00@0ogl00P1oool00`3oO`00X23`0:0P
l00307ooo`80ogl000D0Oooo0?mo002P8?00X23`07ooo`040:0Pl00307ooo`3oO`00ogl00080Oooo
1@3oO`020:0Pl0030?mo001oool0ogl000<0ogl00P1oool20:0Pl0<0ogl00P2P8?000`1oool0ogl0
0?mo00020?mo0080X23`0P1oool20?mo03@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0<@3o
ogl20?mo00h0oomo0_l0000a07ooo`80X23`301oool20?mo00D0Oooo0P3oO`0907ooo`80ogl0101o
ool20?mo00D0Oooo0P3oO`0307ooo`80ogl00P1oool40?mo00<0Oooo0P3oO`0307ooo`80ogl00P1o
ool20:0Pl0H0Oooo0P3oO`0407ooo`80ogl01@1oool30?mo00<0Oooo0P2P8?030?mo0080X23`00D0
Oooo0?mo003oO`00ogl007ooo`020:0Pl3P0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0203o
ogl20:0Pl0d0oomo0P3oO`020?ooO`80ogl09P3oogl00ol00000Oooo07ooo`0I07ooo`80ogl0301o
ool20?mo00P0Oooo0P3oO`0307ooo`80X23`1`1oool20?mo00@0Oooo0P3oO`020:0Pl00507ooo`2P
8?00X23`0:0Pl01oool00P3oO`0307ooo`80ogl0101oool20?mo00D0Oooo0P2P8?0:07ooo`80ogl0
1@1oool20:0Pl00307ooo`2P8?00X23`00D0Oooo0P3oO`0307ooo`80ogl0101oool20?mo00<0Oooo
1@3oO`020:0Pl0<0Oooo0P3oO`0807ooo`80ogl0<P1oool1o`00007ooooo00000ol00000oomo0?oo
O`080?ooO`80X23`3@3oogl20?mo0080oomo0P3oO`0W0?ooO`03o`00001oool0Oooo00l0Oooo102P
8?0507ooo`<0ogl01`1oool20:0Pl00407ooo`3oO`00ogl00?mo00D0Oooo0P3oO`000`1oool0ogl0
0?mo00030?mo0080X23`1`1oool20?mo000407ooo`3oO`00ogl007ooo`@0X23`00<0Oooo0:0Pl02P
8?00102P8?0207ooo`80X23`00<0ogl007ooo`1oool00P1oool20:0Pl080Oooo0P3oO`000`1oool0
X23`0:0Pl0020:0Pl080ogl01P1oool20?mo00D0Oooo0P2P8?000`1oool0X23`0:0Pl0020:0Pl003
0?mo001oool0ogl00080ogl000<0Oooo0?mo003oO`000P3oO`0407ooo`80ogl000<0Oooo0:0Pl02P
8?001@3oO`020:0Pl080Oooo0`3oO`0607ooo`80X23`0P3oO`0b07ooo`7o00000Oooool00003o`00
003oogl0oomo04D0oomo00?o000007ooo`1oool02@1oool20?mo00<0Oooo102P8?0607ooo`80ogl0
1`1oool20:0Pl00307ooo`3oO`00ogl000D0Oooo0`3oO`0307ooo`<0ogl02P1oool40?mo000307oo
o`2P8?00X23`0080X23`00<0Oooo0:0Pl02P8?00102P8?0207ooo`80X23`0`1oool20?mo0080X23`
00D0Oooo0?mo003oO`00ogl007ooo`020?mo00<0X23`00<0ogl007ooo`1oool0101oool20?mo00D0
Oooo0P2P8?030?mo0080X23`00@0ogl007ooo`3oO`00ogl00P1oool40?mo0080X23`00<0ogl007oo
o`1oool00P1oool20:0Pl0<0Oooo0P3oO`00101oool0ogl00?mo001oool20?mo00D0Oooo0P3oO`02
0:0Pl080Oooo0P3oO`0`07ooo`7o00000Oooool00003o`00003oogl0oomo00D0oomo0P2P8?0l0?oo
O`80ogl000<0oomoo`000?l000002@1oool20?mo0200Oooo103oO`0407ooo`80X23`201oool30?mo
00D0Oooo0P2P8?000`3oO`00X23`0:0Pl0020:0Pl080Oooo0P2P8?0207ooo`80ogl000<0Oooo0?mo
003oO`000`1oool30?mo0080Oooo0P3oO`020:0Pl0@0Oooo0P2P8?000`1oool0ogl00?mo000507oo
o`@0ogl00P1oool20?mo00D0Oooo0P3oO`0207ooo`80X23`00<0ogl007ooo`1oool02P1oool20?mo
000407ooo`2P8?00X23`0?mo0080Oooo1P3oO`0207ooo`<0ogl0;`1oool1o`00007ooooo00001?l0
0000X23`0:0Pl03oogl20:0Pl080oomo0P2P8?0K0?ooO`80ogl07`3oogl20?mo00<0oomo00?o0000
07ooo`1oool09P1oool20?mo0080Oooo0P3oO`0407ooo`80X23`00<0Oooo0?mo003oO`001@1oool2
0?mo00L0Oooo103oO`020:0Pl080Oooo0P2P8?00103oO`00Oooo0:0Pl02P8?0C07ooo`@0X23`1@1o
ool20?mo00X0Oooo0P2P8?020?mo00P0Oooo0P3oO`0507ooo`80ogl00`1oool20:0Pl0030?mo001o
ool0Oooo0080ogl00P1oool40?mo000307ooo`3oO`00ogl00080ogl0;@1oool1o`00007ooooo0000
0ol00000X23`0:0Pl0030:0Pl0<0oomo0P2P8?0J0?ooO`80ogl01`3oogl20?mo00T0oomo0P3oO`07
0?ooO`80ogl0203oogl00ol00000Oooo07ooo`0=07ooo`80ogl01@1oool20?mo00X0Oooo0P2P8?03
07ooo`80ogl02@1oool40?mo00h0Oooo103oO`020:0Pl0<0Oooo0P3oO`000`1oool0X23`0:0Pl003
07ooo`030?mo002P8?00X23`00l0Oooo0P2P8?0507ooo`80ogl02P1oool20:0Pl0L0Oooo0P3oO`00
0`1oool0ogl00?mo000507ooo`80ogl01@1oool40?mo000307ooo`3oO`00ogl00080Oooo00@0ogl0
0:0Pl02P8?00Oooo0`3oO`000`1oool0ogl00?mo000Z07ooo`7o00000Oooool00003o`00002P8?00
X23`0080X23`00@0oomo0:0Pl02P8?00oomo0P2P8?050?ooO`@0ogl06P3oogl20?mo00D0oomo0P3o
O`020?ooO`80ogl01`3oogl20?mo00T0oomo00?o000007ooo`1oool0301oool00`3oO`00X23`0:0P
l00407ooo`80X23`2P1oool20:0Pl0T0Oooo0P3oO`0307ooo`80ogl04P1oool20?mo00<0Oooo0P3o
O`0807ooo`030?mo002P8?00X23`00T0Oooo0P3oO`0H07ooo`80ogl01P1oool20?mo00D0Oooo0`3o
O`000`1oool0ogl00?mo000;0?mo0080Oooo00@0ogl00:0Pl02P8?00Oooo0P3oO`0207ooo`80ogl0
:P1oool1o`00007ooooo00000ol00000X23`0:0Pl0020:0Pl0030?ooO`2P8?00X23`00P0oomo1P3o
O`0O0?ooO`80ogl05`3oogl00ol00000Oooo07ooo`0<07ooo`80X23`101oool20:0Pl1D0Oooo0P3o
O`0307ooo`80ogl0101oool20:0Pl080ogl03P1oool30?mo00/0Oooo0P3oO`0707ooo`80ogl0201o
ool20?mo00`0Oooo103oO`0807ooo`80ogl00`1oool30?mo000307ooo`3oO`00ogl000@0ogl00`1o
ool20?mo00P0Oooo00<0ogl00:0Pl02P8?00;@1oool1o`00007ooooo00000ol00000X23`0:0Pl00<
0?ooO`<0X23`0P3oogl20:0Pl3T0oomo00?o000007ooo`1oool0901oool20?mo00H0Oooo0`3oO`04
07ooo`80X23`0P3oO`0507ooo`80ogl000<0Oooo0?mo003oO`000P1oool50?mo000307ooo`3oO`00
ogl000P0Oooo0P3oO`0A07ooo`80ogl02P1oool20:0Pl080ogl02P1oool20?mo00<0Oooo0P3oO`0@
07ooo`80X23`101oool20:0Pl2d0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0303oogl30:0P
l080oomo0P2P8?0j0?ooO`03o`00001oool0Oooo02<0Oooo0P3oO`0607ooo`80ogl03P1oool20?mo
000307ooo`3oO`00ogl00080Oooo0P3oO`00101oool0ogl00?mo001oool20?mo02L0Oooo0P2P8?0A
07ooo`80ogl0401oool20:0Pl3<0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?000P2P8?0Q0?oo
O`80X23`00<0oomo0?mo003oO`009P3oogl2o`000080Oooo0P2P8?2F07ooo`80ogl03@1oool20?mo
0200Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?000P2P8?0Q0?ooO`80X23`00<0oomo0?mo003o
O`003`3oogl20?mo01L0oomo00Co000007ooo`2P8?00X23`2P1oool20:0Pl1H0Oooo0P2P8?0307oo
o`80X23`201oool20:0Pl00307ooo`3oO`00ogl00580Oooo0P2P8?0<07ooo`80ogl03@1oool20?mo
00H0Oooo0P3oO`0H07ooo`7o00000Oooool00004o`00003oogl0X23`0:0Pl3H0oomo0P3oO`0H0?oo
O`03o`00001oool0Oooo00X0Oooo0P2P8?0A07ooo`80ogl00`1oool20:0Pl0<0Oooo0P2P8?0507oo
o`80X23`00@0Oooo0:0Pl02P8?00Oooo0P3oO`0207ooo`80X23`00<0Oooo0?mo003oO`001`1oool2
0?mo00`0Oooo103oO`0307ooo`80ogl00`1oool20?mo0080Oooo0P2P8?0T07ooo`80X23`8`1oool2
0?mo01P0Oooo0Ol00001ooooo`0000Co00000:0Pl02P8?00X23`0P3oogl20:0Pl2<0oomo0P3oO`0M
0?ooO`80ogl02@3oogl2o`0000/0Oooo0P2P8?0@07ooo`80ogl0201oool20:0Pl0D0Oooo0P2P8?08
07ooo`80X23`00<0Oooo0?mo003oO`001`1oool0103oO`00X23`0:0Pl03oO`0:07ooo`@0ogl00P2P
8?000`1oool0ogl00?mo000307ooo`80ogl00P1oool20:0Pl1L0Oooo0P2P8?0@07ooo`80ogl04P1o
ool20?mo00@0Oooo0P3oO`0N07ooo`7o00000Oooool00003o`00002P8?00X23`00<0oomo0P2P8?09
0?ooO`80ogl0603oogl20?mo00`0oomo0P3oO`0?0?ooO`80ogl02`3oogl01?l00000Oooo0:0Pl02P
8?0707ooo`80X23`101oool20?mo00@0Oooo0P2P8?000`1oool0X23`0:0Pl00307ooo`80ogl000<0
Oooo0:0Pl02P8?00101oool20:0Pl0@0Oooo0P3oO`0E07ooo`80X23`00<0ogl007ooo`1oool0301o
ool20:0Pl0<0Oooo0P3oO`0507ooo`80X23`4`1oool20?mo0080Oooo0P2P8?0@07ooo`80ogl04P1o
ool20?mo000407ooo`3oO`00ogl007ooo`80ogl01P1oool20?mo01H0Oooo0Ol00001ooooo`0000?o
00000:0Pl02P8?000P2P8?020?ooO`80X23`203oogl20?mo00<0oomo0P3oO`070?ooO`80X23`2P3o
ogl20?mo00`0oomo0P3oO`0M0?ooO`03o`00002P8?00X23`00d0Oooo0P3oO`0407ooo`80X23`00<0
Oooo0:0Pl02P8?000`1oool20?mo000307ooo`2P8?00X23`00@0Oooo0P2P8?0607ooo`80ogl000<0
Oooo0?mo003oO`001@1oool20:0Pl0T0Oooo0P3oO`0?07ooo`80X23`0`1oool20?mo0080X23`0`1o
ool20:0Pl1<0Oooo0P3oO`0807ooo`@0X23`7`1oool20?mo00T0Oooo0P3oO`0F07ooo`7o00000Ooo
ool00003o`00003oogl0oomo0080X23`0P3oogl20:0Pl0d0oomo103oO`050?ooO`80X23`;`3oogl2
0:0Pl080oomo0P3oO`030?ooO`05o`00001oool0ogl00?mo001oool00P3oO`0;07ooo`80X23`0`1o
ool20:0Pl0`0Oooo0P2P8?0707ooo`80ogl000<0Oooo0?mo003oO`001@1oool20:0Pl140Oooo0P2P
8?0307ooo`80X23`2@1oool20:0Pl0030?mo001oool0Oooo00H0Oooo0P3oO`0E07ooo`80ogl0102P
8?0R07ooo`80ogl07P1oool1o`00007ooooo00000ol00000oomo0?ooO`020:0Pl1<0oomo0P3oO`0?
0?ooO`80ogl03@3oogl20:0Pl1H0oomo0P2P8?00103oogl0X23`0:0Pl03oO`040?ooO`04o`00003o
O`00X23`0:0Pl080ogl02`1oool20:0Pl0<0Oooo0P2P8?0<07ooo`80X23`6@1oool20:0Pl00307oo
o`2P8?00X23`00H0Oooo0P2P8?0307ooo`80X23`2P1oool20?mo000307ooo`3oO`00ogl000D0Oooo
0P3oO`0A07ooo`80ogl00P1oool30?mo02D0Oooo0P3oO`0407ooo`80ogl0601oool1o`00007ooooo
00000ol00000oomo0?ooO`020:0Pl2@0oomo0P3oO`0=0?ooO`80X23`6@3oogl20:0Pl0L0oomo0P2P
8?0k07ooo`80X23`00<0Oooo0:0Pl02P8?006P1oool20?mo01P0Oooo0P3oO`0307ooo`80ogl0:`1o
ool20?mo01P0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?000`3oogl20:0Pl0D0oomo0P2P8?0e
0?ooO`80ogl05`3oogl00ol00000Oooo07ooo`0807ooo`80X23`0P3oO`0;07ooo`80X23`1`1oool2
0:0Pl140Oooo0P2P8?0<07ooo`80X23`N`1oool1o`00007ooooo00000ol00000X23`0:0Pl0030?oo
O`80X23`1@3oogl20:0Pl3D0oomo0P3oO`0G0?ooO`80X23`201oool00`3oO`00X23`0:0Pl0020?mo
0080Oooo102P8?0507ooo`80X23`1`1oool20:0Pl0X0Oooo0P2P8?0407ooo`<0X23`301oool20:0P
l0l0Oooo0P2P8?0807ooo`80ogl0H01oool1o`00007ooooo00001?l00000oomo0:0Pl02P8?090?oo
O`80X23`CP3oogl20:0Pl004o`00001oool0X23`0:0Pl0@0Oooo0`2P8?0407ooo`@0X23`2P1oool2
0:0Pl0h0Oooo0P2P8?0407ooo`80X23`7P1oool20:0Pl0P0Oooo0P3oO`1P07ooo`7o00000Oooool0
0004o`00003oogl0X23`0:0Pl0T0oomo0P2P8?0H0?ooO`80ogl06@3oogl20:0Pl1`0oomo00?o0000
0:0Pl02P8?00101oool20:0Pl1<0Oooo0P2P8?000`3oO`00Oooo07ooo`0507ooo`80X23`8@1oool2
0?mo01D0Oooo0P3oO`0607ooo`80X23`401oool20?mo02D0Oooo0P3oO`0207ooo`80ogl00P1oool2
0?mo01<0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl02@3oogl20:0Pl1T0oomo0P3oO`0G0?oo
O`@0X23`7@3oogl00ol00000Oooo07ooo`0207ooo`80X23`501oool20:0Pl0030?mo001oool0Oooo
00D0Oooo0P2P8?0;07ooo`80X23`401oool20?mo00@0X23`5@1oool20?mo00H0Oooo0P2P8?0@07oo
o`80ogl0201oool20?mo00L0Oooo0P3oO`0B07ooo`80ogl00P1oool20?mo0080Oooo0P3oO`0C07oo
o`7o00000Oooool00003o`00003oogl0oomo00D0oomo0P2P8?020?ooO`80X23`<P3oogl20:0Pl1X0
oomo0P3oO`040?ooO`80ogl00P1oool20:0Pl2/0Oooo0P2P8?0407ooo`80X23`0`1oool20?mo00D0
Oooo0P3oO`040:0Pl3T0Oooo0P3oO`0207ooo`80ogl00`1oool20?mo02l0Oooo0Ol00001ooooo`00
00?o00000:0Pl02P8?000`3oogl40:0Pl0L0oomo0P2P8?190?ooO`80ogl0103oogl20?mo0003o`00
001oool0Oooo00<0Oooo102P8?0P07ooo`80X23`0`1oool20?mo00@0Oooo0P2P8?0307ooo`80ogl0
0P1oool20:0Pl0H0Oooo0P3oO`0J07ooo`80X23`1P1oool20?mo01P0Oooo0P3oO`0V07ooo`80ogl0
301oool1o`00007ooooo00000ol00000X23`0:0Pl0030?ooO`80X23`2@3oogl20:0Pl1D0oomo0P2P
8?0k0?ooO`03o`00001oool0Oooo0080Oooo102P8?0807ooo`80X23`5P1oool20:0Pl0P0Oooo0P2P
8?0807ooo`80X23`1P1oool20?mo00d0Oooo0P3oO`0;07ooo`80X23`1P1oool20?mo0400Oooo0P3o
O`0<07ooo`7o00000Oooool00003o`00003oogl0oomo00<0oomo0P2P8?0P0?ooO`80X23`?03oogl2
o`0000h0Oooo0P2P8?0P07ooo`80X23`7`1oool20?mo06<0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl0403oogl20:0Pl5<0oomo00Co000007ooo`3oO`00ogl04`1oool20:0Pl0T0Oooo0P2P8?00
0`3oO`00Oooo07ooo`020:0Pl2L0Oooo0`3oO`1M07ooo`80ogl0101oool1o`00007ooooo00000ol0
0000oomo0?ooO`0@0?ooO`80X23`A03oogl20:0Pl0h0oomo00?o00000?mo003oO`004`1oool20:0P
l00307ooo`2P8?00X23`00H0Oooo0P2P8?000`3oO`00Oooo07ooo`020:0Pl0X0Oooo103oO`0I07oo
o`<0ogl0G@1oool20?mo00@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl01@3oogl20:0Pl0`0
oomo0P2P8?040?ooO`80ogl00P2P8?0i0?ooO`80X23`3`3oogl00ol00000Oooo07ooo`0E07ooo`80
X23`5`1oool40?mo01H0Oooo0P2P8?1107ooo`80ogl0901oool1o`00007ooooo00000ol00000oomo
0?ooO`050?ooO`80X23`1`3oogl20:0Pl0<0oomo0P2P8?040?ooO`80ogl00P2P8?0<0?ooO`80X23`
8P3oogl20?mo01T0oomo0_l0000=07ooo`80X23`701oool20?mo01/0Oooo0P2P8?1107ooo`80ogl0
901oool1o`00007ooooo00000ol00000oomo0?ooO`030?ooO`80X23`0P3oogl20:0Pl0D0oomo0P2P
8?080?ooO`80X23`3`3oogl20:0Pl280oomo0P3oO`090?ooO`80X23`403oogl00ol00000Oooo07oo
o`0:07ooo`80X23`0P3oO`0J07ooo`80ogl05@1oool20:0Pl600Oooo0P3oO`0;07ooo`7o00000Ooo
ool00003o`00002P8?00X23`00<0oomo0P2P8?020?ooO`80X23`2@3oogl20:0Pl0@0oomo0P2P8?0n
0?ooO`80X23`00<0oomo0:0Pl02P8?003P3oogl20?mo00T0Oooo0P2P8?000`1oool0ogl00?mo000I
07ooo`80X23`00<0Oooo0?mo003oO`004`1oool20:0Pl600Oooo0P3oO`0407ooo`80ogl01@1oool1
o`00007ooooo00000ol00000X23`0:0Pl0080?ooO`80X23`103oogl20:0Pl080oomo0P2P8?070?oo
O`80X23`4@3oogl20?mo02H0oomo0P2P8?030?ooO`80X23`0P3oogl20:0Pl080oomo0P2P8?060?oo
O`80ogl02@1oool20:0Pl080Oooo0P2P8?0H07ooo`80X23`00<0Oooo0?mo003oO`005P1oool20:0P
l6<0Oooo0P3oO`0507ooo`7o00000Oooool00003o`00003oogl0oomo00H0oomo102P8?040?ooO`80
X23`2@3oogl40:0Pl140oomo0P3oO`0V0?ooO`80X23`0P3oogl20:0Pl0<0oomo0P2P8?020?ooO`80
X23`203oogl00ol00000Oooo07ooo`0:07ooo`80X23`1`1oool20:0Pl1`0Oooo0P3oO`0:07ooo`80
ogl00P2P8?0807ooo`80ogl0C`1oool20?mo00D0Oooo0P3oO`0807ooo`7o00000Oooool00003o`00
003oogl0oomo00H0oomo0P2P8?0A0?ooO`80X23`?`3oogl20:0Pl180oomo00?o000007ooo`1oool0
4P1oool20:0Pl1`0Oooo0P3oO`0:07ooo`80ogl02P1oool20?mo04l0Oooo0P3oO`0507ooo`80ogl0
201oool1o`00007ooooo00000ol00000oomo0?ooO`080?ooO`80X23`I@3oogl00ol00000Oooo07oo
o`0T07ooo`80X23`7@1oool20?mo05@0Oooo0P3oO`0207ooo`80ogl02P1oool1o`00007ooooo0000
0ol00000X23`0:0Pl0080?ooO`80X23`G`3oogl20:0Pl0D0oomo00?o000007ooo`1oool01P1oool2
0?mo01/0Oooo0P2P8?0507ooo`80ogl01@1oool20?mo00l0Oooo0P3oO`1D07ooo`80ogl00P1oool2
0?mo00X0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?004@3oogl20:0Pl480oomo0P2P8?0B0?oo
O`80X23`1P3oogl2o`0000H0Oooo0P3oO`0R07ooo`80ogl01@1oool20?mo07D0Oooo0Ol00001oooo
o`0000?o00000:0Pl02P8?004@3oogl20:0Pl480oomo0P2P8?040?ooO`80X23`5P3oogl00ol00000
Oooo07ooo`0T07ooo`80X23`1P1oool20?mo07L0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
1`3oogl20:0Pl1l0oomo0P3oO`0a0?ooO`80X23`5`3oogl00ol00000Oooo07ooo`0507ooo`80X23`
1P1oool20:0Pl1@0Oooo0P2P8?0607ooo`80ogl0:01oool20:0Pl4<0Oooo0P3oO`0807ooo`7o0000
0Oooool00003o`00003oogl0X23`0080X23`1@3oogl20:0Pl0@0oomo0P2P8?040?ooO`80X23`1`3o
ogl20:0Pl0X0oomo0P3oO`0@0?ooO`80ogl0303oogl40:0Pl1l0oomo0P2P8?080?ooO`;o00001@1o
ool20:0Pl0H0Oooo0P2P8?0907ooo`80X23`2@1oool20:0Pl200Oooo0P3oO`0>07ooo`80X23`@`1o
ool20?mo00<0Oooo0P3oO`0307ooo`7o00000Oooool00003o`00003oogl0X23`0080X23`2`3oogl2
0:0Pl0@0oomo0P2P8?060?ooO`<0X23`5`3oogl20:0Pl0<0oomo0P3oO`0<0?ooO`@0X23`7`3oogl2
0:0Pl0X0oomo00Co000007ooo`2P8?00X23`501oool20:0Pl2/0Oooo0P3oO`0307ooo`80X23`D01o
ool50?mo00<0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0103oogl20:0Pl0T0oomo0P2P8?00
0`3oogl0X23`0:0Pl0070?ooO`80X23`4P3oogl20?mo00@0oomo0P2P8?0O0?ooO`80X23`803oogl0
0ol00000X23`0:0Pl00X07ooo`80ogl0501oool20?mo00H0Oooo0P2P8?0h07ooo`80ogl05P1oool4
0?mo00@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0103oogl20:0Pl0T0oomo0P2P8?000`3o
ogl0X23`0:0Pl00K0?ooO`80ogl09@3oogl20:0Pl240oomo0P2P8?0X07ooo`80ogl0501oool20?mo
0400Oooo0P3oO`0N07ooo`7o00000Oooool00003o`00003oogl0oomo01D0oomo0P2P8?080?ooO`<0
X23`9P3oogl20:0Pl0h0oomo0P2P8?0P0?ooO`03o`00002P8?00X23`00X0Oooo0P2P8?0307ooo`80
X23`2P1oool20?mo0100Oooo0P2P8?020?mo01<0Oooo0P3oO`1A07ooo`80ogl01@1oool1o`00007o
oooo00000ol00000oomo0?ooO`0E0?ooO`80X23`203oogl30:0Pl1d0oomo0P3oO`060?ooO`030?mo
002P8?00X23`00h0oomo0`2P8?030?ooO`80X23`5`3oogl60:0Pl0H0Oooo0P3oO`0207ooo`80X23`
0`1oool20:0Pl0X0Oooo0P3oO`0@07ooo`80X23`0P3oO`0C07ooo`80ogl0D@1oool20?mo00D0Oooo
0Ol00001ooooo`0000Co00000:0Pl02P8?00oomo0P2P8?0:0?ooO`80X23`303oogl20:0Pl280oomo
0P3oO`020?ooO`80X23`0P3oogl20?mo0100oomo0`2P8?020?ooO`80X23`5`3oogl40:0Pl080oomo
00?o000007ooo`1oool00`1oool20?mo01d0Oooo0P3oO`1g07ooo`7o00000Oooool00003o`00002P
8?00X23`00<0X23`103oogl20:0Pl0@0oomo0P2P8?0<0?ooO`80X23`2`3oogl20:0Pl1T0oomo0P2P
8?0E0?ooO`H0X23`00<0oomo0:0Pl02P8?000P3oO`0I0?ooO`03o`00001oool0Oooo00L0Oooo0P3o
O`0607ooo`80ogl0401oool20?mo0280Oooo0P2P8?1>07ooo`@0ogl00@1oool1o`00007ooooo0000
1?l00000X23`0:0Pl02P8?020?ooO`80X23`0P3oogl20:0Pl1@0oomo0P3oO`090?ooO`80X23`103o
ogl20:0Pl0030?ooO`2P8?00X23`00D0oomo0P2P8?0R0?ooO`@0X23`00<0oomo0:0Pl02P8?000P3o
O`0G0?ooO`80ogl000<0oomoo`00001oool00P1oool20?mo00<0Oooo0P3oO`0607ooo`80ogl07P1o
ool20:0Pl1@0Oooo0P2P8?0207ooo`80ogl0BP1oool50?mo007o00000Oooool00003o`00003oogl0
oomo00<0oomo0P2P8?0H0?ooO`80ogl00P3oogl20:0Pl0/0oomo0P2P8?000`3oogl0X23`0:0Pl005
0?ooO`80X23`8P3oogl20:0Pl1h0oomo0P3oO`020?ooO`03o`00001oool0Oooo0080ogl02`1oool2
0?mo00P0Oooo0P3oO`0507ooo`@0X23`2`1oool20:0Pl1P0Oooo0P3oO`1=07ooo`80ogl00Ol00001
ooooo`0000?o00000?ooO`3oogl03@3oogl20:0Pl180oomo0P2P8?0C0?ooO`80ogl05P3oogl20:0P
l0<0oomo0P2P8?050?ooO`@0X23`2P3oogl20:0Pl1L0oomo00?o000007ooo`1oool05P1oool20?mo
00D0Oooo102P8?0<07ooo`80ogl0A`1oool20?mo01X0Oooo1@3oO`01o`00007ooooo00000ol00000
oomo0?ooO`0=0?ooO`80X23`4P3oogl20:0Pl1<0oomo0P3oO`0F0?ooO`80X23`0`3oogl20:0Pl0D0
oomo0P2P8?0<0?ooO`80X23`603oogl01?l00000Oooo07ooo`1oool20:0Pl100Oooo0P3oO`0G07oo
o`80ogl0A`1oool20?mo01X0Oooo1@3oO`01o`00007ooooo00000ol00000oomo0?ooO`0Q0?ooO`80
X23`<03oogl20:0Pl0D0oomo0P2P8?0W0?ooO`;o000000<0Oooo0:0Pl02P8?00401oool20?mo07h0
Oooo0P3oO`0107ooo`7o00000Oooool00003o`00003oogl0oomo01H0oomo0P2P8?0=0?ooO`80X23`
<P3oogl20:0Pl1l0oomo0P2P8?080?ooO`80X23`SP1oool20?mo0080Oooo0P3oO`0107ooo`7o0000
0Oooool00004o`00003oogl0oomo0?ooO`80X23`4`3oogl20:0Pl0d0oomo0P2P8?0b0?ooO`80X23`
0P3oO`0C0?ooO`80X23`00<0oomo0:0Pl02P8?001@3oogl20:0Pl080ogl01P3oogl20:0Pl080ogl0
=@1oool20?mo00L0Oooo0P3oO`0307ooo`80X23`A`1oool20?mo0080Oooo0P3oO`0107ooo`7o0000
0Oooool00003o`00003oogl0X23`00<0X23`;P3oogl20:0Pl0030?ooO`2P8?00X23`02@0oomo0P2P
8?000`3oO`00oomo0?ooO`090?ooO`80X23`1P3oogl20:0Pl0030?ooO`2P8?00X23`00L0oomo0P3o
O`080?ooO`80ogl08`1oool20:0Pl100Oooo0P3oO`0707ooo`80ogl00P2P8?000`1oool0X23`0:0P
l01>07ooo`7o00000Oooool00004o`00003oogl0X23`0:0Pl0D0oomo0P2P8?0Y0?ooO`80X23`00<0
oomo0:0Pl02P8?00803oogl60:0Pl0T0oomo0P2P8?000`3oogl0X23`0:0Pl0070?ooO`80X23`5@3o
ogl00ol00000Oooo07ooo`0207ooo`80X23`1P1oool20:0Pl0<0Oooo0P3oO`0?07ooo`80X23`6`1o
ool20:0Pl540Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl01P3oogl20:0Pl2D0oomo0P2P8?04
0?ooO`<0X23`803oogl50:0Pl0<0oomo0P2P8?050?ooO`80X23`1P3oogl20?mo0080oomo0P2P8?0F
0?ooO`04o`00001oool0Oooo07ooo`80X23`1P1oool20:0Pl0<0Oooo0P3oO`0H07ooo`80ogl0I@1o
ool1o`00007ooooo00000ol00000oomo0?ooO`0]0?ooO`80X23`103oogl30:0Pl1H0oomo0P2P8?03
0?ooO`80X23`1P3oogl40:0Pl0030?ooO`2P8?00X23`0080oomo0P2P8?030?ooO`80X23`0`3oogl3
0?mo0140oomo0P2P8?080?ooO`03o`00001oool0Oooo00L0Oooo0P2P8?0307ooo`80X23`6@1oool2
0?mo0080Oooo0P2P8?0:07ooo`80X23`201oool20?mo04T0Oooo0P3oO`01o`00007ooooo00000ol0
0000oomo0?ooO`0U0?ooO`80X23`303oogl30:0Pl0040?ooO`2P8?00X23`0:0Pl180oomo0P2P8?03
0?ooO`80X23`203oogl20:0Pl0D0oomo0P2P8?030?ooO`80X23`0`3oogl20?mo0180oomo0P2P8?02
0?ooO`80X23`1@3oogl2o`0000L0Oooo0P2P8?0307ooo`80X23`7@1oool20:0Pl0X0Oooo0P2P8?08
07ooo`80ogl0B@1oool20?mo007o00000Oooool00004o`00003oogl0X23`0:0Pl1T0oomo0P2P8?09
0?ooO`80X23`303oogl30:0Pl0040?ooO`2P8?00X23`0:0Pl280oomo0P2P8?040?ooO`D0X23`7@3o
ogl20:0Pl0L0oomo00?o000007ooo`1oool03`1oool20:0Pl080Oooo0P2P8?0:07ooo`80X23`J01o
ool20?mo007o00000Oooool00004o`00003oogl0X23`0:0Pl1T0oomo0P2P8?100?ooO`80X23`103o
ogl50:0Pl2L0oomo00?o000007ooo`1oool03P1oool20:0Pl080Oooo0P2P8?0:07ooo`80X23`J01o
ool20?mo007o00000Oooool00003o`00003oogl0oomo01`0oomo0P2P8?0M0?ooO`80X23`103oogl2
0?mo00H0oomo0P2P8?050?ooO`80ogl0403oogl20?mo00@0oomo0P2P8?070?ooO`80X23`4P3oogl2
0?mo00P0oomo00?o000007ooo`1oool09`1oool20?mo03T0Oooo0P3oO`0T07ooo`40ogl00Ol00001
ooooo`0000?o00000?ooO`3oogl0703oogl20:0Pl1H0oomo0P3oO`050?ooO`80X23`103oogl20?mo
00H0oomo0P2P8?050?ooO`80ogl0203oogl20?mo00H0oomo0P3oO`020:0Pl080oomo0P2P8?070?oo
O`80X23`4P3oogl20?mo00T0oomo00?o000007ooo`1oool09P1oool20?mo03T0Oooo0P3oO`0T07oo
o`40ogl00Ol00001ooooo`0000?o00000?ooO`3oogl0=03oogl20?mo02@0oomo0P3oO`080?ooO`80
X23`00<0ogl00?ooO`3oogl02P3oogl20:0Pl1/0oomo0P2P8?0907ooo`80X23`1P1oool20:0Pl2X0
Oooo0P2P8?1507ooo`D0ogl00Ol00001ooooo`0000?o00000?ooO`3oogl0:`3oogl20:0Pl2D0oomo
0`2P8?0@0?ooO`80ogl00P2P8?020?ooO`80X23`1P3oogl20:0Pl1L0oomo0P2P8?020?ooO`80X23`
00?o000007ooo`1oool01P1oool20:0Pl0H0Oooo0P2P8?0Z07ooo`80X23`A@1oool40?mo0040Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl06P3oogl20:0Pl0D0oomo0P2P8?080?ooO`<0X23`1@3o
ogl20?mo00L0oomo0P2P8?030?ooO`80ogl03@3oogl50:0Pl0L0oomo0P2P8?090?ooO`<0X23`00<0
oomo0:0Pl02P8?000`3oogl20:0Pl0030?ooO`2P8?00X23`00h0oomo0P2P8?070?ooO`80X23`1@3o
ogl00ol00000Oooo07ooo`0R07ooo`@0X23`6@1oool20:0Pl4@0Oooo0Ol00001ooooo`0000?o0000
0:0Pl02P8?006P3oogl20:0Pl0D0oomo0P2P8?090?ooO`80X23`1@3oogl20?mo00030?ooO`2P8?00
X23`00@0oomo0P2P8?030?ooO`80ogl03@3oogl40:0Pl0P0oomo0P2P8?030?ooO`80X23`1@3oogl2
0:0Pl0040?ooO`2P8?00X23`0?ooO`@0X23`00<0oomo0:0Pl02P8?003P3oogl20:0Pl0l0oomo00?o
000007ooo`1oool0401oool20?mo00l0Oooo102P8?0C07ooo`80X23`101oool20:0Pl4@0Oooo0Ol0
0001ooooo`0000?o00000:0Pl02P8?00;03oogl20:0Pl0P0oomo0`2P8?0I0?ooO`80X23`3@3oogl4
0:0Pl0H0oomo0P2P8?00103oogl0X23`0:0Pl03oogl20?mo0280oomo00?o000007ooo`1oool01P1o
ool20:0Pl0030?mo001oool0Oooo00@0Oooo0P3oO`0D07ooo`80X23`401oool20:0Pl4X0Oooo0Ol0
0001ooooo`0000Co00000?ooO`2P8?00X23`=03oogl0103oO`00X23`0:0Pl02P8?0?0?ooO`80X23`
1@3oogl20?mo0100oomo102P8?060?ooO`D0X23`00@0oomo0?mo003oO`00oomo102P8?0:0?ooO`80
X23`3P3oogl40:0Pl003o`00001oool0Oooo0080ogl00`1oool30:0Pl1T0Oooo0P2P8?000`1oool0
X23`0:0Pl01J07ooo`80ogl00Ol00001ooooo`0000Co00000?ooO`2P8?00X23`=03oogl00`3oO`00
X23`0:0Pl00@0?ooO`80X23`1@3oogl20?mo01`0oomo0`2P8?040?ooO`@0X23`2P3oogl20:0Pl0h0
oomo102P8?000`3oogoo000007ooo`020?mo00@0Oooo0P2P8?0I07ooo`80X23`G@1oool20?mo007o
00000Oooool00004o`00003oogl0oomo0?ooO`80X23`@@3oogl20?mo0100oomo0P2P8?0B0?ooO`80
X23`2P3oogl20?mo00H0oomo0`2P8?0G0?ooO`03o`00001oool0Oooo00h0Oooo0P2P8?1_07ooo`40
ogl00Ol00001ooooo`0000Co00000?ooO`3oogl0oomo0P2P8?0O0?ooO`80X23`4P3oogl20:0Pl0L0
oomo0P3oO`030?ooO`80ogl0403oogl20:0Pl180oomo0P2P8?0:0?ooO`<0ogl01@3oogl30:0Pl1P0
oomo00?o000007ooo`1oool00P1oool20:0Pl0T0Oooo0P2P8?1_07ooo`40ogl00Ol00001ooooo`00
00?o00000?ooO`3oogl08P3oogl20:0Pl180oomo0P2P8?070?ooO`80ogl0103oogl20:0Pl2L0oomo
0P2P8?070?ooO`80ogl08@3oogl01?l00000Oooo07ooo`1oool20:0Pl7/0Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl0?P3oogl20?mo00D0oomo0P2P8?0E0?ooO`80X23`2P3oogl20:0Pl0@0oomo
0P2P8?000`3oogl0X23`0:0Pl00K0?ooO`<0X23`00<0ogl00?ooO`3oogl01`3oogl00ol00000Oooo
07ooo`1a07ooo`80ogl02P1oool1o`00007ooooo00000ol00000oomo0?ooO`0O0?ooO`80X23`503o
ogl20:0Pl0L0oomo102P8?0I0?ooO`030?mo002P8?00X23`00X0oomo0`2P8?030?ooO`80X23`00<0
oomo0:0Pl02P8?000`3oogl20:0Pl0H0oomo0P2P8?030?ooO`80ogl00P2P8?070?ooO`<0X23`00<0
ogl00?ooO`3oogl0203oogl2o`000740Oooo0P3oO`0:07ooo`7o00000Oooool00003o`00003oogl0
oomo01l0oomo0P2P8?0D0?ooO`80X23`1`3oogl40:0Pl0/0oomo0`2P8?020?ooO`80X23`00<0oomo
0?mo003oO`00103oogl20?mo00`0oomo0P2P8?020?ooO`<0X23`103oogl40:0Pl0H0oomo0P2P8?02
0?ooO`80X23`00<0ogl00:0Pl02P8?005P3oogl20:0Pl1`0Oooo0P3oO`1G07ooo`80ogl01@1oool1
o`00007ooooo00000ol00000oomo0?ooO`0c0?ooO`<0X23`2`3oogl60:0Pl0030?ooO`2P8?00X23`
00<0oomo0`2P8?020?ooO`80X23`00<0oomo0?mo003oO`005P3oogl30:0Pl0@0oomo0P2P8?040?oo
O`80ogl01P3oogl20:0Pl0L0oomo0P2P8?0@0?ooO`80X23`00?o00000?mo003oO`006@1oool20?mo
00X0Oooo0P2P8?0=07ooo`80ogl0?01oool20?mo00D0Oooo0Ol00001ooooo`0000?o00000?ooO`3o
ogl0103oogl20:0Pl2d0oomo0`2P8?0;0?ooO`H0X23`00<0oomo0:0Pl02P8?000P3oogl20:0Pl1H0
oomo0P2P8?080?ooO`80X23`103oogl20:0Pl0@0oomo0P3oO`080?ooO`<0X23`103oogl20:0Pl1<0
oomo0P3oO`0U07ooo`80X23`3@1oool20?mo04<0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
103oogl20:0Pl4H0oomo0P2P8?0F0?ooO`80X23`7P3oogl30:0Pl1X0oomo00?o000007ooo`1oool0
M`1oool1o`00007ooooo00000ol00000oomo0?ooO`0e0?ooO`80X23`1`3oogl40:0Pl0030?ooO`2P
8?00X23`0080X23`1P3oogl20:0Pl0H0oomo0P3oO`080?ooO`80X23`2P3oogl20?mo00D0oomo0P2P
8?0<0?ooO`80ogl03@3oogl20:0Pl140oomo00Co000007ooo`1oool0Oooo0P2P8?000`1oool0ogl0
0?mo000;07ooo`80X23`2@1oool20?mo05P0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0=@3o
ogl20:0Pl0040?ooO`2P8?00X23`0?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?000`3oO`00X23`
0:0Pl0020:0Pl0H0oomo0P2P8?060?ooO`80ogl0203oogl20:0Pl0L0oomo0P2P8?000`3oogl0ogl0
0?mo00050?ooO`80X23`1`3oogl20:0Pl0<0oomo0P3oO`0=0?ooO`80X23`2P3oogl20:0Pl0H0oomo
00?o000007ooo`1oool00P2P8?000`1oool0ogl00?mo000;07ooo`80X23`2@1oool20?mo05P0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0;@3oogl20:0Pl0T0oomo0P2P8?000`3oogl0X23`0:0P
l0040?ooO`80ogl000<0oomo0:0Pl02P8?004@3oogl20:0Pl0<0oomo0P2P8?000`3oogl0X23`0:0P
l0020:0Pl0D0oomo0P2P8?080?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?001@3oogl0X23`0:0P
l02P8?00oomo0080X23`203oogl20:0Pl140oomo0P2P8?070?ooO`03o`00001oool0Oooo07@0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0;@3oogl20:0Pl1L0oomo0P2P8?050?ooO`80X23`00<0
oomo0:0Pl02P8?001@3oogl20:0Pl0030?ooO`3oO`00ogl00080X23`00<0oomo0:0Pl02P8?000P2P
8?000`3oogl0X23`0:0Pl00<0?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?000`3oogl0X23`0:0P
l0020?ooO`80X23`203oogl20:0Pl1/0oomo0_l0001d07ooo`7o00000Oooool00003o`00003oogl0
oomo03l0oomo0P2P8?050?ooO`80X23`1@3oogl20:0Pl0040?ooO`2P8?00X23`0?ooO`80ogl01@3o
ogl20?mo00@0oomo0P2P8?020?ooO`80X23`0P3oogl20:0Pl0L0oomo0`2P8?020?ooO`80ogl00P3o
ogl20:0Pl2X0oomo0P3oO`0S07ooo`80ogl0CP1oool1o`00007ooooo00000ol00000oomo0?ooO`0o
0?ooO`80X23`0`3oogl30:0Pl0`0oomo0P3oO`020?ooO`<0ogl01@3oogl40:0Pl0D0oomo0P2P8?00
103oogl0X23`0:0Pl03oO`030?ooO`80X23`0P3oogl20:0Pl0<0oomo0P2P8?0C0?ooO`80ogl05@3o
ogl20?mo0003o`00001oool0Oooo0200Oooo0P3oO`1>07ooo`7o00000Oooool00003o`00003oogl0
oomo03h0oomo0P2P8?040?ooO`<0X23`00<0oomo0:0Pl02P8?002@3oogl20?mo0080oomo0`3oO`05
0?ooO`H0X23`0`3oogl50:0Pl0030?mo003oogl0oomo00D0oomo0`2P8?020?ooO`80X23`4`3oogl2
0?mo01P0oomo00?o000007ooo`1oool06`1oool20?mo0580Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl0?P3oogl20:0Pl0@0oomo0P2P8?020?ooO`<0X23`103oogl60?mo00T0oomo102P8?00103o
ogl0X23`0:0Pl03oO`020?ooO`<0X23`1@3oogl20:0Pl0030?ooO`2P8?00X23`00@0X23`00<0oomo
0:0Pl02P8?000P3oogl20?mo00H0oomo0P2P8?0C0?ooO`80X23`1@3oogl20:0Pl080oomo0P2P8?02
0?ooO`03o`00001oool0Oooo01X0Oooo0P3oO`1B07ooo`7o00000Oooool00003o`00003oogl0oomo
04@0oomo0P2P8?030?ooO`80X23`103oogl40?mo00/0oomo0P2P8?020?mo00040?ooO`2P8?00X23`
0?mo00X0oomo0P2P8?000`3oogl0X23`0:0Pl0040:0Pl0D0oomo0P3oO`060?ooO`80X23`4`3oogl2
0:0Pl0D0oomo0P2P8?020?ooO`80X23`0`3oogl00ol00000Oooo07ooo`1]07ooo`7o00000Oooool0
0003o`00003oogl0oomo04<0oomo1@2P8?0F0?ooO`80ogl0103oogl20?mo00030?ooO`2P8?00X23`
00L0oomo0P2P8?020?ooO`030?mo002P8?00X23`00D0oomo0P2P8?070?ooO`80X23`9@3oogl00ol0
0000Oooo07ooo`1/07ooo`7o00000Oooool00003o`00003oogl0oomo02`0oomo0P2P8?0E0?ooO`P0
X23`4`3oogl20?mo0080oomo102P8?00103oogl0X23`0:0Pl03oogl40:0Pl080oomo0`2P8?000`3o
ogl0ogl00:0Pl0050:0Pl0040?ooO`2P8?00X23`0?ooO`80ogl0103oogl40:0Pl2@0oomo00?o0000
07ooo`1oool0<P1oool20?mo03H0Oooo0@3oO`01o`00007ooooo00000ol00000oomo0?ooO`0/0?oo
O`80X23`5P3oogl20:0Pl080oomo0`2P8?030?ooO`80X23`2P3oogl20?mo0080oomo0P3oO`020?oo
O`@0X23`00<0oomo0?mo002P8?001@2P8?020?ooO`H0X23`00<0oomo0:0Pl02P8?000P2P8?040?oo
O`80ogl01P3oogl20:0Pl1L0oomo0P2P8?0<0?ooO`03o`00001oool0Oooo0080Oooo0P2P8?0707oo
o`80X23`901oool20?mo03H0Oooo0@3oO`01o`00007ooooo00000ol00000oomo0?ooO`140?ooO`80
X23`0`3oogl20:0Pl0030?ooO`2P8?00X23`0080X23`2@3oogl00`3oO`00X23`0:0Pl0020?ooO`04
0?mo002P8?00X23`0?ooO`80X23`103oogl20:0Pl0H0oomo0P2P8?000`3oogl0X23`0:0Pl0060:0P
l0/0oomo0P2P8?0H0?ooO`80X23`103oogl20?mo00L0oomo00Co000007ooo`1oool0Oooo0P2P8?07
07ooo`80X23`1`1oool20?mo05@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0C03oogl40:0P
l0T0oomo0`2P8?030?ooO`80X23`00@0oomo0:0Pl02P8?00oomo0P2P8?020?ooO`H0X23`00@0oomo
0:0Pl02P8?00oomo1P2P8?070?ooO`80X23`0P3oogl60:0Pl1`0oomo0P3oO`080?ooO`03o`00001o
ool0Oooo0180Oooo0P3oO`1D07ooo`7o00000Oooool00003o`00003oogl0oomo04`0oomo102P8?09
0?ooO`80X23`1@3oogl20?mo00030?ooO`3oO`00ogl00080X23`0P3oO`060:0Pl0@0oomo0P2P8?00
0`3oogl0X23`0:0Pl0050?ooO`D0X23`0P3oogl60:0Pl1D0oomo0`2P8?0?0?ooO`03o`00001oool0
Oooo00L0Oooo0P3oO`1N07ooo`7o00000Oooool00003o`00003oogl0oomo04X0oomo2P2P8?060?oo
O`80X23`103oogl20?mo00030?ooO`3oO`00ogl000@0ogl00`3oogl20:0Pl0<0oomo0P2P8?020?mo
00@0X23`00<0oomo0:0Pl02P8?00102P8?020?ooO`<0X23`6P3oogl30:0Pl100oomo00?o000007oo
o`1oool01P1oool20?mo03P0Oooo0P3oO`0T07ooo`7o00000Oooool00003o`00003oogl0oomo04X0
oomo2P2P8?000`3oogl0X23`0:0Pl0030?ooO`80X23`00@0ogl00?ooO`3oogl0oomo0P2P8?020?oo
O`D0ogl00`3oogl20:0Pl0<0oomo202P8?000`3oogl0X23`0:0Pl0040:0Pl080oomo0`2P8?0:0?oo
O`<0X23`303oogl20:0Pl080ogl04@3oogl00ol00000Oooo07ooo`0N07ooo`80ogl07`1oool20?mo
02@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0CP3oogl30:0Pl0@0oomo0P2P8?040?ooO`80
ogl00`3oogl20:0Pl080oomo0P3oO`0=0?ooO`80X23`2@3oogl20:0Pl0<0oomo0P2P8?0:0?ooO`<0
X23`303oogl20:0Pl1@0oomo00?o000007ooo`1oool07@1oool20?mo04D0Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl0;`3oogl20:0Pl1`0oomo1P2P8?060?ooO`80X23`0`3oogl20?mo00@0oomo
0P2P8?050?ooO`80ogl02P3oogl20:0Pl0030?ooO`2P8?00X23`0080oomo102P8?020?mo0080X23`
2@3oogl20:0Pl2@0oomo00?o000007ooo`1oool0H`1oool1o`00007ooooo00000ol00000oomo0?oo
O`0<0?ooO`80X23`8@3oogl20:0Pl1`0oomo1P2P8?040?ooO`@0X23`0`3oogl30?mo00030?ooO`2P
8?00X23`0080X23`1@3oogl00`3oO`00X23`0:0Pl0020:0Pl0030?ooO`3oO`00ogl000@0oomo1@2P
8?020?ooO`@0X23`0P3oO`020:0Pl0T0oomo102P8?0M0?ooO`80ogl0103oogl00ol00000Oooo07oo
o`1R07ooo`7o00000Oooool00003o`00003oogl0oomo00`0oomo0P2P8?110?ooO`80X23`00@0oomo
0:0Pl02P8?00oomo1@2P8?050?ooO`030?mo002P8?00X23`00@0X23`1P3oogl40:0Pl0030?ooO`2P
8?00X23`00@0oomo102P8?020?ooO`80ogl00P2P8?020?ooO`80X23`00<0ogl00?ooO`3oogl01`3o
ogl40:0Pl0030?ooO`2P8?00X23`00T0oomo0P3oO`000`3oogl0X23`0:0Pl0040?ooO`80X23`1P3o
ogl20?mo00<0oomo0P3oO`000ol00000Oooo07ooo`1Q07ooo`7o00000Oooool00003o`00003oogl0
oomo0500oomo102P8?000`3oogl0X23`0:0Pl0020:0Pl0030?ooO`2P8?00X23`00@0oomo0P2P8?00
0`3oogl0X23`0:0Pl0020?mo00@0oomo0`3oO`030?ooO`80X23`1`3oogl20:0Pl0030?ooO`3oO`00
ogl00080X23`00<0ogl00?ooO`2P8?000P2P8?060?ooO`80ogl000<0oomo0:0Pl02P8?000`3oogl2
0:0Pl0D0oomo0P3oO`020?ooO`80ogl000<0oomo0:0Pl02P8?000P2P8?020?ooO`80X23`2@3oogl2
0:0Pl080ogl000<0oomoo`00001oool0H@1oool1o`00007ooooo00000ol00000oomo0?ooO`1@0?oo
O`80X23`00<0oomo0:0Pl02P8?00102P8?00103oogl0X23`0:0Pl02P8?060?ooO`<0X23`00<0ogl0
0?ooO`3oogl01P3oO`050?ooO`<0ogl00`3oogl30:0Pl0030?ooO`3oO`00ogl00080ogl00P3oogl2
0:0Pl080oomo0P2P8?020?ooO`80X23`00<0oomo0:0Pl02P8?001`3oogl20:0Pl0040?ooO`2P8?00
X23`0?ooO`80X23`0P3oogl20?mo0080X23`3@3oogl20:0Pl0@0oomo00Co000007ooo`3oO`00ogl0
GP1oool1o`00007ooooo00000ol00000oomo0?ooO`0V0?ooO`80X23`703oogl20:0Pl0P0oomo0P2P
8?030?ooO`X0X23`103oogl20:0Pl0040?mo002P8?00X23`0?ooO`80X23`0P3oO`020?ooO`<0ogl0
103oogl30?mo0080X23`0P3oogl20:0Pl0D0oomo0P2P8?040?ooO`80X23`00D0oomo0:0Pl02P8?00
X23`0?ooO`020:0Pl0030?mo003oogl0oomo00@0oomo0P2P8?00103oogl0X23`0:0Pl03oogl20:0P
l0H0ogl03`3oogl20?mo00<0oomo00?o00000?mo003oO`00GP1oool1o`00007ooooo00000ol00000
oomo0?ooO`0V0?ooO`80X23`703oogl20:0Pl0P0oomo0P2P8?050?ooO`H0X23`1P3oogl50:0Pl003
0?ooO`2P8?00X23`00D0oomo0P3oO`030?ooO`80X23`0P3oogl20:0Pl0030?ooO`3oO`00ogl000H0
oomo102P8?050?ooO`<0X23`00@0ogl00?ooO`3oO`00ogl00P3oogl30:0Pl0T0oomo0P3oO`020?oo
O`80ogl03`3oogl20?mo0080oomo0P3oO`000ol00000Oooo07ooo`1M07ooo`7o00000Oooool00003
o`00003oogl0oomo05D0oomo1@2P8?070?ooO`D0X23`2P3oogl20?mo00<0X23`0P3oogl20:0Pl004
0?ooO`3oO`00X23`0:0Pl080ogl000D0oomo0:0Pl02P8?00oomo0?mo00060:0Pl080oomo0P2P8?00
0`3oO`00X23`0:0Pl0030?ooO`<0X23`8P3oogl20?mo00030?ooOol00000Oooo05d0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl0E@3oogl20:0Pl0030?ooO`2P8?00X23`00L0oomo0P2P8?000`3o
O`00oomo0?ooO`0:0?ooO`80ogl00P2P8?030?ooO`80X23`00@0oomo0?mo002P8?00X23`0P3oO`00
103oogl0X23`0:0Pl03oogl20?mo00030?ooO`2P8?00X23`0080X23`1@3oogl20:0Pl0@0oomo0P2P
8?0V0?ooO`03o`00001oool0Oooo05/0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?00FP3oogl3
0:0Pl080oomo0P2P8?030?ooO`80X23`103oogl20:0Pl0030?ooO`3oO`00ogl000/0oomo0P3oO`02
0?ooO`030?mo002P8?00X23`00<0oomo102P8?050?ooO`<0X23`00<0ogl00?ooO`3oogl0:`3oogl0
0ol00000Oooo07ooo`1J07ooo`7o00000Oooool00003o`00002P8?00X23`05X0oomo0`2P8?020?oo
O`L0X23`103oogl30:0Pl080ogl00P3oogl20:0Pl0L0oomo00D0ogl00:0Pl02P8?00oomo0?mo0002
0:0Pl0030?ooO`3oO`00ogl000@0X23`0P3oO`030?ooO`L0X23`00<0oomo0:0Pl02P8?000`2P8?0U
0?ooO`03o`00001oool0Oooo05T0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl00P2P8?1I0?oo
O`80X23`0P3oogl50:0Pl0030?ooO`2P8?00X23`00@0oomo0P2P8?040?ooO`80X23`1P3oogl50:0P
l0040?mo002P8?00X23`0?ooO`P0ogl01P3oogl40:0Pl0030?ooO`2P8?00X23`00D0X23`00<0oomo
0?mo003oO`00803oogl00ol00000Oooo07ooo`0?07ooo`80ogl0B01oool1o`00007ooooo00000ol0
0000oomo0?ooO`020:0Pl4h0oomo0P2P8?090?ooO`80X23`0P3oogl20:0Pl0@0oomo0P2P8?000`3o
ogl0X23`0:0Pl00;0?ooO`80X23`0P3oogl20:0Pl0040?mo002P8?00X23`0:0Pl080ogl000<0oomo
0?mo003oO`00103oO`020:0Pl0<0oomo0P2P8?020?ooO`80X23`0P3oogl20:0Pl0<0oomo0P2P8?00
0`3oogl0ogl00?mo000Q0?ooO`03o`00001oool0Oooo00h0Oooo0P2P8?1807ooo`7o00000Oooool0
0003o`00003oogl0oomo0500oomo0P2P8?070?ooO`@0X23`1P3oogl20?mo00<0oomo0P2P8?0:0?oo
O`<0X23`0P3oogl20?mo00@0X23`00<0ogl00?ooO`3oogl00`2P8?000`3oogl0ogl00?mo00020:0P
l0<0oomo0P2P8?060?ooO`@0X23`00<0oomo0:0Pl02P8?001`3oogl20?mo01`0oomo00?o000007oo
o`1oool03@1oool20:0Pl2l0Oooo0P3oO`0G07ooo`7o00000Oooool00003o`00003oogl0oomo05T0
oomo102P8?030?ooO`<0X23`0P3oO`020:0Pl0<0oomo0P2P8?001@3oogl0ogl00:0Pl02P8?00oomo
0080ogl00`2P8?000`3oogl0X23`0:0Pl0020?mo0080X23`00<0ogl00?ooO`3oogl00P3oogl60:0P
l0030?mo002P8?00X23`0080oomo0P3oO`050:0Pl0<0oomo0P2P8?0:0?ooO`80ogl07@3oogl00ol0
0000Oooo07ooo`0m07ooo`80ogl05`1oool1o`00007ooooo00000ol00000oomo0?ooO`1J0?ooO`80
X23`103oogl30:0Pl0040?mo002P8?00X23`0:0Pl080oomo00<0ogl00:0Pl02P8?00102P8?000`3o
ogl0ogl00?mo00060:0Pl0050?ooO`3oO`00X23`0:0Pl03oO`000P3oogl20:0Pl0030?mo002P8?00
X23`00<0X23`00@0ogl00:0Pl02P8?00oomo0`3oO`050:0Pl2l0oomo00?o000007ooo`1oool0E@1o
ool1o`00007ooooo00000ol00000oomo0?ooO`1J0?ooO`80X23`203oogl20:0Pl080oomo0P2P8?00
0`3oO`00X23`0:0Pl0020:0Pl080oomo0`2P8?000`3oogl0X23`0:0Pl0020?mo00040?ooO`3oO`00
ogl00?ooO`80X23`00<0ogl00:0Pl02P8?000P3oO`000`3oogl0ogl00?mo00030?mo0080oomo00@0
ogl00:0Pl02P8?00ogl00P2P8?070?ooO`80X23`6@3oogl20?mo00h0oomo00?o000007ooo`1oool0
201oool20:0Pl4X0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0J03oogl20:0Pl0L0oomo0`2P
8?000`3oogl0X23`0:0Pl0020?mo00@0oomo0P2P8?000`3oO`00oomo0?ooO`040?ooO`@0ogl00P3o
ogl00`3oO`00X23`0:0Pl0020?mo00P0oomo0P2P8?0I0?ooO`80ogl03`3oogl00ol00000Oooo07oo
o`0707ooo`80X23`BP1oool1o`00007ooooo00000ol00000oomo0?ooO`1R0?ooO`<0X23`203oogl2
0:0Pl0030?ooO`2P8?00X23`00/0oomo0`2P8?040?ooO`80X23`1@3oO`001@3oogl0X23`0:0Pl02P
8?00oomo00<0X23`1@3oogl20:0Pl2@0oomo0P2P8?060?ooO`03o`00001oool0Oooo0580Oooo0Ol0
0001ooooo`0000?o00000?ooO`3oogl0HP3oogl30:0Pl0<0oomo0P3oO`030?ooO`80X23`00<0oomo
0:0Pl02P8?000`3oogl30:0Pl080oomo0P3oO`00103oogl0X23`0:0Pl02P8?020?ooO`@0X23`1@3o
O`000`3oogl0X23`0:0Pl0050:0Pl0@0oomo00@0ogl00:0Pl02P8?00oomo0P3oO`030?ooO`80X23`
4P3oogl30?mo00L0oomo0P2P8?070?ooO`03o`00001oool0Oooo0280Oooo0P3oO`0]07ooo`7o0000
0Oooool00003o`00002P8?00X23`05l0oomo0P2P8?070?ooO`030?mo002P8?00X23`0080oomo0P2P
8?000`3oogl0X23`0:0Pl0030?ooO`<0X23`0P3oogl20?mo0080oomo0P2P8?00103oO`00oomo0:0P
l02P8?030?mo00030?ooO`2P8?00X23`00@0oomo00<0ogl00:0Pl02P8?000`3oogl20?mo00050?oo
O`3oO`00X23`0:0Pl03oogl00P3oO`030?ooO`80X23`2P3oogl20?mo00H0oomo0`3oO`0A0?ooO`03
o`00001oool0Oooo00<0Oooo0P2P8?0L07ooo`80ogl0;@1oool1o`00007ooooo00000ol00000X23`
0:0Pl01O0?ooO`80X23`1P3oogl40:0Pl0<0oomo0P2P8?001@3oogl0X23`0:0Pl02P8?00oomo0080
X23`203oogl60:0Pl0030?mo002P8?00X23`0080X23`0P3oogl50?mo00<0oomo0`3oO`0E0?ooO`80
ogl06P3oogl00ol00000Oooo07ooo`0307ooo`80X23`B`1oool1o`00007ooooo00000ol00000oomo
0?ooO`030?ooO`80X23`F@3oogl20:0Pl0030?ooO`2P8?00X23`00@0oomo102P8?020?ooO`040?mo
002P8?00X23`0?ooO`<0X23`0P3oogl20:0Pl0030?mo002P8?00X23`00<0X23`00<0oomo0:0Pl02P
8?00102P8?000`3oO`00X23`0:0Pl0030?ooO`80X23`00@0ogl00?ooO`3oogl0oomo0`3oO`000`3o
ogl0ogl00?mo00020?ooO`80X23`603oogl20?mo00<0oomo0P3oO`0?0?ooO`03o`00001oool0Oooo
04l0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl00`3oogl20:0Pl5T0oomo0P2P8?000`3oogl0
X23`0:0Pl0050?ooO`<0X23`0P3oogl20:0Pl080oomo0`3oO`020?ooO`80X23`00<0ogl00:0Pl02P
8?000`2P8?020?ooO`@0X23`103oogl20:0Pl0030?ooO`2P8?00X23`00@0oomo0`3oO`020?ooO`80
X23`00<0oomo0:0Pl02P8?000P3oogl40:0Pl140oomo0`3oO`030?ooO`80ogl0403oogl00ol00000
Oooo07ooo`0607ooo`80ogl0AP1oool1o`00007ooooo00000ol00000oomo0?ooO`1]0?ooO`80X23`
0P3oogl20?mo00<0oomo0P2P8?000`3oogl0ogl00?mo00030:0Pl080oomo0P2P8?060?ooO`80X23`
00<0oomo0:0Pl02P8?000P3oogl20?mo00D0oomo1@2P8?020?ooO`@0X23`203oogl20:0Pl080oomo
0P3oO`030?ooO`80ogl05`3oogl01?l00000Oooo07ooo`1oool20?mo0080Oooo0P3oO`1607ooo`7o
00000Oooool00003o`00003oogl0oomo02<0oomo0P3oO`1A0?ooO`80X23`00<0oomo0:0Pl02P8?00
0`2P8?020?ooO`80X23`0`3oogl20?mo00030?ooO`2P8?00X23`00D0oomo103oO`020?ooO`030?mo
002P8?00X23`00<0X23`103oogl00`3oO`00X23`0:0Pl0020:0Pl0D0oomo0P2P8?020?ooO`80ogl0
7@3oogl00ol00000X23`0:0Pl0020?mo0180Oooo0P3oO`0:07ooo`80ogl0:P1oool1o`00007ooooo
00000ol00000oomo0?ooO`0S0?ooO`80ogl0E03oogl20:0Pl0030?ooO`2P8?00X23`0080oomo0P2P
8?030?ooO`80ogl000<0oomo0:0Pl02P8?001`3oogl20?mo0080oomo0P3oO`020:0Pl0L0oomo102P
8?0Y0?ooO`80X23`501oool20?mo00X0Oooo0P3oO`0Z07ooo`7o00000Oooool00003o`00003oogl0
oomo02<0oomo0`3oO`110?ooO`80X23`1`3oogl20:0Pl0D0oomo0P3oO`0:0?ooO`80X23`0P3oogl2
0:0Pl0030?mo003oogl0oomo00<0X23`4P3oogl40:0Pl2T0oomo00?o000007ooo`1oool01`1oool2
0?mo0440Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl01P3oogl20:0Pl1/0oomo1@3oO`000`3o
ogl0ogl00?mo000l0?ooO`80X23`00<0oomo0:0Pl02P8?00103oogl20:0Pl0D0oomo0P3oO`000`3o
ogl0ogl00?mo00030?ooO`80ogl000@0oomo0:0Pl02P8?00X23`0P3oogl20:0Pl0030?mo003oogl0
oomo00<0X23`1@3oogl00`3oO`00X23`0:0Pl0040:0Pl080ogl00`3oogl50:0Pl0X0oomo0P3oO`0>
0?ooO`80X23`303oogl20:0Pl003o`00001oool0Oooo00H0Oooo0P3oO`1107ooo`7o00000Oooool0
0003o`00003oogl0oomo00H0oomo0P2P8?0M0?ooO`H0ogl0?`3oogl20:0Pl0h0oomo00<0ogl00:0P
l02P8?00103oO`000`3oogl0X23`0:0Pl0020?ooO`80X23`0P3oO`030?ooO`80ogl01@3oogl00`3o
O`00X23`0:0Pl0040:0Pl080ogl01`2P8?0;0?ooO`80ogl03P3oogl20:0Pl080oomo0P3oO`080?oo
O`80X23`00@0ogl0o`00003oO`00ogl0B01oool1o`00007ooooo00000ol00000oomo0?ooO`0T0?oo
O`<0ogl000@0oomo0?mo003oO`00ogl0A@3oogl20:0Pl0T0oomo0P2P8?020?mo00L0oomo0P2P8?02
0?mo00<0oomo0P3oO`050?ooO`80X23`0P3oogl30:0Pl080ogl0102P8?020?ooO`80X23`7P3oogl2
0?mo00T0oomo0P3oO`000`3oogl0ogl00?mo001807ooo`7o00000Oooool00003o`00003oogl0oomo
02<0oomo103oO`00103oogl0ogl00?mo003oO`110?ooO`80X23`0P3oogl30:0Pl0@0oomo0P2P8?04
0?ooO`80X23`0P3oO`030?ooO`80ogl01P3oogl30:0Pl0D0oomo0P2P8?020?ooO`<0X23`0P3oogl5
0:0Pl0030?ooO`2P8?00X23`02H0oomo0P3oO`050?ooO`03o`00001oool0Oooo04H0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl08`3oogl70?mo0340oomo0P2P8?0?0?ooO`80X23`0`3oogl20:0P
l0@0oomo0P2P8?030?ooO`<0X23`0`3oO`020?ooO`80ogl01P3oogl30:0Pl0<0oomo0P2P8?0;0?oo
O`D0X23`0`3oogl20:0Pl0030?ooO`2P8?00X23`01H0oomo0P3oO`070?ooO`80ogl01P3oogl00ol0
0000Oooo07ooo`1507ooo`7o00000Oooool00003o`00003oogl0oomo02D0oomo0`3oO`0c0?ooO`80
X23`4@3oogl20:0Pl0`0oomo0P2P8?020?ooO`80ogl01P3oogl20:0Pl0H0oomo0P3oO`020:0Pl0<0
oomo0P3oO`070?ooO`@0X23`0`3oogl50:0Pl0030?ooO`2P8?00X23`0180oomo0`3oO`0@0?ooO`03
o`00001oool0Oooo04@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0KP3oogl20:0Pl0@0oomo
0P2P8?090?ooO`030?mo002P8?00X23`0080X23`00@0oomo0:0Pl02P8?00ogl00P2P8?060?ooO`80
ogl0102P8?000`3oogl0ogl00?mo00040?ooO`80X23`0`3oogl20?mo00@0oomo0`2P8?020?mo0080
X23`4P3oogl20?mo00D0oomo0P3oO`0;0?ooO`03o`00001oool0Oooo04<0Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl0M03oogl20:0Pl0T0oomo00<0ogl00:0Pl02P8?000P2P8?000`3oogl0X23`
0:0Pl0020?mo00T0oomo102P8?070?ooO`80X23`2@3oogl20:0Pl0030?ooO`3oO`00ogl001/0oomo
0P3oO`0<0?ooO`03o`00001oool0Oooo0480Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0M`3o
ogl20:0Pl0@0oomo0P3oO`020:0Pl0@0oomo0P2P8?00103oogl0X23`0:0Pl02P8?030?ooO`80X23`
0P3oO`020?ooO`D0X23`0P3oogl20?mo0080X23`203oogl20:0Pl0030?ooO`3oO`00ogl00080X23`
7`3oogl20:0Pl0P0oomo00?o000007ooo`1oool0@@1oool1o`00007ooooo00000ol00000oomo0?oo
O`1L0?ooO`80X23`6@3oogl20:0Pl0@0oomo0P3oO`020:0Pl0040?ooO`3oO`00ogl00?ooO`80X23`
00D0oomo0:0Pl02P8?00X23`0?ooO`040:0Pl080ogl01`2P8?020?ooO`80ogl00P2P8?080?ooO`80
X23`00<0oomo0?mo003oO`001`2P8?0J0?ooO`80X23`2@3oogl00ol00000Oooo07ooo`1007ooo`7o
00000Oooool00003o`00003oogl0oomo00D0oomo0P2P8?1E0?ooO`80X23`3@3oogl20:0Pl1D0oomo
0P3oO`080?ooO`X0X23`5`3oogl60:0Pl0l0oomo0P3oO`0E0?ooO`03o`00001oool0Oooo03l0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0103oogl30:0Pl6@0oomo0P2P8?0C0?ooO`80X23`303o
ogl40:0Pl080oomo202P8?000`3oogl0X23`0:0Pl0020?ooO`80ogl01@3oogl70:0Pl0040?ooO`3o
O`00X23`0:0Pl0l0oomo0P3oO`0?0?ooO`80ogl01@3oogl00ol00000Oooo07ooo`0n07ooo`7o0000
0Oooool00003o`00003oogl0oomo00@0oomo0P2P8?0I0?ooO`80ogl0F@3oogl20:0Pl0@0oomo0P2P
8?00103oogl0ogl00?mo003oogl20?mo00T0oomo0P2P8?020?ooO`L0X23`00<0oomo0:0Pl02P8?00
0P3oogl20?mo0080X23`0P3oogl80:0Pl080oomo0P2P8?020?mo00<0oomo0P3oO`0I0?ooO`80ogl0
1@3oogl00ol00000Oooo07ooo`0n07ooo`7o00000Oooool00003o`00003oogl0oomo00T0oomo0P2P
8?0D0?ooO`80ogl0F@3oogl40:0Pl080oomo0P2P8?00103oogl0ogl00?mo003oogl20?mo00H0oomo
0P2P8?00103oogl0X23`0:0Pl02P8?020?ooO`80X23`00<0ogl00:0Pl02P8?000P2P8?040?ooO`@0
X23`00@0oomo0:0Pl02P8?00X23`0`3oogl20:0Pl0<0oomo1@2P8?020?ooO`80ogl0103oogl20:0P
l1D0oomo0P3oO`040?ooO`03o`00001oool0Oooo03d0Oooo0Ol00001ooooo`0000?o00000?ooO`3o
ogl02@3oogl20:0Pl1H0oomo0P3oO`120?ooO`80X23`3@3oogl20:0Pl0H0oomo0P2P8?0:0?ooO`<0
X23`0`3oogl20:0Pl0040?ooO`2P8?00X23`0:0Pl080oomo102P8?000`3oogl0X23`0:0Pl0020?oo
O`80ogl00P2P8?000`3oogl0X23`0:0Pl0020:0Pl0@0oomo0P2P8?00103oO`00oomo0?ooO`3oogl4
0:0Pl0040?mo003oogl0X23`0:0Pl0@0oomo0P2P8?000`3oogl0X23`0:0Pl00B0?ooO`80ogl01@3o
ogl00ol00000Oooo07ooo`0l07ooo`7o00000Oooool00003o`00003oogl0oomo0240oomo0P3oO`0K
0?ooO`80X23`9@3oogl20:0Pl0d0oomo0P2P8?0@0?ooO`D0X23`0`3oO`000`3oogl0X23`0:0Pl002
0:0Pl0<0oomo3@2P8?000`3oogl0X23`0:0Pl0040?ooO`@0X23`00<0ogl00?ooO`3oogl00P2P8?00
1@3oogl0X23`0:0Pl03oO`00oomo0080X23`0P3oogl40:0Pl0030?ooO`2P8?00X23`00D0oomo0P3o
O`0C0?ooO`03o`00001oool0Oooo03/0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0?P3oogl2
0:0Pl4H0oomo0P2P8?000`3oogl0X23`0:0Pl0030?mo00040?ooO`2P8?00X23`0:0Pl0@0oomo0P2P
8?000`3oogl0X23`0:0Pl0060:0Pl0<0oomo0P2P8?040?ooO`80X23`1@3oogl20:0Pl0030?ooO`2P
8?00X23`00H0oomo102P8?080?ooO`80ogl04`3oogl00ol00000Oooo07ooo`0k07ooo`7o00000Ooo
ool00003o`00003oogl0oomo08D0oomo1@2P8?00103oO`00oomo0:0Pl02P8?060?ooO`80ogl0103o
ogl30:0Pl0040?mo002P8?00X23`0?ooO`80X23`2@3oogl20:0Pl1D0oomo0`2P8?0H0?ooO`03o`00
001oool0Oooo03X0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl01@3oogl20:0Pl7h0oomo1@2P
8?000`3oO`00oomo0:0Pl0020:0Pl0D0oomo0P3oO`030?ooO`@0X23`00@0ogl00:0Pl02P8?00oomo
102P8?00103oogl0X23`0:0Pl03oogl50:0Pl0030?ooO`2P8?00X23`00T0oomo0P2P8?070?ooO`<0
X23`00<0oomo0:0Pl02P8?005P3oogl00ol00000Oooo07ooo`0i07ooo`7o00000Oooool00003o`00
003oogl0oomo00D0oomo0P2P8?1m0?ooO`@0X23`103oogl30:0Pl0030?ooO`2P8?00X23`0080ogl0
00<0oomo0?mo003oO`000P3oogl20:0Pl0L0oomo1P2P8?00103oogl0X23`0:0Pl02P8?030?ooO`80
X23`203oogl50:0Pl0P0oomo0`2P8?0F0?ooO`03o`00001oool0Oooo03T0Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl0MP3oogl20:0Pl0`0oomo102P8?030?ooO`@0X23`00<0oomo0:0Pl02P8?00
0P3oO`000`3oogl0ogl00:0Pl0020:0Pl0D0oomo0P3oO`030?ooO`<0X23`0`3oogl20:0Pl0H0oomo
1P2P8?020?ooO`80X23`00<0oomo0:0Pl02P8?00203oogl20:0Pl1P0oomo00?o000007ooo`1oool0
2`1oool20:0Pl2/0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0MP3oogl20:0Pl0X0oomo0P2P
8?070?ooO`@0X23`0`3oO`040?ooO`<0X23`1@3oogl20?mo0080X23`00D0oomo0:0Pl02P8?00X23`
0?ooO`040:0Pl0030?ooO`2P8?00X23`00<0oomo1P2P8?040?ooO`80X23`8@3oogl20?mo00030?oo
Ool00000Oooo00/0Oooo0P2P8?0[07ooo`7o00000Oooool00003o`00003oogl0oomo07/0oomo0P2P
8?050?ooO`80X23`0P3oogl20:0Pl0<0oomo102P8?020?mo00@0oomo0P3oO`090?ooO`D0X23`00<0
oomo0:0Pl02P8?001`2P8?000`3oogl0X23`0:0Pl0020?ooO`<0X23`103oogl40:0Pl0h0oomo0P2P
8?040?ooO`80X23`2@3oogl20?mo0080oomo00?o000007ooo`1oool0=P1oool1o`00007ooooo0000
0ol00000oomo0?ooO`0m0?ooO`80ogl0?03oogl20:0Pl0T0oomo0P2P8?030?ooO`80X23`00<0oomo
0?mo003oO`000P3oO`020:0Pl0040?ooO`2P8?00X23`0?mo00<0oomo0P2P8?020?ooO`80X23`00<0
oomo0:0Pl02P8?00102P8?020?ooO`h0X23`0`3oogl40:0Pl0<0oomo0P2P8?020?ooO`80X23`0P3o
ogl20:0Pl0030?ooO`2P8?00X23`00@0oomo0P2P8?0=0?ooO`03o`00001oool0Oooo03H0Oooo0Ol0
0001ooooo`0000?o00000?ooO`3oogl0?@3oogl20?mo02@0oomo0P2P8?0V0?ooO`80X23`0P3oogl8
0:0Pl0040?mo003oogl0oomo0?ooO`80X23`0P3oogl20:0Pl0<0ogl00P2P8?030?ooO`80X23`00<0
oomo0:0Pl02P8?002P2P8?020?ooO`@0X23`00@0oomo0:0Pl02P8?00oomo0P2P8?00103oogl0X23`
0:0Pl02P8?020?ooO`80X23`5`3oogl00ol00000Oooo07ooo`0e07ooo`7o00000Oooool00003o`00
003oogl0oomo06<0oomo0P2P8?0Z0?ooO`L0X23`2`3oogl30?mo00D0oomo0P2P8?0:0?ooO`<0X23`
0P3oogl40:0Pl0030?ooO`2P8?00X23`00@0oomo0P2P8?0M0?ooO`03o`00001oool0Oooo03@0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl02@3oogl20:0Pl7/0oomo0`2P8?090?ooO`80X23`2`3o
ogl0103oO`00X23`0:0Pl03oogl20?mo0080oomo0P2P8?020?ooO`80ogl01P3oogl20:0Pl0030?oo
O`2P8?00X23`0080oomo103oO`030?ooO`80X23`00@0oomo0:0Pl02P8?00X23`3P3oogl20:0Pl0h0
oomo00?o000007ooo`1oool0<`1oool1o`00007ooooo00000ol00000oomo0?ooO`090?ooO`80X23`
N`3oogl30:0Pl0@0oomo0P2P8?030?ooO`80X23`0P3oogl20?mo00L0oomo00@0ogl00:0Pl02P8?00
oomo0P3oO`020?ooO`80X23`0P3oogl20:0Pl080oomo0P2P8?020?ooO`D0X23`0P3oogl40?mo00<0
oomo0P2P8?00103oogl0X23`0:0Pl02P8?0>0?ooO`80X23`0`3oogl20?mo00X0oomo00?o000007oo
o`1oool0:`1oool20?mo00D0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0;`3oogl20?mo05H0
oomo0P2P8?040?ooO`80X23`00<0oomo0:0Pl02P8?001P2P8?000`3oO`00oomo0?ooO`020?ooO`80
ogl00P2P8?000`3oO`00oomo0?ooO`070?ooO`80X23`0P3oogl20:0Pl0@0oomo0`2P8?020?ooO`80
X23`0`3oogl20:0Pl0030?ooO`2P8?00X23`01H0oomo0P3oO`0;0?ooO`03o`00001oool0Oooo02X0
Oooo0P3oO`0507ooo`7o00000Oooool00003o`00003oogl0oomo02l0oomo0P3oO`1F0?ooO`80X23`
1@3oogl50:0Pl0030?ooO`2P8?00X23`0080X23`00<0ogl00?ooO`3oogl00P3oogl20?mo00@0X23`
1`3oogl70:0Pl080oomo1@2P8?020?ooO`80X23`0P3oogl80:0Pl0L0oomo0P2P8?020?ooO`80X23`
5@3oogl00ol00000Oooo07ooo`0?07ooo`80X23`7`1oool1o`00007ooooo00000ol00000oomo0?oo
O`2;0?ooO`80X23`00<0oomo0:0Pl02P8?00103oogl20:0Pl0<0ogl00P3oogl20:0Pl0@0oomo0P2P
8?070?ooO`L0X23`0P3oogl50:0Pl0H0oomo2P2P8?050?ooO`80X23`0P3oogl20:0Pl1H0oomo00?o
000007ooo`1oool03P1oool20:0Pl1l0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0R`3oogl2
0:0Pl0L0oomo0P2P8?000`3oogl0X23`0:0Pl0020?ooO`80X23`0P3oogl20?mo00X0oomo1`2P8?04
0?ooO`@0X23`103oogl:0:0Pl0<0oomo0P2P8?040?ooO`80X23`0`3oogl20?mo00d0oomo0P3oO`03
0?ooO`80X23`;`1oool1o`00007ooooo00000ol00000oomo0?ooO`0d0?ooO`80X23`2`3oogl20:0P
l4d0oomo102P8?030?ooO`@0X23`103oogl20?mo0080X23`203oogl70:0Pl0<0oomo00<0ogl00:0P
l02P8?00202P8?00103oogl0X23`0:0Pl03oogl50:0Pl0040?ooO`2P8?00X23`0:0Pl0T0oomo0P3o
O`000`3oogl0X23`0:0Pl00:0?ooO`80ogl00`3oogl20:0Pl2l0Oooo0Ol00001ooooo`0000?o0000
0?ooO`3oogl0=03oogl20:0Pl0/0oomo0P2P8?1:0?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?04
0?ooO`040?mo002P8?00X23`0?mo0080oomo00<0ogl00:0Pl02P8?000P2P8?060?ooO`80X23`00<0
oomo0?mo003oO`000P3oogl20?mo00<0oomo00D0ogl00:0Pl02P8?00oomo0?mo00050:0Pl080oomo
0P2P8?000`3oogl0X23`0:0Pl0060:0Pl0T0oomo0P2P8?020?ooO`80X23`00<0oomo0:0Pl02P8?00
3@3oogl00ol00000Oooo07ooo`0]07ooo`7o00000Oooool00003o`00003oogl0oomo08d0oomo0P2P
8?090?ooO`@0ogl00P3oogl00`3oO`00X23`0:0Pl0080?ooO`80X23`00<0oomo0?mo003oO`000P3o
ogl20?mo00l0oomo0P2P8?001@3oogl0X23`0:0Pl02P8?00oomo00@0X23`2@3oogl20:0Pl0D0oomo
0P2P8?0>0?ooO`03o`00001oool0Oooo02`0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0UP3o
ogl20:0Pl0<0oomo0P2P8?00103oogl0X23`0:0Pl03oO`020:0Pl0<0oomo0`2P8?000`3oogl0X23`
0:0Pl0030:0Pl080ogl00`2P8?060?ooO`80X23`4P3oogl20?mo01d0oomo00?o000007ooo`1oool0
4@1oool20?mo01P0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0A@3oogl20:0Pl4l0oomo102P
8?00103oogl0X23`0:0Pl03oogl20:0Pl0040?mo002P8?00X23`0?ooO`80ogl02@2P8?020?mo00<0
X23`00<0oomo0:0Pl02P8?000`3oogl20:0Pl0/0oomo0`2P8?00103oogl0X23`0:0Pl03oogl20?mo
00040?ooO`2P8?00X23`0?ooO`80X23`5`3oogl00ol00000Oooo07ooo`0A07ooo`80ogl0601oool1
o`00007ooooo00000ol00000oomo0?ooO`150?ooO`80X23`C`3oogl40:0Pl0@0oomo0P2P8?040?oo
O`80ogl00`3oogl20:0Pl0X0oomo0P2P8?030?ooO`@0X23`1@3oogl20:0Pl080oomo1`2P8?000`3o
ogl0X23`0:0Pl0020:0Pl0040?ooO`2P8?00X23`0:0Pl1L0oomo00?o000007ooo`1oool0:P1oool1
o`00007ooooo00000ol00000oomo0?ooO`280?ooO`80X23`503oogl20:0Pl0030?ooO`2P8?00X23`
0100oomo0P3oO`050?ooO`D0X23`103oogl20:0Pl080oomo2P2P8?040?ooO`<0X23`103oogl00`3o
O`00X23`0:0Pl00@0?ooO`03o`00001oool0Oooo02T0Oooo0Ol00001ooooo`0000?o00000?ooO`3o
ogl08P3oogl20:0Pl1l0oomo0P2P8?0C0?ooO`80X23`:03oogl20:0Pl0@0oomo0P2P8?070?ooO`80
X23`3@3oogl00`3oO`00X23`0:0Pl0020?mo00<0oomo0P2P8?070?ooO`80X23`0P3oO`050?ooO`H0
X23`1`3oogl30:0Pl0030?ooO`2P8?00X23`00H0X23`0`3oogl20:0Pl0@0oomo00@0ogl00:0Pl02P
8?00ogl0403oogl00ol00000Oooo07ooo`0=07ooo`80ogl06@1oool1o`00007ooooo00000ol00000
oomo0?ooO`0R0?ooO`80X23`7`3oogl20:0Pl1<0oomo0P2P8?0X0?ooO`80X23`3@3oogl20:0Pl0H0
oomo0`2P8?040?ooO`@0ogl00P2P8?020?ooO`@0X23`0`3oogl40:0Pl0L0oomo0P2P8?001@3oogl0
X23`0:0Pl02P8?00oomo0080X23`103oogl50:0Pl0D0oomo0P2P8?060?ooO`80X23`0`3oogl20?mo
0100oomo00?o000007ooo`1oool03@1oool20?mo01T0Oooo0Ol00001ooooo`0000?o00000?ooO`3o
ogl09@3oogl20:0Pl0/0oomo0P2P8?1I0?ooO`030?mo002P8?00X23`00T0oomo0`2P8?000`3oogl0
X23`0:0Pl0030?ooO`80ogl00P2P8?040?ooO`80X23`0`3oogl50:0Pl080oomo0P2P8?020?mo00<0
oomo00<0ogl00:0Pl02P8?000`2P8?020?ooO`80X23`0`3oogl20:0Pl080oomo0P2P8?090?ooO`80
X23`00<0oomo0:0Pl02P8?000`3oogl20?mo00T0oomo0P3oO`030?ooO`03o`00001oool0Oooo02L0
Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl09@3oogl20:0Pl0/0oomo0P2P8?1I0?ooO`030?mo
002P8?00X23`00D0oomo0`2P8?050?ooO`80X23`0P3oogl20:0Pl080ogl00P3oogl20?mo00@0X23`
1@3oogl20:0Pl080oomo0P2P8?030?mo0080X23`0P3oogl20:0Pl0@0oomo0P2P8?070?ooO`D0X23`
1P3oogl20:0Pl0030?ooO`2P8?00X23`00<0oomo0P3oO`090?ooO`80ogl0103oogl00ol00000Oooo
07ooo`0V07ooo`7o00000Oooool00003o`00003oogl0oomo09D0oomo0`2P8?050?ooO`80X23`0P3o
ogl20:0Pl0@0oomo0P3oO`040:0Pl0T0oomo0P2P8?020?ooO`030?mo002P8?00X23`0140oomo1@2P
8?060?ooO`80X23`5`3oogl00ol00000Oooo07ooo`0V07ooo`7o00000Oooool00003o`00003oogl0
oomo00H0oomo0P2P8?2H0?ooO`80X23`1P3oogl20:0Pl0040?ooO`2P8?00X23`0?mo0080oomo1@2P
8?030?ooO`80X23`00@0oomo0:0Pl02P8?00oomo0P2P8?030?ooO`030?mo002P8?00X23`00D0oomo
00<0ogl00:0Pl02P8?000P3oogl20:0Pl240oomo0P3oO`0V07ooo`7o00000Oooool00003o`00003o
ogl0oomo00H0oomo0P2P8?070?ooO`80X23`S`3oogl20:0Pl0H0oomo1@2P8?000`3oO`00oomo0?oo
O`050:0Pl0<0oomo1@2P8?000`3oogl0X23`0:0Pl0030?ooO`030?mo002P8?00X23`00D0oomo00<0
ogl00:0Pl02P8?000P3oogl20:0Pl0H0oomo0P2P8?0I0?ooO`80ogl09P1oool1o`00007ooooo0000
0ol00000oomo0?ooO`0?0?ooO`80X23`>03oogl20?mo05`0oomo1@2P8?020?mo00P0oomo0P2P8?00
0`3oogl0ogl00:0Pl0020:0Pl0/0oomo0P3oO`020?ooO`80ogl0203oogl20?mo0080X23`5P3oogl2
0?mo0080oomo00?o000007ooo`1oool0901oool1o`00007ooooo00000ol00000oomo0?ooO`190?oo
O`80ogl0G03oogl50:0Pl080ogl0203oogl20:0Pl0030?ooO`3oO`00X23`0080X23`203oogl20:0P
l0030?ooO`3oO`00ogl00080oomo0P3oO`030?ooO`@0X23`00<0oomo0?mo003oO`00603oogl20?mo
0080X23`00<0oomoo`00001oool0901oool1o`00007ooooo00000ol00000oomo0?ooO`100?ooO`80
ogl0I`3oogl20:0Pl0040?ooO`3oO`00X23`0:0Pl0/0oomo0P2P8?020?mo00@0oomo0P3oO`000`3o
ogl0X23`0:0Pl0090?ooO`D0X23`00<0oomo0:0Pl02P8?005`3oogl20?mo00050?ooO`2P8?00X23`
0?ooOol000009@1oool1o`00007ooooo00000ol00000oomo0?ooO`100?ooO`80ogl0I`3oogl30:0P
l0030?mo002P8?00X23`00L0oomo0P2P8?020?ooO`80X23`0`3oO`030?ooO`80ogl000<0oomo0:0P
l02P8?00103oogl20?mo00<0oomo0P2P8?040?ooO`80X23`203oogl20:0Pl0@0oomo0P3oO`030?oo
O`80ogl00P3oogl20?mo00D0oomo00?o000007ooo`1oool00P3oO`0P07ooo`7o00000Oooool00003
o`00003oogl0oomo04L0oomo0P3oO`1Q0?ooO`80X23`00<0ogl00?ooO`3oogl0103oogl50:0Pl080
oomo0P2P8?000`3oogl0ogl00?mo00020:0Pl080oomo102P8?040?ooO`80ogl000<0oomo0:0Pl02P
8?000P2P8?040?ooO`@0X23`1P3oogl20:0Pl080ogl00P3oogl20?mo00<0oomo0P3oO`0:0?ooO`04
o`00001oool0ogl00?mo0200Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0A`3oogl20?mo05X0
oomo0P2P8?050?ooO`<0X23`00D0ogl00?ooO`3oO`00ogl00?ooO`060:0Pl0030?ooO`2P8?00X23`
0080oomo0P3oO`020:0Pl080oomo0P2P8?090?ooO`@0X23`0`3oogl20?mo00040?ooO`2P8?00X23`
0:0Pl080oomo0P2P8?030?ooO`80ogl04`3oogl00ol00000Oooo07ooo`0Q07ooo`7o00000Oooool0
0003o`00003oogl0oomo0:<0oomo0P2P8?060?ooO`80X23`00D0ogl00?ooO`3oO`00ogl00?ooO`02
0:0Pl0050?mo003oogl0X23`0:0Pl03oogl00P2P8?020?ooO`80ogl03`3oogl20:0Pl0D0oomo0P3o
O`020?ooO`80X23`0P3oogl20:0Pl1T0oomo00?o000007ooo`1oool0801oool1o`00007ooooo0000
0ol00000oomo0?ooO`1I0?ooO`80X23`B`3oogl20:0Pl0L0oomo0P2P8?080?ooO`80X23`1`3oogl2
0:0Pl0<0oomo0P2P8?000`3oogl0X23`0:0Pl00/0?ooO`03o`00001oool0Oooo0200Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl0C03oogl20?mo00/0oomo0P2P8?1;0?ooO`80X23`1`3oogl20:0P
l080oomo0P2P8?030?ooO`030?mo002P8?00X23`00<0X23`103oogl20:0Pl0030?ooO`2P8?00X23`
0080X23`00<0oomo0:0Pl02P8?00203oogl20?mo00<0oomo0P2P8?000`3oogl0X23`0:0Pl00K0?oo
O`03o`00001oool0Oooo01l0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0C03oogl20?mo06D0
oomo0P2P8?030?ooO`80ogl0102P8?070?ooO`80X23`0`3oogl20?mo00P0oomo0P3oO`020?ooO`H0
X23`4P3oogl20?mo00L0oomo00?o000007ooo`1oool07`1oool1o`00007ooooo00000ol00000oomo
0?ooO`1B0?ooO`80X23`GP3oogl20?mo0080oomo0P2P8?000`3oogl0X23`0:0Pl0020:0Pl080oomo
0P2P8?050?ooO`<0X23`00<0oomo0?mo003oO`001@3oogl20:0Pl0@0oomo202P8?020?ooO`80X23`
3@3oogl20?mo00P0oomo00?o000007ooo`1oool01@1oool20?mo01L0Oooo0Ol00001ooooo`0000?o
00000?ooO`3oogl0DP3oogl20:0Pl080oomo0P2P8?1E0?ooO`80X23`0`3oogl20?mo0080oomo0P2P
8?000`3oogl0X23`0:0Pl0020:0Pl0030?mo002P8?00X23`00<0X23`0`3oogl30:0Pl0040?ooO`3o
O`00ogl00?ooO`H0X23`0`3oogl30:0Pl0@0oomo1P2P8?0H0?ooO`03o`00001oool0Oooo00@0Oooo
0P3oO`0G07ooo`7o00000Oooool00003o`00003oogl0oomo05H0oomo0P2P8?1E0?ooO`80X23`0P3o
ogl20:0Pl0030?mo003oogl0oomo00@0oomo00<0ogl00:0Pl02P8?00202P8?050?ooO`80ogl01@2P
8?020?mo00<0oomo0P2P8?050?ooO`L0X23`5`3oogl00ol00000Oooo07ooo`0M07ooo`7o00000Ooo
ool00003o`00003oogl0oomo04h0oomo0P2P8?020?ooO`80ogl0G@3oogl20:0Pl0030?ooO`2P8?00
X23`00H0oomo2P2P8?060?ooO`80X23`00<0oomo0:0Pl02P8?003P3oogl50:0Pl0030?ooO`2P8?00
X23`00X0oomo0P3oO`090?ooO`03o`00001oool0Oooo01`0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl0CP3oogl20:0Pl0D0ogl0=P3oogl30:0Pl2H0oomo0P2P8?00103oO`00oomo0?ooO`3oogl2
0?mo00H0oomo1P2P8?070?ooO`80X23`203oogl20:0Pl080oomo2P2P8?0:0?ooO`80ogl02P3oogl0
0ol00000Oooo07ooo`0K07ooo`7o00000Oooool00003o`00003oogl0oomo0500oomo0P3oO`000`3o
ogl0ogl00?mo000f0?ooO`<0X23`9P3oogl30?mo00<0oomo0P3oO`060?ooO`80X23`0P3oogl20:0P
l140oomo0P2P8?020?ooO`80X23`0P3oogl40:0Pl1P0oomo00?o000007ooo`1oool06`1oool1o`00
007ooooo00000ol00000oomo0?ooO`2i0?ooO`80X23`0P3oogl20?mo0080X23`103oogl20?mo0080
X23`1P3oogl20:0Pl0<0oomo0P2P8?000`3oO`00oomo0?ooO`070?ooO`L0X23`00<0ogl00?ooO`3o
ogl0503oogl00ol00000Oooo07ooo`0J07ooo`7o00000Oooool00003o`00003oogl0oomo0:T0oomo
0`2P8?090?ooO`80X23`0P3oogl20:0Pl0@0ogl00P2P8?020?mo0080oomo0P3oO`030:0Pl0030?oo
O`2P8?00X23`00@0X23`0`3oogl30:0Pl0030?mo003oogl0oomo00H0oomo202P8?000`3oO`00oomo
0?ooO`0C0?ooO`03o`00001oool0Oooo01X0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0Z@3o
ogl30:0Pl0@0oomo0P2P8?030?ooO`80X23`0`3oogl20:0Pl080ogl00`3oogl20?mo0080X23`0P3o
ogl30:0Pl0030?ooO`2P8?00X23`00H0X23`00D0oomo0:0Pl02P8?00X23`0?mo00090?ooO`L0X23`
00<0ogl00?ooO`3oogl0503oogl00ol00000Oooo07ooo`0I07ooo`7o00000Oooool00003o`00003o
ogl0oomo0580oomo0P3oO`1L0?ooO`80X23`0`3oogl20:0Pl080oomo102P8?030?mo00<0oomo1P2P
8?050?ooO`80X23`00<0oomo0:0Pl02P8?00103oogl20:0Pl0L0oomo202P8?000`3oogl0X23`0:0P
l0020?mo01<0oomo00?o000007ooo`1oool0601oool1o`00007ooooo00000ol00000oomo0?ooO`1B
0?ooO`80ogl0H@3oogl20:0Pl080oomo102P8?040?mo00030?ooO`3oO`00ogl000H0X23`1@3oogl2
0:0Pl0D0oomo00@0ogl00:0Pl02P8?00oomo0P2P8?040?ooO`D0X23`0`3oogl30:0Pl080ogl04`3o
ogl00ol00000Oooo07ooo`0H07ooo`7o00000Oooool00003o`00003oogl0oomo0;40oomo102P8?0:
0?ooO`80ogl00P2P8?00103oO`00X23`0:0Pl03oogl30:0Pl0050?ooO`3oO`00X23`0:0Pl03oogl0
0P2P8?050?ooO`80ogl000<0oomo0:0Pl02P8?000`2P8?030?ooO`80X23`0`3oogl20?mo0080X23`
00@0oomo0?mo002P8?00X23`4P3oogl00ol00000Oooo07ooo`0H07ooo`7o00000Oooool00003o`00
003oogl0oomo05H0oomo0P3oO`020?ooO`80X23`D`3oogl60:0Pl0<0oomo0P3oO`030?ooO`80X23`
0P3oO`020:0Pl0040?mo002P8?00X23`0?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?020?ooO`<0
X23`103oogl40:0Pl0030?ooO`2P8?00X23`00<0oomo0P2P8?030?ooO`80ogl00P2P8?00103oogl0
X23`0:0Pl02P8?0C0?ooO`03o`00001oool0Oooo01L0Oooo0Ol00001ooooo`0000?o00000?ooO`3o
ogl0EP3oogl20?mo0080oomo0P2P8?1C0?ooO`80X23`1`3oogl20?mo00<0oomo0P2P8?070?mo00@0
oomo0`2P8?000`3oogl0ogl00:0Pl0030:0Pl0@0oomo0`2P8?020?ooO`80X23`0P3oO`020:0Pl0H0
oomo0P3oO`00103oogl0X23`0:0Pl02P8?0C0?ooO`03o`00001oool0Oooo00L0Oooo0P3oO`0>07oo
o`7o00000Oooool00003o`00003oogl0oomo0<@0oomo0P3oO`080?ooO`030?mo002P8?00X23`0080
X23`103oogl00`3oO`00X23`0:0Pl0040?ooO`80ogl00P2P8?060?ooO`80ogl00P3oogl20:0Pl1@0
oomo00?o000007ooo`1oool01P1oool20?mo00h0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
`@3oogl20:0Pl0P0oomo0P2P8?030?ooO`<0X23`00<0oomo0:0Pl02P8?00202P8?00103oO`00oomo
0?ooO`3oogl20:0Pl0@0oomo102P8?030?ooO`80X23`4@3oogl00ol00000Oooo07ooo`0F07ooo`7o
00000Oooool00003o`00003oogl0oomo0100oomo0P3oO`170?ooO`80ogl0IP3oogl40:0Pl0030?oo
O`2P8?00X23`00<0oomo0P2P8?020?ooO`050?mo002P8?00X23`0:0Pl03oogl02P2P8?000`3oO`00
oomo0?ooO`030:0Pl0@0oomo1@2P8?020?ooO`<0X23`4@3oogl00ol00000Oooo07ooo`0E07ooo`7o
00000Oooool00003o`00003oogl0oomo0100oomo0P3oO`170?ooO`80ogl0F`3oogl20:0Pl0H0oomo
0P2P8?030?ooO`80X23`00<0oomo0:0Pl02P8?000P3oogl30?mo0080X23`0`3oO`040?ooO`80X23`
1@3oogl0103oO`00X23`0:0Pl03oogl20:0Pl0030?mo003oogl0X23`00`0X23`4@3oogl00ol00000
Oooo07ooo`0E07ooo`7o00000Oooool00003o`00003oogl0oomo0;H0oomo0P2P8?050?ooO`@0X23`
00D0oomo0:0Pl02P8?00ogl00?ooO`020?mo0080oomo0`3oO`020:0Pl0030?ooO`3oO`00ogl00080
oomo1@2P8?040?ooO`040?mo002P8?00X23`0?ooO`80X23`00<0ogl00?ooO`2P8?000`2P8?030?mo
00L0X23`403oogl00ol00000Oooo07ooo`0E07ooo`7o00000Oooool00003o`00003oogl0oomo05h0
oomo0P2P8?1L0?ooO`D0X23`00@0oomo0:0Pl02P8?00ogl00`2P8?020?ooO`80ogl00`3oogl20?mo
00<0oomo1@2P8?000`3oO`00X23`0:0Pl0050?ooO`80X23`0`3oogl20:0Pl0P0oomo0`2P8?0;0?oo
O`80ogl0103oogl00ol00000Oooo07ooo`0D07ooo`7o00000Oooool00003o`00003oogl0oomo05h0
oomo0P2P8?1F0?ooO`80X23`103oogl40:0Pl0<0oomo00<0ogl00:0Pl02P8?000P2P8?030?ooO`80
ogl00P3oogl20:0Pl080oomo0P2P8?00103oO`00oomo0?ooO`3oogl30:0Pl0@0oomo0P2P8?00103o
ogl0X23`0:0Pl03oogl20:0Pl080ogl000<0oomo0:0Pl02P8?000`3oogl20:0Pl0`0oomo0P3oO`04
0?ooO`03o`00001oool0Oooo00D0Oooo0P3oO`0=07ooo`7o00000Oooool00003o`00003oogl0oomo
06<0oomo0P2P8?1A0?ooO`80X23`2@3oogl70:0Pl080oomo0`3oO`020?ooO`80X23`0P3oogl30:0P
l0<0oomo0P2P8?050?ooO`80X23`00<0oomo0:0Pl02P8?000`2P8?020?mo00030?ooO`2P8?00X23`
00<0oomo0P2P8?0B0?ooO`03o`00001oool0Oooo00D0Oooo0P3oO`0=07ooo`7o00000Oooool00003
o`00003oogl0oomo0600oomo0P2P8?000`3oogl0X23`0:0Pl01J0?ooO`P0X23`0`3oogl0103oO`00
X23`0:0Pl03oO`020:0Pl0@0oomo0P2P8?0;0?ooO`80ogl00P3oogl40:0Pl080ogl0103oogl20:0P
l1@0oomo00?o000007ooo`1oool04`1oool1o`00007ooooo00000ol00000oomo0?ooO`1P0?ooO`80
X23`G@3oogl20:0Pl0X0oomo0P2P8?000`3oO`00X23`0:0Pl00A0?ooO`80ogl00`3oogl00`3oO`00
X23`0:0Pl0020?mo00@0oomo0P2P8?0D0?ooO`03o`00001oool0Oooo01<0Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl0W`3oogl20:0Pl2D0oomo0`2P8?060?ooO`030?mo002P8?00X23`0080oomo
0P2P8?0B0?ooO`80X23`1P3oogl60:0Pl0@0oomo0P3oO`090?ooO`03o`00001oool0Oooo01<0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0W`3oogl20:0Pl2D0oomo0`2P8?020?ooO`<0X23`0P3o
O`030:0Pl0040?ooO`2P8?00X23`0?ooO`80X23`0`3oogl20:0Pl0040?ooO`2P8?00X23`0?ooO`80
ogl0103oogl20:0Pl0H0oomo1P2P8?040?ooO`80ogl02P3oogl00ol00000Oooo07ooo`0B07ooo`7o
00000Oooool00003o`00003oogl0oomo0<<0oomo0`2P8?000`3oogl0X23`0:0Pl0020?ooO`@0X23`
00D0ogl00?ooO`2P8?00X23`0?ooO`050:0Pl0030?ooO`3oO`00ogl00080X23`00@0ogl00:0Pl02P
8?00oomo0P3oO`080?ooO`80ogl00`3oogl20?mo00040?ooO`2P8?00X23`0:0Pl0l0oomo00?o0000
07ooo`1oool04P1oool1o`00007ooooo00000ol00000oomo0?ooO`330?ooO`<0X23`00<0oomo0:0P
l02P8?000P3oogl40:0Pl080oomo0P3oO`000`3oogl0X23`0:0Pl0020:0Pl080oomo0P3oO`020?oo
O`<0ogl02`3oogl20?mo00<0oomo103oO`020:0Pl100oomo00?o000007ooo`1oool04@1oool1o`00
007ooooo00000ol00000oomo0?ooO`2a0?ooO`80X23`5`3oogl20:0Pl0040?ooO`3oO`00X23`0:0P
l0@0oomo0P3oO`020:0Pl0030?mo003oogl0oomo00@0oomo0P3oO`00103oogl0X23`0:0Pl03oogl2
0?mo00@0oomo0P3oO`020?ooO`80ogl00P3oogl20?mo00L0oomo0P3oO`090?ooO`03o`00001oool0
Oooo0140Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl03@3oogl20:0Pl:80oomo0P2P8?0G0?oo
O`80X23`00<0oomo0?mo002P8?000`2P8?00103oogl0ogl00:0Pl02P8?050?mo00030?ooO`3oO`00
ogl00080ogl00P3oogl20:0Pl0030?ooO`3oO`00ogl00080ogl000@0oomo0?mo002P8?00X23`0P3o
ogl40?mo0080oomo102P8?030?ooO`80ogl02@3oogl00ol00000Oooo07ooo`0A07ooo`7o00000Ooo
ool00003o`00003oogl0oomo00d0oomo0P2P8?2L0?ooO`80X23`8`3oogl20:0Pl0040?ooO`3oO`00
X23`0:0Pl0<0oomo0P2P8?00103oogl0ogl00:0Pl02P8?060?mo00060?ooO`3oO`00ogl00?mo003o
ogl0ogl00P2P8?030?ooO`<0ogl00P3oogl40:0Pl0h0oomo00?o000007ooo`1oool04@1oool1o`00
007ooooo00000ol00000oomo0?ooO`2[0?ooO`80X23`6`3oogl20:0Pl0H0oomo0P2P8?020?ooO`<0
ogl00P3oogl80:0Pl080ogl00P2P8?000`3oogl0ogl00?mo00020?mo00030?ooO`3oO`00ogl000H0
oomo0P3oO`0C0?ooO`03o`00001oool0Oooo0100Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
b03oogl20:0Pl0H0oomo0P2P8?020?ooO`<0ogl00P3oogl80:0Pl080ogl00P2P8?000`3oogl0ogl0
0?mo00020?mo00030?ooO`3oO`00ogl000H0oomo0P3oO`0C0?ooO`03o`00001oool0Oooo0100Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0L@3oogl20?mo05T0oomo0P2P8?090?ooO`@0X23`00@0
ogl00:0Pl02P8?00oomo103oO`020:0Pl0<0ogl0803oogl00ol00000Oooo07ooo`0@07ooo`7o0000
0Oooool00003o`00003oogl0oomo0740oomo0P3oO`1G0?ooO`H0X23`0`3oogl20:0Pl080oomo102P
8?001@3oO`00X23`0:0Pl02P8?00ogl000D0X23`0`3oO`000`3oogl0X23`0:0Pl0020?mo00040?oo
O`3oO`00ogl00?mo00P0oomo0P3oO`0=0?ooO`03o`00001oool0Oooo0100Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl06@3oogl30:0Pl:`0oomo102P8?020?ooO`80X23`00<0oomo0:0Pl02P8?00
0P2P8?020?ooO`80ogl00P2P8?000`3oO`00X23`0:0Pl0050:0Pl0@0ogl00P3oogl20:0Pl080ogl0
00<0oomo0?mo003oO`00103oO`000`3oogl0ogl00?mo00020?ooO`@0ogl0303oogl00ol00000Oooo
07ooo`0?07ooo`7o00000Oooool00003o`00003oogl0oomo01T0oomo0`2P8?2I0?ooO`80X23`4@3o
ogl20:0Pl0L0oomo102P8?030?ooO`80ogl00P3oogl20?mo00H0X23`1@3oO`000`3oogl0ogl00?mo
00020:0Pl080oomo103oO`000`3oogl0ogl00?mo00040?ooO`<0ogl02`3oogl00ol00000Oooo07oo
o`0?07ooo`7o00000Oooool00003o`00003oogl0oomo01d0oomo0P2P8?1?0?ooO`80X23`A@3oogl2
0:0Pl1T0oomo202P8?00103oO`00oomo0:0Pl02P8?020?mo00H0X23`203oO`020:0Pl080ogl000<0
oomo0?mo003oO`000P3oO`070?ooO`80ogl02`3oogl00ol00000Oooo07ooo`0?07ooo`7o00000Ooo
ool00003o`00003oogl0oomo01d0oomo0P2P8?1?0?ooO`80X23`H03oogl<0:0Pl0030?ooO`3oO`00
X23`00D0X23`00@0oomo0?mo003oO`00oomo1@3oO`000`3oogl0ogl00?mo00050?mo01@0oomo00?o
000007ooo`1oool03`1oool1o`00007ooooo00000ol00000oomo0?ooO`3C0?ooO`80X23`00<0oomo
0:0Pl02P8?000P2P8?030?ooO`030?mo002P8?00X23`0080ogl00P2P8?060?mo00040?ooO`3oO`00
ogl00?ooO`L0ogl00P3oogl20?mo00030?ooO`3oO`00ogl000d0oomo00?o000007ooo`1oool03`1o
ool1o`00007ooooo00000ol00000oomo0?ooO`0Q0?ooO`80ogl0[@3oogl20:0Pl0@0oomo1P2P8?03
0?ooOaD0ogl00P2P8?00103oogl0ogl00?mo003oogl40?mo00`0oomo00?o000007ooo`1oool03P1o
ool1o`00007ooooo00000ol00000oomo0?ooO`0Q0?ooO`80ogl0[@3oogl20:0Pl0@0oomo1P2P8?09
0?ooO`d0ogl00P3oogl20:0Pl0H0oomo0P3oO`0<0?ooO`03o`00001oool0Oooo00h0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl0e`3oogl40:0Pl0X0oomo00<0ogl00:0Pl02P8?001@3oO`000`3o
ogl0ogl00?mo000;0?mo00l0oomo00?o000007ooo`1oool03P1oool1o`00007ooooo00000ol00000
oomo0?ooO`380?ooO`80X23`3@3oogl80:0Pl0H0oomo00<0ogl00:0Pl02P8?001@3oO`000`3oogl0
ogl00?mo000;0?mo00l0oomo00?o000007ooo`1oool03P1oool1o`00007ooooo00000ol00000oomo
0?ooO`1R0?ooO`80X23`I03oogl20:0Pl0d0oomo202P8?070?ooO`030?mo002P8?00X23`00h0ogl0
00<0oomo0?mo003oO`00403oogl00ol00000Oooo07ooo`0>07ooo`7o00000Oooool00003o`00003o
ogl0oomo02T0oomo0P3oO`0g0?ooO`80X23`N03oogl20:0Pl0030?ooO`2P8?00X23`00H0oomo0P2P
8?070?mo00030?ooO`3oO`00ogl000<0ogl000@0oomo0?mo003oO`00ogl0403oogl00ol00000Oooo
07ooo`0>07ooo`7o00000Oooool00003o`00003oogl0oomo02T0oomo0P3oO`2d0?ooO`80X23`1P3o
ogl20?mo00030?ooO`3oO`00ogl000d0ogl04@3oogl00ol00000Oooo07ooo`0>07ooo`7o00000Ooo
ool00003o`00003oogl0oomo0=l0oomo0P2P8?060?ooO`80ogl000<0oomo0?mo003oO`002`3oO`03
0?ooO`80ogl03P3oogl00ol00000Oooo07ooo`0>07ooo`7o00000Oooool00003o`00003oogl0oomo
09P0oomo0P2P8?150?ooO`80X23`00<0oomo0:0Pl02P8?001`3oogl20:0Pl0L0ogl000<0oomo0?mo
003oO`000P3oO`000`3oogl0ogl00?mo00060?ooO`80ogl01P3oogl00ol00000Oooo07ooo`0>07oo
o`7o00000Oooool00003o`00003oogl0oomo09P0oomo0P2P8?150?ooO`80X23`00<0oomo0:0Pl02P
8?000P3oogl20?mo00<0oomo0P2P8?000`3oogl0ogl00?mo00020:0Pl0X0ogl000<0oomo0?mo003o
O`000`3oogl20?mo00H0oomo00?o000007ooo`1oool03P1oool1o`00007ooooo00000ol00000oomo
0?ooO`3V0?ooO`80ogl00`3oogl20?mo00030?ooO`3oO`00ogl00080X23`00<0oomo0?mo003oO`00
1@3oO`030?ooO`80ogl02`3oogl00ol00000Oooo07ooo`0>07ooo`7o00000Oooool00003o`00003o
ogl0oomo0>H0oomo0P2P8?060?ooO`80X23`103oogl00`3oO`00X23`0:0Pl0070?mo00`0oomo00?o
000007ooo`1oool03P1oool1o`00007ooooo00000ol00000oomo0?ooO`0^0?ooO`80ogl0;03oogl2
0:0Pl8P0oomo0P2P8?060?ooO`80X23`103oogl00`3oO`00X23`0:0Pl0070?mo00`0oomo00?o0000
07ooo`1oool03P1oool1o`00007ooooo00000ol00000oomo0?ooO`0^0?ooO`80ogl0;03oogl20:0P
l9<0oomo0P2P8?020?ooO`80X23`0P3oogl40?mo00@0oomo0P3oO`020:0Pl0D0oomo00?o000007oo
o`1oool03P1oool1o`00007ooooo00000ol00000oomo0?ooO`3@0?ooO`80X23`7`3oogl20:0Pl080
oomo0P2P8?000`3oO`00X23`0:0Pl0030?mo00@0oomo0P3oO`020:0Pl0D0oomo00?o000007ooo`1o
ool03@1oool10?mo007o00000Oooool00003o`00003oogl0oomo0=00oomo0P2P8?0L0?ooO`80X23`
1@3oogl30?mo0080X23`0`3oogl30?mo00X0oomo00?o000007ooo`1oool03@1oool10?mo007o0000
0Oooool00003o`00003oogl0oomo0>h0oomo0P2P8?020?mo0080X23`00<0oomo0?mo003oO`000`3o
ogl20?mo00040?ooO`2P8?00X23`0?mo00D0oomo0P3oO`030?ooO`03o`00001oool0Oooo00h0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0l03oogl20?mo0080X23`1P3oogl20?mo00040?ooO`2P
8?00X23`0?mo00D0oomo0P3oO`030?ooO`03o`00001oool0Oooo00h0Oooo0Ol00001ooooo`0000?o
00000?ooO`3oogl0o`3oogl:0?ooO`03o`00001oool0Oooo00l0Oooo0Ol00001ooooo`0000?o0000
0?ooO`3oogl0j03oogl20:0Pl0P0oomo0P2P8?0E0?ooO`03o`00001oool0Oooo00l0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl0j03oogl20:0Pl0P0oomo0P2P8?0E0?ooO`03o`00001oool0Oooo
00l0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0m`3oogl20:0Pl0@0oomo0P2P8?0:0?ooO`03
o`00001oool0Oooo00l0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0e03oogl20:0Pl1h0oomo
0P2P8?000`3oogl0X23`0:0Pl0040?ooO`D0X23`1P3oogl00ol00000Oooo07ooo`0@07ooo`7o0000
0Oooool00003o`00003oogl0oomo0=@0oomo0P2P8?0N0?ooO`80X23`0`3oogl30?mo0080oomo102P
8?060?ooO`03o`00001oool0Oooo0100Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0n@3oogl3
0?mo00`0oomo00?o000007ooo`1oool0401oool1o`00007ooooo00000ol00000oomo0?ooO`3l0?oo
O`80X23`103oogl20:0Pl080ogl00P3oogl00ol00000Oooo07ooo`0@07ooo`7o00000Oooool00003
o`00003oogl0oomo0?`0oomo0P2P8?040?ooO`80X23`0P3oO`000`3oogl0ogl00?mo000207ooo`80
ogl03P1oool1o`00007ooooo00000ol00000oomo0?ooO`3o0?ooO`80oomo0P2P8?000`3oO`00oomo
0?mo00030?mo0080Oooo0P3oO`0>07ooo`7o00000Oooool00003o`00003oogl0oomo0?l0oomo0P3o
ogl20:0Pl0030?mo003oogl0ogl00080X23`4`1oool1o`00007ooooo00000ol00000oomo0?ooO`3o
0?ooO`<0oomo0P3oO`020?ooO`80X23`4`1oool1o`00007ooooo00000ol00000oomo0?ooO`3o0?oo
O`D0oomo00<0ogl00:0Pl02P8?000`1oool20?mo00l0Oooo0Ol00001ooooo`0000?o00000?ooO`3o
ogl0o`3oogl50?ooO`030?mo002P8?00X23`0080ogl000@0Oooo0?mo003oO`00ogl03P1oool1o`00
007ooooo00000ol00000oomo0?ooO`3o0?ooO`H0oomo00Co000007ooo`3oO`00ogl00P1oool20?mo
00h0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0o`3oogl50?ooO`03o`00001oool0Oooo0080
X23`4P1oool1o`00007ooooo00000ol00000oomo0?ooO`3o0?ooO`D0oomo00?o000007ooo`1oool0
0P2P8?0B07ooo`7o00000Oooool00003o`00003oogl0oomo0?l0oomo103oogl00ol00000Oooo07oo
o`0407ooo`80X23`3`1oool1o`00007ooooo00000ol00000oomo0?ooO`3o0?ooO`@0oomo00?o0000
07ooo`1oool0101oool20:0Pl00307ooo`2P8?00X23`00`0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl0o`3oogl30?ooO`03o`00001oool0Oooo00P0Oooo0P2P8?00101oool0ogl00?mo001oool2
0:0Pl0H0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0o`3oogl20?ooO`03o`00001oool0Oooo
00`0Oooo0P3oO`000`1oool0X23`0:0Pl00607ooo`7o00000Oooool00003o`00003oogl0oomo0?l0
oomo0@3oogl01?l00000Oooo0:0Pl02P8?0G07ooo`7o00000Oooool00003o`00003oogl0oomo0?l0
oomo0@3oogl01?l00000Oooo0:0Pl02P8?0G07ooo`7o00000Oooool00003o`00003oogl0oomo0?l0
oomo00?o000007ooo`1oool04`1oool20:0Pl0@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
oP3oogl00ol00000Oooo07ooo`0D07ooo`D0X23`0@1oool1o`00007ooooo00000ol00000oomo0?oo
O`3m0?ooO`03o`00001oool0Oooo01H0Oooo102P8?0107ooo`7o00000Oooool00?oo00008?l00001
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, \
0.889355, 0.889355}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, 0.889355, \
0.889355}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1, pdf1, pdf2, {Red, Green}];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2, pdf1, pdf2, {Red, Green}];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1, obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45448 
%%ImageSize: 400 181.791 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0108209 0.238095 [
[ 0 0 0 0 ]
[ 1 .45448 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45448 L
0 .45448 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0108209 0.245293 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0108209 0.488926 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF00A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0108209 0.732558 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C834
59C9355AC9365CC9365CC9355ECD3B61D14389B25CBB9C81BD9F86BC9C80B29274B59678
51C337AD9173BCA285BCA48CBAA590B19B88B29D8A857668796F639486738A7A62887760
9B886D5AD1457FAF5953CA3E56C93D55C63A55C5382AE11B00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008CB65EB89A7CBA9D81
BEA588C7B095BDA38BC2A78FDCC7B5D8C9B9CCBEAEC9BAA9CEBEACBAA793AC9580C3AE9B
D2C3B5C0B5A8CBC1B6D6CEC8B6B3B2868484B0AAA842464C1D2E39626C6FA7A8A48F9190
9B9F9DC9CCC8B0B6B1BDC1BBC7C4BACAC1B5C4B7A9C1B0A2BCA797B59E8EB39A8784B163
59CD4256C93D51C33600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE318
59C6315BC734B69169B8946CBA9A72B89E7BD2BB9DCCB69CB6A28AD4C4AED2C4B0BAA996
BCAB97D7CBBCDDD1C5CBBDB1CFC2B7CFC7BCC5BDB1AEA393BDAE9ECCBFB2C3B6AAC6BBB1
D5D0CBC2C2BEB3B1ACBCB9B5A1A2A26E6E719E9A98B1B3B399A8AF90A4AEBBC9CEA9BAC4
3450655B7B915B7B8C627E8BBCCED2C8CFCFC9CCCACCCBC9CECBC8CEC9C7CEC9C6CEC9C4
CFCAC2CEC5BCC5B8AEBCAFA3B3A393AC978555CA4300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002CE31959C7325BCA3489B14FB8986BBD9C72
C09D76C19E7AC5A484CBAB8FC4A78DC0A88FD4C3ACCFBEA9B9A790B8A68FC2B5A2CAC0AE
BFB5A5D3CABED8D2C9C8BEB3BAAE9EC6BDAFCEC9BCC7C0B4CAC2B8D6D1CAD6D1CABBB3AC
C2BDB6B3B2ADB0AEA8ABA89FCAC8C1D3D3D1C0C1C1BCC0C1AAB9C2334D66536D838FA1B2
203A5412345182A2B6748E9CB0C6D0C1D0D5C7D0D3CBD1D4CAD0D2CDCFD3CCCFD1CCCED1
CCD0D1CACECFCCCECECCCDCCCACAC8CEC9C8C7BFBBC4B9B3BAABA0AF9A8859CE4550C236
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002DE3195BCA35B8946FBB9874BC9B76C09E7AC3A480C4A682C4A682
C7A885C5A987C6AB8DD1B7A0CFB7A0C9B198C7B099C8B29DC8B09DBEA894CEBEACD3CABC
BEB6A9A69D92AEA69DC6BDB5CAC1B7CBC3B9D8D5CDD6D6CEC1BEB5C0BCB3C8C2BBC2BAB3
BCB5ADD6D4CED6D6D0C7C7BFC0C1B9CBCFCD8690938891949BA3A94B5C6F455C6F9FB1BA
A9BCC785A0B29CBAC8B6D3DF648495ABC6D2C0CFD3C8D2D4C9D1D4CCD1D5CAD0D4CDD3D7
C6CED1C9CED1CBD0D3C9D0D3C9D0D3C7CCCFC9CBCEC9CBCEC7CAC9C7C7C3CAC6BFCBC1B8
C3AFA4A88E7E94755E47B52922D81100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC935
5ECC3ABA9670BC9974BC9D76BEA07BC0A07FC4A284C7A78AC7A98DC8AB8FC9AD90C9B090
CBB293CCB393CCB296CDB39ACEB69ECEB8A0CEB9A2D5C1AEE0CCBBC8B4A1C4AF9CBCAC9D
A79F90BEB7A9CDC5BCC7C2BDCDC8C3C6BCB5CBC4BCCDCCC4C3C1B9BFBCB4D7D5CEDADAD4
C6C6C1CBCCC7CDCFCABEBEB8B3B2A9B7B5AE979B9C9DA1A3B8BCB9CAD2D7B7C8D498AFBD
B8D1E14E6F8C254E6F799FB9284C667090A7BFD2DAC7D2D5C6CFD3C8D1D3C7D1D2CBD4D7
C7D1D2C9D0D2CCD1D4C8D0D3C7D1D3C8D0D3C8CED3BFC8CEBDC8CBC4CDCFC5CCCCC6C9C8
C7C5C4C7BEBCBDB1ACB1A1969D857489674F42B02100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BCA3486AE4FB79A72BDA37E
BEA281BD9F81BEA283C0A686C2A889C7AB8ECCAE92CCAF95CAAF98CEB49ECEB7A0CBB69E
CBB79FCEBAA0D0BAA2D3BAA3D5BFA9DAC8B3CFBEA8D2C0ABCEBCA7CBB4A0D0B7A4B9A99A
CEC7BBD9D4CACDC7BDCAC5BFAAA69FC7BFB5C7C0B6D8D7CEDBDAD5CECDC8CECDC7D9D7D3
CCCAC4C0BCB5C5C1BAC2BEB8C4C0B8C3BFB9D5D8D4CFD6D6B7BFC0C8D0D7687F9623476D
6D8EAE3F5F82143A6261839DA8C2D38EA8B8BDD3DDC6D5D9C6D2D6C7D1D3C8D2D4C6D0D2
C6D0D1C6CED0C8D0D4C8CFD5C4CDD2C2CCCEC6CED4C4CDD5C0CBD0C5CDD2C4CCCEC6CECE
C4CACBC5C7C9C0C2C4C1C1C0C4BFBAB9AAA29D877686694D3DAD1D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002CE41BB09268B3986EB99E77B79C77B79F7BBAA381
C0A887C1A888C4AB8BC6AD8FCAB398C8B196CEB89FCFBBA5CCBAA5D3C0ACD2C1ACD0BFAA
C9B8A5D0BFACD3C2AFD7C3B0D7C4B0D8C6B0D7C5ACD7C3AAD6C2AADDC7B3D7C1AEC3B2A3
B2A99FCDC7BEC7C0B6ABA69CBCB9B0DAD6CECAC7BFD3D2CBDADAD3CECBC4C2BBB2CCC5BE
D3CEC8C7C2BBD2CFC8DBD8D3D6D4D0CCCAC6CACBC8B7BFC2768489A9B3B88F9EAE46607F
7D94ADBDCEE0A5BBCE9BB6C9BAD3E295B2C36E8FA1BED6DFC8D6D9CCD6D8CCD4D9C9D1D4
C8D0D3C8CFD4CBD2D8C9D0D6C7CED4C5CCD2C4CDD3C4CDD6C4CED6C4CDD2C0CACDC3CCD0
C2CBCEC5CBCFC1C8CAC3C7CABEC1C4C1C3C3C1BEBBB7ACA4988471628D381ED50D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CE3185AC8335ACA36B0946CB59B76BAA17DBCA583BAA281BBA381BCA582BDA886
BEAA8AC2AD8FC8B295CDB89ECCB8A1CAB9A3CABAA6B7AA9AADA295A69A8BCABDABD4C3B0
D4C1ADD6C4B0DBC9B5DBC9B5DAC8B4DBC9B2DCC8B0DCC6AEDAC6AFDDCBB7D7C6B1D5C4AF
BCAF9EB9AFA4C1B8B1B8B2A9D7D4CCD8D7D1C4C1BAB9B5ABC7C3B9CFCBC2C7C2BAD2CCC6
DAD6D2D8D7D3C4C1BCD3CDC8D2CDC8C5C0BABBB6B0BFC0BEA4ACADB2B8BBCBD2D6C5D3E1
A2B6C7AABDCAA3BACC2B4E6E3A607F6185A01C435D9DBCCDC4D8DBCED9DACCD6D7CAD5D7
CAD3D8CAD3DACDD5DBC9D2D5C9D3D5CCD3D8C8CFD6C8CFD7C7CED6C6CDD5C2CBD0C0C9CF
C1CBCFC4CED0C4CDD0C0C8CCC1C7CCC2C6CABCC2C5C0C1C3C5C0BCAB9B90856D583BAB1E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058C833
85AE4FB7996FBB9C75B89C78B99F7DB9A380B7A380B8A384B7A383BDA987C1AD8AC1AD8C
C3AF91C8B298CDB79FCDB8A3CEBBA9D0BFAFC2B6A6B9AFA3D4C9C1A89E94C1B4A4DAC9B6
DECAB8DDC8B5DFCAB6DCC8B6DDCBB7DFCEB9E0CFB8E0CCB5E0CCB4DAC9B2D9C9B1D8C8B0
D2C5B0DED3C5E2D7CED0C6BCCBC2B6CAC4BAA6A49D9B9B95A6A8A0D8DAD2D8D7D1C4BEB8
CFCAC5CFCAC6BCB5AFC6BCB4CFC8C0D7D4CDC9C5BFCDCDC8D5D7D4C8CBCCADB1B4A4B1BD
2745603D5D788CA6BB2A4869183C5FA1C0D68AA7BA96B4C4C3DAE1CBD9DACCD7D9CAD4D6
C5CFD1C2CDD0C5D0D2C9D4D6C9D4D6CBD4D9C9D2D7C9D2D9C7CFD6C7D0D5C1CACFBFC8CD
BCC7CBC2CDD2C3CED4C1CAD1BFC8CDBFC7CCBDC5CBBDC1C9BDBFC5BDBCBFAEA9A68A796C
5E883600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE51A83AE4FB0956E
B89C78BC9F7DBFA282BDA283B9A083B6A084B5A082B7A284C0AB8CC1AD8CC9B393CAB697
C9B79CCDBBA1D3C0A7D1BDA6CFBCA9D0C1B1D6CEC1D9D5CFDCD7D3B3AAA0CCBDABD7C4AE
DDC8B3DECAB7DECCB8D9C7B5D9CAB8DCCEBDE0D0BDDFCDB7DECCB3DCCBB3DECEBADBCFBB
D4C8B3D4C5B4D4C5B6CFC1B2CBBFB0D6CDC3C2BFBBCBCBC88C9089CACDC5D2D1CAC0B8B1
C3BAB1D5D0C6D6D4CAC9C7BDCECDC4D8D9D2D4D6CFBBBBB4C2C4BF868B8E949A99ACB1B4
5D6F80536C80B0C4CFB3C7D58BA8BDA2C0D1B4D0E253768DA0C1D0C4D7DECAD4D6CAD3D6
C9D3D5C8D4D4C7D3D4C8D2D4C6D0D2C8D1D7C7CED6C6CFD7C5CED5C3CCD3C2C9CFC1C8D0
BCC5CCBDC6CDC2CBD2C2CBD0C3CCD3C3CAD3BEC7D0BBC2CBBBC1C8BEC4C9B8BEC3A7A6AB
7B736D55863700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002CE41958C934B0956CB09970B6A079
BAA17FBBA182BBA082BDA385BDA489B9A48CBAA58CBEA88BC8B192CAB294CCB498CDB89F
CEBBA3D1BFA7D4C0A8D3BCA5D1BDA6CDC1AFDEDBD0DCDDDADFDCDBD6CBC3D5C4B2D8C3AC
DBC6B0D9C7B1D7C9B4D7CDBFDDD6CDDFD9D0DCD2C5DECFBBDDCBB3DFCAB4DBC9B5D9C9B5
D8C8B4D8C6B1D8C8B6E1D4C5D3C8BAD3C7BCD4C9C4B1ABA6ABA79FC3BDB3D7D4CCD6D2CC
C7C1BAD8D6CDDADBD3D3D3CBC2BDB6CBC4BEC7C2BBB4AFA5BAB7B0B8BAB9B6B8B7BCBBB9
D2D8DCBDCED89CAEB6B1C4D046647E264C6C7CA0B9224764537A91C0D8E2CBD7DACCD4D7
CBD5D6CAD6D7C8D5D5CCD5D8CCD4D8CAD1D9C9D0DAC4CCD3C2CBD1BEC7CEBEC7CDBDC6CB
BBC4C8C1CACEC0C9CEC5CED3C7D0D5C5CED5C2CCD3BBC4CBB8C3C8BCC6CABFC7CFABB1BC
3F4652404042467D341AD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C73484AE51B3986FB1976FB59B74B59F78BAA482
B89E81BAA083BBA286BDA389C3AB92C3AD96C1AB92C5B095CAB599C9B499CAB49ACEB9A1
D2BFA8D2BEA9D1BCA7D1BBA6D4BEA9D4C5B1DDD8CAE0DED7DED8D1D5C7BAD7C5B2D8C3AC
D9C4AEC9BBA7B3AB9DBCBAB4CCCECCDADCDAE0DDD6DACFC0DCCCB7E0CBB5DDCAB5DBC9B4
DACAB3D7C7AED6C6B2DCD0C1D3C7BACEC0B2CFC1B6D6CCC2D3CBC3C7BFB8DCD9D1DBDAD4
CAC9C0C2BFB4CBC8BEC7C3BAC3BAB3C5BCB5DAD5D1D6D4CFC2C0BCD4D5D1D1D6D2A7ABA6
B3BABB5F74842C495F8CA3B6445F7B1033577D9FB69EBBCC7492A5B8D0DCC8D7D9CDD7D9
CCD6D8CBD6D8CBD6D8CDD5DACBD2D8CCD3DBC9D2D9C8CFD6C7CED3C1CACEBCC5C9B9C0C6
B6C0C2B7C2C6B9C4C6BFC9CDC4CFD3C6CFD7BFC9D2BFC8D0BBC6CCBAC4CDBFC8D1BDC6D0
7C8894717F8A62676B66594A1DD61000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0056C835AE936EB19672B39873B39974B49C77B69E7BB9A282B9A285
B79E87BAA28BBEA891C3AD97C3AC96C7B09CCAB59DCCB89ECCB79EC8B399CBB69CCDBBA1
CDBBA2CEBBA3D0BEA6D0BEA6D4C0A8D5C2ACD2C4B2D4C7B9D7C6B6D3BEA8D8C2AAD9C3AD
CCBBA9AEA391CDC6B9DAD8D3BFC1C2CED0D1DEDCD6D9D0C4DCCCBBDFCBB8DFCAB7DCC9B4
DAC8B2D8C6B0D5C3AFD2C1B0D2C2B1D0C1B1CEC2B4E0D7CFDFD8D2C6BEB6CAC1B6CECABF
C3BFB4BEB6ABD5CEC4DFDBD3D7D5CFC4C0BCD9D5D4DAD9D5BBB7B4B9B4B0B1B3AF767B7A
A8AAAC919BA853697E98ABBABFD1DE92AAC0849FB5B5CDDD86A3B56C8C9FC1D9E1C9D6D9
CBD5D7CBD5D7CAD3D8CDD6DBCDD6DBD0D7DCCCD5DACDD4DCCCD3DAC7CED4C2C9CFBEC7CC
BCC6C8BAC4C6B8C1C4AFB6BCB6BFC2BDC6CDBBC6CCBDC6CDC0CBD0BFC9D1BFCAD3BCC7D0
A6B4C08798A88B9CA69CA2A390827100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002AE31980AD4FAE9471B19776B39977B29B75B19C77B19B79B79E80BBA287B9A28A
B9A38DBEA893C5B09CC8B59FC6B39DCAB69FC9B49BC8B398C8B399C8B199CCB49CCAB59C
CCB89FCBB79ECBBAA0CDBDA2D2BEA6D2BCA7D4C1ABD3C0AAD7C1A7D3BDA0D8C1A5D8C4AD
B4A694BBB2A2D2CABEDDD8D1CCCCC8C4C3BDD9D2C8DCCDBDDECCB8DDC8B3DECAB4DEC9B4
D9C6AED9C6AED8C3AED1C0ACDDCDBDDDD0C1C9BCADCFC3B7CCC2B7C5B9ABBFB2A3D3CEC1
DBD8CFD3CCC5D1CBC5DBD8D3D7D8D3C1BCB7C1B8B3CAC4BFC1B9B5B6ADAAD4D1CFC5C7C5
B6B7B3CED0D0C9D4DBA0B2BBA9BCC57A93A8183B5C4F718D5778921A3E5DA6C5D9C7D7DD
C9D4D6CCD5DACCD3DBCCD5DCCDD6DACDD4DACCD5DCCCD3DCCDD6DDC7D0D5C6D0D2C4CDD2
BEC8CDC0C7CDBDC4C7B6BDC0B2BABDB3BCC1B4BEC1B8C3C5B5C0C3BFC9D1B7C5CEBCC9D3
B3C2D03A4B62334A603A515E6E76775B904400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C733
53C733A89067AD956FB09775B39978B59C7BB29C7BB19D7EB39F81BEA78BBDA68CC0A991
C3AE98C9B39CC9B39CC9B29CC8B19AC6B097C4AE93C7AF93C6B195C6B196C9B198CCB39B
CBB59DCCB99FCCBB9ECEBD9FD3BEA5D2BDA5D2BEA5D4C0A6D7C1A5D8C0A2D5BC9EDAC1A8
C2AE9AAB9D8CD2C7B9CAC2B6ACA598CBC1B2DBCCBADDCCB7DECBB4DECBB3DBC7B0DBC8B0
D8C7ADD6C3AAD4C1A9D1C2ABD3C2B0D4C2B2D0BCACCAB9A9D0C4B5DAD0C5C5BCB1CFCBBF
D9D9D1D7D5CFBDB7B0C2BDB6C7C6BEC9C3BFBEB4ADD5D0CBD8D6D3C3C1BEC9C8C5D4D5D2
B6B7B2A8A9A48F9BA130495E506D808099AB23406033536FB4CEE2728EA58FAEC1C2D7E1
C7D4DAC9D4DACBD4DBCDD6DDCFD8DFCED6DECDD6DDCBD3DCC9D2DAC2CDD2CAD4D8C8D0D5
C2CBD0C0C7CDC2CACEC2CACEBDC5CABBC2CBB6BEC4B6BFC4B6BFC6B9C3CCBDC7D1B0B9C6
B8C1D0738193667B8E4D647653657085858261914400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007BAA4BA79169
A7916AAC956FAF9773B09876B39A7AB49C7DB49E81B39E83BBA68DC0AA91C5AE95C6AF98
C4AF99C4B098C4AF96C6AF97C6AD95C5AB92C5AC92C5AE94C5B197C6B299CAB49ACCB49A
CCB59BCCB89DCEBA9FCFBBA1D0BBA2D3BDA5D1BBA3D3BDA5D4BEA2D6BEA1DABEA1DCBEA5
D9BFA8BCA995AC9C8DAFA090C8B8A5D9C8B2DCCAB4DDCBB5DBC9B3DAC8B2D8C5B0DAC6AF
D9C5ACD6C2A8D5C2AACFBDA6D0BDA7D2BFABD4C1AFC9B8A7D0C6B8DAD5CACCC6BBBBB3A5
C4BFB2C8C4B9C1BDB2BDB9AFD2D0CADCDAD6CEC9C5C4C0BBD1D1CCBFBCB8ABA5A0B9B5B2
8B8C899B9D98BABDC16372855D7485B7C8D2B0C2CF8FA8B9A0B8C8AAC2D6577992ABCADC
C1D4DBC8D2D8CCD3D9CCD5DACFD8DFCED8DECBD6DCCCD6DFCCD6DDC9D2D9C8D1D7C7CED7
C3CAD2C1C8D0C4CBD3C8D1D9C3CDD5C3C9D4BBC4CCBBC6CCBCC8CEBDC7D0C1CAD3B0B9C2
AEB6BF9FAAB592A3B198ACBB889BA59CA6AAA9A1993EB02500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A48B64A78F69A7916C
AB9370AE9574B09778B49B7CB49D7DB5A082B8A287BBA38BBFA38EC6AD97C8B29AC4AF98
C1AD95BFAE94BEAB8FC1AB90C4AB90C4AB8FC2AC92C2AD95C5B19AC9B59DCEB89ECDB59A
CEB69ACDB89ECCB9A0CDBAA2CDB9A2CFBAA2D3BEA6D3BFA6D5C0A7D6BFA5D8BFA4D7BCA1
DAC0A4D8C3A8D8C3ACD9C4AED8C3ACDCC7B1DCC7B2DFCAB4DDC9B1DAC7AFDAC7B0D9C3AC
D9C3AAD8C3A9D5C0A9D3BEA6D3BEA7D3BEABE0CFBCCDBCACC8B8A9C8BCAFC3B8ABC2B4A7
C4B9ADDDD8CFD9D5CEC4BEB8CAC4C0D5D1CDC9C2BEB4A9A1B8B0A7C2B9B6B6ADABC8C2BE
CECECBC1C2C0BDBCBDCED3DAB4C1CB95A1A9A0B1BD334F692B4E6E7F9EBC16395E648AA5
BFD7E1C9D4DACBD5D8CCD3D9CFD8DFCDD6DFCCD6DFCDD6DFCDD6DDCDD4DCCDD6DDC7CDD8
C7CED7C1CAD1C8D1D8C9D1DBC8D2DBC6CFD9C3CCD5C5CFD6C0CDD3B8C5CDBEC8D1B2BEC4
B0BAC0A0A6B1414D5E44596D5268756C7C8091979395847500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0028E11979A64CA68F6CA7916FA99171
AB9273AE9678B19B7EB29C7FBBA287C2A88CCAA98FC89C87C79782CDA48AC4A88EBEAA90
BBAA91BBAA8FBBA78AC1A98DC3AA8CC3AA8DC5AF95C5B199C7B29CC8B39DC8B399C9B196
CAB59ACCB9A1C5B6A0BEB39FBCB39FC3B8A4CBBEA8D1BFA8D2BEA6D6C0A5D7BEA5D9BFA5
D9C0A4D9C3A7D7C3A9D8C4ABDBC6AEDBC7AFDBC7AFDCC9B1DBC9B1DBC9B1D8C5ADD9C4AC
D9C2A9D9C1A9D6BDA6D4BCA6D3BAA4D0B9A4D0BAA7CDB9A6C9B5A4C9BAAADCD3C8D6CCC2
C1B5AAD4CCC0D2CDC3C4BDB2B7AFA4C2BAB0CEC6BFC1B8B0C2BCB4DAD6D2D4D2D0B9B7B3
CECFC9C4C5C0A1A09CACADAF566573364D5F96ACBA3C557214355997B5D086A2BB608096
BDD6E1C6D3D9CCD4D7CDD4DACFD6DCCED7DECBD6DCCBD4DDCED7E0CED7E0CBD4DDC4CDD6
C6CFD4C4CDD2C5CED4C6CFD8BFC9D1B7C3CCB4BEC8C5CFD6C5D0D6BEC9CFBDC8CEB6C1C7
B4BCC2B1B4BE565D6E5565794C606F6577817F8B8E9088843DB02800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A18866A18A689F8A68A18C6CA59173AA967B
B09D83B5A48AB3A28ABCA690C3A38EC69984D79482B65B4B9D3423BB644CCC987AC2A586
BBA688BCA68BBEA58CC1A78DC4AA8DC4AB8EC4AB91C4AD95C6B099C6B099C5B096C7B297
C2B29BA49B89817D707170656C6D656C6F678C8E81BCB4A2D1C1A8D6BFA7D8C0A8DAC2A9
D8BFA4D9C3A4D7C3A6D8C4A9D8C5ABDBC6ADDBC5AEDCC8B1DBC8B0DAC8B0D9C6AED9C4AC
D9C2AAD9C0A8D7BDA6D3BBA3D2BBA3D1BBA4CFB9A3D5C1ADCFBCACC8B8A8D5CABCD0C7BB
BDAFA1C1B2A2C8BDAECEC6B9C2BCB0C7C2B9DAD7D2D6D5D0B8B5B0CBC6C1CAC6C1ABA8A0
AFADA4ABABA88C8E8CB6B6B899A2AD586C7C9BAAB6BDCCD796AFBE8DA7BAA9C1D068879C
89AABBC3D5DECDD5D9CDD4DACFD6DCCED6DDCAD5DBC9D4DACBD6DDCBD5DFC9D4DDC5D0D6
C7D2D6C7D0D7C4CDD4C6CFD6C2CBD2B5BDC6A9B1B9B4BBC3C2CDD6BFCAD3C4CED8B8C1C9
B8C0C8BBC1C8909BA481939F8297A28DA0A9A1AFB6ACADB095837A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CC22F9885619A88679D8B6BA39173A59377AC9B82AE9E85
B2A38AB3A48DB6A68FBDA491C99A89A14E3DA52E1FB32418B42012A12912C98365C5A182
BDA386C2A78FC2A78EC4A98EC3A98BC4AA8CC4A98EC5AB91CDB49BC7AF95C5AE95BEAE97
8F87757272628A87789A94869A93887D7D7560645E74756BBEB5A1D3BEA6D7BFA7D7BFA8
D6BFA6DAC2A7D8C1A5D8C4A7D8C5A8DBC7ADDBC7AFDBC5AFDCC7AFDDC9B1D8C4ACD9C5AD
D8C3AAD6C0A7D9C1A7D5BDA3D5BFA7D3BEA6D0BBA4D3BFABD0BDABC8B6A2C4B59FC4B7A4
C7B8A8C1B3A3D6CFC3DBD8CFD8D6D0BFBCB5CBC9BFCBC8C0B3ACA5B0A79ECCC4BDC8C4BF
B3B1ABD4D4D3CACBCDB0B0AFC4C7C8C2CAD097A0A7A0AAB26B82932245646A8BA9345573
315473B8D3E2C9D7DBCCD3D8D1D8DECED6DFCDD7DDC9D4DACAD5DBCCD6DFC9D3DCC8D4DA
C9D4DAC3CCD5C6CFD8C6CFD8C7D0D8BFC5CFAEB5BDAEB7BEC0CCD4C0CED5C2CED6BFC8D1
C0CBD4BCC8D18494A1374C5B415966667E8685979EA4ACB3B0A9A840B42B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CC2309989649C8E6BA19274A19278A6967EAC9E85AB9D86B1A28A
B0A188B4A48BB6A28ABF9C87B6715EA83A27B12715B52110B22410B64B30D09475C4A285
C0A589C3A88CC2A78BC1A78AC3A98AC4A98BC6AB8DC6AB8DC8AD91C5AA91C1AC96968A7A
6D6D5F919283A39F8CA69F8AA9A18F9F9A8D7679725B615A92907FCEC0A5D4BFA4D5BFA4
D8C1A6DAC1A7DAC1A3D8C0A2DAC4A8DBC7AED8C7ADDCC8AFDCC8AFDBC8B0D8C6ADD6C5AB
D6C3AAD5C0A8D5BFA7D5BEA6D2BCA4CFBAA2CFB7A2CFB8A3CAB5A1CAB6A2C4B49DD2C5B3
E1D4C9C1B5AAC1B9ADCAC5BBC6C4BDB8B4AAB7B3A7D2CFC5D3CDC8B7B1ABD5D2C9D5D4CF
BCBAB6BCBAB6C2C1BEA8A7A1A0A19A939A9E3546566C7F8E849AAE17375A41607FA0BAD0
526F83A7C1CCC4D5DAC9D5D9CED5DBCED6DECCD5DDCBD4DBCBD4DACDD6DDC8D2DBCAD3DC
C9D2DBC4CDD7C4CED6C3CDD6C5CFD7C6CDD6BAC2C7ABB3B8C2CDD2C0CDD5C1CBD3C1CBD5
C2CFD8BECCD797A7B72F43583E56694A64726F858E96A3AA98989A62954D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0024DF179787649C8E6C9D8F72A1927BA49680A69A85A79B85AC9E87B1A18A
B2A189B6A48BB39B81BE91769C432DAE3720C54D33DA6B509D381DCB8164CB9F82C1A488
BFA589C0A789C1A88AC1A887C2A987C3A888C7AA89C7AA8AC5A88AC2A78BB3A48F676557
77796C9E9C89A6A08BA59E8CAAA291A8A0927F80775D675F737868CABEA6D3BCA0D6BCA2
D6BCA4DAC0A7DBC2A4DBC3A4DAC4A8D9C5ACDBC6AEDCC7AFDCC7B1D9C6AFD9C6AED7C3AA
D8C4AAD5C1A7D5C1A8D5C0A9D3BCA5D1B8A2D0B7A1CEB7A2CBB7A3D6C3B1C4B29FC5B4A3
CCBDAEC2B2A3BDAD9EB6AB9ECBC6BCD1CCC7BCBAB2D3D2CCD7D7D2C1BCB8B6AFA7C1BBB4
B2ACA4A59E95C0BCB58F8F8B9EA09CC7CCCE64717F647280C0CAD2ACB3BF8F959DBABBBC
B1B4B6909A9FC7D2D5CAD3D6CDD6D8CED6DBCBD5DAC8D4DBC8D3DBCAD3DCCAD3DCC9D2DB
C7D0D9C7CDD8C7CDD7C3CBD4C4CBD1C0C5C2C6CBC2C4CBC8C0CACEBECCD3BDCAD3C2CFD8
C2CFD8BECAD7AEBCCB7B8B9A7689976277827E939C9DACB4B6BBC0978C861BD40F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
22DD146699408C7D5B9586659B8D709B8E75A2967EA3977FA79C85A89B83A99980AE9D83
AC9A7FAF9D80B49D80BD9277A7583E982E14AB4A2BD58B69AF7554C79A7BC0A084BFA48A
BFA388BFA286BFA385BFA385C2A587C2A484C3A485C3A585C5A888C0A68B9588755C5D52
7A7F70989983A09C84A29E8A9E998B939084797C775A645E727769C6BBA3D1BCA1D6C0A5
D6BDA5D7BEA7DAC2A7DAC2A4D8C1A5D9C2A8DBC5ADDAC5ADDAC6AED9C5ADD8C4ABD6C3AA
D8C5ABD5C1A8D6C2AAD4BFAAD2BDA8D1BCA4CFBAA2CDB8A2C7B5A0CBB7A3C9B39EC5B09B
C2B09ECCBCAAC3B4A4BBAFA2D0CABFD6D5CFC4C2BCB6B1AAC1BBB3B7ADA7B1A49DC3B8B1
D2CCC6BFBAB5D1CDC8CFCBC9C2BCB9BAADAAC4AFB1B39697B38C8BC39392BB8782BA827C
B98481A67A7CBE9B9FC8AEB1CCC0C2CECDD1CFD3D8C9D1D7CAD4D9C7D0D6C7D0D7C9D2D9
CBD4DBC5CED7C7CED8C7CED7C9CDCDB1AE95ADA87DCBCAAEBFC6C0C2C9D1C2CBD5C1CDD9
B9C7D2C2CEDCBCC8D56A76864D5E6D63758076878F859299A1AAADBEBBBA43B83300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0021DC15
8473548777588B7C608D80659589709D917AA29680A39880A99E85A99C81A99A7EAB9A7C
AB9A7CAE9D7FB39F7FB99B7DC59779BA7F60B37C5AC59D7BBE9D7EBEA083BBA084BCA286
BFA386BE9F80C1A382BFA081BEA080C1A483BE9F7EC0A280C2A482BFA4868A7E6A595D52
6A7367838774898977898A7C82857B767C75646E6C57625D818272CBBFA7D0BFA3D2BEA3
D4BFA5D5BEA6D9C1A7D9C1A4DAC2A6DBC5AADBC6ADDAC7ADDAC7ABD8C3A8DAC5ADD8C4AC
D8C2ABD7C2ABD7C2ABD6C0ADD3BEA9CEBBA2D0BDA4CDB9A1C8B49DCAB59FC7B39BC7B29C
C3B29EDACEBDCCC0AFB9AC9DBCB1A2BFB7ACB7B0A5B0A69BC7C1B6D7D1CDC9C2BFC8C0BD
D7CFCDD1C5C2B8A19DC19B95B6817BAB635FA347479F33329F2423A42021A41C1CA31919
A2191C9E1C219B232A9F363DAB585EB78084C4A7AACFC5C8CFD1D3CAD2D6C5D0D5C9D2DB
CBD5DEC7D0D7C5CFD5C3CCD2C7CCCABAB89AA69D5DB3AB6ECBCBB2C6CACCC4CDD6BCC9D5
B2C1CCBBC9D4B7C3D06A76892A3C4E495F6D62748079888F7F898B9C9D9E88726700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00817154
837359887A60847B618B826A9990779F957CA2987FA39980A69C82A59A80A7997CAE9C7D
B19E7EB29F80B39F7FB59E7FB89E80BA9C7FBCA081BAA081B89E80B89F82B89F80B99D7D
BB9D7DBEA07EBEA07CBEA17EBEA17FBEA07CBE9E78C0A078C0A278BDA17B8E7C6455544B
5A635E676E686D736D6A726D67706B5D6A6654625F5B645AA7A38FCDBEA3D0BFA1D2C1A3
D2BFA3D4BFA4D7C2A7D8C2A5DCC4A9DCC5ABDAC6ADD7C5ABDCC9B0DAC5ACDBC6ADDAC7AE
D8C3ACD6C0A9D5BFA8D3BDA8D4BEA9D0BCA5CCBAA2CCB9A2CBB79FC9B59DC6B59CC4B29A
C2AE99C1B09DBFAF9BBDAC99BCAB98BDB4A4D6D0C6C7C0B9C4C0B7D4D5CED0CCC6B5A49D
C3A19CBC8480AD5B56A53733A1221DA31512A80E0FAC0C0EB20B0CB70C10B50B0DB70A10
B30A0EB30A10AE0910AD0C14A70F159D181D9A3337AA666BC8A4AAD4CBCECBD0D4CAD3DB
CAD5DCC9D4DAC5D0D5C5CED5C6CFD0CACCBCB6AE7CADA25CC7C190C9CBBCC1C9CDBAC5CF
B7C5CEB5C2CBBFCBD88C98A86573816577825C70787B8C9399A8ABA5ABAF96898300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001FDA145D913E7B6C53
7C6F5780765F847C668A846D958E779A927CA09882A19A80A49B82A89E85A99B82AC9B81
AD9C80AE9D81B09E80B29F81B4A080BAA384BAA183B89F80B59D7DB69E7CB49C77B49C77
B59C78BDA17FBA9C7ABB9C79BE9F7BBF9E79C09F76BE9D72BE9E6FBE9D70A58C6D5C5548
525855535E5D56636055615E515C59505B57545C52898776C4B7A0D0BCA2D2BFA1D2C0A3
D3BFA4D5BFA7D3BFA6D7C2A8D9C3A8D8C2A7DAC4ABD9C5ACDAC7AEDAC6AED6C4AED7C5AF
D8C4AED9C3ADD5BFA8D3BFA8D2BEA9CEBCA5CEBBA3CCB8A2CCB7A0CAB59EC7B59CC1B197
C1AE96BDAA95CAB8A6D2C1B0C2B1A1C3B7A8D6CFC5D3C8C1B2A49AC0ABA2C6A098B6726B
AB4740A42421AA1715AF0F10AF0A0CB2090AB4090AB4070BB6080AB7080AB70709BA080C
B7070AB3040AB3060AB5070AB2070AAD080DA90E149A111A972E37B2757AD1BBBFCECFD5
C8D1DAC7D1D9C4CFD5C6D1D7C4CFD2C4CDCBC2C3B0B1A87AA69A62BCBA95C0C6BCBEC7CC
B8C1C9B6C3CBB7C5CFA7B4C26978885C6E786D7F847F8C92929DA2A3A8ADACA6A21BD40F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00786951726953736C57
8C85748F8877857E6C8B8471958D7A9C9480A39984A49983A79C86A69A83A79A80AA9980
AB9A81B1A087AF9E82B2A184B3A184BCA88BBAA185B79E80B49B7BB39A77B19A73B29C75
B49D77B79C79BA9C78BA9A73BA9972BF9D76BF9D74BD9A6FBC9B69C0A06DBCA07589775C
5955464E564A555E536064597471647E76678E806CBDA990CBB599CFB99ED3BDA3D3BDA4
D3BDA5D4BCA4D3BDA5D5BFA6DAC3A9D8C4A8D8C4AADAC5ADDCC6AEDAC7AFD7C5ADD9C7AF
D6C3ABD6C1A9D6C2AAD4C1A9D0BEA6CDBDA3CDBCA2CBB9A0C9B49CC8B39CC8B49CC3AF97
C7B099C2AB97CCB9A8D4C4B4C8B7A8BCA899BCA899C1A497C69889BC7468AC433CA61E1B
AE1210B30D0BB50B0BB6090BB40608B5060BB30608B30607B40808B50808B50707B60608
B40406B60609B00406B30608B40608B00609AF060BAB070DA30B1295191DA25357C9ACB0
CDCDD3C6D0D9C5D0D9C5D0D6C3CED2C3CDD0C5CBC9C7C6B4A9A173A29D66C2C3A5C2C9C6
BEC6CCB5C0C9B7C3CDB3C1D03F5067293C505E727F82949C849096848B8E9894903DB229
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001CD81270684F6D6C5885877A
BDBDB6A7A59D868172918D7897917D9B9480A29A85A49B87A79D88A49880A89A80AA9B7F
AB9B80AFA084AF9F84B1A187B19F83B9A387B39B7DB59C7DB29978B59B76B49B73B49C74
B39C73B79E76BA9E73B99B6FBA9A6FBE9E75BB9870BD986CBD9968BF9D6CBF9E6EBA9C70
9E86637F70528D8165A08F74A99278B69D81C5A98AC8AC8ACCB293D0B99CD2BDA2D4BEA6
D3BDA4D4BFA4D3BEA3D5BFA7D8C2AADAC5ABD7C1A8DCC4ADD9C4AED9C7B2D4C4AFD4C5AF
D6C4AED4C2AAD5C3AAD2BFA6D2BEA6D0BCA4CEBAA1CCB89FCAB69EC8B49BC9B59CC7B39A
C5B098C9B29CC6AE9BC3AC99C2AB98C2A492C89C8AC68073B24B41A9231CB01410B30D0C
B90D0BB80B0BB6080AB5060BB6070CB5060BB40709B70A0BB30907B50B08B50907B50709
B6080AB4050AB00506AE0405B10707B10707AE0606AF060AAC060BA7090E951116954248
C5A6ACCDCBD2C8D0D6C4CFD5C1CCCFBFC8C4C4CBBFCBCCB3C4BF86A19949B7B278C7CAB7
C3CACCB7BFC6BAC4CDBBC6D35161733445575D7180697F8990A2A99FA9AE92918D3EB42D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF001BD711508939726F5C939788B5BFB7
C1C7C6B0B3AF86867A91907C94927D9B9782A09A87A29C88A19A84A49B81A89C82A99B80
A99B7EAC9E81AD9E83B2A186B19D7FB1997AB19779B09677B19774B49B74B19771B39A74
B39971B59870B49669BA9A69B79766BC9A6BC09A6EBE986BBD9968BE9C69BD9D6BBE9E6E
BE9D6FBE9F72BDA076BFA47CC3A67FC8A682C8A781C9AC83C9AF87CCB593D3BEA0D2BEA2
D1BDA2D3BEA5D4BEA7D5BEA6D7BFA8DAC2AAD8C1A8D7C4ACC9BCA8B1A8979F9789A29A8D
AEA89AC3BBA9CDC2ABD1C2A8CFBEA5D0BEA5CFBBA1CDB9A0CAB69DC9B69EC8B59DC7B39B
C6B19AC8B09CC7AC98C5A793CDA795CE9383BA5D51AA2924B31715BA0E0FBB0B0DBA090B
BB0A0AB8090AB9090BB50508B40608B50709B50909B60A0AB60909B70A09B80A0AB80A0B
B7090BB5060BB20509B20509AE0305AF0506B00607AD0305AC0408A9060CA3080D950F15
933E42C7A8ABCBCBCEC4CDD1C5CDCBAEAF9AAEA977B8AD62AFA339A79920A59C39C8C795
C5CBBDBEC7C9BCC5CDB7C0CA7A89926675816B7C857B8C948E9FA59CA9AEA8ABAB6A9C52
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004E863367604A6B685796998FB9C3BFBFCBCB
C2CCCDB8BCBB8A8B838D8D7B9795819D99869F9A87A19C89A09A83A39C82A49C82A89E83
A49679A99A7BAA997DAB9B7EAF9B7CB0997AAE9776A9916CAD946DB39872B59B76B09571
B3956FB7976DB9986AB69563B99863B99662BB9565BD9767BF9A68BE9C6AC1A070BF9F70
C09E6FC49F71C3A175C2A378C3A37AC6A57CC7A67EC9AB83C7AB84C8AE8CCFB698D2BCA0
D1BFA2CEBEA2D2BFA6D6BDA7D7BFA9DAC4ADD5C2AFB8AE9C8A8776908D7DA7A0939D958B
7C786F7C7C72B8B4A4CEC2ABCDBEA5CEBEA5CDBCA3CEBAA2CBB79ECAB59DC9B39DC7B29D
C7B19CCAAE9BCFA797D49E92CD7E73B03D35AF1B16BB1211BD0C0EBF0B0EBC0809BD090C
BA070ABB070CBB080BB70509B40608B30608B20707B40708B40408B6050AB7070AB7070A
B30507B10308B1070CB0040AB10509B20509AE0407AE0508AB0507AA0509A70409A4090C
931114984749D3BABACACECFC6CFCCC1C2AFB1A770AA9A3DA9991AA9980AA49511ABA33E
BDBE82C3CAAFBEC7BFB6C2C48A9AA63F55674D6877748E9891A4AA8893998C8E908A786D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00518633665F4B68655790918BBAC2C28FA0A4A9BBC1
C2CED2C4C8CB8B8D868D8E7F9696849C9A889D9A899E9C88A09B85A29C85A59C86AA9D86
A7977BAA9979AC9979B29E7FAF9B7CAD9978B19B79AE9975AE9874B19877B49B7AB29775
B49570BA9970B59467B89364B7925EB9945FBD9661BE9866C39F6EC5A172C3A073C19E71
C19F71C19F71C2A177C3A47DC6A780C7A780C8A881CCAD87CAAC87CCAF8DCDB394CEB69A
D0BDA0D0BFA2D4BFA6D6BDA7D9C0AAD6C0ACC3B3A57E796D999789B8B1A0C0B4A3C3B4A7
AFA49B74736D76776EC5BEACCFC0A9CFBFA6CFBFA5CDBBA1CDB89FCEB59FCCB39DCBB29C
CCAF9AD4A696D2837ABD5149B12923B71512BD0D0DC20B0FC0090DBE0A0DBD0B0BBA070A
BA070ABD080DBA070BB60609B40608B20608AF0507B3070BB1060AB20609B2070BB2080A
AE0909AB080AAC0A0EAB090EA9060AAE080DAE0708AD0508AB0608A80307A80307A80607
A1070B880D12A66668D1C6C7C5CFCEC3CDC7C3C5AFBAB481A89938A19009A69602A79A0C
A79F25B2AE55B7B985C3C9B4A9B3B13547513C56644F6975798F98A0AFB6A0A5A8897A72
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF001BD711665D476764548A8C85B4BABCB2BFC45A7178637D82
C1CFD3C8CCD09092908C8E829494859695869A98889D99869C9683A19A85A59B87A99B86
A6967DA89879AB9A7BAE9B7BA79472AB9975AA9775AE9C77AF9B77B19B79AF9676B09573
B49671B39369B69566B59260B99460B9935DBD9660BC9965BE9D69C3A172C5A377C5A277
C5A175C19E74C1A177C5A67EC5A880C7AA83C9AA86CCAE8AC9AB87CFB18FCBB091CDB596
CCB89AD2BEA2D3BEA6D5BFA7D8C1AAD6BFAF9C8F8475736BA4A299BCB7A8BEB5A5C2B8A9
B1AAA083847F5F6660AEAD9FCCBFABD1C0A7D0BDA4CFBBA3CEBAA3CDB7A1CFB6A1D1B29F
D8A595CF766CB7342CBD1F18C11510C30F0DC20D0BC1090BBF090BBC090BBA0909BA0A0A
B80809BA070AB70609B40607B30709B1070BAD080AAA090DA70C0DA00E0F9D13159D1C1F
9A242798282D95293092242B921B2097141B9D0E12A20C0FA5080BA70609A70405A90506
A604099B080F831C21BF9697C8CACAC1CECFC4CBCBC6C7B6ACA363A19018A99704AD9C04
AF9F08AC9F14A59A2CC0B96EB9B8886A70586C7A7568787C7180848F9DA09DA4A6A29793
1BD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004C873464645285887FA9AEAFBDC5CD909FA75C7076798C91
C6D1D7CBD2D68F95928B8F848F92849596889B97889F98869D96839F9683A29482A49582
A3947BA5977AA7987AA59476A79474B09B7BAE9978AC9771AE9970B09A72AD9671B49B78
B39671AF9167B59466B59361B7945FB7945EBB9460BF9965BE9B68C1A070C2A175C2A176
C19E74C09E74C4A379C5A57CC3A37AC5A57CC8A782CFAF8FCEB190CBAF8ECDB293D4BB9E
CEB99ED1BBA3D2BEA6D4C0A7D5C0A9D4C0AF897E7575736F93948FA9A89EAEAB9EAAA69A
9B9C94767E795B6760A2A496CDC1ADD0BEA7D0BEA7D1BFA8D2BEA9CEB6A2D5B2A1DDA094
C9635BB62621C21814C7130EC7110CC70F0CC50D0BC30B0BC00B0ABC0907BA0B09BA0A0A
B90909BC090CB60708B40A0AAF0F0DA40F0D9A16149B292B983E44924E58885665734E64
664E675C4A655A4B655F4F666E5568835B6B8D4F5A8C30398E141A9E0A10A5080BA9060B
A6040AA1040A920E128D3F42CFBDBDC5CBCFC2CBD2C2C9C5BEB990A69732A7930DA8970A
AE9E08AE9E04AA9A06B09F19A99C2977712B5F68536A7B7D889A9E8C979A848688968A84
3AAB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF001AD81262604C7D8378A1AAA9AEB8BCBCC6CEA3B0B7B1BEC4B9C4CA
C9D1D9CBD3D79EA4A28B8E859393849591839B93879D94859E95849E9582A0927FA39481
A39680A3947AA4957AA5957AA79478AF997AAE9676AB936EAD976DAD996FAA956EB39A77
B69B78B2936DB39366B2915FB3935DB5935DBA9561BD9765BF9C6BBE9D6EC09E72C3A076
C4A076C5A47BC5A67EC3A47DC4A47AC6A57BC9A881CBAC8ACBB190CBB190CBB293D1B89C
D3BAA2CFB8A0D6C0A8D2BEA5D6C1AAD8C2B08E83796F6F6E7D807F8A8F888C9189838B83
757E7B5F6F6A5C6960B0AF9FCFC2AED1BFACD1BEACD3C0ADD5BDAADAB4A3DF9C92C1504B
BA1F1DC61513C9120FC60D0AC60D0ACA110EC9100DC50C0EC20B0DBD0A0CB9090BB9090B
B80A0BB80D0DAE0D0DA31516A030329E4C5386566260496237335522295219234F1B2652
212E55303D633B496B3A4B6C32456838496C323C5B5A4D658856668D2F3A96121AA1090E
A5060AA305099E0A0D821316B88A8CC6C5C7C2CCD2C3CDCCC1C3A8A3974898891F645806
9E9312AC9E08AFA003AE9E04A696098D831E3D3F1E394A4D657B8494A2A8A5A8AA9A8F8D
3AAC2400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00655F47676C5E99A5A0ACB9BCB2BEC4BBC8CFBDCBD2C1CFD7C4D1D7
C8D1D7CCD2D5A7ADAB8A8C838E8E809995869A94869C95879D95859F95839E927FA0937E
A39781A3957DA3947BA5957BA7957AAC9478AA9172AB9570A8956BA9966BAC966EB09872
AC916DB0916CB19165B09360B1945FB3955FB89562BD9966BB9967C0A071C5A67AC7A67E
C7A57FC3A37DC3A681C6AA84C4A780C6A680C9AA85CBAE8CC9B18FCDB595CBB495D1B99D
D2B9A0CFB79ED3BDA4D4BFA7D6C0AAD7C1AFB4A4996A676362696867716F69737063706A
5E6D675B685F7F8678C4BEACD1C3AED4C3AFD6C3AFD7C1AEDFBBABDF9B8FBD4843BD1E1E
C91314CC1011CB0F0FCA0E0ECA0E0DCB0F0ECC100FC60C0DC30C0BBD0A0BBA0A0AB50C0A
AE0F0EA61D1EA53F42985B69674E6835355A16264E182C552F42665A6A89697289848595
9898A3969BA8A4AEBC94A6BA3451718CAFD16B8EA89EB3C98787998B6C7C954856921921
9F0A10A10409A0060A910D108D4346C6B8BCBFCACFC2CECFC5C9B3A59A5592832855490B
71680B988F0FACA20DAD9E06A797069D8F177B75346970636F7B807E898E98A1A3A7A6A4
47BE3800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0033AD225E60518D9790A9B6B7B3C1C8B7C5CDBAC9D1BECED6BDCED5BBCCD2
C5D3D8C9D2D5B3B8B88488818B8C809391849894889A94889F968AA095879E917FA2937E
A2937CA2927BA4967DA09177A39076AA9176AA8F72AD9573A8926CAA946BAE976FAC936D
AC9168AD9062B19160B2935FB39562B39462B69665BA9966BF9E6DC4A477C8AA82C8AA85
C5A583C6A785C3A684C4A886C7AB88C8AA88CBAD8DCBB092C9B091CAB495CAB699CEB99E
D2BCA2D0B8A0D2BCA4D5C1A9D5C2ABD6C2ADD5C1B0A6988C6C69616C6F69767B727D8276
7F827689887ABEB7A6D0C3B0D2C2AFD4C1B0D5BEAEDAB5A9E29C93C14A44C01E1CCE1517
D11114CD0F11CF1113CC0E0FCC0E10CE1012CC0C0FC80C0EC30C0CBD0E0CB2120FA81F1D
A9444898606F584A66232D56142855273C624D607776808C8C9196AEB1B4B5B9BCA9ABAD
CCCFD56471817A8D9E90A4BC0B284F2F547C7BA2BAA5C3D0C7D6DFC6C6D0B99EA79D565D
901A209E0A10A1060A99080D7F1B2093717BBFC5CFC3CCD2C3C6ADA49C4F8B7B1B6C5B13
7F731B4D4801959219A39B0DA19403A3940C978E2B8E92668A968C97A2A3869091888987
689B4E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00488234787E75A9B3B4B0BCC4B1BFC8B9C7D0BDCDD6BFD1DBAEC2C9B3C6CD
C3D4D9C6D1D6B8C1C28388848B8D82919185939185969286A0988DA09689A09586A19382
A2927FA4947DA3937BA29278A49277AB9378AB9174AF9576AC9472AB936EAD956DAB926A
AB9165AD9061B1915FB1915EB49562B49565B79767BC9C6ABD9D6DC1A175C6A67DC3A47E
C5A683C5A687C6A98AC6AA8BC7AD8CCBB090CBB094CAB196CCB498CAB498CDB89DCCB69C
D0BAA0CEB79DD2BEA4D3C2A9D5C2ABD7C2ADD9C4AED9C7B3C0B3A2B3AA9AB5AF9FB9B3A3
BFB6A5CEC2B0D3C4B3D6C6B6D7C6B6D5C1B2DDBAADE09B92BB453FC72422CF1716D01313
CF1111CF1111CF1110CD100ECB0F0ECD0F10CE0E13C90E0FBD100FAD1A19AB42449D6471
57486622305D162F5C32476A69738A8E919AB0B2B1C5C5C2ABACAACED1D2B3BBC28C959D
C6CED6556477384C61A9B9CB62758C4D678090ABBCB7CCD6C5D5DDCAD2DBD3D1D6C1A6AA
954A4F91151C9C070B9B070A820B117A444EAAABB6C2CBCEBDBD9DA49A3F958313826C0C
90801A4D46016261087471089B940FA19407A2961778721A696F3E8C9782ACB8B1A3A6A0
82756200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006F6D5EA3ACAAB2BEC3B5C1C9B6C4CBB8C6CEBBCBD5A7BBC480979FB3C8CF
BDD0D6C1CFD4C0C9CC868C898B8D848E90849392869491869D978C9A9285A197899F9383
9E917F9F927CA2967DA3967BA5967CA49278A99477AA9272AD9572AC946FAB926BAB9269
AB9065AC8E61AF8F5FB49463B29260B59462B69664B99968BE9D6EC0A074C0A279C2A680
C3A886C4A78BC5AA8EC5AA8DCAB092CBB394CBB295CAB197CCB49BCEB8A0CBB79DCCB79C
D4BFA3D0BBA0D0BCA2D4C0A7D6C1ABD7C4AED7C4AEDDC9B3D7C6B1D8C8B5D9C8B7D7C7B7
D7C6B6D8C7B6D7C8B6D7C8B8D6C2B4D9BAADE3A297BF4B44C2221DCD1614CF1311D01311
CF1211CE1111CC0F0ECC0F0DCC0F0DC90C0DC71212B81717B4383AAB6573675573253662
143261334D756D7C90A0A5A7CBC9C5B9B4B1C4C1BED1D0CFC6C2C5B8B1B3C9C3C7A29C9F
ACA4A2B3AEAFA5A8ACA1A7ACBAC7D25972886B89A1A4C0D2BAD0DCC7D4DDC9D1D8D1CED3
B89399882D34940E13990509900A0E7E3039897D87C2CCCDB6B895A5993CAA9715A58E07
A48F13645703554F0B4849086E6E0C968F0E9F93089B8F0C9C972887863B989B76A9AB9E
9D908400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF003AB62A92978EBAC7CBB2C2CAB5C4CDB3C3CCB4C5D09EB2BD7D949D81989EA0B5BC
82959CC2D0D8C5CED3868B8C8A8C859191869594879D998D9D988C9B93879B93859B9281
A09583A29584A09480A39881A59881A3937BA69377AC9576AF9577B09575AB906BAE936C
AB8E66AE8E63B09062B39464B59463B59363BA9568BD9B6DBD9C6FC0A076C5A882C2A988
C4AA8CC4AA8EC7AD92C6AC91CAB196CAB498C9B599CBB69BCBB89DCBB99ECCB89DCDB89D
D2BEA3D0BCA3D2BDA4D4BFA7D6C1ABD6C2ADD5C2ABDAC6ADD8C6AFD8C6B3D9C9B8D6C8B8
D7CAB8D5C6B4D4C5B2D4C2B2DABDB0E4AA9FC3564EBF221CCD1812D0140FCF100CCF110E
CF1210CE100FCC0F0FCD1010C80E0DC21515B72629B557647F5A743138651430612B4971
677B92AFB6BCB3B2AEB0ACA1D7D1C8D3C8C4B3A09EC9AAAABF9595B27D7DAD7473AC7270
B17B74C0938EC8ADAC8A8083B8BFCA2239590F2F58799AB4ABC3D1C7D5DDC9D3D9CDD3D8
CFC1C7A36B7185171F99090F970B0E81212969505CBFCAD0C1C5B5AEA467A9972AA8930C
A8930A928006867A135049046563116965069B910CA09305A6980BA7991C998F37908A5F
9588731CD40D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0069A454B6BDBDBBCAD4AFC2CCB7C8D3B4C6D19CB1BC76909A79939B8BA2A88CA1A6
A7B7BDC7D2DAC8D0D88F9396888B8690908798978B9F9B8F9B968A9891849D95869E9584
A29886A59A88A39885A29782A0937EA1927AA59479AA9576AB9273AE9471AD906AAE9069
B09268AE8F62B09062B29263B49364B69467B8966ABB996FBD9C73C6A681C8AA89C1A78A
C5AA90C4AA90C5AC90C8B093C7AF94CAB39BC8B298CAB499CDBA9CC9B89AC9B698CDB89B
D3BEA2D2BDA3D4BEA7D4BEA7D6C1ABD6C1ABD8C4ACDAC6AEDAC7B0D7C7B1D5C7B4D4C6B3
D5C6B2D6C5B1D3C2AED6BFADE5B5A9CE6C63BD2720CF1A15D51511D4170ED3150ED1110F
CE110FCE1210C8100EC31311BA1A19B74146AC7084554D791B3367213E6B5C6F8A92979F
A2A09BC3BDB4C4B8ADAC998EBA9B92BD8B87B16663A84344A52D319F1E219B17179B1417
9D1A1A9920219D3B3DAB686ABC9DA07A7988364762748CA1B6CBD4C8D5DCC8D1D8CAD2DA
D3D2D7BF9FA4852E38930C1499080D83171F603F4DA9B7C2BBC7C8C6C6B3ADA667A39327
A6930BA18E04A7971283760A5C55064A46019891139B90059D9104A69A0AA39618B0A351
A3936B3AAA1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A09E8DBFCBD0B4C4D1B2C3D2B1C2D1A2B4C2768E9B738F9A7C99A36A868D92A9AD
BECED4C7D2DBCAD2DA969CA0888B878F908696958999978A9F9A8E9C95889D9486A09787
9F9584A19886A39986A0947FA0937C9F9078A39379A89479AB9376AA9070A98E69AE9269
AD8F64AF9063B09063B39265B59368B8956BB49369BF9F76BD9F78C0A27DC2A585BFA387
C3A98EC1A98DC5AD90C4AE90C9B498C7B297CAB499C9B298CAB59ACAB69BCBB79DCDB9A0
D3BEA5D4BEA6D5BDA7D7BEA8D6BFA9D6C0ABD6C0ABD7C2ACDBC6B0D8C6B0D7C5AFD8C5AE
D6C4ADD8C6B0D8C2AEE2BBACDB8A83BB312DCB1C15D41911D41710D21510D31410CF110F
CA100FC61311B81917B12E2FB85C678262802C3B6E1B3C733E5B828791A0A6A19FAD9E94
B19D8FB59A8DBF948AB6716AAB4A46A22826A51515B31214B20B0FB0090EAC0708AB060A
AB0709AA080CA50B0F9813159B3E3BCA9E9FA5A3B15A7288B1CBDBC1D1DAC7D1D8C8D1DA
CBD1D9CFC2C995565F89121C97080F851017693C47919CA9B4C6CFBAC3C4BABCA7AAA25F
A3941FAC9B0BAE9F06A798099185106E6404988E10817707837B079E9508A49809A2941D
B6A55849BB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4A298BAC6CDB0BFCDB0C1D1A6B9C9798F9E6E89954A69724361686A8489A6BAC1
BFCFD6C5D0D8C8D1D89EA5A9878A86918F869593879795899A978B9992869C92869D9183
A19484A19584A29683A29480A1917C9F8F77A29179A59278A99274A99070AB906CAD8E66
AD8D61B08F64B19067B09168B6956CB5946AB3946ABB9E76BA9D77BEA07BC0A180C3A487
C6A98EC6AC91C5AB90C3AB8FC3AE93C8B398CAB39ACCB49CCDB79FCBB59DCBB69ECDB9A1
D1BCA5D3BEA6D2BCA5D2BCA4D8BFAAD8C1ACD5C0ABD7C3ABD8C4ABD6C3ABD7C5AED6C5AE
D8C7B0DAC8B2E0C3B0E8AA9DB8423BC6201CD11811D41811D4160FD51511D31310CC130F
C2140FB3211FB95860A5738859527A1B396F264B7C7086A2A4A7AAB3A99EB7A395BC9E8F
C39386BE746BAB413DA71F1EAD1112B30C0EB7090BB9080BB70609B4060AAF0405B00607
B10708AF0506B2070BAC080B9E0D109A353B956F811725465B7C97BDD4E2C5D1DAC7D0D9
C8D0D9D1CCD5AB7F88841E28950B13870B13753B48717786B4C9D3B7C5CCBDC4C3C2C0A5
A59D4DA79917AD9D04AA9B04A596089B8E06A0920B7D700C5F59008C880DA1970BA29509
A2911B50C11500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0093938BB7C4CDB0BDCDAABCCC849BA8718C984C6B742142466F8B8EA3B9BEB9CBD3
BACCD5B7C9D0C6D3D7A8B1B3868B8790918994948A95958B9592899A948A9890859A9183
9F95859C9382A39786A19482A29582A0917BA29278A79377AA9374A88F6FA88D69AB8F65
AD9063AF8F65B2926CAE906AB3966EB0956AB4986DBDA07ABC9E7CBA9C7BC1A283C6A78A
C7A98EC6AA92C8AD95C4AB93C4AE96C9B49BCDB79FCCB7A0CBB79FC9B59CCEBBA2CDBCA1
CEBDA2D0BDA4D1BDA4D4C1A7D6C3ABD4C1ABD4C1A8D7C3AAD5C1A9D9C6AEDAC9B2DACAB3
D8C8B2DBC6B3E9BEADCB6C61BF2821CF1914D21511D41711D5170FD5160FD1150EC41811
B62D29BB6D756B5B7D243769173B703D5D8590A0AEB2B0AEBAAE9FBAA893C3A290C98D80
B04F47A82220B11414B50B0DB6080ABA080BBC080BBA060BB70509B40608AE0304B00305
B00607B10406B00607B10507AE080B980A13AA57625C5067415A73B1C8D5C4D1D8C8D1DA
C8D2DBCFD1D9BEA5AC802D36900E16890A117C3A475F6372B0C6D2B5C4CDC1CDD1C5CBC6
BBB98AA5982DAC9D0DA89803A59602A09102A3920880730D5F5804615F078784119E960A
9F8F0A4CBE0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
73A0458B8C84B5C2CAB2C3D195AAB8728B985C798321404857767B4D696FA7BEC690A7B0
7B949B9EB4B9C6D5D9AFB9BB858D8A8F938C92938A96948B98948C9A968C9994889A9485
9C95839E9684A39586A39383A39381A0917BA6967CA9957AA89274AA9373A78F6AA88F68
AA8F65AD8E65AF8F68AF916AB1976FB3966FB99B76BA9D7ABB9E7DBB9E7FBFA284C4A789
C7AB8FC9AE93C6AC92C4AC93C5AF97C8B39ACBB79FCBB69FCEB7A1CDB69ECEB8A0D1BDA4
CFBEA4D0BFA6D1BFA7D2C0A8D3C0AAD6C2ACD6C2AAD8C4ACD9C6AFD9C7B0DCCAB3DBCAB6
D8C7B4DFC0B1E1998FB8362ECD201AD51A13D41610D6170FD5170ED0160DC61C14BC3C38
B474814C4C70183A6C244877617997A4A9ADBAB1A7C1B0A3C2AA9ACAA190C57C6FAC3A34
AF1917B70E0EBD0D0DB8080AB7060BBA070BBB070BB90409B70508B50609B00307B10408
B3060AB20509B10408B20509AE0508A6090D972B32A2839572869F9BB6C6C3D4DCC5D2DA
C4D2D9CAD3DAC3B6BC86414A8D111A8C0A118038454F5161B0C8D5B4C4CCC0CFD5C4CECF
BEC1A4AFA956A99B20A8970BA89805A29200A4940593850C5B53034848054B4D01908C13
9F910B92740A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AA8F688B8E87B3C3CAAABFCD7890A064808D28465154727B4B69705A767E87A0A8516A70
92AAAFBDCFD4C5D1D5B9C2C4838A898C908A94958C98978D97958999968A9C978A9B9385
9B94849D95869F93849D907EA2937DA4947CA3937AA5947AA49174A69271A48F6AA9926B
A88E65AE9065B2916AAE9069B2956EB79975BB9E7CB69C7BB79C7DBBA083BDA285C3A88A
C3AB8CC2AA8EC7AF95C5AD95C1A990C5AF96C9B39CCAB49DCBB49BD0B69DCEB69ECDB6A0
D0BCA8D0BEA8CFBDA7D3C1ABD6C3AFD6C2ADD6C3ADD4C2ACD8C7B0D7C6AED8C7B1D9C7B4
DCC3B3EBB6ABC35852C3251FD31D15D61A13D51811D2150DD0180FC41E15C24848AD778A
3B4570183E724A698E8E9EAEB1B0B0BFB0A4C5B1A1CAAEA1D09E93BF655DAB2924B11411
B70C0BBC0B0BBC0A0AB9080AB60709B60609B6050ABC070CB9070BB6070BAF0509B0060A
AE0609B3070BB10407B20507AE0406AA070A93181F7949680F1F4D2D4E73B6D0E0C2D3DB
C4D3DACAD3DCC6BDC592566089121D8B0912843A483F3F52AEC8D6B8CAD3BECCD4C3D0D6
C5CBC1BABA92C3BB6CAD9C29A7950AA79603A29301998B048F8514564E02514E07646204
979011947E1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AD926C919290A9B8C68FA5B66A8798304F5D45646E4C6B75506F76567177A4B8BFA3B5BD
9CB3BB889FA6C5D3D8C0C9CC878E8E8C8F8D90918C93928B98958D98948A9A95899A9486
9993839E96869C927F9F927CA0917AA4967CA2947AA4957BA69578A69372A6916EAA916D
AE916BAE9167B1946BAD9069B39772B69A77BCA281B79D7EBAA081BEA388C5AA90C0A789
C4AB8EC3AA90C6B095C7B095C3AB90C6AE92C6AE95C7B199C9B49BCEB69CCEB69DD0B9A3
D0BAA4D2BEA6D0BEA6D2C1A8D4C3ABD7C5AFD6C4AFD7C6B2D6C5AFD6C6AFD7C6B0D8C3B0
E2BDAEDE8D84B93028CF2017D61A13D51612D11411CF1711C41F17C14D4CA97B92344273
193F735D7998A8AEB4BBB3AAC1B1A3C4AE9DCBAD9ED6A095C05E57AD1E1BB6100FBB0B0D
BA0A0CBB080BBC090CBA090CB50608B5080AB40709B4090CAF0A0EA90D119E0E109E0E11
A40B0FAC070CAF0509B00609AF0508AB060A96141C804C681525531B3F65A3C2D4C0D2DB
C4D2DAC9D2DCCDC4CF97606C8715208C0A11863A4736374CA9C5D5B8CAD5BCCAD5C1CFD9
BECCD0C8D0C9C8C6A3B0A652A99A1BA39305A292019E90039D9208978D0F776C0C5F5700
8C840F98851400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A588608F8E8CA1B0BD8097A74C6A783655604D6B744E6C7457747986A0A791A6AEA2B6BF
778F976A8288C2D1D9C5CDD48B91938E939090928D95958F9B97929C9590978F87979285
9A97879B96849D95829E927FA0927CA3947DA1947BA2957BA59579A59272A79070AD9172
AF9472B19772AF936DAF936DB49774B79C79B59C7AB8A081B9A485B8A487BDA98CC0A98D
C5AD92C5AD95C5AD94C5AC92C7AD94C6AD94C9B198C6AF98C7B39ACAB69CCEB89FCFB9A1
CEBAA2D2BDA8D1BEA7D0BFA6D5C4AAD3C1A9D3C1ACD5C3B0D6C5B0D5C5ACD6C4ACDFC3AF
EAB5A5C0554AC4261BD51E14D51812D31614D11713C31B15BF49499E72893245761C457A
6B87A5AEB3B7BFB5A9C5B4A2C5B09EC9AB9AD1988DBD574FB4201CBF1212BD0B0BBC090C
BB080CBC080BBA070BB8090CB40A0AAE0B0CA40E0FA11E20A0363D9D4C568F505C92515C
9E3B429C0F14AD070CAE0309AE0407A9080B9820266F475F47618585ADCC8DADC1BED4DE
C4D3DAC8D1DBC7C3CC98637086141F8E0C14883A49332F47A8C2D5BACBD8BAC8D3BDCBD4
BECFD6C3D0D5BCC0AFABA267B1A43CA39415A59509A192039D91029D8E049F900E796D07
847A0A8F7E1042B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A07F5593918D97A6B1849CAA31505C4B6C74496A6D4D6B6E88A5AA546E7591A8B1899FA8
ACC4CB81969DC0D1D7C6D0D58C9596878E8B8F928D95958F99958E9D968F9990899A9286
9C95869C96859C95839B92809D927EA2967EA2957CA3957BA19176A69376A89276AC9377
AF9577B19979B29878B29876B29976B69F7AB7A17DBDA686BDA588BAA68BB7A289C5B095
C5AE93BFA98EC4AE93C5AC92C9AF94C9B094CBB39ACBB49DCDB79FCCB69DCBB39BCDB6A0
D0BBA7CEBCA7D1BFA8D2C0A7D1C0A7D2C0AAD3C0ADD4C1AFD6C4AFD6C4ABD9C4ACE1C0AD
E09789B73127CF1F15DB1D12D4170DD21712C61B16BC4140A7778D304373214D7F728EAA
B2B4B7C0B4A8C4B3A2C4B19ECAAF9CD39D90B8544EB31E1BC31413C40E10BE0A0CBB080C
BA0A0DBA080BB80B0CAE0D0DA214149D2E329E525E8359705245662F315A1D2752242347
81526696242CA9090FAE030AAF080A9D090AA040474A3653415F89416A9422476BB1CFE1
C2D4DBC7D3DBC8C4CE98637084121D8C0B14893B4B302C45A7C1D5B8CDD8B1C0C9BECCD4
C3D2D9C0CDD5BBC2C1B9B89EA7A269B0A652A094259E910D9C8D039E8C02A69608A19309
9B8D0D86720641B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
977141A299908F99A47C909E4C66714C6B7048686B7D9C9F506E728DA7AEADC6CE69868F
74909997B0B6C2D3DAC3D0D6959FA1878F8B90938D96978F98968E98948A969084999183
9791819A95859A94849990809D9582A19784A398839C9178A1957AA3947AA8957CAD987D
B0977AB29979B2997AB29A7AB79F7FB69D7DBCA584BBA685BBA688BBA88BBDA88EC4AE95
C5AD93C3AC92C5B095C4AE92CAB296CAB297C8B299C9B39BCBB59DC9B39BCAB39CCDB59F
CFB9A3CFBAA5D0BBA5CFBBA3D2BDA7D2BFA9D3C1ABD3C1AAD8C5ADD6C2A9DAC4ADE8BDAC
C7675CC52921D61C17DA1B14D51911C91B13BA3532B47B8B3847751A477B7795B2B7BBBB
C2B6A8C6B5A6C6B2A4CBAFA1D6A899BB5D54AE201CC31514C91211C30C0DC00C0FBA070A
B80909B60D0BAB1714A8393B9E5C696B536E313761152B5D193260435980606E8C7B7186
A36874981D24AA080CB0050BA9070A98181A985A6A2023453F5C816280A11737589BB8D0
BED2DDC8D4DCC8C1CD985E6D85101C8C0A13893E502A27439FBBD0B1C6D2B8CAD1B7C8CF
C0D2D8BAC9D2C1CDD4C2CBCABFC4B9BDBEA4A8A56E9B9234988B129E8F07A19203A39301
A7990F8B790621D90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
9A713CB5AA9C848E9597A9B5556D774E6A6F6F8B8F5C787C77939B9CB8C35F7C857D9AA0
809CA2607C81A3BABFC0D0D49DA8A9868E8B8D908A95958E92928A908F86969287958E80
9993839A94849D97879B94829E9784A29988A49B89A09681A69982A4957CAB987FAD987E
B19A7AAE9773AD9774AE9979B6A081BBA384BBA283BCA687B8A586B9A78ABDAB90C3AF95
C0AA8FC8AF95C7AF96C3AE91C7B295C6B195C4B096C7B39AC9B49CC9B29CCBB59ECCB69F
CDB8A1CDB9A5CDBBA5CFBDA5D0BFA6D2C0A9CFC0A9D0C0A9D7C5ADD6C3ACDBC1AEE9AFA0
B84039CC221ED31813D71B14D21F16BD2C25C276824C50771B477B6083A5B6BDC3C6BCB2
C7B5A7C8B5A5CDB1A2DAABA0C5766DAB2520BD1513C5100FC70F0FC20B0EBD090CBC0A0D
B50909B3201CB6555679576D2D3660122D5F203D6A5369888691A1C2C3CDCDC1C7B28486
A13D3EA20F11AD080AAB080B9A1013A24D594F3D5D122C556C8CAAB4CCDC9FB8CBA1BED2
BDD5DFC9D4DDC4BAC795596486121A890A12863E50292A459FBFD1B0C8D2BAC9D2BDCCD5
BFD0D8BFCDD6C2CFD7BFCBD3B8C3C9B7BFC2B7BEB2A7A9818A8838928A1D9E9213A3940A
A3950E7F6E0245B90C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4EBB24B5A7957E868BA0B2BB526B7264818669848970899091ADB54D6D76617F87A1BDC3
758F968AA3A88EA2A6C4D1D6A9B3B6848E8B8E938C97969192908B9290899692888E897D
9592839390819995869B95859C96859F9886A19885A29783A59882A89880AB977FAD957C
B29B7BB09978B19B7BB29D81B49E82BAA285B9A084BAA487B8A585BCA889BEA98DC4AF94
C5AD93C6AC92C3AA8FC2AD90C4AF94C5B095C5B096C7B199C8B29BCAB59ECAB69DCBB99F
C8B79ECCBAA2CEBCA4CBBAA1CFBEA5D1C0AAD0C1ADD2C2ADD4C3ABD1C0A8DDC0ABDB8F82
BA2E25D21F19D51812D51C15C2231BCA656A7663841A3F734E739AADB8C1C7BEB5CEBDAF
C9B6A7C8B4A3D4AEA1D18A82AA3531B91716C3100FC71012C60E0EC10A0CBE0B0EBA090C
B60A0BB82B2AAF5C653C2A4A2839615668858E96A3C6C5C7B3A6A3BC9F9EB983819E3C3B
A01214AB080CAA090B9B1213A04B54634B670D21513D649084AAC795B4C67EA1B53A617B
B4D6E5C7D3DEC1B6BF905259861116860B1083414F282E45A2C2D2B1C6D1B9C6D0C1CEDA
BCCCD6BFCDD6BECCD5BACAD2B1BFC8B3BDC7B4BEC4B1BBB7869178999F6FA2A1569C9328
988D0F85790864960E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB91FAD9B847D8487A5B6BF5B727A7B979D5B757C99B4BD4C6A725C7B8188A4AA8EA8B0
98B1BC879EA79CAFB6C4D0D6B2BBBF808B88868D868B8C888D8D8990908996948A8C8A7D
9390829893849892829893829C98859E99869F9885A49B86A89A84AA9982AF9A82B09980
B19C7FB29E7FB4A185B39F85B6A286BAA186BCA48AB8A489B8A487B7A486BFAB8FC6AF97
C4AC93C3AB91C2AC90C3AE92C4AE91C7AF95C5AE96C6B199C6B29AC7B49BC9B99DC9BA9D
CABA9FCBB9A1CFBDA5CEBCA4CEBBA4D0BDA8D1BFABD4C2ACD8C5ADD6C1AAE4BCAAC96B5F
C32721D31B14D71B14CD1E16C24342A67A92273F70385D8AA9B3C4C8BBB5CEBAACD0BBAC
CCB9A7C8B2A0D69F92A7463FB01F1DC21312C8100EC60E0EC31011BC0F11B41012B50D11
B70C0FAE0E10A82B2EA5626A9A8689A29C96AA9F94B59F95BC938CB66D699E2E2DA31211
A80907A60B0A9815179D4B565D48631325560B2A5C7595B82C4B6A1F3E5D6B8DA71E425D
A1C0D4C6D2DFBBAEB9884650891319840B118545562A324AA4C3D5B2C6D1AEBCC5BECBD6
B8C8D2B9CAD4BBCCD4B8C6CFAFBCC4B5BFC9B3BEC8B1BEC67C8F93778A8394A487A1A767
9B962F978E158D7C1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B718AB9374818784A8B8BF7C919B60788290ABB6607C854F6C7288A2A6A1BBC3718E99
5976807D959CBCCCD3C3CDD3B6BEC27B8381828783868883888A828D8A83929185939486
9493849895859894849B9587A19A8B9F9887A09986A49B88A89C87AA9A83AC9A81AF9B81
B19D82B3A086B29E84B39E83B7A086B8A088B8A28ABBA68AB8A084BAA588BDA78CC0AA92
BFA991C0AC91C1AC91C1AD92C0AB91C4AD96C4AE97C4AF98C6B39BC8B69DC8B79DC9B89E
CDBAA2CDB8A2CFBBA5D0BEA5CFBEA5D1BEA6D5C1AAD3C0A8D7C5AED6C0ABE8B8A6BA4C42
C9241DD71D14D31E14C02924CC7D8A4C4F772849799399B4D6B7B8DDADA3DBAC9FD9B3A6
CEB4A3D0AE9FC87970A42723BE1A1AC91112C50E0EBE100FB01D1CB23B3EAF494FA53239
A4181AAF1010AE1111A32925C88578B89785B79584BA8075A84A44A01E1BA9100EAA0B08
A20D0B97222493505C4C3E611027561837673C54748593A291A0AE667B8F9BB2C19FB9C9
AAC4D4C5D2E0B8A8B4833C468B1119850C157F45572C3752A9C7D9BBCBD8BAC7D0BDC9D5
BCCAD5BAC8D5BBCCD6BCCAD5B3C0C9B3BFCBB2BFCAAFBDCB5C707F293C41637364778361
8C934E9592289B8D1A40B20500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A68A62858B82A6B7BE8498A27E95A274909B48666F779197A6BDC55B757E7F99A0
9BB2B9BACED6BCCED5C3CED3BCC5C77B81808184808687808A8A808C8A7E8D8C7F959486
9291839693849B97889E97899E97899F9A88A29C89A59D8AA79C8BA99B89AC9A88B29D88
B09C84B29E85B39E84B49E82BCA38AB69F87B9A289BCA58AB7A286B9A489BDA98DBEAA90
C1AC94C1AC93BFAB90C0AC90C3AB93C7AD98C9AF9AC6B199C5B29AC7B59DC8B69ECAB8A1
CBB9A2CDBBA4CEBBA4D0BCA4D3BFA7D3BFA7D6C1ABD6C3ADD7C5B0D8C0ACECB2A3B43B2F
CF231AD41B11CB2118C54D50916C863945728980A2C0818CB84F4FB83C3AB6433ED38379
D9AC9FDCACA0B5524EB1201FC41615CA1110C31412B62B2AB2636D654C6946436270576C
AC646AA12426AF1011A9100FAF3830D37C71B65C54A22B27A51413AD0E0DAA0D0B99110E
97343885566B3030570D295A23456D92ACC4C1CFDBA5B0B6BEC9D1AEC2D07893A6A1C2D7
7093A6C1D4E3AE9CA780323A8C0E15820C157847572A3B54A6C4D6B7C8D4BCC9D4BECAD5
BECCD7C0CEDBBFCFD9BACBD5B3C1CAAFBEC9AABBC5ADBECC94A6B662737D88948F8F998C
8F977696944A9B8D2448BB0D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4885B93978D9BADB2879BA593ACB845656E6E8C9396B2BA58737E536F7692ACB2
A2BCC3A2BDC77C939BBCCBD0C3C9CD8084867E817D80817A86867E8D8C828C897D969186
9994889995889895869E988AA0998B9F9A89A39D8CA59F8EABA092AE9F93B4A193B39F8C
B5A088B6A089B59E86BAA28ABCA38DB9A18AB8A288B9A489B8A288BBA58CBDA88DC3AE93
C4B098C4B098BFAA92C2AC94C4AC95C7AD98C9B09BC7B29CC5B39CC7B59EC8B49EC9B49F
CEB9A4CCB9A2CEBCA5D1BFA9D1BFA9D0BEA9D2C0ACD5C3AFD4C3AFD7BDAAE7A899B13127
CF1F18D21C14BD231FD17882684E69A285A4B2596BB6282EC51E1FCA1C1AC11E1AAD322E
E19F99E0A8A4A9403EB51D1CC61412C81312BB1D1CC06069514062183165324D74707484
B18F90BF6664A21614B00C0AAE0E0DB11C1CAB1313AE0E10AC0B0CA3100F9A2426924852
59415D17235010325D557B9AACC6D6ADBCC3C4D0D896A7B193A6B1667E940B2B4C4B708E
41667DBBCFE1A8909D7F2833900E15800E1574495B31465EAFCEDDB5C8D5BBCBD8C0CCD9
C0CCD8C1CEDBC0CED9C0CED9BDC9D5B1C1CBACBEC8AABFCCA1BACA8FA8BB8DA3AFA1B3B6
B1BEB5A6A881978D404CC11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A584539E9D9193A0A7ACBFCB66808C5A798190AEB663828B4F6E7669848B7E989F
66838A59767D99AFB6B9C8CEC0C9CC838A8C797C7980817B83837E8B8B838F8D83928E82
9B97889D988C9A96899F9B8CA39C8CA69E8FB0A699B0A597B1A497B3A399B5A496B9A796
B6A590B7A38EB7A18AB69F87B9A38CBAA48CB49F87B8A58BB6A38AB8A58CBCA88FBBA88F
C3B199C3B098C1AB93C5AD95C2AB94C3AC96C6AD98C7B09BC6B19CC7B19EC9B49FCAB6A0
CCB6A0CDB9A1CDBAA3D1BEAAD1BEABD2C0ADD0BEAAD5C3AFD5C2AEDABEABE4A495B43329
CD1D15D31F18C03435BA73829D738AB55E70B9252DCD191DD01718CE1614C71A15AD2E2C
AF757BB890989F4244B2211FBF1313C30F11B3191ABB6270443354535B7CA19CA8BBA09D
C9978ED37871A71F1AB30B0CB7090BB80A0DB40D0CA90F0DA02221A04C537A526A31315A
0F245717335E4C6880A7BCC5C0CED19EA7AB9FAAB0495D6A5F748296A9B8486479628096
A3BECDBFCAD6A285907C1F29930E1582121B6A41533E536CB2D0E0BACBD7BBCCD8BECCD9
BFCCD8BFCAD6BECAD6BECAD7C0CFDCB2C2CFAEC2CCACC0CD738DA22F4F6A305067587480
8094979AA29499966F96845400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A47E47A7A1918C999E97ADB75C77818BA7B172909B496A7167888D47666A688488
6C858A97AFB68EA4ACB0C0C6BEC9CD899395757C797D7F7983827D8A89838A8A80929084
9C988C9F9A8F9F9B90A59F93ACA697ACA596B2A79AB3A89BB1A698B5A89AB5A597B2A291
AE9E8CB19F8BB39F8AB29E87B8A48BB7A388B8A489BCA88EBAA68CB7A489BBA88DBBA78F
C0AB95C1AC94BFA891C2AA93C3AD95C2AE96C7B099C9B19BC5AF98C7B29BC9B49ECBB6A2
D0BBA8D0BBA6D1BDA8D0BFA8CEBEA8D1C1ADD0BFADD6C5B1D5C2ADD9BFA9E6A999B0362A
CD2118D11F18CA4443B66874CF8391B12F36CC1D1FD31616D21615CD1613BC1C17B65158
69516B69637EA7656FA42629B91819C41113BC1215BB353EB55C69BB757DC07572B75A53
AD3C34AC201CB10F0EB80B0DB9090CB40C0BAC1F199B3936774751453E5E18295B132B5E
3A4D7079808F97989593938DB8BBB9B5B9B8A9B0B0C0CDD2ABBCC3ABBBC4B5CDDB89A6BA
9FBCCDBBC6D49D7C867C1A21910C118618205F3A4E4A5F79B5D0E1B7CAD2BBC9D2BBCBD8
BDCDD8C0CDD7C0CDD9C0CFDABFCFDCB7C9D7AEC2CDAFC1CE758B9C45617645637668818E
85969B828B888A8C80887E6C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00789B31A59B8684929694A8B2778F9A8DA9B649677360828847696C5D7D7E7D989B
A0B7BD8FA8B14760698CA0A5BECACE97A0A3757C787B7C7782827A84847C89887F8E8C81
969287A09992A39C94AAA199AAA298ADA59BAFA599B3A79BB2A69AB4A89AB5A698B1A190
B2A08EB39F8DB39E8AB59F89B8A28AB9A48BB7A38BBAA58DB7A289B9A48ABDA88FBCA690
BCA690BDA891C0A892C2A993C2AB94C5AF97C4AE96C6B099C6B09AC8B39CC7B59DC9B8A1
CCBBA4CDBBA4CDBBA5D0BEA9CEBDAAD0BFACCFBEAAD5C4AED3C1A9D7C2AAE7B6A4B1453A
C9251FD41F1BC72C2AF68084E1686BC22423D31C18D31815CE1714C11C16B43C3C9D6F84
2A3C655B708DC6A5AAAB5753A72824BA1817BE1212BC1215B4171BB21C1EAD1918B01816
B01411B41410B40F0DB80D0EB60A0BAB100DB54E4E5430421C2043192852414D737A748B
9B858BAB8B85B59288AF928BCEBFBCD6CFCFB7B8B8C2CBCFA5B6C17B919F8FAABD193A5A
3053737C8B9E96707B7C141B8F0A10841B2658384F526984B2D0E0B8CBD5BCCAD3BACBD8
BCCED9BDCED6BCCDD5BCCDD7BFD2DCB5C8D6ADC0CEB1C3D1A1B6C46B869799B5C294ACB6
A4B6BBAEB9BCA5ACAB8F8B862A9F1900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004CB81CA99A807E898AA1B5BE92A9B457737E5D7B845271765D7C8169888C425F66
839EA72D4951718B928A9CA0BAC5C9A2A9AD7176767B7B7780807A81817888877D8E8B80
938F859D9991A29D97A6A098ACA59DABA299AEA498B1A598AEA495ACA392AEA491B0A491
B1A28EB09F8BB39E8BB29D87B4A088B9A58CB7A38AB7A389BAA58ABDA58CBFA78FC2AC94
BDA992BFAA94C1A993C3AA93C2AB94C2AC95C5B099C5B098C5AF97C8B39BC9B69EC9B8A0
C8B8A0CABAA0CABAA1CDBDA4CCBCA4D0BFA9D4C1ABD2BFA7D0C0A7D2C2ACE1C0ADD18476
B93028CF231CCF211CCE2928D02A2BCF1D1AD21D17CC1F18BF261FBC4E4FAB7D92364673
1F4777889FB3C3B7B1D6AEA1C27C70AA3930AE1F1AB71A17BA1918B51614B11816A71715
A5201FA92D2BC03D3AAB1211B40D0DA51110A95057381C3643355386637AB07582A45056
9C3839982D2D9A2D2D9C363B9E4E54B37E82B6999AA19A9B65727C344C5B8CA2B44A637E
33516EABB4C68D5E667F1117900A10841E2951374D5F7892B6D2E1BACCD5BDCBD5B6C7D4
BBCED8B9CCD4B7C9D4BACCD8BDCFDBB7C9D7B3C6D2B8C9D6AFC3D32D495F47677B5D7889
7A919B90A1A89EABAEA9ACAC57443600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004AB417B29D81808788AABCC57E95A057737B5B788059767D71909637575C88A2A9
778E97445E6444595CA6B3B6BAC4C5A8B1B37175767A7C797F807A83837B89877D8D8B7F
928F839D998EA19D94A5A199ADA8A2A8A198ACA397B2A798AEA292A99F8EAEA492B3A795
B3A590B1A28EAE9D8AB09C85B5A188BAA48CB7A189B8A38BBCA78FBDA58EC3A993C4AC96
BEA892C0AA95C2AA94C3AC94C2AA93C2AB97C5AF9AC5AD97C8AF99CAB39CCAB49DC8B59D
C9B79FC9B8A0CCBCA2CEBEA4CEBEA4D0C0A7D4C1A9D3C0A7D1C0A7D2C3AED9C4B2E8BCAC
D27C6FBA382CC62820CA251FC6221DC2231CBC2E25BD4E4ABC7880887693304B7A1D4A7C
6888A6B2BABDC2B9ABC9B6A6CEB1A1D2A090C17B6FB25954AD4F4FAB4F54A5565CA2646E
9165767B5668BD78809D1D1FAF0C0FA30C0BD06367AC5C68A44653A02731A3161DA91015
A80A0EA8090EA8090FA60A129E0C14911319923437A67272C6BABDACB8C19CADB7B8CDDB
A1B6CA989AA9875057871317910A0E85212C4A344969829AB7D1DFBECEDABECCD6B4C6D3
B4CAD6B7CBD7B7CAD7B7CAD8BACCDAB9C9D6BBCAD7B9C8D6B0C2D45068824F6C854F6B80
6B839182949D7F8C92878C8E5C4E4300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB517B69E81888C8EA7B9C4627985657F88556F777F9CA23C5A5E79969B7F989E
768D94667D82A7B7BBB4BFC2BAC3C7B0B8BD767B7E7C7D7B80807B82807A87837B8D8980
938D859D968EA19C93A4A097ADA9A0A9A59BA6A294ABA494AEA394ACA092B1A497B3A494
B8A797B2A08FB09D89B49F88B5A189BBA68EB7A189BCA78EBAA78EBAA590BEA790C0A892
BDA68FC1A892C0A791C2AA93C3AD95C0AB94C2AE96C3AF97C4AF99C6B29DCAB7A1CDB9A4
CBB6A1CBB9A2CCBAA2CDBDA4CCBDA5CFBFA8D4C3ABD7C3ABD4C2ADD4C3B2D6C4B5DBC5B4
E6C2AFE4A696D2796CC66159C2635EC37779B58893817891415981224C7C3C668F8098B0
B8BCC1C2BAB3C4B8ABC6B9A9C7B8AAC7B2A4C4ACA1917B7C685A6A524F6A3D45632D3A5D
25375D383E5CA470809B1C22B10C0FB00B0DB61E21AA181EAC1118AE090FB2080FB2060C
B0060BAF050BAF030BAC020AA8040AA6070C9D0B0F8E1C22AA7176C8BEC87C8E9C8DA6B7
40586E5A5B6D7D404989101692090F85212F432F476D89A1B8D2DEBDCFD8BACBD5BACDD8
B9CDD8B7C9D7B8CAD6B9CDD8BCCEDABDCCD8BBCCD8B8CAD8B6C9DAA1B7CEA0BBCF9FB7C7
A0B5C0A8BBC3A3B1B8979DA25E524B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0028DB0BB094748D8E8FA4B5C07A919D58737D7D98A14B656D6A8588769093738E91
97B0B48BA3A99DB1B6B4C2C8BBC6CCB5BDC47A7F847879787E7E7986847D89867E8F8C82
948F849C978E9F9B929F9B94A6A39BA6A499A9A599ACA598AEA498AFA395B3A696B5A594
B7A694B4A290B5A28DB39F87B5A189BAA68FB6A18AB9A48CBDA991B9A58DBDA58EC0A891
C0A790C2AB93BDA78FBFA991BFA991C1AC94C2AE97C6B29DC4B29CC4B39BC8B89FC8B89E
CBB9A2CAB7A1CDBBA5CFBDA8D1BFABCFBEA8D3C2ABD6C4AED6C4B1D4C1B1D7C5B6D5C6B6
D7C8B7DCC5B6E1C3B8B59B9A80768258607C354F753257804C71957D96AEAEB8BFC0BCB8
C5BCB2C8BCB0C4B8AAC4B8AAC2B6A6C3B5A5BFB2A2BDB2A8AEA9A692939B838994828793
8E8D99A78F97A55758A11414B50B0CB40809B3070AB3070CB20709B2060AB30409B4040A
B4060AB4070AAE0406B10409AC0407AD0509AB070AA10A0F891A20A47381292F435B7486
607486635C6F803B468B0E1691070F892534402D45708EA4B8D2DEBBCED6BBCCD6B1C3CF
B8CBD6BCCFDCBCCED9BCCED8BCCED8BACCD8B6C9D4B7CAD9B1C8DD5B79944F728B6D8A9E
738A97869AA292A4AAA4AFB377706C27981000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A4835D93918FA1AFBB738A9769858F628087668187728B8E68838669858A
5E7C805C7A7D8CA6AAB1C4C9B6C5CCBAC4CB7E8589787B7A7C7D7885857E87877E8F8E82
959185A19B90A49C93A59E95A6A19AA6A298A8A499A9A396AEA698ACA191B3A796B5A595
B7A595B5A191B6A08EB39C86B79F89B9A38CB5A088B9A38CBBA58EBAA48DBDA68FC0A791
BCA58FBEA992C0AB92BFA991C2AC94C2AD96C3AF98C6B29DC7B39EC7B59EC9B8A1C8B7A0
C9B8A2CCBAA6CEBDAACEBDABD0BEABD1BFAAD3C1ACD2C0ACD5C3B0D7C5B4D9C8B7D5C6B8
D5C8BBD7C9BCD8C8BED0C4BEBAB4B6A7A9B4A7AEBBB1B8C2C0C0C3C5C0BDC9BFB6CABFB2
C9BCAFC8BAADC7BAACC5B8AAC6B8AAC7B9ACC0B5A6C1B6A6BEB6A6B8ADA1B4AB9EB4A99C
BCA499C188829D2D2AAD100FB50909B50709B40708B30608B4070BB30409B20308B6050B
B30507B40709B20809AF0506B00406AE0609AC0406A8050997090E933C44A5919E90A1B0
B8C8D1A797A27E313A8F0D1493080E8624353F2E497896AEB5CFDCBBCED6BCCDD7BCCCD9
B8CAD6BACCD8BDCFDBBDCFDBBDCFDCBBCDDBB8CAD6B8CBD8B5CBDF3A587543657F607F91
5B727E788B937B8A917E878D6F696924961000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A17C4F9A958E9AA7B28399A774919C62808985A1A75D797E617E85537076
56757767848686A2A6627C81A8BCC1BBC8CB858D8E7B7D7C7E7F7A81817A88877E8F8D82
9693879D988FA39C94A39C94A6A098A8A49BA7A499A8A498ACA59AACA497B3A797B4A395
B7A496B9A392B59E88B89F89B89F89BCA58FB6A089BBA28CBFA690B8A18AB8A28ABCA68F
BDA790BEAA92C2AD95BFAA92BFAC94BFAD96C3B099C5B09DC5B09CC7B39EC8B6A0C9B7A2
CDBBA7CDBBA9CCBBA9CFBDAAD0BEA9CFBDA7D0BEA9D3C2AED4C3B0D8C7B6D8C7B8D5C6B9
D3C5B8D5C7B9D4C7BAD4C8BBD0C5B9CDC4B9CCC3BACCC2B8CEC2B6CDBFB3CABEB1C8BCAF
C6B9ABC5B9ABC3BAACBDB5A7BEB7A8C1B8ACC0B7ABBCB4A5BAB1A1BAAE9EB6AB9ABBA496
C39187A74642A61614B30B0CB70A0CB5080AB2080AB10708B40709B6080AB50709B7060C
B40608B30608AF0507B00409B10507AD0305AE0509AB030AA2050C84121D946B7E8E9CB5
8796A7A8959D7E2B30940E1395080F8725353F2F487A9AB1B6CEDDBDCDD9BACCD6BBCDD9
BACCD6BDCDDABCCCD9BACCDAB6C9D7BACBD9BBCBDAB9CAD8B8CADB758CA18BA7BAA1BDC9
9CB2BC9EB0B8A5B4BA9EA8AE7B777A38671D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009C7440A69E91909CA5A6BAC766818D96B2BC6F8B945D7A814E6B71537477
62828488A5A85B777B55707597ABAFBCC9CE8F959A797C7B7E7E7A83827C8989828F8F86
9A978EA09B93A29D95A29C96A9A39FAAA5A0A6A297A9A298AFA89DACA499B2A699B2A393
B7A696B4A390B29F8BB39F8AB3A08BB4A28BB7A38CB9A38DBBA58EBBA58DBCA78EBCA68F
BCA690BFA994C2AC96BFAB93BEAB94BEAB95C2AE98C6B09BC7B19CC8B29DCBB6A1CCB7A3
CDB8A7CEB9ABCEBBABD1BFACCEBCA8CFBDA8D2C1ACD4C3B0D3C1AFD5C4B2D5C5B5D6C9B9
D5C8B8D5C8B8D3C8B8CFC7B5CFC6B8D0C5B9CFC3B7CDC2B6C9BFB3CAC2B4C9C0B2C8BEB2
C8BEB2C4BBADC2BBACB6B3A3BAB7A8BCB6AABCB4AAB8B0A4B5AE9EB6AB9DBBA699C4948D
AC4F4EA41A1CB00C0DB70A0CB50909B20809B20809B20809B40709B50709B30709B20409
B30A0CAD0A0CA9090BAB090DAF0A0EAE060BAC0408AA0207A5040A8C0A148B4E681B224B
2C43629B8A947A2228940A1195070E8723314333497899ADB5CFDEBCCDD9B4C6D0BBCDD7
BCCED8BDCDDABACBD6BDCFDBBBCDD9BACAD7B4C6D4B4C7D6B9CCDB7F94A9668196728F9F
7F99A383969D95A6A99DAAAD95999D48392E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A27740BAAEA188939C99AFBC87A2AD8BA6B177919B4D67704E6B70557578
4566686C888C94AFB3778F939EB0B4BECACD98A0A4767A7C7B7D7981827D8686818E8F87
9C9C949F9D969F9C959F9B96A39F9AA9A39DACA59CA9A297AEA79BAEA599AFA595B2A595
B6A696B3A090B2A08CB4A38FB5A38FB4A08BB8A38CB7A28AB6A28AB8A58DBCA990BAA68D
BAA68EBBA790C0AA96BDA994BDAB96BEAC96C1AD98C3AE99C7B29DC8B4A0CBB8A5CDBAA9
CCB9A8CDBBABD0BFAFD0BFACCDBDA6CFC0A9D1C1ACD4C3AFD4C3AFD3C3B1D4C5B6D5C8BB
D4C8BAD3C7B8D0C7B6CFC8B7D1C8BBD0C4BBCCC2B8C9C2B4C8C2B1C9C2B2C5BDAFC6BCB1
C5BBB2C2B9AFC2BBAFBFBAAEBDB8ACBAB4A8B8B2A4B5ADA0B7AD9FBBA89EC49690A94D4D
A61B1EB20E12B60A0EB6090BB70A0BB20809B20809B5080AB5090DB30A0DA90A0CA00B0E
9A1416962224983033992B3395151D9F090FA90509A90307A303078E060E8E4C62242D53
56738F9C8B977A2029960A1196050C861E2C4E384E7391A8B6D0E0BDCED9AABCC4B2C4CE
BCD0D9B4C6D4B8CBD9B8CAD5BACBD5BBCDD7BCCED9B5C8D8B2C4DA8298B32845604D6980
637C8A74868F7F8F957A878B7C83854A3F3700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004EBB24BDB09F7E8C92A6BBC99BB2C087A1AD617C864F6A73516C732A464B
223C405A747A627F856D888CB3C4C8BCC6CBA2A8AD76797B7B7C797E7D798887828E8E88
96988E999B909B9C919F9D94A49E97ABA49DADA59CAFA69DACA399ACA298AFA498B0A397
B4A396B4A092B39E8DB4A18CB6A18DB8A18EB7A28DB7A38CB4A28BB6A48EBAA68FBBA68E
BDA890BAA790BCA894BCA994BDAD96BEAD99BEAC98C1AF9AC6B59DC7B7A0C8B7A4CBB9A9
CAB7A8CCBBAACEBFACD0C1AECDBDA9CDBEAACFC1AED3C4B2D2C2B0D2C5B4D2C7B8D1C8B8
D2C9B8D1C8B8D1C8B9D0C8B8CDC5B8CCC2B9CCC3B9CAC3B6C7C3B1C5C0AFC6BEB2C8BEB7
C5BBB5C4BBB4C3BBB2C1B9AFBCB5ABB9B2A7B6B1A3BCB2A4BAA79CC79A95A74D4EA31B1D
B41112B70A0DB9090FB7090DB30709B10808B00807B10B0BA90C0C9E121498292E9A4B56
855769634E684F47655548617E4F5E932C35A10C12A80409A203078E0A12905265293457
9FBCD69E8B987A1E2595081197040C841724593B526F8BA2B4CFDFBFCFDAB9C7D2B7C9D4
BBCEDAB3C5D3B1C3D1B6C6D3B8CAD6B9CBD7BACEDAB9CADAB6C7DC92A7C26A829D8DA4BA
94A9B6A3B5BEA3B4BAA0ADB18A8F9352474227980E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004FB81EB8A690818B8FA8BCCA8EA6B47B97A45976814D69722441461C3639
7C9395849CA0658286547276758C8FBCC9CDABB2B5767A7A797B777C7D7883837E93928C
95968E989A9097988EA1A095A5A197AAA39BAAA29AAFA59DB0A69CAEA197AEA197B0A39A
B8A89CB2A092B5A190B6A18DB7A28DB5A08DB5A08CB7A28BB8A48BB9A48DBAA48DBCA68F
BEA991BCA68EBDA993BEAC95BCAC93BEAD96C2AF9AC1B09CC3B8A3C9C0AFCBC2B3C8BBAE
CCBCAECDBDABCDBEA9CDBEA8CCBDA6CEC1AACEC1ADD0C3B1D0C3B2CFC4B3CFC6B5D2C9B8
D0C6B6D3C8BBD1C7BBCFC6B8CEC4B9CCC3B9CDC4BBC9C1B8C7C1B4C7C1B4C7C0B6C7BFB8
C8BEB8C3B8B2C0B7B0BDB4ADBBB4ABB9B3A8B9B1A5BAACA2C59F99AE595BA21C1EB31013
B80C0EBA0B0EB80A0CB6080AB4090AAD0809A60E0C9D19189D393E915364634A682F335B
172D5B122C5E1B3661495F7C686677A3636C941219A3040B9C0306880D1184516415254A
304D6C867383781C2295080F99050D820E1B643F55647D95B2CFDEBACDD7BDCCD8BCCAD7
B6C7D4B9CCD9B8CBD9B7C9D8B5C7D5B7C9D7A5B7C5B6C8D7B9CADC889CB46D879E758FA1
7D95A181969F8CA0A698A8AE9BA4AA5A5352279A1300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0051B81AB29A7E878C8FADBECD8FA7B56F8D995878832F4D5518323672888D
6B828790A9B06580857B9699657B7EB8C8CBB1BABE777D7E7B7C797E7E7982827D878780
9192899B9D939B9C91A1A197A3A197A7A49AACA49CB1A7A0B3A89FB3A79DB1A59BB0A399
B6A79BB3A394B1A08FB5A38EB2A089B1A089B3A088B7A28BB8A28AB9A38BBAA48DBAA590
BBA78FBCA990BEAA92BEAB93BEAC94BFAE97BFAF9CB3A999C0BEB2D5D8D1DADCD9D0CFC9
C7BEB1CCBBAACFBEAACDBEA8CBBFA6CBC0AACDC0AECEC1B1CDC1B1CCC2B1CDC5B3CEC5B4
D1C6B6D0C4B6CFC4B6CDC3B6CCC3B7CCC4BAC6BEB6C9C0B9C8BFB6C8BFB6C9C0B8C7BEB7
C5BCB5BEB7B0BCB7AEBFB9AFBBB5ABB8AFA6BBAFA5C6A8A0B26866A12024B31115B90D0F
BB0C0EB8090EB70A0EB40A0DAC0E0F9A15169B3C3F956272554A6B20305F0F295A1B3963
445F7E7184988E9AA49FA6A9A99D9E9F6061901115A4060B9B06098E272A66465A172C4E
849CB38C7682761A2394081098040C7F08116F40525B6C83B2CFDDB9CED6BBCDD4BCCAD3
B9CAD2B9CCD6BACCD8B9CBD9B9CBD9B5C5D5A0B2C0B0C3D1B5C8D960799241637E34576C
557481748A9573868E76858D747F88575457269B1600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0050B615AD9170898C8DA9BBC87E98A56F8D994C6A75102C325C757A677F86
3E5A615A777D76909693ABB0768B90BAC7CDB9C1C77A8283797D7A7E7E7983827D86887E
9092859B9C90A1A096A4A099A9A49EABA59FAFA7A1B0A59FB0A49EB1A59CACA298AEA197
B1A397B0A394B5A494B3A090B09E8AB2A089B29E88B7A38BB49F87BAA38ABCA48DBBA68E
B8A68DBDAB92BBA791BFAB96BEAC97BDAD9BA69F8F9E9E91B3B8B2ACB4B5CED4D7D5D8D5
C4BDB2C7B9A8CCBCA9CDBDA8CABEA7CBBFAACCC0AECDC1B0CCC0B0CCC2B1CBC2B1CFC5B5
D0C4B7CFC5B7CEC6B6CCC5B5C9C1B5CAC1B9C8BEB8C8BEB7C8BFB8C7BEB7C9BFB8C6BDB6
C0B9B1BDB8AFBDB9AEB8B6AABCB9ACBDB4A9C2ADA4C28581A02B2CB31419B90D10B90B0D
B80A0CB80B0FB00C0EA512139E2F339B5E6C5A4E6D1F336110306325456F586E86848F98
9499999EA19AA19F96A69C95B89390983F419C1013A6060A95080A9A494F3A2F4C183556
98ACBC9D828B78192194071098040D8707117B3C4A535A6EB2D0DEBCD0DBBACBD4BACAD4
BBCBD5B9CBD6B9CDD7B9CBD7B8CAD6B4C6D4B3C5D3B0C4CFB2C6D588A0B54D6E836E8EA1
8CAAB596AFB98FA2AAA8B5BF75818E41444C4E3A2B00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AF8F68888785A1B1BE8198A669869423414B4A656C60777F3F575E
112A2F657F8544606758747A9DB2B9B5C4CBBBC6CB7E8789787F7D7F827C8A8D868A8D84
8E91869C9D929D9B94A4A09AA9A39DAAA39CAEA6A0AEA49FB0A59EB1A69DADA399ABA196
AEA196B0A193B2A191B29F8FB4A18DB5A08AB4A088B4A087B8A38ABAA48CBAA48DBAA68E
BBA78EBEAA91BEAA91BEAB94BDAC99B3A697938F82B8BAB0D8DDD8BFC6C7BFC4C4D0D0C9
C1B9ABC9BBAACBBCA9CDBEAACBBCA7CCBFA9CBC0ABCCC1AECEC3B2CDC1B0CEC4B2CEC4B4
D0C4B7CDC3B7CCC4B7CDC6B8C9C3B6CBC2B8C8BFB7CEC6BFCAC3BAC7C0B6C6BEB6C3BBB4
BEB9AFC0B9B1B9B2AABAB5ABBAB5AABBADA5C9A09AA44343AE191BBC1113BA0C0EBA0C0E
B60B0FAF10119E1B1DA14B547C5B752D35621030641F416D59738D8B98A0969B969D9D93
9C9A8CA4A295A8A296B19A93AE6E6C911A1EA4090DA2080A8C161984556810204822466B
7E94A299808473181D91080F99020B8F070F7D2D394D485DABC8DAB7CDDABACCD6B7C9D5
B9CAD6BACBD9BACBDAB8C8D7BAC8D5B9C7D6B5C6D3B3C5D3B2C5D3A1B5C7728C9E7D99A7
87A2AC8EA6AD90A3AA98A7B17E8F9D222E3950443800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A9865C9E9B9795A4B08EA6B546636F3E5C645C777F3B545C0F282D
627B7E8BA4A87D979C63818638565CA5BAC0BBC8CD8590937C84838386828C8E898E9089
8F92889FA0969B9A94A4A09BA6A19AABA39BAEA59FACA19CADA29BB0A69DAEA399AD9F95
AEA094B0A091B19F8FB4A191B4A08DB6A18BB4A088B4A088B7A38AB9A58CB8A48CBAA68E
BCAA92BBAA91BBAA90BCAB93BCAB97A89B8B9A9486B5B3A7C9C8C1B5B7B2B0B0A8C7BFB2
C5B9A6C9BBA5CABCA8CDBEACCDBDACCCBDAACBBFACCDC1B0CEC1B2CFC2B3CCC1B1CDC4B5
CDC3B8CDC3B8CEC4B9CEC6BBCAC4B8C9C3B7C9C3B7CCC5BBC8C2B9C5C0B5C6BFB4C5BDB3
C0BCB2C0BBB5BCB7B1C0B9B2C1B8B1C1A8A3BD7977A42222B81313BD0E10BB0C11B70F11
AA120FA52E2AAC666B5946601C2B5B1634664661858192A098A19E9C9E94A09F939E9C8F
A09F8EA5A193A89C91B085809233349F1014A4070B980C0F9845513F31540C2C5C325C82
4964778B7981731D21910A0F9B040D95050E7D1A275A4558A3BECEB7CFDBBCCDD9B8C8D5
B8C8D5BBC8D7BDCADBBCC9D8BCCAD7B8C8D7B5C7D3B2C6D1B3C8D6879FB0456479577688
66838E7B94997B8F947C8A926374811C2B36504A4000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AD8554AEA79E8F9EA77E94A23853607B97A23F5C650D272E597277
718B916C8890819AA0728A90768D929BAEB3BBC9CF8D9B9F7D86878C8F8C8F908D939490
999B939D9E969F9F97A3A29AA3A098A7A39AA9A39CABA29CADA49CAFA69CB0A298B1A096
B3A295B09E8FB09E8EB19E8FB39F8DB49F8BB19D86B19D85B4A087B9A68EB4A28BB7A590
BAA893BAA890BBA88FBCA991C0AE99B8A8978B8273A4A095A6A398979588BCB7A7CBBEAC
CCBBA7CBBBA7CABBA9CDBDADCDBCADCAB9A8CCBCABCDC0AFCEC1B1CBBEB1CDC1B4CDC3B7
CCC2B8CCC2B8CDC2B8CEC3BACCC3B8CBC2B8CBC2B9C9C1B8CAC3B9C5C0B5C6BFB4C8BFB6
C2BDB3BEBBB2B9B7B0BCB8B1C1B9B1D0ACA9A44749B11B1DBE1112BC0C10B60D0FA91310
B13F36CF837E98677070536C6256737D7E9391959B9A9D97A3A598A0A193A09E919D9E90
A4A293ABA297B5958E9E4F4E941416A5090D9E0A0D952A33754F6B112050254871A9CAE0
ABC0CB9C8E946F1F23920B1199030995020B810B167041538F9EAFB6CDDABBCCD9BCCAD7
B7C7D4B8C8D5B9C9D8B7C7D6BACAD9B8C8D7B3C5D3B2C5D3B5CAD87C94A86E8BA2557288
6D8A9788A2AAA0B4BA9EAEB58697A11E2D3858554D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AB7E4BB5AAA08B97A0899CAB758D9C67838F143138466064698389
4C69712B4950607E8394AFB4698186A7B9BDBBC8CE9AA5AA7F888A8B8F8F919290939390
91928D9C9C979E9E96A4A49AA6A59DA6A19BAAA49FADA49EAEA39CADA299AFA097B09F94
B29F92B09F90B09E8EB19E8EB39F8DB59F8CB39D87B4A088B2A089B4A58EB6A68FB7A790
B8A892B8A793BAA993BFAC97C5B19DC1AE9BB7A798A19688A9A291BCB5A2C8BBAACAB9A8
CEBEABCDBEADCDBDAECCBCADCDBEAEC9BCAACBBDABCCC0AFCAC0ADCBC0B0CAC1B3CAC2B6
CCC4BACCC3B9CEC3BBCDC3BCCEC3BBCBC1B8CAC0B8CABFBAC6BEB7C5BEB5C5BDB3C6BDB4
C0BAB1BCB9AFBBBAAFBEBAB1C2B4AECD9F9F9B2D32B5151ABF1013B90E11AD1412B53B34
DD8079BA60609B353C96283494353EA97070AD988FA29E92A19F92A5A298A2A095A3A193
A9A093B3968EA86562931B1DA30C0EA30A0A991F219156692626530E2A5C5F7E9995ADB6
A7B9BF9E959B73292F8C0B1298030898020A8B060F7529377B7585BBCEDCBACBD9BACAD7
B6C6D5B5C7D5B8CAD8B6C8D6B4C6D2B7C7D4B6C8D4B3C6D4B2C6D68AA0B2849FB0748E9D
768E98778E96869BA090A3A88C9EA61F303A5A5B56269A0F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0053BE28A69A8B828F96AEC1D0879FAF3E5B67314C54667F854A636A
0F29304A65685D797C456266819A9F94A8ADBCC8CDA8B1B67F878A8C91918D8F8D949590
9796929B98959F9D98A4A29DA5A19AA69F97A9A199ACA39CAEA49DACA299AEA299B1A496
B0A091B3A193B09D8FB19F8DB3A08CB29D89B39E88B39F87B19F88B4A48DB7A78EBBA991
BCA894BBA794BDAC98BFAE9AC1B09DC4B29CC6B3A1C2B1A1C7B7A5C7B9A6CABBA8C9B7A5
CCBBA8CBBCA9CCBEAECABEAECABEAFC7BAABCABEADCAC1ADCBC3B0C9C0AFCAC0B3CAC2B6
CBC3B8C9C1B8CAC0B9CDC3BDCCC1BACABFB6CAC0B8CAC2BAC4BDB5C7C0B8C1BAB2C3BCB4
C5BFB8BEBBB0BCB9AEC0B9B2C2B4AEC592929C272BB81519BC1011B41310AE2B24DF7871
AA3D3B9E191BA81114AC0D11A31216902A2AB18B849D9C939EA097A7A59CA39E95A79D93
B1938DA96162982023A30C10A7080AA11010BE595C6E425928284E43507095A2AD959EA3
8B989F716A747C3841890B129702079A020A92030B780D1B7C5261B4BCC9BBCCD6BBCCD6
B7C8D5B6C8D4B8CAD8B7CAD8B7CAD5B6C7D2B8CAD6B2C5D3B2C7D68CA4B64561755D7787
69828A687C835E7274697B7D687A811A2C395B605F279D1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0052BD23AA9B86808D92A7BDCA617D8B2C4B54627C82486166122B2F
455E627C949992ABAF9AB3B76D878D556D72BECCD3B7C0C781878D87898C8B8A8B939190
9998959B9A969C9B97A3A09AA8A39DA9A39CABA39BAEA59CACA199AFA29AAD9F98AFA196
A99B8EB3A496AF9F8FB09F8CB2A18DB5A38FB4A18BB29E86B6A28AB7A48CB8A68FBAA691
BAA491BFAA97BAA895C2B2A0C1B19FC5B4A1C4B2A0C3B1A0C4B3A2CAB9A9C8B8A6CBB9A7
CBB9A7CEBDABCDBDADCEC0B3CABDB1C7BBACC5BCABC5BEAACAC3B0C8C1B0CBC4B5C7C1B3
CCC6B8C7C1B4C8C2B7CBC4BAC9C1B8CAC4BBC9C4BAC9C4BDC6C1BBC4BFB9C2BEB7C0BCB5
BEBAB2BEBAB0BEB8AFBEB7AFC2B3ADC9989899282CB81519BB0F10AD140FD96058BC4A48
A21718AE0D11B10A0DB20B0DA90E119021257F5D67606D7693A09CA1A099AC9F97B6928E
A559589B2023A70C10A9050AA70408A20A0FA82A2F9D3A47924A5A9B6A75BFA4A8B8B1B3
B9BFC4958E9681444C890E159802089A02079502098C0914782834B7A4B0C2CBD5BFCDD8
BACBD5B7C6D3BBCBD8B8CAD8B3C7D4B6C8D4B7C9D5B3C5D3B0C5D3A4BCCE2C496066879B
6F8E99738C9579909580959A82969E1C303D5B64653A6C1E00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB81A9F8B6E7A8183ABBFCA3E59637591995C757C183035364F53
6E8A9058757C809CA38DA6AC6E868C687D82C1CED5C2CAD4858991898A8D8D8B8C908F8D
9697939797929B9994A09B96A6A19DA9A29FA9A19CADA39BACA299AFA49BAEA097B1A399
A99B8EAC9F90AF9E8FAF9D8BB19F8BB19F89B5A189B59E86B79F88B6A289BAA68DBDA791
BFA996BEA897BDA999BBA99BBCAB9CC1B0A0C6B4A4C3B0A1C8B5A6C6B3A3CAB7A5C9B8A4
CBBAA8CCBDAACDC1B0CBBFB0C9BCB0C7BCADC5BEACC2BBAAC8C0AFC7BFB0C6BFB0C5C1B2
C9C3B5C9C0B5C9C0B7C8C0B7C4BFB5CAC3BAC9C3BAC3BFB6C6C1B8C3BFB6C1BDB5C1BFB7
BFBCB3C1BDB4BDB8B0BCB5ADC1B3ADD0A8A79A373AB1171BBA1011AC110EE6605CAC2424
AE1013B40B0FB40E10AC0E109D131796435150436422395A8D9BA3A79B96B08681A14A48
9B1A1AA90D10AA0709AB0509A90307A90509A4060BA0080D9A0B129010188C2C30AF797C
A69798A89FA2834E52830F1797030B97010798020996050F800D17935A64CEC4CFC0CAD5
B9C8D5B8C7D4B2C3CDBACCD8B3C7D2B3C7D2B5C9D4B6C8D6B2C7D5ACC4D5637F937695AB
7493A7688397597687637F8F6A859515313E52626252453000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB616A78F6C888D8BA8B8C270878F7F99A3304B552D454C728991
526F792B4D5564848A607B807E9599A3B6BAC2CFD5C7D0D88A8F958B8D908D8C8D8C8A8A
92918E9696929A9995A29C99A49B9BA99F9FAAA19EAFA79FADA59CACA398AB9F96AB9F93
A99C8FAC9D8FAE9C8DB09D8CB09E8AB09E89B4A088BBA28CB99F89B8A38CB6A48DBAA793
BAA895BAA997BDAA99BDAA9ABEAD9CBDAC9AC4B2A1C5B2A3C5B2A2CCB9A8C9B8A6CBBCA9
C9B9A9C9BCABCBC0B0C8BFAFCCC0B2CABFB0C5BCADC4BAADC6BCAFC6BEAFC7C0B2C3C0B3
C7C3B8C9C1B7CAC1B8CAC2B8C7BFB6C8C0B7C9C3BAC6C2B9C4C1B8C5C1B8C0BEB4BEBDB3
BEBCB3BDBEB3BDBBB1BEB7AFC0B5B0CAB0ADAD6464A42025B51115B71112B9181AB41116
B50D11B30C0FAA0E109817189A434E785B7C19285A2C4069A297A3AF74759631329E1315
A90C0DAC0709AC0809A80307A90307AA030AA70105A60105A60308A6060B9C0B0D871A1E
AB7877A29090A174757D121996050E9A02099C030B98020C8C040D76151FAD818BCAC7D0
BBC9D5B6C8D2B3C5CFBBCDD9B7C9D5B7C9D5B7CBD7B5C9D8B2C9DE7C98B33957791D385E
0A224A051B4302173D0416380C223F09243854686A554D3C00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0050B814AA926A9B9F9BA0AFB99CB0BC516C7726424B68838B58737F
264751406267617F8249636695ADB098AEB3C3D3DAC9D2DB8D939A898D908E8E8F929291
9897959797949A99959D9996A49E9BA7A19EA7A19EABA6A1ABA49CAA9F96A99C94AA9D92
AC9D90AA9A8BAF9E8EB19F8DB19F8BB09F8AB3A18BB6A089B69E88BAA28BB9A48FB8A694
B7A996B9AB98BBAB9ABEAB9BBDAA99BFAC9AC0AE9DC6B3A4C8B5A6C8B6A5C9B8A6C8B7A6
C7B7A8C9BAADC9BBAEC9BDAFC9BFB0CCC2B4C6BCB0C5BCB1C2BAAFC4BCB2C9C2B7C3BFB4
C7C5B8C6C3B7C7C1B6C8C1B9C8C0B6C9C2B7C8C2B9C6C1B8C4BFB6C5C1B8BEBCB3C1C1B8
C1C1BAC1C1BAC2C0B9BDB8B2BEB8B1BEB2ADC6A09EA24C4FA12022B01819B11415B21418
AB1217A0151996262C9E5B696B5A7A1F2F5E2F3B6A8268859E505B9A1F23A81214AB070A
AF0808AF0808AA0607A80307A70208A70206A80309A60107A90408AE060DA9060C920A0F
93454A998087A6858B7A1D2691070F98020999020998020B92020B870813751E2AB5939E
C2C6CFB5C6CFB0C4CFB1C5D2B7C9D7B2C6D5AFC8D8A7C1DC6380A81A396B011B5000144D
001146000F3F010E3B000D37000F34021833475C6554544813CC0600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98D619B9B9696A5AF869DAB24414C728E97607C83325058
3E60652B4D4F7F9B9C98AEB3627A81516970B4C6CDC8D2DA91999F8A90938E9191909290
9798959B9C989D9C999D9C97A09F99A5A09BA39C99ABA5A0A8A199A9A097A89E94A99E93
A8998EAB9B8EAD9C8DB09F8CB2A08CAE9D89AF9D89B09D86B6A189B9A38CB6A18BB6A490
B9A994BBAA96BBA998BBA897BEAC98C0AE9AC1AF9EC1AF9FC5B4A4C7B6A5C8B7A6C6B7A6
C6B8A9C7B9ADCABCB0CABEAFC9BFAFCBC3B3C9C2B2C4BCAFC4BDB2C5BDB4C3BCB3C3BEB4
C3BFB4C5C1B6C5C0B5C7C0B6C4BEB2C6BFB5C7BFB6C7BFB9C5BEB7C5C1B8BFBEB5BFBFB9
BEBEB9BFBEBAC0BDB9BEB9B5BEB9B3BAB3ADBEAFAAC7A4A2B174709F48469A353897343A
98454D995E6E7C64813A406D1C2F6151537B936580932E3B9F1319AE0E11AE0909AB0507
AD0709AD0709A90506A80305A60105A70105A70206A60207A70208A90108A8040997060C
8D323E50384A998B997830398B0A1396010998030995010992010A8F020B830814762330
B0949EBEC7CEB5C7D0B8CAD7B7CADBB1C8DE7E9CBD24447502205B011A5900155100104A
010E44010E40010D3A000B36010E340112321B2F40535A5222980D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98552A5A19991A0AA7F94A14C66717390993A595F3B5D60
3154556C8C916D8B93718B919BB0B78B9EA6B0BFC7C8D3D89CA6A8878E918C92928F9392
9596949898949A9B959C9D989E9E989F9B97A39D99A8A19BAAA198A79F94A59C91A69A8E
A99A8CAB9A8CB09D8FB19D8CAE9A89AC9A87AE9C87AF9C85B49F87B39F86B4A08AB5A38E
BBA893BDA893C0AB98BBA793BDAB96BDAA98C0AC9CC1AF9FC1B0A0C6B6A5C5B6A3C3B7A4
C4B9A8C3B8AAC5B9ACC8BDAFC7BEB0CAC1B3C9C1B4C2BBB0C1BAB0C3BCB2C3BCB2C2BBB1
C4BDB2C7BFB5C4BCB4C6BDB5C7BEB5C8C1B9C7C1BAC4BFB8C2BFB7C3C1B7C1C1B9BFBFB9
BFC0BAC0C0BBBDBBB6C0BDB6BEBBB2BCB8AFBCB5AEBBAFAABEAEA8B09C9C7C6B756A6377
4F56732A3D66183367293A6D75648A924D62951E28AB1418AF0B0DB1070AAE070BAB0508
AB060AAC070BA90408A90409A9040AA80309A80409A80307A80307A80306A5030698070C
9237443D2A426E718485525C830F1797040B96010593000793000A94010C8D020D7F0A16
6E2F36B5B1B5B4C8D1B0C7D9A6BFDC58759F0B2A60011C5C00175A01145901135501114E
010F46010D41010D3E010C38010C33000E3005172E515A59219A1000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A87E42B2A99A89959C98ABB67F96A44F6B7736565C305155
6E8B9044606727434A5F7B828EA6AC7B8F96B6C7CEC5D1D8A7B1B6868E918E9395919595
9395939798949899949A9C979E9F9AA19E9BA49E9BA69D97A89E95A99F96A3988DA5978B
B1A093AA978AAD998BAF9A89B19C8AAD9B88AB9A83B09D85B29E85B5A189B6A48DB6A58F
B8A791B8A68FB9A792BAA693BEAC98BCAB97BCAA98BEAC9BBFAE9DC2B2A2C3B4A4BEB2A0
C0B8A5C3BBA8C2B9A8C2BBABC6BFAFC6BFB0C7BFB3C4BCB2C1BAAFC0BBAFC0BCB0C1BDB0
C6C0B2C8C0B6C7BFB7C7BFB7C6C0B6C0BEB3C4C2B8C4C2B8C1C1B7C0C0B7C1C0BABEBEB7
BDBEB6BFBFB7BBBAB3BFBCB5BCBBB1C0B9B2BAB3AEBCB5B1B4B2ABAFAFAC999EA3707F8E
5A6E855669877476949470889035469E1620AB0D12B20B10B2080CB1070EAF070DAC060A
AB060CAB060CA60409A60309A5050AA5060BA30508A50308A50207A80307A1030690060B
9648572E2647515E789B7B8677141C93070E98040995010894020993000A90020C850510
6E1F2A918898ABC4DA9AB7D73B5A8A04215D01195B01165B01185D02175B01135400104B
010E43000D40010D3D000C38000B31000D2E02132C38434A46362100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BD24BCAD9C7E878EB5C8D56983913858633B5C61607D82
486166172E327B9497718A8E687F86B3C5CCB2C1C8C1CED5B2BDC3848D908990928D9291
9496959796949A99959C99969E9D9A9F9C99A49F9AA69F98A59D93A39B90A59A8FA5988D
A7978DA7958AA89587A89683AD9B87AE9D89AA9A84AD9C84AF9C84B5A289B5A48BB4A48B
B7A78EB7A78EBAA992B9A894BCAA96BBAA96BDAA96BEAB96BCAC97BEAF9CC0B3A1BCB2A0
BCB3A0C3B8A4C3B7A5C1B8A8C1BBABC3BDADC5BEB0C9C1B6C2BBAFC1BBAEC0BCAFC0BCB0
C2BCB1C6BDB4C7BEB8C7BFBAC6C1B9C1BFB6C0C1B6C1C1B7C0C0B6C1C2B7BEBFB6BFC0B8
BEBFB7BEBFB7BBBCB4BABAB2BBB8B1BCB7B2B8B4B0BBB7B3B2B3ABAFB0AAADAFABAAADAD
A8A7ABB29EA7A86B76932531A8141CB30D13B5090FB50811B4060FB1060EB1090EAC070B
AA060CA7080D9D0A0E93090E900F15901317950C119D050BA30307A50306A00508890C15
8D546D161F484D6382A696A176252B900D1597030A96000A94010B93010B90010A86050E
7A2A3D322A4E6688B62B5085011E5E01185C00145802165B02185C01185A011551001248
01124004153C0C1F4307173C01103201122F04152F22313D4C423400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0056BF26B7A38F6F787CB1C5D04B677338596258777C516D72
152E32758D917B939AAAC1CBAFC4D0BBCFDBA9BAC4C4D0DABBC4CE838A91868E908C9392
9598979696959896949D99979F9D999C9B97A29F99A19B93A29A91A2988EA1958BA4948B
A49288A69289AA968AAB9687AD9A88AB9A85AE9D87B29E88B39F87B09F88AF9F89B3A28C
B6A48EB4A38CB6A68EB7A791B9A894BBA994BDAB95B9A78FBBAA93BEAE99BAAF9AB9B09C
BBB19DC0B4A0C2B6A3C0B7A6C0BAA9C2BDADC7C1B4C8C0B5C5BEB3BEBAAEC0BCB0C1BEB2
C3BEB3C6C0B6C4BFB6C4BFBAC4C0BCC4C3BCC3C2BAC2BFB7C2BFB6C2C1B7BEBFB4BFC1B7
BDC0B7BEC0B9BCBDB7B8B9B3B7B6B1B9B6B1B9B6B1B6B5B0B6B6ADADAEA6AFAEA8B0A8A3
BB9F9FA760659A212AAA1117B40D11B5090DB3080EB4070DB4070DB2070DAF0A0EA60A0D
9B0D12951B239539428E4D5D805466845663A04A52920B11A5060AA6040A98080C92333F
492E500D25547193B49DA3B2824D5483101795040C97010C94010B92010A8D000781050C
7B2F45201644041D5C011C6200176100145A001357011458011758011C570E2B5C1D375D
3951695066764F6275162842061C332139490920300F202E4D463E24960900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0053BA1DAA9175717474ACBFC8516C7745626B627F84173034
688185738D945C778299B2BF7A94A1748E988A9DA6C3D1DAC0C9D3888E958B9092919594
9195949496959795919C99949E9C979D9D98A19F9A9F9A92A39B90A49990A3968DA4948C
A5938BA99790A9978CAC988AAE9B8AAD9A88B09C89B49F8BB49F8BB29E89AF9C86B19F89
B3A18BB3A28BB5A58DB6A690B9A793B9A893B8A791B8A790B8A792BBAC97B8AA95AC9E8A
B5A592BDAF9CBAAD9BBEB5A5B9B3A3BEBAA9C3BEB1C7C0B5C5BEB5BDB9AEBCBAAEBFBDB0
BFBBAFC1BEB2C3C0B6C2BEB7C4C1BCC3C2BCC0C0B8C0BEB6C1BEB6BFBFB8C0C1BABDBFB8
BCC1BABBBDB8BCBEB8B7B8B2B8B9B1B9B6AFB8B8B0B8B8B0B4B4ACB1B0A6B5AEA7C0A3A1
A961649C2028AE1018B40B12B50B0EB4090FB3080EB3070DB0090BAA0A0F9D121595272E
934B5B7C57744B456C232D5D1926544D405F934A57920C14A10209A1040997171B9D5869
201C412A4A775D8CAE6D8CA389727E77181F91070E97020A9301099202098D02087E040E
7631491C144502165700155E01165B01175800165306235B1634653457815A80A07A9AAF
8BA4B093A8B35C7285061932213B4C4B64684053590E1D2A48494821960D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DC0C9F815D8C8B87A7B7BF5D75825E7A841A363B5D787B
6C878C5470794B65719EB5C1405A63859BA2C2D2D9C4D1D9C7D1D78B9298868B8D888C8D
848888878B898E8E899A98919B99929D9B979F9C979E98919E968CA1968D9F9188A4958E
A4938BA4948AA6968AA99789AA9788AE9988B09B88B19E88AF9D88AF9D88B09E87AD9C83
B2A089AF9D88B2A08CB3A18CB1A08CB3A28EB5A48EB4A58CB0A18AB1A28CB1A38EB3A38F
AE9D89AEA08BB0A492ABA190B2AB99BBB5A5BEB9ACBEB7ACC3BBB2BEB7AEBEBBAFBEBDB1
C0BDB1C0BEB2C0C0B5C4C2BAC3C2BBC2C3BEC5C5BFC2C2BBC0BFBABFC0BAC1C4BDBDC0B8
BCBFB7BEC0BABCBFB8BABDB6BABBB6BAB7B2B9B8B2B5B4AFB5B6AFB5B1ABC2ABA7AC6869
A02529AF1116B40C11B6090FB5080CB6090DB4080CAF0B109C0D0F982A309757656C5675
2E3567122964102C65253A6957517581495F8B19259E0710A4030AA1040AA41A21A34857
6C48616A6F8895AFC37792A49C97A1773139880C1395030B9401089100098A010B79071A
4E163B12114B02145901135B001559011A57092759375B8186A8C497B8D32A4C6781A1B7
7491A07794A62D4762011530506A75586F6D54646422303844484A21981100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009E7D53A5A39DA1B0BA839BA836535C48656A718D92
4D6A7146646C95B0B993AAB494ABB4A3B6BFC6D5DDC7D2DBCCD5DC8D969B7C8487787D7E
75797780827E8C8B8795928C98948D9E9A95A39C97A19790A1978E9F958CA0948A9D8F86
A19289A6958DA7968BA99889AB9988AA9885AB9A83AC9B84AB9983AC9B84AE9E85AE9D85
B19E86B5A08AB4A18BB19F87B2A088B19F88AD9D84AF9F85AF9E84AB9A81AB9A83AB9B84
AD9E87AB9E87ABA08AB1A794AFA794B0A897B4AD9EB6AEA2C2BAAFC4BFB3BDBBAFBDBBAF
C1BEB3BFBEB4BFC0B9BDBEB9C0C2BDC3C4C0C5C6C2C1C2BDBEBFBABDBFBBBEC2BBBCBFB6
BDBFB7C0BFBABDBFBBBABCB8BABCB9B5B4B2B9B8B4B4B5B0B5B5B0BEB0ACB8818299282D
AF1318B70B10B80B0EB40A0CB3070CB2090EA80D119E1F259E4F5C7156732C39690C2866
11326D36507C6F769393768B883B4B8C13209F0814A4040CA9060BA40108A1040B940914
87202BA06B75A19BA3B0BFC9A3A9B38B646E7A141D92070F95020A90000A860511600B29
240A3E0A155901145C01145A021D592748777A9BB9A1BCD1AFC7D98299AD5770846E8797
5D788833516B021E3D0F2B424660644F635C52635F3B494D3E4346219A1500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A38055A7A49E9CAAB5879FAC314D587591994B6870
3B595F88A6AB4A68716E8A95748E9995A9B3C4D3DEC0CBD5C8D0DA939BA27C8487767A7C
737674848480928F8C9C9593A098959F9793A49D969F978F9E968E9F978D9F94889E9085
A29086A49287A9978BA89687A99887A89884A99983A89780AE9B83AC9B82AA9A80AE9D84
AE9C84AF9D85B09E86AF9C83B19D84AB9A80A9987EAA987CAB977CA9977DAA9981AB9C85
AA9B83AC9E86AB9D88ACA18DAAA28DAAA290ACA596B5AFA1BBB4A7C1B9AFBDB9AFBFBBB3
C3BEB8BEBCB7A2A5A39197969FA4A4BCC0C0BFC1C0BEC1BFB0B5B29FA6A4A8AEAAB8BDB8
BCBFBABCBDBABABCBABCBDBEBBBCBDB8B8B6B4B6B1B3B4B1B5AFACC39F9F993D42A8181E
B50D13B80A10B80B0FB60A0EAD0A0EA010159B323B92607842436D122E680F346C3A5782
747C989B85949A5E698E272F970F17A0050DA40309A7030AA40308A70409A8040AA4040B
970911821E25B08C9599A6BA5A75908B8497732C35880C1392020A8D020B73081B3B0A35
0F1051041661001A5E0928614A6C949DBCD7ABC5D7ABBFCEB2C5D48297A799B2C094ACBD
4F6782071F450D284745637359727255666052605A414F5139424525A11D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A68254A6A09996A3AD748896758F9C5F7C853A575E
7D9AA04C6A72607E8675909A758D97A5B6BFC6D3DDC3CDD8C9D0DBA0A4AE7C8186727679
7B7E7E8B8C8A9392919793919D96939C958E9E998F9A958B9B968D9C948C9D9188A29087
A18E83A49186A69487A39283A69584A89784A99884A99884AA9782AB9981AA9B81AB9C82
AA9980A8957CAC987EAD997EAF9C81AF9F84AC9C81A9987DAB997FAB9980AA9B81AC9E85
A7997FAA9980AB9C85AB9F8AA9A18DA8A18EABA491AEA898B2AD9EB3ACA1BDB7ADBEBAB1
C1BEB8A9AAA5949994B2B8B5888E8DA9AEAEC2C4C5A2A5A4959A97A2A7A3A1A8A3848E8B
A3ADA9B6BDB9BABDBABEBFBDB7B7B5B7B8B4B5B6B1B2B1AEBEABABAF6C709B1D24B21016
B60B11B80B11B5090FB00C119B14199A445173577525366C0E327126477A6B79979C8B9C
9D687190333995161CA10B11A4040BA40309A40309A30208A40309A50409A50207A50309
9F030B830A138F5A676E768F1A39586C788C8B626B7A141A8B040B8605105A09261F0C45
07175F021B6213366F678EB4A6C6DCB0C7D8B1C5D4B3C5D4ABC0D23D5B7391B5D34C6B8F
14305B011B452A486173939D6B828360726E5260584856553440412CAB2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A47C4BA19A8F929EA5AABCC9849CA93C59646C8991
55727B5C7A84738F99788F97ABBDC6C4D0DAC6D1DCC5CFDAC7CFD9AAB2BA696E75727579
8385878F908F92918F96918F9D95939B96919A959093918A96938A9C948C9F91899F8F86
A18F85A18E82A18F81A69385A99686A89683A99782A79581AB9985A8967FA9977FAB9A7F
AB987CA79277B09B80B19C81AD9B80A9987CA9997AA89877AD9C80AA9A80A99A80A99B81
A8997FAB9A80AC9E85ADA28BABA08DA89D8BACA28EABA28EAEA897A9A394B5AFA3B9B6AB
C2BFB7AAAAA5888C87AEB5AF8A908DAFB2B0BABBBB8C8D8BBDBEB9BEC0BABCC0BAADB3B0
808988B5BDB9B9BAB5B9B8B3B9B8B3B6B5B1B6B5B0B9AEABC7A0A298373CAE181DB60B11
B60C10B50D10B00D129C181CA055625F5174162F6810336E475D878E849D98697491383F
8F151D9B0B11A3070EA8050DA7040AA50109A4030BA30208A10109A20108A60308A70409
A00309860610874C603C425B86A1B596A9B69B8D95762E34840D137E0919470E33121353
03165F011C5B4B749FA3C8E1AFC9D7B7CBD9B2C6D5B4C5D6AEC2D54F6D8A466C94163565
001C480D2C4C41606E5C757A53686852645E5362574D5B562D3A3A544E4500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0051BE29A397898A959EA8BDCB607B865B788257747E
58767F6C8992728D96A7BBC5BED0D8C1D0DBC3CFDAC5CFD9B2BDC6909BA26F767C737579
88878992909092908D938E8D9B959499949297928F8B8884908D859A92889C8F869F8E86
9E8B829F8C7FA29183A49383A89685A99782A5937DA4937DA4927CA7947DA7937BA8947A
AB987BA89579AF9C82AF9B82AA987EA49278AA967BA69273AA9779AA997EA7977EAA9C85
A4977FA69A81A9A089ACA28FAEA191AA9D8DA89B8AADA392ADA696AAA395A8A496AEAB9F
BEBDB3BCBBB39C9F97939B92A4ABA3BFC2BDB5B5B3959795C0C1BDBEBFBABCBEB8B4BAB7
7F8985B2BAB5B7BAB5B9B8B4B9B6B3B3B3AFB4B4AEBFB0AEB98285971F26B51117B90C12
B50C11AF0F13A01D23A35A6A554E72163168203C71717296997184943E4A91181FA00E15
A4070DA7040CA7020AA50309A30207A40309A6050BA40309A30208A60209A8050AA70309
A00509850A1488556D1A28499CC0DA6488A177889C8E6B757317226E0D26310B3A0B1454
0915531F2F633D6085A4C9DFAFC8D6B4C8D6B6C9D8B6C8DAAAC0D77694B60A2B59001E50
1C41645476877A949A6E82855D6E6F53635E5262584858562C3A3E56544E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004EB91FA59781869096A9BECA5E798473919A486771
65838B5C777F98AEB6BDCED8BDCED9C1D0DCC5D2DEABB6C3838D967B858980868A838687
88898890918D8E8E8A95919096918F98918F98928D827C758F88809D938A9D8F879D8B85
9E8A82A08D80A18E80A59384A69483A7937FA7927DA4907AA49078A8917AA9927BA8937B
A8957DAB9881A7947BAB987EA69579A39176A69277A79275A89375A9957AAA9A81AB9D85
A79C85A69B87AA9F8DACA190ACA291AEA393A69C8BA99F90A9A3999B9A8F9091869A9D94
B9BBB2BCBCB2BEBFB4C1C2B8BFC1B8C5C4BDBEBEB98B8C8BB3B6B6BCBFBDBEC2BD9FA5A2
909693BABEB9BABBB7B8B7B5B5B4B2B2B2AFB3B3AFC0B0AEAC6D70A11E22B71114B90C10
B40E11A1161AAA596659486C2334674A5182896A8B954758951C28A30F18AC0A11AE0A0C
AB0508AD080DAA060CAA070CA6050AA60409A60409A6030AA7040BA8040BA7030AA8060D
9E090C881E276E4F6E1026507CA1C11D4164385473AEA9B97137465E1637270C42121253
2813454D34583A4763A8C8DCAEC9D6B2C9D7B5CCDCADC6DE6E8DB0143464011F511F466D
5D859C88A7B28FA6AB7D8F926D7D7D5D6D6950625B394D4C253A3B61685F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004FB91CA29074899497B0C5D187A0AD54737E5E7D86
65818893A9AFACBDC6B4C3D0B9C9D7B9C9D898A6B677818C7780867B8386808689868A8D
88888A8F8F8F908F8D918F8C9992909A908E9E94918F867F8C847A938A819D908A9A8B85
9B8A819E8C7FA39081A49283A1917FA2907BA6937CA7937AAA957DAA937BAD947DAB9680
AB9681A7927BA28D73A49075A49276A8987CAC9B81A39073A79275A59174A6957CA99980
A69982AB9F8BB0A493ACA192ABA293AAA392A49E8D9C988A7C7D747D8179787E77626C66
848D88BAC0B8BCBEB5C1C1BAC5C3BBC5C2B9C1C1BBB0B2AF8E9293919899929D99949D98
B2B5B2BAB9B6BBBAB6BBBAB6B7B8B3B4B3B1B3B3AEBFB1ADAE6C71A21D23B81114B90E0F
AD1112B4474C87596B5C4E6F8769888F465D94212FA3121AAD0D13AD070EAF080DAD0709
AB0508AA0409AB050BA8030AA6060AA1060A9F0C0CA10C0FA4070DA60309A70309A20309
91080D9343543A345C1A3B667698AF7490A2849FAFC2CEDC927A8B4E2247200F47190F4C
46123C60233F3C344F9CB9D1A9C8DAAEC8E093B2D53F618F07285F011F550A27514F7089
59798668828B63767C5E6F71606F6D5464604D605C1F3439294147606E67209B1300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0027D90BA68D7093999DB4C8D86F8A9961828C5E7B81
96ADB3B6C6D1B3C1CFAFBECCABBBC98796A46B7681737A82787C807A80837F848787898D
858689888A898D8E8B92908C948F8C98908E97918B979289918D829892869B9287998B84
9A89819E8C82A39084A59284A59081A48E7CA58F79A7927AA6937BA9957DA8937BA9947C
A6947CA39278A39173AA9679AC9B7FA5957BA8987EA59376A69174A89276A59278AA9982
A89982A89C84A59A84A59B87A99F8CA69D88A39C89807F727B7D768D91898F958E737E7C
566663A3AFA8B7BBB3BFC0BBC5C5C0BEBEB6C3C4BDC0C1BCC0C2C0B8BAB8B9BCB8BEC1BC
BBBBB8BAB9B7B8B8B6B9B9B7B8B8B6B6B6B5B8B9B4BEB3B1B780829C2127B61217B80D0F
AA1111D5686AB66C75A14E5E9523319F111CA70A11B20B0FB1070BAF050BAB0509AC070B
AA050AA9040BA8070EA2080D970C0E8C1816A5423CBE504E980D12A3030BA8040B9F060B
8A1721825473102254537EAA9FC5DA9ABACA7DA0B2AECCDDB2B6C6614E6D1F164B170E49
43123C5213304535547F9BBF8CAFD44F709E10306703235C092C5D2A4B70728EA469828D
849BA1778B90697C7D6476755B716D4E6464344A52061A2D172C3D606F7025A21C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A58666939597B2C4D46B849667839088A2A9
B0C2CAB8C7D4B3C3D3A1AFBF7A808F706C786E677075737A7D7D837E8084818689858889
8888898987888E8D8A92908C928F8A938F88948F88959188969087978E84998F859A8A81
9B897F9B897FA08D82A18D80A18B7CA48979A58C79A6917BAA967EA8947BA7967BA69579
A493769F8D6FA49070A38E6EA39071A18F73A28F74A69074A79070A89270AB9676A89679
A5967CA4987DA59B7FA99D84A89C84A89D86A69F8B6B6A5F6D746E7E88827A8480627170
4D605C9BA8A0B9BDB5BFBFB8C3C2BCBFBEB9C0C0BBC0C1BBC0C0BBC2C1BDC0C0BBC1C2BD
BBBBB8B9B9B5BABBB6B8BAB5B6B9B4B7B9B6B7B8B3B8B4B0CAA5A4963339B0181DB80F11
B41012B31D21A81B22A8141CAC0E15AC070EAF090CB3090CB4090EB0070CAC070AAB060B
A6050AA0050C960B138D1A2292434A8B585DA7717396353B980B12A6050CA3070C900E14
99506238305F0627605E8FBE5585A97DA9C5234E689BBFD5BFD1E09393A92F2D5511144B
1D12472512412122541630690C2C68001D5A022157254770779AB891B1C99AB5C789A1AD
A5BCC48DA2A9889BA17A929567838B304C5C061F3701122F01142D3C4C5629AA2700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A2825D939493B0C0CE8096A578919CAAC1C8
B1C6CEB4C5D4A5B4C67072826D55635F303963383D8370747C7B7F7E83867F8585838786
8789898C8C8A8F8F8C92918C8F8F88939188918E86918D85968F86978D84988C839A8B82
9B897F9D897E9C897E9E8C7FA28B7CA18878A78D7DA7917FA28D78A7907AA59077A58F73
A69071A49070A28F6EA38E6AA8936EA18E6BA3906FA79373A79170AA9370A89371A69475
A6977BA79A7FA5987FA99C82A79D83A49C83A49E8A75756A525C57586A665566644D5C5B
616F69A9B1A7B9BDB2C0C1B6C4C3B9C5C2BBC5C4BEC5C6C0C0C0BBC5C4C0BFBFBCC0C0BE
BFBEBCBEBDBABABBB6B9BAB5B5B7B2B5B6B1B4B7B0B3B2ADC3AFACB670729F1C20B71213
B90E10B80C11B50D11B40C11B2080CB3090DB2080BB2070DB3090EB1080DAC080CA4090C
960B0F8D1E248D445075516845364F6A4D60873D4990141DA0090FA1070C921013974755
5A49710C25602147796991B2274C6B5B7F9A638396A9C5D4BFD2DEBCC4D1736D8828214D
18134914114D0B124F041A5505265B21426E6685A6A1BFD769879F82A4BD46677E7A96A7
6C87946A818F677F8F3C576D14314F031A3F011238010E330111331A2C3E4C4D4400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A38256A5A49FA9B8C397A9B596ABB5AEC4CD
B0C6D2A5B6C4717584674C5A67232D6A0D13671619865E607F797C7D82847D8485818788
888B8B8D8D8C908F8D91908C918F8A928E87918D87938F87968E86938980998B83998881
9A877F9C89809B887D9D8A7D9E8A7A9E8A78A38D7AA58F7CA7917DA68F79A28B73A38A6F
A68D72A58F71A18E6DA08F6EA39170A28D6DA28E70A39070A4906FA89272A99675A8977B
A69780A99D86A59A84A39A82A29A83A29A84A49D88989684666C625B666066716B68716A
8A9085A1A497B3B4AAC0C0BAC2C1BAC4C0BCC6C3BFC4C3BFC1BFBDC4C0BFBFBEBCBDBCB8
BDBCB8BDBCB8BCBCB7BABBB6B7B9B4B7B8B2B3B4ADB4B4AFBEB0ADC08386A02529B51315
B90E0FB7090EB70C0FB50B0CB3090BB5080EB3080EB2070DB10A0DAA0A0D9D0E12911F24
8F475372566E36365A2F33596C57727D3647860F199A070E9E0A0D901116934652625173
0F26600E346A688BA8859EAC9CB5C2ABC5D588A3B1BED4DFC0D1DBC7D2DCAFACBC694D68
4A1A3F42113D341542262B557797B5A3C2D6AFC8D8ADC6D649657A67859B486577708796
5E7481657A8E213959041A4501144301104102113B010E360110350A1A35494C4F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009B7848AEABA59CACB9BCCEDDB1C2D1B0C3D2
A8BCC978818E614D575C1D266B0C1474080E6F0E12824B4E84787A7E81847E8285848689
8687888B8B8B8A8A898E8E8B918F8B918D88918C868B877F928A83988D89978984988680
9B857EA0877E9E887E9F897DA38C7D9F8877A18A78A68F7CAB937EA38C759D876E9F896D
A38B6FA79075A89479A28F73A39173A38F73A190729E8F6EA1916FA4936FA39372A79A7F
A19580A89E8AA59C88A39885A69D88A19A83A19C86A19E8A9697879395889193869A9B8E
A3A194A3A295AFB0A7BCBDB7C1BFBBC2BFBCC5C5C1C0C0BFBFBEBEC1BFBFBEBDBABCBCB6
B9BAB5BCBDB8B8B8B5B9B9B7B7B9B4B4B7B0B4B7B0B5B6B1BCAEACA46367A11E24B50F13
B6090BB7090DB40709B6090CB70A0FB3070DB40B13AC0B0FA31113951F25954955755773
383D631D2C5948477078526E7C2737890F1A95071094090E8C1B21904F6051476B102B61
0D356B587A9DB9D2E3ACBFCDA3B9CB6384A0698EABB3CEDFBFD2DDC1CFDAC6CCD8A493A1
6B34466C142A640E26512D4A7D8EA4AECAD9B1C7D5AEC4D19CB5C58EA7BC92ABC198B0C1
7C94A2829BB1041A44021347000E42010F41010D39010D35011034031430444A5200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009C7640A9A39992A2ADC0D3E2AFC1D2ABBBCB
848D9A6A626D59323857121570202587363A6310167E454988787B7D7E807C80817F8283
848788888B8C8D8F8D8E8E8A92908C918C87938C868F89828C857D978D89968885988582
9E85819D847EA0877FA0887DA38B7C9E88779F8B77A28D79A5907AA390779D8C6FA79479
A69277A28D73A18D71A18C70A18C6FA08E70A798799D8F70A19171A29271A39375A3967E
A69C89A5A08C9F9A86A19985A59C87A09A849F9A86A19C8A9D9A899E9B8C9F9D90A19F92
A2A093A2A195AEAFA6B6B7B1C1C1BBC2C1BDC2C3BFC1C2C0C2C1BFC0BFBDBCBBB9C2C1BD
BDBDB8B8BAB6B6B8B5BDBFBCB7B9B4B2B7B1B2B7B1B1B4B0BBB1AEAE73769B1C22B30F13
B70B0DB6080AB6080AB70A0FB2090FAD0B10A00F13921B209446537F5E7A39406E143068
2C41716C5B7F7E3C54841725930E1892070F8C0D1284252E81546B3638630B2760194073
8CAECF94A9BC9BB0C27E96AD8AA0B8324F701A3F60ACCBDFBCD0DDBECEDCC3D1DBC4C4CF
997C896D25336F0F2161263C5C5F74ACC8DAB0C8D7ABC1D29FBBD2335175203D6A48678A
7494A95E7991081E47011244001044010F40010F39010E32031633051A333B465010CD0C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053C12BACA5958E9EA5BED0DFB3C2D39198A8
6C5E695D3C416D4446562B2C734E5186585F59181F6F383C8673747C7C7F7A7E7E7C8080
828889878B8B8B8D8B93928F91908C928F8C928E8A928A84948B85968C87968985998883
97847E9D88809F8981A38D83A08B7CA08E7BA08E7AA18C77A9937DA08C749B896EA28E71
A18C6F9F8A6DA18B6DA18B6B9F8B6BA08E6FA49576A19273A49476A29275A39379A4977F
A59E889E9A83A09B84A19A84A29A86A09A88A19B88A09B889D9A879E9D8A9F9C8DA29E91
A29F93A6A69BACADA4B2B3ACBFBFBAC0BFBDC1C0BDC0C0BBC3C2BEC1BFBEBAB8B5BCBBB7
C0BFBDBDBDBBB6B8B4B4B6B3B1B6B1AFB5B1AEB3AFB4B8B4B7AFADB68284991F26B10F14
B70C0FB80B0EB50B0EAE0A10A00B13931A22994752835F7A3E4270132E6E0D33732D4D7F
7C759272283C8C101D960912930A1186131B843B48654C6A1D2B5D072863193F6F6283A1
92A8B896A4AE8696A46C80918FA1B0899DAF91ADC0B4D0DFBED2E0C2D3E0BFD0D9C4CEDB
BFBDC8906D79671E2C601C314A4055A0BCD0ACC7D792A9BF617C9B0D2958011B56031F4F
44647E536F830E2346011241010F4302113E0115360F283D324E592D47532D3D4624A220
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004FBD24B0A5919099A1BFCEDEA6B0C1786D7A
6332395813146E3A396B52536A5C61775A62581D26672C31846C6E7677797A80807B8081
8083858789888C8E8A8E8F8A90908D92918F95918E938B88968C88968C87988E86998D84
95877E97857E9D8A83A28E859E8B7E9D8A7A9E8A75A18974A78D78A188709E876BA08B6D
9E8B6BA08D6EA08C6D9D89689D8A699F8D6CA09272A29478A99A80A7977DA29279A69983
A29A849F9883A19984A099839F9984A09A879F99889F9A889D9A889C9C8A9E9C8CA19F92
9C9C90A1A298ABACA4BBBDB4B8BAB3C0C0BBC2C1BDC2C1BCC3C2BDC1C1BCBEBEBBBCBDBB
BABDBCBABDBDBABEBEB4B8B8B5B9B9AEB2B2AFB5B3B3B6B4B6AFAEC2969B92232BB11318
B60C10B30C11AD1317991A2096414D89627946486E1730680C326E234A7E5E7EA08B99AA
9D8089771B24910F18890E158327317D4E643C375E10275E0A2E6630547C6E8C9E869B9F
91A0A2A5B0B7919FA7B8CCD7B8CFDC94ADBD85A6B99BBDD1BAD3E2BFD3E1BDCFDCBDCDDB
C4CEDAB9B1BD845E6C5920324A344A839AAFA9C3D394ABBD7991AC122C5B01185601154B
4765856F8BA018315001154000133E0C2343284452425C5D4B635E4B606229393E2AAA28
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004DB71DB7A38F91969EBFC8DA837F8F6A434B
61131664080A6424266A4F51675D62755D6460273063262C83676A747477747A7D797C7E
8484868989888C8C8A8E8F8A8F908D91918F928F8C96928E948E89948E879890879C9188
9D8D859D8A839F8B83A28E85A28E81A38E7C9D8872A18A73A187719A81689E86699E8768
A08A6A9E8A689F8B699E8C69A08D6AA59170A391719F8F72A6977DA7987FA2937EA39783
AAA08DA29988A59D8B9B95829D9784A099879E99869D99869C9A889B9B899C9D8D9C9D8F
9D9E909D9F93AAACA1B8BAB2BCBEB7BCBDB8BDBDB9C0BFBCC1C0BCBDBEBCBBBEBDB9BDBD
B7BEBCB5BCBCB6BCBCB5BBBBB4BBBBB1B8B7AFB6B2AFB3B0B1AEACC5A1A4912D33AD171D
AD1115A01D219B3E47936475554E6B3442683049752C4C765A7A968399AB91A0A79A9DA0
A58D906C262B7E232C8244555442641D2A5C07245C1338674E6F8C7B939D8E9FA08E9B9B
9CA7A9C7D4DCB0C2CC92ADBE5B819A7DA1BB355D777DA4BBB7D3E2BCD2DFBFD3E1BFD1DF
BDCDDAC2CCD9B1ADB8725A684737495E6F82A6C2D1ACC3D48098B3203D68001A53031852
1D355D718FA61F3C510B263F25415745606B4E66694C615C52635D4E61602334373A7A35
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0025D90BB9A2867C8082A4A9B468535D591C22
6D171A71181A5E161A663C4168545B775F67642E36601F26866467726E727175797A7C7E
8080818989898C8B8A8D8D8B91908F928F8E94908E928F8B928E89968E89958C859D9188
9D8C859C8A839E8C83A08E839E8C7F9F8D7B9B8872A08B73A28B739D856A9D85689E8567
A28A6B9F8969A08D6D9E8B6B9F8B6A9F8A6BA39071A09171A4967AA89C86A69A879F9380
A29987A9A192AFA7999C95859C9481A098849F98859C99849B9A879C9C8CA0A1949C9C91
9C9D909FA193A6A89CBDBEB5BFBFB9BFBEBBC1C0BFBEBEBCC1C1BFBBBEBCB9BEBDBABFC0
B8BFBFB3BCBCB6C0BEB1BAB7B2BDB9B2BCB8B0BAB5ADB4B2B3B2B2C8ABAE913D429A2226
9F393F9A6575615772373C5E605B7C7A627C917E919295A094A0A697A1A498A1A1979B9B
9A9594866D6E856F7B2E30550C255A0E2F63315377667F907F91938594919FACAAA7B2B3
8E999E97A3ADA0ADB88699A8345067688399748D9E9EB7C8BCD3E0BDCFDCBED0DCBED0DC
BED0DCBDCEDABFCDD8A5AAB5676A7A43576BA2BFD18DA8BA25425D29476F011C4E01174E
072148506F7F435F654660674F696D5168695069664D645D4E625C495C5D213238494A47
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B0926D74716D7572785B3C41551B1C
7B3C3C742D315A0C116126296A4A4F74555D682F375A1B1F8260637270716F7576757779
7D7D7F8887898B89888E8A88928D8B948E8D908A878E8885918785918482998B869F8F8A
9E8C859F8C85A28E879E8A809F8B7FA390809F8D789E8C769E89729D84699D8365A1886A
A0876AA48E719D8B6D9F8F6E9B88689E8B6FAA9A7F9F9175A092799E927DA79F8A9E9681
A29A86A39C8CB2ACA1A29C8E9A92819D96839F99859E9B869A9986A1A395A7A89FA19F98
A1A096A1A196ACADA2C0C1BAC1BFBBC1C0BDC0BFBFBDBEBDBDBFBEBCBFBEBDC1BFBFC3C2
BDC1C0BAC0BEB8C1BDB8C1BDB6BFBBB7C0BEB3BCBBB2BAB9B6B7B7C2B3B5936769A06A6E
7F66773C3F615A5A7C906C868A3B4C84212B995659A6989B959EA197A1A1999F9F979E9D
949897969594838A9320355528486D5D76917B8C94818B898A938D89928C8B9190939799
959296948F96968F95A0949CA297A0B2A7B1988E98B8B1BDC4C5D1C2CCD8C2D0DAC0D0DC
BDCFDCBACEDCBACEDBBACAD5A0AFBB51697B84A5B76985937992A0637C932E476B04204C
234563617F88637B7A596E6E5C7070546968516A664A645D4C635D43585C1D3039565B5B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A67D537B6D656C5F655634395F3334
794F50652E3152090B702F2F6B3A4077414A661E24601E217F62627172746F777A737679
7A797D8480838E8A8A8C8A878C8A858B85818E84829086848F818091817F92807D9C8984
9F8A859D898298857C9C877E9C867EA49185A29181A3907D99836D9C83679A80619C8264
9E86699F8A6D9B8A6B9D8F6D9C8D6BA09174A79A809C8F76A2967DA19780A19B859E9884
A39C8BA8A294B2ACA1A59F929C9584A099879B97829D9B869A99869D9C90A8A79DA8A49A
A9A69BACACA1B1B6ADBAC1BBBBC0BDBEC2C1BEBFBFBDBFBCBFC1BEC2C5C2BEC2C1B9BDBE
B9BCBDB9BEBEB5BEBDB5BEBDB3BCBBB7BDBDB5BABBB6BABBB3B5B6B6B4B4B6ADACB9A9AF
7C6A7F8F6B89984D65931F2EA012199F11189D424C69586A6B7F8C92A1A2979D9C9BA09D
949A969297958A949378868C7C8A93838C92888C8B8A88858E8A85928481957B7D9B747A
94606796555E9045508F39458C323C8A2F3C862F3C8B3E4C965D6BA2828FB6ACB8C3C8D4
BFCFD8BBCFD9BBCFDAB7CAD5B6C9D299B1BE82A0AF86A2B0AAC4CF8BA2AEA9BED1516D83
7F9BAD637B82677B7C586C6B596F6C566B684F67614A645E4C63602F434D1F34405D6766
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074912F7E67597262634E30336A4949
725352501D1F530E0E7A3839641F25671019670B11712E317E61636D6A6F6E747A71777A
7C7B80827D818882838886848785828983818A817F8B807F8C7C7C8E7A7A917E7C92807B
9A878099877E9C897F9E8A819E8A83A18D839D897B998471978069A0886EA0876A9A8265
9C896C9B896D9D8B6E9D8D6F9E8F719B8E73A2977FA399809F957DA9A08C9F9785A49E8D
ABA496ACA69AABA79CA9A5999A96849B98839996829B98859796849C9C8EA2A297A2A097
A8A99FA5AAA3959E978B96918994938E9B9BB0B9B9B7BEBBBEC2BCBCBFB9BCBEBBBABCBE
BBBDBEBABDBCB8BEBCB8BEBDB6BCBCB6BABAB4B7B7B7B9B8B5B6B6B6B5B6BAB2B3C09EA6
A85F6F962536A2131FAB0C14B00A12A50B149734424C3B584D69818CA2A6969F9C9CA39F
9AA09C9197938B94908B92918D8F8F8D87889885859776778E585B893B4183222C83141F
890F178F0B15950B16980A13980A119506109207128F0714870B1A8017267F303F976B79
B8ADB9C0CAD5B7CBD7B2CBD6B1C7D2B1C7D5A3BECF4F7085799BAE5C7C8A6C8794637986
5E737B5C6F725A6D6C596D6B586F685169634E67614E66673A505B091E3024404C5E6D6D
219E1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004AB2187F654B6E5F595239375E403E
70585563413E4C19177E42455E11176306096A151682474A6A4A50736B706B74766C7576
7D7E82868285857F818782808A8381877F7E877E7C8A7F7D8679758979768C7A778E7D77
95847C96837C99867F99867F9D8981A08D819C887897816C99836B9C866E9F886F9E8A6F
9E8F739B8F739A8D72A090769D8D759C8E78A0957FA69E8A9F9785B1A89AA9A193A7A294
ABA69AB1AAA1ACA69DA6A4989796869998859A9887A09F8E9B9A8DA0A094B0AEA4A9A79E
A9ABA38990899CA59DB3BAB2B5BCB89FAAA8818E8CB8C2BEBCC1BBB9BBB6B8BBB9B8BCBB
B8BBBAB7BBB9B6BABAB5B9BAB7BBBBB3B7B6B4BAB6B4B7B4B4B6B3B6B4B5BEA5AA8F3F4A
A01C29AD121AB00B10B1090EAF070DA709129123336145653A537490A8B295A2A098A09D
969B9993969393918E978A8C9B7E81935C6285353A801B21870E168F0B1592061096040C
9B060C9E060E9F040D9E02099E04089B010698010899030D94020D8F04108907157B0F1F
7B3345A68B9DBCC3D0B7CCD6B4C9D4B6C8D68197A82F4A5F446274637F8A627A83768A91
5F7376677B7B5B6F6E586A6A576D69516A674D6666384F5A0C1F3701102D0B213852656A
25A52100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004DB4158163416C5C525A423C553531
6A5250624F4C5A403D714344550B0F6210128242437946495E353A7C6C6F6E71726E7776
787A7C848284817C7D8981808C8280887F7C887E7B8178748074718575738774738C7975
92817A92817A99857F98847E9A867D9A877A9885759A88719B886F97836AA08C739C8A70
A293799D91779F9178A4957EA1927BA2957FA39782A69F8CA39E8BA9A494A4A193A5A396
A9A398B3ACA2AEAA9FAFAEA19D9F909E9F90A09F92AFAFA29D9F93A4A69BA9AA9FAAABA1
B0B2AB818983B1BAB3B6B9B4BFC1BFB5BCBB7A8483B1BAB8B8BDB9B8BBB9B9BDBCB8BEBB
BAC0BCB7BEB9B7BCB9BDC0BFBEC1BFB7BBBAAFB6B3B0B6B3B2B7B2B1AFB0BD9CA08C2932
AC131DB70D13B4090FAF080DAB060BA909138D1423754C6D2B426487A3B098A4A59CA1A1
9A98989E8E90A17A7F934F5789262F89101A8F0C1491070F94040C98010D98010A9A0109
9B02079D02089D03089E030B9F020A9E02089A020997020A94010A92010B91020C8E0410
830917721D2E9E7D8BC4C7D1B9C9D3BBCBD87E909BA6BAC6788D97A7BEC681989EA3B8C0
6A80867E93955C6E6E5A6B6A586C6A536B6B37515A081D36010F30000C31011230314454
387B3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0083592F735A4A664B43532E29
6D4A495D4443644E4E6A46474E12135F20218A5A5D612D305923277D6365717171747877
77797A7B7C7E7D7B7C817C7A857E7B88807D847B788078748077727E736D8575708C7A76
8F7E7897867F97857F95837B97847A99867B9886799B8A789E8A7697816B9C89719C8C73
9F90789F9079A1927CA29680A59883A1957FA59984A59E8AA6A08DABA596AEAA9CA5A196
AEA99FB2ACA4A9A69BAFADA1A9A69CA5A398B1ADA3B0AEA4A9ABA0A1A69CB0B5ACC2C7C0
C7CDCBB5BEBCBBC3C1AEB4B2B1B6B4ABB4B37F8988B4BCBAB7BCBBB7BBBABABFBDB5BCBA
B6BFBDB5BFBDB3BCBBB3BAB8B6BCB9B6BABBB4B9B9AFB5B3AFB5B1B5B3B6C7A9AD8C2C34
AB131BB60912B50812AF0710AB050FA80913870E1A7B506D1C31557D99A9979FA1A99C9E
A48084934B5489202B900F1A93071098051095020C95030B9401099A030B9A030A9A0107
9A01079D020B9D020A9D00099D02089B010597010692010893020991000993010B94020C
8C020C8108136F1D2AA98A95C0C5CFB5C8D5859EAB92ACB88DA6B17D99A286A0A670888F
627A7E5F73755D706F5B6B6A576A6B4A626B0E243C011034010C32010B3202123610253D
464D4C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7210754B34735047522824
7644434C1B1B6848486851525F3E3E4D292A7E5B5F5F2B31551A1F826264757171767878
79797D79797D7878787F7D7B827C7C857D7B7F76747E75727D756F7B716A837570847571
8D7B77927F79937F7899857C96827A96837C99867C9885779F8B7B9E8A749A88719A8A73
9F8E769F8E779F907DA09482A29684A79887AB9F8DA69E8DA6A090A8A395ABA79AAAA69B
AFA99FABA69BA9A79BACA9A0AFADA6A5A59DB1AFA8ACACA2ABB0A6B5BDB4CAD4CFC9D2D1
C9D3D4CEDADACDD8D9B8C3C49CA7A7838E8D9AA4A1AEB6B3B6BBB9B5B9B8B6BBBBB2B9BB
B3BDBEB2BCBDB2BCBBB1BBB8B5BDBAB6BABCB1B5B6ADB3B1AEB4B2B5B4B6C7AFB3913B43
A6121BB3090FB20910B00911A909109E0D168119257B5975182C4F7E8B9FA28B929F5D65
91272F9A131C9B08129C050C9B03099A020B97010A930008930108970108980107980108
99010A9F030D9D02089F040A9D02089E03099C040998030B93020991010891010A92020B
8D000988020B7B07126D2330BAA5B1A5B4C229475C4266784869764A676F6A8387687C82
5E76795A6F705B6E6E5A6A6A586A6E2D4354021435000C35010C33010C32001036061B3B
414D5400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00419E08713B237F574E5F3231
77393C4D0C0D68383A65494D6551536455576F5C615F313754171D805A5E776E70727174
7475777676787777767A7A78827E7E7D78787871707B73717D74717D736F80736F82726D
8874718F7875947D779C857E94807896847C9D8A809A877B988778A08E7DA08F7C9C8C76
9F8E7AA4927FA39383A39686A59989A99C8CAA9E8EA69C8DA8A192A8A194ADA79BACA79B
A9A39AA9A59CA8A59DA7A69EAAA8A2A5A49EAFB0A8ADB2A9A9B3AAC9D4CEB6C0BDAFB7B6
AAB4B3B8C4C3CDD9DABDC8CC8E9A9B9EA6A5ADB4B0B0B7B3B4B8B7B6B7B9B3B6B7B1B9B8
B1BBBBB5BEBFB5BCBEB4BBBCB4BDBCB3B9B9B2B8B8AEB4B4B1B7B6B4B3B5C5B1B59D4F58
A41722B20B13AD0A0FA70E149611178E2C358A576A453F5F494C6C8B677C8D3441981521
A50C15A80610A3030B9E01089D02089B020B9701089601079501079903089B0309970107
9A02099D020A9E0207A004099D00079D010898010698020796020892000891020B8E010A
8D020989010982020B72081380475099949D6E84904A6A7792B0B87B949A92AAAE809498
839A9C5D7675576C6A59696953656D10233D011037000B36000C33010D32000E33021738
3A47570CCB0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00449E0571321880544C683935
611B1A580C0A773939511E22643F4368565B6B5C6263363C5313177F545975686B6F6E70
7272727474747675737575737A78787D78797E79767874707B73707A706E7E706E82706D
86726E8B746F947D779681799581789A887E99877E9E8C829B897C9D8A7CA493839E8D7C
A0907FA59585A59386A59689A5978AA5988BA89C8EA89C8DA9A08FAAA495A9A497A7A398
AEAAA0A9A59CA7A79EABABA3AFADA6AEABA4AEAEA4ADB0A6B5BDB6C4CEC9A7AEABAEB2AD
A8AEA9A9B4B0C8D7D6CDD9DBB4BFC0ABB3B1B2B6B4B5BAB9B6BAB8B3B5B4B4B8B7B4BBB9
AFB8B6B1BAB9B3BBBCB1B9BBB0B6B5B4B8B7B3B7B6B0B4B3B2B7B3B5B5B5C2B0B4A65F67
9F1822AA0E149E121590252D995C6A68566E3F3E5C6E5B79874A61871B2B9A0C17A60711
AC090EA9040AA8040BA4020B9D020A9B010999020998020B960109950108970109960107
9A01099E020AA1020B9F020C9D020C99010A95020993030890030A8E01088C01098A0109
89020A8600078301077C030C6B121A846267B1BAC095ACB789A2AB9AB0BA738C907E969A
657E805E76755A6E6D586A6B465665031334010E37010D37010D33001030061833041B36
2C3D4E1D9C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D407794023754B436E3C39
580F0C5B0E0D7D3538560D115416196D4F5168575B6A3D43521114794D4F76686B717073
6F70727272717473717474727C7A78807B797D7A75797871766F6C7A6F6E7E6E6C836F6D
856C6988706A907A7395817A97847D97847C98867B9A887C9F8C7EA39183A18F81A29182
A29283A39484A09283A19485A09485A29688A59989AA9E8FAA9F93A69E92A9A399A5A198
A8A49BAEAAA2A7A79DACACA2AFAFA7A9A9A0AEAEA5AEB0AAB5BBB6C5CECBAAAFADB0B3AF
AFB5B0AFB9B5CAD7D7C8D5D7B1BABCB0B8B6B3B9B7B1B7B5B6BABAB5B8B9B5B9BAB2B9B8
B0B9B8B2BCBBB2BBBBB0B9B9B4BABAB7BBBAB2B5B4AEB3B2ADB4B2B4B7B8BCB1B3AB757B
8C1F259220259D535F7D647F363D643A42697C607D802E439214249F0A16A4040EA9060D
A9060BA9060BA7050BA3040C9F03099B02099801069B020A980108960107960107950108
98030A98020B99050E94060E8C060F870A11810C127A0A0F77080E7D070E81060E83030A
85030886020883000982030C73070F74353F8A808A72869259727E637A8260787B688283
637D7E5C75735B706E596C6F314357031239000C38000D350317361C37493D59642C4654
1D333F1C9F1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774021774C456A3837
5C1D1B60212279353A55070B5D1D1F6A484B6B4E54662F34561013794F4F6F636568686A
6A6B6D6B6A6B6C6969706C6D7976777E7C7B7E7D787A787379736F79706D7C6E6B806D6A
816A6888706C8F797496817C947D7996827999857AA28F82A29181A79686A59485A49384
9F9183A39587A497879E9280A29685A69A8AA59C8CA79E90A59C90A69D93AAA199A8A098
B2ACA4ADAAA1ACA99FAEADA1B1B1A7ABABA2AFB0A9AFB1ABAFB4B0C8CFCDBCC2C1B4B9B5
B7BBB8C4CCCCCCD7DCBBC6CBA7AFB0B2B7B6AFB4B3B4BAB8B2B8B7B6BBBDB4B8BBB5BABB
B3BCBBAEB8B5B0BAB7B0B9B8B1BAB7B3BABAAFB6B4ACB4B3ABB5B4ACB4B4B3B2B2AB8F91
8550529E788545496E1F3568545886835473842136950D1DA20814A6070FA5040BA5040A
A7060BA9050CA40309A3040C9F030A9C020A9D040A9B010A9901089402079203098E060B
85090D83121A86222C8836448346557B4E606B4A5C694D5F6E4E6077485873313F701521
7C091284040D85020B83010B7C050D6A15206146517C8B965B727C778B93738B8C768E8F
6C84865C74735A706D586C70263A5002113B000E380314342945554460634B6261445B5F
1C323A25A92B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723A15794E45663937
61322E693E3D6B343751080B69262A76434A6B313A590E135D1B1B735252665F625F6162
6365666868696665666C6A6D7473767877777E7B787D78757A746F79716B7A6E687E6D68
816D6889746F907C7598847D99857E96827A9B877CA18F80A19081A59284A59283A49484
9E8E80A190829E90809E9381A19887A19989A69C8FA59C91A6A094A79E94AAA199AFA79E
B1ACA3AFACA3B3B0A6B0B0A5AFAFA5ADAFA4B3B5ACB3B7AFA6ABA6B0B7B4C3CDCCCAD3D3
CED4D6CBD2D5BCC6C9B0B8BAADB3B2B7BBB9B6BAB8B5BABAB0B8BAABB5B7ADB7B9AFB7B7
AEB8B4ACB7B3AFB9B7ADB6B5ADB6B5ADB6B5ADB8B4AAB5B1AAB6B2ABB5B4ABB2B1B0ADAD
B3ACAF797E9323376167628E884B698C192A9F0C18A40711A5040BA9050CA9050CA7030A
A8040BA6030BA3020AA1030CA0030D9B020A98030998020A92060E870B1182182085323D
7C475572546C5A4E6F363A631F2B5A1122540F24521126541427511C2A50333855685469
6D2D3F770E1C84051084010C7E030A6D0B15552E3A9AA4AF9EB5BE798E9599B1B5698184
6E86885D73725C7270596F721E364B01123C011537203E4F405F614A64605065604C6363
1F363C40484700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00713910775043663C3A
5E3431745752643D3B541214681A1F73242A640E135D0B0D6A34346A56575E5C5E5A5C5E
6061636767676A67676B686A7371747573757976758079768178767B706E7B6F6C7B6C67
7F6D6783706A907C7596827B98847D99857C9D897EA08D7FA18F80A08E7FA1917FA1927F
9C8C7A9E8E7E9B8D7C9F95839E97869E9788A29A8BA59C8EA79E91A89E93AEA59DACA69E
AFACA3AFAFA6AFAFA6AEAFA6ACADA4ABADA4AEB1AAAFB4ABA8ADA6A7ADA8A6AEABABB3B4
B3BABDAEB4B7ACB5B5AFB6B4B2B8B4B8BDBAB5B9B8B2B8BB8F999C89979A7E8B8C9AA6A5
ACB8B4AEB8B5AFB9B6ACB5B4AEB7B6B0B9B8AFB7B6A9B2B1A6B2AEA8B3AFAFB6B4AEB0B2
ADACB1A49FAD8D72898F3E57961425A30914A9080EA9060DA8050AAA070CA8050AA60308
A30207A5050AA2020AA1030A9C030A93020B8D070F84101A832D397A4559644C6B3B3B65
1B2B5E0E245C0A225C12286020356530436A6272908D9CB598A7BE9CAAC191A3B8758497
766B7D763A48740B1681030E7F0109720510602A395D5D6D889EAA627980677F81647D7D
5D77755F787559706D5872731F3A4C011538102A434562694A65614F68614F65614D6165
1E353F44505600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00773F13794E42704445
582A2C765857684B4B5D212360060B68070B5F0C0C682E2C6C50515D56585B5D5C5B5D5C
5E5E5E6865666B66676C6768716C6F706C6F7772737D74748077747F72718173717E6D6A
816E6888736C90797395817995837997857B96847A9B897D9F8E80A08F809D8E7C9D8F7C
A39583A09181998C7C9C907F9A9180A19A88A29A8BA59B8FA9A094AAA198ADA59EAAA6A0
ABABA3B0AFA9B3B0ABAFAFA7AAACA4A4A79FADB1AAAEB2ABA8ADA7A5ABA7A6ACA9AFB5B5
AAAFB1ACB2B1AFB4B3A7ACAAACB2B0AEB4B3B9BEBFAFB6B8869092AAB6B7A3AFAE84908F
AEB9B7AEB8B7AFB9B9ABB5B6ACB5B6ADB4B6ADB2B5A9AFB1A6B0ADA8B2B1ACB5B2B0B1B3
B7ABB1B48993903642A01522AC0A14AF070FAA040BAB060DAA070CAA050BA80308A50207
A4030AA4050EA2050E9D060C91090F81121B813442734C68433D671A285D0A235F0C2865
1833683C4D7764688882738B8362768557698753638A56658C5D6B8F6A7890828E9BA3AD
B6C0C8A08B947229347C091581020C78040F6C2635392E406A80895D7579667C7B68807D
5D76725F7572597270557073223D4C0118333550614F676A54686451686347605E3F575F
17314026394604C50700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783B0C78483A794C4D
5224267553536A4C4C642D2E5806075D0A0B652D2D6A4F505E5457545457555758595A5C
5B5A5D6362646867666C686670696C716B6F766E6F7B74707F7771847A7683757282716E
86726D907874917B7594807898847C97837C9B877D9A8A7D9A8C7C9B8E7D9C8F7C9D917E
9F94829D9181998E7C9C917F9E9382A2998AA69A8FA4988FA7A095A7A198ABA69FABA8A1
ACABA1AFACA5B1AFA7AFAFA5A8AA9FA7A9A0B0B2A9AFB1A9A6ABA6A4ABA8ABB2B0ADB2B0
ABAFADA7ABA8AFB3B1AEB4B1ADB6B2B1B6B6B6B7B9B9BCBD8B949594A0A08290908F9D9D
A9B7B5ABB7B5ACB7B7ADB7B8ADB7B9AEB6B8ADB6B6B2B8B8ABB2B1A7ADAFA9ADACB9AEB0
B9899096323DA1141DAF0D14B20A10B0080FAA050DA9040BAD080FAD060EA9050CA6030B
A5050F9F070F93080F85121A863947734E6938355F12245E0725640F2F682F4B77606E8D
7F758B855B6C7F36457D1B2983101E860B1B880C17880C19810B1778141F622931888289
B5C6CDBBBDC7855967720F1F80040F7A040F6A1D2D2F2236758E989BB5B76D8383889E9C
5F75725F75735A716F59707337515E0119304863724C63665467665265654F646B1E3547
031A39071C38068B1200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008846107847357C514E
4F201F774A49663C3B6C38394F13125B282764494B5E54565351564E505354565858595B
5C5B5E626164656566696769706B6D756C6E776F6E78726E7D7870867C77877876857370
86726F91797690787495807996837D95827B97857B9486789A8C7C9E8E7EA19181A49685
A194839B8E7D988B799E917FA39685A39687A4988BA69B90AAA298A9A39AADA9A0ADACA3
ABA9A0B0AFA5B3B4AAAEAFA6A8A8A0AEAFA7ABABA5AAAAA4ACADA9ACB0ACADB2AEABB1AD
AAAFABAAADAAAFB4B2A8B0ADAEB5B3B1B6B4B6B9B8B2B6B6B1B8B89CA6A69BA7A7A5B1B1
A9B5B5A9B5B5AAB5B5A9B3B4A7B3B3A8B2B3A8B3B3AAB4B5ACB3B5AAADB0B4AAAEB4838A
99313AA5131CAF0B12B30B10B1080DAD060EAA040EA9030DAA050CAB040CA50209A2050A
99080D8C11178A343E8057703F3D6812235F0622600B2C63294A72667A93807B89885D6A
7E2B3686111C8E081294061196030F97020D98030C97040F8D08137D1D2A7654658C9CB1
A3C5D7B9CBDA967F916714287C04127B04106E1F2E2E2033506C787E9C9F677F80677F7C
6178765D73715C7071596D6F48616A021C2F405D694965675066694B616922384D031638
01143E04193D024C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00627209774732825A56
55201F7B37375D1516682F2F6742435843465A50555250554D4C52515155525456535655
5C5C5D6261646362676766696F6A6C726C6D746E6D78736F7E787382787688797A847373
857070937A788F7773917D7892807B95848093857C94877A998B7C9C8B7DA49284A09282
9F9382A196839D927E9F9581A09984A59E8BABA190A89E91ACA598A7A397ACAAA0AAA7A1
ADAAA4B1B0A8B0B1AAA8AAA4A4A69FA1A29CA7A5A0A8A5A1A5A4A1A8AAA7ACAEABABAFA9
AAAFA9AAAFAAAFB4B3ABB3B1AAB4B0B1B8B7B3B7B8AFB3B4B1B8B8AAB3B3A5AFB0A6AFB1
ABB5B4A8B4B2A9B4B2A7B1B1AAB5B5AAB4B4A9B3B4A9B2B4A7ABAFB3A7ADBB8B93972E3C
A91521B30D15B2080FB20910AD060DAB040DAD0711A7010CAB060DAA060DA4070D940C11
86222A86506553496F1729620726651031683A5980617991737B8A88717D823F49861723
9409149B050F9C040B9A010A9A010A9B010B9A020A93050D7E131F7545601D26530B3464
5787A9B6CEE296859666192B7C061377030E6F2434291E373B596959787C627C7A667B79
6578776175745D7170576D6C566F72102939314D5E4D6976334C5D10254101123700103A
01113C04173E06152A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A1077A4B33825A56
5A1F1E610D0C600A0C602627624A4C564D515752565250544F4C51524E53555356555557
57585A5D5D616060646766686D6968756F6F76706F7A75717F7773817675857677867274
85726F8E77738D7470917B7693827B92837D94877F95887E9C8E819E8E809E8D7EA09182
A29585A39786A49786A19683A19A86A39E8AABA593ACA596ACA598A7A398A9A79CADA9A2
AFAAA4AFACA4B2B3AAA6A79FA1A49B999B929D9E959B9B95999B97A3A5A2B0B1ADA8ABA5
ABADA9ADAFADB3B6B6AFB6B6ADB6B5ABB4B4B2B7BAB5B8BAB5BABBAFB6B9ACB3B7ABB4B6
A9B5B4A6B3B1ADB6B8ACB2B6AFB6BAACB4B7ABB3B6A9ACB0B0A5ABB78992993541A5131F
B10C14B10910B50A11B0070FAC040CA80209AD080FAA050CA8070CA10B0F8E13188E3F4D
6A4E6D26336808296A0B316D345782647F9570808C808188886771792A3787101B970712
9D030B9D02099C01079B01079A010998020996020B830B148346582A2B53072D6043759F
9FC8E1B9CBDD927C8D6616267B061276030E6E2B3D1F1C3A5272885D7B8288A0A1657A79
6275745F73735F7374596E6F546C6E324C5A0E274118335204173E000F3C010E3A010D39
010F3A02163E04162C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DAE12825336805A56
602729570A07651F1D6A41435E4D50585056534E534F4C4F4B484B545053514E50555457
545558585A5E5B5D616462666C6869706C6C7471707B76737F787581767682737383706E
8974718C7672917B778E7A75907F7791837993847B96867B9A897F9E8C7FA18F81A39484
A29585A79A8AA69988A69A89A59D8AA7A08DABA393ADA499ABA398A8A399A8A59CADA9A2
AEA9A4B0ACA7AFAEA79A9B949A9D959193899294898D90868C8F8892958FA8AAA4A7A9A3
AAAEAAA7ACA9B2B8B4ADB5B2AFB7B5B1B6B8B3B5B9B5B7BAB3B7B9B4B9BCAFB4B9AAB3B5
ADB9B9A8B2B3A9B2B4AAB2B5A9B1B4AAB3B5ABB3B4B0ACAFB99299983B44A61822AF0C14
B00A0FB30A0FB4090FB0060EB1080EAF070CAD090CA8070C9A0B118D232D8D576D4B4671
112B67072C6B234B7D5D7D9B7B919E7F8E9284848986666E75243084091492060E980209
9B01079A03059902049C03089A020A9500098C070E862E3E4C395C07265A3568949DC9E4
B6D0E0B6BCCB8664726A101C7D060E6D040D6B36491519397B99B069838B6E8385647978
6277765F74725E72705A6F6D566C6C38505D01163501123E010F3F020E3E010E39010D37
010F3702163A0D203600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050AF0F82522E795851
623939511C196D433F644E4D5D51545A5358504E5349474B49484B4F4D4F575556535253
56575A56575B5B5B5F5F5E626666676D6C6B7773727972727D747280747383757386736F
89756F8B7671917E79917D7994817A93817995847B96857C9A897C9E8C7E9F8F809F9181
A09383A49787A49787A49887A69C8AA79E8DAFA696AEA499ADA49CAAA29AA8A39BABA6A1
A9A49FAFAAA5AEABA4999A928C8D858C8E838E91848D8F828B8E838E9086A0A199A5A6A1
A3A7A5A3AAA8AAB3B0AEB8B4A5AFADAFB6B6B0B5B7AFB3B5B3B7B8B3B8B9AEB5B9ADB8BA
ABB5B6A8B0B2ACB2B5AFB4B8B1B5B8AEB2B5B0AEB0BD9CA29D4751A01720AD0C13B10A11
B00910B00910B0070CB1060DB50A0FB2090EA80B0F961017903847755274242F660B2D6E
0F387441688E7594A881969E87959885898C90777E772C37810B168F030C920109970208
9701059A03089B02079A000895020A91030D7C0C17824F6B1421511947778DBDDAAFCFE1
BDCDDBA49CAA743948790B1781050E6A0C1858354E0916384B687B617A80647A78617A76
6079745E777359716D5C6F6D596D6C354857011337010D3F010D41010D40010D3B010E37
0110320A233C31475208C90800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B3107C4820795A51
6952505E49456857536158565F57595954564E494C4440444342454B4A4C555254535155
52515659595E5B5D615C5E616262636C69697873737B72737E7576807575827473877672
8A78728C79748F7C788F7C77907D77917E7795827B9A887F9B8A7D9D8D7E9F8F80A29585
A29585A69989A79A8AA69A89A39A88A59E8CACA595ACA499AFA69DA9A298A9A39CA9A59E
AAA7A1A9A6A3A8A7A29A9A938A8C81878A7D8A8D7F8B8C808B8C838D8D8595968FA5A8A3
A4ABA7A7B0AEA1ACA8AEB8B6A4ADAEADB2B5AEB2B5AFB3B6B4B8BBABB1B3A8AFB2AAB3B5
A6B0B2A5AEB0ABB1B4B0B3B8AFB2B5B3B0B5BDA4A9A659629E1B26AD0D17AF0910B30A11
B10710B20910AE060DAF050CB50C11AA0C0F971C22934D615D4E77152A68062C6C244D82
6184A37995A281999D8093958490938D8388753D467A0C188D030F94030D95040B97020A
95010899030997040992040C8C050D8108138231444B3A65092A616595BBB0D7E8B9D0DE
B6BCCB8E6D7F6C15257F061279050D7225343525430D2346557284718889657978627773
6178726076735B716E5A6F6A566C69435864021334030F3E000E3F010D3F010E3C001037
071F3933505F50676A15971600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B80491E775A4F
665B5A61595665605C5F5B5B5854555B55584F494C47424644424549484A55525657565B
5051554F5457565A5D5A5F606364656967687471727872747B71747E7374847777887976
8879748778728D7C768F7E77917F789380799481799A887E9C8B7F9D8D809B8D7F9D8F80
A29383A39484A29585A69A8AA59D8BAAA393ADA79AA9A498AEA89EAAA59CA8A39CA9A59E
A9A69FA7A6A0A7A8A29FA29A8A8D82898C7F888C7E898D7F8B8E828D8F848E9389989F96
A0A6A1A5AEACA3ACABABB6B6A8B1B3ABAFB4ADB1B6AFB4B8B2B7BBB1B6B9AAAEB1AAAFB2
A3ABADA4ADAFA7AEB1A9AEB2B0B1B6BAAAB0AB707996212CAA0F18B10910B20910B30811
B40911B0070EAD070BAD080EA80E1598232E935B753F3F710C2C6E0C35733B638C7191A5
7F979F84989C7E9392809291878E908C6D736E182286061192040E93010B91030A8E020A
8C050D85080F7E0F167B1B247D2C36733646745879122158255282A1CDE7B4D1DFB8C6D4
9F8F9F7630427E0C1980030E6D0811713D5412173A4261805F818B869DA0697D7E627673
6378726178725B74705A706E586E6E4E646F041634010E3B01103F00103E001239102A43
33525D4664665B6F6E17991800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008852227B6152
655D5A605C59625F5E605F615A575A5853554E474945404245414547464B504E54514F56
5254584F5455555A5A5C5E5E6162626968697370717C74757E75757E7473827574897978
8B79768B79748E7C75917E788F7C7696827C98867E99897E99897C9A8C7F998C7E9C8F7E
9C8F7EA295839F917FA09383A19989A59F90A9A396A4A195A9A69CAAA69FA5A39BA8A59D
A8A59CA9A9A0A8A9A29C9D968E90858A8C80878A7C888C7D898D7E888E808B9184929990
9AA39DA5AEACA7B1B2A3ADAEA4ADAFACB2B6ADB1B6B1B5B9B3B6BAB1B6BAA6ABAFA7ACB0
A1A9ACA7B0B2AAB1B4AAACB1B5ADB3BF919B922C38A8131DB00C12AF090FAE060DB2070F
B40911B0060EAD080FA10E16972C398A5A7C2B336E072A7118437F577D9F7E9BA7849B9E
8A9C9D8A9999899897859393939092743F487C0F1A8D040E8F020A8F030B87060C790A12
7D27337C445768496355496C4043692E39671A3066072C656993BAB6D2E6BAC7D5A092A4
814759790F1E8606107B060E7126343D2C4C061A4354749065838B62797B667A7B647676
6679766177725C75715A706F5A6F71566A730A1B3601113901143C071F3E274357435F68
4864664964615A6E6C1DA12000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00637C197D6252
655C5A5F5B586663626161615B5959524D4C4C464645404044424349474A525054525055
514F545353575556575C5C5C626161696768726D6E7972727C73727F7473837676837373
8471708E7A768F7B7594807995827B93817A96857E96887E97897E998B7D9B907E9B907C
978C789A8E7C9A8D7C9A8F7E9B9582A39D8BA59F90A4A092A5A397A2A298A7A59DAAA7A0
AAA9A0ABABA3ABAAA5ABAAA5989892888B7F888C7E878C7C898C7E8A8D808C8F858A9087
959D97A1AAA8A8B1B0AAB3B2AAB2B2ACB1B4AFB4B7B2B8BBB1B7BBABB2B8A7AFB3A7B0B2
A6AFB2A7AFB3ABAFB4B2ACB1C1A3AA98424DA31823B00C13B40C10B20A11AD060EB30A11
B20A0FAD0A109E0E169634437C587E212F6E09307628538B6E92AF87A1AA8C9FA18F9F9E
92A19E8C9B9A849493838F8E998D8F6D2831860B1791020D8D020985050D781A23744459
493F6519245B0C21610621640E316B2C4F814566956080A8ACC4E1B5BACC998395804354
76101E84061280060D711620623F590F1A44103056577687678184627A785E7472607573
6579776176745B726F5C716F596D6D566B7111263803173219364A3F5F6A4C696C4F6969
4E67654A64625C7170393F3C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0041A915806253
6B5E5E615B59625F5C6565635F5C5D554F514E4548484242474444474647515053575557
5150525353555555575C5B5C615F606A6766716C6B726C6B766D6D7D7274827477837575
82716F8F7C7A8F7C768F7C7593807A94827E92817B93867C96887C968878988C7B958978
938876938777938676988E7C96907C9A94809E97869E998AA09D919F9E93A4A49BA9A7A0
A7A59EABAAA4ABA9A5AAA6A3A5A29E92938B8E9085878A7D8B8F838C8F848E92888F958D
98A09A9CA6A2A5B1AEA3AEADA9B3B1ACB4B3AEB4B4ADB6B5A6B0B1A4AEB1A3AEB0A4AEAF
A4ADB0A9B1B5B0AEB2C2A9AFAA68729B202BAC0F17B20A10B70C10B30A11B10A11B0080D
AD0C1099101599424F6D557C172F6E0A34793361917598B088A1A88C9EA091A1A192A0A1
8E9E9D8D9D9C8396947E8D899186856D252B880A1494030E8D040D7C121C77475D1F2050
06215D1C3F7A2546840226625B82ADB4D2EDBDCFE6B8BED6A498AE8F61767A293B7F0E1C
85050F82060F73141D73455D1E214A0A26555C809D64828C99B1B4687C7D5E73745A7370
6177756377775F73715C716F546D6A546C6C314C513250574664684C6B6B4F6D694F6A66
4E68654966654761633D4A4A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048AF1B856858
6E606068616067635F6968645F5D5B524A4C4B4044493E424C4346474143504B4D575554
514F4F504E515553565857595C5A5A6661606F6968716C6B756D6D7B7170807474867979
8F7E7F927F7F917D7A907E7791817990817A93817B928079907F7491827595877A938678
958878928573948573968976928773958B779A92809993849794889C9990A1A097A8A59E
A9A7A1A6A5A1A8A7A4A9A6A5ACA8A5A29F9B9A999496989193968E999D969AA098959B95
9BA29E9CA7A2A2B1ADA3B2B2AAB7B6B0B9B9ABB0B4A7B0B2A4AFB0A3AEAFA0ACACA3AEAE
A0A9ABA7AAAEB3A0A8B8828C932C37AE1820B50E15B3090EB3090EAE080CAE080FAA0A0F
9A121795425363517B133072093679426C9A83A2B790A2AB91A1A48D9DA08F9FA28E9E9E
94A4A48B9A9B82929182908F97908E743339870C1594040E87040A872E3A3F274A071B52
0E31668EAFD2AEC7E54F68888FA2BFACAFC4A08DA29161777E2D42831627880A1588060F
7F060D75182276485D2A2853041C4F28496E9FBFCE7D959C788E91697C805E72725C7471
6177756379775E74715A726E556E6A576D6B5269684F68664D68664D6866506D694D6A67
4A686A33515C0E2A3A35474F0ACA0900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049B31C856B59
6F6462625B5A696561686660645F5E52494A483E404D42444E41444E42445246495A5154
534F50504D4E5553555958595D5B596762616F6769736D6C78716F7B707182757787787B
8F7D7F8F7B7C927D7B93817B93827C917F7B927F79907D758B7A6E9080728C7E6E8E8172
8D80708C7F6C91856F928771928771918671968A78968E7F918A7E9894899D9991A8A59F
A9A7A2A5A5A0A6A7A3A8A8A5ACABA9ACABA7A5A6A1A3A7A2969C969A9E999B9C979C9E9A
A5A9A7A5ADAAA5B0ADA1AEADA5B1B1AAB4B3A9B2B4A1AAACA1ABACA3AEAE95A29F9EAAA9
9FA7AAAFA9AFB788929336439F1923B00F15B20C13AF0A11AA060CA9080EA3090E940F15
96425363507C1330720A397F4A74A286A2B695A2AC9BA2A8999EA2959C9F95A0A1909D9E
8D9C9E8999998595948491928A8C8D8254597A10198F060F88050C83243155304E30355D
6A7A97A5A9BEADA6B98D7A8D8963778340548021378710248E08178D040E8A050D7B0A13
762632724D6B252858051D551638605A7A8D748B927284886A7E8065787A657876627672
6076725D75735C757257716D546F6A546D6A546A675168654F68634F6A6653716F49676C
2A4756051E3901173531455615971700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB71D80644A
6F635F665D5D6B67646A68656A6565574E51514548513E41492F324D3438534347564D52
5853574E4C4F5452555755565C5A586863626E6768776E6E7A706F7D71728576798B7B7D
8B79798E7A7A8F7C79907D79937F7C917B778F78748B746D8E796F8D7A6D857666867969
8D806E91846E91856E998D779588749488749188748D87748F8C7B918D819693899A9891
A3A39AA7A89FAAABA4A8A9A3AAABA6AEAEABABADABA2A7A49BA29D9AA09CA0A4A0A1A6A2
999F9CA4ADAAA0A9A7A3ACADA8B2B2AAB4B3A7B1B0A5B0B0A4AEAFA6B0B19FAAAA9EA9AA
9DA1A4B6A0A69649549A1E2AA81018B10C12AC080FAB0A12A80A11A20A0F9410168A3947
614E75102A6B0935784A75A18BA1B69A9EA7A69FA5AC9BA3A98E96AA8E96AB969C9F9799
9597988A94948896968693938A91939A828770222C830A1589040D840916882B3F834258
864D5E8542537F2E407A1A2E7E0D208808199107169506119208108309107A1A237D4357
54446915215904215C1739675D7C93788F9775888B7F8F926E8082667A79617572637673
6176736278765B737159726E546F69526B65536C66526A654E68654A67693D5B66153148
02193D00113A01153A294055169B1D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B81B7C5435
79665E645C5A6A66636D69686A6465594D51574246522D324312164B2024584045554C52
57555A4E4D525353555554555E5B5C68636570686B786D707A6B6E8373758B7B7C907D7D
8C7A788876748572708D7978927C798F77738D736E8B70698D736C8A73678A7668918170
91846E978974978974988974978975978B79938B78918C799A95858F8C7D8B897C929286
9D9F92A4A69AA7A8A1A6A7A1A9AAA5ABACA9AAABABA7AAA8A1A6A2A0A5A19EA4A1A0A6A4
A3A9A8A0A6A6A0A6A7A1A9ABA9B1B3A9B4B4A5B2B0A3B1AE9FADAAA7B4B1A6B1B0A6B0B0
AAA8A9A67C828C232DA4131CAF0F14B10B10AD090CAD0C11A60A0F980F129039446B5579
132E6B0D37774C71998D9AACA18E989F707C954F5B8B2E3D8B21318C20328C2C3B934A54
9B70769F90948D949686959594A0A1A9A7AB876067721E277F0A13890511880612830715
820915890C178A07128B05118B030F8B050E87080E810D137B1F277D4252634B68252959
081C58041E5E173A6C7EA2BF7D98A5A2B5BC798C9091A4A875888D697D7D697D7B627474
63777564787661777459726E566F6A536E69506B6850696A456068264156071E3E01133D
000F3D02103D01123B1E364F2A323400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058B91880512C
7B645A645C5B6C68686D6769675E5F5B484B5633374F191B460C0D471A1D5A4047564952
5754595455584F51535354565D5C5C66616370676A766B6E7C6F718377768E807F917F7E
8F7C798F7C788874718F7A778F79768D75708B736B886E678B6F678970658B7769907F6F
8D7E6B8F806C9C8D779F8E77A0907B998F7C96907D94907E918E7F908D808F8D808C8D7F
96968A9F9E95A4A49DAAABA6AAAAA6ABAAA8A8A8A6A6A7A5AAACAAA7A9A8A4A9A7A5ABAA
A4ACAEA0A8ABA0A8ACA1ABAEA6B0B2ABB6B5A2AEACA9B6B39BAAA79EACA9A2ACACA5AAAC
BEACAF9951589E1A22AC0C14B20C11B10A0FB20C10AD090FA00E13912E387D628119336F
103779586D9A9A8BA09257648A2A378D1421920D18980C189C0D199A0E19960B1793101C
8317249959629D8E928A9598839496828D918483868B6F7374383C74191F7A0C157E0813
7F0611850814840912810912790D18771D267A36407C50635B4C6B282D5D0D1C550B1C57
203163556289535F7B9BA6B78A939CA4ADB37C8B8F6E81856A7F81667B7C667B7C627676
6479776377755D7371596F6D56706C546E6D4E6C6E375461102A4401153B01103C031141
000E3F010D3D00113B1328452C373E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059B71587542C
80665D6A63636B696A6F696A6E5C5F5D393C551F23571C1D4A1B1B4C2F30524144554A4F
58545758575A51505552515659565968636473696E786D707C72718479788C7F7D907D7D
907C7B8F7B788F7A798F7A798D76748D757189716B886D66866B62876F628B7667877463
8C7A668F7F689A89739B897391816B958B769D97849592829290839192848F908395968B
93948B9C9B96A6A5A0AAAAA6ACAEACACACABABAAAAABACACADB0B1A8ADAFA5ACACA1AAAA
A2AAACA2AAAC9EA8AAA2ACAEA5AFB1AAB4B3A8B4B1ADB9B69CA8A59DA8A89EA7A9B2AFB3
BB949A922E36AC141BB60E14B40A10B4090FB40B10A90B1198252F966A8922336D1C3D83
5D62989263848A293D9513219D0E189908119609108E0B14840F1884161F89101B940D19
910B187E1622986C748A90957B9395819698A5B3B48C9194837F837561696844526B384C
6E354A713449733C4F71465A694E6753496A2F345D152153111F54252F624D4872654B6E
744A64763F5377384B76394877455084616985777A767C7C7484836C7E7D657877647776
657A766478765D73725A6E71546C714A6772254157051C4000123E010D40010D40020E42
010E41000F3E00133910284032434600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00936139
856B6371696B6E696A7164666C4B4E571C2058171A5524234D2F2D4C3D3C504544554B4C
584F535D555A58535757545759575A686367736B6E756B6C7C7371857C7A897D7D8C7A7A
907A7A8F7A79927B7C90777A8C7274876E6C866E69846C65836B60897262846E5C867360
8E7C678E7E6696886D8D7D648B7A60978A7399907D9A968894948891938691948995978E
99999192928B959691999D9BA4A9A7ACAEACA8A9A8ABACADA6AAACA5ACAEA7AFB1AEB4B7
ABB0B3A1A6A99DA5A7A1AAACA3ADAEA3AEACA3AFABA9B5B1A2AEAAA2AEABA5ADAEB8AEB2
B0747E9B1C28B20F17B50A10B80F15B20A0FAF0C139A141F995772393B711F397B5A5189
853E6392182FA10D1CA20A14990A108B1119872933874A5A76566D6B556D8B5C6F811F2D
8D0A15840C158244525B61716787937A959ABED1D49EADB178888F6C7B863B4B601F2C52
1A295A1B275A1A2A591222560A1D540A1E5710225934396866507575405C742238780F23
7E081B8207168206168006157A0814720F196D2229815A5C8D85847D86876A7A7C657777
677A78617574596E70566C753F586B162E4F011341010F43010C41020E41010D3F010E3F
02103F00133C0A233E334F5C43525500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0096663B
88716771696B6E6566765B5E612E315C1B1C551C1E5733344E3B3B4B40404A3F41554A4E
5A4F5660555D5D535A5E585C605A5F6C636873696C766B6D7F75768A80818A7E808B7C7C
8F7D7B8F7C788E7A768E78778A71727F67667E6964806A6282695D886E5D8C735F8D7863
8877608C7D6595886E94856998896DA0937A97907B99968792928593958A8D90868B8D86
8F8F898B8B868B8C86878B869BA09DA6ACABA9ADADACADAFA9ADAEABB3B2ADB6B7ABB3B5
A5ACAFA5ACAFA2AAACA3AEAFA3AFAEA7B2B0A8B2B0B0BAB8ACB6B4A9B3B2A7ACADC1ABB1
9A4854A51723B40C14B80D13B40B10B00C11A01019953E554A3B692B3D75796C9A853453
9B1528A20917A108149410197F212E76445D564D7427376B0F2A6310295B5148687D3143
890C17890B1482394E303254587B9574909A83969D7C8C9476899167808AA3BDCC5D7799
032558305887668CAF6D8CAF6A7EA4595C7F705673703049761529800A1B8705138D040F
8F020D8E010A8B010A8B010B87020A82010A7C060F6E12197D4A4E7D72746D7778687879
62757564797C5A727D2F4860091F49011448020F48010B45010C42010D3F010E3C01103D
001339122F4936576149646846565618971400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A17646
827164726A6C6D5B5C653E3D6029285F28285833354B373A493D3F4C42434B4044574A51
5C4F5660545B5E545B635961655A626F626974676C796D7085797B8C80818B7E7E8B7B7C
907F7E8E7C798E7B778C767388706F806A687C665E7C66597D6658876F618A73638A7864
8675618B7D699488739A8D78998B749C8F7A99917E9996859291858E8F8391938894968A
8F90868A8A8289887F8989818C8D879EA29DA9ACA8A9ACABACB0B0959D9CA6AEB1ADB5B8
AAB2B5A7AFB2A3ADAFA3ADADA4AEADADB7B8AAB3B5AAB2B4A3ACAE9EA7A8AFAFB3BD9AA2
8E2A37AB111EB40912B80D14B30B11AC101792263679587B3743738777A28835509D1322
AA0D189E0C178D1B2987485F574C78182E6A092A6E1038752F54826173938C7085791E2C
8F0B168A0B1681395128285235567772919E768F93A6B9BE94A9B52D4A5CAACADAACC8DC
3E5F7E678BA8B4CEE0A8AFC08C768A79384E7814278508178C04108D020F8D010D8E020B
90010B8E010A8B00088A020987010885020A83020A7D060F690E1782565C767574687779
61767C5067771D375502174501124801104901114A031046010D41020E3F00103D02193E
1A3B5140626A4868674A646447595916961400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A67744
8671627E6D6E67464663322E653430643F3D523B3B473B3C44393B4A3D414F404654474D
5A4E525E54595C535A60565E62595E6C6267766C707B70747F7478867A7E8C7D808F7C7E
8E7B7C8E7B7C8D7A79887472826C6B7D65637D645E7F665A7D6558846E62867164877566
8878668E7E6E9084719185719386739D917FA19787948E80908F83999B8E98988D97968C
96938A8E8B838A89808B8B818788818E90899B9D97A4A6A1A9ADABA9B0AFACB5B5ADB8B7
ACB6B7ADB5B7ABB3B5ACB5B7A8B1B3A9B1B4ACB4B7A9B2B4A5AFB1A6B0B2AEADB1AE828B
8E1F2BAC101AB50B14B40A13B20D159B121C9E5B71474066877499893650A01526A90C15
9C101791304171486E2E38720E347B0C3979335D8C6989A68091A39A88947E3944860E1C
920912830D188048641B2252476A8D8FAEBD546F78B1C9D0C0D5DF718A9983A0AF9DB8C7
768E9F6877888B8291835564751E2E8009188A030F92020E91010A8F000A91010B90000A
8E01098A00088A01098901088501078301087F00057F010974040C6D242A82707366767C
465F73122C5002174901114A010E4A01104C01114C010F47010E4002103F01153B1D3E52
3F676A496B684663614D666550626217991700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA23
8E6E5D8464655A29286E3A3575514D604948503D3E493A3C493A3E493A414D3F4653464D
574C535C535B5D545C62575F635A6067606377707272696C83797D83777B897C808D7D80
8B7A7D8C787A8D78788974728167667F625F7E615C7F635C80685D846D61836F61867365
88756893827396867591826D9C8D7B9C8F7F9E9384938C7F91908497978D9594889A988C
9C9B909091889091898C8D858A8B848689828F938DA2A5A0ACB0ABADB4B2AAB3B1ADB7B6
A9B5B4ADB8B9ADB6B8ABB3B6A7AFB1A9AFB2A9AFB4A8B1B4A2ACAF96A0A7A6A4ABA4717B
911926AD0F18B00911B40E15AB1018A0333D865A6E876684913C56A21727AF101A9E111D
8D35486A537B1D367409377D22528A6389A9809BAB8A98A09B8B918A4853871320950713
9107117D192A65446D0B20595A7EA6B5D3E47E97A17D959E90A7B0748B99536E857A96AB
9EADBD7D6D7C793C4B7A121F8506128A020B93030C93020A91020891010A91010A90010A
8F020B8C010A88010886000983010982010683010782010A7B040C630D156B505C42546E
09244F00174D00134D01114D010E48010F4901124B00124701114202143F0F2A443F6569
4A6E6B4B6A654863604B6762556A671CA11D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B91F
9166507E53535C2727764A476D55535A4B494C3C3B44353547383C4B3D4450434A52464C
584D545B515960565E635A61675D626A6063786F717F757982797C837A7C857A7B8A7C7E
87787B8E7C7E8C78788A73727F6462785D597C615C7F645E846960866F64867062897466
8B786A907D6F9B8A7A9685729C8C7B9B8E7D9B908197908295938697988B96978B9C9A91
9C9B929799908F92898D918892968E8B8E88898F89969C98A5ACA9A7B0ADACB5B3ACB5B6
AAB4B6ABB5B7ACB5B8ADB5B8A9B0B3AAAFB3A9B1B4A6AFB1A3ACAF939AA0B1A9B0945761
941620AF0E15B40C12B30F15A21517BD656AB67D89953F4FA11826AD0E16A2141D9C4258
6854811531750B3B7F3664967396AF8BA0A88F979CA28E968A475387142397081696040E
880E1985435E28275E06276540688D7895A57A9199748B9799AEB9B2C6D7223D5C314A6B
7B738A6F31427B0E1C88040D8A02088F020A93020B93010B90000991010B8E010A8A010A
87020984030984040C84030D84020B84000986010983010A7A020C61081A472A480A1746
01154E01145201135201125001124A0013441129521D375F01123F01153A2D4E5D4A6C6A
51706A526D6A4C65624F6864576B6922A72500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057B81C
9763467B4B455D2F2D765856695A5B574A49493B384737354838384B3C3F4F4044504147
5749515A4F565C5359605A5E655E616A60637C717481757883777C84797C83777987797A
87797A8877788B76768970707F6463755A56765D587B625C816960856F62887063877061
8C7668907D709987789D8E7C9E91809D90809B90829A938795938793938A95958E9B9A94
9B9B9593958D8B91878F968B8F948B8D918A858B858F9792A2ABA7A5AEACA9B2B4A8B0B4
ADB5BBACB6B8AAB4B5ACB6B7ACB6B7A9B2B5AAB3B6A7B3B4A3B0B1A5AFB2BAB0B69D5B66
9D1824B20F17B20C11AD1014A22325E68E92AB4F57A11B26AD1116A31419A2475765507C
1130740B3C7E4F7BA5819FB391A0A99B979EA4848C883C4A88122095061397050F8B0A15
88384C4E3E690A2462143A6D61869E89A2AABACDD65A76876D8B9DBFD6E67F8FA5675F76
692F42750C1984030D8A020A8D010790010990010992010A9001098F030C89030E7F0610
740B1270131A711B2372162175081283041085010B7E01097206134A09261A0F3D05134D
001252011355001254001650061F492847614A667D1A325100153E051A3B3F616D4B6C6A
53706B516C6947626249646552696B3E494700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0D
995D386E3C3171504B776765645A5B5448474C3C394A38374736364E3E3F5245464E4243
574B4D5A4E535F545960565B665C626D61687D6F7780717982757E84777D85767A87797A
8B7B7B8B787A89747686706E8168647A5E597C615A7B625A806A5E846D60886F63907869
8772638B786A8F7E6F968878998D7CA094849D93869692849394879C9C9398989095968E
9798919599928B948A98A3999BA39A8B908A8C928C8E97939CA6A3A3ABACA9B1B3A9B2B5
AAB4B6ACB6B8A9B4B4AAB4B4AAB4B6A4AFB1A6B1B3A6B2B3A6B4B5A5B0B1B6ADB2A3616C
9D1822B10B12B50E13AD1216B9353AD15F679F1A24AE1119A711199D39496E547C142F73
0D3E7F4E7AA38DA8B989929B9B8D959B6975862837921020970712950711890E1887384D
594470102764133A6F8BAECD6A889777939EBFD7E0A7C0CE657F8F9AABBA958A9A703645
750D1A82020C8700088900088E020A9001098D00088C020989040B7F08107717237C3B4A
724F63594A64453F5D4D3F59734052710C1B7E030E77020F5A072224083707104F001357
001354011553011A4F18385D395C6E4D6E783F5C6E04193B0720470A254040646D4E6D6C
53706C4664663A5761142F401F3B4944545900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
92572D744A3C745F5D736B6B635C5D534745503E3A49353240282A4E3A3B524445504647
5247495B4F5261545A60535A675A616E5F667E707781747B85787F83787D84777A897A7B
8B7A7B8B787A8B78798874737C6561755B55775C537A61557F685B886E638970638D7666
8B78698D7C6D8F7E6F96877A96897D988E8299918496938493938598988D97988E9A9C92
9396908C938D9CA7A3C5D2D0C9D3D2B6BCBB8D93908C948F99A29EAAB3B1A7B0B0AAB4B5
A9B6B7A7B6B6A8B5B6ABB5B6ACB6B7A9B3B5AAB5B7A9B4B5A9B4B5A4B0B1B5B2B4A56D72
9D1E24B71217B80E15B00D13C9303AB41F28B3121BB0151D9D2A39875E821D33730E3B82
47719F8CA0B39C969D9D7981893E498B1A26960D199B071693091481121E87465B514370
0E2568082F704D769DB6D5E796B0BB6F89957E99A1829DA5788F998B8C987F505E781220
8A07128B000A8801088800068D01099102088B04097B060C79222A7B49595C4867292D59
102054061B5208205210224B51415B691B2D78061564051B31072F0E0F4C021359011359
0216530721512A4B6752727C5573784D6A741A365001183B27436308233B4465704F6D6E
4F6C6B39556208203C00143803193441545E08C80800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8E572676544474635F726868675D5E574846533A374A2728441D224F313857414855474D
564A4F594D545D51596556606958627060687A6D747E727882777D82777C827478897A7D
8C7A7E8A757A8B76788872727E6664755A56775B527A5E5480655B896E65907A6D8A796A
8D7D6D9384749285759B8E7E978B7D968D8196918395938396968796978B95978D91968F
7B837D7D87839CA9A89DACAEC6D1D6C6CED3888F908A918D99A39EA5B0ADA4AEADA6B0AF
A6B2B1A4B0B0A8B3B4ABB5B7ABB5B7A7B1B3AAB5B7A5B2B3A3B1B39AA8A9B3B5B6B28488
952127B51218BA0D15BB0E18BA101ABB1019B81118A91F269852693836681D3875546696
968FA7A177859547548F202E96111E9B0D15980A13890C178126367D54733336690D2A6F
0732723D66907394A88098A27B939B768C9678949BB6CFD57C89958A748271202D870815
8E030C91020C8F020A8C01088F020A8F0209850C10873D4754405B1D2858091F5906225B
11316037577A728CA5717D8E7C65716313206E0819450424170B4104115901135D011756
102C58405D755371785975775D797D385366021A3D122B4C3C58720218343A586C4B6975
3853660B224300113C020F3C0112332F435312961700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
915C277E5D49634C48715F5F6A5D5E594546522B2C440C1049121750292D563C42524048
574751594D565F535D65586168596073636A7B6D757D6F7882747C83757B827276867678
8D7A7C8B73768A7174897070806763765957735753795E577D625B866D65927B70928072
8F817197877999897A998B7B968A7B9A91829790839390829A988A999A8F999D95858D87
737E7A9FA9A8CAD7D8A6B4B9B7C3CBBCC6CC848A8F7E84828C9591A2ABAAA3ABADA5ADAF
ABB4B4A7B1B0A7B3B4A7B1B3A7B2B4A8B4B6A4B2B3A3B1B29EACAE95A2A6AFB5B7C1A2A5
8D2C31AD141CBB1019B70A16B50912BA0F18B31118B4373FB172857457797F597C934F69
922E41981C2B9F131FA00C199D0C18920F19821E2B824960584C73172C6606296D16407B
4C74997795A68298A082939BB6C7D093A8B7446173BCD1E2A8A7B67842507F0F1B8E050E
91020B92010B91010A90010A90020B8F030A800911783449281F470A2056193C694C6F8D
6D8D9E738B957A838C88747C6D2F396D091565091F2C052F0B105003135F01145A143162
4B6B815773785672715A76774D6A760C254500183C2F4C63445E710115380B2148183356
051B42011141010D3E010C3B010F361C2F46189E2200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D662E855E495B39367259596D5A5B583D3F4512134C090B5012144E2326543D3E524348
55484F574B525D515A62555E6759607263697B6C747F6E7782717983727A807074857678
887678857273897273886F6F8166647B5F5C735652795C587E645E876F688470658E7C6F
9383749787789787789B8C7C9486789E9286958E81959283959486949688989D927A827A
78837F8A9695C2CFD1A8B6BCB2BFC5A9B3B98A9194848A88949A97A4A9AAA5AAADA7ACAF
AFB4B7A6AEB0AAB4B6ABB5B7A7B2B4A4B1B2A2B0B0A6B4B4A7B3B4A7B1B3ABB4B6BBACAE
974B50A11720B50F1AB90F1AB60D15B70F16AE0C13AF242FAA3F5089263E8C1C319B1828
A51420A80F1AA50A159F0D188B101D7E2A3A8A637F454474102A69052E711640756085A4
7694A295ACB192A6AC80919DC5D4E0A5BACB29455B93A4B79586946E2230890C1690020B
91010A93010B92020B8F030C8D010A8A020A86050F791B2C63405B35415E6784987B98A3
93ADB2859297887C8379454E6E0E1B7406155606221B0638050F5201125D0117532F4E6E
5B78805E76775D767459757C2A465D00183D0A26434563724A6572061939001340001242
000E40020E42000C3D000D3B010F3710233C1DA52A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A16A2F885C465C34317356566F595B593536480B0B570F0F4E0D0E4A2020553E3F514246
55484D584A5161535D6556606A5A6275626A78656D7D69717F6C747F6F777E6E72827475
847575847374877273876E6D816664785C577659547A5E598066618670698A766D907D71
928273918172908272928575978A7B988E819A938696928598978A999A8D9A9C927D837C
727C798994939EA9AC8592998D9A9F828C8F888E91898E8EA0A6A5A3A9AAA2A8ACA7ACB0
ABB0B3A8B1B3ABB6B7A9B4B5A8B3B5A7B2B3A4AFB0A8B3B4A8B2B4A9B3B5A7B2B4B1AFB1
AD7D818F2129A9111CB10D1AB30C14B50D13B00A11A80D17A0111EA31221A7111DAA1018
A80F15A2101896131E8A25358D4F66705A7E2E3A6E0E2D6C0B32712A52825F84A17F9CAB
829BA1BACDD2B0C4CB6D7F8CA5B6C2B5C8D5758B9C7D87988C6D7C6F131F89080F8F030A
8C01098B040B83060C800B137B081080050D87040D7C081575303F9F939FA0B0B88DA2A7
ABB6BC8B7E867D4A557116227B071373041549092A11084003105501165A0421524A6A7F
5C77795D75755A74774866760C2647011A4024455B4C6B73506C740D213D011341011043
020F43000C41010E3E010E39011036091D38323F4500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A902587553D60332E765653715655522221520A0A590E0E4E1212532D2C584241554647
594A4E5A4A4F6151596756606E5963775C6577555E704E5677606878686F7E6F73827374
8374748372728772738B72718469677D5F5A7C5E577F625D836B6686706A8B776F907D72
8F7F719082728C806F928674948A7A928B7D9A95889693869594879694899E9C958A8B86
6B706C737A7A6972757981848F98988289878B908D969997A7ACACA8B0AFA6AEAEA5ABAD
A7AEB1A8B1B2A8B4B4A8B4B4A9B4B5A9B2B5AAB2B6A6ADB1A6AFB29AA5A7A5B3B4A9B2B3
B6A8AAAE6D74921521B11521B40B14B80D14B40E13AE0E15AC111AA50E17A0111895141C
8E242C8F3E4F8754706858812D3A6F0D2F6C0A33702A53845D82A17794A5AAC1C9A1B6BC
7A9197A0B3BCB1C4CE889AA680939C8C9FA6A6B8C08083907C4C5C7B0F1D8A040B8A0309
83070C7B1B2480415171475D704359702937760C15830611730B148C545DC7B8C09C939E
8E6F7D74303F760F1C82051280030D6D081B360932090D4A011357001B54294C6C5C7B83
6078765F75794D6876153151011C44102F4D446771516F6F557073243B4E02163D011142
000D41020F41010F3D011036031939031B3339474E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
55B71B814C2F6A3D367B5B5872524F531F1B510D09541615582C2D513736524040534546
584A4E5D4D5464535B6B586071525B6B3A4465242F7036407D5B6274626878696E77676B
79686A8571738973748C7373856A687F625E7E605C7E615E81686489716A8C766C8D7A6F
9180729181728A7A6A928574928A79918A7C99948897948894918696948C99989195958F
92958F878B87949A969396948A8C8880827D858883979C99A2A7A6AAB0AFA8AEADA1A8A8
A9B1B2AAB3B4AAB4B4A8B4B4A8B3B4A8B0B4A7AEB3A8AFB2A5AEB197A3A5A6B4B6A4B2B3
ACAFB1BA9298942733AE1622B80F17B51014A71B1F9E303A933A479247577F435888607D
6E5D824346771D336D0C326E123E75345C8A5E83A389A8B99BB4BB889BA2A0B1B5A4B6BC
859B9F85999F8EA1A6A5B8C178919E9DB8C4B5CFD96B707F723C4E820F1F8B030C86050B
7E1C257348602326510A22531229505049606E3542730A147F0611750F1DA45B6A7E3949
7318297E081885040F80040D7108126A263C261541051351001752193D62537886627D80
60787D516A7D173252011A4508284B3E6173516F7357716F57706F4E6671061D3C00113F
021044020F4200123C06203C314F611931423A4B500BCB0A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59BA1C814D2D784D477452526949454B221B4D1D1758322C553E3B4E3D3D4E3F4153464A
584B525F4F5866525B6D51597448506A212C670C166D1F277F5459705B61716168726166
7664677D696D81696E856B6F896E6D8468657E615E7A605C82696488706A8B736A8B766A
8F7D6F907E718977699385768F8577928A7E98918696928896938B96958D96978F9D9F98
979C939AA097979B959395908C8E8882847E8D908C969D9BA0A9A9A2A9ABA5ACADA1AAAA
A7B0B1A9B2B2A9B2B2A7B1B1A6B0B3A9B2B6A8B3B5A5B0B1A6B2B3A5B0B2A5B2B4A8B6B8
ADB1B4B58B9292202BAE131CB40C12AA1217B352628363874F55823E507D253F6E17366E
10346D1940773157884E759B7195AE84A1AE869EA59CB1B5A4B7BB92A1A690A2A58B9DA1
93A8AB849B9EA3B6BBC3D7E33A576D55788EADCAD69198A6703F4E7F101C8D060F85050F
8831413D25470E23563E5F907E9DC19DAAC096788575232D7E050E84030F8109167E0614
83061284050F78070F6B141C6835463F2F500A13460215501333604A70865F8089627C88
446078122D54011A4808244A3E5E7255747A59737458726F57706E596F73374E6004193B
00133D01163F102B4936576447666A2C454E374B5016991600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2DDD0D7E472187554D62333474504C52342B53372F55403952433F4B40404D404353454B
5A4C54624E5867444F703C4767232B6F17206E0911650F157D4B506D555B726065726265
7B696C7A666A7C656A775D61876D6F8469687F63617C615E80656289706B8A736D88746A
8F7D738F7E718D7D6E91837595897E968C82978F869892899A978F99978F98999092948B
959A92989D97979C978C918B898C8684877F979D96949D99919B9B8C9697959E9F818B8D
97A1A2A1AAACA7AFB0A8B2B2A9B3B4A7B1B3A6B2B3A2B1B19CA9AA9AA6A7A5B0B2798689
95949AB8828B991C25B10F17B60C13A91420A75A78272F69134284406EA05177A06184AB
7697B681A0B78BA6B48BA4AD89A0A58CA0A38B9FA08EA1A48DA0A393A5A88A9D9FA4B9BC
C2D9DF6A848E839DA6AFC7D3728C9F607C91768D98959DA5825E687716208C081188030F
781120783E5A513E608F88A795849F87677B8449577C1C2881060E87020B88020A85040B
7B070D6C1019662C3B5038501F214606154801164F00164F1F3F6A4B6D8A4E6C852D496B
072353011B4F07254F395A6F5B777C5D76775B737356706D587270546B6B5A72773E5764
1C37482A4A5744646B4B696B4D6969334C522E444821A62300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008345177E403164292677504C5C443E55423B56453F5243404F404050414357494B
5E4F53694C5457232C6A21286C171E731A1E690F1461171C6F4349664D55705D626E5E60
7665667B67697C666A7A626582696C806769806666836766886B6A896D6B876F6A88746C
8A786F8A7A6E8C7F708F837496897D968B81978E859A948B99958D98968E999990999B92
979B95949A95969B98878C888589828C91898A938B7F8982808A867B86827B85847E888A
919A9E97A1A39FA9ABA6B1B2A6B1B3A6B1B3A2AEAFA2B1B1A3B3B3A3B1B2A6B1B398A2A5
AAA1A8A766709F1A24B60F18BA0E15AB101CAC536E393C7130609782ABC88DA6B492A6B0
96A9B093A7AC90A3A791A1A693A4A78FA1A48CA0A18DA2A39BAFAEBFD1D595A9AF94ABB0
B1C9D177929C7C99A07F999E93ACB77792A966829AC1D4E29B8F976E2A34810D1689050F
820410780B1B74192D711C33731A3075112577091880071182030A850208830409790E13
7E374467476026274A0918470218480C28522C4B720A244F011B480A245406205001194D
011C500E2D5641637957767C5E7778667B7C5E73735A727158716F57706E5A7374536D6F
4A686753706F59757254706C4F696930494F26404437443900FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4C16702E1764261D7F58535F4D475648425748434F3F3D513E405440425C4749
5F4648653F435F272C66212361191B6825286D34376B424565494F624B556551596B585B
7563647663647762647960647C63667F6568866C6E8369698A6E6E846A67846C668B756D
8B796F8B7B708F8375948777978A7B968D8097908598938C99958D999790969590989B95
919791949D979198948389837C817B828780777F7876817A77827A7A847F7B8280828A8D
869193929EA096A2A39DAAABA5B1B3A7B2B3A4B0B1A4B3B3A4B3B4A2B1B3A2AEB1A8AEB3
A999A0954B54A61721BA0E16BC0E14B20E189A283E705480274B7B7FA6BE96AEB49BAEB1
9AABAD97A8A997A7AB96A3A990A1A69AADB0A6BABB8FA4A694A8AAB4C7CC86999F889CA2
879CA298B0B68CA9B27B9BA5B8D7E636577A092F5C7EA1BCA2B1BA8A6F766F232C7D0E19
82060F8404108003108004127E04117E04127E06107C060E7B040B7F02097B060C863844
49324F0F194803184B1029562948665677886A8793455D70162E4C041C45061E48132C52
2E4B68506F8058787C5F7C7C617B7A657D7F6277795F74765A7273597072587072526C6B
49666256716E536D69526F6B4C6968223D442441463C4D4400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0099591E642307652A1F7E5753624E4B56484353443F513D3D543A3E5E3D435E393E
5E3639693C406533365B28296D404069424767494E654E555C4A525F4C56634F58665258
705C5F7461637661647C62677D62667E636685696C866A6A8A6E6E896F6C87706A917C75
907E758F81779084779487789A8D7D9991839792879A968E96948C9A98929E9E99969A94
898E898F97917C867E727D746D776F6E766F727C7676817C77817D747F7B757F7D7E8889
828E9086959592A1A195A4A4A5B1B2A4AFB1A7B2B3A5B0B195A2A4A2B0B2A4B0B3A6ADB1
B29FA7904048A9161EB90C12B90A10B50B129E101F9750722C35636E92B293AEB79EAFB3
9EADAF98A9AA97A6A996A4A997A6AC9EAFB3A4B7BB899BA292A5A98FA2A597A9AB92A2A9
90A4AAC2D9E36182983159739CBED557779510345B3D657E9BB7BDB4B8BC91777F763B46
6B1D286A0E1C6C0B17680914680D176816206A26307C3A44812D3776050E77070F7E3C4C
25183B0E194725335877869E778591636D73676D70676E715E6D724F636F50687557717C
5471765673735A78755B79765C7A75627C7B6077786074765E77775B73755A7174546E6D
4C6A6753706C4E6965526E6A4F6C6D122D352E4B50485A5000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007483155E21046C3730774E4F624A475A4B455845415A3D3E54282C5B252C612C33
65343B6C4045613A3F5E3D41654A4F654D56665059655159615159594951624F56634E54
6853586E585D755F63785F627D64657E6567866A6B8A6C6E8668698A6F6C856F6A8F7C75
8B7A7291817B91847B93867995897C9991839A948795928798958D9898919999938B8D86
777C747C817A737B736D796F727D74737E7678817A777E7B79817E78837F727F7A768381
7D88888592928D9C9C93A2A298A5A6A6B0B4A5AEB0A6AFB1A2ACAEA3B1B2A5B3B4ACB4B7
B4A2A8924149A9161FB80D15B80A10B70A0FB00F189A283E76567E3B537C95B1C599AAB0
9EADAE9AAAAD99A9ACADBCC19CAAAF93A2A694A4A790A1A790A4A790A3A7C2D5DBAEC2CE
88A1ADB4CEDC7B98AE3A5A767190A3819CAA8BACC0527A8DA8CAD2C2D4D9C0C6CFA69EAB
6D5E6E564359583F595A415D5743604D41613938583D3550723F517109147A060D8A3543
74455B62405967415364384761313C5D2B335E2E3362363A6A4B4E6C6062656B6B5D7170
58737058736F57746F5C77745B7773637D7B647D7C62797A607B79607A7C546D72476465
4665624868634E6C6753716E476169041E2D39575E4A5E560DCE0A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0049A80C5B2206703D36683A3B684844604B455D444161363758191D5F181E682930
643138542D346A4D555B464E5B4953624D5965505B64525A5F4E575A4952614D545F4A50
624C52664F546F565B745A5D775E5F8169688A71708D7072876B6C856E6B826F698B7A72
8D7B74927F7B93847B928579998E7F9890829D978A9C988D9A978C918F8882837B797D74
767E74737971737C73727D74727C7478817A767D767C837D78817D78827E77837D7A8683
7782827D89898998988D9D9D9AAAABA4B0B4A2ACB0A4AEB19AA4A79BA6AAA2AFB1A9B1B4
C3AFB68C3B45A4141DB80F16B90B13B90C11B70D14A211209E506D3F3B657893B297ACB9
9BACAE9DACAF98A7AA99A7AD9CAAAE97A6A890A2A2BACCD0ACC1C6899FA6B5CCD399B1BD
6E8797879EAB97ADB99BB4C66C8AA09BBACE82A7BE235168ADD3DFBDD5DDC1D4DEC0D1DE
B2C5D46D8399334A69172F550B234D091F4D0F224D413A5B64283C78081581030B7F0B16
740F1E6C09196D09166D07136C071269050E65050B63040C5F0A1258171E6743456C6666
5D6C6A576F6D5B74726078765F79755D7774607A79627C7C5D7A785B7779344E56224146
40605F44625E49686449676C1B354700163018334347605D1DA01900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DAD0F6025076B342B67322E6E4642694A455F3332591A1A5D10135F13185F2327
60363A6043495B474F5A49525F4D58624E59645058604E555A49525747515C4953604B53
5F4A50614B506951556F5559785E608166678A6E6E8D70708A6E6F87717084726C8B7A72
8C7B73917F7895837A9A8B7F988E7E99928495918599978B969387817D747E7D757D8079
727871727870727A74737D78717C77737F7A79847E76807A77817D77827F75807E768282
7682837B88887C8B8B85969696A5A79AA8AB9CA7ABA2ACAF9FABAE9DAAAEAAB5B9ACB3B7
BCAAB191444EA2141EB30C13B80D12BD1015BA0C13AE0B15961B2E88587B3E4D7290ABC2
99AEB59BAAAF98A7AA99A9ADA6B7B99BADB093A7A9BBD0D49AB1B689A0A58AA2A795AAB1
9EB6C089A1AEB0C8D588A5C0183D693F6A91618FAB5E899DB8D9E3C0D7E0BFD4DFBAD0DC
BBD1DCBAD1DEB2CADE9DB0CB757E9A625C78664D666E3449710D1C82051086010987030C
83020F7E010D7B010A7600087301087201076F01057002086E020868030C5B090E623135
6E6365616F705B71705E75765D767357726E5873715D77765B78765A7678344E56153039
426364466362415E651D364B01153301103101132D384F5523A82400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0054B4156B300C592012652F286F433F6C3F3D5C1C1B6111116614165C171B6C3E44
60454B5E495058474E57484F5D4B54614C535F49505A454D59444F5946515A49535D4953
604C51634F52634D4F6C545774595D84686C8A6E708F737488706E836F6D8875728D7B73
8B7A6E91807694847B988A82998D8397908498948899978A828074807B71827D787F7E78
757973797E796E7674566462566664516260586A686A7A79758281758081747F80758182
7782837A85867B898978888889989A99A8AA9AA9AB9CA9AB9DAAAC9BA9AD9BA8AFA0A9AF
B6A9B0954F589E1720AE0910B50A0FB6080CB80910B40910A60F1A96334B644D725E7699
92ADBE98A8B19BAAB09AAAB0B2C5CB9CB3BA8EA5A98DA6A992A9AD95A9AE8CA4A7B3C9D0
A6C4D46388A383A5BF7193B2052D5B14426C6790A7B3D3DFBDD4DFC1D7DFC1D5E0C0D3E0
B8C9D6A6ACBE8E869B785C726B384B661D2D6A0D1B79081782030F87010B87010789020C
85020C80010A7C010A7601087401087301097001056E00066F00076C000867020859090E
63383C6B6A6B5B6F6E57707058737055726E54716D55726F577471577472455D640B2330
3F6068324F580E243B011034000D32010F3101112D1A303A327C3500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002DDC0C71380A4D190463342C7F53505B222063171660110E651F1F5B282A64444A
59464E58474F58464E57474F5C4B525F4B526048516046525E45505B45505B46515E4A54
5D4A4F624F52634E506C555870585C80666A8A71748C757487726F87736F8B79758E7C74
8C7A7092837990827992857D90877D958E839A948A8D887E7F7C727F7E747D7C757B7C75
798179626E6959686660736F687A766677765267674D6264677979748281748280758283
7681837985877784857685857F8F9092A3A596A6A98F9DA197A5AA95A4AA96A6AB98A4A9
ADA6AB9B5F67991822B10D15B90C13B90A10B90B12B80C12AF0A119C10209A506C48466A
7A98B1B2CAD59FAFB593A4AB8B9FA6889FA590A7A98CA2A5B8CED2BED4DDA2BEC89CB8C4
7EA1B60C3656567B987292A77095AE5B89A38BB3C1BED8E1BFD2DDC1D4E1BECBDBACADC0
9482977C4F666923386D12257209177D051381020D83020D83010B89040D85020987010A
83000881010A7C010A7501087401097300097100067001077001076E00076B0206650307
530F136E5C5C5B6C6B54706E56747156737154726D54726D55736F53706C4C666D041D31
1C364F041934000E31010A31020B31010C2F010F2C0B1D2A414D4300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007E410F521E07683A317A49465917146C1E1A5B14106A37346345465B484E
55464D54454C56454D58464F58464F5D4A545B44505D434F5F46515F49535B46515E4A53
5F4B51614C52664F536F56596B5256785F638770728F76758D74728A73708C7974907F79
93817A96857D92847A91847A91887E958D84968D86857D7674736C6A6F676E756D797F79
6F797550625F677A776E7F7A707E786D7D795C7070475E625369696B7E7A6E7D7A727F7D
707E7E717F807280817989887B8B8A83949581929489999D8C9BA098A9AC92A3A796A5A9
A6A8ACAC7F868F1A24B0121CB90C16B90912B70B10B6090DB1080DAD0D1793172A8E5A77
515B7999B5C49DB2B890A2A78BA0A3B1C5C7BBCFD29CB1B6ACC3CA9AB6C45E7F907F9EAA
7C99A67795A982A3BA7E9DAFA9CFE42C5B768EB8CBBCD5E1BDCEDAACAFC1968399855168
7826397A11217B05137D040F7C000981010A83020980010981000983010985020A850108
8401088402097E01087801077401087401087301067201067101067001076C0105690105
59060A5C393D556064526E6E547370526F6C52706B52706B4F706C4E6C6F3D5867041838
000E34010D34010C3300093101092F010B2E010E2C0314243C484300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0081420D5A240B663329793D3B651D1A6E2922652F2C6B4949634E5356464F
54444D55454E55424C59454F5C485258454F563F4B58404A59424C5E47545B46525C4950
604D525F4B51634D546F565B73595C795F63846A6E8C73748E7372896E6E8F78778F7C78
907F7893817A96867E8F83788E857B91897F877F777A776F656762656E6A5B6561777E7C
5661625063646677786D7A7A6F7C796A79765F7372475D604F6566677B796F7D7B768080
747E807481827483837383827E8E8D829392778A8A91A2A392A2A499A9AC8C9DA094A3A7
9BA5A7BB9EA48B2732A71521B60C18B70811B60B10B6090DB60A0FB40A13A80F1B972A3F
835F795E6E8391ACB697ACB18B9FA3B9CCD1BBD0D7A7BDC58BA2AA8DA8B088A5B0849EA8
87A1ACB3CEE35B7EA4406A9477A5C534617EB2D1E7B0BCCE988DA0865C707A2A3E841526
8A0A168A050E87020A8102087E01097E00087F02087D01067F010784020A840109840107
83010582010780030979030A7303097003096F03076E01066E01056E00066A0105670004
5C050B512532343A45506C6E53716D54706B536F6A516F6D4C6C7329465B071E3F000E39
010A36010A34010A3100082F000A2D000E2E00122A0012223846460ECE0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008649105F2A0E571E156B27236A241F6C36306E4D4B6D585C56474C53454A
55454E50404953414B57454E5A4A515D4B5259444B574149533C4758404D57414C5C4950
5F4C51614D5365505770595F765E61795F63886E728D75748A72708D7473907A788E7C77
90817C93847E94857E92867F8C837A8A8177807B6F78786F5F6660626D69646E6A7A817E
4B56574F62646173756775786573765D6F70586C6E44585B556A686D7F7B75837F778381
6F7C7D6E7C7E738283738383748485778888788B8A8194948A9B9D8C9C9F8B9C9F94A4A6
9AA6A9B9ACB29A515B981A26AE0F1BB40912B80C12B70A0FB50B0EB3090FB00A13A61220
9A3C506A536DA8BED4B7D2DF96AAB299AAB28FA4AB899DA78AA0A896ADB4BDD9E59BBAD1
7D9EB984A4C8062B64042F694973989AB4C9A6A4B88C667E7D344C7B12268909198F0411
8E020C8C02098800088200087F01097E00097D02097D000681000887010A870209830309
7E040976070E6F0B14660F195E161F5D19235D161E600B1468050B6A0107690104660005
5C040C542737161C2E4D696F506D6A516D694F6B6A3F5C6916314C02163E010F3F010B3B
010936020934010A2F020C2F00102B0B263726454E0E252E2C3D3B21A11A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0064790B642E0E54190B6120176F38317855536C585964555755474A504447
53434953404856414B54424B56464E56454C5A474E59454D553F4857404B57404A5A464D
5E4B51604C526650556B5659776365786164866E718A71728B73728E76748D7672917F79
8A7C778F837F908580908580908680837C727E7C6E7B7E706C736A68706A737973777C78
495655485D5E596C6F5B6D7256696E53686D485E6241575A6073716F7E7872817C6F7E7C
69787B707F836A797D7887887A88887B8A8A84959581939480919393A1A595A4A795A4A6
9FADAFADAEB2AF818A83222DA31621B30B15B80B12B80B11B50A0FB30A10B20911AE0B16
9D142492445C685E7A778DA28FA4AE92A5AA9AADB3BFD3DCB1CAD694AFBCA3C5D91C4369
244D756F91B048668B4F689178829D90798B8644597D182E880B1E8B021191030F93030E
8F020B8D010A8A020C8400088100098001087F010880010883010889020A830209770C12
72222B733F4F684861544260453C5A3F3956463952674151590D16670308690204680205
58070E512D4209142C4B66714F6D6B4D6A68425F66061F3A021541000C4000093D010839
010736010835010C3001142C18353F305454375A5728424224373125A71F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0041A2056228064F1304602C2173534C705F5D685C5B615455574A4B524144
593D44512C364A283159424A57454D55444D5B48515A454D553F4858414B543F485B484F
5E4B50624D526954576C58597461627763647F676A876F708A73738D7775907B77917F7B
8D7F7B8B7E7B8E817E8F837E897E777E766C7E7B6D7D7E7176796E72766E7679717B8079
5E6A68435657475C60455D61425C60415C5F3E585A516768697A7973807D727F7E697879
6B7B7E7283876F7F838391938390927987898897988898988191928E9C9F99AAAC94A6A7
A0B0B1A7AEB2B7A0A99C5A66901C27AD0D17B50A10B50A11B30A11B40A11B40A12AD070F
A70A15911122944F64928695BDC8CFA3B4B79CB0B5B8D2DE6C8EA17B9CAF80A0B252728A
68859F839BABABB7C9A499AE89586C8025378B10208F041391020E8D000A8E010991020B
8E010B90020D8A010B88010A8402098101097D0209810209830106820208720811804454
513E5E1E25540A1E53051E54031E4E061F49102241544357510E1A630208670102640206
55162036273E081B374966734F6D6B4E696749626A021635021040010D42020B3E010839
010936000B31071E3623454E365A573D5F573E5D56354F4C1A2E2735792B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004AAA0C5D1F0051190962392E735D557269636B615E6358575D4D4E584045
5329304409115522295C3D4353404857454F5A464F564048513B4458424C55414959464C
604C536752586B575D705C5F7460637C656881696C8970738972718C75758E7879907D7C
9384818E807B8F847E9086808379727D746A80786E7B796D76776C7B7D747C7E767D817A
757D794F5E5E3E515440595A415E5D496362536A686275726D7B7A6E7A7773837F6D7D7B
6676776B7C7D6F7F82818F918290908392928B9A998695948796968B9C9C889B9C8C9FA0
9BADAEA2AEB1ADA8AFC09DA793414DA1161FB20C14B30A11B30A12B60B13B30A10AF0910
AE0B13A30814941826A45E69D7C4CBC9D2D58DA0A598B0BB5C7B8B7E9CAB819AA4BCD0D9
C3D1DBA6A4B28B6D7E833B4E8415278F061596041096010D94010C90010A8E010991040E
8E000B90010C8D030C89040D7E060C75080F891E257D07107E030B75050F76344646385F
06195402205E1536682F4F7544607C55677D605E6F5227375A071166010765030458090F
5432420F14330C26434767744F6C6C526B6A5068700C203B010F3C020E40010C3E000938
000F341730473559603A605D3A5E563E5F563F5E55354F4C172D28444B3800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052B2135A1C00511A0B6A40345E443C71635E6E63606658585F494B532C31
571A2251060D4E0F135F383F533E4755444D58454E58424B533C4457414958444A59454A
624D536A565B6D5B607563687761657B636783696D876D71876D6F8B7273897173907D7C
91837E90847C8E857D8D857D877F757E776D7F7A707C796F7A7B70797B717D80787E827B
7D837E737C79616E6D60716D5E726D61746F6878736C79746F7B766E7C778F9E98B6C3C1
B3C0C18F9D9E7B888A7D898B8695959EAFAE97A8A69BABA997A8A793A4A593A5A89BAEB0
8EA1A39CACAFA3ACAFADA6ACB0868D8D242BA90F19B10A10B80E15B40A12B10810AF0810
AA050BAB0712A50B18961B29AA6571BBA8B0949DA28EA1A7B7CFD8B4D0DF98B2C2A6B2C1
AC9FAF925F737F2336890D1E94071597030F98020D9A030D98040E92010A8C01098D010C
8B01098B040C810A107312177D303496495184242E77040F77060F6D1D2B593F610C1B53
04235F2D507D4D708864808C6B798073646D5C2A355A081367030B6802075B0709613039
27223B03153B23425D496973506C6C536B6C546C7313274002113A010F3C00113C0A1C42
0118333A5A6542666340625B4161593D5D543E5B55334D4C162B2A49554800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0056B6145E22015F29195B2A1F5B36307B6563736161684F4F653B3E561A1F
550C125304074E0C10633B4155404954434E5A485257434B543E445941485E474E584349
604C516F5C5E7461637865687B646A7C636782686C84686D856A6D8A6F71886D6F897372
8C7B778F847C8F887F8C877E807B717C796D7B7A6F79796F76776D787B707F827782847D
82837E7D807D7A7F7D777F7C707A75758078727C75757D79707C78899895C8D7D6C9D6D7
CAD5DAC6D2D87C8B8F7887897D8E8E8A9C9C9CACAE83949587999986969B81929884969C
8EA1A5899C9F9BA9ABA5ADAFAFA5A9A3646A9A1D27AE0F16B60D13B20911B0070FB10A11
AF090FAE070FAC0710A40B17931B28A05E68C0B1B69CA8AEADC3D246657F60728E927E95
89445A88182F940C1D95031095010C99030F95010A95010A95020D93020D8A010888040D
7F081072131E7A3C49724D5B906872752E3972081478050E6A111B69405B15194A031C55
4A6A9488A4BD718694727781755D6465252F6307116B020A6C010666010572262A5D3947
1315320D23424363734C6C6F506B6A516A69546C731E3348011434061E3C2544573E5C6D
09203238576044676246665F43625B405E57415E5A284245142F2E4556480FCE0900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00642A03602B1A521D125F332D7F6362765858632F30641E2057090E
590E124F0A0D521E1F5C3C3F53404852404B5A46505A454E57434B58424859434A5B464E
6551576F5C5F7362637966687E696D785F6282666A83686B84686B886D6F82676A856E6F
8976748E837D90877F9188818177707D766D7B797078786F72736B76786D797A6F838279
82817B80827D787D7A7C8381767D7B7C868077827B76817C6E7E79A0B3B1C5D8D9C8D8DE
C9D7DFC9D7E085959D788B8E8295957E9090899A9B8396968B9C9E808F94849499798D91
889C9F8FA0A49AA8AC9AA6AAA4ABAEBBA4A9893B439E181FAA0A11B10A11B0090FAF070D
B0080EB0090EB10910AE0911A50D168F1824A25F68B09EA77D879561687E81637D812D44
8F11249806179A031098020C97020D99030E95020C94020C92020C8D030C81071071131F
753B50624A6A332E5251406075384E740D1B7A060F6A0A15734258231F4D0418540F315E
92B2CAACBDCE88819272495964162470081475050C7200067201066F0308670A125E1B29
4F2F424E4F5D536A6E4F6B6A526E6A506968536B6E334B551E3B473C5D6548696C4D6A6E
152A382E4D594568684A696444635C415E5A405D5B122D30163332435A4B21A31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006E340A622D17511C105E3029835C5B723D40611619610F105A0E11
5114174F2223533335574244523F46513D465B464E58434C58444D543F485C474F5D4951
6351576F5F6472626579676A7D6A6D755F637C6466806669896F71866C6E806668826C6A
8977748678728E827C9286818275718276717C777177766F74756D74756C7A7B717C7D74
81837C7E847D78817C78827F767F7D78837E75817B75837C6F7F7997ABA8C4D8DAC5D8DE
C4D6DFB8CAD375888F7185888295957486858FA1A1839696889B9D8191978193977A8E91
7A8E919BADB199AAAEA0AEB49FABAF9EA1A5AD8E938529319C0F18AE0C13B10B0FB0080D
B30B11AE070DAE070FB10A12AD0911A30C178F1926A86571B8939D96606E842235920C1C
9C05109E040D9E040D9C030D96000A97020C94020C92040D890810750D19722D415E4467
2D316714245F4D4978683153750D228106136F071173384D352C570516531431677E9DBD
7683937E6A7D692F456B0F217604117C020B7601067501077402077202086D010766030C
56081253282D656061546764536D6A516A685068684D68684665634867634967644D696B
1D36431D3B4944676948676245655C43615C3E5B5A082225223F3F40574A23A71C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0083481359240A4E1B0E6C3D378250516824276915157125255C2525
5831334F33354D373C513E4654414B56414B58424D56424B543F495A454F59444E5E4953
604F566B5B617361677B696E7A686D7A676B7763647C656784696D866A6D836867856E69
86726D8A7B748F837D9187827C726E7D74707A757274746F75776F787A72787B72737A71
757E7677817978827C76807C757E7A757D7A737E79727F797B8A867B8B8AA5B7BCB4C7D0
A9BCC47B8F9674888C708485839596788A8B889A9B819496809498778B9081959A84989D
788D918A9EA299ABAF98AAAE8E9DA29EAAAF9A9A9C9B6F738820289E0B13AB0A10B00A11
B30C14B00811AD0710AD070FAD0910A20910921219AF4A55A547538A17269209179C0511
9E040B9C010A9D040D9A020D9B040F95020E8C050F7D0D177E32426C4766302D5D0C1E5F
0D2267433F7A6B3459760D2582061477071279324646325C0A1756031A59485C8789869E
6F4659691A2D72081B79030F7D010B7E020A7A010877000A7300077301086F0106690005
66040856060A5D36375F62605067644E67644D66634D67644A68634A6964466560496767
27424D152F3C44666747676046665C43635C41605C133130314F4D43594D36782A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063750B592405562315713B367231307321236715136A2C2A633B3C
56373A48292E543A41513E4751414C56444F56414D58434E56414B5A454E5B46505B4650
5E49526B575E705F6579676D7C686F79656B7B65687E63678B686D8D63677C5250896962
88716B8776708F847D9088807A746C7D76707A767073746C74766C767A70737A726E786F
707B7378827C78817C77817C747C77777E7977817D75848079888675848478898B788A8E
7A8C907083866C7E817385897B8C8E7B8B8E7B8D8F7F9296748B8D758D8E6E84887B9094
73878C7A8E928EA2A49DB0B08FA2A395A5A9879495AEA6A8925C628A1A25A00D16A9040E
B50B14B30913AD070FAD080FA80B129C1418C54E54AB343E97101D9C08149C030EA0050E
9C020B9C020C99030B9A040F9606108409167821316A3B5840376511205D031F63152C6D
565386672E527A0D248805147B0813752A3D5239620E1454081A5C363E72705B7B65283D
6F0F1E7905137D020D7E000A7F01097E01097F020A7B010A7400077301076F01066B0105
6901046303055011126558575367644E67654E6865506A664C67624B6662476561466363
35505614303845676645645D47665E44625C45615C3B58513B595141574B4A4C3A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0041A208551E02622C1D61211A72222074201E6C25236F3C3B623A3A
512728481B205B383E543E4554434C54434D56424D54404A57424B5E4952604A535F4952
6049516753597260667B676E7F69707E676C796065805961854C537B3237752F2F8F615C
8C7570897C77887F788D867D7C766D7B776D7B786F78786F797A7173796E6C766D6E7670
767D797A827E767F7B76807C737E79747E7977827B81908B7C89897987877B8B8A829391
7E8E8E71838474878976888B7685897A888B88979A788B8E7E92937F9494768C8D7B8E90
7A8E90768A8D7E949596AAAA899E9E90A3A48DA0A18E9B9BA3989A995B638D1721AD131C
B40C15B50B13AD090FA90C13A0191EC74F53A72B369B0D1AA70A16A5030E9F010A9F040C
9A000A99020B97060D8F0A15811B2A81455F4C3B6417245F06256719387842568C746991
7235508010248F06168206127625385B40680D14540B165B3B366B683F6265152B770818
8106117E020B80030C7E010A7F000A7E010B7E01097C020B7501077202086E00066B0105
69010466020552070C482F364A5B5E4C68674C67644C69654F6B664D676345625D456260
4662633E5D5D44656247655F46625D48635E49635B4660563B554C42584E48504000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0049A90E591F0663271B560D0674241E6D25217F4945704141582223
5115164E14174E2328573F4454434C55424D53404B53414857464A5F4B51614A52624952
60464F6852586F5B617D676E7F686D7C676A7D656881575E712C32882D317E29298C5552
8A716D857875897F798E847F7E766F79756C7A7A7174746D78797272786F6D786D6A726C
767C787A807C77807B76807B75817C76837B7A857D848F8B7883847986877E8E8D839392
7A898A7788886D81827487886C7C7F848F948793988494978E9FA08E9F9F7C8E8F748689
798C8F788C8F6F868892A8AA96ABACBDD0D296AAAC899C9E97A1A2B3A4A688444B951823
AB0E16B40D14A80A0EA1191FCD575EA92D37A00F1CA70813AD0A12AB060FA4030C9F020B
9C040D95050E860E1883344A6E5076282F670724630B316F5A7FB299ADD67561827B314A
840D1F9006138807147E263967486E141B5A131D5F4B3A6F6025466F0D217C031382010C
86020B81000982030B81030B7D010C7800087A01097D010B7A02087501087101056E0006
69000265010355050C3F212E2F3D4A4866684866634867624968634B686346656144635E
49666249676147655F47645E47635D48625C476158435D5435504A39524A43524300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB0116227065516094F080269251E804C457A4F4C683434571214
570F12541A1D502A2C553E4255434C57434E55414C54414958464A5E4B4F5D474F624650
60414C674A536F525B785B627E65697864677A656885626882434A761B207C24238F5652
8A6D6A847370847875877C79847B7579746C74726A73736B73746E70766E6A746B69716A
6E746F757B76767D78757E7A7E888475817B75807B8B97947A88877686867586867C8C8C
7E8F8E7083826C81806A7E7F72848684929789979C8B9C9F97A6A99AABAC7385897D8F93
7285887F9395798E918CA1A49DB2B4ACBFC49DB0B499ABAE97A7A7B7BFC1A69197994D58
9B1A23AD1319A6181AD3575FAF323DA3121EA80712AC070FB00A11AC050FA5020D9D030C
920911831A2779415C443D6C0F2968052D6D325E9191B5D9AFBEDB8F74927A29448D1023
9205108A09147C22356B4970171F5B1E28675D4977631D3B760A1B83041082000A840108
8601078601098401088002087D040D75040B73010876030B75040A75040B730108710107
6C010366020453060D3F21341A293B45656A4767644A69644968644A666548656246655F
47665F4A686146645D47655E45645C46635B466058435E563B5A5526453E435748209F16
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057B615692B034F10024F10076B332C83544E7C4A485418175E1919
5D2020572C2E593E41523F4556434D503D47513D4856424B5D484E614B5260464F623A47
5E2B386E3A4668343E602F37805C617B60667C63698162678752577728297426218A5750
866B66857570817671847B76827A7477716976726B7A776E75756E70746E6C726D6F756F
707570737975747976757A79838A8978817E76817E788683758583758685768686788585
7C8A8A788A89647877667B7C728689879A9D8D9FA2859A9C94A7AA93A4A97F929775898D
6C8183B2C6CA92A6AB7D929695A9AD8D9FA69AACB1A1B2B6A7B9BCCDDEE2C5CDD2BFA8AF
954A5297242AC74B50B8353DA7131FAB0913AE0810B20A11B20A11AF0912A80A11930A10
91323C6A4260272F66062A6D1A48816F99C0B0D1EAA8B1C68A697F812B428F0F20960711
88070E7D2334725076191F5D1F27676B507C691C3677061583020B85020A810007850108
8401068501088403087F030975040A68060D5F0A12611A2367262E6A1C2568070F6F0208
6D01046303065211192F1D330D213644666E4667664968634A69654C68654C666349655F
47665E47666047676144635E46646044615D46635C415F573F5E5714332E354C4122A51C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006D2D07501003541A10713A33783936753130642220612B27
5E3735573D3E544043503D4453404A53404A523F49533E495C46505D464E624049622836
560B176416216B1F295C1A218B585F6E424A6C444B815E657B51556E383685504B87625D
856B6882726D81756F847B75867D77776F6A79726D7C787174756D6F736D6E736E727772
6E756E727973757B77737875777D7A7C8582737F7C73817E738280788886728080839091
7987887484846D7F7E677B7B728688889B9D809396889CA08DA0A592A4A97F9298778B91
758A8E6E82896F838A7F949999ACB0A3B4BBC9DBE0CBDCE2ABBDC4B2C5CCB5C8CCA4ACB0
B99FA7AD636DB03742AF1824B40F1AAE050EB30B11AF080DAE090EA8080F9B0E12AB3D41
A062732B2B57082F6D3A699D9BC3E1BED5E9AAA9BE885E787E2338910D1D9A0813910B13
7E2230704D711C24601A27696A5080701D3980081785010C84010983000983010984010A
83010A80020A79050A6C0A0F641B24693C4A584056453B5A36314F6A4D60580D196E050D
6C010659040754293513122B0C263D40646C43646245645F4867614B67644D66634A655F
496860486860476962456560476562486662405E584262563D5C512E4C452C483B25AA21
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0077350C511203581F156729226C1F1C7226236B312D643E3B
5B4341534141503D41523F464F3C44533F48523E47563E4A5B404D63414D63323E601823
6B161F630C14651419530F1378454864353A5B2E34816165806466876868846765846866
8A716F88767182756E857B75897F797C726E7A716B7E7871797A72727770737A736E7470
6B726E747C76757B76757A7671787476807B707C7874807D79848473807F6E7C7C728281
7688867183817789886B7C7D697B7D7D90918598997A8C908FA1A690A2A78093987C9096
7F949971878C8EA2A7B0C2C799ACB1889BA2BFD4DBC1D5DCA9BBC2A3B5BCB4C6CACDD9DF
C2AEBAA35263A41827AF0A16B30811B60B13B40A10B0090BA90C0CA01718C64F51A1323B
81344A48426B4975A2A7D2EDBBD3E3A8A1B58C5972821E39910B1C9E0A15910A14842738
6E4B701B25631025686056886A1F3F83091B8A030E88010A83000982000981010881030C
7C060F6D0A1267202A6A4456493F5C1E264D091C4B07194D1F26536244605709196E030E
6903075F181D40283707122C1B394C3D616442645F4766604B68634C67664A68654A6863
49686248696148696247676146655E44645B4363594161543C5C5123443C315146317A2C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0084421155190661271C55110A6B1E186A28237148425C4540
53433F5044424E3F414E3C43503E46533F485840495E3B475F323E69354260202A5A0912
6C161E5E0E145E1B1F643334704D4E6C4F50634949725C5D7C6969806D6D806C6B836D6B
8B7572897671837770877E77887E7A857C777B726B78736977776E71756D6E746E6F7572
767C78767D78767D77767B76747A76747D79717B77737E7B727D7B6E7C7A6E7E7C6A7C7A
687A78697C7B7184847080826C7B7F80909382939595A5AA7C8E9385989C84979B7A8E91
72898B789193B0C5CBC3D8DFB5C9D08A9EA67B90989DB1B8BDCFD59FB0B7AFBEC6CAC7D3
AC77889D2639B3101FB80A15B70912B40911B30C12AA0C0F9F1819CF595BA52C3196101C
82192D674E7254779CB4D1EA9F96AB844A6282183092081B980713910C1682293C6A4D74
18276706236B4247816933567C0C218B02108C020C89010A8602098101097A030A6C060D
691F286F465B493E61141F4F061C52041E53152C5A3E436B5C405F5B162B6906136F010A
650105641A214E2C38191C2D37515943636146655F46635E4B6964486663476763496762
4766604968624C6C6649686348676046655C4564584161543C5C5128484216342C435241
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008E4F145C24095A201159180D70312876463D6E50485B4742
5443405043425245464D3E434E3D45553C485F37425D212D59121D67242D68232A61181D
6B292F6029305D323765494B6B585B6756586655577767677A69697F6D6D7E6B6C826E6F
8773718A787284777089807A8B827E89827B7F7A6F74706576746C767871767C75777D77
787C7A767A77767B76777C77777D7A798381767F7D707A776A77746979766B7B7A70807E
728381768888788A8B6E7E817584887B8A8E88989C7C8E9483949B7B8D92809395ABBEC0
B0C4C87F969C718A927E969F89A0A695A8AF9CB0B5C1D2D7CBDDE1C7D5DCA9ADB7BD9AAA
983549AC1426BC0E1ABC0B15B80A13B30A13A70D13A82327C852589F222AA3111BA00A14
881120764A68333D618C80A07E3C57851429950919970714860B1687384C574068112566
052E732E4B846E567C72132E8A05168D010D8C020B8A020984010879030C6A0E186D3648
4D3D5B172150051B55041E561D35624F5B7D6B62795A2E415E0F1E6C051172010C6F0108
69000660040A510B11502F34565A5948625C45635C44615C4867614766614A6964496862
47665E4B68634B69644A68634967624A666149655E4463583D5C523957511F3C32435343
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF003E9F02652D08541D095B231569392D7651486A4C455C433F
564342554344503F41503E43543B445429355314205E0F185A0D1264232869303559252A
6C4449603F4760444B6950586551585D4A526A595F79696C7C686B7D686B816D70856D71
8A74748A76748A7A76887D7A8A807D857F798480767C796F78766F767871777A73767B75
787B7A757878767A77787D7B747A79717A7A707B7B6F7B796B79777180806F7D7D788783
6D7C796A7D7D697C7E6B7E806D80827F92958B9EA1869A9F7E9196788A8F83969AA2B5BA
A3B6BD7D92987F949A8CA1A7B1C4C9C0D2D6A1B4B8ACBDC2C4D4DBBBC3CCB7A3AF934556
A0192AB00B18BA0B14BD0E15B80E16A80E15AD2D31CA545CA2232EA6101CAA0812A50812
870914A25C707C516B7D2F498A122796091696091186111C7E3B534D42710F2A6C0C3A7B
608CBC818AA860253C840C209003128E010D8C020B86020978050B6B18246A42572E2A51
081A50031D55153061526284766D826C4253621B2B67081671040C7401097200076F0108
6E01066D02076202054B07085C444151625846635B44625C4767604867604B6962496862
4867604B68634E69654D676549676548656347645F45635C415F543D5A522947403E5143
20A01500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047A808632E0556250E54251567372E5A29236638325C3A35
5842405544444F3C3D51363D4A2028531720591016560C1061242765383C6C484D69484D
64474E644A53654A546A515A59424C503B465F4F5775666A7B696D7C686B80696D876D72
8C74778F7B798B7B7A8C807F8C83808A847F827E798B8881797A7273756E72766F737871
757B77747977727975757E79757D7B717A7A717E7D707D7C6C79797682836E7B7A72817C
6F817C637776667A7C65797C6E8284798D8E839899819699A8BDC09AAEB38A9DA285999E
7C8F959FB2B7879AA083959CC0D2D9C6D8DEACBFC4A2B3B99FACB3B1ACB6A36C79951D2D
AE101CBA1019BA0D15B70E13A60E11AE2D31CD575DA4212DA60F1BB20D16AC070FA50710
8F0812B955637F1B2D8F0F1F980915940C15841A25844B6739366B0C2B720D3A7B6B98C4
ACC7E28672876F182A8A061792030F90020C8D040C7E061071222F6445601A1E4B041752
0A2158394B7267647D6F4B5E6B2130700B1A74031176020C7602097501087202086E0006
6C00066C01056601045704064F242451565143605942635C4567604968604C6A62496762
4968624C69664D68654D66644764614A676348676145635B425F533E5A530D2A252F433C
22A31B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004FAF0E5D260150210E602F2361231E52100B6E38325B3833
55413E534443523F40502F354E1E254F141A56181D5D282A66404465484F685057675156
634B52695059674F5966515959454F4C39445F4E5777676C7B6A6D7D6A6D836C6F876F72
8C77798A797A8A7E7E908785908A8786837E84827E8A898482827B787A7273766F70746E
757B76727A766E7A76717E7A768280707D7B6976726A7673737E7C727C7C707C7C71827E
718582677C7A627677677A7E75878B83969885999A8095967C9295788D917F94997D9598
A0B7BBC5D9DEB7C9D08FA1AA8EA1AA9FB2B99DAEB39EADB2A3AAB0A0838E852837A51320
B40E15B80C13B20D12A11012B0363AC9555DA31C29A70C1AB10B15B40A12AC070EA40510
920811BC4B578C1220960A178C0C168328397A5174292E6907276F19448382ABD2B8D6EC
AEB8C97F5A6E7C152690061492020C91030D83071179253562416113184A06164F1B295A
5C577B6542596422326E0D1D7A06137E030E7C010B7700097702097401087101076D0005
6A00056901046301025802064C19202B293145616040635F4666624665614B6A65496864
4967644967634A686449656148656049686246656044635C425F56415B5616302E324A42
23A81F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0055B5125F28005A28155F271F560E0B560A07723B355F413C
54423F4F4040533E40512C335B2A325B293062373D59383E5F454E614B54634F56665357
6853596B555E6B545E69535B5B47514735405C4C5576676D7C6B6E7E696C836C6F877174
8D7A7B88797A8477798A817F827D7A888581817F7B88888493948E85877F72746C73746F
7276736C77755D6E6F4F64665B6F71687A7968767276817B6F79746B7473627070687B7A
667B7A647A7865797A6A7E8461787F7F969B7A90918296967B8F908BA0A2B3C7C98DA3A8
92AAAFAFC4CC9AABB48798A17F9298A3B6BCC9DADEBFCACF968D94874856901624AB0E19
B71116B30F16A0161B9C3E44C87D868A1C2BA40E1EAB0612B20912B10710AC0610A70912
920A0FBF4C57881320821221793146644E7A192A6A062B712B548C98BFE2B8D7E9C1D5E3
ABB2C1815A6C7F172794071591010B88040D7A1A26744D671818451A1F52443964633E5D
641F346F0C1E7A05137D010E7E000B7D010A7901087501087301057301077101066E0106
6D01066901036401025802064F1E271413223652593F6160456561486663456560466662
47666346656049686249666147645F47665F47656045645E4362593F5B52345249284135
337B2C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDC0B692F02612C1752140B580C08560A066B362E60413A
594340523F3D52393B4D23284A161E5B2F385E42475741485E4A52614E55604D52675558
6653586B555F6E55616B545E68525B523F4963555D73656B7D6C6F826D6F876F71877172
8A76788676778376768077747E7976888481817E7B8D8C8890908C878A8477797172746E
7076745D6A6D3C5357365056385257576D6F6A7A77717C766C76726D7A766D7D7C637777
667B7B6D8181677A815B74814562707892987B918F839696849799A3B6BCC4D7DF9AADB6
80959E7B8F989CABB3AFBDC599AAB0A4B7BCCADBE0C3C6CF946F7D821E2E9D0E1BAB0C16
AF0F169F131E9742547358749476907C1B2FA40D1BAC0611AE070EB20811AB060FA50710
920E13B14E5776293A8253723935680D286C083274507AAAACD0EBBBD7E8BDD5E0C2D5E0
ADB6C4866877791B2B8E08168E030E7D040C95485550314E503D61663B5B651B346F0A1E
7B051481030F84020C82010C7F020B7C01097601057100047102047102066E02066D0206
6E01066B01046701035703074F26300A0D1F2F4D5740636145645F48676244655F476962
4666604866614967614A686048665D4C676047645E46645D4565583F5E4E3D5D4D375443
44503B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00763B095E250F511007550E085D1F166F453A62463B
583E375238345639383E1518542A30573A4157444A57484B5544495F4E555B4A51604F53
69555B6B545F6B52606B505E6E5460705B6470606775666C7A6A6E7D6A6D826B6E80686B
857074806F718477768B817E867F7C8883818C89868B8A878E8F8A8B8D8781857E72746F
7277764C5B5E385056324F55355055546A6C68777777807E6D76736D7A7968797A677A7B
65787965797D6079832A4B5C4D6D7C7E969C98ABACBACCCF8EA0A584969C8A9CA580919B
7B8C958B9DA4C9D9E0C9D6DFC5D5DD96A7AFA9B7C0AB9FAB8C4658961523A50B15AF0F18
9D131C9B455B64517F1B306B6E6692792036A20E1CA80610AA050CAE0710AA0710A30A12
8C151EA062746152761D2C6507286E1D49857CA6CEB2D4ECBBD6E4BED5E1BDD3DEC1D4DF
BBC7D28C7D896F2836830A198F081483061096364283364B6D1B30730A1C7E051382020D
83010C83010B83010981010B7C010A7801077302056C01056703066208086C1818660A0D
6902066B010565020552060C4A2B39070F252F4F5B40646342625D47666146645F476760
45655E4B686349675F48685D49695E48655E4A666046645D446457405F513D5D4D375545
43533E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0082460E571B0452110754170D6F40366A4B415E473A
543B324F3831573D3A422929543D4050414754474E564A4E54464A5C4B525D4C53614F58
6A555F6D56617057637055626E555F715D6466565D5F515773666A79696D80696E7F656A
80676C837072867A7981777486807C8984838B88868E8E8A8E8F8A8D8D898788837F817B
7278745A6768334B4E314F52415C5D6074736C7A796F79786D77776C7979677778697A7C
6D7F826378813A5A6A284C5D6F8D98768D91899DA1A6BABF788C917F939886999EBACAD0
B5C4CC8E9FA7B0C2CBBDCED7B4C6CE8FA0A8A4ABB3A584918C2737A10D1AAA0E169F141E
8C33485D4877122B7313327A796C9880253A9D0C19A3050FA6050EA80811A4070F970811
8828385E466A112C64072F6D456FA19FC4E5B7D7EABBD5E3BCD4E0BCD3E0BCD1DEC0D3E1
C2D1DCA7A7B17F5662700F1D85041089040E83050F84061583041186020E86010B86000A
83010A83000883010980020D7B010B7301086B04085D060C591A2060363A82565A5D131A
6603086B010661030456151E35223704142D33556044656543615C46625D43615A4A6863
4B68634D68634A666048675F44655B46655F46645F42605B43625A426057405C513D574B
4254410ECE0900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF008E4E135416004F10035F251A65362E603E355F463C
58413855423D5444424D3F404E414451434A54454D55474F58494F5D4C505F4E5468545D
6D535D6B4D58745863715A636E5A616B5A605D505652464D73676C7C6D71826B70785E63
6E55597E696C8677777F757288817D8883808C8A868686818989868F8E8C91918E898B86
787C756D76715667645367666C7F7E6976746F7C796D7978727C7E68757764737765777B
667B814B687A10365062849799B4BA748A8D778D91768D9289A0A381959A8CA0A6C6D9E0
C6D9E1899BA682949F93A5AFB5C9D0BAC9CFACABB2A87480931A28AA0E199A10188D3748
675078192C6C23377C605890905C7C891C2EA10E1AA50914A30610A40812A007108F0A15
8539512A275A0F397374A2CBB2D4EBBCD4E4BFD7E1BFD4E0BCD3DFBBD2DDBFD3DFC0D2E0
C1D2E0B2B9C6977E8C7C293784061389010C87010989010B88010B860009870008870109
84010982000981010A7D020C74030B64070D5E1A235933423C30452F293C603E4C590A16
6802076B03075A060A582D3B14112D0B223B40616A47646645626049636047625E4D6764
4E68644B64604B66614A676248665E44625D43625C42615B44625C45605C425A533E574B
4357421FA11500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006C7A0F55170055190A5B1F13581C1466332C57322A
5C413C55433F4C413F493E3F4D3F4454434C56454E5746505B49525F4C5265505570525A
73475056262F79545C725B606F5D626E5E6465575D52454D6D61667C6D717E676C755B5F
6A515476616483747689807E87817E827E7A87848083847D8586818E8D8B999A988C8F8D
828682727773767E7A7D8683747E797B82807A8483737E7F707C7E67757760717364767B
5D76841B3F5C1943605F818E6F8A8C768D8F788F927C9295C2D6DAB6C8CF7B8F988FA6AE
8EA4AB8497A07789958C9EAAC6DAE2CAD8DEB6ADB69954619F1A28A9131E972B357E576E
333762605C8D7A4F79742341A33A4D981724A30D17A60B16A60C179C050F9A0812870F1C
7A42601621582B5889ADD7EEBAD5E0C2D6DFC0D4DCC2D5DDBED2DDBFD2DEBED2DDBED1DC
C3D4E09CA0AE7855677417288706148A020D86010986010A850109860107830006830107
82010880030B78050C69070F621A23663D4D4436501B2040202444533C56541224670510
6B02066105085B202A37263F0411321C3B5240656A47656445625F49656347635F4D6965
4965614966614A68624866614A686047655D46645D44625D46635E47615D445D553C584B
3C543F22A71A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A2095418005923125A1B105C140C65251E4E211A
61433D53413E4D403F4E40415242475A484F56444C5B4852634B56684B5369434B713F47
69262F6A262D815258765B616F5D626F5F656C5C6262535966575C7B696E735B60705459
674D507460627F7072817776837D7A817C7A807C787E7C767A7A758383807C7C7C6A6E70
686E6E6A716E777F7999A09EB1BAB9B2BCBB98A2A3727F81707F806D7E7D6D8180637880
3E5B76072C534A708B6A888F6E868593A7A77D91947D9295AFC3C8A1B1B9788A93798C93
B3C6CCC7D9DFA8BAC3798D97A5BBC3B6C6CCBBB0B98B404DA11925A20F1AB84C5AA3667D
8D58748A37518E192C92101EBF424E9A131F9F0914A007149C05119B0712940A147E1829
64456A0A255D527FA7B6DAEABDD5DCC0D4DCC0D4DCC1D5DCBFD2DBC0D2DDBED1DCBFD2DC
C1D3DBA3A7B379526176132487051386010B8401098401098401098500088201097E0209
7A040D6F0912691E296B3F51483B571A21470D1944302F5452344D550E216805116C0208
6004075A1C22452F430B103503193B3357684166674767634A68644A6965466560486862
47666149686249696348686148676048675F43625A47655E43615A44625B405F533A5A4A
3D5843337A2700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BAA10581F015C281650130859160D6A3128633C33
5D423C543F3C51404055434756454B5A474D5C464F624650663E49622D37672B347C3840
76242C7B2C33845057785C6374636A7263686D5F636B5E626E60666E5D62735D62694F53
6F55597762657D6E6E7B716F7E757379716F7F797578746E76766F7F807A8485827E8181
7C8482616C67A9B4B1C7D2D4C1CDD3B9C7CCC5D3D7A7B4B86C7B7E697A7A687C7F5A7585
103257133A605C7D906B83877C9191C5DADA9FB1B5778A90768A9097A9AFA9B9BF82939A
B3C5CDC6DAE3A8BDC68EA4AE839CA394A8AEBAB3BB9655619A1B27AA121EA41A279C2332
9519289E18249C151D931C23C7546097111F9E09169D0814990511980712870914833950
37305F072B6385B0D1B8D7E3BFD5DDBFD4DEBDD3DBBED4DBBED3DBC0D3DCBFD2DABED0DA
BDD0D8A7B0BD7D61706D142484051488030F84020B84010A86020A83010B7E040D710811
6918276C3E515142611D234E0818481C26534C3F62582840600D1D6B040F6D030A5E0509
5920274A35490C143502163C1E3E5545686F4768654967624B6A6448676345666045655F
47686249686347676248686247666048676141615A44615B46645C426157405F513F5C4D
3D5544434C3500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0054B415602704511D0A4E160A5D291E6941375E4239
5C453E55423C53424157444958464C5C454B623F47602F39672D3768252E76343B813D42
711F26792A32854F57795D65715E677162687063676D60657063686E5E627A666B7D676B
70595E776366807170796E6C786E6C746B69736C6873726A77796E8A8C82878983888C88
868D89939F9AC6D1D3B8C1CB7C889174818A819095C6D4D87F8B906F7C8060737E294564
0327533055758EA9B47A8E92788D91859B9E72868A71848A778B90BFD3D7C8D9DFA6B8C1
798E9A7A919B88A0A89AB1B990A7ADB5C7CEC0C5CCAE8D94852A349B1720A5171FA01822
90141E8B252F964B55BB7B859D435191101F96071293050F91040D940B147C11207D5274
14235C1A4377A7D0E8BAD4DFC1D5DDBED5DEBBD3DCBED6DFBED4DEBED3DDBDD3DABCD2DA
BDD0D9AEBBC875647466182A81091785010E83020D83010C7F030C7406106A16216C394C
523F611F2654061C4F041E502B39634E395755142868091672040E6D040C5C09105A2935
40334C0B133A01173F1939543F646C4A6A684A68634C68644A6964476761466862466661
4667614B69644B69644A686348676244645F41615B46645E45635C436158446156405C4F
3F584747533D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059B8156C30064911024E1C0E67403262453A5C443B
5D473F56443D5745455A474B5E464C643D445E222A5F151E732B3465222A74353C7F4247
6C292F6C2F3480575D765E666F5F677060696B5E626E62656D606574666A79696C7B686B
7D686B7E6A6C7B6B6C796C6C736967716865726D677A7971777A72848880848983878C88
89938FB4BFBEC8D2D8858E987A838A798386667476B9C7CC818D9564727D465C73082551
0B2F5A51738BA1B9C184969C74888D7B9193A6BBBDB3C5C97B8E9599AEB5ADC1CA8399A2
748A948499A2C4D9DFC5D9DFB5C9D29AB1BDACC3CFA4AAB1B39498915056934853955568
855B776C5F833F42668A728F7722388C0C1A8F071088030C8C060D8A0C187D2F46463C6C
0728655984AEB5D9EAC0D6E0C3D6DEC2D6E0BED5DEBED3DEBCD2DDBBD1DCBED3DCBDD3DB
BAD1D8BACAD57368775E1C2D7708167E020D7A040D7408116C1823713C50554160232955
091D54031E552E4F7A7C9BBA70778E4F21356208156F050D67080E5C17205C38492E2849
071643011B451B3D5A4165714767684B68654966614A66624A6963496A644A6A644A6965
4968654A676446656046666043655F45666141645E40625B42635B4361584260553D5C4F
3E5A4943523A0FCF0800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00733408491503572D1B654634644C3D5E473B
5E48415C45425B434461424764384065273161111B620D15752A306423296B31387C4A50
754C5279585D77606577676D6E5F6770606972646970646870646872676B786A6E806E72
7965687B6668826F707C6F6E726965746D6878736D7D7A767D7E7A8488838A8F8A878E8D
7B8788B3C0C4C4D0D7727E84737D7E6F7A76697875BBC9CC67777F566A7C1A375C082F61
1F466B54758361787D687A807183876C8185BDD3D7C3D7DD8B9EA583979F7F929AA5B9BF
9AAEB48A9EA5C3D6DEC6D8E2AAC1CC7494A83E657CAECBD8C0CBD0A9A6B270749238487F
1839780E39783A52867E597C7E172C8E0A15900A128A050C8C09117B142360365C132460
0F3B719AC3DFBAD7E3C1D6E0C2D6DEC2D5DFC0D4DDC0D4DEBCD3DABDD3DABFD3DCBDD3DC
BBD2DABFCEDA7F77855E25366B0B176C071161111E683448584362282C5B081D5604225A
2D4E7D5070937E9EB593AFBC777E8B552D3A570C1559121B653847493A56161E47041747
05224E204760456D764A6A6C4F6B6A526C684B69634B68634B69644B69644968624C6A66
4A696549676347676245686245686245676142645D3F615A42635B426359426256415F54
425E4E47564121A11400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF007B400E4D1F075D3B25624732614B385C4639
5F46406044435E3A3D67373D5E1F276D20276A151C641118753538703F42744A5176555D
735B62715E6371616676696E72636A72626873636874636870626574666A7A6B6F826C71
85686D8764687C5B5D806C69746B64756F6878746F7F7D7A8888848C8E898A8D8A6B7474
727F81A3B2B6C5D5D9839495707F7D6D7A7795A3A2A0B1B5586C793A53700321540D3366
3D658058757E6E8488AFC2C6BECFD5758991788D9683979F8799A07E8F9696A9AFC5DADF
C4D7DF8B9FA78DA1AA93A7B0A1B6BF93B0BF65899DB8D6E8C4DAE7ADC4DA3B5D8F053282
1247945E8ABD9995B682374D8D10219108139911188F0911850F1B854259302B5C072966
5886AEB3D7E9BED6E2C1D5DFC1D5DEC1D5DDC2D6DEBED5DDBCD3DABFD6DDBED3DDBBD0DB
BED3DEC1D0DD85859354303F551A255E2E3E493552222652071A53021F5A0C3063355A80
7EA2B8698998627E8A829CA487959B564A53563B4652415622274D051A49011B4B0E2D54
3B5F74456C724B716F4B6A684D6A674C69644B69634D69644F6B674C69654968624F6D69
4C6A664B6A65496A6345676145665F46655E45655D46655F43645D3F6158436259425D55
445F5346594923A51A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00824811582F0F5C3E275F4731604B385E4639
66473F693F3F572023652229671B2372232969191D5C171A6B3C3E68494D735A62715A63
6E5C6471616A74656A76656B7D6B726F5D64725E6576626874616877636982676D845C63
8249516E2F357946497F6462786D677F7A747F7D7981807C8586808C8E888D928D898F8D
8E98998B989BB7C7CCB9CCCFA0B1B2ABBBBCA4B3B7687983556D81142E5A011957153663
5C7C8C657F83667E82A5BABFA9BBC2687B82667A808FA3A8C4D6DAB4C4CB7C919AA3BDC5
A1B7BF8B9FA772878FA6BDC3C7DCE1C6D9E2ACC6D891B4D283A9CB94B7D8254C7F03317D
1B4D8D96ACCD9564798D1B2B9F111E970A14940A148A101C7A293D553E660C245D1E4979
A3CBE3BAD6E0C2D6DEC1D4DFC1D5DFC3D6DFC0D3DCC0D4DDBCD2DABED3DCBDD3DDBCD0DC
BCD0DBC2D3E08F99A665616C685F6A343755071A4C011D58072C5F264E72466F8851788A
6C909B98B8C256747F9EBCC4A1B9BF67757D7D8997142844021C480A29542B4D6B4C6F80
5272785070704D6C6A4F6D6C4F6D6C4A68674A68654F69674F69664D6A664C6B654F6C6A
4F6C694C6B664C6B6547676147676148676246645F46645F43625C426058426058445F57
405D52475F5023A91F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008B54145B320D5A3D255B46325E4A385F4337
643A33652829681D2164151A61141B662024652B2C6A3F41684C5065515769575F6E5D66
6E5E686E5F6874646A77656B78656D78646D746067785F677D5C65785157824E54773239
80292F822E307D41418468647A6E697E77747E7B7781817D8688828B8E88898F8A8D928F
8F96958F989B889298919BA397A2A9818D936A787E5E6F7B3C5271031B540018582C4D73
98B6C29BB2B75F777D5A73786B808584989B6D82859CB2B6C5D9E0B9CBD5748994748F96
A4BCC2BFD3D9A0B6BC9AB1B8BED4DBC0D3DF97B1CB224C7F0F457F8BB8DE8CB0D042638F
738DB2A892AB8A2D419E13209D0B14970A128A0C16751E2F75577915245E0B2F6884ABCC
BAD8E4C2D7DEC3D6DCC2D5DDC2D5DDC2D4DDC3D6DEC2D3DCC2D4DCC1D4DBBED2DBBED2DD
BCD1DCBFD0DDA1B2BD99A7AFBECED74257740E2B5B1A40742D5B82608CA180A7B820475C
7196A8ACCBD77D9DA875949F9FBBC37D959C637B85314D6036546B4C6C7F688892617F84
5673754E6C6B4B6A68516F704D6B6B4B68694A68684C68674A66634A68634F6E684F6D6C
5370715572704A686547666348676146635F46625E43605C46635F446159436056466156
405C50486053434B3800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF006B830F5F390D5C3E255E4432644939633D32
581C176E212069191A661C1F5C20226B3D406C4B50654F5462515665545C6959636C5D67
6A5C6671626B77666D7B666E7D666E7C636D7A586381535E73363F752A32802F347D2427
862727781F1E8747478264627B6E6B8177767F7B797F817C868A848F948E8A908A8F9590
8F95918C9292898E9073787B70767A6B7478626E74596B7F182F5C011D5D05265E416381
69858F6A808563787D5D747698AEB0C3D8DAB0C4C96D848C91A6AE92A5AD8C9EA6758B91
BBD2D8C5DAE1B3C8D195AEBB91AEBEA3BDCBB0CBDF3C608A2A5C8E9CC8E9BDD9ECA6B5C7
B9AEBF964F629C1B2CA50F1B9D0C13910F187A1E2D6744631C2A5F082B666088B1B8D8EA
C0D8DFC3D6DCC0D4DAC2D7DDC2D7DEC6D8DFC4D5DDC4D6DFC2D4DCC0D3DABFD2DBBED3DE
BCD1DCBCD1DBBCD1DABED1D8BCD0D8AAC0D07F9DBA133762012754527A999BC1D52F546B
42687B84A5B2809DA85D798468838B839CA1647F847A949CA1BDC5658188849FA385A0A2
5773734E6C6B4E6E6B4F6D6C52706F4E6B6A4C6A674A68654A68634C6C6751706D4C6B6A
4D6C6C4C6B6A49686549676449676446645F45635D44625D45625D49645E466158476157
445F54485F5449524200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049AF0D653E0E5E40246144326842365E261D
5E130C6815116015105E24226A4346684F556352595F52595E515761535C655862695C67
6C606A6D5F6877626B80616B87626D8658646C2E3C8134416C151E7A1F2472181B893333
7E2C2A6A1F1E672F2F7B5D5C7B6E6B79726F767470797C768689838D918B8E948D8F9790
8F98918F9791888F8A797F7A707774737D7D65737D394D6D031C56092B6D264E7C4E7183
5C767A6F838396A8A8677A7D889CA2BBD0D69BAFB67488908B9FA5C3D5DAC7D8DE98ABB4
8CA3ACA1B6BF94A9B47B96A731576C88AEBFC3DBE8B6D0E685ADD075A2CB87AAC9B0B2C5
A87383942133A81320A50D1796111B781B2C775474202E62052C6548729CB3D8EBBCD8E2
C0D7DEC2D8DDC1D8DCC3D8DFC2D8DEC2D6DDC2D5DDC1D3DDC1D3DCBFD3DCBBD3DABAD1DB
BBD2DBBDD1DABDD1D9BDD1DABAD0D7B7CDD7ABC5D55B779605274F244B6D739AB07699A9
4F727F50727D8AA8B07E9AA279959BAAC7CC98B3B9728B93A3BCC37B939A637B81647D81
5B7477536D6F51706D506F6D506F6E4E6B694D6B664C6B664A6A664C6D6A4B6C6A496B68
496C694C6C6A4C6C694A686647656347656244625D47666148676149645E466159476157
476157475D524C574800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B41269400D5B3E205F402D5E2E21540E05
64130A63160E682D26603B36634A4C63535A61555D5A4F565F535A62535C6758626F606A
70606A735C6779545F6C37436C2D387E333F832B387A1E29791F24731F2068201F8D524F
82514F774A497A56547B64627C716E77736F7A7A747E817A8789838D908B8C918C8B928B
909991909991919A93828883757C796D7777637280192F59021A5D001F5E2F54775E7C86
667C7DA5B6B7C8D9DC8899A06A7D85768A919EB3B7A4B8BD93A5ADC0D1DAC1D2DB91A5B0
7E95A08A9FA7BED2DBBED5E293B1C1A6C5D3BFD5E2B1C9DE4066910A3C7A436494B59FB9
943345A81425AD0F1C9D131F8326396443671E2D62072E69416D97AED2E8BEDAE3C0D9E0
BFD7DEC1D8E0C2D9DEC3D7DEC2D6DDC2D6DEC1D5DFC1D3DEC2D4DEBFD4DDBAD3DABAD3DD
BBD4DBBFD3DBBFD3DBBCD2DCB9D1DAB8D1DAA7C3CD7795A95F809A4269844A728696B7C5
789AA8436777A7C8D5A1BECB6B899594B1BB96B1BC627D87667F8663777E5E73795D747A
64797E5D7577567371506E6E4F6F6E52706E506E6A4B69664A6A664C6B694C6C6A476965
4A6A654D6C6A4B6A674665644B696647646147646045625E48676147655F47635A49645B
466257455E524A594A209F1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0055B914693E095F4020633F2B5C2317590C03
66170D6121186D453C634D485F4E5062565B61575F5D525B60535C64545E6A5761755C66
7B586480535E6025317E3D457A3339701D24923D44691B217C393E743F407F5756866967
826A6A735E5F715E5D7F706E7E74717C79757F817B898D85878A838E908C8A8E898E948E
979F979099918D9491858B897379776B75794B5C74021A4F00175C06265A52748B93ACB1
70828676888E93A5AD68798067797F798D92C4D9DDC4D9DF9FB2BC8699A483969E95AAB1
7D929991A8AFC5DAE1C4D7E1BACFDC99B4C880A1BEABCDEA51769E1E43759D9FC6965068
A41E2EAE1321A218269239516447721B2C6A052D6A45709CAED1E9C0DAE7C3D7E0C4D8E0
C2D7E0C2D7E0C1D7DDC4D8E0C2D8DFC0D5DFC0D5E0C2D6DFC2D5DEBED3DCBAD4DBB7D2DB
B9D5DBB9D3DBBAD3DDB8D2DCB4D1DBB5D0DAB0CCD759778A88A8C2224266214569A0C4DA
799DAF254A607091A692AEC064808F55728069868F6581875A767999B1B373898C6A8287
9EB5B962797E5A7675547170506F6D516E6C4F6E6A4A6866496865496865496966466661
4969634E6D6A4D6B6B4A686848686447656046635F48656043615C47666046655E47625C
456259445F554B5C4E25A61E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00704209613B1B582A17602215570D04
6621186F3B316C4A43644E4A5D4B4C5F51555D52595C515A62545E64525E6E5461693E4A
612330752A386F242F8042478B55575C1F238E515679484D8562667C6468817072817375
78696C79676A7968698477768076747C79757F807A878B838689828D8F8A9195908C928D
929B938F99918F9995888F8E747C7C6A768122385D021D5C001A5D12325E628292B9D0D5
74868C61747A6A7E83B4C7C9A9BBBF6B7F859EB5BCA4BBC5859BA5778C93A8BCC1C6D8DD
BDCED491A5ADA6BDC4ADC2CBA9C0CF4C6D8E1646728DB6D7B6D1E8A3A5C0A9738C982236
A91A289C2231A45D78615284162F740A35785582AFB4D7EDC1D9E6C4D8E3C6D8E2C7D9E3
C3D7DFC4D8E1C4D8DFC5D8E1C3D6E0C1D5DFC3D7E1C0D5DEC0D5DDBED4DDBED7DEBAD4DC
B7D2DAB7D4DBB6D3DDB5D1DCB6D4DDB7D1DBB6D0E036536E88A9CB173662022654507895
84A9B95577884E6D7E65818E7A95A0597680A1BDC3A4BFC4647F84A1BDC09DB7BA657E84
70878D637B7F5D7877587572516E6C53706C52716D4D6C68486764476764466863486863
4668624A69664967684A69684969654A69634A67614A666247645F47655F48676046625E
46625A486359495E4E367B2A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007C490B5D300C59230E602011601F15
743931632E266C403953312F634C4E6252556054595C4F57634F5B634856714C59612D39
813F4B64162280353F6F3A40815C6075515683616680666B7C6B707A6D727F747982767B
796A6E7B686B7A686A7D71707D74727A767182827D898A84888A858E908C9395928A8F8A
8F98908D98928895918590907A858A57677E061F53001E64103572254C6E5C7B86677E81
6D80856C7F827C9195C5D9DDBCD0D66B818768818886A0A6B3C8CE9EB0B7A2B4BBC4D5DD
B3C5CD9BB1BC8CA6B1AEC8D3C4DBE892ADC6507797ABC9E0C7C8D7B4859A8F2A40971F33
9A3E53956A91414983103179164281729CC6B9D9EEC3DBE4C3D9E1C5D8E2C6D9E0C4D7DF
C5D9E0C6D9E1C6D9E0C6D8E2C7D8E2C5D6E0C4D6DEC2D5DFBED4DCBED6DCBFD7DDBED7DD
BBD5DCB9D4DBBAD6DEB8D3DEB6D3DBB7D0D9B9D3E33E5E7B3D64865378982F5473456982
6586948BA9B55172808DACB8AECAD4849FA98CA8B2ABC3CE70899369858D6C878E667D84
6981866A8284617B7D5A777459767457737153706E506F6C4B6A66476764496B66486864
4969644B6A664A69684969684969654B6A654B68624C686447645F4A686048665E45625B
46655A476457455C4E49503D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008750105E2D08622E175A23127D4438
692D246122186F372E562E2B654C4E665457665358684F58603B48693B47703C475E2E38
82535C531F26774449724D51795F657F686D7D676E7B686F76686F7A6E747F747A85797F
87777C7F6D707564667D6E7080777576726F82817F8988878C8C8B8A8C8A8D908D929692
9198938F9B948C9A958491917B8A942E4267031B5D021E6B0F3671476E88628084708585
BACDCFB5C8CA6A8085869EA47B939867808360787CA9C0C5C6D8E0BCCDD597A8B09FB2B9
A4B7BFA8BEC95E7986ADC8D6C3DBE5C4D8E3A8BCC8ACB4C0B59AA8833E4F944051B77F98
696092203E880B3E8632629999C1E2BDDCECC3DBE3C7DAE0C3D7DEC5D8E2C5D9E1C5D8DF
C4D8DFC6DCE3C5DAE2C6D8E2C6D8E1C6D9E3C6D8E1C3D6DFC0D6DEC1D7DEBED4DCBED5DE
BCD5DDBAD4DDBAD3DEB8D3DFB7D4DCBAD4DDBDD4E27492A9466D885B859B84A9C13B5F7B
7B9DB2ADCBDB36586C6185989EBDCB86A3AE5D7A8569858F6A828B5D7880819CA38BA2A8
6D858AA1B9BF6E878B5D797A597675597475546F70516E6D4D6B6A4C6B694A6969496868
4A69674968644767644969684A69664B6A654A68634967634A686347635E4A675F46645A
446458426055465F5249534300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009254185C250764311C6935246A3023
632014601A0F6931266C4B43614E4D6750526A464C5F2C355F212C733038601F265D2930
79555B65494D6D5254755E6176646978676E7B687079687171636B796D737E74797F737A
87777E8473777C6C6F7C6D6F796E6E817A7A817E807E7E808687858C908B8B908C929894
939A97939D98939F9C8A97987486980E2656031A650018660C2C606A8A9C7F97998FA3A3
BDD2D5AFC3C96A808660797EA0B7BABFD4D591A3A88DA0A7B1C4CCA0B2B998AAB298ABB1
C5D8DFC8DBE3AFC4D09EB5C2ACC5D1AFC4CDAEBEC6B4B8C08C7981AF8B95C7B4C86A79A9
103C8D084299548EC7AED9F2C0DEE9C4DDE4C6DAE2C9DAE3C8DAE2C7D9E2C5D7E0C5D8E0
C3DAE0C1DBE3C4DCE4C6DBE3C5D9E0C4D8E1C1D7E1C2D9E2C0D6E0C3D5E0C3D7E1BED4DE
BBD4DEBDD5E1BCD3DFB9D2DEB8D3DEB9D1DBBDD3DF94ADC31B40615E89A7577E9F012552
3A60829ABCD17798AA5174845F808C77949E6A878F88A5ACA9C3C978929A8BA6AEAEC4CE
768F977992996E898D5F7B7E597776587574567172506C6E516D6F4D6A6C4966684C696A
4E6D6A4D6C68496A654969664968644B6B644868624B6A654F6A674D686249675D47655C
48675D44615A4760554A5A4A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003E9D04571B02622C186F3928622113
71251C62170F642C246B4C4668514F633F42652C33702B3362171F671F2766272D5C2F36
6C515768565A66555A6D5B6273636A75666C7B6B7177676E6E6166776D737E747A7C7178
81747A7D6C727C6B6E7E6F707C6F6F817877807B7C8382838788868E918C8D938D898F8C
8C9391939C99919A998B979E51658205215D021B6A001A631F3F6BABC8D7A1B5BA8A9CA1
8A9EA47C9096889CA15D7579B7CED2C3D7DCA9BBC18EA0A88EA2A8BBCDD3BDCED59EAFB9
BDCED7C1D3DBB1C7D692B0C5668CA498BACAABC0C8B5C3C9BCC5CCC8D4E57E9DC20F448B
0440A30747A27FB8E9B9DEECC2DCE2C3DAE0C7DBE4C9DAE3C7D9E0C8D9E1C6D9E0C5D8E0
C1D8DEC3DCE4C3DAE2C4DBE2C6DCE2C4D9E4C0D6E1C3DBE4BFD6DFC1D6E1C2D8E1BFD6DE
BDD5DEBFD4DFBED3DFBBD3DEBAD3DFBCD2DDBED3E0A5BCD60B2D591B46716F9ABC14385E
446A885A7E8F86A5B06F8E9973929BAFCCD599B7C085A2ACAEC8D28CA6AF69848D7A949D
69848A637F836581836580815B7777557272567373526C70526E71516C6D4D68674B6867
4C6A674C6A674667624766644968624A6A634B6B644D6C664F6D694A676246655E47655E
47645C47615B4962574A5D4C1EA01600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0047A70C5B210168311B5C200F6F271B
64170E6320176839316D4D49674244682F35641D246D252A66242A5B262D714B53684F56
65555C675A5F64545D6D5A6474626B77676E7A6A717B6B7177696F7F757C7D727A7D7179
83757B806F737C6A6E7B6B6D796C6C8076757F7A787F7E7B8889868F938E8E948E8E9591
969D9A979E9A959D9E92A0AF28406D04236B001E6D00206033557B84A0B07F959C75888E
768A90B4C6CBC7D8DE8CA1A871899292AAB08FA3A7889AA091A5AAC8DAE0C9D9E2A9B7C3
ACBBC5ACBDC5B7CEDC5B7D942B58739DC1D4B8CFD7BED4E0A2C3DD699BC75B97CB4283C5
04469F03489F629CCFBBE0F0C4DEE4C4DCE2C6DBE4CBDDE4C8DAE1C7D9E0C7D9E0C6D8E1
C6D9E0C8DCE4C9DDE5C6DBE2C6DAE1C5DAE3C4D9E3C4D9E2C2D9E0C2D9E3C1D8E0C3DAE1
C1D8DFC3D6DFC2D6E1BFD5E0BDD5DEBED4DDBED3DEB5CEE21E42661E4C75527F9A7CA1B6
7CA0B66B8FA1B1D1DF93B2C3698B9CA6C5D49CB9C667839276929D6E899265808769858A
749093617D7E839D9F708A8C647E825F7B7E577575526E70526F70506D6C4F6E694E6B66
4D6B684C6A674868634B6A664A69644D6A654E6C664D6B654D6C674A696547666146635E
46615A476159435E53485D4C20A31800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004BAC0D5F2604612713601C0F71251A
5F1B10703C32734C456D44446A3236661E256E21277433376B3D426F515A68565F655961
62585F6559616B5A646F5D6675636C7969707868707A6A727F6F76806F767F6B73836E74
70585B8C7276826B6E7E6B6C7B6D6C817776827B7985817E8585828B8E8C888D8B8D9290
929795999F9C959EA37688A30B28640221740F3384163E7A476A8A58748072888D8A9CA2
6B7E85A2B7BEBFD4DC8DA2AB7289938AA3A8C4D9DDBFD3D9889EA6A4B8BFADBEC697A7B1
9FB1BBB9CBD4C7DCE4BCD6E1A2C0CEB2D1DEB9D5E1B6D6EE467AB00B59A62A79BB91CDF5
467AB14984BE98CCF3BDE1EFC6E0E6C9DFE4CBDEE4CCDDE4CADAE1C8DAE2C6D9E0C4D8E1
C8DCE3C9DDE4C9DDE4C9DBE2CCDFE6C8DCE3C6DBE3C6DCE4C4DBE1C2D9E2C2D9E1C2D9E1
C0D7DEC2D7E1C0D6E2BFD7E1BDD6DFBED4DEBED4DFBAD3E47FA5C24778A05888A9A7CFEA
406A8D39668AA1C8E17293AB57788E6C8A9C77929F6A86937590999EB6BD77929786A5A9
ADC9CE748D907E999E728E936380845F7D7F5C7B7B5471714E6C6B4C6C694D6F6A4E6C69
4C69664A69654B6B674C6B664A6B654B6A654E6C664F6C674D6C6749696546656043615B
405F58436058436056465B4C25A71D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0055B512682D03541606671F15611D11
70382C71423A70403C6227276722246723255C21246B41446A4E5466555E635660685D67
695F686B5E676D5E6871606872616978676F7B6871826B7485656F845863693D46946F76
67464A8462657C5B5D715857847471847C7988827F87838081817E868886868A898D9291
909896939A9B8F99A44A5F8704206A001F780124770F366F597B93627C83AEC2C7C7D9DF
869AA369828D6E8A919BB3B994ABB0829CA2C2DBE3B7D0D87F99A092AAAFAFC4C7C0D4D8
A3B9C0B1C5CDC9DAE1CCDFE5C4E0EB8DBCD782BBDFACDFFC4F89C01764AE468CC1BCE5FD
D2F2FFA3D5EF80B8DABFE5F3CCE3E9CFE1E7CCDDE5D1E1E8CDDDE4CADCE4C4DAE0C2DAE0
C6DEE3C7DCE3CBDEE4CADDE4C9DCE4C8DCE4C6DDE4C5DBE4C6DCE2C6DBE3C4DAE1C3DAE1
C1D8E0C0D6E1C0D6E3BED5E1BDD6E1BED6E1BDD4E0BCD4E96A8EB60A397B1A4C888EBEE7
15436C1E4D756C95AF7191A56D8A9B7B95A3A7C0CB92ADB78FA8B1B6CAD298B3BA7A98A0
9EBBC27893996A858B668287617D815F7D7F5E7D7C58777553736E52726E4F706C50706D
506E6B4B69684B6A674C6C674E6C674A68644D6C674B6A654C69664B6A6548676242625C
3F60593F5F57416055455C4D474D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0A7336065A190756130A753B32
78483F612F266C30296F2D2863221F71403E6E4E4F6C585C64565D6659616A5E676D626C
6A5F6971656F70626C70616A7661697D606B835D69814F5A7A37447C293770212D7E494F
805C607A55587B575A8167697C6C6B807876817E7A8484818282818A8B8A878A89858C8C
8B9494939B9E8E9BAE1F376A022071011E790122702549797A98AA627981879DA5A1B7C0
647A87637D897B989FC2DCE0C4DAE279929D738F9A7E99A094ACB1A7BDC1C0D4D6C9DCE0
C9D9DFCAD9DFC9D8E0D0E3EEC0E1F44383B22B7AB291C9E8B9E0F9A8D1EBC9F1FDDAF9FF
D2F5FF7BB5D775B6DAC7ECFBD4E6EED4E4EBD1E2E9D2E3EAD0E1E8CFDFE7C6DAE1C4DAE0
C9E1E5CBDEE5CDE0E6CBDEE5C7DBE2C5DBE4C7DDE5C7DBE4C7DCE4C9DDE4C7DBE3C6DBE3
C2D9E1C2D7E3C2D6E3C2D5E2C0D6E2BFD7E3BDD4E1BED6EB6082B00535810A4188659AC5
6F9AB7638BA57C9FB2ADCAD8A3BBC988A0ADB4CED8A9C3CE7F98A59EB6C18BA5AE738F97
789299768E936E898D7F9BA0698387647F82637F815D7C7B57777454747153756F52736F
4D6D694D6C684C6B674F6D68506E694D6A664B6A644C6B664E6C684D6B674D6B66486762
46666045645C47655A435D4E48534000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783A085417015D2317744139
69332B62231B6D2F256A342C673B366B4D4D69585C65596163575F61555D665B636A5F69
6C616A6E606972616B765F677A525D7738467626348D354083212F811221730D168B484E
7F585C7352548C7073897476786A6A7F767376726E7574728486858C8F8F8A8E9082898A
8B96968D9BA07287A107246102217700207A00226E5478A3BBD7E87D959C5C767E607A82
A3BAC38DA5AF748D97B5CFD7A6C0C96E899490AAB2B7CED4C9DDE2C1D2D6D0DFE1D3DFE2
DDE9EDE9FAFFBBD2E1C6E0F0C7E4F595C0E1A4D4F1D9F7FFF1FEFFF4FFFFCADEE6ABC7D4
B6D8E7B3DDF2B2DBF1D7EFFADFECF4DCE8EFDAEAEFD7E8EED3E4EAD2E2E9CDDFE6CBDEE5
D0E2E9CFE0E8CCDFE6C9DDE5CADEE5CBDEE8C8DCE5C7DBE5C5DBE5C4D8E2C7DAE7C5DAE5
C1D7E1C5D9E4C5D7E3C3D6E2BFD5E0BFD7E3BED5E2BFD6E690B0CE3C679C4B7EB574A4C8
A9D0E88BB3CF81A8C1B5D2E29FB7C8809BAC96B2C08FA9B77A94A0829DA68DA8AE7A9298
9FB7BCA3BBC1748F95A1BCC47B969C6D868B6B8588708C8D6381815C7A7A597775567570
55757054726F52726E506F6B4F6E684D69654F6C674D6C674C6B684C69664E69664D6865
48656047645B47655844605247574600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C3D0E531903643122723C2E
5A190F611B1061291D7A554B71585465535561555A5F555C5F565C60555C61565F655961
6C5B63745B667D5B656F3F4A75313D701420780D199328338518247E0A147B1119914A50
724C4F7C61628A7575837473796E6C827A767D78747473707B7C7D86898A8D9192899191
8B96968E9FA7435F8104256B00237B072E87002670547AA584A2B2748C92647D8287A0A5
C4DAE1BBD0D98096A28099A290A9B0A9C1C7ACC1C8C3D8DDCCDDE1D4E1E2EFF6F6F2F7F9
E3EAEFCEDFEAADC5D3D6EDF5E4F3F9EFFCFFF4FFFFF5FFFFF0FCFDF4FEFFEFFAFEF1FFFF
EFFDFFF3FFFFECF9FCDFEBF3DFEAF1DEEBF2D7E5EAD4E5ECD4E7EBD4E6E9D2E3E8CFE1E8
D0E1E9D0E2EACADDE4CADEE6CADDE4CBDCE5CADDE6C7DBE6C3D9E4C4D7E4C5D8E5C1D7E4
C1D8E4C3D9E5C4D7E2C3D6E4BFD5E0C0D5E1BED4E0BBD2DEABC7DB9AC0E74F80B673A3CE
9CC6E82150785080A49CBDD498B3C692ABBD94AEBC9DB5C28BA4ADA3BEC6B2CBD188A0A8
A4BEC6A9C2CA7D959E7E969E778F946F888B748D8E7C9596748E90647E7F607B7C5F7B78
587674567474567676537271506F6B4D6B664E6C674A69644D6A674E6A66516B694D6864
4D686149655C486659456255465A491E9E1400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008246145621086331205B2114
5E1A0C6225155F3527735D53695A5862555860545A60555B5D53585C52595D515964545D
70565F724954672D387C374281313C7918218A2028962F3687252C76171D8D3E43835054
836769816E6F8474758174737F7573837A797F7B797B7A787B7C7C868A8A8A8F8E8C9493
8D96988B9BAC1D396B02237601248217419C012B715D85A97F9BA6ABBFC29AAEB47C919B
ADC3D09EB4C194AAB69BB2BBBBD0D6CCDEE4CDDDE2DEECEFE3ECEFF2F8FAF9FCFDFBFDFE
E6EBEEDBE4EAF2FCFEF8FEFFFBFFFFFAFFFFF3FFFFC9E8F1B7DCEAD2E9F1F2FBFDF8FCFD
FAFFFFF9FEFFE9F0F7DCE7F0DDE7F0D6E4EBD6E4EAD6E5EBD5E6EAD5E3E7D3E2E7D0E0E7
CFE0E8CDE0E8C9DEE5C9DDE5CCDFE7CADBE3CADCE5C6D9E5C3D7E4C4D9E5C3D8E4C2D8E5
C0D7E4C2D8E5C4D7E2C2D5E3C1D4E1C1D4E1C0D3E0BDD3DFB4CDE55278A806387E255A95
81B1D4527E9F648EAC85A5B8A9C1CF95ABBA9FB7C4BBD0DD9BB5BF9AB7C1ACC7D18AA2AC
87A1A9899FA9899EA78CA0A7869A9F8A9FA2849B9B81989A7A92966C8587678283637C7D
5C79775A787959777854747451716D4F6F685070694E6D68536F6A526D694F6B684E6B64
4E6A604B695E48665A476457475E4B22A41A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0060730D5D270B572412581C10
5F24156C3F2F69504371625B6A5E5F63555B60535A64565D62555B5A4D555C4E5669535B
5E3B4377434D661D2875232D82303772192077171E7521268E4B4E864E5190646884676B
7E6B707F747783787B84797A83797B837D7E7E7C7C808180808382858A88848D8A889190
909A9E798AA10B266202257E012489002685083579678DAE8AA0AAC6D4DABECED699ACB8
95ABB7AABFCABFD1DCB9CBD3C6D6DBD3DEE3E6EEF1F3F9FBF8FCFEDEE4E8DDE4E9FBFDFE
FBFCFDF6F9F9FAFFFFFAFFFFF5FFFFE7F5FCD7EDF6A5CDDCA8D4E3DEF6FBF8FFFFFBFEFF
E9F0F3D4E1E6DCE8F0DFEBF4DBE5EEDAE6EFD6E5EAD8E6EBD6E4EBD7E5EBD4E3EAD0E1E9
CDDFE8CADDE7C8DDE7C9DDE7C7DAE4C7DAE4C7D9E5C5D8E6C4D8E6C1D7E3C0D7E3C2D8E5
BFD6E2C2D6E2C3D6E2C1D3E1C1D4E2C0D2E0BED1DFBFD3E1ADC5DC4A6E9708356C295A89
6A96B0A4C8DB91B4C88DB0C0B4D2DFA8C4D585A1B0ABC4D096B2BD7797A27E9BA67D97A2
7F98A196ACB58DA1A99AACB4B3C5CB9BAEB292A6A9889DA07A9296728B8F6B8787617C7D
5E79795B78785C79795574724F6E6952706B51706851706B51706A516F6A506F6A4F6C66
4F6A604C675D4B675D49655A445C4B32772800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A309612806521B08582111
693C2C6D514364544B6D615C685D5D61565862555B66555C664F5762484F5438406B4C55
5F3B43804C546E222D721D257C30356A24296F2D338C565B8E626993656D97626C7D4D59
8666717E7277837B7D847A7B847979827B7A838181818381828686818987858F8F8D9697
909B9F8296AB0E2C65022782002891002C8E23549488ABC896A7B2A9B4BDA4B0BAAEBEC5
B2C3CAC9D9E0D0DDE6D2DEE4EBF5F7F0F6F9E9F0F4ECF2F6F7FDFFDDE3E8D8DFE4F9FCFE
FEFFFFFCFEFFEEF7FBDFEFF9B3CDDAC1D8E5DEEFF8E6FAFEEAFDFFF5FFFFF8FFFFF7FEFF
ECFBFEE4FBFFE0F6FFE1F0FADBE9F3D9E5EED7E6EED2E3EBD0E1EBCBDEE7CBDFE8C9DDE7
C9DCE9C5DAE6C7DCE7C7DDE8C1D8E1C0D7E2C3DAE6C0D7E4BFD6E3BFD7E2C0D8E2BED5E2
BCD4E0C2D6E1C2D5E0C2D3DFC0D2E0BED1E0BACFDDB9CFDDB3CCDD63849D8AB3D17BA6C8
628BA5A9D0E7517C9C5985A595BACF6D8FA27090A088A5AF7E9BA46F8E98A6C3CC9BB6C0
819CA6AFC8D298AFB8859AA49EB1BA879AA085999C8BA0A47D9297748D91698586658182
627D7E5E7A7C5D797A56737153706C58726E58726E55716D54726E52706B57736F526D69
536A65536B654F68614C685D455E4F414B3700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EAD106326014B1200522111
6A473869534867574F6D615C6C625F635758665357694B5263343D6228325E2A337B535B
603A4186545C5F1C23712A307E454A7D4F5686575F87535D8A4C577326328D303F761E2C
7F4750877276877D7F8A8081857A7A847D7B84837F888987858A89898F908F9798939C9D
94A0A293A5B6234376032C86012E9A0133973366A7AED0EAB7C5CFC3C9D0C9D0D8D1DBE2
D5DFE5DDE5EBD9E2E9E0E9EFF2F8FBF2F8FBD5DEE5D3DEE5EDF4F6F3F7F9F3F7F9F9FDFE
FDFFFFF8FBFDDAE3EAD9E8F3D2E6F0EEFDFFF6FFFFF6FFFFE5FDFFC0EBFCB4DEF4D7F3FE
BFD9E3B6D5E1C1DFECCFE3F0D1E2EDD1E1E9CEE0E8CCDFE8C6DDE6C6DDE8C4DBE6C5DBE7
C5D9E7C5D9E7C4DAE5C5DBE6C2DAE2BED7E2BDD8E2BDD7E1BED6E1BED5E2BED5DFBDD4E0
BBD2DFC0D3DFC2D4DFBFD0DCBDCFDCBED1DFBAD0DDB5CFDBB5D1DE7192A585ABCA194070
2049786F9CBE1241662C5B7D5881957596A57D9EA98FACB5ACC9D07E9CA6A6C2CDA8C3D0
73909D96B2BE839FA9849EA887A0A78A9FA6879DA1869A9F798E9472888D688285678284
617D7E5D797B5B78795976755976735971705B75725D777457757152706C55716E57716E
546B685369665369634E685E47635441513C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056B6166227004D1903582F1E
6A4F3F69564967594F6F645E6E62606E5B5D69474C622932661921650D1761172081515B
623C457D555C60343981565C8259617E4D577A364275232E8931398C2932861520831721
80383F8E7275887D808C82848980828781818B8C89888D8A8990908C9394969B9D999EA1
9AA0A49EABB94C699605328A0237A6023CA3275CA0AFCDE9C9D2DADCE0E5DBE1E9CFD9E1
D4DEE6E1E8EEE2E9F0DCE4EDDEE6EDE7EFF4E3EAEFD9E1E5F2F8F8FDFFFEF8FCFDDBE2E6
E0E6EBF9FDFFEDF1F4EEF2F7F7FEFFF4FFFFE6FAFFD1EEFF8ABEE33C8FCB549FCFC5EFFE
DBF6FFC4E9F8B7DBF3C9E1F1CBDEE9CCDEE7CCDFE8C7DCE4C2DCE3C4DCE6C1DAE3C2D8E3
C3D9E5C7DBE7C5DBE6BED6E0C0D8E1C0D8E3BCD5DFBDD6E1BDD6E0C1D6E3BFD4DFC0D4E0
BED2DEC0D3E1BED1DEBED2DEBCD0DDBACFDBBBD2DCB9D0DCB6D0DE7594AB3E668C022861
042A624170916590A46E95A8668A97ADCCD790B0BA7C9BA7ACCAD484A1AE75919F84A1AD
6B8895698591718F9875929B85A0A7869FA57F969C7B9197758A916D8489647E82627D80
6380805977775473755775765674725A74745A76765C767458757053706C57746F5A7471
516C67506963546C63516A5F4B6658465A4700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0C6C330554270C573822
66503D68564766594E6F625C6F5D5B76585955202464141B7B1C21700F145C10167A4C53
6F50586D50577B5D647D5E657B5058803E487D222D811A238B272F963039871920871F25
7932388F72788980848D888B8B888A87858788888B90949691989B959C9EA1A5A7A7A7AB
A9A9ADAFB2BC7D92B70938890345B00850B53672B3D0EDFFD7E1E9D7DDE4D2DBE4D2DBE5
DCE6EFD4DFE6E6EFF5D4DCE6D2DAE4E2EBF0FAFFFFFAFEFFF3F7FAF5FBFDF4FBFDD1DBE2
D9E2EAF7FCFFF8FDFFF4FCFFE5F2FDA5C4E65A8EC08FC1E99CD0F65EA0D38AC7EDBFE8FF
BEE1FC5889B384B5DBBEDCEDCADFE8C5D9E2C8DBE5C7DBE2C3DBE1C3DAE3C2DAE2C3D9E3
C3D9E3C4D9E3C0D7E1BFD8E1BDD6DFC0D6E3BFD5E0BDD4E0BED4DFC0D3E1BFD2E0BFD2DE
BED2DDBED3DFBAD0DCBCD2E0BAD1DEBAD1DBBAD2DAB8CFDAB6CFDC92B1C3456B8644698E
51789C48738CA5CADA9DBFD1638A9EA0C4D68DADBD5778886B8B9766828D607D87809DA6
7B96A0708D96A7C6CD7C99A290AEB78AA7B06E8990678085647E83637F83617E815B797B
5E7B7C5575745574745371725371725773765A76775D77765D77745E7974607E77647F7A
526D694B6661526C63516C634C695B475B4C1B9D13
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006F38075A3111583C22
644F3C66554767584E6F5D576E535077494A631D1F660B0F761719691314622324764E53
7B5A637F576177485382515B83475182323C7E1A25841C24862930852F377E292E7C3034
86525991767D91848B97929797979A919194949497989A9E9A9CA1A2A5A7ADADAFB1AFB2
B9B4B7C1BCC3AFBDD7214F92084FB41160C22F70B1B9DDF5CEDBE2D9E1E6D7E0E7D9E2EA
D7E1E9CDDBE0DFEDF3DFE8F0D7E0E8E0E9F0E5ECF3E8F0F7CFDAE3D5E2EBE2F0F6CCDBE2
DEEBF5D3E0EFBFD1E5C2D8EEC7DEF8759EC9326FA591C3EABBE0F3BDE4FC75A8D74682BD
81BBEC417DAE7AAED2C0DDECC9DDE3C7D9E1C7D9E1C8DAE2C6DAE1C5D9E2C5DAE3C4D8E2
C2D9E2C2D8E2BFD7E2C0D7E3BFD6E1BFD4E1BFD4E0C1D7E3BED5E0C0D5E2BED1DFBFD2DF
BED2DDBED5E1BCD3DFBDD2DFBBD1DEBAD1DEB6D1DAB6D0DAB8D0DCAFCAD66183939BBFD5
7FA6C6416C908EB4CF496E8C174162567E9660829258768669879296B3BC708E979DBBC4
A5C2CA708D97A0BDC67E99A364818A638289618085688488658184688587688587668385
5A767753727050706D516F6F5572735370705472725976745E7975637E796A878267817E
5A74714D6662516B664E69624D695C4D615120A319
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C470D5E3811573C20
634E3A66544769524B714F4B7A4A486422226C191A650B0C6B1A1C66272773424573454F
7C43506B222D84344073242F85343F8D364174161F7D242980393D955D6289575B996C72
9B70799268708A6C72A4969AA09EA29E9EA39E9FA39D9EA1A2A2A6ACABAFB5B5B6BCBABB
C9C7CAD1CED4CBD4E84A71A90647A5024EB24184C5B8DBF3D7E2EAE3EAEDE5ECF1E3EBF1
D5DFE7CBDAE3CBDCE4D4E3EAD0DFE5CAD7E0CAD8E4C0D0DDC5DAE6BCD3E0B3CAD5B7CFD8
C2D9E5BFD8EE6485A77596B9BCD8F2BAD7EFA0CAE990BDE3A6D1F2A2D0F31A599C0D5BB2
377FBF99CDEEABD0E5C4DBE6CADCE3C9DBE3C8DAE3C8DAE2C7DAE1C6D9E3C8DCE4C5D9E3
C3D9E4C5DAE5C4D9E5C3D9E5C1D8E4BFD5E3C0D7E4C0D7E5BED6E3BFD6E5BFD5E4BED3E2
BAD3E0BBD5E4BCD4E3BAD2E2BAD3E2B5D1E1B6D1E1B4D1E0B7D2E3B5D2E386ABC180ABCD
133E7604306E4977A24E7896355D775E85979EBEC88AA6B27B99A4A8C5D18DAEB97C9FA9
97B9C06F8C9769858E6D868D6581866B888B5C7A7D6480846683856784856B8888688486
5F7B7C5472704F6F6B4D6B6B516E6E506E6E4F6E6C516F6C5775705D797566837F677F7F
647E7C60767459726D526C64516C5F52675724A91E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00885311613D13553B1E
644F3A644C406D47415C221F742E2D6C1D1E6E1C1D601818743C3E73434867333A6A2934
6C192672101C87242E872C366B19228640477235397B42468F5E659668718F5F6A8E5B66
8D4C59702A33AB787CB39CA0ADA6ACA5A4A9A6A6AAA4A4A8AAABB0B7B8BDC2C4C6CBCDD0
C0C4C9C1C3CABEC5D37B97C10E489D044FB53172B9BEE0FADBE4EBDBE0E6D8E0E7D3DBE4
CFDAE4C6D6E1BED0D8BED0D7B7CBD3C7DAE6C6D9E7AEC4D399B2C08CA6B2ADC7D29EBAC7
B3D0DDBFDBED9AB9D492B2CDA4C0D6B0C7D79FC3E329649F256BA88AC6F24781B62B6DAC
74B2DEB6E5FDC1E0EFC6DCE6CADDE6CBDDE8C6DAE5C9DDE7C9DFE7C9DEE8C7DEE8C5DEEA
C0DDEAC0DBECBEDCECBBDDEEB7DCF0B2D8F0B3DAF5B2DAF8AFD9F7AED8F8AFDAFBA9D4F7
A6D4F8A5D4F9A1D0F6A4D1FAA1CEF69FCBF59BCAF398C6F196C4F197C5F45589BE4C85C5
0E4092023185427BB687BAE198C5E378A4BFA2CAE2A5C7DF6F93AB93B6CD6D94A75E8695
7397A270919A6E8D959AB6BD728E9493AFB4829DA2617C81648184607D80698687698588
637E815673734D6C6A506D6C4F6D6C4E6C6B506F6D52706E57757054716D55726F668180
6984838EA6A56C827F58716B536F6351685A25AB22
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00905D17624113533B1E
5D4A345A4132572A215B1812742621661B196D2E2E713E416C3C4261282F5A11186F1C25
791C2575101A81242D80353C71343C8F61688661668E646C89515E8139487D3140A35B68
8F3E4AAA555F96565BC2A4A6AFA7ABA8A9ADA8ACAEAFB5B8BAC1C5BCC2C7B6BBC0B4B5BD
AEAFB7D3D1D7CAC7D0B3BEDC24509A064AB01655A3A7CAEBC5D3DCCBD5DDC9D6E0CDDAE5
C0CED9B2C3CDC4D6DEC1D3DCA7BBC8AFC5D4A7BECE88A2B086A1AEB1C9D4C4DAE5A6C0CB
98B4C0AAC4D2A7C2D1A0BCCDAAC9DCBAD8EC9CC2E4205E9C2B75B39CCFECCEF2FFB7E7FE
88CCEC7FC0E3B6E2F8C8E1EEC9E1ECC8E1F0C4E2F4BFE3F5BFE8F9BAE5FBAFE1FBA5DEFC
9BDBFF8DD0FE83CDFC75C4F968BBF55EB1F452A5ED4E9DEB4190E23C89DD347FD52E79CE
2971C72A72C92369C21E62BC1D5EB71C5AB41856B01954AF1750AD164CAB0D45A40F48AB
0A3FA702339A0B419B1F55A2295EA71F51973362A33A64A32F5A953D689F436FA1507EAA
81ACD18DB6D56D94B09FC3DD7FA2B76E90A06E8B995F7B865C797F5A787A627F81678387
6781855A767753716E4F6C694B69654B6A674C6B68516F6B5875715775705E7C79668381
718E8D849D9E8096955F7775536E6752675D29AD26
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A808633F12563C21
5B422F573A2B54281B53130A6620175B1F197648466B3D41592128621A205D09106E171D
7622297521296B252C8D5D64835C658C616B8F5A668844527F27398A2033851B2BBB6872
9749538E3842853D43C19EA1AEA7ABAFB3B7B5BEC0BDC7CAB7BFC4BCC1C8BCBEC5BDBBC1
BDB6BCC0B5B8C6B6BAB8B4C83D5896063D9C11499AA2C8EDC0D5E2B3C5CEAABDC8B5C7D1
B2C3CDA8B9C4C5D7E2C4D7E29BB0BD8AA1B093ABB6B3CAD390A8B39BB3C0C2D8E3B6CBD4
AEC3CBADC3CCBDD8E4BDDDEF6D95AD97BBD0D0EAFBB3D5EBB6DDF1E3FEFFD0E9F4AAD3E2
7CBBD798D6EBC0EDFAC6EDFBC0F0FDA9E4FD8AD4F77BD2FB6ACBFA61C7FC44AFEE329FE8
2795E72090EC1A8BEE138AEF0B80ED0A7BEF0670E80D6CE60D60DA125AD21356CC1654C8
174EC01748BB1B47BA1B43B61A3DAD1B39A81B39A61733A0142E9A122993112890102890
122C95122E970E2A920E2C910F319209298B072684072782082C84062A8105297E052D7F
0B3483153E8811397F2C539529528C33598B4569914C708F56788E5678865B7C85618089
607E835E7B7D5675724F6E6A4D6D684D6B684D6C694E6C6851706B52716D607E7D688684
7B9896809999849B9E637B7B516B6651655D454B3A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047AD0C6841115B3C21
4A29164A26155227194D15095B21156D3A32623132591E24601C226F20265F090F67151C
6D2B306E3A4078515781646A846069763542791D2D8A2633972C3A9B22328E15239B3F48
BF7A82964D5685444AB7989BB4B0B4B6BDC4B9C3C8B7C0C6B2B8BDB4B6BCB3B2B8B3AFB4
B7AEB2B3A8A9AA9E9FA4A2B052689A08358A0C3D8B90B6DCAAC3D2A7BDC8A4BBC4BBD1D7
C5D8DFA0B3BEADC0CCA9BCC7899FA8859CA4B5CAD0C7DAE2B5CAD595ABB9B5C9D5BCD0D9
C2D6DDD4E6EBCADEE7C6E1F0ABCCDDD8F3F9F0FFFFEAFEFFDDFEFFC5F4FFA0DDF4BAFAFF
ADF4FFA5EFFF95E5FE70CEF854BFF14CC2FA32B5F523AEF411A1EF0C9EF50696F3048CF2
0787F50174EF016FED057DFA0375F5016AF00562E62152CE4441B05C399E64379463318B
692E856E2C82722B80742C7D7228777226726B236D671F68611A605E185A591555581658
53175B4E175E4C156048145F44165E3E155F3A165F371B652D19642415642319691E1A6E
1B1F77131D7710237B0B237C06227905227304226A0626670F30691D3D6D2E4F78436689
5478915F8090597C83517275517171516F6E4F6D6B4E6D684C6C67506E6C5271705B7B78
8EACAB9AB4B4859EA15B7577506A6750645C444A37
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB4106B3F0C552C12
4E23134019084F29175123126C34255C1D166522226C2428661C217023295A0F1467262C
80545A73555C735F677A676F8C67706A1F2B8216238F1E28A3363E8511198E1D24832F34
B07C8182585DA78186B6A3A7B0ADB3B0B1BAAAAEB4AAAEB2ABADB0AEADB2AFAEB3B0ADB3
ACA9AE9F9EA08E8F9089919B6179A1062E780A357B789BBF8AA1AEA2B4BDA6B9C0C1D5DC
C4D9E0A4B9C4A4B8C3AEC2CCC0D5DCB9CED4B7CAD3CADCE8BDD0DDBFD3DECCE2EDBDDEEF
B3DEF4C7F2FDCFF9FEC7F3FFC4F5FFC9FCFFB3EEFE89D6FB6BCAF449B7F032A8E837AFEC
26A1E21E9FE31CA3EC0D99E90B9CEF099FF1079FF108A3F6019BF4009AF6029AF90092F4
0391FA0283F30281F40586FA047FFA087AF8266EE96D51B7AF3980C62A5FC62250C92450
C71F47C81E47C81D44C3183EC31B3DBE1A39AE0E2DAE1330AA132FA5112DA3122E990D28
910A278C0828910C2F8E0C2E860A2C810D2F770D30701237660F37620C38650F3E600F40
5910465413504B15533C14562D11552411571E135B13135D0B145F07175F051C62042062
08266318386B2E517943678650758852737E51727552716E53726D577471537270537373
75959798B3B689A2A659727648636251645C3C7F31
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B915723F0D532007
5524134D231157311D61311E6523165A09065B0809782C2F632023703436622F34805259
764853663E4A7A5E6879646D8A686F6C2D3781212C80141CA03D427D24288B4144956466
A68F91A49699A59B9EA8A0A5ACA6ABAFA9AFAAA6AAADADAFABACAFA7A8ACA5A6ACA4A7AC
989CA192979A8C91958491986E87A50628690A31717091B19EB3BDCCDBE0B8C8CEB4C7CF
B3C7D2A7BCC7B1C5CFBBCFDAC3DCE6C8E1ECCBE5F2CCEAF9BFE6FCB8E7FFB5EEFF74C3F6
53B4F541A6E550B5EF3CA3E2339EE039ABEC259EE81399EB0C96EF0693EF0492ED0792E9
0F93E71897DD27A4E226A0DD29A9E528AFEB23B3F31FB5F81BB7FE15B4FF0EACFF11AAFF
0DA2FF0E9BFF0D96FF0B8AFB087AF20E78F43666DB873D94C92552D61B32D2172BCF162A
C30C20C50E23C40F20BF0B1CBC0D1CBC101EAD0713A50413A30816A106149C051390010F
8A010F8C01109608198F031287051281121B923C459F5B638A424F7115287E0A1F860519
87051B84061F8006237906266C0829630A2E580A324909363A0839350F46260D4B1D0F53
15155C0B1861041A610524640E32652649733F627E50728158787D597878547271567575
7494948DA9AC819A9F5E787C46615E55685E2AAD25
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00733A08571C06
5B2313592A196333235D1F1262120B6B13105E0A09712B2C5924266F4548724C50703B46
671E2C66202D8E606A6C4D558263698E6067803842711D2387414497666AA484889C8B8F
9A93979C989C9E999DA49DA1ACA3A8ACA6AAABA8ACA8A6ACA3A4A9A0A1A6999CA29AA0A6
949CA08F989A8894968393997E95AD0C2E660A336E7295B49EB4BEC5D4DCBFCDD7B4C5D2
B5CADABFD9EABEDBF2B8D9F6AED9FC95CDF97ABDF161ACEF3B90E0308CE3238AE41186EB
078BF3068EF60B94F80891F5028CF00695F70193F20195F10596EB119EE92CAEED54C5F3
7DDCFAA0EFFFA4F7FF97F7FF75E8FF5BDBFF3DC5FD2CB9FC1BACFB0F9EFB038AF30586F6
057FF30172EE056EED0460E20351D4064ECE324EC1772B7DB51740C11225BB0C1CB7091A
B3091AAD0516AF0818AD0817A205129F08149707139104148F031294051492061383010D
7C030E7A010D7B020D7C020E70050FB1696EDFB7BBBEA3ACCFB2BCB383906A1321820715
88040E86010D86010E84020E81020E7D02107802107603147105186C051E6508275B0C33
4D0C3B3B0C42280E4B1A15570F1B60081F6305225F1334663257785176885A7C83628082
728F8F88A4A76E888C5672734966605B6E6322A41C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723209591804
612514662F2153140A6A1C16630B076D1312590C0B703A386A424371484C643038702732
70111D680B158A4D54815C64856B748D737B6E484E8D6166937276948187988D95968E97
9991999B9399A1979CA2979DA79DA39F9AA09B9AA09A9A9F939498929599959B9F959CA1
8C9498909C9D819293819497849BAE1D40721947828DB6DEA2C0D8B2C9DEB8D0E8BAD7F5
AED5FD81B4EB5C98DC4385D82C77D7146CD8096AE00971EC0671EF0270EF0273F30278F6
0182FA0087F8028DF70190F50194F6059CF910ADFE1BB5FF33CAFF45D2FF54D5FF66D5FD
68C8F66CC3F550ACEB349EE71C92E9128CEF077DEA0879EA0772E20868DD085CD60D59D6
0F51CB1247C21942BB233EB42230A2282C9A3E25877E1F66A81134B0091CAE0819AB0617
A504139F0110A106149D0B16860A118523288F3A43893645741727780A1B7C0A16721018
78282F681C255B0C1664121C5D0E1A905261976E7C502F42776070D4BFCC7742506E0D1B
74040C77040D78030B79010B78000A7C020C7B03097901087A010A7C020B7C030D790210
77031772061F650A29570F35400E402E14501A17580B1A5D07225F0E30603C6080628595
7393988CABAE6480824F6A684B665F5E6D620ECE0A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0079350F581706
6C2D1F641F165D0C0869100D6209056C201D66302F6C4946674645562328631B24863039
700C15720C14772D359671798B78838B7C8787777F87757B8C7D848D838A9089908F8892
928B94988F96998F96978D94958E95949097908F959191968F8F958E92988D9599969DA3
929A9F93A0A287989B8D9FA693AAC13D61990C3E8B5F95DD568AC95A8BCD669BE0417DCB
2C6BC70F51BD0950C70651D00457DC0262E90064EC0067EF006BF20171F40378F7047FFA
078AFD0A92FF0D97FF0F9CFF0B9CFF0C99FE0694F80791F3098EEF0D8AEE0C85ED0D7FEB
0E7CE8157BEA1471E3156ADD1B64D9235DD42E55CC374FC23B42AD443AA04C359A553598
603793632D846A287B7627777A236E7B1F697E1759971545AA0D28B0091BAD0617AD0817
A80716A406149E07138F121ABE7072DEB6B9DCC2CBDDC3CFCDABB888505E5A1722BA898E
D7BDC0CAB2BAA48B91C8ABB1865D6A4F1D2E9A7684AD95A28E8390C2BCC78A6E7C561E29
793A3E6E2D315C1317610E1465091066040B6C040B700208710006750106770106790108
7A010B7B010C7A020D79031273051C670A2A530F35360D3E1F12490F1652051E571E4472
749EBA8FB5C465848856717049615A57605300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C391162210E
7531255E0C07660B096C141163181276403B6F4F4A6A53506C4F4F5F292C5F0D138D3238
73151C71171E6D2C348B6B74887B84847982847982837780857982887C858D838C8C858E
8E87908C858C8E858E8D848C8F868F8E878F918D9492919792939895999E959CA2979FA4
98A1A895A2AB92A6B781A0BD6B93C73060B001339A0539A50D44AF0541AF0850C20650CB
033FC20134BB0138C2013CC8004CD7076DF40473F8077BFC097EFD0B80FF097EFC0B83FE
067DFA0379F50274F10173EF0272EF046AEA076BE70865E11264DF175AD4245AD23257CD
4457C8514FBF634DB97049AE74409F803E998334898E3284952D769F2F729824679B2567
98216197236091225E8A205C8A24628425637B215F892059A3183FB81029B60818B90B18
B80C18B30916A60B189C2431F9B5C0E1B7C8996B858A6178CCB9C6CEBFC85B424CCEBDC6
C6BAC78A7286B29AAACCC5CE948893786471CDC0C9AC9FAFA79AABC3BECC9086948B7882
C5B4B8BAA9ADB59EA1B49398603239A36B75661F2963030E6A01066D01066F0003720106
7502087401097701097C010A7F010B7F031078051668051D5A0C2C44123F24134D0F2163
1138755885B07EA4B9617F8351666046493800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C6C0B6E3118
651E11610A05630C086A211A74393172443E6D4944735451634544703C3C621012711C1E
813D3E794748825F657E6C727D737A7F757E7D727A8377817E727B80737E857A84847D86
877F89887E87897F8890858D93878F938A919994999191969A9DA299A0A599A5AD99A9B6
98ACC2829DC2577EB51E529D0F4CAB0945B1012FA50126A00024A0002CAB0345C50650D4
0037C3002EBC053ECE064AD80459E7096EF90372F90473F80470F30167EC0462E9035ADF
0558DB0B58D90E51D0104AC61C4AC12C47BB3D48B7544AB56644AA743D9C863E9794398E
9F3485AB327FAD2D79B02F79AF377A9C3272953676923C7E8C3F828A478C7D4A926B4590
624A965246944B4D9C454EA23B4AA43649A83147A74D48A4883378BE1D43CE1727CD141E
CA121CC4101BBA111EB01C2EB33C52A039537E203C6A263EBEA6B2D5CED6776874CFC1CD
BBA5B6632A46662B45D1BBC89A939E968E9BCBC0CE634059552740BFAAB99B92A09B919F
B7ADB653435292828FBEB3BD584752CAB2BE7445555D08176701076700036800016B0206
6A070A6D10166E08107A030D7C010A7F030B7A010B7B030F7C07167609236311373F154B
1C1D621132754C75A47394A9556A6824A72000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003A9B026C2E0F
560D025C090260170D743B307A433C7339326028227F554E55342D784D495D221F6B3331
89676779686A786B71786D757B72797970787B70797B6E777D717B776B767A707A7A727A
7D767E857B848B808791848A9B8F959D959AA09DA29CA1A89BA5B394A6BE7C98BC567CAE
315C9E1747990B42A40540AD0441B6043EB8012CA600219D0024A4012CAE0749CC0D5FE6
0855E10349D80348D7024BD90657E5045BE9045AE50757DE084ECF0C45C31841BB1F35A8
2D319D4234995432906130887936898834808F30799D3079A62C73AA2F72B13D7CB24686
A546899C4C938D51998A65AE786BB16571B75175BB497DC24282C82E76C6257CD1218ADF
1B90E71993EC118EEA118BEF1288F20F80F2137BF1256CDF7451ADC32F61E4283AE1212A
D91A25D11823CF1D27C71D2CB01B2BA02C3AB1646ECEA7B0D5C5CFD6C1CE765565D3BAC9
C7A5B775243F732037D8B5C2A699A7A194A5CBBACA632E475D192FC5A1ADA993A276556B
CFB3C289748381727FC2B9C4544452C5B1C07B51625F091A6B01096900046B0205690308
67181ACA90926F232D720815760A1072070D72020B79020C81030E870513810516750C29
5A18482F206211286A466891556B7525A72300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049AA0C6C2D09
5710015C140572362571392D642018772B23651F18824E4672524979605A7B625D796361
7A6E71736D73736D74706970726B71786F77736770766872746771756A747970797B727A
817980897F8890858E9589919D939EA39FAE9EA8BE849ABD5477A82F589B134496073B9A
0438A00338A40334A4012FA40034AE0136B40638B6002CAD0430B50336BB0546CD0758E1
065AE60751DE0748D40946D00440C80D42C51C3DB82B31A1422E93522A84612577712470
7C22668722639126659329669C326F973A7891488A855199795AA36F66B0646FB7607CC2
577EC15884C06698CD6FACDD75C5EE64C8F157CDFA48CEFC44D2FF34C4FF25B8FF15ADFF
0DA9FF0CA4FD0B9DFF0892FE0787FD047BF70675F30F61DC5348ADA92862D31D34CE1120
CA101EC30E1AC2121DB41520AD3940E8A9ADE3C6CCDBC3D2C79DB493506C79354BE1BBCA
C199AB79223A802839E2B9C4A48D9DA08A9DD1BFCC6B42535D2939CBADB8A789995D283F
7E4F60A98E9BBDB2BCBEB5C1584553C8B3C17C5162650C1D71020A7000036D0105670408
5A151AC9A4A87038436A10209A4951A25A6168101A6E0610750610840A1589070F8A0512
850E24691B4831205F12296138536C22A72700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B1136A2A06
5C1B08672916793E2D67231763100791392F65160B6C322779595078696379706D777071
7772786D666F6C666D6C666B70696F72697174697174667070626B6F636D776D7580767E
837C848A858F8F8C999293A8868FB1687BAC375798164292083B99073EA60438A70336A7
0032A20132A2022D9E0530A60738B10437B4063BBB0333B90331B80430B90332B90C44C9
0945CA053DC2012BAE0123A1011F9520208A5E2B847A1E69891A5B8E1B578A1B54892660
80326F6F3A7D684E975A539F4F5AA74268B7387AC8348CD8339AE435ABED33B2F14ECBFB
72E3FF90F2FF9BF4FF98F1FF7EE5FF55C9F931B0F226ADF61EABFA109AF3078CF20180F0
0381F4037FF50074EF0067E90161E8005DE20058DB074BC9393AA18D1F5FBE122EC30E1F
BF0B17BC0915BB0D18A0131EE1979EE5C9D1C09FB197597487304F861D3B95374CF9BCCD
CB8CA07E1932963447F0B7C4A5758A8C5971DEBFCDBEA6B3B6A0ABD1BEC8987585976274
C599A75F4451A3939FB7A6B466505ECDBAC67F576665102175030D770106710104670307
58161BC6A4AB6A39485E10228F525CB98B9454162385414A914F57721824850E17940E16
960B1787112E5A275D192362183156327A3800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDB0C632200
5B210976402B6929186C190F75140D781B11813727814E3E76594E746661776E70777177
78717A756C766760676963686861676E666E72697074656F75646E73656F766C74807A84
818291848EA56D7FA4405A911B3E870C368F04319704329F0131A40130A50130A50233A8
0236AA0539AD0334A7012CA00535AC073AB30839B5072DAA0B239E101B8F19137F23157A
342F950A1A85011A8600167E0415761D106764256E782464783073693C84513E8C3D4698
2B50AA1E60BF1D80DC2096ED1A9AEF26B2FB1AB4FC23BDFE30C5FF30C0FE29B7FB24A9F3
2DA6EF2696E32699E6259BED128BEA0982EE047EF10279EE0279F00170EE006AEB0066E9
005FE10267EA005EE40056DD0053DA0157DC0357DB0347C6303EAB84256DBD1437C70F1F
CA101AC60B15C10F19A91D26F0ADB6E1CAD48D6879955469DA91A3D3788D96253CC35066
AF39509F142DA51E34CB5A70A2354F8F203BBB6379D492A7B88096CF95AB964B6283364A
D59FADCCABB6CFAEBC916679855D6ECBB6C0B39AA48B4D5B6F09167A030C7701066B0407
632528C3A9AF6C4D58521C2983545FB58F9B4D1F2CB7919CB398A19C6B776F1F28801922
9317228E142D6326561F256708204D343E3E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00672B02
6B391C76462F6C2A1A6C120A7A150D6D1408925443916D5C755F55665955776E6F726B6F
766F77736B765C555E665F686B616B6B626B71676F70646C776A74756D77787685717892
566A912C4A8310388207348D033194022F9A012C9A012B9C012CA00331A70333A80233A9
0237AE063EB40836AB032696112E9B182E9A2929902D157336095B46084D5F0E496D124B
601B5C1F0D5F041877001B81021D85142B913444A72E44A6224DB21860C81474DB198BED
1995F80D8FF814A3FF13A7FC0D9EFB12A3FE0B9EFB0792F6048BF20182EF027DF0027CF2
0275EF0271EE0273ED0175EE016EED0068EA006AEB006AEB006CEB006BEA006AE7016AEA
0066E70067E9016AEC0267E80162E30162E60160E40558DB2E52C5803685C31E44D41321
D8141CD5131BD2151DC01A26E17787F5C1D0E5C2CFE8BECBFBC1D1CE6D85AC1C34BA1327
BA1123B80C1EB50B1DB40E24B30D26B00E26A61026A61B349F1A35991731961028911024
8C1F32A0455A953B507C1B31964054B87D8CC798A5B06F7F6D09197C010C7C01066F060A
804749C2B2B7C0B1B984646D8B6D75A68691532A37C8ABB8685461997B8BA8828CD19CA6
7C223184193461275920276A051D4F18612800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A3F0A
6C3D1A6E40277439256917087A21117A31209266558E7569817269685F5878706F71686C
756C746F666F4B424B575059675E686E646E726872726C7573727F6870874B5C821E3871
072B76042D86032F91022E94002893002896012A99042E9E012FA00131A30433A60633A7
0934A80F30A11B289121136C3C17644E11586B1A5970134A6E0E3E660D3B5D0C3F54114B
522D75252B870626950129A2022DAB023CBC0B56D60B63E20E71EE0B7CF50C87FC0A89F8
067FF1037AF1067DF2057DF20072ED0070EC0073F00069EA0067E90066EB036EEF0069EA
016CED006CED0172F10174F00376F10277F0037EF40281F20387F40389F40A90F80489F5
0287F5068DFA0084F50180F5017FF6037FF70177F30470EF2267DD7749A3CA2957E61E2E
E91E24E31C20E01B20DB1C28D02A3DD5556DE07A91DB7792C6506DBC2744C6182CCB1421
C70F1AC10B18BF0B17BF0B19BF0C1BBD0D1AB70C19B70D1BB50B1BAF0A19A30412A00613
9D091897091A9407198F03148C081A861024871B30861A2C7F071583010A8102076E080C
AD797DAB929C8D6778764A59AD91979A818A5C3C49CFB9C5B4A5B0766271B09FAAB1929F
A66173811F3B6223542526670820510D921C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00647609
6D350E703D2086503678381F74331B996A55917565826F667B6F6976706B6861616D6568
6F676D71686F5850565A54596D69706E67746E697B666A8343537718306606246B012479
012887042C91002A91012A94012A95012A96012A98022B9A032D9B072D980E2A931E288D
31207D401567571458620D426C103B6B113E5E1448501550380A4E290D5B1A116A141D7F
13349E0C3BB30130B10538BF0942CB0341CB0855E00760E80563E80261E50265E70160E1
0159DA015ADC005ADD005BE0005DE2005FE30265E80169EC0067E9006DEC0073F00175ED
027BEE0484F10687F20A89EE0E8EEE1492EB1B9AEA21A5F020ADF417A8F01DB0F11DB1F8
12ADF90FAEFE09A9FE0BA7FF07A0FF0B9EFF0A94FF0B8AFF1D79F47866CDC83671EC243A
EF232AEA2127E31B24DF1923DA1927D41B32CA1B35C91B38C81633C50F28C50E1FC60F1C
C30C17BC0A15B90812BD0B15B90A12B80C14B30811B80C15B60B15B00A14A3030E9C020C
9B030E97010B98050E92010B90020E8D010F8B030F88020E86010C88030C81040A6E1217
CAA0A38866736121396A243ACFA7B3C4AFBB816D78BEAFBA82767FC4B9C5C5BAC6957784
AA647690243E731F473422590E1C460C8E1700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048A809
6F3004692B0D7F4A2C8051348A634A8C715E8674667C6E646D605A746A67504747665D5F
696366716A706A6469615F66696B7764698248527B192D6305216403217302237E022484
02268A02278E01268F02289302269303279105268F0B238B1621822A1C7444196660195B
73154D7A1142761341691A47542256311A5E212478162B8A081F88051E8E032397032FA6
0B46C00E4ECA0035B70639BE053ABF0136BD0441CA024BD20045C90047CA0149CD004ED0
0152D20056D5005BDC0061E30065E60571F1006FEC017AF20382F5078BF60890F21192EB
25A2EA3DACE858BAF16DC5F383D7F895E5FE9DEFFF8FEDFF77EAFF58DAFF56E2FF3DD0FF
20BCFF11B0FF08A8FE07A1FD0498FF038FFD0280F90278F9096BED4A5ACC9B2D77D21B3B
DE1927DA1422D40E1DD4111ED1121FCC1020C50C1CC70D20C60C20BC0719BE0A1BBE0C1C
BA0916B70814B30812B30914B10811AF0811B00711B10712AF0812AA07129C020C97010B
97020D95040D8B01078900088801088701078602078200068301098201097D050C772227
D2ABB0BBA2AB9E6D7F6F233A954E63C792A6916C7ED2BAC7B0A0ABB8A6B6C4B5C3D0B4C0
AA677897253D841A354E1D40251E3909C70A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052AF0E
7129026D250A874E338E664C8B6F5883715F7B6D618173696E5E5773635F4E3E3E625455
6B61646F666D79758064677A4C58781C2F63081E64031D6E021D7604217F042181021F80
02208302228A03258E04248D051F850E1B7B1E166B37125E5615566F15497B1540791542
6D1A4C591E58402065231F6D122680092D930633A5083AB2032FA8052CA6062EA8032FA8
0437B10944C00032B20029AB0126A60026A50132B30346C80146C70049CA0657D8045EDE
0262E10167E5016EEB0478F4017EF50288F8018EF70699F413A4F233BAF652CDF97AE3FE
9DF5FFB5FEFFC3FFFFC6FEFFBEF9FFABEFFF8BDFFA69CAF648BEF52AAFF216A2F00D9AF4
0390F5028BF90286FA007FF8027DFA0275F8016BF10468F20560E72558D0683B95A92156
C01534C3112BBE0C24BE1126BA1126B60F27B20F25B10D26B00E25AD0E24A90C23A70A22
A60A1EA60A1EA50A1DA3081CA20719A30819A50818A50515A30615A1061696010D95030D
9905108D01098300068101058000067F01077C00047B00067B01067B0107750209711019
98535FB48392C78EA07A2236790A2182162E7F2239C78196D19CB0966C80C5ABBBB597A5
B26F8095223984122757142811C80D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BB613
772B00742A0D763D258C695188705B81705F7F71657C6D6479686177655E685552615151
6F62676B63716465802E3C69081D5A01176300176D021A77011A7A011B7D031A7B001271
021572051D7D081C7D12187122105E4211535C0E426E0D3878133B711A42602355452465
27217114257F09288B0630990536A6053AB0063EB90A43BF0536B000249E011E9A001B96
00219D053CB90237B90026AA0024A60026A80031B5044ACD045ADC0363E4046CEC087BF7
027EF50486F9048FFA0799FB07A1FE0EADFF15B5FF24C5FF3BD4FF51DBFF66E1FF6AD8FA
6FD4F961C4F452B6EE3FA5E4329EE52095E61593EE0B8FF2068EF4078FF90385F7027CF5
0176F30274F3006BEC016BF0026CEF0164E9025DE1035CE10156D90B51D02843AE583083
7824638220597D1F577822587425596E1F576D20586A1C556D20586A1F56641B53641A52
671B5068194C691949701D496F194474184279163D7B11377C0F31811030840E2B870D26
860A1F7B061675031173020D76020D74020A7001066F01056F02066E01056E01066F020B
750819730F2378172A7E0D1D8704129106178F071B8E11288F1E37873147E7B4C5E3B0C1
99405591172F76102729881300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7D36036D2A0884543783664D826B587C695A7A6B5E7D6F657C6C637263596F615A6F6365
6D6674484D6C16245503185C02196803196E021671011774011A78021B79051A76010C63
070B5F151060240B50400B455C0C3B6B0C336C123B601A4A481F592E21681723770A2786
05299206309E0432A20535A60837AB032FA6012CA70233AE0330AA001E99001894011A98
0127A80842C40341C7012FBA012CB6053BC40442CC0452DA076DF10679F90483FA0792FD
099AFE0B9FFF0DA4FF0EA8FF05A2FE09A7FE089FF90BA0F7099BF20C9AF30B98F20B94F1
0D94F40A90F3088BF50585F60480F50581F7027BF60177F50278F50274F30170F00067E9
0063E60161E3015EE2015EE3015EE0025CDD0155D40355D2014FCD0249C9094BC21741AF
2539A02A35982B399B2235962136961F35951A31931B2F931B2E911E30941A2D90192C8F
1C2E8E1B27871C268222298223267B2727782D277430206E3320693A20674423674A2361
54285E522352501D46491033500D2C540A2155061657030F5B030A5C03096002076A0106
77020E78021075010E7D010A8A020A94051094030F9907159908198E0E21AA4157A9455A
9D223793132C6D193A264F2800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C49107A411989644379634878645075635278685A7A695F7A685D6C5A506E625E676470
353C5C08194D01155902196702176B02176D01136A01156D02197104186E0A1364180C53
2D0A464C0E3F5A0930620A2F5F103A4B12463318591D1E6F0E2580082C8F042C96022D9D
032FA20330A4022EA201299C001C8F00188A00198C022DA20331AB0022A0001D9F0329AF
002DB60648D00450DA003FCE013ACA084DDC034CDB0760EB0979FD047FFD0587FF0991FF
068DFC0184F70285F90080F60183F80287FB0184F80283FA017EF6017DF70182FC017EF9
0179F6027BF80178F70277F70072F10371F2016CEC0268EC0267EA0466E90162E5015CE0
015CDC0058D70155D50257D90156D40256D30050CC014CC7024CC80249C70147C20346BF
0645BC053FB8043DB5043DB4023BB0053FB2043DB3043CB30238AF0437AF0333AA0435AA
0435A90231A70431A5042FA2042F9E042F9C06319A062D95062B93072B9109298F0C298B
0D288210287C14257517216E1F2167271F5E2B194C2B0E362E082634061C3F0516550515
6D071973031573010F7B01098D080F93060F91030B96040E9E08129A06129A0A19990D1B
9F14228F19326027521E184311901900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
3D9E02764016866440756042705F4670624C6C5C4B746253705D4F6B5E55605E64252E4C
05164A02175C02176601166902156A03166A011366041466081360120B4F2C09434B0B39
5C0A2F620C2F58113A40124A24115913186B081E7C05278D042E9704339E0331A1022FA3
012EA4002BA200299E01249700168700198A0020920536AD033EBA053ABD002FB70132BE
0136C5054EDA0E6AF3045BE8074FE10448DB044ADC0961EE066FF6006FF40374F90070F4
026FF4006CF2026FF6046FF7016DF20170F4006EF00270F2036CF2016BEF016FF1006AEE
0066EB0067EE046FF1016BEC036AE90264E40160E10262E2015CDB015BDB0159D90255D6
0155D20155CE0152CF0253D10053CC0151CA0151C90350C80350C4014BC20148BE0247BD
0244B70140B4023FB20341B20341B0023FAD0441B10441B10340B0033DAD033CAA043CAA
053CAB0338A70337A60335A30233A102329F02329E01309C012E9A022F9B022E9A012C95
01299201299102289004289003278C06278709227C081B680814550B1048110B3C260F3D
3F123F4F0E355A082471071B8408158B04108D010B980510A70E14A2080EA0070D9F0B12
9209177D1C3E4429620C1A4F155A2600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B00D7B4612805E33735F3D6B5B406A5C43695A426C59446B5B4E5854571B253D041643
01165302175F021463031467011162031261040D57110C4D23063E4108325A0B2D5D0B2F
500E39340D44190E520E186B051C7B03238802278E022A94022A96002A97012B9B002CA0
012CA4022FA70230A8022EA700289D002A9E0134AC0343BF034BCC0850D40342CC043FCC
0542D1034DD80B67EE0C66EF0146D50039CB013BCC0245D4045AE60160E90262EB0263EA
0162EA0160E80162E9005EE60162E80365EA0162E70061E5005FE30160E20160DF015EDF
015CDE0362E20363E40160E0025FDE015CD8015BD7025DD8015DD6035DD6025AD20156CB
0155C70253C50252C50655C60756C50855C10551B90851B6084EAD094FAA0D4FA70B4BA0
0F4DA00D4998104894124A95164D951A4E96164A92164B9216499015468E13468C15498E
14458C13448A1041870F3F880E3E870A3884093885063384043285073689043387043085
042F86032D88022B8B012A8E022C9001298D03268A02238203217B031E73041A6C061969
0F18671A175F2B18514316465C1237710E2B7F071C940A19A50F16A60C109F060A9D0912
8E0C22671E4F2E2C7409215E1D223400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C5510825F2D6E59366D5D4169593F6D5B436E5B4B534B4A13192D03143A02174B
02165502165A000F5802115D040D560907471C043936052C4C0726540B2A490D33310D41
150B500A1666031B7302217F012589052C94032C97012996012696022999012A9B012BA0
002CA40233AD0138B3023CBA0541BC0440BB0649C6034DCD0455D70757DB0347CF033CC7
063CC9003BC60351D70653DB0038C50233C30132C30037C5034ED80258E00057DD015ADE
015BDF0058DC035CE00059DD015BDE015DDE025ADC025DDD015CDD015AD80159D40059D4
0058D30159D2005AD2025AD2045BD1055CCF065CCB075CC60C63C90D5FC10E5AB5125BAF
155BA9195BA51F5CA4225A9F265F9D2B629C30659B37699B3A6A963F709743749541708E
4873924C7491507791567E94597F955B7F96587C93587A905A7B9052738A5074894A6F82
51748C5B7F955A7D935E829A5579915378904A6F8A466A893C608231587A355D8032587F
2E547D274C7A22487C143B750C3675063074022A7302297502277802257A022479012279
021E79041F780821720D1E6A1D1C61321A564F18476F1434870E1F990C16A1090FA20B15
8D102A622B651B297507235F0C922000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00788E13896026745A356B573B6A59406F5E4C5E5350181A2B031234011343031851
031759021457020E52070D4E1509402E07324507254F09224209272C0B38150D4A0A1560
031971011E7D03258503288A03298E01289101289700279900289E022DA2012FA30132A8
0237AF0139B40442BE0245C3054ACA0247C7044BCB024DD00250D4054ED30039BF002DB4
032CB3002DB50544CA094ED40036BD0133BC053EC7003CC3044ED30457DB0257DC0258DA
0257D90155D60156D50155D40155D40258D70257D50157D40357D40358D0045ACD065AC9
085BC30959BA0E5AB8135AB1175DA91E5EA62562A12E68A1366FA24276A54D79A2517C9B
578199597F9565869B6786986885936C8894728E9878949C728F95719192719191789597
7D979C7A9399829C9E89A2A38AA5A590A8AB90A7A990A7AA92ABAD8EA5A893ABAA8EA5A5
94ABAD9EB5B59CB3B595ACAFA0B8B896B1AE92ADAB8DA6A88AA4A7809BA07C989D79939B
658289607E85607F8A5879884B6F823B6279335A76274E6F19406813396A093065022965
02266C0226710225740425770425780925771824712F2161531D4D781535950F21A91724
8D1736522B68142B770420580A8F1B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CDD099566217A582C6C53366C5942655A5121232F04103101113E011449011552
0416590410520C0A451D04333F0A2D500A254607232E082D150A3C070F52031565021A74
03238402258901248901258A01268D002892012A9A022DA10130A70134AB0238AF023BB2
0440BA0341BC0344C10145C5054ACA0445C60342C40146C80248CB0343C80235BA0026AA
0126A90128AC043ABE0A4ED10141C50343C6084FD0024ACB0550D1004ED00251D20051D0
0254D20153CF0254CF0253CD0556CD0456C80758C40855BB0953B0145BAF1C5DA92863A7
3069A03F73A14E7CA25580A06088A06386996586946886906D89916F899271898F738B8D
768C8E799192849A9D83989A869B9D879C9E8BA1A1889FA089A09F8AA29F92AAA694A9A8
97ACAC9AADAF99AFAFA0B7B5A5BAB8AFC2C1AEC1C0AEC0C0AFC4C2B3C8C6BBCCCBB6C6C5
B4C5C5BCCBCBB7C7C8B4C5C5AEC1C0ACBFBEA7BDBD99B1B195ACAE8BA4A77D969B819B9F
738F8F6D8A8A6A85876681855A787C5474774C6D6F45676C3F6067385A66325764284D61
1D445E173C600F335E03285D01276702287304297B092A7F1D2E7D3D296B671E4E8D193C
832049462D6F0E2C790B255A0D8F1A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0028DB0A7F571F6447266D5A4837333506122802123902144401144B00134F
05114E0E093D29082D4408214C08213A08291B06330A0B45021157011868001A75012183
02278B02288E02288E01248D012791022D990130A00233A50437AD053DB4023BB30139B3
023CB6003BB60140BD0140C00341BF023BB90031AE0238B5023AB9023BBB0335B70126A8
0124A70226AB0130B3094BCC0349C9034CCB024EC9014BC6024DC8034FC9024FC60451C3
0650BF0852B80B54B11055AC1A5AAA225EA22E69A03D72A04C799F5E85A562849E6D8A9C
728D98789297708A8C748D90779091748C8C768F8D79939081999879908F839A98899D9B
8FA3A18DA1A092A5A59BABAC96A5A59FAFAFA3B4B4B0BFBFB1C0C0BDCDCCB8C9C7BCCACA
BECECEC1D2D5C2D5D5C7D9DACADBDCCBDADBCADADECCDBE0C8DADDC3D5DAC4D5DAC3D3D9
B8C8CEB8C8CFBAC9D0B3C1C7A8B7BDA2B3B997ACB08DA5A8849DA27E979E7891996E8A90
6B898B658284607C7F5E7980577578516F704E6C6C48676744636142615F3C5C5A3A5C5A
3457563456592F52592A4D5C1C405911355B052D60022A6D052E7F1032882A2E7E502466
5E2D6C302F7B0C2D79122855108F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006A88185A3C13584B3D10151F02132F02153C021544011546071346
150B37330A2844071B430A20270429110A3E040D4F02145E011869011E7502227F012587
02278E01268E012890002891022D9803319F0131A30235A90336AC0135AB0136AC0137AD
0037AE0139B1013AB4013AB6023CB70137B10130A70030A60134AC0138B50436B60027A7
00219F0123A40029AC0440BE034AC5034DC4034DC0044EBA0950B50B4FAB1452A41F559D
2F619F3F6EA04E7AA15A83A261859F6686976B8B92708D92738B8F758A8D728688788C8E
758B8A7B918E8096938398977F949382979591A7A392A9A698ACAA98A9A9A6B6B5B0BABA
B9C4C5BAC7C8BDCCCBD1DCDBD9E0E1DCE3E6DDE5E7DFE5E9DBE2E8D5DFE5D4DEE4CCD4DB
C5CFD5BDC8CFB0BCC4A9B3BBA2ACB5A0A7B097A0A99399A48D929B868B937B808781878D
767E85767E86757A83757A826E747A6E767B6874766674756372766170755F6F735E7276
587172556D6C536A6C51676C51686C4C666848656549676542615D3D5E5A3C5D593B5B56
3958533656503856523755523353512D4F53264A551C405909305D0530720C35831C3789
2033861232850C307319244200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB4116C4D20352D2308132102153402153C02144006123C170C30
390B2549091A3403161A05270B0C4203105501146301196C02207502237C012482012688
02288C02278F022993012994022C98022F9D012FA2012EA40130A6012FA40031A50134A7
0439AD0338AE0135AB0136AD0137AF0239AE0238AD0338AB033BAF033BB50337B4022CA6
01249D02249D0028A0083FB00A49B00C4BA518539E2359973768994D799E5E819E69849A
79909F72899370888D6E84877186887086847089847288867C93908498978194938B9F9D
8A9E9C91A4A29DAFADA1B1B1B4C2C0BCC9C8CBD8D6D4DFE0DAE6E8E1EBEFE4EEF2E5EAF0
DFE4ECD4DBE5C6CED7BCBEC7B9B8BFA09BA296909691888F8780877D777D787276776F71
796F6F786E6B776E6A756C66776E68786E69796E6A7A706A7E71697E6F687E6F667F7168
7B6F65786D637A6D64786B60786B5E786A5D7268596F65556D65546D6558696156656355
5E6153595C4E5B5D53575B54555C56505C554B5C534C6057475D56435D573E5B543A5850
3D59513C59513B565038545039574F39585233544F3352502C4C54183B530A325D063475
0A3D8E0738871130650F911D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADD0B765526221D17061529011534021437030F33130727350A20
4509192F0315120321050B3E031358021767011A6F01207901237C02248003278703288A
002388062B93022894012691012892012996012A9A02299D01289A022C9D012FA00134A3
0135A60034A80135A90237AA0238AD033AAE023AAF0036AA0139AE023AB1043AAF0432A0
03298B0629811438842751913965984F779B61839B6A87956A858C778F93708688708487
74888B6F8687718786768B897A8F8D839894879D97889C969BAFA99FB0AEAAB9B8BDC9C9
CBD7D7D9E4E6DFEAEDE3EDF2DFE6ECDADDE4CCCDD6B9B8C3A7A7B295939F87858C837E82
7D777B7A74787972757A71717C716D7F6F6C806F6786736985736781706283715F836F5D
836C5A806B537B6A4F7D6C507D6D527D6D557668507B6D547D6D55806E577D6D557B6B54
7C6D567C6F57796A527B6C5376684C76654A76654A74634878674B7B694F7C6B52796C51
776B4F75684E7467507066506F67506D664F6B664D64644D5E634E565E4C505D4B485949
445847465A4D41574C3D544C39534B36534A3958503B5A5137554D2C4B47214249113852
0733610A3366172B490AC80B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007B55241F1A1307192C0116320411300E06212E07193F0917
2A04150F041F040B37031453041B68021E7402217C032582032583012383042687012284
03268B03279001269101258E01258E012691012693022695012697012898022C9B0333A1
0233A10132A20134A30135A60338AB023AAC023BAC033BA8053CA3063B98124291244C8B
3E5F8E547092607A91667E8B6981876E8588708688768A8A718684768B8A768C8B778E8C
7F9695809797899E9C98ACA99EAFACB4C4C1C9D8D4D7E2E0DCE6E7DBE6E9D4DEE2C4C8D0
B3B5BCA3A1AA8F8C94837F867D777B7A72757B70747C6F747E72737D716F7E7169817367
7D71627D74647E7462756C57796E5676695472654C73674B73674D72684C72684B74694E
6A5D42695D416960436A62446B6546676144635D406B654B6D674D6A634A6D68506F6B56
6A67536A675269655066624D6A674F6B674E66624966624A6761496C664D6A664C69654A
6762476A62486C644A666146696547686040665C39675D3B6860406661426160415F6145
5D61475A5D49535B484B59484557484153493B53493855483B5A4C314F4327483D214441
1E4248102F3B115B2000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF005F811A21180A0918230415290C0B222504163C0815260412
0D051E030B3100104602195E021E6E001F78012282012385012083022182011F7F022284
03268C03279100228B01238A01238901248A01248C01238E022491012793012B98022E9E
00309F0132A001349F0237A10339A0053B9A073B9017478E2C568D466B925C7C966E8796
748A916D81836D80816B7D7D748786758A88819696809595839594899B998E9FA097AAA9
ADC1C1C0D3D7D0E1E5D4E2E4D5DEE2C5CCD2ADB0B69A9BA087848A77757A737071726C6B
746B68786B67786A647D6F668073667B70607B705F7F71627E7261756C58706851746D57
6D6A526B6A536A684F6E6A506C694E68644C6A654A6A65496C684C6C674B6A6749686447
615D3E656043686445605D3E62604165614465624563614665624864604669674F666550
646651696A5565675267675665665466675266675163624E61634B5E604863664E61644E
62654F62634E5F604A5E61495F62475B593C5753325955315753305752315653305C5836
5D58375D583A5A583D575B43545C455057464C5A493F54433A5343344E402B493A27483B
244639254336139C1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047B21436230811191B070F1B1C0915380A152904110F061D
030C2D01113F011653031D69021F7501207D002183012285012083011F80011D7D021F81
01208602208B011E8A01208B01218900208701238802248B00238C022691012A96022D99
013299023596053A900C3F891B4886355E8D50739664829A6C869272878E75888B7B8D8E
7A8E8C758987758A8A7A8F8F7F9393879A9990A2A1A5B6B5B5C3C4C8D4D8C7D3D9BFCAD1
ADB8BE919BA17E848A74757B7471756E6969736C68716960766B5F766A5C776A57766952
7A6D5573674F6F654C70684D716C507570557A755B77705A746D576A664D67644A727056
6E6D546A6A4E69674B68644868654966654865644869654A6361446A65496B6649696547
646142666344666445646243626243605E41606042605F425E5D40615D43615F465F5E48
62614C6768536767556967576465526A6B5567674F63644E65685070745E696E59616552
6366525D604C5C5F4A5A5F485D6249605F485A5A3E59583B59583A595837575433575231
5753315651325250345153394D513852543F51563F4D58434555433E5241354E3D2D4A3A
26483525473430462F0CCD0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005A390D1F1A10130D12280810310914130516060E29
01113700154B051D64021D70011E7701217E01218101218402238503208200197B01187A
011A7F001A82001984011F8A03238D01218901228701238801268B022C8F032D8E043189
0B38821A467F305984537693678395708992788D92798C917D8F937B8D8E7E8F8F839694
8195928398948CA19F9BAFAFB4C6C8C4D3D6C7D2D5B5BEC29AA0A581858D6E70756A6769
6966626969606F6B60726A5E706456695C47665B3F675D3D6860406D64466B6044695E42
6B614471684D6F694E6B684C6868497171517976587670566A664C6F6E516E6E4F6E6D51
6E6A4F6863466763436661426966466867496766496561456764446B66496B6649696548
6965476663446665456463445F5F40646345646245615E415C593C645F465E5C435D5C41
5B5B4062604864624D69685461634D63664E62654C686B5361654D6265515E614F606453
696C5A5E62525D614E5A5F4B595E4A5B5F495D60495A5C445A5E425A5D3E575839565739
595A3D57593F5559414C543E464D374B513B494F37494F3848523D4554403D533D354E3A
2D4A382646322B46311DA31700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005F80153A250923100B2C0E121D0913090D1E031431
011540021D5B03206E011E74001E7702217C012180022284022183011C7F00197B00177A
031A7E021B80011D83012188002088012388012385032684042A80062E78123B75315682
56779363808F708A92788D90768A8A7A8F8F80939482939587999A8396948DA09C9CAEA9
B1C2BFBECECDBCCBCDAFBCC08F979E777C816A6D6D6666626A675F6B655A6E66576A604B
666046625F426663456A6447675F44685F41665E3D6A63406E69486C67496A6347655C41
665F436C664C6B694D6E6B506C6C4D6C6C4C6F70506C6A4E6C6C506B6D4E6A6C4C6D6C51
6C664D6B644768624167613E64603F666345605F40656143656343676244696447656145
666245676244656342626143656445656346666248615C42635F43615C445C5C405D5D3F
5C5C3D605F4163624665654B63654B61644960634A61644B62674E686A566B6D5B656756
646755636755646856676D5A5A614D5B604A5B5F48595D44555C41575D4153593C555B3F
565B40575C42535B434D59444451404A5645404D3B323C2938432D424F3641523840523B
3A513B324B362E483335422B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DC0B5C360935160526100F110F19051428001636
021B4E02216701217302227A03247E02227E032381011F81011D80021F84011C7F011B7C
001C7E021F82011F820020840021840226830226760A2D6E244675496987648290708890
7387898196937E93907C908F809591899D998FA09F95A4A4A6B6B6BCCBCAC0CDCDAEB8BA
909799787E80696B6B6867656A65616D685E6F6959706A53736A4F70664B6E664A696246
6C674B6F6D506F6D516D6A4F716C51746D526F6A4E6D684B6F6C516F6C536D6A516D6750
6A654D6E6A51706D536E6A506E6D4F6C6D4E6B6E516A6B526C6E526A6B4F636546666347
69634868614468614067603C65603D615D3D5E5B3C605C3F615F3F615C3C635E40645D40
656043656142666344636242626241615D40605F43605F436160445F5E425E5E3F5F5E40
60604160604063634461604563644961604962624C5F614A60624A656550656753636451
61655060654F5E634C5D644C596149586048585E465B5F495A5F49565D46565D44555B42
545A3F565A42535B42505E494856474353472C40322639292C3C2838462F425038434F37
4350383C4E38344B363447311B9D1100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0045AB0E4B220223110B0E162101152D001840
03205C02226C01207301227B022580022381011E7E011C7D021E82021E84021E82031D80
011D8000208101227F03257B0428721539733A5A815E7A90748B977F95977E93927D9190
8899968A9E998A9F9B8B9E9C98A9A8ADBCBBBBC8C9AEB9BF98A0A7787D82696A6C646362
67656174716A7772687972657A73647B75657A75647874617B7662797460797662777560
76756072735D75755F74725E73715C76715B75715B72705A74755E70705C747160757462
7475617576626F6F5B6E6F587071576E70556C6F566F705B6C6C5567674D636446656346
666144666143666140655F3C655E3A63603D605C3E625D405F5C3E605C3D605A3B615A3D
645E41635F42615F405E5E3C5B5D3860603C5F603E5D60415C5F406060445F5E40605F40
5E5D3F5F5F416060435F5F465E5F485F604B65675164675060634D62614C5D5F465C6046
6368505C634C5D654C5C644B59624959624A5A614A595E485B5F4B5A5C4A555844555944
54574251563F4E573F55655047584933453923392C273E2D32473340503D45533F4D5843
49533B454F373D4E3734452F1EA21500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074451429170B0D1824011837001B4C
03216201226D022273012279032580012482022180001E7E032184032186011C80011C7E
001E7C03247904286E183C6E456683708B997E93978293948B9C9C8CA19E8BA09D90A4A1
91A3A19DADABA6B7B8A9B8B9A3AFB1899192717276605F6262605F66635C6A675B716D5D
726F607C7B7081817794938AABA8A0A5A19C9E9C999C9B9693918B93928A8B8D83818479
8084778185767E80717D7D6E7B7B697A786478776273755F70745D6C6D5B6F6D606D6D60
6C715F6E73646C72616C72606E74607476627175626F73617075626B705C686B5465664F
63644C626349636448615F425F5E3D5D5B3E615F42605D405E5C3E5E5C3E5F5D3F605D40
625F415F5F415C5F405D6041585C3C5A5D395D603D585B3C585B3F5C5C415E5E415E5C3F
5E5B3F5D5C415D5D435D5E485B5E485A5E4A5C604C6165516165505D60485B5F44585D3F
595F445961495B644B626752646A555D624D5B604A585E475A5D48575945585B47545845
4E523D4D533E4D59455061503E50412C40322A3F313349373E533E4959474E5E4D4D5D4C
505D474D563E464F373C49303C442400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003BA40B321D0B111C2A031B41021E56
022165022471012375012379032681042887032887022586012486032586012081032178
06276C1F3D6F4D6988718B98819697869592909D9996A2A19AA8A791A1A19CAEACA1B3B0
AFBEBE99A4A87F878A696F6D5E605A5F5D53665E51675D4E746E5D868674999A8BAEAFA3
BEBEB8CFD0D0D0D1D6E1E1E8F4F0F9EBE4EFD6D0DCCDC9D7BEBCC6B8B6BEACACB09EA09F
989C9693958C9091879494889294858F8E808E8E7E8C8F7C8B8E7A898B7B868578828375
7F81727A7D6E7178676C75646A74636C71616971606A72626A75646671636A74656A7465
697363657160606B5A5B64506067515B624D5E654F60654E5F654B5D624A5B614A596049
586047576149556148545D47515B4350593D565C41585B43585C46575C46565C455B5F48
595C46575A46575C495A604E585F4D57604F5761515760515B63515C644F60664F60654E
5B624A5E66505D654F5B64505B634E5C624D5E624C5A60495D634D585E49535C454F5642
4B523C5058465B685946564B2D42352C4335344A3A3E5241495C494E5F4E5163544D6254
5668565E68544E533B434B3140462200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA1B3C2407131B26041B43031E59
012168052A7C01247A00237A002581032C8D022A8E00258601248401237E01216E15336B
4560806D82908090948D9C9C93A19F9BA6A49AA5A497A2A3A5B1B3A3ADB0A1ACAD798586
676F6D5F605C615E5469635168624B6E644D786D537F765D85816A7777647374657D7C73
86848189898A949298B2B0B9C5BECCC8C0CFB3ADBBA29EAA9A97A296949B908D90888784
88898187887F87887D8384778083717E8172797B6C777A6A7579687375677175676F7365
7377697175676D7465737C6C7782727782736C78696974666A796B6C7C71697B7066776C
64756A6172695B6E66566A5E55685955665957665855655659685957665852625456675A
5264575263565467595463574F5F505261515362515260515260524F5E514C5C4E4E5E50
4C5D4E4A574D4E5A5157645D57665C5B6A615A6B625B6A605F6D5F5D6858626959686C5D
6C71616F7665687461636E5D636D5B646A596369575D64505B634E565F4B4F59444E5642
4D55415B665748594E33463D2F473A3049393D5643465D4B4F625053645554655950645A
5C7064606F5E535B44474D3134761D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005D3E121E1E1E051B3B031F56
00226909368B002A86012682022A8A043195022C900126830325770D2D6B3450765D7485
74858B818F90919E9D96A3A28E9D9D91A0A199A8AA8F9D9E7F8A8A646B69595D57585B50
6463526C67516E664D6E64496F664A6B61456960426961436E684B706B4E736D54726A55
6A64526B66566B6557706A61726C6877716E746D68736D68716D646F6C616E6B5E6C6A5C
6B6B5B6C6C5B6A6A586E705B6A6E556B6E586B6D59696C596B6F5D6D72626A72646B7669
6D7A6C6F7C6E727E7274817473827673857B75877D6F81795F776E59726B577269566F69
536B664C646147625E45615B3F5C54415C55415A53405751445B54425951405752435A57
4058553E55523E57523E58533A554E3B554D3C554C3D544C3E544E3F544D44575042574D
40564A3F534C3E52503B515038514F405854425A53455A504A5B4D4F5C4E565F52595F52
5D62525D63545C65545E69596671616A74646870605A645358625055604C4D57444C5644
5661514E5D52364A40374C413E56463F5742405743506555596B5D5A695D56675957695F
5D70665F6E6158614C4A4F3424A41300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7F182C22110A1B32021E51
002168093B9403389901309103349602349605328A04297021406E4C637B6B7E847A8988
84918D828E8C8F9B98909C9A909D9D8390916E797959625C585B4E62604C6A664E726F55
6F6E526E6B4F6F6A50706A5170674D6D65496E65467268486B63406B633F685F3F6C6245
6D63456D634572674B766951716550796D597C6F5C7A6E5B79705A776F59757058716E58
726E58746F586E6A516C6B506A6B506C6E566B6E586A6E5B656D5C656E6166736864736A
5F736A61766D5D726D59716C56706D4E696549636043605D32544F2546421E423C1C3B37
1C3A3717363316373413322F11312E11312E14322D14302C13302C12302B142F2D15312F
132E2E102D2C0F2D2B10302F1033301D3E3B213E3B28423D31453E3A48413E4D433A493C
3A4D3E35493E28413B1D3A381C3A3925443F334F473F574A485B4A4F5C4D55605361695B
606958616959616B5A667160636F5E687262656F5F5B645456615054614E4B5A47576658
4A5A4F384C42394F4341574A485F4E5166544F62515B6B605E6C625B685E5B6B5F58695D
5C6C625E6A5E5B624C53533313D10900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0027DB0D5237121C222B031D48
01266B053A94033EA4023CA2063C9F03358C0B32722D4B6C5568756E797D778180808C87
838E8A808B8A828E8C76827E626B645B60555D5D4E68634E73694E796E51746C506D684D
69684C6D6C4F6D6A4F6C674E70694F716A4D736B4E746C4E716A4A6F68456F66436F6241
7365417769447B6C497E6C4C7E6F4F80715184735685745985775C86785E83795D80785C
837B61847B627F785F79775F7B7C6471745F6F735F7179686C786B6470685869624D605F
3C53522E4948213E3E1938380F302E102F2C17373124443E2F504A3D5B564D6B65607B75
5C7572506B67486460405C564560583B554E3C554D3A514C394F4A344C44334B42324942
2F483F2C453E2C463F27423C24413C223E391F3A35253E38293E35314137364539374738
3243332B3F3020392E17322C0C28241230292D493F3E54464B5D4C566354677265636E60
5965565A65565D6556595F4D5D644F5D63525C62515B6151545F4D4E5F4F4C615344574E
3C524841594C4860524E645753675A5B6D606170655F6C635C6A60606F655E6F6459695D
5D6C5F616C5B5E6348417F2300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0068891F3D31220D1E3D
052D6E09449E0343AC023EA40637910F34723148654F5D62646A697377747A808077807E
757E7C6E76745E675F565C4F5B5C486B664C71684A6D64436D634373684C70674F67634B
6E6B526C694D6865496E6A4F6F6B4E716B4C6D6748716A4C72674A7569497C6F4E7B6C4A
7A6B4677694278694578684775664472644073654377674A75664A83755A7A6E54796F55
7269517169546A6753686A56696C5A6A6E616972646875676979705264612A413F122D2C
0725230A2A251A3A33314F49536E6672897F8FA49CA5B8B2BBCBC7CDDBD8C3D2CEB5C2BE
A3AEAC8A95947A89836A796E6E7A6C646D5F646E615D655960665B62665A5D6457586050
5965525864555B675A5762585160554F5E524F5E534D5E504D5D4F515C4F4D584C505B4E
535D4E4B5948425443415243364A3C2B4337253E2F2D41324C5D4D6673645D695C5C685C
5965575A65565D63515D604B60634D5C604D5C614F595E4F5560544E5F56445852455A54
4A605750675C586E625F726764756A67756B66736A62716861726760716660726759695D
606E605E66525F603F2DA91400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0E6A4C2226272F
0625590B459A0546AA053D94103670364962545D5F575A53696A6472736D737572676B67
5D61595758495C5A43676346726A4A776B4B7265476B62426E67496F684B6A6348706A51
6E69506762496B66496F6B4D6C684A6D6949706946716543716442786B4B77694B756646
74654273653F72654073654271634070633F6F603D6D5E3D7061416D5F4174664C756A50
7269526D68556265535E655561675A626B625B6B64475A562C4441112A290C2A2524433D
4261596C897F99B3A6BACEC6D2E1DDECF4F2F6F9FDEBECF3DADAE3CBC7CDB0AAA99F968F
8F8378857769796E5C736A53766C51776B507A6C51796B4F77684D806B537C6A4F79694C
7C6F508072597D705B796E5C776D5B746B59726A55706951776E547D7055786C52796D54
73684F71694F6562485C5C43595F48535E4B485746394838384938536050606B5C5F685A
5C65535D655061654F61634E6164505D6152576052545F554D5D544A5D574E625C536662
5C6E6761736B6779716A7A7061716768766E66756D67777164756E63746C637369616F63
636E5E65664E655C3430A70C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B318503C28
17284615468C094091133A7332445B4E54545B5E5461635667695E686A605D5F545B5B4B
5D5A426862426C653F7066426F654375694B7267496961436A65486D694B686346726C4F
6F684C6661446E6A4C706C4D6D694A6D67467065416E613B6D613B6A63406761426F6546
7064416E623D6E613C74664271623E70623B71643D72653F7265406C5F3D7265476F6449
6B644B66644E666857646A5B626A5F4D5D582239360A26220A292522403B58756B86A099
9EB5B1ACBFBCB0BFBEA6B1B2A4A8AC9F9BA09A919691868A8F82828D7B778D7B6F8D7A66
8D785E887255816B4A7C68457C68427E6842806B437F6A41826C42876B448568408E7145
91764A90744D89724F897254856E52866F538672538B7452957E59937B58927D5E917D60
8875598272537E6F51756A4D6D674A67634A63654E5B63504E5B4A4954455E6455636656
61644F61654E6367516266545B62565C675E56655E526460536863586F685A6F6862746F
6C7B77707E7C70817B6F807764756D6C7C766D7C766B7B7668777168756F65736B636D63
6669586B63446D582546B71500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00855E2D
342F3226426F183968314256494D4A535449585C4C6063515E604F595B49595943625E42
6D64436C5F3A6B5E376E66416A62426C634473694A6D674966624469684A6E6C4F6B674B
6F6A4D6A6547676243746F4F6E694A6F67476E633F6E613A6C623B6A65406A65456D674A
6C66486E674971694A7065446D623E6D643E6A60387168407269437169486E6949696446
6A654A686750626554535B4F36443C0B221E0C2B242B4B424E6C647B948E8EA19D919E99
89908E7B7E7C70716C716E67716C6579736B837F748D897B9D96849C93818A82706D6450
6A644A7A745A7C765D736F55635E435E593E5B573A5E5A3867603976663F79653C7A6439
76613578643B7868437B6A4A7866477666476E63446C61436A6145665D4765604D656351
60604D5E5D4966634D6C69507570536A6346686449666852696F5E5A6051626556626350
6568526067525C66545F6B615C6C665E726F5D73716A7D7C697D7B6E847E687B7571817E
78878575848471827F70837C71857D71838072837F6E7D786E7B766A756F67706864685A
686148705B2D68902000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE10
583D1F404147323A3F46463D5251405959465D5E495B5F455A5D415C5C3E5C5A3A615C39
63593267592F675B3069613A68623D6C634074684872694B6C67486763476A674E706D54
6D684C6C66476E68466D68466F694A6E65457367447266417367416E6440736A47726949
73694B736A4C72694C6C64466862446A66456A643F6B623B7069446D6846686442666141
6D684B65654E444C3B2C392E50615A4159533452484F6B5F697C73757E78747871737368
7571647C75677F77657D746065634E797D6A989E8FB1B7ABB8BCAE9D9D8F8A8879777767
7174657A8075687068505D5545554A3B4E413548373B4B35434B2F615F40756C4A776946
73633E726441736849736C516C6A516567505C624E555D4B545F4F525C4F535E51556256
5663555C685A555C4C5A5D477B7961726D54706C536D6A5671715F686C5B656956626856
5F69575E6C5E68786D6B7D787185827389877087847D908E7F93917D928E778C877D8F8D
7C8C8A7B8B89768A85768C86758B857487867182816E7E7B6C7A74656E6764695C67644A
6F5C30678F2000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
5C7F1A473419473E2750492F5A553B5F5C445E5B415C5C3D5E603D5D5D3A4D4E2B534F2A
615529635424635627645A2C635A2D645A2E6B5D356E603A706440736A4A6F6A4F6B674E
676449635D3D665E3C6A63406C65426E65436F6543716745756946726643746844776944
7568437668457567477264456D62436B60416F63416D613C6C613C615833655C37766D4A
70694B6060473D473668746ABBC8C3606E6C57685F5362565F685B6C6B5B74705C74715C
73725D77756073725D71705C6D715B7077637D81728183768385788687798182746D7265
5B675E4758553C4F4F2C44441C39351938311A3A2C2F483648563F67684C766E507D6F4F
746948736C4F7C7A636F7462636D5F5A6A5D55675A56675C57675C5D6B615F6E615F6F62
59695B505C4B5A604B706D5775705A75705C74715E7471606F7061656A5B656F5D667366
72847A7A8E897D908D8092918092927F90917C8F8F869897869998859A98819794859796
8192918496938195927D9390778D87748785768585707C7B68736E60665A6360456C5D2F
66912200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59780D5337115544255A4F3062593C635C3E635D3F5A57395455385257384A4F2F504F29
6158296657256959276859286759286357246B5B2B6D5C2F6F5F3572643D716844706A4A
6F6A4C6965456965426C67436D67466F68476C67466A65436B62416F63406D603C6D5F36
6E5F3471623874643C7968427D6C467B694276633B76653B73663973663878693F7D6E4A
746A49636144444834898F82979C9660625C65685A6066567177667573607A7661767561
707361727968656E606672666B78696570626C7467687064646F6558655E43524D334641
1F3633142D2C08252402201E0929231C3B32415C51596B5D646C5776715672664973684B
6F6C527A7E6C7982756C7B7063776E647970657B70697A7069786E68756B627064506053
4A5A4B5F68546D705974725C75735E7776647475666F74676D766B79857B8B988E859591
8C9F9D99ABAB9AAAAA95A4A492A1A38897998696968B9A9A8494938093928B9F9D90A0A1
8A9B9B8999988294947E9290788985788984717F7B6E77736B6D63686247756132997734
29DE0C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6A40045A40155D4C2A6657376A5C3D6B5F41565436333A1F303E26414F374D563C515536
57542C5D54246456266B5B2C66572766572565552669592C6B5A2F6D5D326D603670663E
746B457069466E6A466E69486E694B706A4E746E53777154716B4C6A62416A5F3B6D5E38
69593167592E6C5E326E60346C5D336F5E346E5C306E5E2E6B5E2D6A5F2E6F623572633D
72664365603E5B573B6F69527C766167604B6C69517479656C7262777663797462787563
6E736541504828403C1E3C371C3A341B353018302A162F28112C270E2825223938384C4A
3D514F3E5353425B595169635D7368576A5D5D6B5D676F5F71725F746F557771567B7A63
7A816F7B877B7C8A8272857C687E755F776E50685F4D6258526158536159536056556253
5F6858747765787A65797C697A7F6E8085778A93879CA79E9FADA5A6B3AFABB7B5A5B1B3
A3AFB1ACB8B9ABB6B8A2AEB0A2B0B19BA9A99AAAAA9AA8A99EABAB99A7A795A4A494A3A6
909F9F8A9A9A8798988291917E8C8877847E6C756C6F70616B5F427F643077992600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB40F
613D04604B1C6758306B5B396D5E3F564F33343A22223420203724293F2D455543515B47
595D415654305D552C5F552961562A5F562863592E675B326A5C346C5E37695D35695F36
6E633C7067416D6641706B49736D4F726C51746E55706B517670567973567B75577C7357
786D4F7167466A623D6C653F6E633D70633E6E61396E61376C61356C65396D663F6C6441
726A4A6F69476F65416F5F3B71603A6C613C726F516E725C767A67807E6B7E7A657E7D6A
4C5548283E38203D3A1738341638331B3B3723423D36554C506D6592ABA8DAEBEBF1FAFB
F0F6FBC8D0D798A1A4848D84767C6E6C715E74766171715D6767556D715E7077656B7869
697A6C6D7D7473807A707F796F817B6E847D667D7760746D627069646F676A7466757C69
787E697A7F6D898F7E9EA699AEB7ACBFC8C2BFC9C4BFC9C4BEC8C5BBC5C5C2CDD0BAC4C7
B6BFC2B4BDC1B0BABCADB7BAADB8BAA7B4B5ACB9BBA9B5B7ABB6B7A6B4B49CAAAA97A5A6
8F9C9D8B9A9C8B999A818C8D7B838073786E6C6955766440916F362ADF0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0044AD07
6443096955246C5C316D5D395E563740432B2F3D2A273E2B223B2A233B2C2D4334415244
535F4D555D45595B3B5E5C3965633F6865426561406862436A644469624168613F67603D
6C63406B63416C66456E6A49706A4D746D53756E54746E53746E516F6A4C746D50736D51
746D52736B50736A4F787154777254777052726B4A726C48726C48746F4D747151757156
7B765C797357776A4971603B7460356E5F326F6946706E557B7A64807C667F7A647E7D69
636A585A68595564565A695C5767595A685C5F6B5E6B76687D877A929992A4A3A4B0A9AF
A59EA4948E92827E797E7968817C617972557B785B62644E4B55444B5848505F52607066
819288C7D2CFE3E9EBDEE5E7BCC4C899A4A67E8985777F767C827680867A888E7E999F8C
B6BCA9CBD2C4D7DFD7D6DDDAD6DDDCD4DBDCD0D7D9C8CFD0C4CDCCC4CBCEC1C8CBC2C9CD
BEC6C8C3CBCDC5CED0C0C9CBBBC5C7B0BABDB0B9BEACB5BBAEBABBA5B2B39CACAB95A3A5
909D9E899799869293787D78716F60726448856B3C779A2D2BDF0E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042AA04
705011705B29705F31675C374A4B313947343247352F46342B43312A42312B42342F4437
3A4D3E4D5C4957624B5B60485D614761644964654B64644B65654B67674B6A684C6A684B
6C684B6D684C6F6A4E716C50736D53746D55716B52726C51736D4F726B4A6D6544716647
74674A746749726649746C4F726C4F726D50716E4F737250757252737050757154726E54
756E57756C547A6D507A6B4979683E7261356D6037706645756C507A72587F765F807962
7F7A608A8468948B6C988A6B94866798896C9C8C70A291749B896C99846C967F6C917B6D
8E7D6E8A7D6C8B806B83765A7F704E7C6D4A8880636B6D5757614E5B67555F68556E705F
807F709E9890ADA5A39D98998D8A8B898784908E87A7A49AC4C5BBD5D8CFEAEFE4F5FAF0
F4F8F1EDF2EEE7EBECE3E7E9DDE1E4D6DBDFD1D6DACCD1D4CFD5D5CED2D4D7DADCDEE3E4
D8DFE0D8E0E2D5DEE0C7D1D4BFC9CCB7C0C5AEB8BCA9B3B7A9B4B6A3B0B29AA9A995A2A6
8A9798818B89787B717067507E683E9D793E2BE01000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0045AD06
775614755F2B6E6032565331444E383E52413B5341354C3B344B3A364D3C324839324738
3246343A4B384754425862505C6551606651616550626551626551666A5466674F6A6950
6D6A506D68506D68516D68516E695275715C736F5A74715A736F54736E506D6849726B4D
756C50786E51766E50746F50716D4F7975587775587A795C79785B7E7C607B785E7A7860
7C79617B735C7E745B82755A8679598074517F724F7C714F78704D766F5079715581765A
7C72518174508978508A754C87734987714A85704A826C44826C448269427D66417C6847
7D7152827A5E7D785B7D7354776A45766842756B496E694D6B6D5374775D8280639A8F72
A6987CA59782AFA496BFB8AED4CFC7ECEAE3F8F6F0FFFEFAFFFFFCFFFFFCFBFDF8F7F8F6
F7F9F8EFF0F2EDEFF1E6E8EBE5E9EDE6EBEFE1E7EAE0E6E9E1E7EBE6EBEFDFE4E8E4E9EC
D8E0E2D5DCDFCED5DBC0C9D0BEC8CDB5C0C3ACB8B9A9B4B6A3B0B1A1ADAF9AA3A5899190
7E827A756F5B7C694494743D54C01F00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CB40B
7D5B17725F2962593053573D4654433C53423C56443D554642574A4055473D52453A503F
384D3940523D41513D43503E4E5847575D4C5B5F4F5C61515D6353616555656855666852
6F70596C6B556B6C556E6F586C6E5771715B71705B74735E75745D75725A78755D73725B
78755D79745D74735971715675745C79766078765E78785F76765F7878637C7D687E7F6A
7E7F6B7979647B78627D78617D7961827E6588846A89856B88876B8A896F89876B898569
8C88698C8968908C6B938F6D9793719994749992739990719C94749E95769C96779A967A
9F9E849FA088A3A58DA1A2879F9E81A19F829F9E839B9B819C9D85A4A48DB5B39CCFCAB4
EAE3D0F8F3E5FEFBF3FFFFF8FFFEFAFEFDFBFEFEFDFEFFFFFEFEFEFEFEFCFEFEFCFCFCFC
FCFDFDFBFCFEF5F6F9F2F2F8E9ECF3E2E8F0D9E0E5D2DCE1D0DBE2D1DBE3D3DBE4D1D9E0
CCD4DACAD3D7C5CED3B8C2C8B7C2C6B2BDBFA8B6B6A4AFB0A1ADAD9AA09E898880796E5B
7E6A4498773E52BE1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA11
845F1B725E295D58324F57404A5A4B4056483C5647415B4D475F52465D50455C4F445D4B
4059434458444657444856444F5947525845565947545A47525C48535C4A58604E5B6352
696F5E7278647178646D77636B746070736071716073736071735F70725E6D715D6C705C
7374617878667E806C7F826D797C677777637475607778627374607274647B7F6F7E8270
7D826E7478637679647B7E687F816C8689758D917C8F927F8D907D868A78868A738C8F78
8F957D949B82939A83979D8897A18B9BA18DA0A391A3A593A4A793A8AB98ABAF9CB5BAA9
B9BEAFB9BEB2BAC0B3BCC2B4C2C7BAD1D4C9D9DED1E4E9DDF1F5EBF9FBF3FEFFF8FEFEFA
FEFEFAFEFEFDFEFEFCFDFDFCFEFEFDFDFDFDFEFEFEFDFEFDFDFEFEFEFEFFFDFEFEFCFDFE
F6F7FAEEEFF5E2E5EBDDE0E7D1D7DFD0D7E0D1DAE1CCD6DFCCD9E1C8D4DDCDD6E0C7D0D8
C6CFD3BFCACEBBC7CAB7C3C6B4BFC3ACB7B9A4B0B09EA7A38C8C817F735C856C45729831
2ADF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C621B775F2A5A542F49523B4D5F4F495E52425B4E3F594D465F534C65594E655A506858
516955526654516051546051555F4D59604B595F48565E47525C464F5947505B4B535F51
596557606C5D636E61697569707D706E786B6D73656D71646F75656E7767717B6A737D6B
71796872796A747B6C757B6B747867757866787C687B806D8388787E83767D84767C8472
7E87747D87737E86737F8775868E7C89907F8A92819196889196898F95878D9482939C89
97A39097A49195A38F9DA9989CA998A4AC9EA9AFA4B2B5ABC3C7BDD4D7CFDEE1D8E5E7E0
EAEDE6ECEFECF2F5F2F8FBF6FCFDFAFEFFFBFDFEFCFDFEFDFEFFFDFEFEFDFDFEFDFEFEFE
FDFDFCFDFDFEFEFEFDFEFEFEFEFEFFFEFEFEFCFDFFFBFDFEF5F8FAECF1F5E4EAEDE2E7EA
DBE0E6D6DBE2D1D7DED4D9E1D3DAE1D2DBE2D2DCE2CCD6DDC7D3DAC5D0D8C9D3DAC4CDD2
C0CCCEBAC5C8B7C5C6B4C0C2B2BCBDA1A3A188867A7B6F578A7146789D342BE01000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6E8D147A5E235F552D454C33495A484961514B6658466053475F544C625951675D586F63
5D73666275685F6E63616E63636F6165705E626B57606A555D6753576150556250546252
536052525F5354605755625956675C5B6B61606D6265706768756A6473676A786C6D7A6D
6F7C707581767582777886787784747C88787E8A7A7C887A7A867B839086849186889488
8392848493848998898B9A8A8C9B8A899786909C8C959E91939C8F99A2949EA798A4AD9F
A7B2A3B0BBAEBBC6B9CCD6CBD7DFD4E4E8E1F1F4EEF8FAF5FDFEFBFDFEFDFEFFFCFDFEFD
FEFEFDFEFEFEFEFFFEFEFDFDFEFEFDFDFDFDFDFDFCFDFDFDFDFEFEFDFDFEFDFEFEFEFEFE
FEFFFEFEFEFFFCFDFEF8F8FBF6F7FBEDEEF3E2E6EBD7DEE4D6DFE4D2DDE3D2DCE1D2DCE0
D1DADFD5DEE4D5DFE4D1DBE1D0D9DFD0DAE0CBD7DCCAD5D9C8D3D6C5D0D5C4CFD3C4CED0
C0CACDBEC6C7B2B8B79D9F998A8373857353957A497BA1332BE00F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DC0987621E6C5B2A4B4D2C4E5C47495E4F486251526B5D51685C52675D556B62536B61
576D6262766C68797168786E6C7B706E7A6C6C7867697564667260626F5E5E6E5C5D6D5C
616E5F5E6B5C5C685C5A695E5D6E635F6F655E6C635F6D6461726A5D6E655B6D6365786F
697C756A7B77697B766A7D7670847A73887D768980778A8281938D80918E84959080928C
83978F889C938FA49998AB9F9EB1A2AEBFB0B7C5B7C4CFC4D3DCD2E2E8E0EFF4ECF4F7F1
F8FDF6FCFFF9FCFFFBFDFEFCFEFFFDFEFEFDFEFDFDFEFEFDFEFEFCFEFDFDFDFDFCFDFEFD
FDFDFDFDFEFDFEFEFEFEFDFDFEFEFEFEFEFEFDFEFFFDFEFEFDFFFEFCFEFEFBFBFDF5F7F9
EEF1F5E9EDF0E0E4E8DDE0E7DDE2E9DADFE5D5DCE1CFD8DDD0DBDFD3DFE4D4E0E4D5DFE2
D2DCE0CED8DECAD6DCCBD7DCCAD5D9C4CFD2C7D3D6C0CDCFC3CFD2C4CFD1C0CACCC0C4C7
ADABA8988F858B786192785279A03C57C32400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007492187D601F5E55284950364D5D4D485E50506759536A5D586D63576D655A7169
5C72695F756B60746A67796E6E7E73748075738172717F6F707D6D707E6E6C7C6C6F7E6F
6C7A6C6C7B6C6C796D6E7B706E7E756C7D7472817973827A798981788B83748982788D88
859895869896849695879A988AA19D8BA39F97ADAA96AAA69DB1AF9FB1B2ACBEBFA7BBBA
AFC3C1BACDC9CADED8CDE1DAD3E5DCE1EEE7E7F2EBF2FAF4FBFFFCFDFFFDFEFEFDFEFEFE
FDFEFCFDFEFDFEFEFDFEFEFEFEFEFEFEFEFEFEFDFDFEFEFEFDFDFCFEFDFEFEFEFEFEFEFE
FEFEFEFEFEFEFDFEFEFEFFFFFDFEFFF9FBFCF3F8FAEEF3F5E9EFF0E4EAEDE0E4E8DDE2E6
DEE4E8DAE1E5DAE2E6D8DDE2D9DFE5DEE4EAD4DBE0D6DFE1D4DEE1CFDADECDD7DACED6DA
CDD6DACCD5D9C8D4D8C5D2D3C8D3D5C4CFD0C8D1D3C4CCCFC2C8C9B6B6B4999086917E6A
977A59A7835357C2292DE11100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006D8F15745B205954304E5843475A4C4C6355536A5D5B70655E736A5D726A
60746C60736C64776D65776C68796E68786E6F7E75707E7472807573807478867A77867A
73827874837978877D76867E77898171847D7F928B84938D7F8E898697928DA19F91A3A2
8B9E9D95A7A695A6A592A6A4A1B6B5A6B9BAA7B9BAAABBBBBAC9CAACBDBFB2C5C7B7CACC
C5D7D8C2D2D2D4E4E4D8E7E7DDEBEBE7F0F1EAF0F0F5F9F9FDFFFEFEFFFFFEFEFEFDFDFC
FDFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFDFDFDFEFEFEFDFEFEFDFEFFFDFDFEFEFEFF
FBFBFCF8F9FAF2F6F7EDF0F2E7EDEEE2E7E9DCE4E6DEE5E8DBE4E5DFE9EADCE5E7D7E0E2
E2EAECE2EAEEE1E9EDE3E8EDE4E8EDDCE1E8D2D9DFCDD6D9CED8DACDD7DACBD5D7CBD4D8
C6D0D2C6CFD2C9D3D5C8D2D4C9D1D2CACCCAB8B4ADA1968A94816C9A7E5CA7805156C027
2EE11200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006C8D167259225C583648553D4A5F4E53685B5A6E635F726961736A
66776F66766F6979736F80776C7E756C7F786E807972827A73827972807872827874857B
73867D74867F7A8B847B8D867F938D819590879B978699968DA09C8FA3A095A6A598A9AA
9AADAF9DB1B1A4B8B6A4B8B6B3C4C4B2C1C3B5C5C8B4C3C7C3D2D4C2D4D4C3D5D6C7D8D9
CDDCDED2E0E0D2DFDFDBE6E7E2EBECEBF0F2F3F7F6FCFDFEFFFEFFFFFEFEFEFFFEFDFEFD
FDFFFDFEFEFEFDFEFFFDFDFEFBFDFEF9FAFBF9FBFCF6F8F9F2F6F5EFF2F4ECEFF1EAEEF0
E7EBEDE9EEF0E6EBEBE9EFF0E3ECEBE1E9EAE0E8E9E3E8EBE4EDEDE2ECECDFEAEADFE9EA
DCE3E6D5DCE2D5DEE3D7DEE3D5D9DED5D9E0CCD4D9C9D2D7C9D3D6CCD4D8C9D2D4C9CFD3
CED4D7CED1D3C6C5C4AFABA39A8F7D9882659F80587DA13F5AC42A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CB61381632A655B3354583D515E4C596A5D61726866776E
68797066766E6B7B746C7E746C81766B807873857E76868077857F7887827B8C85798C83
7D908981928E80928E829691899D9A889C9A8CA09F91A5A38DA29F95A9A699ABA99FB1B2
9CAEB0A9BBBBB0C1C2AEBEBFB8C6C7B9C6C7C0CDD1C4D3D7C8D9DAD0DFDED3E0E0E4EEEE
EAF1F2EDF4F5F1F7F7F3F9F8F9FDFCFCFFFEFAFDFDFAFCFDF9FBFBF8FAFBF4F7F8F3F6F7
EEF1F1F0F3F3EEF2F3EBEEF0EAEFF1E7ECEDEBF0F0ECF2F2E8EFEFE6EDEFE8EEF0EDF2F3
EDF3F3EEF4F7EBF2F2EBF2F4E4EEEDE5EEEDE4EDECE0E5E8DBE3E5DAE4E6D7E3E3D6DFE1
D6DEE0D0D9DDCFD9DBD1D9DBD3D8DCCFD4DACDD3D8D3D9DDD2D8DBD2D5D8C6C6C6B1ACA5
A194879B86719D8061A8855983A73E2DE21400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DE0D698D1F78612E68623D5D644B5E6A59637367
6B7C71667970687A716F81766D81766E837974837D7A85807E8A847A89837A8C8780938E
8596928A9A968C9E9B8DA19E95A8A696A9A897A9A99AADAEA1B3B4ADBEBDABBDBBADC0BF
BBCCCCC2D1D2C3D1D3C1D0D2C2D1D1CBDADBD7E5E7DBE9EAE5F1F1F0F9F9F7FDFCFBFFFE
FCFEFDFCFDFDF6F9F9F3F6F6F4F7F7F4F5F7EDF1F2F0F4F6E9F0EFEEF4F5EDF2F3ECF0F2
EBEFF0EFF3F4F2F9F8EEF5F5E9F1F0EAF1F1EFF7F5EEF6F6ECF5F3E9F1F2E9F2F1ECF3F4
EBF0F2E7EFF1E3ECEDDFE8E9E0EAEBDEE8E8DAE4E3DAE2E2D5DDDED5DFE0D3DFDFD2DADC
D0D9DAD0D9DBD4DDDCD4D9D9DBDCDFD7D5DAC8C5C5B6ADA6A9998A9C87709C8362A7865B
80A23E59C32900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0027DC0B658E207A65336D6340696951
666F5D6573656C7B7072817573827873857B7988827A867F7C88827987807D8C887D8E8C
869693859692869996889C9B8FA2A18FA1A295A7A898A9ACA0B2B4A9BABBB5C4C4AFBEBE
C0D0CFC4D3D2C5D3D6C7D5D8CCDDDED0E0E1DBEAECDCE9EAE7F2F3F2F8FBF3F8F8F6FBFA
F4F9F9F2F7F7F2F7F8F4F9F9F3F7F8F6F8FAF6FAFBF6FAFBF0F7F6F1F7F7F1F7F7F1F6F7
F4F9F9EBF0F1F1F7F9EEF6F5E9F2F1E8F1F0E8F1F0E6EFEEE6F0EDE8F1F0E4EDECE5EDEF
E4EAEDE1EAEBD9E5E6DCE6E7DAE3E4DAE3E3D7E1DFD7E0DED8E1DFD6DDDCD6DEDCDCE1E0
D8D9D9CFD0CBC7C2B9B8AC9CAB9785A28771A18364AB875B5AC7305BC42800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADF0E47B618866931
7561366B63416D6D536B715D707A6B7380747484797988807B89827F8B867A888480908D
8395928295928499968398978EA3A28FA2A490A2A393A4A696A8A9A0B2B3A8B9B9B0BFC0
B6C6C5B7C6C6C1CED0C3D1D4C8D7D9CEDEDFD0E0E2D5E4E6DCE9EADFEAEBE0E9EAE2EDED
E7F2F2E6EFEFEDF4F4ECF2F2EDF1F2ECF0F1EDF2F4E9EEEFE9EFEDE7EFEEEAF2F1E8EDEF
EBF0F2E8EDF0E9F0F1E6ECECE5EDEBE6EFEEE3EDECE3ECEBE3ECEBE2EBEBE0E9E8E4EAED
DDE4E6D6E0E0D6E0E0DCE1E2E5E6E8E6E7E7E2E4E1DDDFDBD2CFC9BFB8AEB6AB9AAD9B87
A48C73A68A68AB8B5E57C6315CC72E5EC52900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28DE0D47B5188E6E347F6A3C746843726D4F71735A777D6A7981747E847D7F877F808C86
82908C80918F839794809593879B9A90A4A48D9E9F96A8A89CAEAE9FB2B2A6BABAA9BCBB
B2C2C1B7C7C7B9C8CABFCED0C6D5D6C9D9D9C8DADACFE0E1D5E4E4DAE7E7DCE7E6DDE8E8
E2EDEDE1ECECE5EFEEEAF1F1E6ECEDE8EDEEEAF1F0E7EFEEE7F0EEE4EEEDE5EEEDE6EBEE
E7EBEEE5EAEDE2E9E9E8EDEDE3E8E6E4E9EAE4EAEAE6EBEAE5E9E8EAEDEDEBEDEDEEEDEE
E5E5E4E3E3DFD6D2CBCFC2B9C3B0A5B7A092AD967EA88E6EA98B647DA44757C5305BC62D
2EE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BF204ABA1E6B962D8A713F836F467F6C4B7F70537F775E
807B6983847681877C848D8585908B8C96948A96948B999890A2A099ABAA9CB0AFA4B7B7
A8B9B8B3C2C2B2C2C4B7C7C9BFCED0C5D5D6C8D8DACBDDDED0DFDED7E1E1DEE7E6DEE8E7
E2ECECDFE8E8E1EAEAE4EDEDE3ECECE7ECEDE6EDECE8F0F0E9F0EFE9F1F0E7EDEDEAEBEE
EDECF0EEEDF2ECEDEEECEAE9EAE6E4E9E3E0E1D8D4D5C8C2CDBEB3C6B3A4BBA694B49B85
B09578AE906FB18E6759C6385CC7355EC6312FE31700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C32453C0224CBA22
47B7239A77478E724687714B85725483725783775F837D6683826E898A798C8E80989A90
9EA49AA0A69EA6ACA5ABB2ACB8BDBBBBC0BFC1C7C6C0C6C3CCD0CCD3D4CED5D6D1D2D4D1
D6D7D4D7D4D2D8D5D2DBD8D5D5D2CED4CFCBCFCAC4CCC6BFC7C0B5C0B7ACBFB3A7BEACA0
BDA898B69F8FB09A84AE957AAF9272B2926EB2906A87AB505AC7375ECA365EC83130E418
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059C32657C32851C0274CBE264ABE2845B92543B826
6F9C3C9B80529A7F529B81579C815B9E84619F84639E8361A18662A38863A68C66A88D69
A98B69AC8D69AE9069AD8E66AB8B62B08F6581A94C81AA4A54C63556C6335AC9365CC834
5FC9335EC83030E41700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0108209 0.97619 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 181.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000]B000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooolP003o000@00[f0`0W
f``09]/<05F^6P1bTR<0Li8T07NC901eTbH0VG8g09]d>`2JMCd0LiP`07JJ<P1hVc<0IJd^03g?7080
:MlC00D0:=hA01oV3000o`002_L401C^1`0Q003o00Wooooo8000o`00100Xb3`0D91h052@N01hF;@;
0:0Pl0D0D91h00<00?l002S8?01@T7P08@00o`3=ooooo`002_oooolL003o000P02KJ2`25OBT0UV/`
09I_<`2GLCP0Uflj09I^>P2HL3`0Wg920:Ef@P2`NDP0]G]>0;InD`2gQ5`0^X=K0;^5GP2cQe`0/XYP
0;:9H@2aR5h0[hMN0:f6G02YPU@0YWe<0:9kBP2MNT@0WWY207JK<@1=_1h0C;XL04^h6`1>^A`L003o
00Wooooo7000o`000`1@T7P0X23`0:0Pl00M0:0Pl1`00?l0cOooool000[ooooo5@00o`00;00Dk@H0
9]X;02KJ2`0/d@h0II/R06nB9`1`Ubd0VGI209afA`2ONDd0XWY?0:1aB`2LI4@0UUHl09M==P2VAc80
]SlY0;Xf8P2k;ah0^R/N0<mBA`2b:a`0[b@E0:0_702JAS<0OBXK08D_8@2<=BP0T3d/0952;@2BB340
ZFeD0:1/C@2RM5@0Wg=?0:UlE02SOe80Wga<09]gA@2KM3d0QhDd07>F:`13`AP07N@:5`00o`09oooo
oaD00?l000@0:<Pl052@N01@T7P0D91h1`2P8?00102h>;@0d51h0=1@N03XJ3`90?n000030>QX?03o
P000oh0000<0oh000`3@D7P90:0Pl080D91h5`00o`3=ooooo`002_oooolC003o000b02gA301JXQX0
SfPa08i[=02BKcX0VGI609]dBP2FId<0RePg08=3:@22;Q/0Nad>07`E2@213@L0Q0P708T82@2=1`X0
S`D809d7202c3P/0b1@@0=DD4@3D5A00da@>0=4D3@3A5Pl0_A<?0:D=302N6a`0VB8S08/82P2@2PX0
RPP:0:8i>`2=:bX0Z4e<07@A30299Ql0Mb0D08M3<035WHT0^j::0:^ALP2QQUl0X85B09Yf?`1kSS00
KY8U05B]6P0:mP<C003o00Wooooo4`00o`000`1@T7P0N5Rd0:0Pl0050:0Pl080d51h7@3oP0000`3@
D7P0^3Rd0:0Pl0060:0Pl00307QH]00Xb3`00?l001800?l0cOooool000[ooooo4000o`00=`09mP<0
Ak@C07Yi902:JC80TFdo09=UA027DCD0NcdV06lP4@1Z3PD0K0L207060`1h0`<0Q0@408X50`2?1@@0
U`D609T51`2N1@L0X@H:09`6202G1PT0U`L;09l82`2g3`l0dQLC0=hH503R6a<0h1PA0=lJ4P3J5`l0
aQH@0:dQ7`2F61H0ZQlO09d:302K1PT0U`P709@K4P3=NVX0QBLO09/^;@2I;2`0VTi90=2i/`3<`k/0
dLNk0;b^V`2dWhD0[9=`0:65G@2MOD`0U70e062F6P0Sf0L04@00o`09oooooa000?l000<0:<Pl07QH
]02P8?000P2P8?000`2h>;@0d51h0=1@N00S0?n000030>QX?02P8?00X23`00P0X23`00<0D91h003o
0000o`003`00o`3=ooooo`002_ooool?003o000i01;/1028Hb80RfXi09=]A@2JK4`0OCXW06`A201b
2@D0M@H307T4101l0P<0O08407/11@250PL0S`@609<4102H1PL0X0H80:X9302X1PP0[@P:0:T82`2U
20`0WPH;09l:302S30`0/`l=0=0H5@3T71H0hB@L0>8l<`3N6a40hQTA0=l`;02_7A`0VP@50:@82`2X
2@T0X`L709TA3037JEd0Q1/D07h31@1k20H0[UA;0:MhK`3?_kT0_k^d0<_6`P3:`kd0dlRm0<2dYP2i
Z9D0X8Y[09IiB@2>JBl0=/L>01000?l02Oooool?003o0003052@N02P8?00X23`0080X23`:03oP00;
0:0Pl003052@N000o`000?l000h00?l0cOooool000[ooooo3@00o`00?@0[cPP0E9hF085a;02<Hcd0
OdD`07@V6P1_4PX0M`L608@6202710D0QP@408L40`2?1@L0S@<708/21`2A0`H0W0D709l51P2S1`P0
Z@L90:/72P2]20T0/@T90;8:2`2X1`/0Y`T<0:`<3`2/40l0Z0l;0;8>2`376A80gdi50>9FD@3Q8QH0
iQ`C0><M5P3F7AP0_A<B0:L=3@2N2@X0XPT909`81`2L3Ph0U@X708T3101i0P<0NPh<078G4`2eQ840
f<c:0<k=b`2n^KH0_[N`0;JaZ@35`K/0b/>l0;j`X@2_Vh00Vh5H05jX:@09mP@03P00o`09ooooo`d0
0?l000D0D91h0:0Pl02P8?00X23`0=1@N00[0?n000030;Ph]02P8?00X23`00P0X23`00<0N5Rd02S8
?000o`003@00o`3=ooooo`002_ooool;003o0011032o0P1dHa<0Q5l_07e<;01a;a`0JA4807<7201l
10T0OP<608430`290`@0S0@208d50`2B10@0V@D609/51P2I1@H0W@H60:H82@2Z2@X0ZPL90:/7202^
2@T0/`X;0;<;2P2a2`X0[@/:0:/<2`2[3Ph0ZQ0>0:hB3P2_5100YaXD0>>TW02jM6/0WB@L08lL501i
5a00JA@?05lC3@1D4Ph0E@l=06P?3P1j3a00V1dN09X;302K1`P0S0@308<20P231@D0PaTI0<bCTP3?
`;d0a/G00=C?b@2l][40cL[70<_:b031_k`0cL_80<c8`P2k[Y/0TXeK05NT:P0Bk@P03000o`09oooo
o`/00?l000D0N5Rd0:0Pl02P8?00d51h0>QX?00L0?n00080j6Pl0`3oP000103XJ3`0d51h0=1@N03@
D7P90?n000030=1@N02P8?00X23`00X0X23`00<0:<Pl003o0000o`002P00o`3=ooooo`002_ooool9
003o001402S:0P1`Ja00PUXX06`m801O50T0JPP607061P1d1@D0N0<507l31`230`H0Q`<408h41P2@
1@H0T`D609L41P2J10H0X0D70:872@2R1`H0ZPT80:`:2@2]2P/0[@X90:l;2P2b2PX0]@`<0;@>302_
3@/0[Q0<0:/@3@2X5A40X1dH08XN6@1Z7AP0D38^06QICP27LFH0XXn50;VXW@34]:T0`KFZ0;R]X@2P
TXL0MfEM058j=00j5A<0G0h=08`?3P2H2`T0V0P70:8C3`2N9B80aWIf0;ZCT03Ec<L0c<G00;^d[@33
_[P0b/[60<[:bP3<cLh0c<k@0<c>c@38a/80]ZbP0:2=K`0m`1d;003o00Wooooo2@00o`00101@T7P0
X23`0:0Pl02h>;@N0?n000030>QX?02h>;@0X23`00T0X23`00<0d51h0>QX?03oP0001@3oP00=0:0P
l00307QH]000o`000?l000T00?l0cOooool000[ooooo2000o`00AP0AjP40OELE07mH;`1L9a80E0L2
06L41@1`1@L0L@<607020`1h0PH0O`<808@41`2910D0R`8409021`2D0`L0U`@609L51@2M1@H0X`D7
0:P72@2]20X0Z`L90:X:302/2`T0[PX:0;@<302d30X0/0`90:h@3P2Y3`d0Xa<A08XP6P1:5@`0A2XP
099nM@3Lb/00i]K:0>[Le03^i>00k^OT0>[Wi03Vi>80jNGQ0>cVh03Xfm@0h]760<FfZ`0m;BH0A@X9
07hA3`2F2``0UPL809db<`3mblh0[XF70=2h]03Gc/P0`kji0=OCcP3>bL<0_[^h0<S8a`37b/`0c];E
0<_<c`2m_[h0alBm0:>AM`0caQL:003o00Wooooo2000o`00101@T7P0X23`0:0Pl03@D7PM0?n00003
0=1@N02P8?00X23`00d0X23`00<0d51h0?n0003oP0000`3oP00>0:0Pl003052@N000o`000?l000P0
0?l0cOooool000[ooooo1`00o`00B@0BjP40Lg8B07Xf5@1N4@H0D@D105@20@1W0`@0K`@707441`1a
0PH0M`8607/2102310L0R@D508h51@2B10D0UPH709L51P2G1@D0XPP70:P8202W20L0ZP/90:88202N
1PP0X`/90:T92`2^2P`0[`d:0:/>2@2R4@h0S1DB06XH501W@SL0ZYJ80=W;_@3Wg=40j^CP0>cWiP3W
i>@0j>KV0>KWi@3Vi^H0iNCW0>SVj03WiNL0iN?Q0>GQg@3TgmP0clBm06YFD@0k30X0N18B098:302V
=ST0UcPn084U9P2cOWX0dL:m0;:WX031^;40b<>l0<g=bP3Ddm<0c/k@0<g@d`3?d=<0b<S=0<?5aP2i
]Jh0ViQc05NS;P0V]PD02000o`09ooooo`L00?l000<0:<Pl0=1@N03@D7P07@3oP0000`3XJ3`0^3Rd
0:0Pl0030:0Pl0030=1@N02P8?00X23`00X0X23`00<0d51h0?n0003oP0000`3oP0000`3XJ3`0X23`
0:0Pl00<0:0Pl00307QH]000o`000?l000H00?l0cOooool000[ooooo1P00o`00B`0CjP<0J7@>08PJ
1`2I2@D0WPT809H82@281@D0QPH507h5101f0P<0MP8607d4202110L0Q`D908L41P2>1@H0U@H509P6
1P2J1`P0W`H70:H82@2T1`T0X0H80:@9202I0`H0V@L909`72@2S2@`0Y0X=0:4=2`2C5Q00G1`A075C
A@2cXY@0h]K;0>WPf`3XiN00inCQ0>OVi@3Xi^D0i^CT0>OViP3Vi^@0inKW0>GVj03WinT0i^OX0>?T
h`3Rhn80h>7Q0=oPg`3Lem40[Z2F05hh<P1g3a00TQHJ08`72`2D2PX0WdU:0=_8b02m]:d0eL[20<S0
^P2m^;@0emOF0=CGf03?dM40dM;E0<W;c`39cM00a<G70:JRWP2UUhP0RFe?02Jf1@07003o00Wooooo
1P00o`000`1@T7P0`:000?n0000L0?n000030>QX?02P8?00X23`01<0X23`00<0^3Rd0?n0003oP000
0`3oP00?0:0Pl00307QH]000o`000?l000D00?l0cOooool000[ooooo1@00o`00C@0Td`H0QSXA07h@
0`2H1@D0Z@P80:d92@2^30X0]Q/D0;PH402h3PX0/@`;09d9202<1@H0P`8608<41P2710D0RPD608l4
102F1PL0W@L60:451P2R1`P0W`H709l72@2L1PP0VP@609`5202L2@/0V@/<098A401_4Pd0KTHj0<Bg
Z03Tg=40inGP0>GUh`3Si>40h^;O0>CSh@3Thn80iNGR0>GRi03VhnL0i^CV0>OTi`3Sh^@0i>CU0>CU
i03Sh^80h^7R0>;Ri03Thn<0hn?S0>CPg@2j[jL0DaPF08<9302>0PD0ZPh@098:3P1g;2d0_ifB0<Zi
[P2o/ZL0_KR_0<k>b@3Adm80blc>0=7Ad`3Ce=L0cm3E0<O7c02l^kl0/[2W09F=O026J4T04mX200H0
0?l02Oooool5003o0003052@N03oP000oh0001`0oh0000<0^3Rd0:0Pl02P8?005@2P8?000`3XJ3`0
oh000?n000020?n000030>QX?02P8?00X23`00d0X23`00<0D91h003o0000o`001000o`3=ooooo`00
2_ooool5003o001=075B201a2P00QP810:451`2[2@X0[`/;0;`Q6`2d6@l0`QdE0;h>2@3130T0a0d<
0;P>2`2X2@T0T`<408@310281@H0R0420985102P1`P0XPL50:471P2Q1`P0W`L909`31@2R1`X0X`X:
09L:2@2540d0F0`906M3<`3@`;40iMoJ0>7Pg@3Rhn00h^;Q0>;Qh03Sh^00h^7O0>?Rh@3ShN00hN3O
0>7OhP3ShN80i>7S0>3Oh@3Ph>80h>3S0>3Ph@3QhN40h>7Q0>CRh`3Th^@0gmkQ0=kJf01fEU00NQHD
090I602<1PL0R`D807lG5P2KHE/0flc70<k3_032]Zd0^;2V0;nl]@3:bl/0d]KG0=CFfP3Be=L0dM7D
0;jo`@2RXih0W9ZA08efIP0KcPP01P00o`09ooooo`D00?l000<0d51h0?n0003oP0006`3oP00J0:0P
l0D0oh003`2P8?000`1@T7P00?l0003o0004003o00Sooooo8`00o`005P1Ae3L0RkEM08njI02F`Fd0
Y<>20<B]U`2eVh80Yk>00;j[UP39^JX0ZYjD08^1NP1SI600Th]n09NbQP2@_H40T<Ij08;4J01MdDX0
C]<k02cU800El0hP003o00Sooooo8`00o`000`1@T7P0X23`0:0Pl00?0:0Pl0<0D91h00<0:<Pl003o
0000o`007P00o`0;ooooo`002_ooool4003o000=03:e0`1b4P40N@<109830`2T1`/0WPD60:/=3@2e
6A<0^B4E0;hK4P2m3@T0`P`90<@<2P020<D=2`100;l=2`2W20L0SP<408P40`2=1@@0VPD80:071P2N
1`D0XPT:0:@92P2U2@/0X`X:09d92P273P`0FA`C089UDP39]Z<0h=_B0=gKfP3Og]`0h^7O0>7Sh03Q
h^00h^;P0>CSh03ShN00i=oN0>?LfP3Sf]T0gm?A0=W7a`3Ka/L0fLC40=k<c@3SfMT0i=oO0>7Ph03O
gn00h=kQ0=[Kg@3IfMT0^jbW06PQ702^BDL0PPT:08@51`2B:B/0R4=70<:RY032]:l0_[BZ0=C;`@30
_KD0`[nk0<O7a`3AdmH0dMCH0<g=d@36bLX0_<2o09RJT`2OT8H0C6DF01o@1`D00?l02Oooool4003o
0003091`N03oP000oh0001X0oh0000<0j6Pl0:0Pl02P8?006@2P8?000`3XJ3`0oh000?n000020?n0
00030=1@N02h>;@0X23`00d0X23`00<0D91h003o0000o`000`00o`08oooooa/00?l002802oP702kT
6P1AdRl0PKU=0:JWI`31XGl0b;6E0<>`V038^J@0`;>P0=S?`P38^jl0bl>g0<2eZ03?a[`0aknh0;Ne
/02d/JX0[:^Z0;>d]022UJ80TZFb035?I`1]Ri/0_/gB0<[>c`3=cLd0cLc<0<g<b037`K/0_[B[07SA
K@1KdDX0:n@O7000o`08oooooa/00?l000<0:<Pl052@N01@T7P0702P8?000`1hF;@0D91h052@N00L
003o00_ooooo000:ooooo`<00?l005404nL1074V0@1c0P40P04209/41`2W1PT0Z@T90:lB402e71H0
]QTB0;/G402j30T0_``90<<;20363@X0b@h;0<T>2P3;3``0`@h;0;<;2P2P1PD0UP@509`8202P1`T0
X0H80:881`2M20T0S@H708@@3P1S:Al0]Z>A0=gCaP3Pg=@0g=[E0=[JeP3MgM/0h^7P0>7Qh03Qh>40
hn7P0>KOg03LbLH0`IBA0;1`K@2QD4d0Tc4a08hM8@2D6ah0UQ`L09HR902G>SP0X5aH0;nFT`3Pdm80
h=kO0=_Kg@3GemT0fmKE08E=AP1j2`X0R0H708X720231PX0M`@808<];P3:/:T0bL:j0<>k/@2f[j@0
a<?00<g>cP3<c=00cm7E0=7De`3:cM00][Zm0;2c/P2HU8`0ICha0:IjH`0^[0`01000o`09ooooo`<0
0?l000<0:<Pl0>QX?03oP0006P3oP0000`3XJ3`0X23`0:0Pl00:0:0Pl0030;Ph]03@D7P0d51h00D0
oh0000<0j6Pl0=1@N02h>;@01@2P8?000`3@D7P0oh000?n000040?n000l0X23`00<0N5Rd003o0000
o`000P00o`08oooooaP00?l002T0;nDL05k<>@21^e00_Yaj0<>SPP37ZHT0b:b;0<V_T03?]Yh0c;FM
0=:lZ@36/j00_[>U0;R`YP3:`k/0c/Nn0<[9`038a;d0b<Bn0=;Bc033`k`0_[jh096HVP2KY:X0SJ6_
08jX^P1mWk@0JXZN0<CBeP39dM@0bm?E0<S@dP3;dM@0b=3B0<O<d034b/X0bLO30;n`Z@2CWg<0Dk4f
017/2@0H003o00Sooooo6000o`02052@N2D0X23`00<0N5Rd02S8?000o`005`00o`0;ooooo`002_oo
ool3003o001A04FD0@201`40NP4207X0002I0`H0Z0D60:d9202a5140[A<>0;/P6P2g4Ph0^@X80<0<
203430X0b@`;0<P>2@383PH0c0h<0<`=2`3?3Pd0aa4?09h40`2J1PL0W`H80:88202S2PT0SPD7084B
4@1G5Ph0/in>0=cFc03KfM@0fm_F0=cKeP3NfmP0f][G0=gNg03Pgml0i]oM0>OCd@34Ui80Sc/g09HN
7P2M51H0Wa8C0:0?3`2Q2`d0Y0/=0:D<2`2T30/0VP/:09<?3`224a<0^7Mc0>GHeP3Jf]/0fM[J0=SG
e`2TO7@0L@l808P7102B4A40QP`?07`41`2@8b<0VFEP0<W1_@3@blP0b<:k0=7@cP31`/40d];C0=3A
e03;c]40b<c>0=;Ee`2UYJL0YJBN06U:@P2HM6/0LgTo00@00?l02Oooool3003o00030830003oP000
oh0001X0oh00302P8?0<0?n000030=1@N02P8?00X23`0080X23`00<0d51h0?n0003oP000103oP000
0`3@D7P0X23`0:0Pl00=0:0Pl0@00?l02?oooolE003o000^03ON8@1b`4L0Zj5]0;jTPP30YXH0aJb>
0<^aUP3=]Ih0dK^V0<bjX`3A_ZP0e/6/0=K5[P3D`JX0e;fZ0;ncYP3?bKl0]k>[0<g8_`3If=40blS2
0=;=b038a;d0cl_60<_8`P3:cld0Z;:g05UbS01jU;00KXbV0::lc@2/a<h0bMCG0<WBe@37d=80b]7F
0<G=dP35c]D0a<gC0<C<c`34b/d0`/G60;nl^@2WUhT0C[0b00Se11H00?l02?oooolE003o0003052@
N01hF;@0X23`02T0X23`00<0N5Rd02S8?000o`005@00o`0;ooooo`002_ooool2003o001C01CY0@1l
>P40R@@108P20`2<0P80V`840:L51`2Y1`L0YPP70;<I5`2_4@h0/PX70;X;2@2n2`P0`P/90<L<2`37
2`X0b@d;0</>3@3<3@/0c`h;0=0@30353P/0]PX:0:X71`2R1`H0V0L707X:2`1J6A<0VGi^0=WCb@3L
gMX0fm[H0=[JeP3KfmL0gm_I0=gLfP3Rgm`0g/K40;EgMP2Q@D00XB@S0:@E5@2W4A00Y`l?0:H?4@2W
3@h0YPX=0:@82`2U2PT0X@P709d92@2J2`/0T@T;09<K6@3>VIH0hMWH0=[IfP3JfMT0`jFN07@J4024
1`D0Q`@60884201n1PL0VS4a08e<B@3Fa<00_KF]0;:ZWP2n^k@0cLc<0<o>dP3;c=00c<kA0<K:c@34
bLd0^;jn09bNV@1dGeL0Ke==0:B@P`0:iP800`00o`09ooooo`800?l000<0D91h0>QX?03oP0006@3o
P0000`3@D7P0^3Rd0:0Pl0080:0Pl0030=1@N03oP000oh0000d0oh0000<0d51h0:0Pl02P8?000P2P
8?060?n000030>QX?02P8?00X23`00d0X23`00@0:<Pl003o0000o`000?l02?oooolB003o000b03SN
8@1o^4`0WjMV0;RQO@2jY8<0_ZR50<2/S038/iL0cKVS0<ZjZ02m/ZD0]j^L0=S6/`3Lb;D0g<Zf0=k<
]@3NbK80f/Vc0<o0[03?aK/0blBj0<?1^@2a[jL0d]380=3;aP3:a/80cLFn0=3;a034`kh0_L;30;W2
bP1]QY/0HWjH05EiU@1gUj/0bMWL0<_Ff037dMD0bM?G0<_Df039dMP0aloF0<7:c`31c<l0`lcA0<78
c02n`lL0^kJe07n?HP0HhPhE003o00Sooooo4P00o`000`1@T7P0X23`0:0Pl00^0:0Pl00302S8?000
o`000?l001<00?l02oooool000[ooooo0P00o`00D`1HO@40Ta<608X30P2=0PD0V`D70:84202U10L0
YPD60:L41P2Y1@T0Z`H80;D:2@2j2PX0_0/;0;h;2P332`X0a`d90</>3@3;3@`0cPl;0<l?2P3B40d0
da8>0=DA3P3C5140^Pd;08P<2P1W;b@0]Z6=0=_Bb@3Lf]P0gM[H0=cIf03Lf]T0gm_K0>3Ge@3?]k@0
]7Qg0:H`<02^61H0/aHC0;PE502c4Q40[A4>0:TA3P2U3Pd0Y`d=0:D:2`2V2`/0Z@/<0:<9202M2@T0
V0P809<7202=1`T0SS0]0=Fd[@3Je]@0emKF0=Fo_02E>c<0S`/708H6102A7a`0TRPX07L82`1e4Q@0
Vf]R0<6bY`2n]J/0_kZb0;nl^03?c/d0b<[:0<g?d`34b</0alc>0;Nl_@2OY:40PWA/04/a;02o][D0
;:0A00<00?l02Oooool2003o00030:0Pl03oP000oh0001P0oh0000<0j6Pl0:0Pl02P8?001`2P8?00
0`3@D7P0oh000?n0000@0?n000@0X23`1`3oP0000`2h>;@0X23`0:0Pl00<0:0Pl004052@N000o`00
0?l0003o00Sooooo4000o`00=@0Qja@0QK5B0;JMN02mXH40_:>50;RSR030ZX`0bK:C0<bhWP3B_jH0
dKfW0=G;_@3Mf]H0bkja0=[6/03Lb[D0f/fo0=kCa03OcKH0g/bf0=S:]P3FakD0e<Ri0=37`02][:H0
c/c40<S2^`3He/d0c/g40<g:``33`KT0[k6^0:f`/02@XJd0[<3;06N6W`1ZS:@0W[_90<_Ef03:eMH0
bMCF0<WBe`37cmL0`lcB0<38cP2nal`0`lcA0<G=e02nall0_<C90;>h_`1DH4l06=@A01@00?l02?oo
ool@003o0003052@N02P8?00X23`0340X23`00<0D91h003o0000o`004P00o`0;ooooo`002_ooool0
E@00o`004^L108HM002A3PP0PP4109041`2I10H0V@4409l41`2Q1@H0Y0@80:H42P2Z1`P0/`T90;P;
2P2l2`X0_`/;0<<=2@3330T0a`d;0<T=303=3``0d10:0=8A2`3A4@/0e14=0=LD3@365a80NRXR0<Ba
Y@3MeM00f=KE0=_HeP3OfmT0gMWG0=kHe`3E`<00YfMR08XS7@2Q5aD0/Q@C0;HC502b4Q80/1<B0:XD
4@2P5Q<0U1@B08dF4`2;4a40S`lA09`<3P2T2`/0XPT90:092@2I1PH0T@<508h31@2220H0XEU>0=[8
`03Ee]L0f<S70:E@A`2a8QL0XbHJ09/g<@2H?ch0M@L:07P92`1m=C00dkNb0<2c[P2dZ:40^;J^0<c=
bP3:bl`0al[=0<W=d@39bll0/[Rj0::XY`2?Qh@0@B@P09N<RP1EQcH00`00o`09ooooo`03003o000X
b3`0oh0001T0oh0000<0j6Pl0:0Pl02P8?001P2P8?000`3@D7P0oh000?n0000C0?n000<0X23`1`3o
P0000`3XJ3`0X23`0:0Pl00=0:0Pl0<00?l02?ooool=003o000c01Kb3P1GbCL0T:UK0;>JL`2gWg/0
^J640;bSRP32ZY80a[2I0<ZeV`3:]IX0ckbS0=6mY`3C_ZP0elVg0=_AaP3Fa;00e/:]0;jdY039bLH0
f][F0=_>_P3ObkL0flVd0=O6/03EakP0cl:d0=[BbP3=a[h0c/_20<S3^@3CclL0bL>m0=WFd`33`Kd0
Z:bY09>MY@1YP9@0JXBM09JbaP28YKH0b=SK0<cFf03<e]X0cMGK0<_CfP37cm@0_/K;0;W3aP2h`/D0
`<W?0080_/S?00@0_/SA08NEXP1lP800;=HQ4`00o`08ooooo`d00?l000<0:<Pl052@N02P8?00=@2P
8?000`1@T7P00?l0003o000A003o00_ooooo000:ooooo`1E003o000_/P80LA<207P8101j0@80RP84
08l00`2D0@80VP<509l4202O0`D0X`D70:L61P2b2@X0]`X:0;d;2P2n30X0`@`90<@=2P363@/0aP/;
0<X=2`3>40/0dA0;0=8A2`3F4`l0d1D@09@B3@2cTHH0hMSG0=cHf`3JemX0gMWJ0=_HeP3Lf=H0g<O6
09I;BP2K61L0YQ4=0:/B3@2_4Pl0ZPl@0:TD502R71T0PAhK05<B3P0j30L0:PT302T91P0g20X0Ga4B
08P@4@2J2@T0W0P609H40`2B0@40T@8208T40P2081H0dK6W0=OGf03LcL/0[E]A0;l_8`2T4@X0UadI
07`91`1m1@H0QaLD080e<02kVYP0eLc>0<S3a02h/Jd0aL?10<O;c035blh0`l[>0<;6b`32aLT0TYND
09^CT@169R80R7Md06eoC@03003o00Wooooo00<00?l0052@N03oP0006@3oP0080:0Pl0030=1@N03o
P000oh0000P0oh000P2P8?000`3@D7P0oh000?n000070?n000<0X23`203oP00?0:0Pl0<00?l02?oo
ool;003o000l01Ka3@1:cbd0XiaY0;:HM`2cW7T0/Yel0;bTR02nZ940a[2J0<RcW@38/YT0b;:G0<Vb
V@3<]Yd0c;ZO0=6nY03C_jL0e/6W0=NoXP3:]j40`kVZ0<S3^P3AbKd0g/fh0=k:/`3Kb;00elB/0=G5
/P3C`k@0c/6c0<Vn/@3FdlP0c/W30<o;a@3:b<80b<2k0<G0_03>c//0^KZg08ZKYP1mUZL0<51^06J5
WP2`bMH0b]GI0<gEg03>e]d0cMGM0<SBf037dMD0`<W>0;k6b@2h`<D0]/340;W3bP2ha<l0QiBV04UO
L@1YOF`06N@A4P00o`08ooooo`/00?l000<0:<Pl07QH]02P8?00>02P8?000`0Xb3`00?l0003o000@
003o00_ooooo000:ooooo`1E003o000fUP80@`P207`l>`1/10D0QP8608l2102A0@<0V@<60:042@2Q
10P0Y0H70:P6202_20X0]@T;0;`;2`3030/0```;0<<:2`363@/0b0h:0<`?2P3?40/0dA0<0=8B303>
5A40ZaHC095>A`3Lcl/0fmKH0=_HfP3IemT0g=[K0>3FeP34YJ@0V4]909TE502X3a00ZPl>0:L>3@2V
5180TQPE06lF501C6aD0GD<i07e[G`2EQ7L0X96309^=O`1fIET0C3H^04`?3@2B3`l0W@X909T41@2E
0P<0T@8108/20@1k30H0aiR>0=[FeP3JblT0[5U?0;LS602o:Ah0Y20H08<>2P2K:b/0QaHC07lP7@2P
JFT0d/340;jl_@2j^;@0blc;0<?:bP30alP0a<_>0<36b@2n_l<0ZZf]09RET`1>>3<0PG9`07m_G@03
003o00Wooooo00@00?l00830003oP000j6Pl5`3oP0000`3XJ3`0X23`0:0Pl0050:0Pl0030>QX?03o
P000oh0000D0oh0000<0d51h0;Ph]02P8?001@2P8?000`3XJ3`0oh000?n000050?n000030=1@N02P
8?00X23`00P0oh0000<0d51h0:0Pl02P8?00302P8?03003o00Sooooo2P00o`00?@0YhQT0W9MS0:^D
L02aVGP0]9al0;JOPP2jXh/0aJjF0<B_V032[YD0aJfD0<F/TP35/9L0b[FL0<ffV`3=^Il0ck^R0=:m
Y@3D_jH0f;nS0=ZoY@36/ih0b[RT0=c9/`3Mb[@0f/Na0=[5[@3F`ZX0d[jW0=O4/@3<_Jh0cLBh0<:h
Z`3@c<80`Kbd0=C@c034_[P0`kji0;Vc[`2^[j/0Zk2h09RX/`25Vj`0OYZb0622W@35eM`0c=CJ0<oH
g`3=e]l0c=GL0<WAf@33bm<0b=3H0<K>f030b]40_LW@0;W3b`2X/;X0K7j>07V:T@24Vg804P00o`08
ooooo`X00?l000<0:<Pl0:0Pl02P8?00>P2P8?0B003o00_ooooo000:ooooo`1E003o001:IPH0JeM@
07IZK@130`@0Q@D809021`2C0@H0W`@809d31`2M10L0X@D70:H62@2^20T0]@/90;X<2P2n2`X0`P`;
0<@;2P3530T0b@h:0<d@2`3@3P/0dQ4<0=0B3P2T5A00Od<h0=O7_`3OgM`0emKF0=[Gf03Kf=P0gM3?
0:=YI@2<8Ah0Wa@A0:X?3`2W3Q00Xa0>09<D4P1V5a40IdHi09Z7N03:^jh0hMG<0>;Gd@3TgMP0i>3K
0>GNf@3Pell0fL_20:nAR01o61@0W@T:09/72P2E1@P0S@8308T20P1l1`80_XMh0=OCc`39/Z/0W3LX
0;DB2P317A@0]B0I08X4102:4QH0Ta`J08LK5`26<Bl0Nd920<Zk^034`;`0^[Vf0;Zl^`34blh0a/oA
0;o8bP30bL/0W:JW09RLVP1ICDP0RX:108MjK@03003o00Wooooo00D00?l00:0Pl02P8?00X23`0>QX
?00E0?n000030=1@N02P8?00X23`00@0X23`00<0d51h0?n0003oP000103oP0000`3XJ3`0^3Rd0:0P
l0090:0Pl0L0oh0000<0d51h0:0Pl02P8?002@3oP0000`3@D7P0X23`0:0Pl00;0:0Pl0<00?l02?oo
ool9003o000o05^m>P2HTf<0Z9=d0;2KOP2eX8H0_j>;0<^PR@2iLEh0aY9h0;jXS02mYh`0`jV=0<F/
T@36/9T0ak:J0<NcV@2^XXl0UY620::MSP3=_JH0el2W0=[1YP3H`jL0fLF/0=_7[`3LbK40f/R`0=W3
Z`3H_jP0e;bU0=6jY@3?^jT0dLBf0<Vn/`3<`[D0bL:f0<6j/03@blD0b<Bn0<6n^P2l^kH0Y:FT061a
O`2;WZl0M92Y07jK/02db]D0cMGI0<oGg@3;eM`0cMOP0<SBfP37d=D0a/oF0;c5cP2f_lL0`/gD0;c6
cP2f_L@0Kgb;0724S`2GW9h0=LdY01400?l02?ooool9003o000307QH]02P8?00X23`00<0X23`00<0
^3Rd0=1@N02h>;@0=@2P8?000`1@T7P00?l0003o000?003o00_ooooo000:ooooo`0^003o001MPbL0
RhR506AXJ`0I0@40H@H808831`2>0PH0TP<809<2202H0PL0W@@80:@72@2^20/0]0/;0;T;2`2m2`T0
_`/:0<<=2P373@X0b@d:0<`>303@3`h0dA4?0;/E4@29A3d0elO00>;Og@3Lg=d0fMOH0=WEe@3I`;`0
_UiD0:LG4P2N2`P0X@/<0:4=3P2E4Q@0MQLE06<c;02]Vhh0gM?80>7Le03Rh=d0h^7P0>7Qh080h>3N
02D0h>3O0=kOg`3KgM`0hMSE09iGC`2I2`X0V`H709T6202C1PL0S@D6088>1@2oR7H0dlg70<2OV02@
81<0/0T40<8;2`2n2Pd0[PT<08l31@231@P0PAhO0>>WZP28De@0aJjZ0;Vb[@32_k/0b<W90<;:c032
b/d0aLg@0;c5a`2W/[80SYRH07ejN01kM7D0RGme00<00?l02Oooool01@00o`00X23`0:0Pl02P8?00
^3Rd01@0oh0000<0j6Pl0:0Pl02P8?00102P8?000`3XJ3`0oh000?n000040?n000030=1@N02P8?00
X23`00X0X23`00<0d51h0?n0003oP000103oP0000`3@D7P0X23`0:0Pl0090?n000030;Ph]02P8?00
X23`00/0X23`0`00o`08ooooo`L00?l004404o0<08NHF02OSW00YiMl0:jNQP2cXh/0^Z:=0<26M02X
>2H0]2<C0;eSA`32XhH0`jR>0<>YS035ZXd0bJjC0<F]U@2DRgX0SH]k0:6JRP1mOWD0R8Mj0=BoYP3G
`:H0f/:V0=W4Y`3Kajh0g<R_0=[7[`3Ha:/0el2X0=FnYP3A^j@0ck^W0<NfX03@`[<0akb`0=??a@36
`k`0b<Fk0;be[P3@c<D0`;nk0;Vi]`2_/k@0MXB@04]VP01POi/0NIJY0<WEfP3?emh0c=GL0<cFg@39
e=`0am3I0<G?e`35cMH0/KVo0<7>e031c=@0_lcE065cP`1<IG80S9^S07^SK`0A003o00Sooooo1`00
o`000`0Xb3`0X23`0:0Pl0040:0Pl0040=1@N03oP000oh000?n003H0X23`4@00o`0;ooooo`002_oo
ool0E@00o`00XX=N07EkP01MIf/03@4103420P1I0P80P@<608410P2;0PH0T`4309X21`2R10T0[0H:
0;89302h2``0_0`;0<4<2`322`T0a``:0<X<2P3=40h0cPl>0<dA3`2C4a00`JFN0>;Ng03Qh>80gmoQ
0>3NgP3La/80^V=J0<4M50375100]A0<0:0;2P2A4Q40FQ4=06U=@P3:_:h0h]cE0=kNfP3Ng]`0h>3O
0>3Qh03Shn<0h>3P0>3Pg`3Ogml0fmkM0=gOgP3Og=`0/7mf09D?302I0`H0W0H909X72@2D1`P0R188
0<B?OP3GclT0ZXMn07@70@2W1PH0_0P90<0:3@2i3Q00X@d?08@31`2>6al0Ma@M07@W;03G`<40c<S5
0<G4_`2h^;L0`<K:0<K@dP2f_/40aLoA0:Fa/`2EXJ80N7Qd06eWI@2;PGL00`00o`09ooooo`03003o
002P8?00X23`0080X23`00<0d51h0?n0003oP0004@3oP0060:0Pl0L0oh003P2P8?000`3@D7P0oh00
0?n000040?n000030=1@N02P8?00X23`00X0oh003@2P8?03003o00Sooooo1P00o`00@`0RgAD0Mi]?
09b?L@2SUWl0Z9^50:jNQP2aX8D0^IMl0:9>=P2^@2D0_fU;0<RGNP30Y8T0`:J80<6WQ`34YhL0aJR9
0;>OQ`1^Kf80Wif70:BNS@2=Rh40J6mT0<fmX`3F_ZD0f/6W0=[3YP3JaJ`0flN_0=W6[P3Ha:/0e/:Y
0=BoZ@3A^Z<0c;NR0<bhY@36]J<0a;BT0;V]X03AcLD0`l2i0<Bo^P2k/Z/0^[B]0;bi]@2i][@0T8ZB
0;VW[02`UiH0Z9>E0<Jl_`3>cm80bmCI0<WCfP39d]X0b=3I0<K>e`30`kh0`L>^0<3:c@31cML0_lcH
09BR/01SMH80QYJO0:b/[00Hha404000o`08ooooo`H00?l000<0D91h0:0Pl02P8?001@2P8?020?n0
00030>QX?02h>;@0X23`03D0X23`00<0D91h003o0000o`003P00o`0;ooooo`002_ooool0E@00o`00
]9b008VHW@1@GEh040<202X31@0[0@40F@@508@31P2=0PP0T04709D21`2Q0`T0Z`L;0:l<3P2b3`h0
^P`<0<8=303430/0a`d;0</>303<40h0cA0>0<8D4@2CASl0g]GA0>3Ph@3Rh^D0hMoQ0>C9b033JF80
_b@L0<XB3`3<4`l0bAD@0:`F4P1S5Pl0SWEU0=G9^P3RgM@0h^3M0=gNf`3Oh=d0gn7N0=kOgP3Qh^<0
hN;Q0>3Qh@3Ogmh0gMkO0=gNgP3LfML0YgA[09P?2`2S2@X0X@H709d61`2D1PH0Ra`>0<ZOR`3Ke]40
Vg5Z07@91@2D10@0^0X:0<0:2P2j30d0^ALI09<31P281PT0R0L;07/9301l?C`0`[Bb0<?2_`39bLT0
aLK:0<S?dP35cM00_/O;0;_6bP2?W9l0TING06YTI@2?Q7`00`00o`09ooooo`03003o002P8?00X23`
00<0X23`00<0d51h0?n0003oP0003`3oP0000`3XJ3`0X23`0:0Pl0020:0Pl0030;Ph]03oP000oh00
00@0oh0000<0j6Pl0:0Pl02P8?003@2P8?000`3@D7P0oh000?n000040?n000030=1@N02P8?00d51h
00X0oh0000<0j6Pl0:0Pl02P8?002P2P8?03003o00Sooooo1@00o`00A00Yda/0QWIJ08YoI@2KT7P0
XiR00:RLP`2[Vgd0[ieo0;FNO`2oVgd0^Hi_0;jOO`2kX8<0_:220;nQO`2oXH00_j5n0<6RO@2UT7@0
GF9I07QmL01hOG@0HfiZ07MkK`3>_j@0dl2T0=O1YP3J`jL0g<J/0=[7[@3JaJ`0fLF]0=O1ZP3E_jX0
ckbT0<bhX039]Id0aK6L0<ZlZ@2k[9/0_K:S0<:j/03>b/<0a[fh0<Z_Z`2cM6l0ZTM30:HV9P2/5aT0
[A<E0:XC5`2V72<0ZT160;J2QP3>aLT0bM;H0<[Df`35cmD0aLRl0:nWJ@39bK<0_lWB0;O5c`2KYkL0
D69`06enQ`2GWj40B;lk4000o`08ooooo`D00?l000<0D91h0:0Pl02P8?001`2P8?000`2h>;@0X23`
0:0Pl00P0:0Pl0030=1@N03XJ3`0oh0000@0oh0000<0j6Pl0=1@N02P8?00302P8?000`1@T7P00?l0
003o000>003o00_ooooo000:ooooo`1E003o002dY8P0Ffeb055NG`0G10D0;`@701l20`0L0@40GP@6
08D2102:0@@0S`4709h52`2S1`d0WPhB0:8@4P2d3Ph0_0d=0<<<2`363@/0b@h<0<X?30384Pd0VahE
0<baZ03Rgml0g]kP0=kNgP3OaL<0`e=@0<TL5@3B5A00e1D@0=0H402i6Q<0N1`C0:N@OP3MeL/0h=kJ
0>3Pg03Oh=/0g]oO0>3Mg`3Qh=l0gm_H0>3Ad@3Sd]<0h]gJ0>3Qg`3Ogml0g]oO0=cDd@2@A3`0WPd9
0:@82@2V1`T0X0H709<81`2I>2T0c:bK0=[Ad@2:DTd0P0X708X30`2Y2@T0^`X:0;/:302g1`/0[0X:
08`41@2B3Q80Q@P:09Ln>036[:X0bLG40;Zk^@2oa<@0cmSJ0<_Ce`35c]@0_<K<09>QXP26SXl0GE]M
09>9P@03003o00Wooooo00<00?l00:0Pl02P8?000P2P8?000`3XJ3`0X23`0;Ph]00@0?n000@0X23`
00<0^3Rd0?n0003oP000103oP0000`3XJ3`0X23`0:0Pl00>0:0Pl0030>QX?03oP000oh0000@0oh00
0P2P8?000`3@D7P0oh000?n000090?n000`0X23`0`00o`08ooooo`@00?l004D09]4J071eC`26OFT0
R85/09RAO02SVX<0Yib40:ZKP@2^WH<0/In20;BQPP2kY8H0]iin0;BLN02dWGL0^Yik0;bLM`30WWL0
_Ye_0;RKL01UGe00E5iG05mUGP1/K5l0]ZN@0=:mX@3C_jD0e;jV0=S2Z03Ia:X0flJ^0=W6[`3HaJh0
el:Z0=>oZ@3>_J@0c;RP0<VeW@33/9P0a[:O0=?3/P33/Z<0b[V^0;fGS02dGEL0[B<O0;8?3`2c20/0
]0P90;H82@2g1`T0]PH90;<62@2a1`X0Z0/B0:4b>@33XjL0bM3H0<KAe`34c]00`;nZ0:bUM@31akd0
^L?;0;;0c01<GFh0M8F=092IW@1W/5/04000o`08ooooo`@00?l000<0D91h0:0Pl02P8?00:02P8?00
0`2h>;@0j6Pl0?n0000:0?n000030;Ph]02P8?00X23`00X0X23`4000o`0;ooooo`002_ooool0EP00
o`00RX]O04YMG01BGel06@8302P20`0H0P801@4002010@1V10D0O@4408H21@2B0PP0X0H<0:dJ7`2[
61/0]B8T0:HE5@2f3@h0a0d=0<H>2@364@X0/a/C0:1QF03Rg=/0gmoQ0=[Jg03Hal<0]e160<<G4@3;
4P`0cA8>0<lE402/6A80LbPM0;:HR`3PfM<0g=_J0=cMf`3Mg]/0g]kK0=kGe@3H`;l0_hb90:M?B`2N
<Bd0UCPb0;BDRP3Ng]`0gMcN0>3Jf@2iTXl0RADF0:092`2W2P/0Y0P809d71`2<2`L0]FQE0<^gZ@3D
b<H0OS4[08X71P2?10H0T`830;892@2h2@P0]`T:0;D92`2E0`D0QP/>09LY:P256aX0RTa80;f_[03:
c<d0bLoA0<K?dP3;e=X0bmGL0;W3b@2MZJh0S9FH05YKGP2@QX001_<10P00o`09ooooo`03003o002P
8?00X23`00D0X23`00<0^3Rd0?n0003oP000303oP0000`3@D7P0X23`0:0Pl0020:0Pl0030>QX?03o
P000oh0000<0oh0000<0d51h0:0Pl02P8?001P2P8?00103@D7P0j6Pl0?n0003oP0040:0Pl0030;Ph
]03oP000oh0000D0oh000P2P8?000`3XJ3`0oh000?n000090?n000030=1@N02P8?00X23`00T0X23`
00<0:<Pl003o0000o`002?ooool3003o001600Oe1@1DSch0Si>50;Jg/P2<RWP0VIAo0::KQ`2TVh@0
ZI^10:bMP@2`X8H0/Ij10;BLOP2cVGP0]9Yd0;BKL`2gVg40^YY/0;jKL02nVFX0_ii/0;FHK02RSFP0
/i]j0<>UQ03:[hX0dK^M0=>nY03D_jD0el2X0=W3ZP3F`Z`0`;>Q0;ncX@3?`J/0d/2W0=2lX`3<^9l0
bKFM0<NbVP38[i/0a:ZF0<RST@2mJEd0/bDQ0;L>3P2i2`/0]`P;0;D72P2f2@X0]PX90;L:2P2f20/0
/@D80;061`2_1PP0ZPL<09TK8@2kUY/0alkC0;g5_P2n_9<0[jE;0;^hP030alL0^/C>05YYN01[OhT0
UjF[07VSKQ000?l02?ooool3003o000302S8?02P8?00X23`02L0X23`00<0^3Rd0>QX?03oP0003@3o
P0000`2h>;@0X23`0:0Pl0090:0Pl1000?l02oooool000[ooooo04800?l005^B?@14EU<0G6QW01d4
100R0P<03@4000400@0@0@40@`4207051`1l0@@0R`870:062`2[2@h0X@L<0:L?4`2J20X0[``=0<0<
30353P/0`1@=08dQ5@36ZZ@0gM_N0=oOhP3Ke=<0_81i0;HK5@333P`0a@`90<L?30315a@0NRLN0;ZR
T`3Oelh0g=cK0=_Kf`3NgN00gmgL0>CGe@2dPGh0Sc8_0:8Q7P2^5a@0X1hJ060I3P2_Vhh0g=_H0=cF
e@3B]K40UChg09/=302R2@`0XPP80:061`2I1PP0TQP>0<>7L03?`[L0bKVe07TK5`2@20T0T@D708d1
102R1PL20;H72@0B0;@81P2U2@T0O@D50;=GF`2;3A00OadN0=Nj^P3=blh0]kbn0<gEf@3<eMd0bM?L
0<WBfP2AWZ80TYfP04a?D@2>QWd05L`30P00o`09ooooo`03003o002P8?00X23`00H0X23`3P3oP004
0:0Pl0030=1@N03oP000oh0000@0oh001`2P8?000`3@D7P0oh000?n000030?n000@0X23`203oP002
0:0Pl0d0oh002`2P8?000`1@T7P00?l0003o0008ooooo`800?l004L05N4=065[B02CUXd0[;^l0<38
bP2<SH40VYR509nKR@2RW8@0Yif50:RINP2]Vgd0[i]l0;2IN@2]UW40]9Yg0;>FLP2hUf`0^9ES0;^F
HP30VfT0`Z1`0<6OL@33X7@0a:El0<RWO`3:[8H0c;:B0=6lW`3A_j@0eknY0=:o[02GTX<0[:FE0:>J
S`28Qgd0c<2Z0<noY@3=^Z40c;BN0<ZaW03@X940bGQ^0;Xo>02k4Q40_`/>0;d92`2k20`0^@L:0;@6
202c1`T0]0H:0;D82`2`1`T0[`P=0:l72`2^1PP0ZPD80:L62@2E6al0aZf^0<C<a02f[gP0YiLJ0:NK
602g]V/0_<>_06YkQ01DKW/0SIjU092:QP0@003o00Sooooo0P00o`000`0Xb3`0X23`0:0Pl00V0:0P
l0030;Ph]03oP000oh000100oh0000<0^3Rd0:0Pl02P8?00202P8?0@003o00_ooooo000:ooooo`1F
003o001APb/0G6YW05=NG@0M10@05P4100D1000100004`4203010P1>0@80K`<408@21@2O1@X0Z`P<
09D82`2J:R`0R@X;0;0?3P333``0``d:0;<P5@2BETH0g=C>0=gPh`3Sg^00dJBQ0;4f;P304@l0a@l>
0<D>30343`d0UAD@0:j;P03Pf<l0gMcH0=_Lg03Lfm`0h=cK0=>m^P2TG5X0WB@S0:HG5P2]5Q<0WAXF
06PV6`2PQgT0f]390=kIf@33Z:40TD<k09LF4P2Q2P/0X`T<0:472@2K1PL0T0D609@X702lSgX0dl[1
0;RMV@1m4Ph0S@@608/2102<0`L0U@850;08302g20X0]@L90;082@2K1PP0Q`P<08/72`255QP0`IFC
0<2j^`33aLT0_lG90<O?e`38d=X0_l[D0:Je_022TYD0FeiQ08MhK`0Eb`82003o00Wooooo00<00?l0
0:0Pl02P8?001P2P8?000`3XJ3`0oh000?n0000:0?n000050=1@N02P8?00X23`0:0Pl03@D7P01P3o
P0000`2h>;@0X23`0:0Pl0040:0Pl0030>QX?03oP000oh000080oh0000<0j6Pl0:0Pl02P8?000P2P
8?080?n000<0X23`3@3oP00;0:0Pl003052@N000o`000?l000Sooooo0P00o`00B01=R3P0R8Z20:fh
_P1UNh40am3D08jBRP2DUHH0WIV709nGQ02VV8D0YYMk0:ZINP2WU7<0[IUh0:jJM02`VGD0/iMd0;BD
I`2gU640^YEO0;jKI`33XW@0a:5f0<:PMP35YWd0b:V20<f_S@3=/I40ckVK0=>nY@3F`JT0]:BF08V7
P@2e/:<0[ZVN06edKP2k]J@0dKnW0=2mYP3@]Z80e9N90<0j=0326A<0aA4>0<<<2`2n2PX0^PX:0;X9
2P2f20T0[P/<0:@D5P2M:Rl0SSE007diB01i>TX0QcQ409HW;@2O2a00Z0H90:85302I@4@0b<W:0<C:
a`2]XE00ZYP80:jO2P2`Xbl0THi>06QfL@26U9L0Ui>B01KO30l00?l02?ooool2003o02P0X23`00<0
d51h0?n0003oP0002@3oP0040=1@N0@0oh0000<0j6Pl0:0Pl02P8?00202P8?000`1@T7P00?l0003o
000=003o00_ooooo000:ooooo`1F003o001MSC80JWId06Y`L`0M1PL03P4100D20@010@404`8302P1
0@0_0@40A`4207X21@2K10X0Y`H<09l<3P2YADH0YQ`K0;`<3@3330X0`a0;0:U1=03E_kH0gmoP0=oO
hP3AYJ@0/3@^0;dE40323Pl0bA8@0<LA302a5@l0UU]<0=O@aP3If]L0fm_K0=cKf@3FdL/0VXf2080h
;`2Q61D0ZQHF0:@I6`1o6QH0ICX]0;j`XP3Pf]80hM_H0<NSW`2A;BL0U`h=09l;3P2Q2Pd0WPP:09l8
2@2K20T0T@T609m4<`2jWX`0e/o:09Y]I`222PP0S`@708h21@2:0PD0R08309820`2_2@/0/`P:0;@9
1`2]2PL0T@<308D71`1l3@h0PSXk0<F_[P2k^k`0`LG90<_@e039d=H0`lcD09j]/P2FYZX0FEeN07e[
G00Gc082003o00Wooooo00<00?l00:0Pl02P8?001P2P8?000`2h>;@0oh000?n0000:0?n000<0X23`
00<0^3Rd0?n0003oP000103oP0000`3@D7P0X23`0:0Pl0040:0Pl0030=1@N03oP000oh000080oh00
00D0^3Rd0:0Pl02P8?00X23`0;Ph]0090?n00080X23`00<0d51h0?n0003oP000303oP00:0:0Pl003
052@N000o`000?l000Sooooo04X00?l0023>5`1hOG40[;Nj0;K3bP2lbM00bm;G09NKUP2DTX@0W9F7
09nEQ02QTh00XiIo0:FEN`2WUGT0[IIg0:^EKP2[Ufh0/YQd0;:BJP2bTel0]iEP0;fJJ031XG<0aZ=k
0<BUOP35Ygl0b:R10<^_SP3</i@0d[ZO0=:lX`3E`:P0_J^M06m`K`1jPGd0KgYd06IbJ@35_JX0e<6^
0=Ro[@3FSH80`BPW0<XB4@383P`0bPl=0<T>3P302``0^@/;0;4A4P2T;c@0Md1B04DmFP0i@fH0BE5`
061XP@1/Ni@0BfB606IcS@2:Gfh0V1lX0:872`2E3100]I>F0<;=d02d/7l0NF`G09F;3P2^X0L0WY0B
05ML@@1jRHl0X:2P027J5`l00?l02?ooool00`00o`00D91h0:0Pl00V0:0Pl0030>QX?03oP000oh00
00L0oh0000<0d51h0:0Pl02P8?001@2P8?001@2h>;@0oh000?n0003oP000^3Rd00T0X23`00<0D91h
003o0000o`003@00o`0;ooooo`002_ooool0EP00o`00J9U107b:T01/NX<05PH700h10@070@400@41
01810@0/0@80;`0203H10@1/0`P0V0D:0:P83@2Z2Ph0Ya8D0;P@3`3130/0a@h<0;dC3@2gLfH0h=[D
0=_NgP3Id=80Zde80;LC4@2o4Pl0`Q8@0<L@3`354`h0UQdD0=Bj[@3KfMD0emOF0=gLg@3KfmT0gm[C
0<Nj[@1g?S40YAlK09@P7@1N5Q80E3DZ0<fo/P3Sg]P0gm_I0=:e]@2C<Bd0XQ8?0:@<3P2S2Ph0W`P<
09l92@2J10H0W@L909<91P2YG4X0c;N[0=G>b`22B400P`D508X1102=0PL0RP8408P20`270040X0H8
0:d61`2_1PH0[`L809X30`221PD0Q1HG06lE5P2XPh40b/c=0;c0``38bm40bm;H0;_6cP2ja/d0Q9>H
06]_L@1oKEl06<`20P00o`09ooooo`03003o002P8?00X23`00H0X23`00<0d51h0?n0003oP0002@3o
P000103@D7P0X23`0:0Pl02P8?070?n000L0X23`00@0d51h0?n0003oP000oh001@2P8?090?n00004
0=1@N02P8?00X23`0=1@N0h0oh002P2P8?000`1@T7P00?l0003o0008ooooo`1:003o001EQ4L0Y:n`
0;G3c02nc]L0]lW@0<KCf02MXj00Shn309NCQ`2PUhX0XI>20:>CO@2SU7X0Y95g0:^AM@2/U780[IE^
0:bBJP2_TF40/iAQ0;JFI@2mWF/0aJIk0<JWP`36Z8L0aZ^:0<^^S`3;/YD0bkJI0<njW`3A^j80eL:Z
0=O3[P2[Wi40Ti6609fLSP2k/Z40e<Fc0=No/03FSH@0aRTV0=0C503?4A80c@l?0<d@403;3A00^a4A
0:Tf>@1_Ael0<CaQ04eKM`2?UYh0[K2b0:R]/P2CWJT0NhjR03]GMP2J^<L0am7J0;^KXP2F8BL0W@P<
08@g?`2l`/X0/Zmf08Ab501[H@h0Q80>0:2D2P2@RS40QY1l09RNV`0ka2`?003o00Sooooo00<00?l0
0:0Pl02P8?009@2P8?000`3XJ3`0oh000?n000050?n000030>QX?02h>;@0X23`00T0X23`00@0^3Rd
0?n0003oP000d51h2@2P8?000`1@T7P00?l0003o000=003o00_ooooo000:ooooo`1F003o001/WTX0
QiJO07N6T@0<0`@0304100L10P010@405`8203<20`0c0@80=@410581102>1Ph0Y0H;0:d93@2_2@`0
^@/=0;d<3@3330d0]b8J0=^dZ03Mg]/0g=kO0<bYZ02V8a`0XQ8@07T=2`213@`0_A@B0;LP5`2PF4X0
g=?<0=SIeP3JemH0g/o?0=g8a03Qf=@0h]_F0<2VW@1Z9al0HSP[09>0L@3?a;P0i=kI0>?Fe02jV9H0
UD4n09hF4P2V3P`0YP`>0:<93@2Q2PX0X@P80:062@2M1`X0TP/70;UlJ@3Ic/D0clG107L[90241080
R@8408/31P2:0P@0R@8408D20P2>0P<0Y`H70;LE502^1`T0Z@/908TD4`2[E5H0KA`M0:9dL02e];<0
`<K90<C;d033bm@0bM?N0;?1b@2N[K@0JW1d08=dJP0Gc0@2003o00Wooooo00<00?l00:0Pl02P8?00
1P2P8?0<0?n000040=1@N02P8?00X23`0;Ph]0H0oh0000<0j6Pl0:0Pl02P8?001P2P8?020=1@N0D0
X23`00<0j6Pl0?n0003oP0001`3oP000103@D7P0X23`0:0Pl03XJ3`>0?n000030=1@N02P8?00X23`
00L0X23`00<0D91h003o0000o`002?ooool0BP0?k@/0V9jI0;C2b@2faLh0X;Bm09J//`2a`/P0YJb^
08j?Q@2GU8T0W9J909jDQ@2PU840XYIo0:FGO`2VU7T0[IEe0:fCK`2/TFT0[hmR0;BDH`2gUFD0_Ia]
0<:SNP33ZHL0aJ^?0<R^TP3;]9L0c;FK0<fiWP3@_:00dKfS0=G1Z@3G`jh0f/N`0=W8]P3Gb;P0elNe
0=O3]03IUhd0a2XT0<lD4@3@4Q40cA0@0<d@3`3840l0^bX^08A<HP0c@VX0F6f:09bPXP3<a/40aKNf
0;bRX`2aTY<0]IVE0:NPXP1lSJ00IXFP0;g@fP3<d]P0[G^209<=4`2:6R00WIVQ0;>_O02YU1D0TGl:
05eG2`1eLPd0WY8:09bD8`2KV6/0E;]23`00o`08ooooo`0302S8?02P8?00X23`02@0X23`00<0j6Pl
0?n0003oP0001@3oP0000`3@D7P0X23`0:0Pl00;0:0Pl0030;Ph]03oP000oh0000T0X23`00<0N5Rd
003o0000o`003@00o`0;ooooo`002_ooool0EP00o`00L:=?09BVZ`1`PhX01`<400T10@040@400P00
01T20P0e0@80=`8103X20P160P<0M`H:09h93@2Y20`0[@P:0;H:2`2n3Pd0`@l;0<15>P3Nc<D0g^?R
0>3Lg@2^FeP0Ma0=04/M601TDDD0PDm40:@Q5035JED0b;2R0=WHeP3Kb<L0aHB00;i7@P2e=Bl0`Y6:
0>;LeP3Of=<0YYV:0=K>_`3ThM/0h^;P0<C8aP1iH5d0GBHS05LF4`1M4a00LQ0@090B4`2L30`0X@P8
0:47202P1PT0W0H909HI4P38Wi00fmC@0<2]Z@1j5a<0RP<408L10P270P<0Q`8408H11@260@<0Q@82
09h6202]1PP0/0D70:X;3@2Z>Ch0OQ<D08hT8`1h:bT0a[Vi0;c1``30bld0`LcB0<C@f@2iam80U:B]
071lPP1mN7805L`50P00o`09ooooo`03003o002P8?00X23`00H0X23`303oP0030:0Pl0050>QX?03o
P000d51h0:0Pl03@D7P00P3oP0030:0Pl0040=1@N03oP000oh000=1@N0P0X23`0`3@D7P80?n00003
0;Ph]02P8?00X23`00l0oh0000<0j6Pl0:0Pl02P8?001`2P8?000`1@T7P00?l0003o0008ooooo`1:
04?@>@2ja/d0/lCA09Z_^`1hTid0QIfS0;g;dP2^]KX0S8j709ZHS02LUXT0WYJ60::HQP2RV8@0X9=m
0::CN@2ZU7L0[95^0:nAJ02`T6<0]9=U0;NEJP2mWGD0a:J30<:XS034[900ak6D0<VcV@3;]YX0b[NK
0=2lX@3D_ZH0e[nY0=O2[03JaZl0elNb0=K6/@3Ga;00gZnR0<Di<P3D6180daH?0<hA3`355180^R4P
0:]7DP1BCWP0@EQn096BV02cYY/0^YJ<0;9WHP2]=C@0ZQPL0:@>4@2S4aD0XS4c0:MmP@1[NY00_LoJ
0<WBf@3;`/P0SRTb08h>5@21M800_<K40:jVI@2VU@l0X94;06YQ1`2CRP`0VHl80:NJ901hZ40?003o
00Sooooo00<0D91h0:0Pl02P8?008`2P8?000`3@D7P0oh000?n000040?n000030>QX?02h>;@0X23`
0080X23`00<0^3Rd0=1@N03oP000103oP0000`2h>;@0X23`0:0Pl0020:0Pl080oh002P2P8?0?003o
00_ooooo000:ooooo`1F003o001]XT`0RYfQ06UhP0080`@00`4100400@010@406@8103/20P0o0P80
?`8304P1101R0PH0Q0D<09l73@2/1`/0/`X:0;`;2`2o40h0afIL0>;He`3Ph><0eKZi090X8023EDP0
`[FX0=;<``3Lb;h0Y5Y50<bKR03KdLP0fMKB09QYHP2@9b40QAXD05PD3@1VCd80clJk0>;OfP3Ng=H0
gmgK0<_>c@22RX@0B59906]TFP28O6l0Rgmb07]`I01DAS`0<a4>068>3`2I30d0X@T:0:871P2N20L0
X3DU0<bbX@3Hd]40Zhb8084>2`2<10D0RP<408D10P250@<0Q04508@20`230@80S`<40:/8202^1`P0
[0H70:H93@2C4Q<0TA`K07hR8030Z:P0/;Bf0<O?d`33c]D0a<kG0;_5d02@X:P0M86607A`JP0Fc@L2
003o00Wooooo00<00?l00:0Pl02P8?001P2P8?0<0?n000<0X23`00<0oh000;Ph]02P8?000P2P8?00
1@3XJ3`0d51h0:0Pl02P8?00d51h0080oh0000<0d51h0;Ph]02P8?002`2P8?000`3@D7P0j6Pl0?n0
00040?n000<0X23`403oP0090:0Pl003052@N000o`000?l000Sooooo01`0C/e90;G2c@2Q]L@0JHB@
04QVK02L/KL0_/kE0;Fo``2<SXP0UYF:09VDR@2KTHD0X9F40:>FP`2RTgl0XI5i0:RCMP2ZT6h0[HmT
0;6@J02bU6/0]9I[0;bON@2oX7l0aZR<0<N/T`34[I<0bkFL0P3<]il0;03?_:<0d[jU0=G0Z@3F`J/0
el>[0=W6[`3Hb;40h<Ba0<]PE`3?6QD0eAP@0=@E403271H0YE5M06EEN@0bBGP0MXVO0;>ZW`30WHh0
]eiG0:hP802e30h0^PP;0;H62@2`1@H0/@H70;072@2P5Q/0KDmU08>M/@37dMX0c=3I09aLI@2>31@0
LEAR0;C7d032b<00Zj970:^L1`2RT`D0TH8<06]W1P2JTP`0N:PA3`00o`08ooooo`03052@N02P8?00
X23`0280X23`00<0^3Rd0?n0003oP0000`3oP0000`3XJ3`0X23`0:0Pl0020:0Pl0030;Ph]03XJ3`0
oh0000L0oh0000L0^3Rd0:0Pl02P8?00X23`0=1@N03oP000d51h00T0X23`3`00o`0;ooooo`002_oo
ool0@000o`00KZ9<08^NX`1AGVD02@840080000000000P0002830`0k0P<0?@4103l10@1=0PH0H@8:
06d01P2D1``0[0P<0;@82P2l2PX0_a4>0<UeK03Ug]h0h^7R0;fDT@2=<240ckBW0=GAc03Ce]@0f<_6
0:EZF@3C/J80gMOC0=3;aP0j;B<07P`302PJ3`1nM6D0bKn_0=gGc03Ng]T0g=cH09^QU`1HGU40Wj6C
0<k7^@3Kcl@0h=G=0=kEcP3Md//0bkjb0:bNT`1:91l0Ra0D0:8;3@2S2PL0WPX80:Q??@3<_K00eM3?
0:=iMP2830`0S`<709052@270@@208810`0D084100240P@0R@430:<62@2Z10H0[0H60:h92`2D1`P0
QPh>07DF5`3;[k<0`lG80;g6b@2iaLT0aM;I0;K6cP2S];/0MH>7071]J00FcPP2003o00Wooooo00<0
0?l00:0Pl02P8?001@2P8?000`3@D7P0oh000?n0000:0?n00080X23`00<0d51h0?n0002P8?000`2P
8?000`3@D7P0X23`0:0Pl00C0:0Pl0030=1@N03oP000oh0000<0oh000P2P8?000`3@D7P0oh000?n0
000>0?n000T0X23`00<0D91h003o0000o`002?ooool0BP2=Tfl0/L;=07VBX00oGFH0Dg1g08BLY02K
/KH0_LW<08V?R`2EUH`0VIJ;09^EQ`2MUXD0XI>30:>CO`2TU7`0YiAg0:NAKP2YT6P0/91W0;6DK@2h
VgH0^Iel0;fQP`35ZX`0ajfC0<B]U039/i/0c;JN0<ngW`3@_:@0d;nW0=C2[03F`jd0f<F^0=W8/@3J
akD0g9Z@0<LW803F6A80e1L?0<LV802GG6d0<Tag05UcT`2NXJL0`k2S0<NDQ`2d?CL0]a0?0;/:2`2h
1`X0^PH;0;L72P2a1@T0/PH:0;85202[1`X0TTAD05=[RP31dmd0am?K0:V3R`2<3QL0ID5A0;?8d`32
cm@0_;bD0;6S<02WUPD0WHh6069L201TH`P0UhD>3`00o`08ooooobD0X23`00<0j6Pl0?n0003oP000
0P3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030;Ph]03oP000oh0000P0oh0000L0d51h0:0Pl02P8?00
X23`0=1@N03oP000d51h00T0X23`3`00o`0;ooooo`002_ooool0EP00o`00III105e/K`1AGF001082
00810@0000000`0002420`0d0P<0<@4103D10@1:0PD0GP<806D3202010T0Z`T<0;L92P2n2`/0_14<
0<b0M@3ShN40h^?U08UlM02:JEd0h=SD0=gLg@3KfMT0e:^Z0;AKCP3K]JP0gMWE0=SCd@2VVi40WYB6
0;V]W`3Bb/40g=[C0=cMeP3MgMX0cLNn0:fYUP3Fe<@0g]cB0=kKeP3Ng=X0gmgL0=cJfP3Mfm`0gMWI
0=W@b`2[UXl0NAPF09`;2`2M20L0V0d90;E`G@3Bb/80em7@09APG02=30`0TP@809431P2=0`H0Q@44
08H21P230@@0QP8508D21`2I1PT0[0L80:l61`2]1PP0XPP;08/72P213Q40Qd=50;Zd]038cm<0_/S=
0<7=e@2ham00UjR_07b:S`1aKVT05lh90P00o`09ooooo`03003o002P8?00X23`00D0X23`00<0^3Rd
0?n0003oP0002@3oP0001@3@D7P0X23`0:0Pl02P8?00^3Rd00<0X23`00<0^3Rd0?n0002P8?005@2P
8?040?n000040=1@N02P8?00X23`0=1@N100oh0000<0j6Pl0:0Pl02P8?001P2P8?000`1@T7P00?l0
003o0008ooooo`1;09f?NP2GZKT0AfId04]ZL`1QOX@0Wk>k08:IX034cmD0Ri6@09:CS@2JUXl0VI>7
09bFQ@2NTh00X99k0:>EO02UUGX0Yi9a0:jBL02`U6d0/IE_0;RMN`2iXH80_ZN;0<>ZSP35[Y@0aZfC
0<N_U@38/YX0cKNM0=2jX`3B_ZL0dl:Y0=G3[@3FaK40elJ^0>6n[@37CTD0e1`E0=<F4`369b80Sf1h
03EDPP2MY:`0`;BV0<F_W`3<T8@0^2`Y0;/<3@2l2@`0^PT<0;@92P2/4140YRL]09P`=`2S5ad0[`H:
0:d62P28<T<0?ef30:c6e037dm/0/I>N08X@6P1N=dT0/LSF0;g;eP32cm40^;B30:RJ7@2RT`@0W908
07a`2@2>PA008MT400h00?l02?oooolT0:0Pl0030;Ph]03oP000oh000080oh0000<0^3Rd0:0Pl02P
8?000P2P8?000`3XJ3`0oh000?n000090?n000030=1@N02P8?00X23`0080X23`00<0oh000=1@N02P
8?00202P8?000`1@T7P00?l0003o000<003o00_ooooo000:ooooo`05003o001BPbP0LH1l05EVIP01
0P800P010@40>`030@406P8102`10P0a0@40=`8203l10@1:0@<0E00207021`2N2@`0^@/<0;l<2P2n
4@h0bGE^0=ODe03EemT0];B^0;Zg/P3De]H0fM?D0<jYYP2`>cH0]R8J0<aeJ`3O`[l0gMKF0=gFe`3P
emL0h=?A0<o0`02c[Z@0e]790=oMfP3Lem80iN?N0>GWh`3Qh^00g=cK0=gMg@3MgM`0g=[J0=gJg03K
f]`0e]KE0=[Ed@2QHe`0U0h<09X72@2G5@l0`I1m0=SBc@3Gd</0Rdi508`81`2F1PT0T`8708l21P27
0P<0Q@830080QP830180P`<708T2102V2@X0[0H70:h62@2Y2P`0T@T<09`Y:@228b<0`jn`0;Ro`@2c
_/80_/_B0;W8d`2__lL0O8jC07=aKP0Hc`X2003o00Wooooo00<00?l00:0Pl02P8?001P2P8?000`3X
J3`0oh000?n000080?n000030>QX?02P8?00X23`00@0X23`00D0^3Rd0?n0003oP000oh000;Ph]00D
0:0Pl0050=1@N03oP000oh000?n0003@D7P00P2P8?000`3@D7P0oh000?n0000?0?n000P0X23`00<0
D91h003o0000o`002?ooool0B`2JR740SZ6^03iNJ01;Jfh0KXZ@08fT[@2G[K@0`m7F08ZBT@2BU8h0
ViJ?09ZAR02LUXH0W9B209fBOP2RUWd0XY=i0:NCMP2^U7L0/YUi0;:IMP2gX7`0_JJ70;VTRP35[i@0
`ZbA0<N^T`3:/YL0c;JN0<beW03?^J@0d;jX0=;0Y`3C`:`0eL>_0=S4[03Q[9/0`bPN0=PJ403<6A@0
/UaW02U8N@2BXK40`[BU0<BaWP3?YYH0]STe0<@A4P2m2@`0^PT<0;<<3@2P8B<0TEIW044kH00Q9Dd0
S3]90:`63@2V2@X0MC]=045US`1ZRjH0aMCK0;2DW`283aT0GCA80;37e`2ha/l0`]3G0;Zm/02/Y5h0
Wi<I09f=0`2TU@T0TH0:046b1`0>003o00Sooooo902P8?001@3@D7P0oh000?n0003oP000d51h00@0
X23`00<0d51h0?n0003oP000103oP000103@D7P0X23`0:0Pl03@D7P20?n000030=1@N02P8?00X23`
0080X23`00<0oh000=1@N02P8?002@2P8?0>003o00_ooooo000:ooooo`1F003o001@Ob40Be]E04MG
E`000@400P410041000200406@<102820@0/0P80?@8304010@1>0@@0G@4507@42@2;1@T0/Pd>0;h;
2`323@/0_SLd0=jh^03Mf=T0f]SG0=?<b`3:YjP0]V9Q0;4X9P2n40h0aA4@0;hG5@2o?S/0cWYh0<]m
O@36K6/0^4m>07Td;`2l[Z40hMcF0=kMf`3QhN40iNKW0>GVj03Rh^@0g=gM0=cMgP3NgMd0fm_K0=[I
f`3IfMX0fMSJ0=SGf02iThd0TA8A09d<3P2N:al0bZ^L0=WDe03Jc</0Qd8k0909202F1PT0T08608h2
1@260@<0QP<308<20P240P<0Q@<508@1102D10D0Y`L60:`72`2/20`0Z0/?09P83@2A6aP0XG]h0;:f
^02ka/T0^lS?0;k=eP2EYZl0QIFJ07=^JP0Jd@/2003o00Wooooo00<00?l00:0Pl02P8?001`2P8?00
0`3@D7P0oh000?n000080?n000060;Ph]02P8?00X23`0:0Pl02h>;@0d51h1@3oP0001@3XJ3`0d51h
0?n0003oP000j6Pl00l0X23`00@0^3Rd0?n0003oP000oh000`2P8?000`3@D7P0oh000?n0000?0?n0
00030;Ph]02P8?00X23`00D0X23`00<0D91h003o0000o`002?ooool0B`2SRV/0RYVT04m[LP1UPXH0
OIVP07fIX@1kUYd0^lcA092JV02CU8h0UI>:09NAQ02IU8@0ViB409jFP`2SVHH0XIIn0:NFO@2_VG`0
/9Qg0;BMO@2kXX<0^jJ70;bYS@34[Y<0aZnE0<N`U037/YL0bKBL0<ZdW@3>^:40ck^U0=2mYP3B`JX0
eL>/0=W3[@3EQGT0cb0K0=LL5031?C/0EEMm06Z7YP32^K00bKBU0=>]X@31J5l0_ALE0<H?3`2m2Pd0
]Q0?0:4oA@1CAFH0;d9]06YhU02GRYP0X3Dj0:d82`2P82D0AcYI076=Z`1mV[80a=CN0:n=VP293QL0
FCA:0:S2dP2jb]80_lkF0<;=d`2k`[X0ZJQf09F<702RT`T0UHH:03?9200>003o00Sooooo902P8?04
0?n000D0X23`00<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0^3Rd0:0Pl0020:0Pl0<0oh0000L0^3Rd
0:0Pl02P8?00X23`0=1@N03oP000d51h00X0X23`3P00o`0;ooooo`002_ooool0EP00o`00DX0P06Ue
L018EeL0004200810@010@000P0101P20@0I00007`0003L31@100@40E`4606h52P1h0`L0Q0D90:D9
2`2l30/0`@`;0;lB3P33DE00i:Z[0=6UY02gMW<0YB`Y0;<C4P2m3P/0`Ph;0<H@3@3640`0aa@@0<DH
5P315aP0`a/I09dJ5P29Ge40gMG>0=kJfP3RhN00hn?U0>KVj03UiNL0i>CV0=kMg@3MfmX0gm[H0=kJ
f@3KfMT0fmOG0=[He`3Ie]L0^IJB094D4@2G2PP0Y48a0<^hZ`3Ddm@0flg908Pm=`2@1`T0T@<908d3
202:0P@0R@<308P20`270@80Q00208@10`240@D0R0020:@72@2]20T0[`T=0:h:3P2K20/0Q`l>0:9`
L03=bld0Z;>e0;g;dP2fa]00^<SB07f=T`1fM7409[P>0P00o`09ooooo`03003o002P8?00X23`00P0
X23`303oP0000`2P8?00d51h0?n0000:0?n000030=1@N02P8?00X23`00h0X23`0`3oP0030:0Pl003
0=1@N03oP000oh0000l0oh0000<0d51h0:0Pl02P8?001@2P8?000`1@T7P00?l0003o0008ooooo`0O
082^F02AWJ<0I7j407B>U@1RP8P0Qj>Z08RQZ@2]_L80V::S08jAR`2AT8X0TXn309FBP`2JU8@0W9N5
0:2IQP2UVH@0ZiV10;6JOP2bWGh0]9n40;^RQ`2iYHL0_JR;0<F^U@34[940a:nB0<J`UP37/YX0b[NM
0<ZjW`020<jlY00Z0=70Z`3E`jd0fl2Z0<UDBP3E71D0bRPS08AQO01CLIL0`k^f0<fjZ`3?[Ih0_6QQ
0;HP7P374100`Ph@0;T=402e51D0SdEB06maPP2]YjD0^I:>0:M0?`2W30d0WalS05e1GP0cDWh0FGZF
055eS@2icmh0YGn908L?5@1G>Th0ZlGC0;[7dP2kbmD0^l[C0;:na`2c_/<0QI>009fPG02DRaL0NHT?
3P00o`08ooooob@0X23`0`3oP0001@2h>;@0X23`0:0Pl02P8?00^3Rd00H0oh0000D0j6Pl0:0Pl02P
8?00^3Rd0>QX?0020?n000030;Ph]02P8?00X23`0080X23`00<0d51h0?n0003@D7P02P2P8?0>003o
00_ooooo000:ooooo`13003o001BPR40DV5K04UHE`010P400`81004000030@40704202l20`0e0@80
@@8505<31@1X10P0K`X=07@72`221PX0V@L70;L>2`313@X0aPl<0<@F4P2i7Q`0/24N0:hF4`2i3`h0
`Pl=0<<>2`353``0aA0=0<@?30364@h0aa4>0;lE4P2M5QD0KbhV0<Vi/03Nf]T0gMcM0>CTi03TiNL0
iNGW0>OSiP3Zg]l0gKRg0<>3PP2`JFT0[Fm_0=>l^03If=H0e]GF0=WEe`2/PGd0TA8>09L>2`2XDd80
c/:g0=;Cd`3Fb/L0RT<k09882@2D10T0R`8608X21`290P@0R08508L1100208H21@0A08D21P220P<0
V`P80:d82@2^20`0[`X?0:`J70232``0TE5B0<S3a02g`/<0_L[C0<3?fP2S/k`0QYJM07=_K`0dXA<0
0P00o`09ooooo`03003o002P8?00X23`00H0X23`00<0d51h0?n0003oP0005`3oP0000`3XJ3`0X23`
0:0Pl0060:0Pl0@0d51h102P8?00103@D7P0oh000?n0003XJ3`30:0Pl0030=1@N03oP000oh0000l0
oh0000<0d51h0:0Pl02P8?001@2P8?000`1@T7P00?l0003o0008ooooo`1<06Ve?02EXJ40N8jI06^8
TP1mV9h0NiJO08^SZ`30c]@0VZ:S08B7PP2;RX40TY:409FCQ@2LUXL0X9V:0:2JR02WW8T0Zi^60;6M
Q02cWhD0]j260;RQR@2jY8P0_:N;0<2[TP31[980`ZbB0<N^V036/YX0b;NN0<^iX@3>^j@0dKjV0=C0
Z@3Fa:d0hK^Y0<8d:`3C7QD0^EQQ04iHPP2iR980bWM_0=FVV@3;RX00Zb@Q0<HE5@2o61L0Wd9=08=6
EP2X;2l0ZaLF0<5eJ02cJ5d0Yb<P0:H?302F;cD0B3YL03QDO02:VZX0VJZh09Fa`P2X`=00Vfeg08P>
5P1D@5D0/LSG0;g9e02mbmL0_<gG0;;0bP2^_/X0Gg9m07f9N@2BU4h0VhdO02;K1@d00?l02?ooool0
0`1hF;@0X23`0:0Pl00P0:0Pl0050=1@N03oP000oh000>QX?02P8?000P3@D7P00`2h>;@0d51h0?n0
00020?n000040>QX?03@D7P0oh000?n00080j6Pl0P3oP0000`3XJ3`0^3Rd0:0Pl0040:0Pl0030=1@
N03oP000^3Rd00X0X23`00<0D91h003o0000o`002`00o`0;ooooo`002_ooool0EP00o`00B7HE03a:
@`18EEL00P4100<20@0000001@4002820P0m0P@0BP8405D21@1V1@P0M`dA0:Ld=`2151L0O0@90904
1P2Y20T0`0d;0<L>2@3940d0```:0;X:202g2PX0^P/:0;/<2P2k2@P0`@d:0<8=3@323Pl0`a0?0<8B
4P295@h0Kd4f0;j]Y03Lf=L0fm_L0=kNgP3ThnD0jnCV0>g7b03STiH0f5iN0<HZ9@2o71T0Z18A09lI
5`2WLVT0f=OD0=?FeP3Gc/h0TDM209T@3P2C40/0ZVMF0=7:a03@cm80f<g>08Y;A02>20P0TP@808`2
1P2;0`T0R@8608P110270PD0Q`8608P31@220PD0PP@709041P2^2@d0[@P<0;0:3P2/3@h0R@/<09IK
E02c[JP0WZRY0;G4b`2lcMH0[[o:086AV@1hMGH0=Z<G0P00o`09ooooo`03003o002P8?00X23`00D0
X23`00<0^3Rd0?n0003oP0005`3oP0000`3@D7P0X23`0:0Pl0030:0Pl0030;Ph]03@D7P0oh0000D0
oh0000D0d51h0:0Pl02P8?00X23`0>QX?0020?n000050=1@N02P8?00X23`0:0Pl03@D7P04@3oP000
0`3@D7P0X23`0:0Pl0050:0Pl003052@N000o`000?l000Sooooo04`0Dl</09RQWP2<XZd0J8J?06V6
S`1cSYD0PIfU0:>f_02RZ:/0OX1k08V9P@2ASX80ViN909bHRP2RVh`0Yin@0:fRU02cXYH0]Z>?0;NQ
RP2jXX/0^:::0;RTRP2lYhd0`ZjE0<:^UP34[ID0ajjI0<NbW038]9l0c;NQ0<jjX`3A_jX0dKn[0=G3
[`3P/Z40`BPP0<TU802UK7h0/EU[0<LN8@386aP0^eeL0;Q_L02d7ah0aA<C0;/nA011@6H0P82@0<>1
O@2/5140]10A0:h@402T8b@0MSa?02H_F@1FMI00[[k6096PZ@1lTJ00@F1k09R``@2BF6<0RPlG05A9
GP2ecM/0_LcI0<3<f@2oc=P0^LOC0:c0c01eT:D0KXNC09fWV@2HTUP0>M4L3@00o`08ooooo`03052@
N02P8?00X23`0200X23`00D0d51h0?n0003oP000d51h0>QX?0020?n00080j6Pl0`3oP0020:0Pl003
0=1@N03oP000oh000080oh0000<0d51h0:0Pl02P8?001@2P8?000`3@D7P0oh000:0Pl00:0:0Pl003
052@N000o`000?l000/00?l02oooool000[ooooo05H00?l0045^301DHEP0CEUK00@20P050P800`40
01010@0`0P@0A`8504/11@1>0@@0F0<608892`2L20X0R`T:07H51`2>1@P0V@<60;<:2P323@T0aPl;
0<H?30313P/0^@T90;T;2P2h2PP0_0/;0<4=2`323Pd0`@h=0<4@402L5180QemC0<c4^@3Lf=H0f][K
0=cMg@3Rg]d0jLg=0=YoP`3B=cH0ealM0=`N6`3C6aD0cAXF0;PG50256QD0Uh1d0=OHe@3Ce=@0]YNE
08`L6P2I3P/0S14:0;5iJP3Ed<`0d=3B0=KAd@2>HU`0QP/:09021@2>0`D0R`<708/21P250@<0P`43
08811@250PD0R0<708P3202;0PL0Z0P<0;482`2c2`h0/0`=08d<302UNG40U9B;08ZET@2haL/0]<C<
0;S7c`26UYd0Kf]/03RU6@800?l02Oooool00`00o`00X23`0:0Pl0050:0Pl0030>QX?03oP000oh00
01H0oh0000<0^3Rd0:0Pl02P8?000`2P8?000`2h>;@0oh000?n000060?n000040;Ph]02P8?00X23`
0;Ph]0<0oh0000D0d51h0:0Pl02P8?00X23`0=1@N00A0?n000030=1@N02P8?00X23`00D0X23`00<0
D91h003o0000o`002?ooool0@`17aQh0UiZC082GXP1eTYh0EWQm06>0P`2=YJ`0QIVQ0:Nb]@1iOGT0
QHEn08f<PP2MV8h0YIjD0:^TV02_YYX0/jNJ0;FWV@2aXHl0/in;0;JQRP2hY8X0^ZJ=0;ZVS02mZ980
`:VC0<>[U035[iP0ak6J0<RdW@3<^J@0ckbV0<noZ@3A`:d0eLB^0>2iY@2n<BL0cR`Y0=MeO@3592D0
dQLF0<0S801jE6/0SGR:0:Po?P2h6aX0_A/O0;I2B02f@3d0/24M0;H>3P2d30`0UCHh03ddD@0jAVh0
OgR40:BDSP35`L00^L3309j`^P1jUZ/0PYV]08]7D02;4aX0EDmW0;K>f`2lbmH00P2nc]P01`2kcMX0
[l;?07:;W01gTYl0UjBW09RLUP1AZT<03@00o`08ooooo`03052@N02P8?00X23`0200X23`00<0d51h
0?n0003oP000103oP0020;Ph]0P0oh0000<0j6Pl0:0Pl02P8?001`2P8?000`3@D7P0oh000:0Pl00:
0:0Pl00307QH]000o`000?l000/00?l02oooool000[ooooo05H00?l004Ac4`1LJF<0BEMH00<10@07
0@402P0001l10`0o0`H0A`4404H310120@<0BP8408H:402E2Pd0M0D706/3102;10H0TP850:@51P2l
30T0`0/90<@=2`323P/0^@X80;X<2`2k2@P0``d>0<<=30323@`0_`/:0;HA401f9b00bKje0=SHeP3J
f]/0f]WK0>?JfP3O];<0be]K0=HW9@3N7aX0eAD?0=<F4P3@5a@0aQTF09dJ5`1R;R<0b<:h0=KFe03:
_;`0T4U809H@3P2H30X0Q0l50;J6M`3Ed]00d=7C0=?Dd`2>Mg<0N0h@0944202?0`D0RP8408D10P22
0@<0OP0307h110230PH0R@<908/42P290`L0X@L<0:h82`2b2P`0]0d=09d;3P2>AT80Xi><09:HU@2X
]kX0_/cE0;2maP2?X:H0MWIg03ZX7P800?l02Oooool00`00o`00X23`0:0Pl0050:0Pl1P0oh0000<0
d51h0:0Pl02P8?00102P8?080?n000050=1@N02P8?00X23`0:0Pl03@D7P00`3oP0000`3@D7P0X23`
0:0Pl0020:0Pl140oh0000<0d51h0:0Pl02P8?001@2P8?000`1@T7P00?l0003o0008ooooo`1<02KK
3@2GTXD0Ujbf05YgP01OOH<0FgUn05]eO@1jSI40/;Vl07IiM`21PGX0S8Uo09RDRP2TWiP0[JNP0:bS
V@2`YIH0[J>A0;:UT@2aX8`0/in70;VTR`2jYH`0_jN?0<6[U031ZYD0`j^D0<B^V036[iP0b[BM0<Vh
X03;^Z40c[jT0=;1Z@3B`:L0f<>_0=9kK`38:R40c2LT0<PS7@32@d40R6=l03MHQ02`/k<0d;:T0<>2
M@2gA3h0/S@d0:Pk?P2G@d/0/SXk0:/>3P2HBeL0Q49E0:Tk@`2Q7R40XAhS0:0k@@2TMgP0PhbF08^P
/P26UZX0QcDk08/E7@1IFW40^]3L0;[:e@2hc=L0^<_G0;[<f@2hbMH0N8jS055^P`1nTid0SibP07Uc
K@d00?l02?ooool00`1@T7P0X23`0:0Pl00Q0:0Pl0D0oh0000D0^3Rd0:0Pl02P8?00X23`0=1@N003
0?n000050=1@N03oP000oh000>QX?03@D7P00`3oP0000`3XJ3`0^3Rd0:0Pl0020:0Pl0030=1@N03o
P000X23`00/0X23`3@00o`0;ooooo`002_ooool0EP00o`00@g<B05IVH018EEL0104101010@0J0@40
:@4204<21@170PD0>`4203l10P0n0PD0FPH;06<5201?0@<0L0D908d51`2C10H0W@@40;T<2`302`X0
``d;0<4<2@2n2PT0`0d<0;l<302m30d0_@/<0;h<302m40h0UA@@0:>2M`3IeM80f]WK0=_Jg@3NdmD0
c8J60<@l>P3A8A`0f1TD0=HI4@3A5a00d1HC0<LJ602=6A<0H2hT0:fQU03Jem<0a[jm08ABD0296AT0
V@`=09`=3`2:5`l0_9:50=?Bd@3@dM<0dM;A0:bTX@1F3Pd0S0L:08/21@290PD0QP8308820`1m0@<0
P04408@210250`D0R@@708T41@2G1@T0[@P<0;<92`2d30`0Z@d?07d>4@1S9BD0Vi6>0:fj_P31cmL0
_/cG08ZLX`1VJF/0>ZTP0P00o`09ooooo`03003o002P8?00X23`00@0X23`00<0d51h0?n0003oP000
5P3oP0000`2h>;@0X23`0:0Pl0020:0Pl0030>QX?03oP000oh0000H0oh0000D0d51h0:0Pl02P8?00
X23`0=1@N0040?n000030=1@N02P8?00X23`0080X23`00<0j6Pl0?n0003oP0003`3oP0000`3@D7P0
X23`0:0Pl0040:0Pl003052@N000o`000?l000Sooooo04d07^@909nCQ@2:WZX0I7n805aiOP1iTiP0
P9RM0:^k_`2g`<H0NGan08:1N`2;R7l0VI>:0:6MU@2ZYYh0Z:FI0:fUUP2`Y9H0]ZJE0;>QSP2eX8T0
^JB=0;bWS`2lYXl0`:RA0<6YTP31Zi<0`ZfF0<FaV`37]Yh0bkVR0<bjX`3?_ZL0d/6Z0=K4[P3Fa;@0
g<Jd0=fZW02`MWD0PVb0055WRP1SP9h0/;>g0<Fj[`35^JX0aKJW0;FSVP1oNXH0G6Aj06EUN`2R?T@0
/`/=0;8B5P2`2Pl0/`H<0;862`2_10X0ZPD:09h>4`2XL7P0I7J805QQM0259bl0SAHQ05UMM@2jdM/0
^L[E0;[<f@2kcMP0_<gI0;W;f02I/LL0Oib`096V/02KZk40QHB400[V100<003o00Sooooo00<0D91h
0:0Pl02P8?008P2P8?020=1@N0030;Ph]02P8?00X23`00P0X23`00<0j6Pl0?n0003oP0001P3oP000
0`2h>;@0X23`0:0Pl0020?n000`0X23`00<0:<Pl003o0000o`002P00o`0;ooooo`002_ooool0EP00
o`00@W<F06UjM`17De@04P8202H20`0W0@40<00204D21@1>0PH0CP4405@21P110`H0CB//081CD`1E
2``0P0H:09052@2F10L0W@D60:h8202n2`X0``/<0<8<2`2o2`X0^PX70;H82@2i2P`0_0X=0;h>402b
8A`0Rd]20=O@b`3KgMd0gMgN0=OFeP25Jf/0OAlN0;PM6`3F6aL0eQPB0=<G4P3D6AH0a1/I07PG4`1o
Ieh0c<Bm0=oLfP3;cL/0B4a7028?2P1;2PX0S@h@09X>402<7aL0`IZ>0=?Bd@3?d=80dM7E0<W9b016
;R`0K`/<08P51P280`<0R0<408<10@200@40O`4307l110220@D0Q0<708P42@2>0PD0[@/<0;892P2c
2Pd0[``>090B4P1R5140Wh^:0;O3bP30d=T0//?;09FU[01NHV@0>j`Q0P00o`09ooooo`03003o002P
8?00X23`0080X23`00<0^3Rd0:0Pl03oP0001@3oP0000`2P8?00d51h0?n0000?0?n000030=1@N02P
8?00X23`00<0X23`1`3oP0000`3XJ3`0^3Rd0:0Pl0040:0Pl0050>QX?03oP000oh000?n0003@D7P0
102P8?000`2h>;@0oh000?n0000@0?n000H0X23`00<0D91h003o0000o`002?ooool06@00o`00WHYc
08fOZ`1YQXl0KhZ?069nP`1NO7l0RZ:W0;G4b@1nPh@0P85k08b;P02KUX/0Y9fE0:JQV@2XY9X0ZjFH
0;2UUP2fYIH0]j6?0;NOR@2iXX`0_:F>0;ZTS@2nYi000P30Zi<0<P32[iP0a[:M0<RfX03:^J<0cKbY
0=2nZ`3A_jX0e<:_0=W7]`3EakX0e/Rl0<c2^`2j^;T0`knm0<[0]P39_Jl0a[Z/0<6gZ@33^J/0`;JX
0;^aXP2gZI/0^X5i0:TH5`2f2@/0/`P90;D72P2f1P/0]0L90;46202`1@L0[0D909DG7`2FSj40Y:>^
08PN9@2>5b80G6Am0;W?f`2lcMP0^lcH0;g>f`2kc=X0^/_H08RO]01dTZD0Q9RR092OYP22Q8P05kl<
3000o`08ooooo`03003o002P8?00X23`02h0X23`00<0d51h0?n0003oP000203oP0020:0Pl080oh00
302P8?000`1@T7P00?l0003o000:003o00_ooooo000:ooooo`1F003o0019ObL0FVe_04mCE`0Y10@0
=@<402X10@0_0@<0@`8304d11@1@0PH0E04405d;3`1cA4D0QU1?07`K6`261@H0T@D809P41`2L1@H0
Y0D70;/<303230`0`@d;0;/;1`2h2PP0^P/;0;`;2`2o30d0]1LB0;mYF`30ZIh0fmWI0=gNh03Be]H0
JG9^05iNE`1kIE`0Sc@_0<XP6`3K6aL0ca`J0:XJ6@1X6AD0TGme0=WDc03Ng]X0f]WH0<O8`P2b/JH0
X9^?06MGC`1[4A80V0d@08hP6@34Wi@0dm7B0<k@d`3?d]H0cm;D096BS00X2@L0HPT:08841P250P80
P@4208010P1n0@<0P08608P720250`H0QP@808@11@2T2P/0/@X;0;8:3P2a3Pl0[38`08@i=`2LOWh0
/Kc20;k<e@32cmT0Tj>]069SI00gYa`2003o00Wooooo00L00?l00:0Pl02P8?00X23`0=1@N03oP000
d51h00H0oh000P3@D7P@0?n000L0X23`1@3oP0000`3XJ3`0X23`0:0Pl0060:0Pl0<0oh001P2P8?00
0`2h>;@0oh000?n0000?0?n000030;Ph]02P8?00X23`00<0X23`00<0D91h003o0000o`002?ooool0
C@00o`00Z8i]09JW/P24WjX0I829055`M@1WQXP0KhZ>0:bl`026Rhh0P81l08b<Q@2NVi<0XIfF0:JQ
W@2ZY9d0[:FJ0:nVV02eYID0/j6>0;BRS@2fXX`0^JB<0;^WSP2kYXl0_jZD0;j[U@30[IL0a[6L0<Ze
X@3=^JL0ckb/0=2nZP3A`:/0e<>`0=G5]03FbKX0dlRh0=38^03?a;T0b/:d0<W1/P37_K80`k^^0;^g
Z@2l]jX0^K6U0;R/W`2lR840ZRDW0;D;3@2d2@X0/`P:0;D92`2/2@`0YA<E0:8L802U3180Z`@809T6
3@1G>eX0Kg>808PF7@2?51h0H6Il0;[?g02caLl0^lgH0;[<f02kc=L0]lWG09b_a@1DL8H0MhfG08ZK
W`2;U9L09IhJ00`00?l02?ooool00`00o`00X23`0:0Pl00]0:0Pl0030;Ph]03oP000oh0000T0oh00
00@0d51h0:0Pl03oP000oh00302P8?000`1@T7P00?l0003o000:003o00_ooooo000:ooooo`1F003o
001=PRh0P96E061OH`0`10@0<@4302D00@0b0PD0B0@504T20`1;0@@0D@450602201[2Q40LPX?07/4
20281@L0TPD709T31`2M1@P0W`@70;L<3@333@d0`P`<0;`;2@2h2`T0^`d>0;T;2P2g2P/0]2/S0<NA
P@3EbL80f=SJ0=CAc`1VJF80O89h0=;=aP3Od/d0hZbU0<4b;03?71/0S1LG03`<1P2;OG00fmKA0=oP
g`3Qhn80h>3P0=cLf`3Dem80e=C>0<o5_P26@Sd0T`h?08lO6034WiD0dM7B0<gAe03>dmD0d=CF0<[:
b00m>CD0704006@72P210@<0O`4207l00@1o0P<0PP@60847201j0@@0O`<:07`31P2G1PT0[0P90;4;
302a2`d0W0d?07d?402EGel0ZK6c0;g:d`2]^lL0XK6k05eOH@0gYad2003o00Wooooo00L00?l00:0P
l02P8?00X23`0=1@N03oP000X23`01L0oh00202P8?050?n000T0X23`00@0d51h0?n0003oP000d51h
1`2P8?0@0?n000030=1@N02P8?00X23`00<0X23`00<0D91h003o0000o`002?ooool0C@00o`00QK=M
09BT[P2;Y;80EW9l02m;D01ON7`0Hgn40:Rh_02?U9H0O7ei08b;Q@2HVHl0WIfC0:FPU`2/Y9`0[jJL
0:jSV02cYIT0]:2A0;JRS@2gXHh0]j><0;VUSP2mZ900_:RB0;f/U@2o[YT0`kBN0<VmZP3;^Z`0c[j[
0<joZP3?`J`0d/Bb0=76]P3BbKP0d/Rj0<o6^@3=a;X0bL:e0<O0/`38_[P0`kZb0;ng[P2k]:X0^[2T
0;j?RP2X9RL0^0d?0;P:3@2b20X0Z@l>09h[<@1b?E80AD1S049:J@27DUh0X@X@09D83@1E@5/0OH:H
08LC6P2>31L0IF5h0;S?g02kb]H0^<[G0;K8eP2hb]L0]<KE0:>fc01gT:H0SZ>^09RZ/02HXjP0?g<^
00`00?l02?ooool00`00o`00X23`0:0Pl00/0:0Pl0030;Ph]03oP000oh0000@0oh0000@0d51h0:0P
l02P8?00d51h0P3oP000102h>;@0X23`0?n0003oP00=0:0Pl0`00?l02oooool000[ooooo05H00?l0
066JBP2=X:P0JfQ`03X51P0f0P80:P4103<20`140`H0?P4303l10`180@@0G`8807442P1g0`X0P0<9
08T52P2A10L0V0@809`31`2O1PL0[`T:0;h<302o2``0^@X;0;@82@2f2@/0]@T90;H:2`2d?380^YB6
0=SAc`3Fe=D0UXF008=_I03>b<00fm_K0=oMg@3UbLT0[DE307`F4`1M@3T0Yj:I0=KDc@3OhN40g>3R
0=_Ph03MhN80fmgO0=GHf03AeMD0eMCD0:f2OP2<5140RQXC0;jGS`3Bd=<0cm;E0<kAe03?d]D0cm7D
09nMV@0j8Ql0H@T908420`220@<0OP4307d10`2:4180PaDD07821@1Y0P@0QB0Q090:302^3@h0/@/;
0;8<3@2U4100SQHG08@m?P2h^;/0]Ko80<;>e`2JZ[<0KG1d03b/8`800?l02Oooool01000o`00X23`
0:0Pl02P8?020?n000030=1@N03oP000oh0001D0oh002@2P8?020?n000030;Ph]02P8?00X23`00P0
X23`00@0^3Rd0?n0003oP000d51h1`2P8?0@0?n000030=1@N02P8?00X23`00<0X23`00<0D91h003o
0000o`002?ooool0C@00o`00PJM809ZU[@1kUj<0>EMP05A/L@1UOhH0NiFJ09BVZP2GWj80O7ij08F5
OP2FV8d0XJ2F0:JSV`2/YYh0/ZJP0;6UW02bY9T0/j>C0;>QS@2cX8T0]j::0;^TS02kYhl0_JZB0;n/
UP2iZiP0/[2T0<_?cP3=bL40c;bZ0<boZ03<`:`0c/6a0<c3/P3@aKH0d<Fg0<c3]P39`KT0bKnh0<W0
^035_KD0_[R_0;bh[@2l]JX0`Z>K0:Xb=02h3Q40^@/>0;4=3`2P;C40JdQP02/lI`12F7L0NXRC09jO
WP2WM7@0WP`@09HP900d=U<0TY2P08HA6@2>1Pl0IU5T0;O@g02kbm@0^/cE0;[<f02gbML0[L3=09BZ
_P1<KX@0NiJQ086DW022SiT0@e`j00`00?l02?ooool00`00o`00X23`0:0Pl00[0:0Pl0030;Ph]03o
P000oh0000<0oh0000<0^3Rd0:0Pl02P8?000P2P8?000`3@D7P0oh000?n000020:0Pl080oh0000<0
^3Rd0:0Pl02P8?002P2P8?0<003o00_ooooo000:ooooo`0^003o002:NUh0ZKc806]YLP0l1@H0?@<3
02T10P0S0@80=P8303<20P0c0@40@04305/11P1b0`P0O0<908422P230`P0R@@609D41`2H0`D0W`L8
0:L61`2h30`0^0/<09d51P2F1@H0[PP;0;87202b20P0/D0c0;fPTP3Gdm80c<[:06]YG03?a[d0emCD
0=KGf03<cLd0RGel04PW8`1nLVT0b/[30=WIf03Ifm/0f]kO0=[Kg@80fMgN02H0f][L0=SIf`3EfM/0
dmSH0;^TXP2761D0RQH@0;^?Q`3CdmH0cM;D0<oCe@3?dmH0cM;D0<g?c`35]k80Te59084610250P@0
Q04507l11@1n0PD0N@8407@10P1T0P<0QQ<H09H;402P2P/0/Ph=0;<=302W61L0gG]n06lW:P2h[[80
]<770;c9dP2V]L00IVab042c;@800?l02Oooool01000o`00X23`0:0Pl02P8?020?n000030=1@N02h
>;@0oh0001D0oh002@2P8?000`2h>;@0X23`0:0Pl00;0:0Pl080oh0000<0d51h0:0Pl02P8?001@2P
8?000`3@D7P0oh000?n0000>0?n000D0X23`00<0D91h003o0000o`002?ooool0C@00o`00E/Da09NN
X`1`RYP0@UmW03]CFP1ILgL0H7b108bRZ@2OZZd0OX>008b?R02GVHh0X9jH0:RRW02]YIh0[ZBN0;2U
V`2]XIH0/J6A0;BQS`2eXHX0]Z:90;ZUS@2kZ8l0_JZA0;f/UP2SVX/0a<Fm0;Vm^P38`K@0b[bY0<fn
Z`3<_j/0c/:a0<k3/P3?a;L0cLBh0<c5^@3:`[P0blFl0<K0]P32_;<0_[Ra0;fg[`2n/JT0]61N0;PC
5@2j3A00[ALG0955C`0g?6H0?UYn08NCV02MWI<0XZ2A0:fHS`2L<cD0X@T=07XiBP0L?6D0Ngf8088B
5`2F1@h0JCI60:o9f02jbmL0^/[G0;_:fP2jbML0]<OC0:Bib@1SP980OYRP08JIW`1nSYT0>3Xj00`0
0?l02?ooool00`00o`00D91h0:0Pl00[0:0Pl0050>QX?03oP000oh000?n0003XJ3`01P2P8?020?n0
00030=1@N02P8?00X23`0080oh0000<0d51h0:0Pl02P8?002P2P8?0<003o00_ooooo000:ooooo`1F
003o002?OfD0MhfJ06EVK00i1@@0>`<202410@0J0@40=P8302h10P0`0000A`4405/10`1a0PD0NP05
08842P250`P0R`@708h20`2C0`D0V@@609l41P2^2@/0/`X:0:D92`2B0`@0Z@L80;48202a1`H0[RdU
0<BERP3IdLl0d<k=0;:^Y03Ed/d0eMKE0=7Dd`1hQX4052<H07QiK@3@c/D0f=_J0=OLf`3Fg=/0emgL
0=OIfP3FfmX0em_K0=[Jf`3HfM`0e=SK0=;Ge`2aTI00Ra<C090D4P2cOgL0dmCE0<gAe03@eMH0cM;D
0<gBd`3;c<d0[IRH08@k=`241PP0R08608L110230PD0O`8507X2101g0@<0I`4207d5202Q2@h0S`43
0:X=3P2b30`0[0dA09X@5`1d4aL0a;Fj0;6l``36dmd0UJJc07AkP`10/R`2003o00Wooooo00@00?l0
0:0Pl02P8?00X23`0P3oP0020:0Pl1H0oh005`2P8?020?n000030=1@N02P8?00X23`00D0X23`00<0
d51h0?n0003oP0003P3oP0050:0Pl003052@N000o`000?l000Sooooo04h00?l005K1:02PXZ80KXBC
04iZM016H6D0EW9i07ZEVP29WZ80Z;Fj08F;S02BTi00VIZD0::QV@2UXi/0ZJ>M0:fTW@2_XiX0/Z6E
0;2OS`2bWhh0]9j:0;>PR02fYHh0^:NB0;ZYTP31[YP0[j2@0:JOTP2f[il0c;fZ0<bmZ`3=_Jh0bkbZ
0<g1[`3<`;<0c<>h0<g3^P3>`k/0bl:i0<W1^@36_kD0a;fd0;bj/@2m^K40bJnZ0:XY;@2m3a80/A`J
0<IYI02?AU<0Qem^09nKU@2SXYH0XJ2C0:^OT`2TFEL0X0d?09P[<`0_<5/0LI2X0:>X[`2061h0V0<:
07dO;02O[;/0^l_H0;O8e@2hbML0^<SF0;C7e02L/L80Kh^N07VBW02CZ:d0T::Z03a4AP0:iP@;003o
00Sooooo00<00?l0052@N02P8?00:`2P8?040?n000030=1@N02h>;@0X23`00<0X23`00<0j6Pl0?n0
003oP0000`2P8?020?n000030>QX?02P8?00X23`00X0X23`00<0:<Pl003o0000o`002@00o`0;oooo
o`002_ooool01P00o`00N6M908FLY01]Jg80>0D503420P807@4104h0>08403L10P100`<0C@8405h3
101a0PH0O08808831`250`L0R`<509451P2C10L0V`D809T31P2S1@P0[PT90:h71`2Z1@H0[PL70;87
202e20X0[Q0>0;MAB`3C[JX0f=;B0=SBd03Fc/h0cKZk07]dLP10C440UYV=0<g=aP3JfmX0e][K0=OL
g03Ifm`0f]gM0=[Kg03HfM/0emWJ0=WIg03Gem`0d]OI0=;@d@2BE5<0U10A09@B402SI5d0d]3@0<oC
eP3>dmH0cm;E0=3AdP2ZSHh0OR/Z08@<3@280`P0P`4408@20`1o0@<0O04207X1101i0@<0I`8307X4
1P2P1`/0T0D709/;3@2b3@h0[`/>0:8<3`2;9RL0/ZJX0;G1b02ncML0ZK[806]eN`1HP3<2003o00Wo
oooo00H00?l00:0Pl02P8?00X23`0?n0003XJ3`20:0Pl1L0oh0000<0^3Rd0:0Pl02P8?004P2P8?00
103@D7P0oh000?n0003@D7P50:0Pl0030;Ph]03oP000oh000100oh001P2P8?02003o00Sooooo04h0
0?l002[O4`2EUHl0T:Ne041LI@13G680Af5U07B?T`1fSY<0]l;808F:SP2@T8h0VYRE0:6OVP2WXY`0
ZJ:J0:fTW02^XYX0[j6C0;:QTP2bX8d0]:2;0;BPR02gYXh0^jNB0;fZU`31/Ih0aK>P0<FcX`39^ZP0
bkVW0<fn[03;_k40b;b/0<[2[P3:`[80blBg0<W1]`3<`k/0b/:i0<S1^P34_[L0`[fe0;jj/02o^;40
aJFR0:XO8`2g4Q40bEA>0:HO802^3A00Va/N08amOP2OXY/0[9bD0:MLF`2S41@0Y@X=09e0B`1VBf@0
ZJJ[09>DW0249Rh0V@8908/74@2HMh@0_/gG0;S9e@2ibmP0]/WD0;K8e@2U^l`0CVYn06f6S`1/PHD0
MHR>03]8C`0I`Pd;003o00Sooooo00<00?l0052@N02P8?00:`2P8?060?n000<0X23`00D0j6Pl0?n0
003oP000j6Pl0;Ph]0020:0Pl0<0oh0000<0^3Rd0:0Pl02P8?002@2P8?000`1@T7P00?l0003o0009
003o00_ooooo000:ooooo`0L003o001oKU40WK:o06aYL`0d1@L09@4101`10@0S0@40=@8403020P0d
0040BP8405h21@1c0`L0OP<708D52@2610T0RP@608l31P2E10P0V@<609@21@2G0PD0Y@D80:l6202`
1PL0/PD70;852080]@L;00/0/`/>0;0W9`2iFE/0]UmR0:M:C01^:RP0He990<6o]`3Hf=D0f=[K0=WK
g@020=SJg00[0=gHg03La//0`Y6F09e_L`25NG/0dM?D0=OGf`3AeML0Whj>084M7`2J3A00VPh?09Y1
?03AalD0cM;C0<kCe@3?e=D0bLG607`c<P2;2P/0RPD708@210220@<0P04107h10`1l0P80N`4307L1
0`1W0P<0MP@60:<:3P2F2`l0QPH90:l<4@2`30l0YP/>08PE602RRH`0/;k50<3@f`2U]Kl0Lgf105R3
=@02003o00Wooooo00H00?l00:0Pl02P8?00X23`0>QX?02h>;@20:0Pl0030?n0003XJ3`0oh0001D0
oh0000@0j6Pl0=1@N03oP000oh002@2P8?020=1@N0D0X23`0`3oP0000`3XJ3`0X23`0:0Pl0030:0P
l0030>QX?03oP000oh000100oh0000<0^3Rd0:0Pl02P8?000`2P8?02003o00Sooooo04h00?l002SK
302BRWX0PIJP061kQ00lE5X0DFmg07FAU`1nU9T0a<kF08V<T@2>SHd0UYJB09jKU`2UWY`0ZZ6N0:jU
W02^XYT0[9nC0:jNS`2aWX`0/j290;RPR@2hY8`0_JRD0;fZV02mZi`0`[6P0<JcX`3:]jH0b[ZX0<bo
[P3;_k40akj^0<Fm[P37`;40a/:e0<[1]`38`;L0bL>j0<G1^033_kH0`;fd0;jl/`2m]Zh0ak2]0:Pe
>02e4A80`2`/0;<>4@2Y4A80TSe=02hjH@2RTID0XTI50:L?4@2[1PT0ZP@90:D52@2N2A00V3<f0:N@
T@29>Ch0V0<;09T430268BX0`[K00;W9e02gbM@0]LSD0;K:e`2S^ll0C6V603]EL`0^Af80>51W0358
D@0ZY1/;003o00Sooooo00<00?l0052@N02P8?00:`2P8?050?n000040>QX?02P8?00^3Rd0>QX?0D0
oh0000<0j6Pl0:0Pl03@D7P00P3oP0000`3XJ3`0X23`0:0Pl0090:0Pl003052@N000o`000?l000T0
0?l02oooool000[ooooo01h00?l0085_EP2M/;d0KFQc02l51P0O0@406`4102810@0Z0@807`4102X1
0@160P<0GP850782201k0PH0P`@808L5202>0`L0T`@709<31@2B0`L0T08609@2202N0`L0[0H90;07
202`1PP0/PH90;@72@2e2P`20;P<3@0f0;P?4`2P5AD0Ga4>071KD@39b;h0emSI0=WJg03Gf]X0f]cL
0=gDeP3D/[H0`gQn0:Tj@01[81h0ESXf0:^XXP3DfMT0cLg@0;Ff]@1DCdX0HA4A09P>402L3100TQhO
0<Ra[@3?e=D0d=?E0=?De`2i[:d0N1DE08`31P2;0`H0Q`8308H10@250P<0P@4307h10`1l0@<0M`42
06T30`1D0@80N`L=07D62`1c1@L0ZPd@0;0;3P2Z2Pl0TP/?08aGF@2Z/kX0a]?N0:Je_`1bNX00FH<g
0P00o`09ooooo`05003o002P8?00X23`0:0Pl02h>;@00`2P8?000`2h>;@0X23`0=1@N00H0?n00003
0;Ph]02P8?00X23`00D0X23`00@0j6Pl0?n0003XJ3`0d51h1@2P8?00103XJ3`0oh000?n0003oP005
0:0Pl1<0oh0000<0d51h0:0Pl02P8?000`2P8?02003o00Sooooo04h00?l001C^1@2SUh00UZVd04AP
JP1ELGX0=5IK076;SP1iT9H0`m3H08fCV02@TI40VIVF09fKU`2RWiX0YZ2M0:^UWP2ZWiH0ZYfA0:fL
SP2bX8d0/9n:0;FPR@2iXhd0^:ND0;^[V02nZiT0`JjL0<JcY039]jH0akRX0<Vk[P3:_k00b/6c0<Bl
/@36_[@0a<6e0<K2]`37`;H0b<6g0<K0^032_kH0`<2j0<70^P2n^K@0_KJ`0;b@S`2Y?Cd0YRDX0:0c
>`1kBV40?T=^07I>J`2R9BX0Z`X<0:h82@2Y1@L0Y`870:L3202Z10X0W`L=08=<E`2=F640T`H=09P3
2P2?10d0RCM30;Zj``2dam<0]LWJ07nK^P0Q?G800AE?004@@`013S/00@hf01X^@`0hQB`;003o00So
oooo00<00?l002S8?02P8?00:`2P8?001`2h>;@0oh000?n0003oP000d51h0:0Pl02h>;@0203oP002
0=1@N0<0oh0000<0j6Pl0:0Pl02P8?002@2P8?0;003o00_ooooo000:ooooo`11003o0027N6<0^<WG
06mWLP0`10H0904201d0000R0@40:P4102L10@0a0P80@`4405L11@1a0`L0O@D8088520281@T0S`@6
09021@2?0P@0S`@609031`2B0`P0T`860:<41`2_1PX0/@L:0;<72P2d1`X0]@T;0;T>3P2j3Pl0/Q4D
060>3@1[Fdh0`[je0=KGe@3Ef=T0e]WJ0=GJf`3Id]80`XB70:/f>`2V9R/0Ea0@05iCBP2m_[<0e]SC
0=GIfP3Ce=D0dm3?0<2j]P1e>cL0U@lB09X:3`2B4140]h^80<kBdP3@e=L0d]GH0;JSY@1h4A40S0<5
08h51@280@800P250@404`250P@0OP8307/10P1h0@80LP<404D10@1A1PP0D0@805l31`2R3A<0Z`/=
0:T:3`2G2Q40SDiC0<C8d@32c]/0/;g:07R0QP1EPcP00P00o`09ooooo`05003o002P8?00X23`0:0P
l03oP0000`2P8?000`3@D7P0X23`0?n0000G0?n000L0X23`00@0d51h0?n0003oP000oh001`2P8?00
1@3@D7P0oh000?n0003oP000d51h00@0X23`4`3oP0000`3@D7P0X23`0:0Pl0030:0Pl0800?l02?oo
ool2003o000S0:^DLP2=WZP0I7j:03MHG@1DLgP0FGEm08bQZ02mbm80UIfP08nDU02FUi@0VYbG09jO
V@2RWYX0Z:2H0:JMTP2ZVhl0[IZ<0;2LR`2]VhL0/Yj60;FQRP2hYY40_:RC0;fZU@2nZiT0`:nN0<Be
Y032]jD0a;ZZ0<Jn[`38`;<0`[^a0<:l/@34_[800P37_kH09`35`KP0`l6h0<;1^@2o_kP0_[jg0<2m
]P2n^[80_;>^0;F[Y`1lNhP0Be]j05=EO@2>@5D0Z1<I0;493@2^1`/0[0L<0:P42@2W1@X0Y`@90:P3
1`2L1@T0ICA:07QXN02931@0UP8809@12`291A00RF9/0:_3e`1@K9T011iM008GF`014U400@i3004=
?P0133D00Q8^03eL=P0;003o00Sooooo0P00o`0a0:0Pl0030>QX?03oP000oh0000L0oh0000<0d51h
0:0Pl03oP0000`3oP0000`3@D7P0X23`0:0Pl0080:0Pl0/00?l02oooool000[ooooo05H00?l008Ig
H@2P//00JFA]02`3100V0@407`0002<10@0`0P<0;`8203@20@150@@0F04606`21@1i0PH0O`<708D3
202>10L0S`4608l41P2>0`L0S0<608h41P2>0PD0W`D70:h8302`1PX0/@D70;@72@2h30d0^Ph=0;P>
402>4Q@0LE990<:m/`3Fe=<0eMSJ0=GIf`3Hf]/0elS90;a`M02Q;Bh0NATK04TH5`1cK6<0alJn0=OI
eP3IfmX0e]SI0=OHfP3Ff=X0e]GF0:f7QP2=4aL0V0T>09P=3`2KEE00dM7<0<gDe@3?e=D0]ZJW07DA
4P290`H0RP<408P20`260@80Q04108020@1l0@80NP4207P10P1h1`L0FA@D09a_K`1V=SL0DP<509/<
3`2Z2`h0YPL<09X;4@2JGV80]kg60<CAg`2a_l/0Nh::05J4>@800?l02Oooool01@00o`00X23`0:0P
l02P8?00d51h00<0X23`6@3oP0000`2h>;@0X23`0:0Pl0040:0Pl0040>QX?03oP000oh000=1@N0P0
X23`00D0^3Rd0?n0003oP000oh000=1@N0040:0Pl0`0oh000P3@D7P50?n000030=1@N02P8?00X23`
00<0X23`0P00o`08ooooo`800?l004d0Qk=N09FT[019Ig<0DW1e03]CE`25WJ<0X[K00;W7c`2NYjd0
Ri6B09JGUP2KVIH0WifJ0:6NV@2TWI@0XiV>0:JFS02XUHX0[9V70:fLQ`2aWXH0/j::0;JUS@2gYhl0
^ZVD0;b[UP2lZY@0_[2M0;bbW`33]j<0`KZY0<Fo/037_k@0`;b_0<:m/P36_kH0a/2k0<?2^@32`;L0
`<6f0;o1^02m_kL0^KZc0;Zg/P2i][80/K:Z0:j]Z@2`TIH0X34j0;4>502e2@l0/`L>0:d:3@2Q3Q@0
UBL_08Td?P2J6R00Y@D909DD6P0o<UL0PHbS08<T:`2G0`/0U04;08X32`1B9dD09TEo004IGP015ET0
0QUJ00`SE@0T>5L0;T5L00XK>@0<8CH0<cLh00WU0`0:003o00Sooooo0P00o`0_0:0Pl0030;Ph]03o
P000oh0000D0oh0000@0d51h0?n0003oP000oh000P2P8?001@3XJ3`0oh000?n0003oP000d51h00X0
X23`00<0:<Pl003o0000o`002000o`0;ooooo`002_ooool0@`00o`00Sh=_0;o@h01RG6H0<0<502h2
0`0U0P80804102h20P0b0P<0<`4104L2101O0`H0K@@707H32@1l0PT0PP<908h32@2A10T0T0D708/2
1@2:0`H0S@<709411P2L10L0X0L90:l8302b1PP0/`T:0;D<302f3Ph0Y1<C074n>`38`kh0eMKF0=GG
f03Hf=`0el_=0;n?TP2VBT`0Ma`N04@T7`1XI5d0[ZnV0=GFdP3Ifm`0e][K0=OJg03EfMT0dmSJ0=;I
fP3Af=T0^ZVY08HG6@2I2Pl0V@X>08PL6P35[JX0c];C0<oBe@32/[@0MaPH08X41`2:0`H0Q`8208D1
0P220@800P1m0@<04@1j0@<0M@4207420@21;b/0JSHg070a=01_1P/0V`P>09h6302Q20h0W@/A09E;
D034`ld0`/oJ0;S8dP1iPhX0F8Dl00800?l02Oooool01000o`00X23`0:0Pl02P8?020>QX?080X23`
00<0j6Pl0?n0003oP0005@3oP0000`3@D7P0X23`0:0Pl0030:0Pl0040=1@N03oP000oh000;Ph]0/0
X23`103oP0040:0Pl0`0oh000P3@D7P50?n000030>QX?02P8?00X23`00<0X23`0P00o`08ooooo`80
0?l004d0LZXo09FNX@1EL7/0?5QL06N2R01hTId0KHJ@0;G5c@2W[kH0Ri2A08f@S`2GUY00WI^E09nM
V@2PVI00XYJ=0:FDS02XUh`0[9V:0:nKR@2cWhX0/Ij80;6PR02cXX`0]JB?0;NVT@2eYHh0]ZNB0;6Q
SP2fZIH0]ZfM0;njZ`34_K<0_[Z_0<2m/@32_k@0a<6k0<?3_@31`;T0`<:k0;g0^@2m_kT0^K^d0;Zi
/`2h]k40];>/0;VJUP2V;S<0/``C0;D:3P2c2@h0Y1<G08hjB01D@6L0:CMV0511HP2D7RP0XP@:09le
?`18B6T0MYN_08EEGP2B1`h0T`4908@43`0m74D00QEK004HF@0B;f80FW^P0622W023WJ/0AEed01le
B@1>HfD0;cPm017;200:003o00Sooooo0P00o`0^0:0Pl0030;Ph]03oP000oh0000<0oh0000@0j6Pl
0;Ph]02P8?00X23`0`3oP0020:0Pl0050=1@N03oP000oh000?n0003@D7P02P2P8?000`1@T7P00?l0
003o0008003o00_ooooo000:ooooo`06003o002KSg`0`m;O05Q?EP0X0P<0;P830P0R0@40CP0[0@80
;P4103l20`1?0PD0GP8506T31P1_0@D0O0<808D31P2?10P0S08508T210290PD0S@<708h11`2B0`H0
W@D809l41`2/1PX0/0H90;D;3P2f3Pl0ZQ8A07DP702k/Z`0e=KF0=OGf@3IemX0dkk109iGF`1e92L0
AAXH06MTG@2m_kL0e]K@0=WLf@3JgN00em_L0=OKg@3Ef]`0e=WH0=GHf`3EfM/0e=SJ0:J0P`2@4aD0
VPT>09/:3P2E2``0W5ID0=76a@3?d]80bL3107TV9@290`<0RP8308L10`230@80P`8308421@1l0@<0
N@8207L20P1d0@40M0L9088P8@1n5aH0PP@809/83@2I1@`0V@@<09h9401m51X0^Zjg0;o<f@2^_l/0
PX^D05F4?P800?l02Oooool01P00o`00X23`0:0Pl02P8?00^3Rd0?n00080X23`00<0d51h0>QX?03o
P000503oP0000`3XJ3`0X23`0:0Pl0030:0Pl0030>QX?03oP000d51h00`0X23`00<0^3Rd0?n0003o
P0000P3oP0001@3@D7P0X23`0:0Pl02P8?00j6Pl01<0oh001@2P8?02003o00Sooooo0P00o`00C@1A
_bX0XjV[05egPP1ONh80EWAj07VCW@2@Yk00aM;K0:ff_@1jP880Ngik09BAS@2LUY40XY^F0:2GS`2P
UH/0X9670:NFR`2ZV8P0ZYV40:bJP`2/W8<0[if50;:PR@2aWhH0[Ib30:fLP@2[VX40[9f50:bOR02^
YI40[jNG0;^cY`30^k00`;fd0;Rh/P2/[jd0`L?10;bn^P2a][80_;nh0;fn^`2k_K/0^KVh0;Jf/P2k
[JX0YD140;D>4`2g2`h0[@/@09d`>`1IAVX08Ca`05IQQP2;GFh0TaTT0:@53@2W10X0X@H>090]=P2W
Y:l0QH:C088E7@2B0P/0IPTS014BD`036eh0A6B?09fgc02J[l40OIJV03YDK`088d80?EQS059TGP0m
B4/04/l=00X00?l02?ooool2003o0003052@N02P8?00X23`02/0X23`00H0j6Pl0?n0003oP000oh00
0>QX?02h>;@20:0Pl0030=1@N03oP000oh000080oh0000<0j6Pl0:0Pl02P8?000`3oP00;0:0Pl003
052@N000o`000?l000P00?l02oooool000[ooooo05H00?l009nBP02/[[/0=a`R02@10@0X0P807`40
02D10@0[0P40<@4104L31@1?0@<0F`4406T1101e0`H0O08708@21`2;1@X0RP<708L210280`@0R`<4
08h31P2C10P0V`@70:/52@2`1`T0/0L:0;@:3@2c3a40W2@Q08=KE03Ge=80e=OF0=KHf03Eb<`0TEQM
04XH5`0U61@0PXEn0<_>a`3Kg=X0f]gL0=OMg03HgMd0fM[M0=SJg03GfM`0eMWI0=CHf@3FfM/0c/_>
08Q0AP2H3a<0W@/?09`<3P2H2@X0RAlO0;:=S@3Bd]40dLk>07Lk>P221@L0RP8308X31@2100D0O@03
07h1101k0@<0NP4307T10`1f0@<0M@4207821@1^0@@0O@8609L72P2F0`X0UP<<09T73`244AL0a:ng
0<7;e`30cMX0Q8bF05R8@P800?l02Oooool00`00o`00X23`0:0Pl0060:0Pl1H0oh0000<0d51h0:0P
l02P8?000P2P8?020=1@N0h0X23`00<0d51h0?n0003oP0000`3oP0030:0Pl0030=1@N03oP000oh00
0140oh001@2P8?02003o00Sooooo0P00o`00>01C_bP0W9nO08JLZP1AKWL0Ggb5076<U@2S];h0aM3K
0;Nna`1cMg`0QXR809FBT02MUY<0W9N@09RDS02MTh/0XI260:BAQ02WUHD0ZIR40:ZHQ02ZVH00ZiZ0
0:^GO@2_W840[9ao0:^JO@2[Vh40ZY^10:bLP`2[XH`0ZZ6?0:nXU`2d[Z80_kbc09bOVP2MXj00]KRh
0:2SX02`]:l0UYjL0;Rm^@2l_;P0^;Rd0;Jc[`2dO7l0[ADK0;L<4@2]3a@0ST1A030lKP13Eh@0SFYj
09H_=P2Q3180YP<:0P2T0`T04`2V10T0T`H>071HK@1YOi@0QTeD08D84P0e3Sd011YO05Z0Z@2`bMX0
/lKE07ZCZP1?LIL02BE>03IDJ01TOH40EVIO03i;BP0P_Q/02P00o`08ooooo`800?l000<0D91h0:0P
l02P8?00:P2P8?001@3@D7P0oh000?n0003oP000j6Pl0080X23`00<0^3Rd0>QX?03oP0001@3oP000
1@2h>;@0X23`0=1@N03oP000d51h00/0X23`00<0D91h003o0000o`002000o`0;ooooo`002_ooool0
:@00o`00XXQf05loA`0g1`X09@4202<20@0N0@409@4102h20P0j0P80B@8305D21@1S0`L0J`<707<2
201k0PT0OP4808<320240PH0Q@<408L10`2=0`H0SP460942202J10L0Z`L:0:l72@2^20T0]0/=0:TI
5P2^IU`0]ZRR0=GEe`3DemP0al;308EVJ@0n8200HV1G0:Z]Y03>clX0f]cI0080fMcM02/0f=gN0=[M
g`3AeMP0]L330:F_[`3Ef=T0eMSK0=;Be02[S8l0QQXM09/=4@2O2a40W0/@09P9302;30h0S3/k0<B_
[P3Be=H0LeIH06l=40271@L0R08408410P1l0080O@4407/10`1i0@80N04307D10P1e0@<0LP450741
0`1m0PH0U`D909P5302D10/0U`L>08@@5@2`V9d0`L_E0;C1c`27SiT0GHY700800?l02Oooool01000
o`00X23`0:0Pl03XJ3`40:0Pl1H0oh0000<0d51h0:0Pl02P8?000`2P8?000`2h>;@0X23`0:0Pl00<
0:0Pl0030;Ph]03oP000oh0000D0oh000P2P8?000`2h>;@0oh000?n0000A0?n000D0X23`0P00o`08
ooooo`800?l004d0:=hB09JET024W:P0G7Z3069oQ`2L/[/0`=3K0;k:e@2AVj80NWj208f=S02BT8h0
VI>B09VCT02<Qh00WI6809j<Q02QSh40YYB40:NDO`2TTW/0Z9=l0:VFO02[V7h0ZiUn0:JCN02XU7H0
ZYQn0:VLQ02XWXP0[J:A0:ZNSP2[XiD0X9f@0;2`Y`2e]Zd0[[>Z0;jo^P2UYjD0_L2l09VPW@2h_;L0
^KRe0;Fd/@2j/Zl0Z4a@0;P?502_41@0TTIH03I1L@1/F7/0VSM40:<?5@2Y1P`0Z@D;0:D42@2V10X0
YP<:0:P52`2C3QD0B3eN06N;Z@1kO900K1db01h@B@0X8eD0LHnY0;79e`2dbM/0JHJY00//FP1FNHl0
QIfS06j0P@1EIEl0=DM702j_;00:003o00Sooooo0P00o`000`1@T7P0X23`0:0Pl00Z0:0Pl0070>QX
?03oP000oh000>QX?02P8?00^3Rd0>QX?0080?n000<0X23`00<0oh000:0Pl02P8?002P2P8?000`1@
T7P00?l0003o0008003o00_ooooo000:ooooo`0W003o001`CbP0E@h>03L20P0O0@407P4101d20@0W
0@80=08203/20P180@<0F08306021@1P0@@0I`4606h21P1d0PH0O@8608441`240`L0R0<508l3202C
0`P0TP8809X31`2Z20/0/@L;0;48302_2@/0Z3H^0;NGS@3Cd<d0d]KH0:>][`0^>CP0>chg09^MUP3?
d<h0em[K0080f=_L02d0f=cL0=[Lg@3LemT0`j^a05mFF@1<FeP0]Kfh0=OJf`3=a/L0VFe^08PU9P2G
3A00V`T=09h:402I20d0U@P:09482`2:30l0TTU:0<o7b@2IU9<0>PP607L720260P<0O`4307`00P1n
0P<0P08407/20`1c0@80M@4207D20`1c0@<0M04307d21@2E10/0U@@<09442`2C2@d0V2P[0:b<TP32
b]@0^lSG08J?V01NS4X00P00o`09ooooo`04003o002h>;@0oh000>QX?0<0X23`00<0^3Rd0?n0003o
P000503oP00D0:0Pl0030=1@N03oP000oh0000H0oh0000@0j6Pl0:0Pl02P8?00d51h4P3oP0000`2h
>;@0X23`0:0Pl0020:0Pl0800?l02?ooool2003o001=01kT2P2IThH0Ujjl05elQ@2BZ:l0/L3=0:Vi
a`1lQY80NX2408B8R`2:RX/0TI2<09NASP2JTXh0TH^109V@Q`2KRh<0XHj20:BBPP2UT7`0Z9Ak0:^D
O02ZUGl0Y95g0:REN@2YVGh0YY9e0:NCN02YVH80Zin:0:ZPS`2VWh`0QHEj08F:PP1/N7@0]K^b0<?3
_@32`[X0/;:`0:J[Z@2`];00^[Vg0;Zj]`2g]k@0^kB`0:U;D02h41<0^CDg08mIK02C>Dd0YA<K0:l8
3P2]1`/0Z`D:0:P63@2K30h0ZB/Z0:873@2U1@X0SBhn02i4L029Z[h0WKO707eXPP0L4DX0CaLj06Q`
S@2=[</0>UZ:00l`H@1=JX<0L8VA06IiO@1PLW00BEeM01X_>`12Qd802P00o`08ooooo`800?l000<0
D91h0:0Pl02P8?00:P2P8?001@3XJ3`0oh000?n0003@D7P0j6Pl00T0oh0000<0j6Pl0:0Pl02P8?00
0`2P8?000`3oP000X23`0:0Pl0090:0Pl0X00?l02oooool000[ooooo05H00?l005TZ1`1?10@0=@42
01d10P0N0@80700102X10P0a0P80>@4204P2101<0@D0E`4606021P1U0@L0J@870702101k0@D0P@46
08D31P280`@0R`450903202>0PP0Q`<70:D82`2_20T0/PX;0:l;2`2V@CP0^Z>L0=KEe03=d=40J7=]
08>:P02n`KP0e]KD0=KHf@3Gf]`0em[M0=SLg@3Fc<h0bZ:V0:=RJ01C9bT0P7eg0<S=b03HfmX0dlK9
0:aIG02T7R00W10A09d<4@2O2`l0X0P=09h93P2I20h0TP@:08h52P243@d0XW5a0<K2`P1:>cX0D`P:
08431@240PH0PP44080210210PH0O@8507810P1e0P@0MP8507@11P1e0@L0N@4709@53@2G10`0T`@:
098630293aD0YGUn0;>ja@2kbMD0QXjG06B2CP800?l02Oooool01000o`00j6Pl0?n0003XJ3`30:0P
l0030=1@N03oP000oh0001@0oh00302P8?000`3@D7P0j6Pl0=1@N0040:0Pl0030>QX?03oP000oh00
00P0oh0000@0^3Rd0:0Pl02P8?00j6Pl4@3oP0000`3@D7P0X23`0:0Pl0020:0Pl0800?l02?ooool3
003o001<09b=O02DZ;P0QIjX0;C5d02KYkL0KUeY07=QI`1nOh<0PXN808Z:R@2AT8`0THn909>@R02E
T8L0V8j409^:P@2MRX00XHan0:F;NP2WTW`0Yi=j0:JBM@2ST700YI1^0::@L@2WTW80ZYAb0:NFNP2V
VWl0ZIf40:JNR01XK6@0JWMc05QXI@2^]J`0`/:i0<?1_032`[d0`/:n0;no_02k^kL0^KZe0;Jh]02f
][40]gio0;0F6@2g4QD0[a8I0;0:402b2@d0/`T>0:X8302K3A<0RRll07A8EP2E?TD0X0P?09PL8`1>
?6D0?6BC05EoW@1cUZX0];o>03LdGP0L4dP04R1I00d]H`1<Ji80OIjh07VEY`23VZ@0N8fH04eXM`0?
9T<00A8a03=L@0X00?l02?ooool3003o02`0X23`00<0d51h0?n0003oP0001P3oP0000`3XJ3`0^3Rd
0>QX?0020?n000030;Ph]02P8?00X23`00l0X23`2P00o`0;ooooo`002_ooool0EP00o`00FaH404T2
100a0@408@0102820P0P0@40:04202/10@0i0P80@@4204400@1A0@H0G@8706<1201W0@@0KP4507/2
1`200@D0Q`8708T30`290@80S`8508l320220PH0X@X<0:l;2@2`20X0/0T;0:H`:P2iUI00e]CD0<W>
cP2c]Jl0d]C>0=?Ge03DemP0e]SJ0=KJg@3FfM`0e/S=0;=[LP2B<SP0CA<B079/IP3Ad/h0f=WH0=[@
d`2fKFl0/a`M0;DB502R3100W@`@09l93P2Q20h0X0T>09X63P2G1`d0U0P;08`51`268BD0cK>d09RE
T`0f3@h0N@H;08<21@240P<0Q08508831`1m0@D0O08607X11@1f0@D0N04707T1201k0@H0TP@;09D3
2`2@0PP0T0D:08T7302DGEl0a/_B0;W5d@28T9X0MeaD0P00o`09ooooo`04003o003oP000oh000=1@
N0<0X23`0P3@D7PE0?n000/0X23`00<0d51h0?n0003@D7P0102P8?000`3@D7P0oh000?n0000:0?n0
0080X23`00<0d51h0?n0003oP0003`3oP0000`3@D7P0X23`0:0Pl0020:0Pl0800?l02?ooool3003o
000W0:FCN@2W]l@0Z[k:09j__01VBeL0K18I07Pd=`20OX00PHF708Z;R`2?SX`0THn;09:>R02BS8@0
Uh^509Z7P02NR7l0X8]m0:6;N@2XTGd0Xhad0:>;L02VTG<0XY1b0:>?L@2RTFl0YYAc0:JHO`2WWHL0
Y9^50:>LQP2>SWh0NX1g08b@Q@2ZZj00`<2j0<G2_P31`Kl0`Knm0080_;bg02<0^[Zg0;Ni/`2e][00
^96B0:/J7P2h2`h0]PX<0;D93P2b2Q00YA8E08hd@01F@V00BT5U07`a@`2C2Q80Tb8Y05I3I@0Q@gD0
UJo209B^`@2I]LL0`];L0:6FZ01I7C`0A1m209:]``2_amH0Mi:V07VBY01aR9T04bY?008DA@0243h0
0@lf02La@P0:003o00Sooooo0`00o`040:0Pl0030;Ph]03oP000d51h02D0X23`00<0d51h0?n0003o
P000103oP000103XJ3`0^3Rd0:0Pl03XJ3`20?n000030;Ph]02P8?00X23`00@0X23`00<0oh000;Ph
]02P8?002@2P8?0:003o00_ooooo000:ooooo`1F003o001=5P<0@P<303410@0R0@407P4101l10@0V
0P809`4104020`1<0P<0C`<40582101H0@@0G`4606P11@1_0P<0NP8407h110250PD0Q`4308d21@2C
0PP0U@<909P52P2S20/0[0T;0;0:2`2`2@X0Y1PD0:]^I`30^kP0d=GE0=;Ee@3Df=H0eMWI0=GIf`3G
emT0f]?F0<fZ[`2cDUT0RQlP04PG501cJV80bL_30=_Jf@3JaLT0`WMk0;HR9@2o4Q@0]Q0C0:D=402N
3100W`X?0:493@2O20`0WPP>09L7302D20`0TPH;08h:3`2KDUD0e<3105lm?P1]1@P0PP<708421023
0`@0Q0D707/1101i0@D0M`4307H2101f0@D0N00407d11@2F1P`0U0<908d32@2<0`X0R0D;08I8C02_
/KL0_l[E08ZBW@1cFE42003o00Wooooo00@00?l00>QX?03oP000d51h1@2P8?0E0?n000030=1@N02P
8?00X23`00H0X23`00@0^3Rd0>QX?03oP000d51h102P8?000`3XJ3`0oh000?n0000;0?n000030>QX
?02P8?00d51h0140oh0000<0d51h0:0Pl02P8?000P2P8?02003o00Sooooo0`00o`00C@2BX6L0Z;W5
0:Rfa`1^Hfd0GBd`07doA01[:Rl0PWYl07f0P@26RX/0Shn=09:@S02CSXT0THV209N;Q`2JQX80WhN0
0::;OP2PS7T0YI1j09n=L`2UT7@0XHa`0:6<KP2STg@0XI9c0:>CM@2UVX@0XIb70:>KQP2PVhL0Wi^9
09nMS@2RX9<0ZJVO0;Zk]@32`Kh0`/:o0;jm^`2o_[/0^KZg0;Vk^02c]k80/[Ja0;JFUP2V5a`0]`/=
0;D:3P2U3aD0U3A005U5J`0R?G<0HTm`08TK:`2@3AD0Oblm03LhI00XBgT0TZVm08>GZ@1fS:80Pj:h
0;oAg`33cMP0UW>006HL;`1mRId0Yko@051]S`0L>6L0FgR?00/QA`014D@00Q4l018W?`0W>TL03M`;
00T00?l02?ooool3003o00@0X23`00<0^3Rd0=1@N03oP0009@2P8?000`2h>;@0oh000?n000020?n0
00040>QX?02h>;@0X23`0;Ph]080oh0000<0j6Pl0:0Pl02P8?001P2P8?000`2h>;@0oh000:0Pl009
0:0Pl003052@N000o`000?l000L00?l02oooool000[ooooo02800?l004`J0`0j0P80;P4201h10@0P
0P807@4102D10P0_0@80B0450542101<0P<0C@4205L10`1Q0@<0JP4606l21@1h0@<0O@0208@10P2;
0P@0T@@709L6202E0`T0VP@90:<82@2]2`/0[@T:0:l:2P2R61@0_H5i0<Jm^@3De]L0e=SI0P3HfM`0
8`3Hd]H0aYNN0;ECF02f:2/0_2l/0:agL02i]jh0e=GB0=cAd`37RXl0/cTo0<0L8@3451H0^A<E0:/D
5`2B4AD0PQ0C07X=4P1k3A40PPhA08`>4P2A2`h0TPX<09D8302I20d0RP/B08lk@02/MgL0KPX<0803
1P1n0@<0P@8607h1101l0PH0N@430080MP4200d0N@4407`11`1o0@L0U@@<09H4302>0PX0R`8908P5
2P1n>3/0]K2e0;_6d@27SiT0M5eE00800?l02Oooool01000o`00d51h0?n0003@D7P40:0Pl0030>QX
?03oP000oh0001@0oh001P2P8?001@2h>;@0oh000?n0003oP000d51h00<0X23`00<0d51h0?n0003o
P0003`3oP0000`3@D7P0oh000?n0000?0?n000030=1@N02P8?00X23`0080X23`0P00o`08ooooo`<0
0?l004d0PJmI0:Rb_P23N8H0H1TL06Y0@@1`GF<0HBH]07e`LP1iOX00QHN708f>RP2@T8d0Ti6>09F>
RP2GSXL0VXf409b:PP2QSX<0Wh]h0:>:M@2NQV/0WhY[0:2<J`2OS6X0XY5`0:FFNP2UUWd0YY^60::J
Q`2NV8@0X9Z709jJR02MWH`0WYjA0:FWW@2j_;@0_knk0<;1_@2n_k`0^[jl0;Rm_@2e^[X0/kRh0;2f
/`2lYZL0XAlU0:hB5P2M=3d0JdeW02m4L@13I8`0QYFU08YDF`278B`0GCUF01X_H011HX<0Q9VN0:Nc
^02S]l<0RZRl07FJ[`2ldn40_]3N0<37d`21HW00GEib0:BmcP1;IHT00QQB055]RP0L=e403BA6039<
F`1;HEh0>Ta>01W96009003o00Sooooo0`00o`030:0Pl0040>QX?02h>;@0X23`0?n002H0X23`0P3o
P0000`3XJ3`0^3Rd0:0Pl0020:0Pl0030=1@N03oP000^3Rd00X0X23`00<0^3Rd0:0Pl02P8?00202P
8?000`1@T7P00?l0003o0007003o00_ooooo000:ooooo`0F003o001;5`<0=04202P10@0K0P407P41
01h0000V0@40>`4404D1101:0@@0A`8304/10`1H0@40GP0206D20`1]0@<0O@8508<11@260P<0S046
09011`80U`D800<0V@D80:D92P2]2P/00P2^2P/0:P2P5aD0_HAn0<c4a03Ee]X0eMSK0=SHg03Jcm<0
_8B:0:hZ;P2m5aL0`aDF0<19AP3Aa;d0fmcI0=cEeP37Q8`0^2D/0<0F6P2n5aT0Z1TJ07`F6@1?2`d0
;@@701P41@0B10D04`<201d30`0c10L0F`hB07X>4P2@2Q00VPP>09H93`2=2a80TS<e084J6P2110L0
O`4408421@1h0@80M`4207H10P80M00200d0N@4607`2201l0@L0U0D;09H22@2?0@L0SP8808P32@1i
:2`0[:6V0;o9e@1nQi40L5mH00800?l02Oooool01000o`00oh000?n0003@D7P30:0Pl0030=1@N03o
P000oh0001@0oh001P2P8?000`3@D7P0oh000?n000020?n000<0X23`00<0d51h0?n0003oP000103o
P0000`3@D7P0X23`0:0Pl0020:0Pl0030=1@N03oP000oh0001L0oh00102P8?02003o00Sooooo0`00
o`00C@1T`d00PhB705db=`1d9bT0H24V071EG01R9Rd0NfU/07AhNP24Q8D0SH^:09:?S@2CSXd0THb8
09J;QP2NSXL0Whb509n<P@2OSGX0X8]d09f5J@2QR6X0XHa]09j<J`2ST7<0XI=g0:FJQP2QV8@0[:FF
09fFQP2OV8D0W9Z60::SUP2OWi@0YJJJ0<30^@31`;h0_knn0;c0_P2l`L40]l2n0;Fn^P2e_[/0/KVg
0;fb]02HC500OE5S065GM@1jAe`0VH6:09JPY02HWih0Thb<05IHKP0XAFl0IG^:08JCT02IXZ80U9RN
09NKY@1lQID0VJ6_0<3=fP30d=`0_LoL0;O4d01WMhL0QjFf04]VP00>9eD0=eE]05=]L01CJVd0DVYX
04eTG@0cAT/0::TY00T00?l02?ooool3003o000707QH]02P8?00d51h0?n0003XJ3`0X23`0?n0000V
0:0Pl0050=1@N02h>;@0X23`0=1@N02h>;@06P2P8?000`1@T7P00?l0003o0007003o00_ooooo000:
ooooo`1F003o001?60<0<P8202D20@0L0@407@420281000b0P<0@08404@20P160@80B04204l10P1H
0@80G@8406@11@1`0@H0O`4708@11`280`@0R`8709<22`2F1@X0V@L:09/62@2V2@/0[PX<0;4:302b
2`h0XaXI0;j7Q03=a/H0eMOJ0=OBe`3@]K`0]fec0;8W:@325aP0bAHF0<LE5@2nBTT0elC30=c1a033
Mgd0]RT^0:lI7@2<51H0H0lA02l:2`0[8Qh0>chi04UAC01PIf<0Jg1/06U/IP1BETl0?40j01dH500P
1PH0D`/?08/=4@2@1`X0T@H:08X93P2?51P0P`<608831P1o0@D0M`4207D10P1a0P40LP8307<10`1d
0@@0M@4607X11P2D1P/0V@@:08l22@2<0`P0P`8907@P9@2eYjT0[[S008VAV`1[GU`2003o00Wooooo
00<00?l00?n0003oP000102P8?000`3XJ3`0oh000?n0000D0?n000D0X23`00<0j6Pl0?n0003oP000
0`3oP0020:0Pl0060>QX?03oP000oh000?n0003XJ3`0d51h2@2P8?000`3@D7P0j6Pl0?n0000E0?n0
00@0X23`0P00o`08ooooo`<00?l004d0Al<Q07IVHP1L>3/0JC`m06@P8@1/:c<0J1hR07MXJ`1aMgX0
Ogf108^7Q`2:R8@0RhB108j1P02AOgd0VXN209^8O`2MRH40XXj109^6L@2NQFT0W8EX09f;K@2MSVh0
XYEj0:6EO02SVhH0Y9j=0:fWV`2QW8d0W9R409^IQP2QXID0YjFK0:J[XP2SZjL0[kJe0;g1_@2n`Kh0
^[fn0;Vn_@2g_[d0][bl0;Jj^P2e][H0^jZ^09=GK02N8c80Y@hF07]3E01fRiH0VZ2M09FJU`27T940
Qhb?0964P`2>JFT0STYA094d?@2D9C00TAdW08dO;02@@Dl0Y8BB0;g6d02gc=P0[L;>07nL[@23X:h0
Lh^L06QnQ`1QM7@0FFi[059YI018H6407cI303RM>`09003o00Sooooo0`00o`001`1@T7P0X23`0:0P
l03@D7P0oh000=1@N03oP0009`2P8?00103@D7P0oh000?n0003@D7P60:0Pl0030;Ph]03@D7P0j6Pl
00<0oh0000<0d51h0;Ph]02P8?002`2P8?000`1hF;@00?l0003o0007003o00_ooooo000:ooooo`1F
003o001=5P<0<P4201l10@0I0P407P4102<10@0c0P80A@4404<10P120@80A`4205410`1H0@<0H@82
06P10`1d0P@0P08608H72P250`H0S04609<22P2G10/0W0H:0:07302X2@d0/0X<0;8:3@2d30h0Y1`L
0<:>RP3?b<P0dL;709YXL01X82T0V1dO0<4F5@3551D0b1DE0<LD5@38@T<0bG1c0:dc>@2N7B40H@l@
030D4`10?SP0IVaV09bQW`2l`;/0al[50<c@b`3?d]00cmCB0=7EdP3;clX0`lW20;6d[`1kOgT0?3Xg
03T92P1o2a00S@L:08d420280`L0P04307l1101n0`D0M`4207@10P1b0P40L@8207810`1b0P80LP44
07T11P2B1P`0UP@;08d1202:0`P0P@46078J7P2UTI@0YJbc08:;U01XGel2003o00Wooooo00<00?l0
0?n0003oP000102P8?000`3XJ3`0oh000?n0000D0?n000<0X23`00<0d51h0?n0003oP000203oP000
0`3XJ3`0^3Rd0:0Pl00=0:0Pl0030>QX?03oP000oh0001<0oh00102P8?02003o00Sooooo0`00o`00
C@0Vf@`0Mf5>05Pm>@1XCd`0ISPh05l=4@1j>S`0KUIK06eeM@20Oh80QX2008^3P@28Ogd0QGYf08Ug
M@2AOgT0UhAm09^7O`2LRG/0VXI^09f8K`2OSW<0WI1e0:6BN@2QU7l0Y9f:0:ZTU@2XY9L0/:ZP0:>R
U02MW8`0XZ:D0:RXW@2/[:@0UYnG0;Rm^02DWYd0^;nk0;Vl^P2i_[/0]kbj0;Vm_@2h_;/0/[Re0;Be
/`2VJg80[1@M0;4:3`2[2100OC=:061iS`2IXZ40VIJF09QjO@2@A4/0RQTP09484@2G10`0W@@;09h4
2`2N0`P0V@<;09<33@2921D0QSU:0;Je`@2hb]H0MX^K07:<U`20UId0K86305a_KP1IK6X0BVAU01@W
?P045380>G=600T00?l02?ooool3003o0007052@N02P8?00X23`0:0Pl03@D7P0oh000>QX?00V0:0P
l0050=1@N03oP000oh000?n0003@D7P00`2P8?000`2h>;@0d51h0?n000080?n000030>QX?02P8?00
X23`00X0X23`2@00o`0;ooooo`002_ooool0EP00o`00CQD203D30P0P0@40604101d10P0V0P40<`42
04/21@150@80A04204L10`1>0@<0H08506T21@1/0@@0LP8507@210293a<0NP<408/21`2D0`X0V@D;
09d62`2Q20/0Y`T<0;0=3`2b30h0/``?0:HJ703ASXl0]hjB06/h?@119bP0OFe/0;I/J`2n61T0aQ@F
0<DB5@344aD0^aTM08LH6`1<30l0>28P06mbK@2e^[D0a/g80=3Fd`3Gf]`0emWL0=GIg03Df=/0cm?G
0=7Ff@3@e]P0d]OG0=7Fe`3Ae=L0cm;D0;c0`01QHUh0@P/<07h:3P271PP0P`870801101m0@80NP43
07@00@1d0@80LP8306P20`1`0P@0L`4307@01@1j0PH0T0D;09D22`2>0@X0QP8808421`1f6Al0[I:F
092EW025SI@0JV=Q0P00o`09ooooo`03003o003oP000oh0000@0X23`00<0j6Pl0?n0003oP0005@3o
P0001@2h>;@0d51h0;Ph]02P8?00d51h00H0oh0000<0d51h0;Ph]02P8?00402P8?000`3XJ3`0oh00
0?n0000B0?n000@0X23`0P00o`08ooooo`@00?l004`0Led`060m=P1T?3/0J4a<05LW:01bA4P0K454
07AeM@1iNWd0OWak08AmO025O7T0OgMb085dKP2;NgH0UH=l09N4N`2IQW`0WHYi09^8L@2MSGD0X91k
0:>FP`2VVXH0YYn>0:bWV@2/Yi`0[:RN0:f[X@2[ZJ40[:jS0;Bl/`37cld0`lg<0:ff]@2BW9/0];^i
0;Nl^`2e_Kd0];fl0;:k^02f_;/0/KJe0;:e]02[L7H0[`hF0;894@2W2A<0P3E904aQN`2QRHh0VD99
09@?6@2H1@h0U@8;09L22P2I0PT0W08;09h22P2M0PP0V0<909822@2C0P`0R@<=080e@@2e^/H0HGj>
06R4S`1bRY00GgEh05a_K`1JJf`08SQ=004==0013c@0:3M62@00o`08ooooo`@00?l00P2P8?000`2h
>;@0X23`0=1@N0020=1@N2D0X23`00P0d51h0?n0003oP000oh000=1@N02P8?00^3Rd0>QX?0`0oh00
00<0j6Pl0:0Pl02P8?002@2P8?09003o00_ooooo000:ooooo`1F003o001@4`80>04102@10@0L0@80
6`0102@1000i0@<0B`8504810P160@80B`8304T10P1F0@80J@8606`2101a0PH0H`8206@51P1V0@80
R`8709D2202K1@`0VPD909L62@2R20/0/0`@0;8<3`2e3140[aDH0<QGF`1^92T0<B4O0:RXX`3LemD0
^Wmn0;`K70334aH0`a8F0;/I6`1g41@09P`;05aKF@2[[ZT0dMC?0=[KfP3Hg=d0eM[M0=CIg03Ef]d0
eMSK0=CHg03?eMP0dMCH0=;Ff@3Cf=X0dmKJ0<kDe`3>dmH0bm7D0;o3`013;bh0H`lA07l62P1o0PT0
O04407P00P1g0080M@4207L21@1c0`D0F`820642101b0PD0LP4607P11`2>0`T0T04908h13@270@T0
PP4806`82P2AKfl0RXnC06mhO01^If@2003o00Wooooo00<00?l00?n0003oP000102P8?0I0?n000<0
X23`00<0d51h0?n0003oP0000`3oP00E0:0Pl1@0oh00102P8?02003o00Sooooo1000o`00C@1JJa<0
LTI0060K701V=cT0ITmB06M8CP1Z=S/0M6i`07AeMP1hMgH0OW]k07agMP1kM740OW9_08EbK`2ANWD0
Uh9j09Z8OP2KRGd0XHmo09n>N`2UU8@0YIN90:RLS@2XWhl0ZZFG0:^VW02YYYd0ZjZS0:f/Y02^]J`0
^lC00:bc/02nb/T0/ko10:^a[`2d^KL0]KNg0;:j^@2d_;d0/kZl0;>j^@2a][H0];Je0;>4R`2X4a/0
XA@J08XlBP1PC6P0NDIN09XG8`2Y2100Y0<;09`22P2H0PT0U`8809P2202L0PX0X0<:09`12P2G0`P0
TP8908h22P2:0PT0O@@=08=DG020UJ00SJJ^086HW01YPH80FFe/05=TJP065CP00@de008A<P0K;TD0
2mX:00P00?l02?ooool4003o00040;Ph]02P8?00oh000=1@N080X23`00<0d51h0:0Pl02P8?008`2P
8?001P3@D7P0oh000?n0003XJ3`0X23`0=1@N0l0oh0000<0d51h0:0Pl02P8?00202P8?000`1@T7P0
0?l0003o0006003o00_ooooo000:ooooo`09003o001B4`80?P8102H10@0O0P407`8202<20@0`0@80
A`<50080?P4202T0BP8304l20`1I0PD0IP4406T10P1`0P@0L0l?08L^;P1g1PP0S@8709@3202E0`L0
U`D909<4202Q2Pd0[`dA0;0;3`2c3180/1<G0:Le<`1`A3l0YZJQ0=KGe`3Jf=T0]X5n0;PI6P2n5AT0
Y1HJ06@>4014<c00TIF@0<_=b`3Hf]P0g^7P0=cMg`3IgMl0e]_N0=CJg@3Efmh0e=WK0=KJg0020=;F
f@0P0=CGfP3Df=/0dMOH0=3Ge`3?eMD0cM;E0<cAdP2BShh0@Pl?07T930200`P0O@4507/1101i0@@0
NP8407P10`1e0@<0KP<506410`1d0PH0M00707T11P2@10X0U@4809022P290`P0P`4706d9302NO7d0
PHB706edN01`J6H2003o00Wooooo00@00?l00?n0003oP000d51h0`2P8?000`3XJ3`0oh000?n0000E
0?n000050;Ph]02P8?00X23`0:0Pl03@D7P00`3oP0000`3XJ3`0^3Rd0:0Pl00D0:0Pl0030=1@N03o
P000oh000140oh00102P8?02003o00Sooooo1000o`00C@16UA<0LD<n05`G5P1Y82@0Hc<e06U5BP1W
<380L6U/06i^K`1aKfl0NgQh07mlN@1iMG00O6m]08=]J`2<MG00UX5k09R5N`2PSX00Y9>40::BP`2S
UHH0XIB40:FJRP2YWY40Z:2F0:ZUW02/ZJ00[jnU0:f]Y02a]Jl0_LC20;>g/`33cLh0]l;40;6h]P2d
^KP0][Zk0;>k^P2a^kT0/;Vi0;Bk^P2_]K@0[[Je0;:JW@2A@TT0H4i^059;LP26<4D0W``H0:H53@2Y
1P`0Y@@;09h32P2K0`T0U`8809<32@2?2100SaTS08DY=P1d;3L0MbXe07XD7`231@`0Q08;07@F7`1g
MX40I7^406f5Q`1RNg/0Fg1^04=FHP0243T0320n03YEG@0[@T`04M8C00P00?l02?ooool4003o0007
0:R8?02P8?00oh000?n0003@D7P0^3Rd0=1@N00V0:0Pl0040=1@N02h>;@0X23`0>QX?0X0oh0000<0
j6Pl0=1@N03@D7P0103oP00:0:0Pl003052@N000o`000?l000H00?l02oooool000[ooooo05H00?l0
05@A0P0n0P809`4101l10@0N0P80704102L10@0h0P80=08203H10P1=0`D0DP4205d21P1R0@<0J083
0741101l1`T0P`/<08L31`2@0PL0T`<809@3202H10X0V`L;09H72P2L20/0[0`@0;<<402V6Ad0ahj:
0<K1_P3Gf]/0f=[N0=WIfP2fPX00ZAhM06DA400i8A/0MGE`0<C9aP3Hg=`0gn7Q0=kQi03Kh><0fmoQ
0=SLgP3Ffmd0eMWM0=CIg03Ef]d0eMWL0=3Ff03Af=X0eMOL0=;GfP3>e]P0d=KI0<oEe`3;d]@0bm3C
0<[<c@2;Lfh0LA8C08431`1n00D0OP4507`1101g0@D0N04407L11@1d0PH0L`4707/22@1i0@L0N044
08h32@2D0PP0S`<908P220270PP0KP@908]NH`22OX<0HfEZ079YJ0800?l02Oooool01000o`00oh00
0?n0003@D7P30:0Pl0030=1@N03oP000oh0001@0oh0000<0d51h0:0Pl02P8?000P2P8?00103@D7P0
oh000>QX?03@D7PH0:0Pl1<0oh00102P8?02003o00Sooooo1000o`00C@0iW@X0KdDo06Po?01N8bD0
KbX`068G701Z?Sl0H5mP06EVI`1ZJ6X0M79e07YgM`1oN7D0Ng1/07m]J02;Mg40V8Am09Z6O02QSh40
Xi620:2@P02OSgl0X9J50::JR`2VWY80ZZ6H0:nZX@2`[jH0[jnV0:naZ02//JX0/KRe0;k5a`2i`L<0
/;Ne0;Nk^@2Z/K<0V:BV0:Vd/@2^^KH0[KJe0:nh]`2/][<0ZKBa0:jb/P2PWZP0JU=d09@Q<`2V2A40
Z@H<0:P42P2V10X0XP<;09/3302A1`l0QR4]06XeC016>el0:cET024bH014EW/0FFV906U]Q01e>4P0
P0D@07P53`1/Ef@0PINP07B<SP1RNgX0Fg5_03aEH0056S`0?5UO04mVH@0fC5408JHX00P00?l02?oo
ool4003o00030830002P8?00X23`0080j6Pl00<0oh000=1@N02P8?009P2P8?000`2h>;@0oh000?n0
00060?n000030>QX?03@D7P0X23`00D0X23`00@0j6Pl0?n0003oP000^3Rd2@2P8?000`1@T7P00?l0
003o0006003o00_ooooo000:ooooo`11003o001D3040A@8203410P0T0@40704201/10@0W0@80=`42
03D20P0^0@40@`8305/3201P0PH0I@8306`2101c0P@0NP8407l110280@H0SP8609<3202F10X0V@D:
09/62@2N2@X0W@L90:h=3`2e3A40Y1/K0;n<R@3=bLP0e]SL0=WJgP3He]X0TWQj044I5`1fMFh0`lW2
0=CGe@3IgMl0f]kQ0>;Si`3NhN@0f^3Q0=cOh03Hg=h0emgN0=CIg03Eem/0d/oC0<k5b`30/KL0^J:Z
0;RLY`2jXZX0aKc10=7CeP3@eML0b];D0<_Ae03:d=80`[Zk07H^<@2010T00P1n0@H00`1k0@D0KP83
07421@0207P21P0>07X11P1j0@L0O08807/21@2@10/0T`8908h22@270@P0P`<806l42028Ee/0Ph64
055EFP1]IVD2003o00Wooooo00@00?l00?n0003oP000j6Pl0`2P8?000`2h>;@0oh000?n0000D0?n0
00D0X23`00<0^3Rd0=1@N02P8?006@2P8?000`3@D7P0oh000?n0000@0?n000@0X23`0P00o`08oooo
o`@00?l004d0?9h807M:A01V?cl0ICXk06082P1V;Rh0GeAF05UKF`1RH680JfQW075[KP1dKW00OWIc
089eL`22L6`0SgQb09J3NP2HQG`0W8an09j?OP2OTh00W8mo09bBP02SVX/0YifB0:^TW02/ZJ80/JnX
0:b]Y02[[JD0ZjnY0:N]Z`2]/[40[K:`0:bb/02d^;T0WjJX09VVYP2KZ:H0[[Rg0:bf]`2^][P0[[Bf
0:Va/02`/K40[gb50:4K9P2`2A40ZPD<0:`73P2X10X0Y0D>09H:4@23:CL0D3MJ01d_I@0Z@G80EeAf
07U;H@25=DH0RC4n08HjA`26MGh0/[Bm07XW=01m10l0D2Df07J>U@1aR8H0GgIc05YbL012G6@083Y>
055WI`1?IFD07SI800iZ9P08003o00Sooooo1000o`001P20`000X23`0:0Pl03@D7P0oh000>QX?2L0
X23`00<0^3Rd0?n0003oP0001@3oP0000`3XJ3`0^3Rd0:0Pl0020:0Pl0@0d51h00D0^3Rd0:0Pl03X
J3`0oh000=1@N00:0:0Pl0P00?l02oooool000[ooooo05P00?l005D:0@190P80>@4102/10@0O0@40
6`4102P10@0j0P80<04201l1000[0@80B`4505l10`1V0@40KP8307010@1f0@80O@8308D10P2<0PD0
T0@709L52`2H0`P0W@D:0:472P2Y2@`0/0/=0;<<3`2T7Q`0aYB>0<k;b@3Hem`0d/G;08UeO00V9BD0
NH9j0<_?c03Lgn00f]kQ0=cPhP3OhND0h>?W0=gRi03LhN40fmoP0=SJg`3Mfmh0e/C<0;^=V@2KG6H0
Qca407dX<`1i8Rd0NQTU088K9`22<SX0]9JJ0=7@e03;dMD0bM7C0<_@dP3?blh0P4A808052`220@P0
P@0507h10`1j0P@0N08507T11@1g0@D0NP8607/11`1o10X0P08809<32`2C0@L0SP<908H11P200@D0
K@<708AADP1hMWL0EEMK06MPG`0OS@P00?l02Oooool01@00o`00oh000?n0003oP000d51h0080X23`
00D0d51h0?n0003@D7P0X23`0=1@N00B0?n001@0X23`1`3oP0060:0Pl0030=1@N03oP000oh000100
oh001@2P8?000`00o`3oooooooooo`06ooooo`@00?l004d0>jh707a?@`1V<C00IRl_05/a<@1LD5<0
D51D05EGF01OGf40IVIX071[K@1eKVh0NgIa08IjN026LW40TGUf09B1N`2EQ7d0UhYk0:2@P@2QU8@0
WI5n0:6FP`2VW8`0ZJ6E0:^WW@2/ZZ80/[:Y0:VZX`2YZJ<0ZJVT0:b_[02[/:/0[K6_0:^d/@2c^;L0
/KNg0::/[@2X/k<0Z[Fd0:Rb/`2Y];@0Z[>e0:f]/@2_NX80YaXT0;8:4@2^1Ph0ZP@?0:/63@2P1`d0
SB<]05i0H00J;VH0:dUe06=]P`24C5P0SA<N09H53`2I0Pd0U`@=080P;`1;Dg@0Vk[?07m=G`1k1A40
CR4c05UgP01VOW`0HGIe05eaL@1DJfh08Ca<04MPJ@0P=4`00Q<k00@U<@08003o00Sooooo1000o`00
0`1XZ3`0X23`0=1@N0020=1@N2L0X23`00<0^3Rd0?n0003oP000103oP0000`3XJ3`0^3Rd0:0Pl002
0:0Pl0030=1@N03oP000oh000080oh0000H0j6Pl0:0Pl02P8?00d51h0?n0003@D7P:0:0Pl0P00?l0
2oooool000[ooooo05P05^d605hI3P1:0`80@@8202l20P0P0@406P4102L10@0n0P@0>@P:05TS:00e
1@H0?P850602101Y0@<0K`8407810`1g0@<0O`4408H10`2<0PD0T`@909D3202I1@T0W@L90:<8302]
2Pl0/P/@0;D=4@2S7Qh0`Y>@0<o9b@39/KL0LD]B034T8`1eO7L0bm7?0=oRi03Jg^40fn3S0>7RiP3N
gn<0g>3S0=kQi03ShnH0h=7H0=:Z]031N840Z45;08HQ:01V5AT0BPlC034=4`0]20/0G@lA08PC5P2A
41@0RRDZ0:MlP038alX0b];D0<_Be03>d=80Pe1C080730230`L0PP4508021P210@P0P08807`11@1j
0@H0NP4407l220211@/0O`<90987302D0`P0T@<:08X2201o0@@0K0<507i:B`24Oh40BTa>065GEP0O
S@L00?l02Oooool01@0Xb3`0oh000?n0003oP000j6Pl0080X23`00<0d51h0?n0003XJ3`00P3@D7PB
0?n00100X23`0P3@D7P30?n000<0d51h103oP0000`3@D7P0X23`0:0Pl0020:0Pl0030=1@N03oP000
oh000100oh001@2P8?000`00o`3oooooooooo`06ooooo`@00?l004d09=@7081EAP1M61L0I2DU05a>
D@1CCe@0D4eA05ACE@1IFUd0HV9U06eYJ@1dL6l0OGMc08=fMP26LW40SWQd095nN02CQG`0VHYo09n>
P02RU8@0YIV80:BJQ`2XXY00[JFH0:VUV`2^ZZ<0/JnX09nQV@2GV8l0U9J?0:BVX@2Z[:L0[k>`0:jg
]@2a][P0]KVj0;2f^P2[][L0ZKBd0:^b]P2/];L0[;2c0:moQ`2U72H0/P/A0;<9402^1P`0Z`P=09`@
5`1n?540:cMZ02E9O01UOY80Og^307l`?02C2180W0<809`21`2I0PX0Ra4K044eF@17MIh0//SK07Y2
D@1g1@l0A2Ho06F3TP1`QXH0HGEd05mcLP1HKVh07cM<00PKA0013c`00@hi00HI=`08003o00Sooooo
1000o`00101@T7P0X23`0?n0003XJ3`W0:0Pl0030;Ph]03oP000oh0000@0oh0000<0d51h0:0Pl02P
8?000P2P8?000`3XJ3`0oh000?n000030?n000060;Ph]02P8?00X23`0=1@N03oP000^3Rd2P2P8?08
003o00_ooooo000:ooooo`1H02[I2P1Z;ah0@@@203l30P0]0@808@8201`10@0Z0@80>P<302`10P15
0`@0@@<402`10P1K0PH0I@4406L10P1^0@40N04307h20P250@80R`840943202H1@T0UP@809d62@2T
20`0[@T>0;<;3`2g30l0ZA/M0=^EUP2oPHL0Kb/_06MIF034al@0g^7Q0=oSi@3Lh^@0f]oR0=_OhP3O
h>@0fmgP0=kLh03Qc=<0cXJA0;XmBP2V8b`0Na@J03/:3@0]9B40A4U305eVH01mQX40Ti>=0:ZCS02Z
KF/0T1TL08l;401l8B<0[i^K0<cCe@3:dm@0c/oA07a3A`221`X0QPD608D4202310P0P08807h2201j
0@H0N@8507X21P1n0PH0N@D906d2102B3Q80U`@;09H32P2<0PL0P@4706/31`1jATL0OGIh059@E01H
AdD08H`6003o00Wooooo00D0D91h0?n0003oP000oh000>QX?0020:0Pl0030=1@N03oP000j6Pl0080
oh0000<0d51h0?n0003oP000403oP0000`3@D7P0oh000:0Pl0090:0Pl0030;Ph]03@D7P0oh000080
oh0000<0d51h0:0Pl02P8?00102P8?00103@D7P0oh000?n0003oP0040:0Pl0030=1@N03oP000oh00
0100oh001@2P8?000`00o`3oooooooooo`06ooooo`@00?l004h0:MP807aC?01O?CX0Ie1>05aDE`1;
B4`0BTU;05ECE@1FEU/0GEeQ06ATI@1cKfl0O7Ad089eM029MW40SW]f095nN@2DPWX0VXUn09n>O`2Q
U8@0YYV90:FJR@2ZXY80[ZFK0:ZSV`2ZYZ00[:VT09>DR`2;SX40S8j209FFS@2UZ:@0YZn/0:Zc/P2_
];H0/[Jh0:fd]P2[]KH0Z[6c0;2d^02a/kH0]I:H0:<R;02`2a80/@T@0;073@2b2a00Vb8[05i1I`0G
=W40BfnB07jFW`28SI00OS]508d5402F0`X0V08809P32@2=1@h0Lc9;02M:N@2ZcN40ZZFd07HH9P1f
3aX0:BE405egP`1TNWL0H7Qc05YaKP1JKV`07c9:008>@0013Sh00a@g0319EP08f0P7003o00Sooooo
1000o`000`1@T7P0X23`0;Ph]00W0:0Pl0030;Ph]03oP000oh0000@0oh0000<0^3Rd0:0Pl02P8?00
0P2P8?000`3XJ3`0oh000?n000030?n000040=1@N02P8?00X23`0:0Pl080oh002`2P8?000`1@T7P0
0?l0003o0005003o00_ooooo000:ooooo`1H02WI201N9A00?00103h30`0^0@809@4102@10@0_0P80
>@<302<10@0n10H0=@<402<10P1F0PD0G@4206010`1Z0@80M04207T10P200@80Q`8408l3202D0PP0
U@<809P62P2R20/0[`X?0;P=402o4180`1HH0<<b<`1h6a`0MVMS0=GJf03QiNH0i>SY0=oTiP3Jgn80
fmoR0=cOhP3Ng>40d;2g0;m^M`2m=d00_ahT07/@4`0h4180EE1=09bSW`34cLT0c]KD0=CHf03CemP0
aL3509AWK`2:8RT0T`L>09083@1m6QX0U7mm0<gEe@3=e=H0^k>f07D[;P261PX0Q@@808<11P220`P0
OP8807P3201i1@/0N@<708032@240`T0O@T=07@71`2S4QD0V`T?09X52`2@0PT0PP4706h4201kA4H0
Q7eo04E2@@1D@S`08Hh6003o00Wooooo00<0D91h0?n0003oP0000P3oP0020:0Pl0060>QX?03oP000
X23`0?n0003XJ3`0d51h4`3oP0000`2h>;@0X23`0:0Pl0060:0Pl0030;Ph]03@D7P0oh000080oh00
00<0d51h0:0Pl02P8?001@2P8?000`3@D7P0oh000?n000020?n000@0X23`00<0j6Pl0?n0003oP000
403oP0000`3@D7P0X23`0:0Pl0020:0Pl003003o0?oooooooooo00Kooooo1000o`00;00<m`<0OeHi
06ALF@1RGeh0FUEH04]5B017ADP0E59G051DE`1IGEh0HV=T06m]KP1lLgD0PGEe08YiMP2<NgD0T7ih
09J3O02KRWh0Vhf009j@P02RU8<0XiV90:ZSU@2ZYIX0ZJFM0:VVWP2XZJ40UIR>08V<O`2:SWl0S965
09VQV@2U[jh0Yk6b0:fa]P2b][X0[K:e0:J/[`2X/;80ZZfb0;RW[P2O=3l0[``C0P2b2100802Z2Q00
VBhn044nLP0RBH00K8^N08JJW@24UI@0Qg=h080=5`2A0``0R0H=08<N:P1^;d<0F3QD02XfJ01jX/<0
/[c;08A6EP201a80HbHj02a2I01[Qhd0IWUi06=iL`1LMG40FW1`02e0D`014C`0329303A@G01BJVT0
3Lh>1`00o`08ooooo`@00?l000<0:<Pl0:0Pl02P8?009`2P8?050?n000030>QX?02P8?00X23`00@0
X23`103oP0020=1@N0<0X23`00<0j6Pl0?n0003@D7P02`2P8?000`1@T7P00?l0003o0005003o00_o
oooo000:ooooo`0G02cK2`1A50@0@@4004820`0^0@809`4102<0000_0@80>0<301/10@0W10H07@42
02P20`1K10H0EP0105`10P1Z0@<0M04307P10P1n0@<0Q@4408l1202F10/00P2G1@X0?`2P20`0Z`T>
0;L=3`2k3@l0_1@F08PE5@1C=S<0bm;?0=oWi`3RinL0i>SZ0=gRi03Hg^40f]kR0>;Oh`3CYjl0/3Ho
0;lI7`375a/0QA8D03l^:P2QYj40cmCC0=[Og`3Dfmh0dm[L0=CHf`3AdmH0UFU`08@I802C2A00T`<<
08h93P1R4Q<0N71]0<[CdP3;d]@0W8R907@H6`2610X0PP<808011`200PT0O@4906D10`1L0040N0D:
08@2202710X0O0@806/3102H41<0Q`@609852`2A0PP0PP450744201oADD0P7Mh04e;B01:>S@08Hl6
003o0009ooooo`03052@N03oP000oh000080oh000P2P8?020?n000<0X23`00<0d51h0?n0003oP000
403oP0000`3@D7P0X23`0:0Pl0060:0Pl0030=1@N03oP000oh000080oh00202P8?000`3@D7P0oh00
0?n000030?n000@0X23`503oP0040:0Pl003003o0?oooooooooo00Kooooo1@00o`00C@1YNcD0I5aK
06ARH@1IEED0BTA404M5A`1DDUD0DU9E05UIFP1RH640KVYZ07Q`L021M7H0Pg=b08mlM`2CP7T0U8=m
09J8O@2IS7`0Uhai09N;NP2ITGh0XIZ90::OT@2TXiT0ZZNP0:^[Y@2UXih0S8n408V=O`2<T8D0TYVB
0:>]ZP2Y/[40[[Be0:jf]`2W/;@0YZna0:^`]02jZk00Z5aU0:d@602e2a40/@T@0:X<4P2?=dX0<3]e
03MPT@23WJT0T:2Q08nNW@23TY00PEUL08d74P272100HC9;028aIP0?;6/0DgJR08NM_`2UW[D0QD1@
0849501f7RX09bQ@04YZPP1cRX`0GWAc06=hMP1MLg00FVm^03]CFP0V@Dl0BVQ[04mYI`1>IfL07Z8R
00L00?l02?ooool5003o02P0X23`00<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0X23`0:0Pl0040:0P
l0040=1@N03oP000oh000;Ph]0D0X23`00<0j6Pl0?n0003XJ3`0302P8?000`1@T7P00?l0003o0005
003o00_ooooo000:ooooo`1H02WH2P1:2`40@04104020P0`0P809P4102@10@0/0@40=P8201P20P07
0@4040@403L2101J0@<0E@0005T10@1[0P80MP4307X10`1o0@80Q`4308h3202B10/0U@D;09052P2F
1``0YPX>0;8;3`2h3a80Pa0B04h/:`2_/Jh0g^;S0>7Uj03QiNL0hnGX0>7RiP3Oh>@0gm3F0=RIXP2o
=Sd0`aHK0;lB5@2I51H0G3`i0;W0^@3FgMT0f]oO0=SNh03Dfmd0dmWK0=?GfP2fWZ<0RB8X09D;3`2C
1P`0TPH;074<3`0f61L0Wj>Q0<cAdP2k/[D0LcTl07`<4@210P/0O@4907h220210`P0PP8807l42P1^
0`P0LP@608P42P280`P0QPH:06`82P1T2Pd0K@@708d52`2A0`P0QP4707H42022ATP0SXN804U7AP19
=C808Hd5003o00Wooooo00<0D91h0?n0003oP0000P3oP0020:0Pl0030=1@N03oP000X23`0080X23`
00<0j6Pl0?n0003oP0003`3oP0000`3@D7P0X23`0:0Pl0060:0Pl0030>QX?03oP000oh000080oh00
00<0^3Rd0:0Pl02P8?001@2P8?000`2h>;@0oh000?n000030?n000050=1@N02P8?00X23`0:0Pl03@
D7P0503oP0040:0Pl003003o0?oooooooooo00Kooooo1@00o`00C@1WSS/0JV1O06UVH@1JE5@0Bd13
04a2A@1ECU00DDm@05MFF01MFeX0JfEU07E^K@1nLg@0Rgam099mO@2BPGX0TX1k091nM02APW@0THAe
0964L@2CR7<0UXah09J@P`2MVY40ZJJQ0:NVX`2[ZJH0Y:>N09VMUP2KWYP0WJ:N0:>^ZP2U/[80[;Be
0:B][`2OZj/0XJZ/0;2OYP2VG6P0Y1`T0;<<4P2^20d0Y0/A08XjC`0U>gP0AfjK096R[P2CWj80TInP
08jMWP24Ti80QVU/08X:4`275b40<bYB06^1Y02>U:d0TWjD08i8GP2752@0QPPA07PU=00c;UP09dI[
086IX@1/P8<0HGEc065gM@1MMG80Eg5/05E/JP1?J6H0D6aY04=QI@0B;D808W`b00L00?l02?ooool5
003o02L0X23`00<0d51h0?n0003oP0000P3oP0000`3XJ3`0X23`0:0Pl0050:0Pl0030;Ph]03oP000
oh0000<0X23`00D0^3Rd0=1@N03oP000oh000>QX?00>0:0Pl0L00?l02oooool000[ooooo05P09]@8
04D70@0m0@40>P8302T10P0S0@80:`8103810P0i0@808P8203`a<@1I?D40C`<705H10P1E0@40GP83
06`10P1g0P@0O04307l20P260P80RP8608T11P2>0PP0S`<909D6302T2@h0Z`/?08PA501[DU00a/W9
0=WMgP3Lh><0g^?V0=gSi03PiN@0gMSM0<N=V02n@DX0c28W0=DG6P3651P0VaPI0798A@3;c/`0f]oO
0=WOg`3Hg]l0emcO0=CIg03EfM`0c<G808df>`2L3140T@H908X52P1_2Pl0>R@R09BIU@39cLd0bLS=
08IDF`1i3A80P0@:07h22@1m0PX0O@4:07l220220PT0P`<808022@1n0`L0Q@@808H22@260`T0TB@W
080m?P1U1@T0U0H=09021`250@L0NP@:08M9B`25O7d0Dda>040]:P0OR`@00?l02Oooool01`1@T7P0
oh000?n0003oP000d51h0:0Pl03@D7P00P3oP0000`2h>;@0X23`0;Ph]00A0?n000030;Ph]02P8?00
X23`00D0X23`00<0d51h0?n0003oP0000`3oP0000`2h>;@0X23`0:0Pl0060:0Pl0030>QX?03oP000
oh000080oh0000D0^3Rd0:0Pl02P8?00X23`0=1@N00E0?n000@0X23`00<00?l0ooooooooool01_oo
ool5003o001=06R:;P1]HEh0K6QV065JF`1C?D40BBHY05I8C01CDED0EEAF05eKFP1/IVL0NFi_08Af
N02=Ng/0RgQf095mNP2?N7<0SGA]08YgJ@2>P6h0U8Ma09R:MP2DRWL0TXil096>P@2KVi40Z:VP0:VZ
Y02/[J/0XZNS09jTX02PYJ<0XJVX0:J_/02X/k80Xk2^0:F`[`2SZJX0X69[09lI8`2_3Q@0[@X@0:8<
4@27=TL09CQa04a^V02JT9d0WFih09]HI02KJG80Uh^>08VEU@2IUiX0O2/d08H74P267c00QRTh08@F
9@2821H0S0TB08@M9`1P=Dl07RQO02e>O01mUZ<0P9:F06f0PP1TMgH0HgQe05ieL`1GLF`0DfeW04iW
J00]BET01Q]0004C?00RDCh01`00o`08ooooo`D00?l01@2P8?000`2h>;@0X23`0:0Pl00N0:0Pl003
0=1@N03oP000oh000080oh0000@0j6Pl0:0Pl02P8?00X23`0`3@D7P30:0Pl0030>QX?03oP000oh00
00D0oh0000<0d51h0:0Pl02P8?003@2P8?07003o00_ooooo000:ooooo`1202?A1@141@00?0420341
0@0V00408@4002T10@0c0@40?04103/41P0l5ah0AA<J05@21@1D0P<0D04205/30`1X0P@0M@4507X1
0`1n0080Q04208L1102;0@D0SP4609D42`2H0PL0X`T<09P=4@1761T0^Kfl0=SJg03Ff]d0f=gP0=cQ
i03Kgn80gmoS0<FAW02f9S40dAXP0=PI6P3F5QL0/aLI05`F5`2l]K@0f]gP0=WLh03Gfmh0emcO0=OK
g@3FfMd0e]SM0;6;T`2D4AT0W0H=08l72`1f3A009PP707j6P03Ae=@0cM3C0:^IW@1g6R00QPL>08<3
2P1o0@P0OP490P1o0PX050220@P0P04807l220200PP0Q0<908P32@290`X0S0/@0:ho@@2H41D0W`H<
09011P250@D0O0D:07dl@02ERhh0E4m@03DS7`0NRP800?l02Oooool0101@T7P0oh000?n0003oP003
0:0Pl0<0oh0000<0X23`0=1@N03oP0003`3oP0000`3@D7P0X23`0:0Pl0050:0Pl0030=1@N03oP000
oh0000@0oh00202P8?000`3@D7P0oh000?n000020?n000030=1@N02P8?00X23`0080X23`5P3oP004
0:0Pl003003o0?oooooooooo00Kooooo1@00o`00C@1_QR80Lf=N06eYJP1TCe80EB8U04TM7P1FAT`0
EeEI059BE@1KFE/0KFEX07Y_L029O7/0TGel08ijM`2?NGL0S7A^08U^IP2:M6H0SG]Y09F6L02KRg@0
VI5m09B@P@2@T880TiB80::QV`2[[:P0ZjZY0:^/[02WZj/0Xj^/0:2Y[02T[[00Z;>b0:Ba[P2OZZX0
]JN[09h/<`2a3A@0/`/@0:l;402H<d40=T9h05IKS02CB5T0U1DQ09@<5@2@41/0TPlJ08/U<02CR8d0
PI>F096>T@1iCE80Lb@b07TN;`1k9S@0Jc5404lgE@0_<V00<c=T05Q8J@1gGW80RgZ207Z0P`1/P800
IGUh06EiM`1MLg80F6m_04EQJP0C:dT00A0n008?@@0143`08C=300L00?l02?ooool5003o00@0X23`
00<0j6Pl0;Ph]02P8?007`2P8?040?n000040>QX?02P8?00X23`0>QX?0D0oh000`2P8?020=1@N004
0?n0003XJ3`0d51h0;Ph]080X23`00<0^3Rd0=1@N02P8?00302P8?07003o00_ooooo000:ooooo`1H
02;@1@171P40>`4102l10P0Z0P809@4102/10@0h0@80@08204H2101820/0A`<505H1101C0P@0B@83
05XH6@1Q5AH0IP8407L2101m0P<0P`8208H10P290@<0S04409821`2L1`X0W@h?068<3@1jLVh0emWJ
0=WKgP3Hf]d0emcO0=WMh03Ie=T0aiRQ0;Ta>`3;5Q/0f1PL0=XI6P3B6AT0Ub`[0:VBT@3If]X0fmgO
0=SLgP3FfMd0f=CJ0<fe_@2aPh`0YVE`09hd?@2S31D0T0/B060:3@0]3@d0HfQU0<?:b@3AdmH0_[Fm
07hl@`242A40R0<:08H32`1o0PT0O`4907h1201n0PP0P@890881201o0PP0P0870883202510X0R@89
09T93P2V3A40Z@`?0:872`2D0`P0R08607/5202;C4h0PgMk05iFF00Y5a807HP2003o00Wooooo00@0
D91h0?n0003oP000oh000P2P8?0E0?n000030>QX?02P8?00X23`00D0X23`00<0^3Rd0?n0003oP000
0`3oP0000`3XJ3`0X23`0:0Pl0050:0Pl080d51h103oP0000`2h>;@0X23`0:0Pl0020:0Pl0030>QX
?03oP000oh0001@0oh00102P8?000`00o`3oooooooooo`06ooooo`D00?l004h0Bk8M07a/J01aI6D0
HBd_05LS901=>ST0DDM805aBF@1KEEX0GEUM06mWJ`1jL740RGio08ilN`2@NgT0SGEf08=/J023Jf80
RG5O08]hH`2BPfX0TX9W09Z@NP2GUHP0TI>809:CS02@T8/0V9fJ0:V/[02Z[Jh0ZK:b0:^a]02RZJ/0
Xjf^0:Ja[P2Z]K80YZn_0;66SP2Z51h0]``B0;@<4P2P72P0DT=a05i;O@2E7SD0WP`H08LQ;@1S?U`0
@D1V07LmDP2931H0I4EJ06b:U`2GZJh0LHB<05M[QP0K=6D0@5V403I6M019>F00MBa6084?80281A80
Q`@@07h74@1g9B`0PG9d06YiN@1TN7P0FW1g03A;H`076DT00@e3008>?`014Cd05Bm:049GG006i@D6
003o00Sooooo1@00o`000`1@T7P0X23`0:0Pl0020=1@N200X23`00<0d51h0?n0003oP0000P3oP002
0;Ph]080oh0000H0j6Pl0=1@N02P8?00d51h0?n0003@D7P70:0Pl0030;Ph]03@D7P0oh0000<0oh00
00<0j6Pl0:0Pl02P8?002@2P8?000`0Xb3`00?l0003o0004003o00_ooooo000:ooooo`1H02;@1@1;
1P80?P8202h10@0V0@409`4102h10P0h0P80@@8204010P120@80B082050310160P80JQ`P07/P:01k
4aT0FP8406<31@1i0P<0P`4308<10@260@80R`450982202C2A00H@X=05i<B035b/L0f=WK0=OHg03F
f=/0eMWL0<Za^02XEUl0[B8Y0<8E5P3?5AD0e1DG0=HF6036;Bd0cZNV0=SGf03Kg^40f]kQ0=O?e031
VZ@0[eAQ0:TP:`2O3QD0W@dE09H>5@1Y2Pl0:`h?03m3?`28TX`0bLk=0<c=d@2`Vj<0P3Q208@94@27
1@X0Q`@908P42@220@H0PP8608031`1n0PL0P0890803201k0@D0OP<708421`230`X0Q`4709`83@2/
2Pl0[@X@0:863@2F0PP0R04607T42021@d@0T8>505aAE00M2`L06hL2003o00Wooooo00H0D91h0?n0
003oP000j6Pl0:0Pl02h>;@E0?n000030;Ph]02P8?00X23`00<0X23`00<0^3Rd0=1@N03oP0001@3o
P0000`3@D7P0X23`0:0Pl0020:0Pl0030=1@N03XJ3`0oh0000@0oh0000<0^3Rd0:0Pl02P8?000`2P
8?000`3XJ3`0oh000?n0000E0?n000@0X23`00<00?l0ooooooooool01_ooool5003o001>05:k8`1n
KfP0IdE406<b<01?>3X0BCi00595BP1MDUL0H5IN06AJH01bIV/0OW=f08]nP02>OGd0SWaj08QbL01n
If80OVII08MaH`28MfD0T89_09J9M@2MTX00U96409FFRP2EU8X0RhZ208Z;P`2LWiX0ZJbZ0:B][@2/
][L0ZK6d0:Na/@2[];H0Yk2b0:V]/02RFV@0/@hH0;H<502/3aL0O4MS07AJP02L6b`0WQLR06diF`0S
>WH0;U>606]iU023=TD0S0/F058cE`1PP9P0RJ2W07fEX`2N^l`0HGbD09^EYP1o=TP0Q`TG08l23@2?
0@`0SP4:08/22@250PT0P0<:07@S:`1bMGP0@e]^010WC`024TT00A5;008?A0024Ch07cmC04IWI`1<
HV803<`;1P00o`08ooooo`D00?l000@0D91h0:0Pl02P8?00d51h8@2P8?001P3@D7P0oh000?n0003o
P000d51h0;Ph]080oh0000L0d51h0:0Pl02P8?00X23`0>QX?03oP000d51h00H0X23`00<0j6Pl0?n0
003oP0001@3oP0000`3XJ3`0X23`0:0Pl0080:0Pl003052@N000o`000?l000@00?l02oooool000[o
oooo01H08<l304X60@100@80<`4202`10@0^0@40;P4203D10P100@80@@8203d00@140P80@`8205L2
101_0PH0NP8908@3201X10L0B`0107831@200@80Q0420P270@<0;02=1@L0G`/>05E5@@2k_;T0e=CH
0=CFf@3Fem`0fMKK0<FQZ02V;cP0]1DL0;TA5`2l41<0`a0A0<hC5@3@51H0cE]M0=C;c03LgMh0g=oQ
0=32bP2WD5/0ZA`V0:lC702N4AP0K`/A04L82`0V2P/0@D=209FQX031b//0dmWK0<G4b`2=GfH0Ob0X
08<=502720l0Q@<:08P32@280`P0Q0<708421`1o0@P0O0870P1o0PT04P1m0PL0OP8808<320240PP0
RP<809l93@2Z2100Z`T?0:H63@2K10/0R04707T42@29BD`0TH:304m3@`0K1`D06HD1003o00Wooooo
00D0D91h0?n0003oP000oh000>QX?00D0?n000030>QX?02P8?00X23`00@0X23`00<0^3Rd0?n0003o
P0001P3oP0040:0Pl0030>QX?03oP000oh000080oh0000<0d51h0;Ph]02P8?00102P8?000`2h>;@0
oh000?n0000G0?n000@0X23`00<00?l0ooooooooool01_ooool5003o001>02[M4@29HeX0IcDc06M?
C@1;>c/0BC]00554B`1JD5L0HEMO06ELH@1aJ6/0OWAh08EjO@2;Ngh0SGUj08E]J`1mHE`0PFMN08E_
H`29MVP0UXAe09R9MP2MTH40U92309NGR`2LVY00TYB;08j@R02;ShP0XjRS0:^c/@2/][H0[KNh0:Zb
]@2Z/;@0YJja0:6RZ@2H?TT0/0dE0;@?5@2[<3H0UV1c0:4O;`2S7R`0GTA_01Y4PP1QQJ<0SiJP08i<
E`2C2QH0Qad]02P]H`1bU;00Ni:L09BZ]`19Hgh0PW2207hH9@2;0``0T`<<09412P2?0@X0RP8:08H3
2`240PT0Q04906l74P10>UH00aY@004CD0014D`01AQ;00PLBP0@:DL0BVa[04eXI@1BJVH04=8A1P00
o`08ooooo`D00?l000<0D91h0:0Pl02h>;@08P2P8?001@3XJ3`0oh000?n0003oP000^3Rd0080oh00
00D0^3Rd0:0Pl02P8?00X23`0>QX?0020?n000D0X23`00<0^3Rd0?n0003oP000203oP00:0:0Pl003
052@N000o`000?l000@00?l02oooool000[ooooo05P08<d304X40@0n0@40=04102l10@0_0P40;082
03410@0m0@40?P4103`00@0n0P80?`4206@31P1b0@D0O04608<21`1X0`L0@@0006l420200@80Q@41
08L20`2<0`D0Q@P<04/W9@2[ZjL0d]?E0=?Df@3Ee]T0f=OL0=>m``2P=Sh0]1<H0;T@5@2i3aH0^PhC
0<4?4P3941D0cADH0=1_L03He=H0gMkR0=WNg`29N7d0KadT06dA5P1B2@d0:@4200`71`0K9240KGUf
0;2i]`3Bf=/0d]WN0;o;d`1RHfh0?A8H03`72@0m1@P0E0T>07D83`261@`0R@<:08<2201o0PP0O`89
07h21`1o0PD0P08907`22@200`T0P@8807l1202:10X0X0X<0:P83`2Z2@h0Z0P>09/32P290@L0N@@8
07De=`21LgD0Bcdn01T40`0YB@800?l02Oooool00`1@T7P0oh000?n0000F0?n000030=1@N02P8?00
X23`00@0X23`2@3oP0040:0Pl0<0oh0000<0d51h0:0Pl02P8?001P2P8?000`3@D7P0oh000?n0000G
0?n000@0X23`00<00?l0ooooooooool01_ooool5003o000P027U2`27DSd0Ke1=05mBDP1:>SP0BcXk
0513A@1ICE80GeIK06IMHP1eJFh0PWEk08AhO028NW/0RWMh08A[JP1iGUT0OVIM08M_HP2;M6H0TGma
09^=O02NTX<0UYB709RHS`2IVI80T9F=09FMT`2;T8X0Uj2L0:N`/02[/kL20:^e]`0/0:Rb]02V/k@0
[k2c09lkAP2c3A@0[A4E0<EBE`2W9Rl0YA`U06=7L@0NBHH0NYJ[09V<U@2A?T`0T`XF08dF8`1@>F<0
<5:307>AX02O]l<0Rj>c07]/O`1f4b40R08:08l22@2?0PX0RPD<07lG8`1/;Sd0GR`o07LF901o0Pd0
C`PU00XBC00155@00AIB01HcFP10GW802R5502A2EP1@Kf`0Af=U03A>E`0QYbP6003o00Sooooo1@00
o`000`1@T7P0^3Rd0:0Pl00R0:0Pl0H0oh0000D0^3Rd0:0Pl02P8?00X23`0>QX?0020?n000030;Ph
]02P8?00X23`0080X23`00<0^3Rd0?n0003oP000103oP0020=1@N0030>QX?03oP000j6Pl00X0X23`
00<0D91h003o0000o`001000o`0;ooooo`002_ooool0@P0Oc@<0BPD203X10@0/0@40<08202P10@0T
0@40<08203d20P0k0@00?04103L20P110P@0J08507411P1g0@H0N@8805D2100l0000K`@708<11028
0P<0RP8408d41P1Q2`/0PW]e0<gAd03>dmD0dmKH0=KDf03>^;d0ZUAJ0;0E6@2h4A@0^A4C0;X@502l
3a<0`A0D0<H@5@3:51P0afEV0=OCe@3Lh>80fMkO05aTI`0Q7Al08b4Q034d<P1@F5D0Phn=0:^f]033
b//0dmWL0;g:dP27VJ<0>TiF01DS9P0W;Bl0;cHg02T_;P0I5A@0:@@606<940211@`0P`8908032080
O`8801@0P@8808431`1g0P@0N`4708@22@200@T0Q`4909l93@2Y2@h0Z@L>0:P83@2J0`L0S08707L4
2@2?EEP0P75b03d_<00E0`<0>@`3003o00Wooooo00D0D91h0?n0003oP000d51h0?n000020:0Pl003
0=1@N03oP000oh0000h0oh0000<0j6Pl0:0Pl02P8?00102P8?000`3XJ3`0oh000?n000070?n001@0
X23`00<0d51h0?n0003oP0004P3oP0001P3@D7P0X23`0:0Pl02P8?00d51h003o00Sooooo1P00o`00
C@23DcD0M6IT05eCDP1>=C<0BBd`05A5B@1GC500HEAL06QIHP1fJ6l0PWIl08=gN`2;NWd0RgMj08=]
J`1fG5D0OFAH08]bIP2<NVX0TH5b09R;O@2HT8<0UYB509NHS@2?Th`0TI^G0;g9bP2UZj`0TY^F0:Na
[`2X/k<0YkBd0:bf]`2Y];H0Yk>d0:Z`/@2SCE80^10G0;H>5P2m72H0/QHN07i4H`0WA800PhJP09QN
J@2B7RT0U@/G08DV=`16>fT05cag07jN]01nUj40S:N^08>6TP1l8c40S@<=08/2202?0PX0QADL05Xe
CP0V;Ud0635P03mCM@1W=DL0I0HL01L=AP0255X05c1M03mNL01HMG/0:DAJ01hhF00R?e<0BFI^01<[
B00253L08ghe00H00?l02?ooool6003o00030;Ph]02P8?00X23`0240X23`00<0d51h0?n0003oP000
0P3oP000103@D7P0X23`0:0Pl03@D7P20?n000030>QX?02h>;@0X23`00@0X23`00<0j6Pl0?n0003o
P0000P3oP0001P2h>;@0X23`0:0Pl02P8?00d51h0?n000`0X23`1P00o`0;ooooo`002_ooool0F00N
c080B0D203D10@0]0@80;`820241000U0P<0<P4203d20P0j0@40?04203420P0o0`D0L@<907T22P1g
0`X0HP<804L10`1D0P<0N08408810`270PD0SP@908H7301C:RH0_l6m0<kBe03?dmL0d=CG0<^`]P2I
?d<0[ATL0;8A4`2L4aL0PQ4D07hC5P2J51P0_Q<J0<8>4`3441D0]SDk0=S1aP3Jg^00fn3P0<39b02b
_;P0ZKJ_0:bg/@34cL`0d]WL0=7Ig038d=P0Sj2X03eEG00bB4/0IgUf09NTX02U/:l0ZKFd0:Ja/@2B
WIH0ATY50283101/2100PP8:08@42@2310P0P047088120230`P0M04207`42@240PT0P`8908`3202O
2@`0YPT=0:L8402S10`0V`<:08l2201d10T0PDe?07ARIP0d92H04`4103d<1@00o`09ooooo`03052@
N03oP000oh000080oh000P2P8?040?n00080j6Pl2`3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030;Ph
]03oP000oh0000T0oh0000<0^3Rd0:0Pl02P8?004`2P8?0C0?n000@0X23`00<0oh00003o0?ooool0
1oooool6003o001=08QM>01ZEU@0HU5B04/L7P1=7R80E3i505Q:E01REUl0J5UP07MXL020LWX0PgAi
08YhNP2;LWD0QFaZ07EHE@1kH5T0S7A[0961LP2HR7X0V8]k09VAP`2GU8H0VIbB07b6P@2e`<00[kc2
0:2X[P25SHX0Xj^/0:Ra/P2W/[80Yk:d0:Jc]@2Q[k00XZb_0:MWJ`2d4Q/0]`XF0;P<5@2d92`0TfEo
08UDL`2E9CH0X10L09P>6@22=4H0>3a]00heM01RQJ00PYJN0:Fha020VJ/0T7F308L:5@2B0P/0T@4:
09032`1l7bd06B1?03=FN`1`S9X0PGb406dL9`191bL01a9H00/SGP1AKgd0EW9a05A`M`067d40>UEZ
00HK@00?9d`00@m0004>>@0JIc@01P00o`08ooooo`H00?l00`2P8?020=1@N1l0X23`00<0d51h0?n0
003oP0000P3oP0020=1@N0@0oh001`2P8?050?n000@0X23`00<0oh000=1@N02P8?002`2P8?06003o
00_ooooo000:ooooo`1H01g;0P121040;@0102X10@0[0P808`4102H10@0j0P80@08203T00@0n0@80
<@8402T1101>0`P0E@8:04`22@110PH0G@@907l62`2410P0Q08708T21`2;0`P0I@d?0928Q@3=dM80
d=;F0=3CeP37][X0WS]10:LF6@2B4QH0C0T=02TI6@0h>3L0?C`n02hK70254AH0_0hD0<4>4`2l4aL0
^TeG0=>V[P3Kc=80gM_N0=cKg`3Jf]d0f=?G0<G5c@2>WjX0EFYe04MMH`1[Ngh0[;Nh0<38b@3=eM@0
d=OG0=3Ff@3?eMT0cmOH0<kGe@30alD0PG]i068H70210`/0Q`<:08H220250`L0Q08708D31`220PL0
P04908022@240PL0UPL<0:89302T1`h0Y@T@0:873@2K0`X0S`8807451`2DIFD0JUIJ024B500D0P40
?PX3003o00Wooooo00D0D91h0?n0003oP000^3Rd0=1@N0020:0Pl0@0oh000P3@D7P;0?n000D0X23`
00D0j6Pl0?n0003oP000j6Pl0;Ph]0020:0Pl0030;Ph]03oP000oh0000<0oh0000<0d51h0:0Pl02P
8?004P2P8?000`3XJ3`0oh000?n0000@0?n000@0X23`00<0oh00003o0?ooool01oooool6003o001=
09=S?01XB4H0I4Y;04d>3P1>6AX0E45305M:D01RE5h0JEYQ07MVKP20KWH0P71f08EfM`27Lg@0QF]Y
07QKE`1mHEd0Qg9Y0960LP2DQGD0UhUj09ZAQ02GU8H0V9^?07V2O02MZJX0W:V_092HW02AUYD0Y:V/
0:Z_/`2Y/kD0ZKBf0:Fa/P2X];@0ZK>e0:b9S@2T5R00]@hJ0;H>5@2^4Q/0WR8d09lF902V4AX0VQ@Q
088iC`13A7@04cMd05IjVP2BZk80S9nY0;73d@1/Oi80P4]H08d73`2?0P/0RPH>08D53@2131P0Je5V
08BLY`2DWJ<0O4UB07D85P0c23400a9H020lI@1MMgX0G7Ef03IBIP0<:4L0BfQc00HH?P0144<00@e0
004?>@0KBCT01P00o`08ooooo`H00?l00`2P8?000`3oP000d51h0:0Pl00N0:0Pl0030;Ph]03oP000
oh0000H0oh0000<0j6Pl0:0Pl02P8?001@2P8?000`3@D7P0oh000?n000030?n000060;Ph]02P8?00
X23`0;Ph]03oP000d51h302P8?06003o00_ooooo000:ooooo`0C03:i1`0f0`408`4002D20P0O0@40
9P4102X10@0i0@40@041040100150@40=@8401P10`0Y0`H0<0T;03462@150`P0O@H@08T22@0208`4
2@1308h31P232`/0EBHT0;k1`03;d=<0c];E0=7?e02AE5X0UaPN078?5@0Y0`@0>cll0:6]Z02`_;P0
/K^g0:R/Z`1o<S<0]1<E0;h<4`2n3A40^Q<J0:/O:P2cCET0b8>=0<^<VP32NX/0XEU[04X^?P0=82P0
DVMY09FSX03>dm@0eMWL0=?FfP3AemT0d=OI0<oFf03@e]T0d=GG0<cCe@3?e=L0d=7B07i;CP1j1@/0
P@<708L320290`P0Q@<708821P1n0@H0P@<:07`120220@L0V@P>0:06302S1``0Y0T>0:47302I10/0
RP4806l82P2FJFX0Dcdo00h4100D0@40?PX4003o0009ooooo`03052@N03oP000X23`00@0X23`103o
P0001@3@D7P0X23`0:0Pl02P8?00d51h00L0oh0000<0d51h0:0Pl02P8?000P2P8?00103@D7P0oh00
0?n0003@D7P50:0Pl0030=1@N03oP000oh0000P0oh003`2P8?000`3@D7P0oh000?n0000@0?n000@0
X23`00<0oh00003o0?ooool01oooool6003o001>07Ik:`1_BD@0Hc/h05D?3P1C:BT0EDA405];D01V
EEd0L5IO0714CP1eD5P0NFU_07i^L026Lg@0RFm]07iPF`21IV80RWA/091nLP2>P700ThQg09J@P`2F
U8L0VIN?08R:Q@1nQH@0RXn>08F9Q@2NXj40Z:n_0:J][`2Y/k@0ZKBe0:Va]@2W[k80X:b^0:b_/@2T
CeP0/1HR0;L>5@2Z6R40WRTd090b@`1d@Ud0ATEd0251M`17KID0OYZY0:Bh_P2:WZD0W:jg08VOZ@2B
Wj/0NbXj08X42`1l8Rh0B3EE054hD@1g5B00OAhX0:9hQ@1m<400P0PC07<?7P0K44@01b5H04m_OP1L
M7/0<TeT00PTBP0iFVT0EG1`01lfC`0144800Q1000lV@`0T>4D00o831@00o`08ooooo`H00?l00P2P
8?000`2h>;@0oh000;Ph]0040:0Pl080^3Rd6P2P8?000`3XJ3`0oh000?n000020?n000030>QX?03@
D7P0X23`00P0X23`00<0d51h0?n0003XJ3`00P2h>;@0103oP000j6Pl0=1@N03XJ3`20?n000030;Ph
]02P8?00X23`00X0X23`00<0:<Pl003o0000o`000`00o`0;ooooo`002_ooool0F018Y`h0<`@101`0
000J0P803`4102<20@0[0040>P8204@10@1:0@40C@4204X3200N0P@0J5EG0:bKX01U@TH0MALL08P5
3P2<0`X0S0@809462@2B2Pd0KQHD07ATGP3;d]40bm7C0=;Ce`2eVZ00Ob8U04l;3@0]71`0IVa[0;g7
`P3FfMT0fmgO0=[Mg`3Gg=/0^i2=0:DN7@2n3Q<0`0lC0<8?50334AL0_aDL0;TI8@2e6R@0YQ`X05d@
600e;c80Pi6@0;O2`@3?e]D0d]SK0=;Hg03@e]T0c]OH0<oDe`3@eMP0d]KI0<oFf@3<eML0c]KI0<oE
f02AMWP0M`P?07l21P2810X0R`D;08831`200PT0O@8907h3201l0`P0Q0<709T73@2M1``0X0L;0:@:
3@2N1@T0UP<:08L11`1`30l0XWYl058n@0090@406@81044:1000o`09ooooo`030830003@D7P0X23`
00<0X23`1P3oP000102h>;@0X23`0:0Pl02P8?070?n000@0X23`00<0^3Rd0?n0003XJ3`01`2P8?00
0`2h>;@0oh000?n000070?n000030>QX?02P8?00X23`00d0X23`00<0^3Rd0?n0003oP000403oP004
0:0Pl0030?n00000o`3ooooo00Oooooo1P00o`00CP1RRah0MTY705ll=P1D<R/0DD0n0553A`1MCUH0
JdUC06hf?P1/51d0M3@j075MH`1fIFP0OVQ/08=YJ`22IV@0OVAP08YbK02=NFh0SWa_09:6N@2FSX<0
V9B;09RGS`2GVi<0V9jG08j@R`2;ShP0Uj2N09ZSY02HXZ<0Yk2`0:Rb/`2X/kD0Xk2`0:>^/02IXJ@0
Ye=L0;0A6P2`41P0PE1c03QFR@0lG8X0B6^E06J6X@23WZX0SjBX09JXZ`2CYZT0TJV^0:JmaP1IMX/0
TjB_07Xa?@2:1Q00KRY104aCO02>SJL0Pd5=08<53P241Q00O0TB06LP;P0d9dT011I>039DM`1@KH40
63=L00@PC00gEFX0FWAg05QaK`1@Ifh062m:020lD`16I6T0<TU>00k@3`D00?l02?ooool6003o00P0
X23`00<0d51h0?n0003@D7P06P2P8?00103@D7P0oh000?n0003@D7P<0:0Pl0030=1@N03oP000j6Pl
0080X23`00D0j6Pl0?n0003oP000oh000>QX?00>0:0Pl003052@N000o`000?l000<00?l02oooool0
00[ooooo0440AjH>03<40@0L0@40608201010@0R0P40;04203P20@100P80B04205800P1J0`L0F2<W
05@i@@1X?DP0LB4[07d53@280P/0R@<908`52P2D1`/0RAXI04l/9P2f^;@0bM3B0<k@d`2bVYl0Lbld
03L=3@1VJ6L0[[Fc0<gCe03HdmL0a9ZS0:iZMP2PPHX0e][M0=:o`02H;Bh0_a@G0<4>4P3541H0``hD
0<LB5P314aH0RA0B03/<301IFUH0]/2m0=3If03AfMT0e=WK0=;If`3@e]X0dMOI0<gFeP3>eMP0c]?F
0<gDeP3=emP0c]KI0<kFf03@emT0UWUm07/;4@0308022@0D07h22P1l0PT0N`8807T21`1m0`P0RP<9
09P52`2K1P/0W@L<0:482`2M1@/0U@@;08H1201i5AT0XWYm034O90040@40704204D90`00o`09oooo
o`030830003@D7P0X23`00<0X23`1P3oP000103@D7P0X23`0=1@N03XJ3`60?n000D0X23`00<0j6Pl
0=1@N02P8?000`2P8?000`2h>;@0d51h0;Ph]0020:0Pl0P0oh0000<0d51h0:0Pl02P8?003P2P8?00
0`2h>;@0oh000?n0000@0?n000@0X23`00<0oh00003o0?ooool01oooool6003o001>04BT301^<2<0
KDm:05M6@01A@400ETE706=9C@1R8bT0IaPM06dQ9@1X>Sl0J59J079PHP1jIFL0OFAW089XJP26JfX0
QfeY08]gKP2=OW40UHQi09N>P`2IUHd0VIN@09NJU02DViH0PhR308B;Q01lQWl0NhF208J@T`2HXjD0
Y;2a0:Fa/P2T/k<0Y;6c0:FSZ02Q>D<0^0lG0;D?601l@fP0Eh2V09FZ/`2GZJd0U:BY09BUZ@2DZ:X0
ZKbo08jSZ02BZ[80PIjV07nL/@1/RZD0SWMo07hA6`201a<0NPlQ07X=7`1m2180P@<:080D701@<dl0
4B5=02A0HP0jEG802R=<00PQCP0T@F@0CFik05iiN`1SNGX0Fg=c05UaLP1?JVT0EW5_055]J`0W@TP0
7J@P1@00o`08ooooo`H00?l000<0P<000?n0002P8?00102P8?030?n000030;Ph]02P8?00X23`01P0
X23`0`3oP0000`3@D7P0X23`0:0Pl00:0:0Pl0030;Ph]03oP000oh0000D0oh0000<0^3Rd0:0Pl02P
8?003@2P8?000`1@T7P00?l0003o0003003o00_ooooo000:ooooo`1H04JT3@0a0`408@0103HB4P0I
0@406P4102@00@0e0P80>@4104H10P1D0PD0F@4305T42@1L2A80H`D<07432@1o0PT0Q`8:08P32P2;
10/0S`L;074Y9@2NV9@0cM;C0<cBe@2aWj80I2/_03XH5`1nPX00c<o@0=GBf034YJl0ZDA@0:`K9028
5QX0MEIF0=WKg@3;YJX0YBDY0<4D5P3241@0b14F0<XC5P334QH0R10B054m>`2PYZ<0b]?@0=GKg@3D
fM`0d]WK0=?If`3BfM`0d=KK0<G6b`2bZ:l0W82<09MmR@2a[[D0bm?G0=;FfP3BemX0c<_@07m9D@22
1Ph0P@<807d1201n0PT0P08907T2201d0@L0M04807@21P1n10P0T0<909T52@2L1@X0W`L=09/3302A
0`X0Q@4707HJ7@2HN7X06a0C00810@0K0P40@`P2003o00Wooooo00<0P<000=1@N02P8?00102P8?0>
0?n000030>QX?02P8?00X23`0080X23`00<0oh000;Ph]02P8?000P2P8?001`2h>;@0j6Pl0?n0003o
P000^3Rd0:0Pl02h>;@01`3oP0000`2h>;@0X23`0:0Pl0080:0Pl0030;Ph]02P8?00X23`00@0X23`
00<0d51h0?n0003oP000403oP0040:0Pl0030?n00000o`3ooooo00Oooooo1P00o`00CP14]`d0IBXG
06m@C@1GB480ECLj05lb>@1W>Sl0H3Dh06U5B01WBe80HTmG061=EP1YE5T0M5mR07aRIP22IfX0R6]/
08Q`J`2?O7D0TH=i09J9N`2ITXD0V9F<09^JU029SHH0OhN0071kLP1cOGH0N85m07F0O@1mRHT0RiZJ
09ZWZ02V/;<0XJb]0:Bb/`2^ZJh0WB`d0;T=502h2a40X2Hj05=MQ02H[kP0W:b^09f//02JZJh0UJJ[
096TY`2W^L00Y;c6059dS01jVJh0Bg2:0:o4bP2LQY00ISA3068U>@1N:Sl0F3A707LO:`1o82/0@bi>
05Y=I@1VE5d0I51D065OI@1KKW<0Eg=b05UfLP1LNGD0Hgak061hN01KLgH0C6UW04i/I`1?K6`083a4
02RR;0D00?l02?ooool6003o000306RX?03XJ3`0X23`0080X23`00<0d51h0:0Pl02h>;@07@2P8?04
0?n000d0X23`00<0^3Rd0=1@N03@D7P00P3@D7P00`3XJ3`0oh000:0Pl00?0:0Pl00307QH]000o`00
0?l000<00?l02oooool000[ooooo05P0@Z<<0303000S0P<0E34b01d20P0G0@408@8103410@0h0040
A`4304`00P1?0080D`0205h01@1V0@D0KP4707P12@220P/0Q04808X42P272@`0NE5<0<S<b`3=e=D0
d=7B07ICE`0Z20/0I6AO0<[>cP3Dc=80/H>=09h`>@2h5A/0Ta<F03h>3`2_[:/0gMcO0;YdO02h6B00
`a4E0<DA5P374QH0bA<H0:/B5P146QX0/;Rf0=CMfP3Eg=`0e=_M0=;If`3Df]`0d][L0<oAf02LPY80
PDYF07HS;`1l5240KAXV050mA02i`L@0dMOJ0=;Ef@2TTYX0LAhX08@52`210PP0O@8807d21`1o0`T0
M`8707411P1c0@L0N0<707`21@2>10X0U@@909`52`2L10/0V0D;08`120240@L0PRd]08Q]K@0=1@L0
0@0001T1000n1P400?l02Oooool00`20`000d51h0:0Pl0040:0Pl0h0oh0000<0d51h0:0Pl02P8?00
1`2P8?040?n00080X23`00<0d51h0?n0003oP000103oP0000`3@D7P0X23`0:0Pl0080:0Pl0<0oh00
1@2P8?0C0?n000@0X23`00<0oh00003o0?ooool01oooool6003o001>02KE1`1V;a`0JSll0694@01L
7b40HQhT05hf?01OBE40GD]F06A?FP1PCUL0G4YC065;DP1XDED0ME]N08I/K02;Kg00QG5]08akL`2C
PW/0V8]n09VCQP2JUh/0QH=k07QmM@1cNW<0Lgef07N1NP1iPWd0Mh9o07R3P`20SXh0TJ6R09n[[`2P
Zjh0XJfa0;J`]@2I:S@0]PhE0;X=4`2a3QP0Od1O07R>Z02K[;40VJR/09f^/02W^[`0UZfb09bc^P27
X:d0VkC505QkV`1JQ9`0^MKP0;oCgP2V^lX0IgfJ03]8K01:>5H0M14P08@53P1i1aD0L`D?06l4301Z
0`T0I0XA06@i?01QK6`0Fg=a05mhM@1KMW<0GWYh04QSJ00_CU40AF=S024jC@076cD0<7hl1@00o`08
ooooo`H00?l000H0D91h0>QX?02h>;@0X23`0>QX?03oP00O0:0Pl0@0oh0000<0d51h0:0Pl02P8?00
3P2P8?000`2h>;@0oh000?n000050?n000030;Ph]02P8?00X23`00T0X23`1@00o`0;ooooo`002_oo
ool0AP12X``0=PX704d`<@1I@dD04`4101H10P0N0040<08203/10@160P@0B`4304d10`1F0@D0H`46
06X11@1b0PT0NP4:07d21`1o0PP0QP@908PL7@2=NgL0b]?C0<gEeP2e/;40?2DV05aKF@2f^kT0d<g@
0:U[M`2M82`0/A<I09`A5P1@7b00ViRG0=CFe`3Jald0[cPo0<DD603641@0bQ8G0<PA5@2n5AX0Ka4D
09:>S03EfMT0fMgO0=SNgP3Ffmh0dm[M0=7Df@2o[[H0TUIQ08DO:P294AX0R0`D07/<4`0m3100ADU:
0;c7a`3?eMP0]Zje07<i@`1k3AH0P08;08832`1o0PT0N`8607T11`1b0@D207411P0@07T11P260PH0
S0<80903202E0`X0V@@:09@32P2<0PT0QP8808@d=@1hG5l0208400810@0N0P40?`D1003o00Wooooo
00<0P<000=1@N02P8?00102P8?000`3XJ3`0oh000?n0000;0?n000P0X23`00D0d51h0?n0003oP000
oh000=1@N0030:0Pl0H0oh0000<0j6Pl0:0Pl02P8?001P2P8?000`3@D7P0oh000?n000020?n00003
0>QX?02P8?00X23`0080X23`00<0d51h0?n0003oP000403oP0001`3XJ3`0X23`0:0Pl02P8?00^3Rd
0?n00000o`002?ooool6003o001>027T2@1Q:@/0KSli068V901T5QH0HS4e05a7C`1HB4l0GD]C061;
DP1MAU00FdMB05m;DP1SCe40KeMK08I/K`2;Lg80R7Aa08ekLP2BPgT0UHV009RBQ`2:Qg`0P7ee07Ym
M`1YLfl0GFi[05U[JP1UMWH0MH6107J2P`1jQXL0OXj>09NWZ@2HYZT0VJN]0:NX[@2J>440/0/C0;P:
402h2a40XQPV06UGN@2F[[h0VZZa09V^]@2>YJP0Z;k30:2i`@1URJ40L9:]03YTQ`2I_<X0`=GO0;_8
e`2LTZD0N4IK074I:@1j1a<0QP<=08L22P230@X0N@4907@12@1`0@L0K`4806@42@1TA4H0Ffi]05Mb
L01ELfl0EW=_04mZK00K=TL04BLn004=<`013bl09dHg1@00o`08ooooo`H00?l000H0D91h0?n0002h
>;@0j6Pl0?n0003@D7PO0:0Pl0D0oh0000<0^3Rd0:0Pl02P8?002`2P8?000`3@D7P0j6Pl0?n00008
0?n000030;Ph]02P8?00X23`00P0X23`1@00o`0;ooooo`002_ooool0F00nX0/0@QPA04TZ:`0Y3a<0
5@4201P20P0L0@40;04203`20P130@80B`4205410`1N0PH0I@4506X21`1Z10X0L@@;07h31`200PL0
Q@@;08`k?02a[j`0cM?E0<cCeP1GEUH0JFaW0<K<b`3@bm00WEeV0:0F6`2Z41H0SA4E040I6@2OYJ<0
d][J0=_FfP2dH6X0`1LL0<P@4P3:4A@0cA8F0<DI6`1k4A40R79`0=3Ie`3GgMl0e]cN0=SMg`3Dg=d0
X:^d05i>G@1n9S@0Ua0G09P>4P2=3A40KPdB02X:2P1>FeH0/Knl0=3Gf@31_l@0N3e307h;4`2310X0
OP<807d12@1o0PX0O@8807X2201a0PD0KP430701101i0@@0P`4408<10`2:0PH0TP<909L42`2C0@T0
T08:08D32@2GDeH0>b@X00H10P040@409P4204440P00o`09ooooo`030830002h>;@0X23`00@0X23`
00<0d51h0?n0003oP0002P3oP0000`3XJ3`0X23`0:0Pl0050:0Pl0050>QX?03oP000oh000?n0002h
>;@00`2P8?000`3XJ3`0oh000?n000040?n000030;Ph]02P8?00X23`00D0X23`1@3oP0000`2h>;@0
X23`0:0Pl0020:0Pl0030>QX?03oP000oh000140oh0000L0d51h0:0Pl02P8?00X23`0=1@N03oP000
0?l000Sooooo1`00o`00CP1[<P`0LCdg06HO6`1V<Bl0GTU>05E5C@1HADh0FTMA05Y5D01L@dh0GDMC
05m;DP1SCE<0KeIJ081VJP2>MG@0S7Ec095oN@2EQ7`0T8Ik0969P@1gM6d0IfiX06ifM01LKVd0Kgej
06EgM@1<HfD0K7ek07=oO`1cPH80NXZ9082ATP2>Wj40U:FX09^VZ@2QF600[1@O0;P;5@2g2Pl0/`/B
09T[?`1cN8l0UZ^b0:2e^02_a<X0V;6j07^HY@2<Z;P0Ih^Y062<Z02[amT0XYZ[08M5FP224R00P0@>
07l12@200PT0PP8908D22@240PP0O08907<22@1a0PL0L04706X11@1I6b80ADeE05=`K`1CL6`0D6m^
02m:G00243L00@`c004:;`013bd07Rdd00Cc0`@00?l02?ooool7003o00040?n0002h>;@0oh000=1@
N200X23`00<0d51h0?n0003oP0000P3oP0000`3XJ3`0X23`0:0Pl0090:0Pl0030=1@N03oP000oh00
00X0oh0000<0d51h0:0Pl02P8?00202P8?000`0Xb3`00?l0003o0002003o00_ooooo000:ooooo`1H
042T2@177a008@@301L10P0E0@40708201l10P0[0@80>`4104H10P1B0P80F08205l11P1W0PH0I@86
04/0101?0P@0O@@808<41`2110P0SE=@0<?4``3>dm@0_<G70393?@2g`;T0dMCE0:f8S`2F6Ah0WQ0C
07TA5@0/1PH0PhZ60<oHf03Fem`0aiZS0;8Q:0344aH0a10D0<P?5@3:41D0YQlO05lj>03Adm40e]gM
0=ONg`3Gg=d0fMcO0=;Kf`2EY:H09b<[05hB6@2G3a<0RA8F05X<400M10@0?Ti70;>o^P3<e]H0b<kC
08IQJ@204AP0QP@;08<32`1n0PP0OP4808022@210`X0O08;07011@1/0080LP4407`11@220@D0P@04
08H21@2?0@H0U@8909@22@2?0@T0Q0<908E4B@0T3Q@01P4300L10@0/0@40?`80003o00Wooooo00<0
P<000:0Pl02P8?00102P8?000`3@D7P0oh000?n0000:0?n000030=1@N02P8?00X23`00@0X23`00D0
d51h0?n0003oP000oh000=1@N0030:0Pl0030=1@N03oP000oh0000@0oh002@2P8?040?n000030=1@
N02P8?00X23`0080X23`00<0d51h0?n0003oP0004P3oP0001`3@D7P0X23`0:0Pl02P8?00d51h0?n0
0000o`002?ooool7003o001>06a73P1N81L0L3Xe06]EEP1DATX0Dd9;05I3C01HB500FTM>05I1BP1H
@D`0GDY@06A?E@1cGF00P6M[08acLP2?MgD0Sgmi09:5O`2@QWl0Pgib071dJ`1YLVd0HV]Y05EXJP1P
L7@0E6U/04mTI01aPG`0L7in06mnP@1gQXL0O8f=08>EUP2@X:<0VJNY0:b;T`2>7RX0[`lI0;P<4@2d
2a00[PdG08djD02@Wk@0UJR_09fa^@2J/[`0QZNn06J9ZP0YBg/0NhVS08iJL0235BT0S`DB08h22`26
0@T0P04907l220250PT0P@D<07LK9@1U:S`0D2Tm05/W=P1U1Pd0J08505LH9@0@62d0CV]^04aYJ@0H
<Dd00@lo0049>0022S<01aXb02M7C@0R=cL04]8?1000o`08ooooo`L00?l000<0j6Pl0?n0003XJ3`0
8@2P8?000`2h>;@0oh000?n000030?n000030>QX?02P8?00X23`00H0X23`00<0d51h0?n0003oP000
1P3oP000103XJ3`0d51h0=1@N03@D7P20?n000030=1@N02P8?00X23`00P0X23`00<0D91h003o0000
o`000P00o`0;ooooo`002_ooool0F013Z@d0>aH901d10@0F0@805`4101X10@0J0@00:P8203`20P16
0@40E08305/11@1Q0@H0J04506P21P1W10X0HP<608442P2910X0Q0X=09=XI@3:c/l0bm;E08JDUP1h
QX80cm?A0;JMY02<<cX0R10E04d92`0/6a/0MG]h0<K?c03Fd=H0_i2J0:/f?@2n4aP0_@lA0;h?4@34
3Q80`A@F08Pk?02a[jh0em_L0=OLgP3Ff]`0e=7E0=C?eP3Gf]h0d=_J0::]ZP15;c00GA<G02l82@0O
71X0Df5J0:bi/`3?e]L0`<?808]_N@1c5b00Q@D<08P42`220`T0O`8807l22@1o0@P0P0<:07`12P1a
0@H0J@4107010`1l0@@0PP8707X110210PD0S08709D32P2D0`X0TP8908<42@2@FEd040<600<10@0:
0@00=P<303l30@0=dP49ooooo`03052@N02P8?00X23`00@0X23`00<0d51h0?n0003oP0002P3oP000
0`3@D7P0X23`0:0Pl0040:0Pl0030>QX?03oP000j6Pl00@0X23`00<0d51h0?n0003oP000103oP000
0`3XJ3`0X23`0:0Pl0070:0Pl0030;Ph]03XJ3`0d51h00D0X23`00<0^3Rd0?n0003oP0004`3oP000
1`3@D7P0X23`0:0Pl02P8?00j6Pl0?n0001@T7P02?ooool7003o000W05=U1P1I9AP0LUiI06IKFP1H
AdT0DBL_05Hc>P1E@d/0FDI?05I0B@1G@D/0GDY@06QCF01aGV00OFIY08UbLP2>N7L0TH1m08j1O@2;
PGX0OgQ]07UjKP1hNg<0Lg]f04IIF`13G5l0Af5Q06=eM01bOgd0JWYk06n0P`23T980Q9>D08JFU@2?
X:40UjVZ0:bY[`2^O8L0WB4[0080]0/B02D0/@TA0:<<602HDf80`<G:09ne_@1aTJ80Q9n_09JV]P2H
OY40R2Lh0987502A0P`0T08;08l2302;0``0OPD<084;4P1o0`/0K2i301hXF@0E<F80:D5T04HkD01N
1`l0HP@703`Q=@0:8Cd0C6Y`04mXJ`055S/00Pe0004;=`0E;D@0=5QG03mOE`0W?cX07k4I00@00?l0
2?ooool7003o00030=1@N03XJ3`0X23`0080X23`0P2h>;@N0:0Pl0030=1@N03oP000oh0000<0oh00
00<0j6Pl0:0Pl02P8?000`2P8?000`2h>;@0j6Pl0?n000070?n000030>QX?02P8?00X23`0080X23`
0P3oP0000`2h>;@0X23`0:0Pl0080:0Pl003052@N000o`000?l000800?l02oooool000[ooooo05P0
@ZX?02T60@0K0@405P4101`20P0F0@80504002/20P0m0P80BP4205P10`1M0PD0H`4606`2201_00P0
M`4:07d32P240`T0RP@;084;3P2PPGl0cM;C0<SAd`1ePh40a<_;0:VNX`1U:c80CPlB028=3P1GH5`0
Z;Jb0<kEe@3Ca</0ZeMT0:XJ8@2k4Q@0^`lB0;`?4@2m3Q00`A0@0;L];@34[J`0f=cL0=SLgP3FdMH0
/7N109`jA02L<T00X6=b0<g<dP3Efm`0WjFX02hg>01^OGP0YKF]0<OBc`3=cm@0WX:;07`e?P1i4AP0
N@<807h320241@T0PP<808032P1n0PP0O@4707h2201k0PX0M08606h10`1d0P<0OP8407l11P1k0P@0
O`4508T21`2C0`X0U@<:09<22@212@`0L4A500T00@020@403`4103L20`0m0P004L812Oooool00`1@
T7P0X23`0:0Pl0040:0Pl0030=1@N03oP000oh0000X0oh001P2P8?000`3oP000j6Pl0;Ph]0040:0P
l0030>QX?03oP000oh0000D0oh0000D0^3Rd0:0Pl02P8?00X23`0=1@N0020?n000030=1@N02P8?00
X23`00H0X23`00<0^3Rd0=1@N03oP0005@3oP000102h>;@0X23`0:0Pl02P8?020?n00003052@N?oo
oooooooo00Kooooo1`00o`00CP1HJP/0GR`N06YAC01/Fe/0G3<g05@<4P1H92T0E3m805M6C`1F@4P0
FTA;05e9CP1_G600N6AX081VJP26K6l0RW1b08ilN@2@QWd0RH9i07eiK`1jNFl0O7ie0823O@1cNgP0
JWMc06ajM01aO7L0U:>O0<3<c@2DXJ@0Ohf>09NXZ02?XJ00S9fP08nRY@2IZ:X0ZJZ^0:A]L`2Y4QX0
]@`C0;494@2]1`l0X`hJ0:MRK@2PYZ`0V;;208bEZP2DEf/0SA0Q09L4402H0P`0U@<=08/22`222A40
NBXc08M4C01j3QP0KQh/020TE@11HH`0IGb;06iHH01R3aT0J@8806<V;@0C73/0<e=X04i/KP1CK6l0
3R0n00`Q@`0E;4H0?V1S04=SG010GUL08S/k02RO9`@00?l02?ooool7003o0080d51h0P2P8?000`2h
>;@0oh000=1@N00O0:0Pl0030=1@N03oP000oh0000<0oh0000D0j6Pl0:0Pl02P8?00X23`0=1@N006
0?n00080j6Pl00<0oh000>QX?02P8?000P2P8?00102h>;@0j6Pl0?n0003@D7P;0:0Pl00307QH]000
o`000?l000800?l02oooool000[ooooo04P0>ih;02X30@0K0@405P4201L20@0C0@404P4102H20P12
0P<0C04205D10P1K0@@0IP4806`1201b0@X0O@<;08@33@260`/0Q@<908<<4@2XRHX0b]3B0;>l_P2[
];@0`/[=02lg>P0M7Q`0?dM408NCT036cLh0e]CH0<RZ/`2R>dH0/18G0;L?4@2f3@l0]`dA0;/=4P2o
3a80_Q0B0;mGF03@b//0f]_M0=WJgP2<L7P0PAdW07hA5`1R3A40<PdE05]TK@39e=P0dM[K0;W4`@3?
f=P0cM?F0;BY/026Ce`0MAHP07L>5@1d2Q40L`T?07P32@1o10T0O`<807`11`1k0PL0OP4708022@1n
0`/0M@4707@1101l0PD207h2100>084110220@@0Q`8609022P2C0PX0T088084H6`1H=ST01`4100<2
0P0H0@80?@8203d2000A`P49ooooo`0306RX?03@D7P0X23`00@0X23`00<0d51h0?n0003oP0002P3o
P00;0:0Pl0030;Ph]03XJ3`0oh0000L0oh00102P8?020?n000030>QX?02h>;@0X23`00H0X23`00<0
d51h0?n0003oP0005P3oP0040:0Pl080oh0000<0D91hooooooooool01_ooool7003o001>03FG101J
9AD0L4U506/g>@1N4Q@0DQ@G05Ld=P1C@4L0Ed=<05U4C@1I@d/0H4eD075PH`1lJF/0Nf9V08EZK024
JV`0Qg9a08f2N`2:OgT0OWM`07IfKP1hNFl0PH5j07b1O01hPGh0N8Am07>1N`2aa<@0amSO09n`^01l
Si00PiFE08NIVP22TYL0OY:E09RX[02MZZl0Z:N[09M3BP2Z31@0/@T>0;493`2`2A40X@lI0:=OJP2<
NHP0Qc1509T85P2K10h0V08=09@33@281a40LB<f04HgH@1?>f00N1LX078D8@0d:E@0:TIf08fHZ`1d
@UD0LPTF07D2201b0`P0IP/D058/>01LIFP0DfaY059ZJP0iEEX0AVEV03==EP0fEUd0AfIP045NF`0E
<C80<Wlc1000o`08ooooo`L00?l000L0P<000?n0002P8?00^3Rd0?n0003XJ3`0^3Rd0200X23`00<0
j6Pl0?n0003oP0000`3oP0000`3XJ3`0X23`0>QX?0050?n000030>QX?02h>;@0^3Rd0080oh000`2P
8?000`3@D7P0oh000?n000020?n000030;Ph]02P8?00X23`00T0X23`1000o`0;ooooo`002_ooool0
F00fV@L09`8001T0000F0@40604101D10@0<0000800104420`1=0@80EP4205X1101U0@L0JP4607<2
2@1k0PX0P04:08D22P2610X0Q0/B0:EoPP39cm40^/?40<C;c@2KY:L0F6IR08B@RP2_^;@0cmCE0<c1
b02]O8L0Vc0l0;0A5`2g3`l0]Pd@0;D>402d2`h0^0hA0;H=3`2h3Q40_emS0=7@d`3Gfmh0c]?F03<g
>P0E1`X03`D6014E5P1AHV40U:FU0;o;b`3DgMh0dmcO0;BnaP1fL7X0E2lk044<5P0W0@H06`0201/1
0P0Y0P@0D`H<07042`1k0PT0N08607H11@1j0@L0O@4807`22@1h0@P0N`4707l21P1m0@<0O`850882
1P240@H0R04708`1202@0PP0S08708le=P11;2d00`0100800@0K0@40@P<303h1000A`@49ooooo`03
0830003@D7P0X23`00@0X23`00<0d51h0?n0003oP0002P3oP0000`3@D7P0X23`0:0Pl0080:0Pl0X0
oh003`2P8?001@3oP000d51h0:0Pl02P8?00d51h01@0oh00102P8?020?n00003052@N?oooooooooo
00Kooooo1`00o`006@0j[`P0ER8=07Do?01[71d0Ibd]058a=@1A?4<0Dd5<05M3C@1F@T`0FTE?05i:
D`1_GF<0NfQ^07YUJ@23IfX0QF9S08M_J@2<OgP0QWig07afL@1eMVh0Mg]b079kL`1hPW`00P1fOg/0
<`1gQX80Q9BF09BW[@1cQX/0NH^=07j@T@1mTYD0Mhf@07^?U02;Wj80Vjf_09FTZ02KTI@0TBTa0:X:
4P2c2a<0[@P@0:D=4`2]>440VAh[09/64P2M0`/0V`@=09<64@1k72`0CcEK01HVH`14>Fl0NAD^07/@
7P18;EH04b=P06YJN01`7Rh0NP@A07h22P1k0PX0M04806d11P1S10L0Eb@U05YRH01>IfD0CFUT04UW
HP0kEe`0;DaA04MVGP14HU`0;de8045M?`04003o00Sooooo1`00o`001@1XZ3`0oh000;Ph]03oP000
j6Pl02<0X23`00<0j6Pl0?n0003oP000203oP000103XJ3`0^3Rd0:0Pl02h>;@20?n000040;Ph]02P
8?00^3Rd0>QX?0H0oh0000<0d51h0:0Pl02P8?00202P8?04003o00_ooooo000:ooooo`0303>F1P0Z
1@<06@410080604101`05@8201010P0Q0@80@@8304h20P1H0@@0GP4506D11@1[0@L0L@4807X32P20
0PX0Q@<:08/62`292A00V5iT0<S:cP38d=80c=;D0:Zd/`2i`l00bm;B0<g>dP2kWJL0WDI@09hJ8`2]
4AL0/`dA0P2c3A00=@2b3@l0]0h@0;8=4@2g41<0^Q4E0;Q<DP3?b<`0eMcN0=;KfP27UiD0Jg]i07^:
R02M[J/0^lS70<gHf03Bg=d0dmcN0::^]00[?DH03AHJ018C5@0P92H0;cTi03E1?`0b?S/08RTY01@8
2P0k1@T0JPD;07T1201i0PP0NP8907T21`1l0PT0O@8907l2201n0@@0O@4407d00`1n0@@0Q@4708P1
202;0PP0S@8708T4202<?Ch0;1dN00<10P060@40:P<504@310100@404/8100Wooooo00<0P<000;Ph
]02P8?00102P8?000`3@D7P0oh000?n0000:0?n000030=1@N02P8?00X23`00D0X23`00<0^3Rd0>QX
?03oP0002P3oP00E0:0Pl0030=1@N03oP000oh0000l0oh0000D0j6Pl0:0Pl02P8?00X23`0=1@N002
0?n00003052@N?oooooooooo00Kooooo1`00o`00CP0Sd`H0GBD@06PM601d;BX0IcLg04hK7P1F=c`0
E4=<05E2C@1F@dX0H4YC0659D@1]FEl0OVQ_07aUJ@1nBU80ORh`08eWH`28OGP0QWif07]hK`1hN700
L7Q^075iM01iPG`0MH1l07N3N`1oRhT0NhZ:082@S`1cQHH0LhF708BAU@22UIL0P9BD07V<S`1gS8l0
U:VZ09b`/02?XJ80XXnB09HR:`2c3AD0Z0lD0;Pk@P2S5200Z@PB0:43302I0`d0S1DR06LhFP0N;VH0
AF>J06YEN`225RX0QPlN05@cFP0N8F00GBY>07L96@220``0P@<<07d12`1m0PX0MP8806l11P1X0P@0
E0H<044j@`1:IfH0BfUU04UVH@17I640AFAP04MTGP18He`0?eU@049CA`@00?l02?ooool7003o0006
052@N03oP000oh000>QX?02h>;@0d51h2@2P8?000`3@D7P0oh000:0Pl00F0:0Pl0030;Ph]03oP000
oh0000L0oh0000@0d51h0:0Pl02P8?00^3Rd0P3oP0000`2h>;@0X23`0=1@N0090?n000X0X23`1000
o`0;ooooo`002_ooool0F00`UP@0>AH?01@10@0D0@805`8200l10@0>0@408P4104810P1@0@<0E`03
05h20`1T0@@0K@460782201h0PT0O`<;08@22P2910T0RPH;08L/;`2aZZ/0a/g?0<cAe@3:b<d0`:jg
0:Z0R@2IBE@0UAHP0:<<4@2]2a00/0/@0;8<402a3140/@dA0;<>3`2b3Q40/`dC0;H=502i3QD0[aTR
0<B7T`3Id=P0emcQ0=OMh03Dg=`0e=gL0=;Lg`33d=H0UJR`09Z^/@3@g=d0U:BT05]]K@1hRHL0V:RU
0:bj^@2g`l<0^lO40;_6a02Z^KD0NHN602h_<@1420/0M`<907L11P1e0@P0MP4807/11P240PL0Q@86
08421@230P@0OP4407d11@210PP0Q`4808T21P2:0@P0PP<9099@D`0F1PT00@0100`10@0j0`D0C@84
04<2000B`P49ooooo`0306RX?02P8?00X23`00@0X23`00<0d51h0?n0003oP0002`3oP0050:0Pl003
0=1@N03XJ3`0oh0000`0oh0000<0j6Pl0:0Pl02P8?004`2P8?000`3XJ3`0oh000?n0000>0?n00005
0=1@N02P8?00X23`0:0Pl03XJ3`00P3oP0000`1@T7Soooooooooo`06ooooo`L00?l004l0:]T:05`N
1P1M71D0Odm:05dN7`1H7R00ECXn05I3C@1D@4/0F4E;0619D01Q>dL0K4==07ICF@1kHfP0Q5MM07PT
902;HUd0Q7Ib08ElM`1gLf/0MWE^06idK@1^M6l0MG]g07^3P@1gPGd0OH^907J6QP1lRh/0KX:106f1
P`29VId0Sj6T08RJWP1dR8/0T:BW08FJW@2K[k<0WJnc0;70`P2aUId0WBL_0;ll@P2Y6B@0[@TA0;09
4@2P1`l0QBHf03/fI`0XCXH0QjK709=bS02<52H0R@hJ05dgG`0`<6X0J2=0084540240@T0QP480883
2@1d1@`0J`/B06lC6P1_0`X0J@8505<<4`0V8SL0AVMY04YYI@1;If@0B6IO04QWH016I5h0AV9K041N
E`0]Ach04M4=00<00?l02?ooool7003o0004052@N03oP000oh000:0Pl080j6Pl2@2P8?000`2h>;@0
oh000:0Pl00G0:0Pl0030;Ph]03oP000oh0000@0oh0000D0j6Pl0;Ph]02P8?00X23`0;Ph]0020?n0
00030;Ph]02P8?00j6Pl00X0oh002P2P8?00101@T7P00?l0003o0000o`0;ooooo`002_ooool0@P0c
W0@0>1/A01810@0?0@404@4200`1000?0@409`8204<20`1A0@D0F00405`10P1V0@D0K04607<2201h
0`X0P@@<08D2302:10`0RPH=08Tk?02^/:h0b=;B0:6FW02==T80VQ`S09lA5@2V3180Z0P@0:X9402_
2`l0/0/@0;4;4@2b2a40]@hA0;D=402g3Q00^0hB0;T=4P2k41<0^14F0:TH902X@E40]7:20;n@W`2]
RiL0R86;04mOJP0T>T<0AeiQ0;2o`03GgMl0bM3B0=7JfP3Bf]X0dm_M0=7If`3Af=/0cmSJ0<oGfP3?
eMP0bmCF0;K1_`1P@400L0H;07@21P80L`4501@0OP<708T320280PD0P`8508D220220@H0OP4607l1
1`2500H0RP4808T2201i2P`0N4iA00`310040@804P41044210190@80@@4001;20@Wooooo00<0D91h
0:0Pl02P8?00102P8?000`3@D7P0oh000?n0000:0?n000050>QX?02P8?00X23`0:0Pl03XJ3`04P3o
P0020=1@N0030;Ph]02P8?00X23`00l0X23`00<0^3Rd0?n0003oP0003P3oP000102h>;@0X23`0:0P
l02P8?030?n00003052@N?oooooooooo00Kooooo2000o`00CP1R8@L0HBPO07</:P1V<2`0FChn058o
A01A?TL0Dd1905U1C@1R?dT0HATT06HF7P1]<SL0Ic]1081NHP20EU@0QfYW08AeK`27OGL0NW9/07Yh
L@1aMW00KgE`07AkMP1dNWL0MX5m07F2P01cPH40NXV807>4P`1/Oh00PiJH08RKW`29Vj00NXnD07R<
TP2HZk00V:Z`0<GIg`2[_L@0]lG:0;>1S@2]7BT0/`XD0;8:3`2X3Q40[3@h06I1H01=N:L0[l?I091P
N@2@4R80TA4M05hhG@0Z<Vl0LRI508H43`240@T0P`8:07`53P1^7BL0CRm602`/D`19>eT0H`PD06@8
3@1::CH04B4i045TI@18If40C6MU04YXH@18JF80AfIQ04ASG010Ge<0;4]101K950<00?l02?ooool8
003o00<0oh0000<0j6Pl0:0Pl02P8?00102P8?020?n000040=1@N02P8?00X23`0;Ph]1T0X23`00<0
d51h0?n0003oP0000`3oP000103@D7P0X23`0:0Pl02h>;@20?n000030;Ph]02P8?00j6Pl00@0oh00
00@0j6Pl0;Ph]02P8?00X23`0P3oP00;0:0Pl004052@N000o`000?l0003o00_ooooo000:ooooo`0e
03NO1`0U2@403P0100/00@0?0P403@4100h0000W0@40@@4204h20P1H0@80G04306<11P1[0@D0L047
07H22P1n0`/0P04808P630231PX0RU9C0;[1`@37d=80RWn108PE6@2V2Ph0Y`/=0:P93@2]2A40Z`L>
0;8=4`2`2Q40/@`A0;0:402`2Pl0]0d@0;T>4@2l3A80_A0C0;/@4P2c3a<0[`dD0:/>5`2T4Qd0SadZ
04L@700A2Q<062LZ08RGU`33cld0dm_M0=OKgP3Gg=h00P3Eg=d20=?Kg@0A0=?Jg@3@f]`0c]OJ0<kF
f@3:dmH0bM?E09:6QP1U20d0M@<807811P1c00L0P`<908T21`250PD0P04607X41`230`P00P1n0@D0
30270PH0R@4708L21`1g4aH0LEIF00L310040@406P8304H30`1:0P80@P8101;20@Wooooo00<0D91h
0:0Pl02P8?00102P8?000`3@D7P0oh000?n0000:0?n000040=1@N02P8?00X23`0:0Pl1D0oh0000<0
d51h0:0Pl02P8?00402P8?0@0?n000@0X23`0`3oP0000`1@T7Soooooooooo`06ooooo`P00?l004h0
LC@>05/M4P1_<2P0ITU30594@@1?@4@0Cci605PmA`1M:3@0IRPa06DI801O8RL0JTU;06QADP1hIVH0
P6e]08IaL027Mg40RH1k089kL`1gM6X0LgQa07EkM`1fO7P0Mgah07IoO01`NgT0KGaj06eoO@1cQHD0
L82308:BU@25UY/0PIBH09:WZP27WZ@0XKNo09R//`2N/KP0_<gC0;Rd_`2T>Td0^@dI0;H:4`2[4aL0
]SXn0:0F7`1j<DX0LX:R08Y<I02A3Al0SQHS05HgH00E<G<0HcUQ08P65P2;0P/0P@8:070D7P1?<D`0
6RIG01hcH@16@600HA/_06l33@1U20h0D1`U03hnA@16I5l0B6EP04UWH`18If40BfYT04YXHP18IUd0
@5mD02I4?@0RZB43003o00Sooooo2000o`020?n000030>QX?02P8?00X23`00<0X23`00@0d51h0>QX
?03oP000j6Pl7@2P8?000`3XJ3`0oh000?n000030?n000030=1@N02P8?00j6Pl0080oh0000<0^3Rd
0:0Pl03@D7P0103oP0001@2h>;@0X23`0:0Pl02P8?00j6Pl0080oh0000<0d51h0:0Pl02P8?00202P
8?00101@T7P00?l0003o0000o`0;ooooo`002_ooool0F00_UP@07P810100000I1@D0508200h10@0?
0@409P4204420P1;0@80D@4105X1101S0@D0K08607411`1h0P/0O@<:0844302310X0P0X>091WIP33
c<d0b=?C09BHV@1U41@0YPdB0:L;3P2Y2Ph0[0T@0:h8402a2Q40/0X@0;4;3P2d3A40]PlD0;P?502l
3A<0_@dD0;d>4`2k4AH0/0hC0:`?4`2R51L0O0lD03H9300g=cX0L7im0:jk^P3?f=P0emgN0=GKgP3E
f]d0eM_M0=GMg`3Efmh0e]_N0=GMg`3Cg=d0dm_M0=7Kg03?fMX0c=CH0<WBe@2UX:<0H@`B07@3201d
0PP0N08608P32@290PL0QP4508D21`1/0P@0MP<808011P210@D0QP8608H11`220`L0PBPY04T/;@03
0@80104101`20`1:0`D0A@4203h1000A`@49ooooo`03052@N02P8?00X23`00@0X23`00<0d51h0?n0
003oP0002P3oP0001@3@D7P0X23`0:0Pl02P8?00j6Pl01<0oh0000<0d51h0:0Pl02P8?004@2P8?0@
0?n000@0X23`0`3oP0000`1@T7Soooooooooo`06ooooo`P00?l004h0E6T605LS4@1X>c80HT4k05I4
@`1A?400Cbhf05DI8`1L51T0J3Dj06DoA01SATl0IDiF05i<E01jJF`0OfY]08UaM02<NWP0Rh5n08J1
NP1oOGD0MGQa07IkMP1eNWL0MWej075lN`1^NgX0LWmo07:2OP1XNg`0Jgn108:FV02<X:@0R9^P09:U
Z`29WJ<0R9^R0;k@eP2W^Kh0];c40:5MJ`2^4Qh0^PdE0:dF702j?dH0Z1@O0:P84@2M<Cl0PR]009<=
6P2982l0ACQY02E>RP25U;@0N1@X09033`2810d0Kb8`02hYDP0D:E`0D55`070gB01]2QP0M@8:0741
201]0PH0I08505@M7@1;GeP0AFEN04]YH@19J680CFUU04]WI019IV80A65H02e:@`0/MR`3003o00So
oooo2000o`020=1@N0D0X23`00@0j6Pl0?n0003@D7P0^3Rd7@2P8?000`3@D7P0oh000?n000050?n0
00040>QX?03oP000oh000;Ph]080X23`0`3oP0001@3XJ3`0X23`0:0Pl02P8?00d51h00D0oh0000<0
d51h0:0Pl02P8?00202P8?03003o00_ooooo000:ooooo`1H02jD0@0U1@40:`l>05<j>P0>0@402@41
00d1000Y0P40@`8204`20`1B0@80F`4406D11@1/0PP0K04607D42@201P/0P`D<08D5301k2Q00Vgmm
0<[Be038dm<0/[nn03hJ7@2K41D0Y`P=0:L83P2/2Pl0/0X?0;0:3P2b2a00]@X>0;P=402f3140]`dB
0;d?502n3Q@0`10F0;H=4`2O3a@0K0lC03<82P0d;Rh0QY>A0<KAdP3Fg^00e]gO0=CMgP3DgMl0eM_N
0=OKgP3CfMh0dm_N0=KLh03DfMh0dmOL0<c@e@3;dmT0d=WN0=7Jg03?f=X0c=?F09J7R`1W2Q00M@87
07@11P1l0@H0Q`8708T2202:0PT0S0@908D4202410P0S0<:08T120290@H0Q`8807`62@28@D40@bP[
00@10@070@808@4204l410170P80>`4100o10@Wooooo00<0J:Pl0:0Pl02P8?00102P8?000`3@D7P0
oh000?n0000:0?n000@0X23`00<0d51h0?n0003oP0003`3oP0000`3@D7P0X23`0:0Pl00C0:0Pl0l0
oh0000D0j6Pl0:0Pl02P8?00X23`0;Ph]0030?n00003052@N?oooooooooo00Kooooo2000o`00CP1H
K@T0FbPJ05PC3`1W?3H0Dd91058g>P1E92`0FB@Y05lj?`1UCED0Ie5G06YCG01QC5D0E49<07YYKP21
Jfh0RWEg08QjN`2;Q880QH=o08Z:Q@1iNg@0LgMb06]gM@1UMGD0JgUf075lN01/MgL0KH1m06EjN@1Z
OX<0PIJH07nDU@2>XjH0SjN[0;;5c02;WJH0U:N^0;70a@2IPHX0VQPV0;H?5P2T7B40/dYB0:L?7@2c
2Q<0Z@L@0:P[=02;4Ah0O2e4034fKP0iH9T0[LcS09N8V@283ah0T0<=07/U=@0Z9E40<RiK06DaBP1c
3Qd0O@<>07T12P1e0PP0L04706/11@1T0@80D`lE02llA013I640B6MS04QWI019If<0BFIQ04QVH@14
He/0<di802a/<@<00?l02?ooool8003o00040=1@N02h>;@0oh000=1@N0<0X23`00<0d51h0;Ph]02P
8?007@2P8?000`2h>;@0oh000?n000070?n000030>QX?02P8?00X23`0080X23`0P3oP000103XJ3`0
X23`0:0Pl03@D7P80?n000X0X23`0`00o`0;ooooo`002_ooool0A@0aU`<0?1H@05lo?`1QCe402P41
00T10@0>0@00:@8104@20`1=0@@0EP8505`21P1U0@H0K08906L21`1`10T0P0L=08@52`261@X0N@dC
0:69S03<d]@0am3C0<OBd`1?D540I`hB0:8<4@2/2Q00[@T?0:l:3@2b2Pd0]@/>0;P;3`2k3A40^@`@
0;X=402l3a40`0lE0;P@5P2A41D0?0T;04E6@`2=VYD0`/c:0=SNh03Gg^00e]gO0=GMg`3Fg^00eMgO
0=KMg`3Df]d0clkE0<2]^P2/RIL0UfAe08M2E01f>d/0ASQ508VGWP3?f]`0d=WK0;^j_`1^>3l0M`D;
07P21`1n0`X0Q@<908X3200208T2200A08X32@2>10L0T0@909412P2C0`X0UPD;09<83P1l5AL0UfEX
01<41@010@402@4202X20`1?0P80A@4103L0000>`0402Oooool00`1XZ3`0X23`0:0Pl0040:0Pl003
0=1@N03oP000oh0000X0oh001@2P8?0?0?n000030=1@N02P8?00X23`00/0X23`103@D7P50:0Pl003
0=1@N03oP000oh0000d0oh0000D0d51h0:0Pl02P8?00X23`0=1@N0030?n00003052@N?oooooooooo
00Kooooo2000o`00CP13TPH0FAh>05TA2`1W@CP0ESlk04d[;@1?82L0FSa305U6C01OCE@0IU=H06aE
H01[Deh0IUAM07QYKP23KFl0QW1c08AeM@24O7T0R8B108j>RP23QWl0LWIb04QKG`0fDEH0H7=c075j
M`1/NgX0IWYj06MlP@16I7<0PiVL09BWZ@2N/;L0QYRR09^/]02lb]80Y[Ro0;Vna`2>>dX0Y`hH0:8O
:`1SAfd0OTIR0:L:5`2^1`l0Z0PA09`e@01N?f806cAb06::]P2ieNL0`=GP09nIYP1o5RD0R0H@080j
C@1V:4<0MP/M08433`230P`0O08:07821@1[10H0K0X=06`21P1V0P@0DALP01`^?P12I600AfIQ04MW
H01:If40BFQO04YVG`16IE/0?ei?03iD@@<00?l02?ooool8003o00030:R8?03oP000oh0000<0X23`
00<0d51h0:0Pl02P8?007P2P8?001@3XJ3`0oh000?n0002h>;@0d51h00@0oh0000<0^3Rd0:0Pl02P
8?000`2P8?020?n000030>QX?03@D7P0oh0000P0oh0000<0d51h0:0Pl02P8?00202P8?03003o00_o
oooo000:ooooo`1H02V?0@1>;2D0IDM902<?4`090@40204101010@0X0@40A@8204d10P1D00@0FP47
06H11`1_0@P0M08;07L330231`l0Q@H;08D72`1f2a40XhZ>0<[Be@37dM<0b=CE08FBS`0_1`T0TQ@J
0:X;4@2_2Q80/`dC0;@:3`2f2@h0^@`?0;X;402j2`l0_0hA0;d=4P2b4QT0Pa<J02l41@1BFeX0_/[9
0=WOg`3Kg^40f=kQ0=SNh03Ffmh0e]cO0=GLgP3Dg=h0emSM0<Fb^`2HGF`0R2Hf08lH902>4A`0MQ0J
02l7300M8bH0U:BS0<oKf`34b<h0NUUR074B6@1k0`P0O088088320260PL0R`<908P220280@P0SP@:
08h52P2D1Pd0U@<;09D32P2O1`l0VPhC0:A=C`1eBDd0404300L20@090000;@8205T410180P80>P41
01n40PWooooo00<0P<000:0Pl02P8?00102P8?000`3@D7P0oh000?n0000:0?n000D0X23`00<0d51h
0?n0003oP0002`3oP0000`3@D7P0X23`0:0Pl00:0:0Pl0030=1@N03oP000oh000080oh0000<0d51h
0:0Pl02P8?000`2P8?0@0?n000@0X23`00D0d51h0?n0003oP000oh0008300008ooooo`P00?l004l0
A:D905@E101R;B<0HTHk05@n=P1?>cX0DCm205=4C01FBDh0GTeC06UCG@1_EF00L5QR06QHGP1VFUl0
OV]_07YPI@24Lg@0Q7ah08^7Q02;RhL0SHj:07f0N`1EI6<0CFEU06YhM`1_NWX0J7Ih06UkO`0nG6h0
IHFB07^AU028WJ80QIVN0;oAf02CY:h0Z;[30:foaP2XU9h0VaPU09`K9@1K?VT0:c]o08E3G`2R2QH0
YPLA09/84P1V=5@09dj409FgeP2le^@0_=CP0;oCh02h`Ld0PD=A08L4402610h0QP8=08L12P240@X0
P@8<07832`1P5Ql0BR/g06H]=P1Y0`P0GPD703hN<00Q>dd0AFAR04MSGP1=J6@0C6IR04QWG`15I5h0
@f9K04=NEP11EdL03=`800800?l02?ooool8003o00030830003oP000d51h02@0X23`0P3oP0000`2h
>;@0X23`0=1@N0030?n000030=1@N02P8?00X23`00@0X23`00<0d51h0?n0003oP0001@3oP0000`3X
J3`0^3Rd0=1@N0020?n000030;Ph]02P8?00X23`00P0X23`00<0D91h003o0000o`002oooool000[o
oooo05P0>H`405<`:00^5QL02`4200D20P050@80304002P20P150P80C`4205<10`1F0@@0I04606d2
1`1c0PX0MP<;07l63`1m0`X0P0@;07@73`2OQ8P0bm;E0<SBe038dmD0^<G302dZ:P1;2`d0Ua0D0:h:
4@2`2Pl0/PT<0;L:3P2i30h0_0dB0;/<402k3Q80Z18H05H;3`0]71`0JW9a0<;=c@3Hgn80fMkQ0=[N
h@3Ig^40f]oR0=ONh03Hg^40f=gP0<_2a`2FHF/0UC0l09PC7P2H3A<0T0lE06/=4`0Z30h0@Te908nN
W037dM80a=7E06=[L`126240L`XA07/21`241@T0Q`<808`52@2;10P0S0<:08d32`2>10/0P`4508X2
202E0`X0V0@;09h84@2F7200diFH06m7B`0M0`H04@8201`20`120@80G@8304P10P0i0@007h<12Ooo
ool00`1hF;@0X23`0:0Pl0040:0Pl0030=1@N03oP000oh0000X0oh001P2P8?000`3@D7P0oh000?n0
00080?n000030>QX?02P8?00X23`00X0X23`00<0d51h0?n0003oP0000`3oP0000`2h>;@0X23`0:0P
l0040:0Pl100oh00102P8?040?n0000308300?oooooooooo00Kooooo2000o`00A`0/a`H0EQ/705/K
4@1M:b@0FT8n04e0@01@@DH0EdI>05a9D`1VBe80L41906lmA01bG680K5eS069DFP1kIV/0KUAG07]Z
K025OW/0Pgmk0860N`2:RXP0N7el07=jMP2?V9D0T9VI079oP01YNWX0FG1n0298I`1ZQh`0P9FG09^`
/`2CYJd0TjN_09^]]P23UZ40^lgD0:ImR02S5R80WDiO06]9K@249d80YBXh0:8:5P2O21<0S@lK040d
H01iXl80_mGN0<7Eg@30d]d0_m;M0;6lb01g=DD0R0@@08D12P260@T0PP8807/53@1^6bH0Bbe402PX
BP17:D<0I0PD068:3P1@:3L04aPi03EHH`18IV<0BFIR0080BVQS00H0BFQQ04MUG@16Hed0A61H03aH
AP0Fb142003o00Sooooo2000o`00101@T7P0oh000?n0002h>;@60:0Pl080^3Rd6P2P8?001@3@D7P0
oh000>QX?02h>;@0j6Pl00@0oh0000<0^3Rd0:0Pl02P8?00102P8?000`3@D7P0oh000?n000030?n0
00040>QX?02h>;@0X23`0;Ph]080oh0000<0d51h0:0Pl02P8?002@2P8?000`1@T7P00?l0003o000;
ooooo`002_ooool0:P1AOP`0=1<<01P30P0G2PX0104100P20@0;0@009@4204H20`1=0@40DP0205T1
1@1T0@P0K@8907412P1g0`/0O0@<07d42P200`/0N0L=091YK@3<dM@0bM;D0<[CeP3;e=D0RiFC01<A
401B2Ph0YP`A0;4:3P2c2Pd0]P/>0;P;3P2j3A40]@lC094B5@0l4140KgIe0;W5a@3Bfm`0fMoR0=SN
h@80fMoR02`0e]kP0=;Jg@31b/h0dm_M0=KCf02KEEl0VaHN0:4=4@2D3a@0G@/?02X72@0W:BH0KX5k
0;[7a03?fMX0bmGI09NV[P1BHfD08b@V04D83@1j0`X0Q@<808/42@2>1@P0R`<808X2202>0PL0SP<9
08@11P2=0`L0V0@909T62`2K3140[EMI09UbM`1B;c@0>@d@02020`0]0P<0G@@606T2101;0@80>P00
01n30@Wooooo1`2P8?000`3@D7P0oh000?n0000:0?n000030;Ph]02P8?00X23`00@0X23`00<0j6Pl
0?n0003oP0001P3oP0000`3@D7P0X23`0:0Pl00:0:0Pl0060>QX?03oP000oh000?n0003XJ3`0d51h
202P8?000`3XJ3`0oh000?n0000<0?n00080X23`00<0d51h0:0Pl03@D7P0103oP0000`20`03ooooo
ooooo`06ooooo`P00?l004l0:=L:05XS2P1E6a00IS`c05U3?@1D@dD0EdI<05e5C01T>D<0JRdf07X_
=@20?TD0MUmW075RI`1^HFH0Lf1U079IGP1kJV/0Ng5_07QaKP1gMVh0QXN108:8QP2IYJ80/;_109f[
/@2GY:P0J7Yn02I5I@1<KXL0Mhb?09N/[P1fRHl0//C909FX/@2L/k/0U:^d09R]/`2`Uj00VQ`W0:8L
9`2D6bL0X3i70:<_?02I21<0UPLA084Z?P0L<FH0Z<_O0<3EgP2me=d0_mCM0;kBfP2d`lh0LSe=08D5
4`240P`0P0@=078G8`1B;d`07bQD02P]EP1I8SP0J`LB064?5P0l9ch01aHj01lmE@19JFP0BfUT04MW
HP17If40BVUT04UXHP14I5h0AVAM04=QEP0oFTX08jPM00800?l02?ooool8003o0004052@N03oP000
oh000;Ph]0@0X23`00@0^3Rd0?n0003oP000d51h6P2P8?000`2h>;@0oh000?n000050?n000030>QX
?02P8?00X23`00D0X23`00H0d51h0?n0003oP000oh000>QX?02h>;@20:0Pl0040=1@N03oP000j6Pl
0;Ph]0`0X23`00<0D91h003o0000o`002oooool000[ooooo03/0FW<=03PE3P0H0@404`8200L00005
0@002P4002T20`140040D08205@00@1I0PD0H@8806X11P1_0PX0L@8;07H32P1n10X0PP@<07l63P2;
EET0a/W<0<cAeP3;e=L0cMCG0<;;bP1SKV/06PH808`?502^2@h0[PP<0;893@2g30l0[A0D08<>5P0^
1`L0MH1k0=;Kg03Ih><0e]kP0=SOh@3Ggn80emkQ0=KOhP38e]X0XK6e0<G?d@3FgN00]i^S09<J902P
2a40TA8E04L82`0C4A80CUmL08JIU036e=40c]SI0<cFf0020<cGfP0K0<;?cP2;UiD0AR@W07`73P27
0PP0Q`4608P21P2:0`T0Q`8508`31P2?10P0T0@:09<42P2D1@X0U@H<098>4P2lOh40RfQ^06I;C`0I
0PH0:0/<03D31@1M10@0K08305820`0o0@407X8100Wooooo1`2P8?000`3@D7P0oh000?n0000:0?n0
00030=1@N02P8?00X23`00D0X23`1`3oP0000`3@D7P0X23`0:0Pl00;0:0Pl0@0oh002P2P8?000`3@
D7P0oh000?n0000;0?n000030=1@N02P8?00X23`0080X23`1@3oP0000`20`03oooooooooo`06oooo
o`P00?l004l05nh605dS1@1M=2@0H4Pl05a7@01LADL0HCm606<V;`1[7RH0Jb/b07Q1A`1hD5D0Lf5Y
071QJ01_HfL0MVU/07eYK@1nJf`0MfaZ07A^J@1kNgD0QXZ508F=S02mbLd0NX>906ikNP2GYJ/0Aeac
00lcGP1ZQi<0MHN<09>XZ`2O/[P0TZN^08jSZ`2V^/80a]WQ09bd`@2?Z;H0[9JL07EGM016Bg/0HEQn
08@D9@2=1`l0R0`G04hbG013JiT0_MOT0<?Fg`2oeMh0_=?L0;kCg02lcmT0K4UH07<84`1^5B80F35=
028[FP0S?fl0KhjZ06=AH`1Q2aD0GBDc02TVB00<9dh0<5EX04UYK01=JFD0BfQT04YZI01;JVH0BFMS
04EWH@14IV00@F=K04=RF010GDl0;hHV00800?l02?ooool8003o000302S8?03oP000^3Rd00@0X23`
00D0j6Pl0?n0003oP000d51h0;Ph]00K0:0Pl0040;Ph]03@D7P0X23`0:0Pl0<0oh0000<0^3Rd0:0P
l02P8?001@2P8?00103@D7P0oh000>QX?02h>;@40:0Pl0030?n0003@D7P0X23`00h0X23`0P00o`0;
ooooo`002_ooool0F01BK@d0CR/T01P1000B0@402P8100H1000900009`8204/3101D0P80EP4105T1
101Q0@@0J04606D21P1H0`P0GP@807X4302110`0P@D=08Lh?P2h]KX0bm?F0<_De`3=dmL0c]KF0;Jo
_`0n@T<0C`/>0:H?4`2_2Pl0/P`?0:/?501V3140;aDI06mfM`3;eMD0f^3R0=SOh@3Gg^00emoQ0=WO
hP3Dem`0Yk:k05mfOP2da<H0e]kP0<o6b`2C?TX0UQ<J07@=4@0i2@X0<SLd08FETP2b`;/0bMGC0<kI
f@3=e]T0cMOI0<gFf03=e]T0bmGG0<WAd`2;Mg/0N@/C08L32@250PH0QP8708/32@2;10P0S0D708h3
202C10X0T08808h2202@1@T0RalQ0:V0PP2PPHH0;Q/P01H52`0T1@T0>0430644101[0`<0D@4103l1
0@0QP`89ooooo`L0X23`00<0d51h0?n0003oP0002P3oP0000`3XJ3`0X23`0:0Pl0050:0Pl0030>QX
?03oP000oh000080oh0000<0j6Pl0=1@N02P8?00302P8?00103XJ3`0oh000?n0003@D7P<0:0Pl0d0
oh0000<0^3Rd0:0Pl02P8?000P2P8?050?n0000308300?oooooooooo00Kooooo2@00o`00CP1Y=Ph0
Gd8/05m9>@1TAD40HBdb06<M9@1]7B<0J2LZ071;D@1cFV80LV9X07MWKP1bHFL0M6=X07YWK024GfD0
NdiA07]ZIP1kMg40Q8=o08b?R`1mQhL0ZkZn09>TY@2EXj@0KX6=01D_GP0_DgH0IGj30:o2b01_Ph/0
V:^a096TZ`2db]40QYZR09fb^P2aam40UkO<0:?0f@0JA8@0BG>[091CJP2E3AX0TPhG07L^AP0I<FL0
Vl3G0<7Fh032e]l0`=GM0;kDg02md]d0`=;N07A/NP1D>4T07BEB00h]H00fGGh0Nif/07JCW@1jQ8/0
CdaN00dRC@0R@F<0BFad04a_K@1>K6X0BfUU04mZI`1<JVD0CfaY04a[I@16If40AfIO04ETGP12HET0
@eiE03F2=@800?l02?ooool9003o00050=1@N02P8?00X23`0:0Pl03@D7P00P3oP0000`3XJ3`0X23`
0:0Pl0050:0Pl080^3Rd602P8?00103@D7P0oh000?n0003XJ3`90:0Pl0030;Ph]02P8?00X23`01D0
X23`0P00o`0;ooooo`002_ooool0F01IM0l0@AlH01/00@0C0P802@4100P20@070@409@8204X2101B
0@80E04305`2101T0@D0J04906011@1G0`L0AP8507042`1o10X0PP@808LD6@2YSY80bm?F0<_Ce@3<
dmH0cMCG0<kEf02Y]K<091dL07L?502W2a40WPlE05493P1ADE00/[jl0=;If`3Ign40f=kP0=WNh03H
gn40f=SM0;BCX01_C5/0=cTo0::a/@3Gg=l0bkk609Q?FP225Qh0>P`<030_;@1]OGT0/l;10<oIfP3@
fMX0dMSJ0<kGf@3=f=T0bmGF0<gFf03:dmL0c=GG0<WBe@2h/[D0MQPO08/52P270`L0QP8608X32029
10H0RP8509<42P2E10X0S`4908h2202?20d0]71_099jO@2VUYT06`X?01P31P0/0PH0D0@806/41P1Z
0`<0D0420441000RQ089ooooo`L0X23`00<0d51h0?n0003oP0002`3oP0000`2h>;@0X23`0:0Pl005
0:0Pl0<0oh0000<0j6Pl0:0Pl02P8?001P2P8?000`2h>;@0X23`0:0Pl0030:0Pl0030>QX?03oP000
d51h00h0X23`303oP0000`3XJ3`0X23`0:0Pl0020:0Pl0030=1@N03oP000oh0000<0oh0000<0P<00
ooooooooool01_ooool9003o001>06aA401L@R`0HDDg06@X9@1W6Qh0GaXO06Te>01WBdl0IeIN06eM
I`1cHf/0NVI^07UPJ@1kDE/0O3m507lZ;P20=SH0OfYW081iM`23QH00S96;08nETP2<TiH0Ph^A06ij
P013Eg800aiJ05akTP1bRHh0KhJ909Z^/@2H[[@0TjJ_09>Z/@2fbm80V;2j0:g5d@1ZRZd0FHVf08fY
a@2KR:00Va/[09T=5@1h8cH0;3EW06Z?]030f>00`]KL0<?FgP34e]h0`]CL0;oCg@2mdM`0[[o809Z^
_@0_D7/0>6:405^1UP1iW:`0M9:M08:LX`1MMh80Hh2>07FBU`1CL700CFaZ051^KP1<JVT0BfQU04i]
J01?KFd0CVaY04UWI016I5l0AF9N04IRFP15H5D0AeQ90P00o`08ooooo`T00?l00`2P8?00103XJ3`0
oh000?n0003@D7P60:0Pl0040;Ph]03@D7P0oh000?n001L0X23`00@0^3Rd0?n0003oP000j6Pl8P2P
8?02003o00_ooooo000:ooooo`12059^3@0L0P40604201820P090@402@8100T1000V0@<0B08405D2
1P1I0@@0G08406411@1Y0@P0L04;07422P1^0PT0N0<:07h2202710P0U@X@0993B`2eZk40bm;F0<_D
f03<eML0c=?G0<_De01dOG/0Da0C08DE6P1530h0HVQV0<[De03Gg]l0emcO0=SNh@3Ig^40fM_Q0<Ve
`@2IDF80FQ/T04Hn?`2R[Z`0emgN0<>X/@26=T80KAHO03@M7@1iQh<0//6o0<_Ge`3Af]`0d=WK0=;I
g03@e]T0c]KI0<kGf@3<e]P0bmGH0<[DeP3:dmL0a]3C0;J_]@1h5b40RP@:0P2:10T0502>1P/0T0H;
09<52`2F10/0T@8909<32`2B0`/0Qa`L0<ZY[02@O800I5EI02lJ7`0Q10X0=P<705@21@1b0PD0KP83
04h10P1000408H<12Oooool70:0Pl0030=1@N03oP000oh0000/0oh0000<0j6Pl0:0Pl02P8?001@2P
8?000`3@D7P0oh000>QX?0080:0Pl080j6Pl0`2P8?00102h>;@0oh000?n0002h>;@?0:0Pl0`0oh00
1@2P8?000`3XJ3`0oh000?n000030?n0000308300?oooooooooo00Kooooo2@00o`005@1JN@l0Gd4Y
05hY7`1T5@h0HRTT06M7B@1TDeX0GU9I06AFG`1]GfX0M5eW07Q:E@1m>TH0NB8[078N8026@Cl0LC`k
07aYIP1hMG40PXAn08fBS00208nGT00i07UoN`1ZMgd05ReO01PkL01LN840WJn`07V<TP2K[kH0SZ6X
0<?Dg02=XZ`0X;Fn09ffa@1mWk00^m?T059mZP2<V;L0WSM80:HA7@1n9SX0<3QY04mhX02lfN@0`MSO
0<?IgP32emh0`]CN0<7Dg@2kdm/0_M?K0;kBf`2id=T0RJFi03=GM`1cUjT0EgZ709Fb_@29YZh0PI^T
07ZBV@1QN7h0G7Ag05AbK`1@Kfh0D6iZ04]ZIP1<K6X0BF]W04e/J@19IfD0AfAQ04MVH@18I5d0B6=H
04UKCP08i`H00?l000Sooooo2@00o`020:0Pl0030=1@N03oP000j6Pl00H0X23`00H0^3Rd0>QX?03o
P000oh000>QX?03@D7PG0:0Pl0030>QX?03oP000j6Pl02<0X23`00<0:<Pl003o0?ooool02_ooool0
00[ooooo05P0BfD>01L1000D00405P@400L000060@00204002T20`180@<0E04405`01@1Q0PP0H044
06L11P1`0P/0MP8<07X2301m0@X0OP4808P32@2M2@h0S1DN0:f2R@37bL`0b=;D0<_DeP3<d]D0cmGG
0;Rm_01F9bT0;PD604Q:A`34c/`0eMcN0=OLh03Eg=h0f=kP0=[Dg@2eSI`0UCQ707DH8@13>SH0Wjn/
0=?Lg@3Cb=00TTAA06LG7`0Y4Q@0S9VH0<[DeP3Cg=h0dM_K0<oKf`3?f]/0d=WK0=3Hg03>e]X0c]KK
0<cGg039eMH0bM?E0<WCe`36cm@0XHbE07d>6P2;10X0S`D;08X22@2;0`X0S@<909@6302A0`X0S0<8
08d3202;1PX0Vda=09Z5R`2`X:H0GU9H02dG6P0W1@`0?0<806452@1k10D0KP8204l10`140@408H81
2Oooool70:0Pl0030=1@N03oP000oh0000`0oh001`2P8?000`3@D7P0X23`0:0Pl0070:0Pl080oh00
102P8?020?n00140X23`2`3oP0000`3@D7P0X23`0:0Pl0030:0Pl0H0oh0000<0P<00ooooooooool0
1_ooool9003o000`04b>2P1O>R00FaP=06LU701YBdD0GTe>061EFP1ODe`0J5EP06m6D@1b<Sh0PD97
07/c>@1i@4D0O5]L085/K@1fHf@0PGEc07imN028Rh@0SY6<096HTP2?V980OXB3055PL`016eX0<eAf
08bQYP1fR8h0RifR09:W[@2S^L80RijV0:Ji_`2T^/40^LgF09>]`@1dVkd0Lhb_09eQO02V72X0Sd5M
02PfLP1EOZT0_MOW0<KIhP33f>40a=SP0P32e^007P30eMh0^mGM0;SDf`2hdmd0]];L07jJ[01CLiH0
AFZ<05j2U01^S9d0Hh2<08FQZ01nVId0N92E07F<T@1LMgH0E75_059`K01;JFH0B6UU04QXH`1<JVT0
BVUW04UVH@17IF00AfIP04MRG018Ge<05lPB003o00Sooooo2@00o`00101hF;@0X23`0?n0003XJ3`5
0:0Pl0050;Ph]03XJ3`0j6Pl0?n0003@D7P06@2P8?000`3@D7P0oh000>QX?00T0:0Pl003052@N000
o`3ooooo00[ooooo000:ooooo`1H03mL2`0N0@40;P`=04HU9`0=0P401`4000X0000/0P@0BP830581
101K0@L0HP8806<11`1X0@L0L0<:07L32P1g0PT0NP8907l2202=0`X0W`P?09T;4`2B=Sh0^jJ[0<_D
e`39eMD0b]GF0<gEe`2`_;l09bl_04QCD@2__KX0d][J0=GKgP3Dg=h0emgP0=?4c@2/HW00W2@a08HH
7`109BD0WJbW0=7Mf`3He]X0XVUd05hJ8@0l;Bl0RI>D0<[De@3Dg=h0dm_M0=7Kg03@fm`0cmWK0=7H
g@3;c]H0/JFa09J1TP1aM880X:jb0<cEe`3;eMT0_kk80817D@262100R@<:08X12@2<0PX0R`<:08/3
202?10T0S`<808`31`281@P0O0l?0;R;S021L7L0[:>Y02XT;01[Gf<08`H:03l4201X10P0P@<506l2
0`1@0@40AP4102:20@Wooooo1`2P8?000`3@D7P0oh000?n0000=0?n000h0X23`00@0j6Pl0?n0003o
P000^3Rd0`2P8?000`3@D7P0j6Pl0:0Pl00@0:0Pl0030=1@N03oP000oh0000T0oh0000<0^3Rd0:0P
l02P8?000`2P8?060?n0000308300?oooooooooo00Kooooo2@00o`00AP11YPL0GR`?06HZ7@1Y;RD0
HSHa06A<CP1TE5P0HTYE06a3D01a?4L0K2`d07MAEP1mHFH0O6U_07eaM`22MGT0NfU[07icLP1mNgL0
RXZ708jASP2?UY00S9VC082=T00T>FH02BY]04]^P020UIL0PYNJ0:6g_01WOh@0Zl370:Fg_P2_`LT0
S:B`0:k8e@2hcmh0U:g00:f:V`2M@UP0Ke:002A7Q`1hWlH0`]_V0<CHh@36fN00a][Q0<KIhP37f>80
a=OP0<3Fg@2oe]h0^mGM0;WDg`2hdm`0RZJk04edT@1=LXd0QZJf05ioS`2F/kh0P9^V06R3R`1hTIP0
NI6E06R1Q01KMgH0EW9a04m]J`1:JVP204YYIP0804YYI`1;JF@0BVMS04UWG`16I5X0AV1C02FY8000
o`08ooooo`T00?l000D0D91h0=1@N03oP000oh000;Ph]0040:0Pl0030=1@N03XJ3`0X23`01X0X23`
00<0^3Rd0>QX?02h>;@09@2P8?000`1@T7P00?l0ooooo`0:ooooo`002_ooool0F00lF@X0@Q/N068e
>`1K=CX04@4100T10@0>0@40:08304D20`1@0@<0G08506021@1U0@T0JP4907042@1c0PT0MP4907P2
20210@T0U0D>09X6302N1`h0V0dE09eEG@37b</0b]GF0<SEe@2b`lL0;4=9061eL@30c//0cmWJ0=;H
f`3Dg=h0f=SM0<:Q[@2J<d40XALO070?4P12:2P0X[2/0=GNgP3Dc=<0XfQe05`I801THf<0^<G50=7L
g03Dg]l0dmcN0=CMg@3Afm`0dMOK0<6c_@2NLH40RSmA06LJ:00`41P0;CDg09FTX`3;eMH0YkJn04=4
D01J4QT0R@D;08`32`2<0`d0R`8;08/42@290PP0R`8708h3202=0`T0Q0T<09A@CP3:][T0L5QL09VA
U`0c7BL0=1`R01X41`0f0P<0KPD908D31`1^0@80C`4204<10@0PP@49ooooo`L0X23`00<0d51h0?n0
003oP0003@3oP0000`3@D7P0X23`0:0Pl0090:0Pl0050;Ph]03XJ3`0oh000?n0002h>;@00`2P8?02
0>QX?0T0X23`00@0d51h0>QX?03oP000^3Rd1@2P8?000`3XJ3`0oh000?n000080?n000030=1@N02P
8?00X23`00@0X23`00<0d51h0?n0003oP0000`3oP0000`20`03oooooooooo`06ooooo`T00?l00500
=;`705lX401Y<240IQhD06Xn=@1UD4h0Id5506DT;@1X9Rd0J41606UBEP1cHFH0NFU_07AUK@1kLGL0
PGAk07m^LP1lKg00PG]l08B4Q02=TXd0SiJB09>MVP1gQi@01b1Q00/XIP2>Z;80VJb`08RLXP26WJ40
[l?709NZ/@2]_/D0[/380;_?f@2H/l@0UkC40;6oaP2`Z;80L8B`00U2V`2?`>@0`mgT0<SKh`38f^80
a]SP0<;KhP35fn<0aM[R0<;IhP31e^40`MOP0;gEg`2ldml0^]?N0:k4e`0XD7D0=ej305f1V`1`T9h0
OYfW08FRZP2G/KX0Qj6Z06n:T01ZQHP0GW]l05McL`1BKG00CFU[04e[J@1;JVH0BFQT04][I01>K6L0
BVMP04QVG@17HET0;IH[003o00Sooooo2@00o`002P1XZ3`0j6Pl0>QX?03oP000d51h0:0Pl02h>;@0
j6Pl0?n0002h>;A40:0Pl00307QH]000o`3ooooo00[ooooo000:ooooo`1H045L2P1[@TD0CR<[03<D
6@0<0P401`4000d10@0/0P<0BP8504l1101G0@<0G@850682201Y0@P0K`8707432@1c0PT0N@4708P3
2@2D10/0VPD;09l7302Q2@l0U1PN0;2DU`38e=H0]LG;03aBF01ML700a=3=0<kGf03?fMX0d][M0<>_
]`2LDV40VQhZ09`D701=3A40C4U90:2][03Eg=`0`:J_09A0CP1]6b80JfIV0<KCd`3Egn00eMgO0=CM
g`3BfM`0eMWO0<_0bP2OJGP0Qb@`07/D7P1=2Q409QdM065bK`2T/k40bM?C0<?>d02;WJ80FfU]03lR
90212@h0SP@;08/3302:0``0RP<808`32P2:0@T0R`8908T32@29;Rh0eK^l08j0Q02APX@0QX>902@E
7P0M1``0:0/>04L4201d10P0PP8507420P1>0@80A`4202>10@Wooooo00<0d51h0:0Pl02P8?00102P
8?000`3@D7P0oh000?n0000>0?n000030;Ph]02P8?00X23`00L0X23`00@0d51h0?n0003oP000j6Pl
0`2P8?000`2h>;@0oh000?n000080:0Pl0050=1@N03oP000oh000>QX?02h>;@01P2P8?000`2h>;@0
oh000?n000070?n000030>QX?02P8?00X23`00D0X23`1P3oP0000`20`03oooooooooo`06ooooo`T0
0?l005009MD7064X3@1W8QD0IR@J06i6@@1Y>Sd0J2<Z06d_=01YAdl0IUIM06MIH@1bH6T0NFU`07]/
L`1oLGP0OFaa08=^LP1lK6d0PGUh08F4P@2<THd0TINE09NOWP1?I8T01RIe02A8N01dSIL0NH^B0;O;
d@20UYl0W;>g09V]/`2ibm80Xk>m0;W=e`2<Z[/0R:^m0;[DhP1GSKl0EiS@02IS[02MbnT0a]oT0<_M
i039f^40a]WQ0<SLh`39g>@0b=cT0<GKh`33f^80`m[Q0<;Hh030e^80_]GO0;_Ch@11Ji00M9ji05R0
W02F^<`0MIFW07ZFX`1nVJ80LhnE07jIW021Vil0JhJ:05ejO01BKg00CVi[04i[J01;JVH0Bf]V04e[
IP1>K6L0BFQS04AQF`14H5L0=H4d003o00Sooooo2@00o`002@1@T7P0oh000?n0003XJ3`0X23`0=1@
N03oP000j6Pl0;Ph]0160:0Pl003003o0?oooooooooo00Wooooo000:ooooo`0N04]W3P1O>S/0:0L:
01P00P090@40204100h0000]0@80B@8304`10`1D0@40E`4305T01@1W0@L0K@4706l3201e0`T0N@46
08h52P2J1P/0W@H<09d73@2O1@/0X0dA09M>E02i`<H0AUUS02U0A02fa<@0c=GG0P3>e]T0>039^L@0
SCA30:0D7P2P4QP0F@`?05EDE02Y][H0d]_M0=34c02A>4P0SQhX05La<@2oblT0e=gO0=KNh03Eg=h0
dm_N0=CEfP2jXK80T4II08/H9@1L3a@07P4401/P801hRhL0^l[50<SCd`3:eMD0b=GE0<ODe@37dm@0
S7an07/>502?1@/0R`<:08X32@290@P0S08808h22P2;0PT0PPD80:E]J`39`L<0JUQL0:6JVP1]JVl0
6`/@02/<4P1K>3/0C@@807L31`240@H0M08405000@140000;6<12Oooool70:0Pl0030=1@N03oP000
oh0000h0oh0000<0d51h0:0Pl02P8?001P2P8?040?n000@0X23`0P3oP0000`3@D7P0X23`0:0Pl005
0:0Pl0030=1@N03oP000oh0000X0X23`2@3oP0000`3@D7P0X23`0:0Pl0050:0Pl0H0oh0000<0d51h
ooooooooool01_ooool9003o001@027T1`1S9@H0IB<I06lm<`1/<Bh0IB8R06Te=P1ZD5D0IeUR06]P
JP1_HF/0Lf5Y07eTK@21EV40McQ407mGG01nFeh0OFQW08AmN`24Ph40R8Z908bCTP2AVj<073Id004Q
M`12IHX0OiJL09FY/`1^RI80[/K;08fV/02C[;<0Zl340;kAeP34e=`0c^7Z09G1f`1k^=h0LZSE0:[G
k`2agO40Wm3Y0=7Tj`3AhNP0c]oV0<CJh@39gn@0c=oU0<SLi037g>D0b=cT0<KKhP32f>80`MKS0;oG
hP2meNH0=f2I04Ij[`12KY00PZBh08FO[@2V`</0VK2k08FPZ021W:80K8N<06b8S01ROX00F7Qe059c
K`1@L6`0C6]X04m]J01<JVH0CF]W04aZI@14I5h0@f=I04IGA@00o`08ooooo`T00?l000L0D91h0?n0
003oP000^3Rd0>QX?03oP000d51h00H0X23`00<0^3Rd0=1@N02P8?00?`2P8?000`00o`3ooooooooo
o`09ooooo`002_ooool0F01GLaH0@R0O01h10@0L0`80304200H10@0;0@00;08304D10`160@80C`42
05L31@1O0PP0J@4706X11P1/0@D0L`8907h31`2E1`d0WPH=09/53@2M1`d0W@L<09l93P2=7BD0K5mV
01da=028VIX0am?D0<_Ee`3=f=`0`;K109M2D@2O51d0W10H06L<4P13>C/0/;Zj0=CKg@3Cc=80XUAR
09LM:01B5AP0UiNF0=KNg`3EgN00e]kP0=GLgP3BcM@0Y6in08L/>`1e5B80?`T?02HQ8P1?Gf00S9fM
0<3<b@3:eMD0b=?E0<KCe@37d]D0am?D0<OBe02m^[d0LA/R08X62P270PL0R`@808X22@2=10X0S`D8
08h7301l4A<0`JNY0;N`]P1OBDh0/K6a096CUP0^8bH07PL=02`<4P1<10L0M`<808H32@1d0P@0D041
04<10@0dA089ooooo`L0X23`00<0d51h0?n0003oP0003`3oP0070:0Pl0050>QX?03oP000oh000>QX
?02h>;@00`2P8?000`3XJ3`0oh000=1@N0060:0Pl0040=1@N03oP000oh000=1@N0/0X23`00<0j6Pl
0?n0003oP0001P3oP0080:0Pl0H0oh0000<0d51hooooooooool01_ooool:003o000^06LZ1`1Z=BT0
HR<J06di;`1/BTD0IeAF069GG`1SEel0JUeV07ENJ01fBE<0MR0]08XV<P1l3aX0Q4iC089WJ020L700
OWMc07]kN@2;SXl0RI:B07F8V`0497000RIh07ZK^@1]QX`0U:bc08nW/@2K]Kd0UJjf0<CHgP3Fhn@0
h^_^0<SMj03>io<0c>Gd0=[co03co_l0e^S^0=?]mP3Ek?L0g^_b0=SXk@3DiNX0cn7W0=3Rj@80bmkV
01l0b=cV0<CIi035fNH0`mWT0<CGh`30e^40_]GR08FXc01QT/40OJO608V^a`2C[;h0U[2n08^U[`2A
Z[00Y;g407VBVP25WZD0KhR;076=SP1ONg/0FGMc05EdLP1AL6`0CV]W04e[I`1?JVL0C6QS04QVF`16
GDh02>L500Sooooo2P00o`00103oP000^3Rd0?n0003XJ3`60:0Pl0050;Ph]03oP000oh000?n0003@
D7P0402P8?030;Ph]0040:0Pl02h>;@0d51h0?n00080d51h00<0^3Rd0:0Pl02P8?008`2P8?000`0X
b3coooooooooo`09ooooo`002_ooool0>P1=JA008@8101h20P0D0@803`8200@10@050@009`<304X8
2`180`H0CP4505l:401T0`P0J04506T1101X00@0LP8:08T52`2G1Pd0V0@;09L5302G10/0UP@:09P7
3@1a3AD0?cPh09n^Z`37dM80b=;D0<C@eP1oTI/0Cce809@H7`294AL0@@P=04i8B`2d`L80e][M0<^b
_@2QBUT0YaXP08e5A`2HVIH0d=[K0=WOh@3Eg=h0fMgQ0<fja@2ABEX0IADP03L;3P0W8200GVe/0:Vh
]`33c]40c]OI0<kEf03<e=T30<WBeP0K0<SBe037d]@0aLO<070T:`271@/0Q@8708L31`2;1@X0TP/8
09HA30231@H0U5AD0<:m`P1JAdh0N6=V09BJW@18AD/0810G02063@0R0PL0DP@:07L320250`L0N@<3
05@10@120@00=4@300Wooooo1`2P8?000`3@D7P0oh000?n0000?0?n000L0X23`0P3oP0000`3@D7P0
X23`0:0Pl0020:0Pl0030>QX?03oP000j6Pl00H0X23`00<0j6Pl0?n0003@D7P03@2P8?000`3@D7P0
oh000?n000050?n000030=1@N02P8?00X23`00H0X23`1P3oP0000`3@D7Soooooooooo`06ooooo`X0
0?l004P0IT4>05`U5P1S:AX0Je9606YLG01REEX0HEEK05a@F01WCeL0KSI107h_>@1l6b80RC0f08M2
A`23HfL0PWAf089gM`21O7`0OWmn08N<R`2=UYL0Bf:7008TP009<X<0M9BZ0;?4bP2FZkL0Ykc80;K9
d03Eh^L0k?Cf0>[_lP3fnOX0l?Oi0?Woo`3eoOl0c^Wa0<CTk`3hoOh0kOCf0>7[l`3Ji^h0enK[0=KU
jP3Bh^T0cN3X0<WNiP3:g>D0b=[V0<CHi@32f>D0`MOT0<?FhP31e>80_m?P082N`@0GBH80NJC008:V
^`2W`M00Xk_9096^^02=Yk80RZ:Z08^PZ02HZk80SjBV082GVP1/QhP0H7]k05]hN@1CLVl2055`JP05
055^JP1?Jf<0BfQM04MQDP0Eaa402?ooool:003o00<0j6Pl1P2P8?001@3@D7P0oh000?n0003oP000
d51h0100X23`0P3@D7P20>QX?0060?n0003XJ3`0^3Rd0:0Pl03oP000d51h9P2P8?000`1@T7Sooooo
ooooo`09ooooo`002_ooool0500fEPL0808101d20P0@0@403`8200@10@080000:`8404P2101B0@<0
E@4305h21`1S0PL0I@4606P21@1X0@D0K`4608`42`2C0`X0UPD;0P2C10X09`2D10X0Q0X@03LJ6`2U
/Jl0bmGE0<_EeP2ncM00DFUb03aCF@2LWj00HbX^03PQ8`1[MgL0^lO80=KFg02aNhT0W2Db0:lD6P2Y
:R`0a;2a0=?Mg03Ign40fMoR0=CHg02_V:@0KcM7038?5`10ADH0KX1o0:Ni]P37dm80d=OJ0<oFfP3@
em/0c]OI0<WDe`39dmH0b]CE0<SBe@020<KBd`0I0;2[/01d5200RP@<08H220260`/0R@L709TI4023
0`D0Ma4B0;n[ZP2JU9X0>b0W0:>KW`2RZjl0Cd1502873@0/2Q409`@805421P1m10/0QP8807h2101J
0@40AP4103I40P09ooooo`L0X23`00<0d51h0?n0003oP0003P3oP0000`2h>;@0X23`0:0Pl0050:0P
l0030=1@N02h>;@0X23`0080X23`00@0^3Rd0?n0003oP000oh001P2P8?000`2h>;@0d51h0:0Pl00>
0:0Pl0P0oh002@2P8?060?n000030=1@N?oooooooooo00Kooooo2P00o`00C`1FJ0T0DQ`;06]:?01Z
G5D0JV1N06=FF@1WBE40GSDn06Y6C@1e>400N30f07PnA@2;EUh0RdQC07m7DP24Mg/0QWal08AoOP25
QhH0R92@096LWP1BJi000R^=01I7V@2Q^/d0]l380<;?eP3Dh>L0i>kb0>S_m03YlOD0inc`0?cno`3_
mOT0g>cf0<kSk03/n_h0h_Wo0=odo@3BjO40eN_f0=KUkP3Ah^/0b]oY0<SMi`36fnP0a]cW0<7HhP30
f>@0_mKR0;oFh@2oe>00`]CO0;oAg`2id=d0Sjg006VA]@1WT;40>fR907BIZ`22X:`0QZB]0:C0b`2?
Z[D0SZNa08bS[028W:40PYNL06j8R`1TP840GGYk05MdLP1JLg00F7Aa05AaKP1EKFX0DVYT04YUF00Q
Yad02?ooool:003o00030=1@N03XJ3`0X23`00@0X23`00H0d51h0:0Pl03@D7P0oh000=1@N02h>;@2
0=1@N0d0X23`0P3@D7P02P3XJ3`0d51h0?n0003XJ3`0X23`0;Ph]03@D7P0j6Pl0=1@N02h>;@V0:0P
l003052@N?oooooooooo00Wooooo000:ooooo`0l031A100P0@407`8101P10P0=00001@4100P0000]
0P<0A@4204l20`1C0080G@4705011@1D0PH0I04506L11@1`0@H0R`<808l21P2C1@T0S`880903202>
1@X0FPP=061UI037d]80b=;C0<WEf01bRY40C6M[0;C4``37dM80=ci108FEUP32d=40f=_N0;RAWP2N
7BX0^1HL0;TC602cA4T0b/C70=WRhP3Gh>40en3T09jY/P0_9c405a<F05Q[J@2/_;`0b=GF0=3Lg03B
f]`0d]SK0=7Gf`3@f=/0c]SJ0<WFf036e=P0aM;G0P38dmD06P37d=@0SFii07d;5@2;10d0R`<:08D3
1`2I7Q<0Q@X507h52P28@T00`L?2071PIP1^DUH0YJRY08F@TP0b:Rd07@P>02<5300c1@/0H@H:07X1
1@250PH0O`4306800@1>0@40=T@22Oooool70:0Pl0030=1@N03oP000oh0000h0oh00302P8?000`3@
D7P0oh000?n000020?n001L0X23`1`3oP0000`3@D7P0X23`0:0Pl0060:0Pl0030=1@N03oP000oh00
00@0oh0000<0d51hooooooooool01_ooool:003o001?05Ek2P1E:Q@0JE=306]NEP1_H5h0JDM:06XM
901U4AT0M4]C079>E@1oF5l0OSU408<V;`2<8R/0PBP`08aiO@2<QHL0RHN708fCT`2GW9h0XJBX08JG
/@05>Y/06UN[0<SLj`3IgnH0eMkW0>3Xk`3Hh>X0j_7e0>odmP3hoOh0f^;X0?Kjo@3amo/0g^gi0:S>
jP1`/=h0VM3_0:kCjP2ae>/0b]kW0<WMi@34g>@0`m[S0<GJi@31f><0`=OR0;kEh@30eN40`=?P0;oC
g`2md]h0^m7M0;[Af`2M^/X0<eV103QRQ`26[;h0QZVi07fMZP21WjX0Mi>O072<V02<Zk<0PYnW082J
X@1_Qh`0IX24061mOP1FMGH0EG=c05YeMP1LMg@0FgMb05UdK`1AJV<0CfYN02^E:P08ooooo`X00?l0
00<0d51h0;Ph]02P8?000P2P8?000`2h>;@0oh000?n000030:0Pl0040>QX?03oP000oh000?n000h0
X23`00@0^3Rd0>QX?03oP000X23`0P3oP0000`3@D7P0X23`0:0Pl00X0:0Pl00307QH]?oooooooooo
00Wooooo000:ooooo`1H031?0P0R0P40704101D10P0<0@401P4100P1000[0P<0AP8305010`1G0@<0
G@8705021`1=0@@0H@4606T11P1e0@P0SP<909021P2A0`T0T04:09<63@1o3a@0@1lO0:Zf]@37dM<0
b=CD0:k1`P1AK6h0/L;10<oIf@3:eML0Sj6S0<CAd@3Hg>00cjfg0:P`?0305A/0a18G0<@D6031DED0
dLc?0=_Rh`3Khn<0b]OL03A=E@18GV00T:>Q0<7Bd@3BgMd0e=oP0=GOh03Bfmd0d=[K0=7Ig03@em`0
bm;H09RW/P1FKWX0OY>L0<WFf03:dmL0[jJ_07/_>`251`d0R@@;08/32P2<3@P0VB0B08451P1`2P`0
[XR60;k1a01@<SP0Tgmn0:>[Z`2S[k40De1D01T93`0[4AP0<`@:05/31@1i0@D0P@8507h2101W0@80
DP4103Q30PWooooo00<0^3Rd0:0Pl02P8?00102P8?000`3@D7P0oh000?n0000=0?n000030;Ph]02P
8?00X23`00T0X23`00<0^3Rd0?n0003oP0000`3oP00F0:0Pl0030>QX?03oP000oh0000D0oh0000<0
^3Rd0:0Pl02P8?001P2P8?000`3@D7P0oh000?n000040?n000030=1@N?oooooooooo00Kooooo2P00
o`00C`0kX0D0FSTI06EB@@1/ETl0M4m<06/Y:P1/4QD0JRPZ07U=EP1j?TT0P3e7084V<@22:Bl0RD=9
08iHGP2@M7/0WIRL09VIW@2MWZ80[:f_0;bj_033amH07eJV025Y^`36g^d0g^K[0=[Tj`3Ah>L0en?Z
0=OQjP3?gNP0b]cV0<WLi@2^a=/0W;OD0:g;j@1m[mL0/M[f03Uh^@1UXM80ZlkS0<WLh`38f^80am[R
0<KJi034fN@0`]ST0<3Fh`31en<0_mKS0;oChP2me>40_=?Q0;[Bh02fdMh0]M3O086V_P0fH8l0G8FU
041YPP1hUjD0RJJa08JV/027YZh0QJ6Z06j9T01SPHH0IX:606V6Q`1ROh00DW5^055_K`1BL6l0F7Eb
06B1O01SOG/0EVm[051[H@0iQCP02?ooool:003o000306RX?02P8?00X23`0080X23`00H0j6Pl0?n0
003XJ3`0^3Rd0=1@N03XJ3`20?n000030=1@N02h>;@0X23`03l0X23`2oooool000[ooooo05P0;dd2
02820@0L0@405P4200h10P040P401`4102L30P150@80C`8405H10`1N0@H0H`8706021P1W0@H0J`46
07d2202C0`X0T`8909L42`2I1@`0RP`?04092P21QH<0am;C0<WAe02Y[K<0UZFX0;[:b@3>fMP0dM[K
0<oJg02ob/`0hm;I0=>8V039=d@0hB4T0>XV8`3_;BX0kBlZ0>IRH03cj^/0j>g^0>W]kP3Pi^L0dM[K
0>3Zj`3QjNX0hnWY0>;Xj03Oi^H0h>KW0=cQh`3GgN00f=ON0<F/^@1^Cf80:38m06f5RP2ib<X0c=GI
0;6NZ`1m:c/0R`/E08`42P2:1@T0RP`50:H_6P231`D0MPT;09MPG@36`<40X9RL06A3A02]ZZT0VZZY
0:6`/@0O8BH050X>01X7300/0`L0H`@:07X11`1o0PH0MP4306<10P1C0@40>4822Oooool00`2h>;@0
X23`0:0Pl0040:0Pl0030=1@N03oP000oh0000`0oh0000<0d51h0:0Pl02P8?00202P8?000`2h>;@0
d51h0?n000050?n000030>QX?03@D7P0d51h0080d51h2P2P8?000`2h>;@0X23`0:0Pl0030:0Pl0P0
oh0000<0d51h0:0Pl02P8?001`2P8?000`3@D7P0oh000?n000040?n000030=1@N?oooooooooo00Ko
oooo2P00o`00C`16[0X0FcdI061:>01O:bD0M2XW06`Q8@1]=3L0IR`c070O:P1l6RD0NB`d08A>E029
EUh0RDeI09A@G@2GE5/0]JBX0:NX[02^/[H0^ko30;bna037b=80F7bf01EI/@32fN`0d]_S0<cHhP2o
d=T0^<_D0;W>g02F[kd0[<G@0:C0c02[amX0VKO=0:k;gP1RT/40GYk?07jbf02=bN/0`^3_0<[Oj`35
gnh0`n?a0;SOl`2[fOD0WM?d08c9l`22__80Mk?/06nZiP1XXn40HYcL05nEeP1JSm40Eh[@031W]@07
>IL0?G>f05N7^01^U/80G8>[05R2XP1mXkT0KY6S08^[^P1mVZ@0H7f3069oP@1WPXH0E79a04m/JP1>
K6X0EG=_05QeLP1ZQXD0P9NF05QbJ`0mRT002?ooool:003o0004052@N02P8?00X23`0=1@N080oh00
0P3@D7P30?n000030=1@N02h>;@0d51h0080j6Pl?`2P8?0;ooooo`002_ooool0F014?PP0808101d2
0@0I0P803P8100@2000400009P8204810`1>0@@0D`4305`11P1O0@D0H`8606d2201c0`T0Q`@;09D4
2@2I10X0W`L;0:893`1f4Q<0EDM60;c5a@39e=@0aK[106a0C02cZ:d0d]_L0=;Lg@3Egn00en7R0>?R
i03QSiX0gCQ10?Hb=03n>SD0oD8h0?m<@@3nDd@0mWA[0?oXjP3mo_d0o_on0?knoP3jnod0k_;d0?;d
mP3`lo<0jnk_0>W]kP3Vjn/0h^KW0?7Mj03IUJT0SSiA02hG8@2?Xj@0`mGG0=3Hg@3=a]00UD5D09X<
6P2K1@l0U0<;08h91@2d@240UAd:08@41`1l:BP0cknn0;k4b@1jIFX0QFa/09:JV`2N/;40Z;Fg02HP
9@1KBT`06PD:038;3`1D0@H0K`4407/11@1c0@80H@410540000j@P49ooooo`L0X23`00<0d51h0?n0
003oP000303oP00;0:0Pl100oh00102P8?000`3@D7P0oh000?n000050:0Pl0T0oh002P2P8?000`3@
D7P0oh000?n000040?n000030=1@N?oooooooooo00Kooooo2P00o`00C`0Re@D0H3hJ058c8P1B7Q80
HB4F06Pe<@1P9b`0I1<J06lO9@1b=C`0QV1W08=4D@2:<3l0Sad]0:]KI02<@TX0]jBW0;Fm`@2h`<D0
^;[10;Vd^@2i[Jl0NhJZ00/nT`2Wa^00Z[o90;[=e@2_`L`0YKW409J]]`2`a]00Z/3=0;W>eP33f>40
`]o`0:;4e@3Hl?T0coCl0;GUl`2Jg_00XnCk08?FnP1G`oL0>kGg022Mk`0DR>h03H7b00Mgl@0?I>40
<4jo03e5[@12?:40B3VL04LbT011;8L0>R=j03DOM00b8gX0;21i02LRM`0P87<0629d01<SMP0D;7l0
4Bim01XkQP0Q@Wl0;U1l041QO@1FMhX0G7b1051`K`1?KF/0CfiY05EdLP1dTY00RJ:T05QbL01;F4/0
2?ooool:003o0007052@N02P8?00X23`0=1@N03oP000^3Rd0>QX?0020?n000030=1@N02P8?00d51h
00@0oh00502P8?000`3@D7P0X23`0:0Pl00<0:0Pl0P0d51h502P8?0;ooooo`002_ooool0F01I:a00
808101`10@0F0@802P4100@200090@00:P<204820P1>0@80E`4305`11@1Q0PL0J`<907812@1g0@X0
S`D>09T42P2O1PX0Y0P=0:8=4@1_;bl0Y:RX0<_DeP3Ae=H0/79k08PZ=P3;/KH0f=gP0=WPh`3Ih^D0
hnKZ0?>i`P3/AU40ncDj0?hg=`3n@C`0o4Q10?]=A03lEDL0m79X0?gTi03oooh0o_kn0?[knP3inO/0
loCg0?;cmP3^l?<0ko7d0>c]l03`k?00l/OG0<e`Q`24:c`0E38i0:Zc]@3@gN80eMgR0=_BgP2iJg`0
/1TS0;8;4@2^2Q00X@P:0:d`502X;A<0T@T508L:302YNGP0aLK;0<;3c01G<SX0ZibK08REU`2@XZ@0
QY2C01`D600I2Ph05@85034>401>0P@0K@8307L10`1a0P<0F`4205410@0k@`89ooooo`L0X23`00<0
d51h0?n0003oP0002`3oP0001P3@D7P0X23`0:0Pl02P8?00d51h0?n000@0X23`00<0^3Rd0?n0003o
P0003P3oP000103@D7P0oh000:0Pl03@D7P30?n000030;Ph]02P8?00X23`0080X23`00<0j6Pl0?n0
003oP0001P3oP0000`2h>;@0X23`0:0Pl0090:0Pl0H0oh0000<0d51hooooooooool01_ooool:003o
001?02WK2P1R<`d0CB4@05H/6@1Y;1h0GQ@B06`S9`1W9RX0N4E=079EGP23Ifl0Mb4]09DZ<@279B/0
W6Q[09f3Q`2_YZ/0[Jbb0:b^/@2[Zk00YZN/09>FV01hRIl022md08BP]`2caL/0_<oH0:Vmb02ldMX0
`MSR0<GOk`2oho<0S/gd08[Bm022bo40Oloc05fol`0bZo407Io[01^Kh`0NXND06ZG/01F[m@0=Z?X0
2J7k00REn`08R_/02G_f05AIa035:ET0c1dn0<HF=@345300_aD]0:`<8@2U3B80V`XO08d6702B2B80
Q0`R08L^A01a7CX0L``^06h<=@1V3S/0E0do040?A@0Y3T/06QAE010KGP0F;fX0:Tef049TNP1DM7L0
EWAc06F5Q@2<YZX0DVa]04=nA008ooooo`X00?l000@0D91h0;Ph]02P8?00X23`0`3oP000103XJ3`0
^3Rd0:0Pl02P8?030?n000030;Ph]02P8?00X23`01l0X23`00<0^3Rd0?n0003oP0003P3oP0030=1@
N0/0X23`2oooool000[ooooo05P0ERXA01d10@0K0@405P8200H10@020@40200002/20P180@80D042
05P1101P0PL0IP4607422P1h0``0P@8=09/63`2S1Pd0Z0L?0:`93P2S5QT0XGn00<kDeP3AemP0d[Zo
07LY<@0^1``0][Rj0=GLg`3Ig^80f=kR0>[PiP3ICeT0o2d_0?d^;P3m=300oChi0?m<B03nCdT0oU9;
0?UmM@3ol_40o_kn0?gnoP3moOh0nOWk0?Kgn@3bm?H0kNoa0?O]mP3ldn40l8fM0<e4E@1^=d40W9ZL
0=CNh03Hh>@0h=_T0=J/_P2kDVL0aAXV0<LB5`313QD0^PhA0<0b4P2j<A80YP/90:093P2H?S`0clO6
0<G:d@2VTi`0FRT]0;Bc]P2>WZ<0Z[Rl0:6Z[@0D3a<03`<701D31@0a0`D0G0<607D31P1h0@@0K@42
05L10@1?0@40?4812Oooool70:0Pl0030=1@N03oP000oh0000/0oh0000H0^3Rd0:0Pl02P8?00X23`
0?n0003@D7P40:0Pl0030=1@N03oP000oh0000h0oh000P3XJ3`30?n000030>QX?02P8?00^3Rd0080
X23`00<0d51h0>QX?03oP0001`3oP0001@3XJ3`0X23`0:0Pl02P8?00d51h00L0X23`00<0d51h0?n0
003oP000103oP0000`3@D7Soooooooooo`06ooooo`/00?l004h0IRP705lY6@1P8AH0H`l906@?3P1Z
<c@0KT=706hU<@1j=d00OUiV08=EG@26CE40VWn409Z@UP2NUi`0YifS0:FQYP2NWZ@0V9bQ09BKX02;
UiT0PYJS01@jLP2@/<X0_<oO0;G?j02G`NT0MZcY04bIj@0[R>/05Wo[00N3m005S_P01I7e00BEmP0<
XoP09;Ce04o8m`1me_T0L<od042imP0NWO@03hW^00QbiP0:Hm`04UC@01Do^01J<8/0]14^0;<96P2Y
1AD0Y`TG09<?602@7b`0Q0/K0849501f4a`0KPTD08@d?`2QOXX0]9FR07DK:@1o10d0O`8=07h23@1l
0`h0M`<@07<5601V22H0C`/f034DB`0F75/05S9W03iQN`1[RY00NYJI04mZI`0kU3/8ooooo`/00?l0
00<0oh000>QX?03XJ3`00P3oP0001`3XJ3`0X23`0>QX?03XJ3`0X23`0;Ph]03@D7P08`2P8?000`3@
D7P0oh000?n000090?n00080X23`00<0j6Pl0?n0003oP0001@3oP0000`3XJ3`0d51h0:0Pl0060:0P
l0_ooooo000:ooooo`1H04lU3@0M0@40704001H20P0<0P401`4100T0000c0`<0E04405P21@1N0@@0
I@4607432@242a80SQ0F09P;4@2]2Pl0/`P>0;D:3@2l3A00]B/^0=c0a03Ee]P0e]KH08j3P`0o?3h0
VZBU0<gGf`3Bfml0emoQ0=OMh03Sa/d0cC0g0>TP8`3]8R80kR@S0>lW9P3c;Bd0m2la0?<_<@3YAd`0
n]_O0>g_l@3YkNl0j>__0>KZk@3Ti^X0k^?Z0>N]_03LFW40hCQ90=U4BP3FZ:P0dMGI0=[RiP3Ffn40
elCB0;mUM`2g8c80aALQ0<PB5`314A@0]a0?0;d`4@31?1<0/@h;0:h93P2P8B<0d[>c0<O=d@39`LX0
KSY40:Z4Q@2laLH0TJBV0:>c]P2>V9`04`/?01@5200E0`D09`8305T<3`1^0PH0MP4406`20P1M0P80
C`4103Q20@Wooooo1`2P8?000`3@D7P0oh000?n0000;0?n000030;Ph]02P8?00X23`00L0X23`00<0
d51h0?n0003oP000203oP0020=1@N0<0X23`00<0^3Rd0?n0003oP0000P3oP0000`3@D7P0X23`0:0P
l0020:0Pl0030>QX?03oP000oh0000P0oh0000D0^3Rd0:0Pl02P8?00d51h0;Ph]0070:0Pl0030=1@
N03oP000oh0000@0oh0000<0d51hooooooooool01_ooool;003o001>06`Z3@1Y8aT0I`l<06<A301^
>3D0Jde;05hM8`1n8BT0LR0W08idOP27NX<0QgV108f3R`2?R940ThZB09::T@2ASI@0TY6G09:HW@2F
WZ@0TJ2X08>P^`0OCI`0<VNo03A^b00NG/P01dC100==d`04J_401G?g00IjnP08Po`028Ki00R8m`08
QOH027k]011fi00LK]h0;VSG041MbP1=D;X0GT>W06dgSP1e;H40OBYf07lUK0218fL0QaaF0:h@:`2c
2AP0[PTF09`B7P3NYJd0^9FV0;bMZ@2@J740_JNb0;^V[`1iFVP0/I^X0:nV]01oHfl0VW5e08UIG01g
>3h0MbD]06`22@1b0@H0M`8907T22`1j0a40K@TR04H<=@0P5dh0;Dn207>I[P1EKV`0::XS2?ooool;
003o00@0oh0000<0d51h0:0Pl03oP0000P3oP00O0:0Pl0050;Ph]03@D7P0d51h0=1@N03XJ3`01`3o
P000103@D7P0X23`0:0Pl02h>;@20:0Pl0040;Ph]02P8?00X23`0;Ph]0<0d51h00<0j6Pl0?n0003o
P000103oP0000`3@D7P0^3Rd0:0Pl0020:0Pl003052@N?oooooooooo00Wooooo000:ooooo`1H04TR
3@0L0@408`8101T20@0=0@40208000h10@0e0P<0E`4405`10`1U0@D0KP8807/53@2@4QP0T0dB09d:
402`2@d0^0X>0;/;3`313Q<0^34f0=g5b@3CeMX0bm7D059NG@2V][H0bMCE0<;<dP3?fM/0d]cM0=;H
f`35V:00^Q/R0</C5`3;4QD0bQ8E0<XD6@3@4aP0eAHH0=TI6`3A9B`0j;_20>7Uj@3Qi>P0gn?V0>CS
j03YcMT0bW>50<DY>@3>6B<0bQLK0<=<D@3<bLh0d]_N0=KKh034]Kh0WDEH0:dC902d31H0]0`D0;49
4P2/2``0XQ/10<QI7`2M40@0Y`L<09d>4P2gKVh0c<_@0<[:d@2;IW<0HB@X0;:WZ02ga<T0YkFm0:Rg
_02HXjH0ASDj02P<400M0PD0<@@705@52P1^0PL0LP4306X10@1L0@40CP4103E100Wooooo1`2P8?00
0`3@D7P0oh000?n0000;0?n000X0X23`00<0d51h0?n0003oP0001`3oP0000`3@D7P0X23`0:0Pl003
0:0Pl0D0oh00102P8?0;0?n000050=1@N02P8?00X23`0:0Pl03oP000202P8?000`3@D7P0oh000?n0
00040?n000030=1@N?oooooooooo00Kooooo2`00o`00CP1LFPh0Ga0706TP601g?SL0KC`f06]9A@1Z
;bh0NSdn07]OHP1lL7L0O79k07mcO01nLWd0PGZ208UoQ`2DR8l0ViFJ09VMY@2AXK@0Khba03mY[P0>
B:/013R^004TX@03>[/01doH00=0c`05D^001VK`00IRiP0;E=D05DO002a4]@0i?JL0DcnR070mV02;
=h/0X3n:0:<nR02MAHl0Re:F075JW@1RH:L0C6Je03]]`00]K/H09FO<02iNa`2P=7<0f1h[0<lE8031
6RP0ZC1309YEIP3@_lX0Y8nL09MVO@2QKh80WYBR09MjSP2>HgH0UX>C09V6U02:NXL0Rgj:0:1oSP1T
1A40J@4406X:3@26<cX0N0H?07P4301m1100N@TQ04/FB00X?7X0FGF601?C4@Sooooo2`00o`000`3@
D7P0oh000?n000020=1@N0030:0Pl03@D7P0j6Pl01X0X23`0P3@D7P0103XJ3`0oh000?n0003XJ3`3
0=1@N0D0X23`00<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0X23`0:0Pl0020=1@N0030:0Pl02h>;@0
^3Rd00D0X23`203oP000103@D7P0X23`0:0Pl01@T7P;ooooo`002_ooool0F0187``07`4102D20P0J
0P802`4100P10@0=0000=P<505d11@1W0PD0K`<807h>50253a@0Q@L=08X43@2N1a00/@T?0;H;3P2h
2Pl0_0dB0:`X:P3;^;X0c]GF0;g9bP2T/k<0`Lg?0<GBe`2__L<0c]SI0=3IfP3Be=L0XUeW0;LD6P2l
41<0_a0E0;l@5P304aH0bA@F0=4H6P3D5a`0c2<X0>Nj_`3Qi^T0hnKX0>gNh`3RUJD0c4IG0=@V<@3G
6Qh0caHI0<`H6P2nB4h0d/kC0=;;d`2nUJ80XT5@0:TC7P2X2180Y@L?0:@73@2R1P`0X1`70<aY9P2P
;P/0U@H809H93P2:;2`0ckVh0<K<dP2_VjD0FaXS09]]KP2f^[d0ZKJk09RW[P2DY:X0P8J=03LP:@0o
7bH0=a@J03021@1H0PD0L04607410`1Y0@80G08105010@190`89ooooo`L0X23`00<0d51h0?n0003o
P0002`3oP00:0:0Pl0030=1@N03oP000oh0000L0oh0000@0j6Pl0:0Pl02P8?00d51h1`3oP0020:0P
l0030=1@N03XJ3`0oh0000X0oh000`2P8?000`3oP000d51h0:0Pl0070:0Pl0030>QX?03oP000oh00
00D0oh002?ooool;003o001>05e]301N6`X0LC@V06@H401e9ah0Md]207YWHP1iKFl0L6Ya071YK`1e
JW<0M6I`07E[M020N7l0SHJ@09>@X`1iQj`0?VBU01A5X004=j400c>R00@cZ`05>KL00c6e00@h_`09
CmL01D7900@c]00Z<j<0GBIn07<RJP1n:6X0O3Ag07LnP`1bC980HFRa05B2bP1BVmX0KKKP08?;jP1/
coH0?[oh02Zgn`0AWOT029Cj00F3mP03L?001eoM074cQ03952T0``dJ0;DB7@3GTIL0aZ6a09Y?J`2j
NH`0XEU^0;YcPP2NNXh0]iZX0:b>V@2=HWD0Tfmm0;2S[P2=OHX0YHJD06`95P1b0@D0H0dB09]_N01m
;c`0QT==07lX<@213QP0S``I05lMC@0O=6805LPH2?ooool;003o00030=1@N03oP000oh000080oh00
00<0^3Rd0:0Pl02P8?005@2P8?000`3@D7P0j6Pl0?n000030=1@N0030;Ph]02P8?00X23`00X0X23`
00H0d51h0?n0003oP000oh000>QX?02h>;@40>QX?080X23`0P2h>;@40:0Pl0<0oh0000<0^3Rd0?n0
003XJ3`00`3oP0000`3XJ3`0X23`052@N00;ooooo`002_ooool0F01870X07`4101h10@0F0@805`82
01820@0B0@40>@<506H21P1`0`L0L`8708lC702=31<0O@<:08X7402L2A40[`/C0:`93P2Y1``0[0X>
09dA5`2dSiH0b];D0<KCe038c]<0[ZB`05AIIP2O[[<0c=OG0=?Hf`3?[kH0Y2Ta0<TD5`3D5aT0fQ/M
0=dN7P3U9bD0l2dY0?0/:03e=Bl0jde50?cPh@3fmoT0mnc_0>JBUP3^DD`0n4@m0?Y1=P3f=RX0lBlT
0>/[9@3RJV`0kL7<0<aDIP3:8Bh0c1HN0<4>5@2e2a80Z0L<0:D82P2L4@D0aVPM09Xb1`2>2@H0S@@;
08<K7`3@[Zl0al_=0<K:d@1eAU00HalS0;JUY`2`_l80[;c00;O8c02K[:h0If=Z03HL:00R51d0MF9Y
04052P1]10T0N@8607@10`1X0@80F`8104h10@170`89ooooo`L0X23`00<0d51h0?n0003oP0002`3o
P0000`2h>;@0X23`0:0Pl0070:0Pl1D0oh0000<0d51h0?n0003oP0002`3oP0030:0Pl0030=1@N03o
P000X23`00P0X23`203oP008ooooo`/00?l004h0?XX406dh801/81<0N1D=07l_8@20GE00LVMV07I_
MP1[I6d0JF5Y071VK`1dIW00MVeh07=hSP1<I9@06T2?00DaU`02;j000S:W008eZ`06>Jd01bjP01Dc
Y@0N78H0=19Y04TMKP0<5gT00QUo03<ZQ01@>X`0>UB]02M^bP0HQND06Yoe01RTn@0DZO/06ZGh01FG
m@0FRN`058O/00Qik002Lnh00G7]005YjP01INL00F;V005Lh003E]T0FC^I0<LE;`3@4AX0`1LQ0>Z/
^@2lSil0gXjR0;0Z@02a6c00]bDj0:HL=P2gBEl0/59Z090Y?P2dK7`0/WF608]8F`30VZH0QSA307/2
2@1`7R40[INN07UAF`1oF6@0YhZF09ARKP2I?4L0MQm501@SG00CZ1X8ooooo`/00?l000<0Z8Pl0;Ph
]03oP0000P3oP00B0:0Pl0030;Ph]03@D7P0d51h0080X23`00<0^3Rd0=1@N02P8?004@2P8?001P3@
D7P0oh000?n0003oP000j6Pl0=1@N0H0oh0000<0j6Pl0?n0003XJ3`00P3@D7P01P2h>;@0oh000?n0
003oP000X23`0;Ph]080X23`00D0^3Rd0>QX?03oP000X23`052@N00;ooooo`002_ooool0F0156`T0
8P4102@20P0O0@408@8201/10P0G0@80<@8406821@1_0PH0L04807@;3`269BT0KP@<07l5302B1`l0
X0/D09`7402N1P`0X0H;0:<8402O:CD0/Vam0;=nS@2YEfL0N2<`04`l@`33cLl0d=[L0=oAe`2gEV00
e2<W0>lV8P3j;RP0n2`X0?de;`3n@3P0od]10?iCB03nFTX0o7Q/0?oFgP3ke^<0n/kL0?V]]03kPWL0
oViO0?eQD@3jETH0n71S0?IaK03_GF@0l4UD0?T`<`3i9bX0lbDV0>HN7P3G5a/0bQ8D0;/E3@3<HAD0
]4T>09h=1P2P1P`0S`X=0:Q`K`3<c<`0a<k@0;bb^01E51h0SfUY0;o3``2d`/H0VJ^^09>WZ@2=X:80
M6mg02D8500P2QL0?BXe07He?01f0`T0P@8707X20`1X0@80GP8305010P171089ooooo`L0X23`00<0
d51h0?n0003oP000303oP0030=1@N0050?n0002P8?00X23`0:0Pl02h>;@08`3oP0001@3@D7P0X23`
0:0Pl02P8?00oh0000X0X23`00<0d51h0?n0003oP0001@3oP008ooooo`/00?l004h0>:d506hl701g
=b40MbXF08iNC023LVT0L6UU075YKP1QF600HU]S06mXM01TIg`0=DQg00X/NP03;Hl00R^D004ZV003
;Yd01bnN01P/U`0a8Gd0Ba9D064DCP1J44X0@Pi@03@TN00?;j001CFf00M;d00:I^P01g?`00EajP03
JnP00fcY001Xj001Jn`006W[009`kP02M^l01Gka00Z4k`0AT?0049[c01>OmP0;W?X01YKj00J@n`07
P_P0C6CA0=TYC03Z82H0h1/T0=D]@@3DBV@0a2M30<PC8`323AP0_@/F0;`<5`2g31L0/`/H0:44402J
1Q<0UPHD09044P2:31d0Q@TG08@32P2ECE40RF1a09MZN02?Mh80/J6/0:bNZP2VM8@0NR9601`QEP07
b0d8ooooo`/00?l000D0J:Pl0;Ph]03XJ3`0oh000;Ph]00?0:0Pl0060;Ph]03@D7P0oh000?n0003@
D7P0^3Rd5`2P8?0C0?n000030=1@N02h>;@0^3Rd00<0X23`00@0d51h0?n0002P8?00D91h2oooool0
00[ooooo05P0A1P802<10@0V0@40:04102T20`0R0@806P4202L00@1J0`D0K0<506X11@1W51L0LSDj
06L4301f0@D0SPD<098540281@`0V0H;0:87302X2@l0/@`E0:lB7`2_5R00_1@L07<@5@2SWZ00cmSJ
0=CLgP3R_LD0`cHn0>TV9P3e9B@0nbXV0?dZ9P3k;BT0nS</0?Hh<P3g@S/0n4Lo0>m>BP3SJg@0h7J0
0>5hP@3WJ6X0keiB0?1?@P3dC400l6UP0?6VY`3/YJX0lhN;0?8c=`3k;2/0nBLY0?8R8@3V6a/0gATJ
0=@K603:?0`0hhHN0;@O1`2f30l0/`/B09@H603?^KL0aLo@0<K>d02OPXT0HAXQ08mkOP2Q[K40Y[Fk
0:jm``2b`lT0V:J^030T;`108BH0=A<L02`64@1Q2Q@0O`8608<01@1m0P@0KP8206410`1<0@80A0<1
2Oooool70:0Pl0030=1@N03oP000oh000100oh000`2P8?000`3@D7P0oh000?n0000Q0?n000@0X23`
00<0oh000:0Pl02P8?001`2P8?000`3@D7P0oh000?n000060?n000Sooooo2`00o`00CP0WePH0KR/8
08ED>02;JE40QG5R07MXH01REE<0IeiP075[LP1OHg@0=49b00TRJ`048Wd00R>5008VSP049Hh03R22
02`KL@1G65T0KaQ>06<ID00m8F<06BR400/]V`059id01SN`00Ho_@03<K@00SBh0098b`02C<l00USI
005Rh@02KN`00gSb00>5l`0DVoD0>[Gf06gAm@2Dh?T0XNWn08SRo01AcOX0;[ci00jRn`05U?`00hOl
00=cmP0PH=`0X2UX0<lE:`393b80a14T0;`>8P2h3240]0/O0;0:6P2/2AP0ZPPE0:/75@2X1a@0V08=
09D43@270@L0Q@4708811`1o0@L0O0<:09E<E02fRIP0ORPm09M>H`37WZl0]Yf]0;V9V02=7CD0=dH/
00?a0`Sooooo2`00o`000`1@T7P0oh000;Ph]00>0:0Pl0050;Ph]03@D7P0oh000>QX?03@D7P06`2P
8?000`3XJ3`0oh000?n0000@0?n0000:0>QX?02h>;@0oh000=1@N02h>;@0X23`0=1@N03oP000d51h
02S8?0_ooooo000:ooooo`1H04HH2@0X0@40;P4103020P0Z0@40908101l10P0V0P80D0<706L31P1T
0@D0K18H07HU;@1]0`X0O@8:09l@6@2Q3QD0UPL<0:D:3`2/2Q00]@`D0;lA4`364a<0c1DC0=8O7@1`
8bD0b/_=0=?Ig03Gem`0c7f90=8W:`3[9200mR@R0?/X9@3m;BX0oC8^0?hk<`3n@ST0oDa30?iEB`3l
IUh0nXJ90?ZV[`3l]l@0o9fR0?enL`3mJUX0nV5E0?VSW`3_^;d0jJV_0?>T[@3Y@DL0nRd^0?HV:P3b
92<0j1lO0=TL5@36;PH0gWdF0<5:2`2l40l0^`XD0;H?502eFeX0d/o@0<OCd`3<cm00OdQ@08eAE02]
ZJX0[;^m0:2_/`26V9h0SJ2V096OY@0]7bP0@1`S03T@6@1E4A/0M@D>08L22@250@H0O@430781101V
0P<0D`4204D30PWooooo0P2h>;@00`3@D7P0oh000;Ph]0020:0Pl0030;Ph]03oP000oh0000l0oh00
00D0d51h0:0Pl02P8?00X23`0>QX?00S0?n000<0X23`0P3@D7P90:0Pl0T0oh002?ooool;003o000e
01O]1@1f;PL0PeTo08E^FP1nKV00O6aT075PF@1[GfD0C4m]00lSHP0266`00QYh00<KNP0346X04QI[
03@@E01N4440I1M604HQGP0O9W`02RbC00LeY@04=Jh01CNb004NVP0189d01Ck0004Z/003=[`01EWN
00Ecl@07R_X02IOm00^Qo@09Y_l05:ol02Vjn@0j^_P0>Zof02RKl00GSNh02HGc00F3mP02Mo800Vc/
005Uj@02HnH00eWK00A@d00Y@:T0Dben054/N019;7L00P14:7D05`0o9780@R=]04HRIP1<85l0EAaF
05/HC@1W6DL0JQLj06<@;01Q2Al0I0DB06@32@1V0PL0LP@?07L;6`241A40T`HE09@@902ZCV40/EIZ
088E<00D]Pl00?l000Sooooo2`00o`000`0Xb3`0oh000;Ph]00<0:0Pl0040=1@N03oP000j6Pl0=1@
N1l0X23`3@3@D7P=0?n00003052@N000o`3ooooo00[ooooo000:ooooo`1H04`I2P0^0@40=@8203@2
0P0Z0@80;08302@10P0M0P80=@8505000P1I0@80I04507412@1n10`0T``F0:lG7P2`3Q<0/0X?0;@:
402g2Q80_`dD0<PA4`3>5180dA@C0;lL7P1dCE40eM_N0=?Hg03C`<H0/SHm0<XK7P3G6A`0hadN0>`M
703`81l0lb4Q0?DV9@3^8b<0lRTY0?4Y9`3b;Bh0kRdg0>X_?P3X;d80ib`l0>HW<03Y:2`0gbT/0>1n
Q@3HX:`0b8^G0>>JY@2f92d0baPL0<`D703<4AL0aa<B0<@h2`3QSAH0b6`A0;DG302l3a@0^0lD0:PY
:03K`;h0c=;E0<W@d`2iWZL0LQTP0:J9S02FXJT0]L?:0;c8c@2__l<0Z;Vn09:SZ00Y6200Ba<L02d5
3P102Q00LPH>08X22P2?0`X0S0D807T20`1]0P80F`<204P30PWooooo103oP0001@2h>;@0d51h0:0P
l02P8?00j6Pl0100oh0000@0d51h0:0Pl02P8?00X23`8`3oP0001P2h>;@0X23`0:0Pl02h>;@0oh00
0;Ph]0L0X23`00<0j6Pl0:0Pl03XJ3`0203oP008ooooo``00?l004d0Ke/A081SA01dHT/0Lf=A07IU
F01ZGUX0<SUI00@GF`025fX00QEZ00@FJP0C45X0?0]105P==P1:44@09aQR00dWQ@05<9X00RnR008]
XP0189<001^=00@e[P02:Zd00S2k00QDgP03BMT01D_L00Q[m003No/01H3i009im`02N?L00W[g009j
m@02MO@00GOf005alP03Lo<00fg/009Vi`03H^<00UcM005He@02EM@00UG@009@bP03C<H00TRo00A3
^004?k@013n`00@o/P04>jl013VZ00@gZ@04<jD00c6O00@aV`05;IL01bbC00PYR@0;9h<042Em01TQ
K00K4TL090X^04X<:`1T1b00P0HB08l43P2M2140WPPB09/>6P1/8TT054Le003o0008ooooo``00?l0
00<0d51h0:0Pl02P8?002@2P8?00103@D7P0oh000>QX?02h>;@b0:0Pl080d51h1P3oP0000`3XJ3`0
X23`003o000;ooooo`002_ooool0F01B7`/0=0<203<10P0i0P<0<@4202/3100J0@80304102T20`1A
0P<0G04106/2101i0`X0P`D=09<8402[3140[`P=0;483@2d2@l0^0TA0;d;4P313Q80``lB0;h@4`1]
2`l0R8R;0<[Ff@3>cmD0Ve9M0:4B602Y3A<0/`dB0<0>4@3F5QP0eA4D0=`E6P3J51H0hATJ0>DK703V
6a/0iQlM0>@Q8@3V92@0ib@W0>DS:03W92L0kBLY0>HT9P3E>D40i8>B0>66U`3:Ef@0^1LL0;PA502b
2a00^0hB0:hM1`3BQQ@0c8TH09DO102J0`T0V@@9098@4P2cNWP0bm3B0<K?e03=bLl0Od=<08Q1@`35
a<@0ZKFj0;O2a`2a_l@0UjN^09BU[@2FXjX0<QTP03X94@0/1@l0@@XC06h73P1i0@<0O`4408D21P1o
0P@0LP4205`10@1=0`49ooooo`030=1@N03oP000oh000080oh0000@0^3Rd0:0Pl02P8?00d51h3`3o
P0001@3XJ3`0X23`0:0Pl02P8?00j6Pl0280oh0000H0d51h0:0Pl02P8?00X23`0=1@N03XJ3`70:0P
l0040;Ph]03@D7P0X23`0>QX?0P0oh002?ooool<003o001=06Ik401jGcP0Je]006YK@`1/FTT0>Se:
00<FB`025V400Q=U00@@G00J2DH0CPX`05L==00W3T/02QYc00<UR`02:YD00B^I004/XP02<:P00B^R
004_Y@03AlH01TW@00E1c`07F^<01eKR004jc003D=d00V7Z009SjP01HNT005kV009Tj@01H^H00F3S
005Og`02Gn000V;R009Nf`02G=P00UgF009Hc`02E<H015C600QF``07DKP02Dn/00a=Y00>Bi`04DVE
01Q>UP0FBi805TR?01A8S@0DAH/0442800`kQP08=XD01SB700@bQP04;XL00R^;008[S`02:8`00b9o
00@LL00;6FP08aQH050D?`1h2b@0W@dH0:<93@2F2aX0BbER01<RB@00o`002?ooool<003o00/0X23`
0P3oP00h0:0Pl0030=1@N03oP000oh000080oh0000<0d51h0:0Pl000o`002oooool000[ooooo05P0
ER4<03T20@0j10@0?0<403020`0P0@804@0100X10P0]0`@0FP8306D20P1/0@<0LP4407X11P290@H0
Z0P=0;493P2`2@d0[@P<0:h8302`20d0/PT@0:h93`2N31<0=`lB0:fj_039dmD0_J>]09@K902[3a<0
/0lD0;L>4`364AD0daDG0=LD5P3P6AP0iR0M0>dS8@3c:B<0lb`V0?Hh;P3b@SD0l4]40>a>C03^CDT0
lD@n0?M5?P3e?cX0l3He0>@g?`3S>4<0h2`b0=@L7@3:5aX0`a8E0;T?3031E0`0e9PA0:=11P2K30P0
VP<;09442P1d51L0cKRi0<C?d@35cM40_:Zb05`E7P1oEE/0V:N]0:jl`031c]00`<k@0;g9cP2BXJD0
UZFX06eZK00O1`h08`4<050C801`1@d0M`4307<00P1f0@@0N08307L3101Q0@40DP<02Oooool01@3@
D7P0oh000?n0003oP000d51h00<0X23`00<0d51h0?n0003oP0003@3oP000103@D7P0X23`0:0Pl02P
8?0S0?n000@0X23`00<0oh000=1@N02P8?002@2P8?090?n000Sooooo3000o`00C@11^@T0O5d`06aJ
?P1/Fd@0CTE500LE>00365<00Q9G00T=D@0W1cH0A@PW03P<>00E4UT01Aeg00<VR@03:YD00BRI008/
W`01<JL00cZe00A4`@04AlD00e3C00A:c`04=Kh00T3800A4c@03=/<00TC=009HgP02FM`00USJ005G
f@02F]X00U[I009Je`03F]001E[900UJa00@GK`06F6e02EZ]@0`JjT0>6jO04AaWP1:M9P0EGfK05Mo
UP1LPi<0HhFF06f=VP1dTil0M9:N07>@W01_SIL0N9FQ07^HY@1hUj80K8^J05inT@1HNHh0AfR2045T
P`0aEgh07TIf018hL@09;G400RAa00@SM00=8Vl0:AmR05hI@@2B3al0VQ<W03T[K`09FSd00?l000So
oooo3000o`000`1@T7P0X23`0:0Pl0060:0Pl0030;Ph]03oP000d51h03X0X23`00L0^3Rd0>QX?03o
P000oh000;Ph]02P8?000?l000_ooooo000:ooooo`1H060[3P0l1@80=0<20384100P0P80608201@2
0@0?0@40=@D606431@1T0@80J@8307421@1i0@H0R@<80:H;3`2_41@0Z0`@0:D82P2U1`X0Z0H=0:`8
3`2T20h0L@/?04A1@P35d=80cl?;09U7E@2/4aT0^10C0<@E603?5aT0gA/M0>`S8`3d:BL0nC4[0?`i
<03m@CX0nd8m0?i?AP3oI5T0oXEl0?bYZP3m^lD0oJV/0?f3P03oKf/0ofUR0?mHE03oE5@0oTY<0?a2
A@3h>C`0kb/_0>PV9P3E=100hYLG0=1o4`2[7@D0/P/=0:T53@2D2`l0Zfe^0=7=c`35d=40c<gB085L
I@1K3AH0Sgj008fQY02M[k00WJfb0:Jg_@2fa<`0X[6i09VU[@1KDe`0;P`D02`12@1610`0K`@:07/2
1P1c0@<0K04306030`1_1@L0I@4205L50@Wooooo00D0d51h0?n0003oP000j6Pl0;Ph]0030:0Pl003
0=1@N03oP000oh0000d0oh000`2P8?000`3XJ3`0oh000?n0000P0?n000030=1@N02P8?00X23`0080
X23`00<0oh000:0Pl02P8?00202P8?000`3@D7P0oh000?n000070?n000Sooooo3000o`00C@0;m`<0
KWdN06Q=;P1NDD@031Ha008DAP0355<04P]103`8:@0k22T050a200<FI@038X800RN<004VSP01;9X0
0c:W00<j/@03?;H00T2l00=5a003?Kd00T3100<j_P019ZT00bjc00I9b`04C</00dg;009@c@03D/X0
1UC200UD_@0BFKT07f>`039[Z@15M:<0EgnL06:5V01/RiH0L8bA07J?T`1lTi@0PiVI08fQXP2AXj@0
VZf^0:6d/`2W^[P0[Ko00;75a@2kcL`0_Lk@0;c?d02ocm40^<W<0;O6b@2Y^kh0VK2b08VRYP1jU9T0
K8V:06F1P`1NNWl0D71a04EUI`0jG640;E9L02=6G@0C>5l022e[00`/NP0h:W00L2=F02@^M`0?FcP0
0?l000Sooooo3000o`000`0Xb3`0X23`0:0Pl0050:0Pl080j6Pl?P2P8?001@2h>;@0d51h0:0Pl02P
8?000?l000_ooooo000:ooooo`1H04Y>1`111`80;P4102410@0A0@404`4101l20`0I0@40:P<305/8
2@1P10D0SRhc07893`1d0PL0Q@8:0:8;4@2W3Q<0W`/@0:<;402U1P`0Z0L<0:X;3`2?3Q<0>A4A09fV
Y`3D`LT0ZTiK0;LK8@3>6Q/0eQ`L0>4R8@3W8R80lR@U0?XX903j;2D0oSD^0?`e;`3i<bd0ncD`0?Xk
=@3j@S/0m4900?96CP3cC5T0lD==0?Hn@`3f=CP0mc@g0?8/<03/:B`0jBL^0>4O:@3M8BX0fQdR0=0Z
4@3ROA@0h:DD0<A02P3<6Q@0b18D0<0@502a@T80h<S90<_Cd`36dM80`[:j06DH8P1/7B@0T96I09b_
]P2fa/X0]/?80:fk`@2R/[T0UJJ^06M[M`0[3a`0?0lI04@6301M1@T0RRT^07@2201b0080I08205D;
301_5aP0H@@305P90@Wooooo00<0d51h0?n0003oP0001@2P8?000`3@D7P0oh000?n0000<0?n00003
0=1@N02P8?00^3Rd01h0oh0000<0j6Pl0?n0003oP0000`3oP0040:0Pl080oh002@2P8?000`3XJ3`0
oh000?n000080?n000Sooooo3@00o`00C00^c`/0HdDJ02XX:0025CL00aE201/>=@0m21d090P]00L?
DP026VX00R9m008WR`02:9400R^F008`X@02<jP00C>Y008g[002>K000SVc008f[@02=Z`00cVe004W
X`019j@01dFi00]>/P0JF:P0<fNS04acWP1LOiT0I8BE06Z6T@1`Rh`0Ni2A07jBTP23V9H0TJBR09f^
[@2a`/00^l[;0<SBe@3:dmP0aLgA0<C6bP2i^Kh0[Jje0:BUZP2MWJ00TY>D08f<SP28QXT0Q82007mj
N@1hMgD0N7Ac07=`K01/KVL0J6aV06=ZIP1IIf00EfAP05ARH@1<HEh0B69L03mMF00kFU<0>UMA03ME
D@0`DU<08TAG00deJP0C=hD03S=i00Z]6000o`08ooooo`d00?l000<0D91h0:0Pl02P8?000P2P8?00
0`2h>;@0j6Pl0;Ph]0120:0Pl003052@N000o`3ooooo00[ooooo000:ooooo`1H04Mo2@173080;041
02@10@0V0P809`4103020P0T0@406`4204<20P1/0`H0OP@;07P22@1_0@H0QP@;0:4<4P2Z3a@0ZP`C
0:P73P2[1Pd0/`/?0:h=4P1k1P/0W75d0=W?d032Hfd0aahU0<dE5`3D61X0eAPK0=LG6@3P6AX0l1lN
0?TW8@3k:R<0nRhW0?Y4@03i>c40o4@f0?Y8>03hE480mfYH0?=cJ@3dN7<0mWE]0?]TF@3iD4@0oDe3
0?]7?`3i?c/0m3Dd0?0_;P3Z9RD0eS4@0>F26`3QZA<0dG4?0<4H2P313A00_``B0:`F6@3AXj40cm7C
0<_Be03>dMH0W6Md07XA6@2PJF/0W:V`09>V[@2K[k@0TJ>X09VZ/@2JZk<0XK:j09NIX@1J>480=@dG
03/42`1[2@l0Q`T?0843201c0@<0G`8305420`1L10@0F0D105HP0`Wooooo00<0Z8Pl0?n0003oP000
0P2P8?020=1@N0030;Ph]02P8?00oh0000d0oh0000<0d51h0:0Pl03XJ3`07@3oP0000`3XJ3`0oh00
0?n000030?n000070=1@N02P8?00X23`0:0Pl03@D7P0oh000=1@N0090:0Pl0030=1@N03oP000oh00
00L0oh0000<0j6Plooooooooool01_ooool=003o001<00_g0`1iEBD051XP008E=00E2BD0>@TJ01D6
8`0455D00Qeb008TO`039XD00RF900@XT`019i000BRF008XV@02;9d00SBS004dYP03=jX00c^^00<j
Z@08?J<06d:B03ACR`1<KXl0I8:B06n8S01eRhd0Mhb=07^AT027W9T0U:NT0:bm^@2mblX0`<_=0;o5
b@2e^Kl0[:ba0:2JX@2>R8d0PgYh07edK`1jLFP0NfiQ07]/FP1kKET0O6eF07IUC01cITX0LfQ=071V
C01eJU40MF]D07=[E@1aJ540LFM=06iTBP1bIT`0LVU?071VB`1`ITd0K6E<06YRAP1UHTH0G61705=M
A`1=Fd/0@UI:03]EC00jF4d0:TU401HmD00A>T<00o83003o00Sooooo3@00o`000`0Xb3`0X23`0:0P
l0020:0Pl0030=1@N02h>;@0X23`0480X23`00<0:<Pl003o0?ooool02_ooool000[ooooo05P0<k/9
048=0@0]0@40:@4202l10@141@<0C@L803020`0E0@40=P8306`3201l0@H0O08707@11`2;1P`0YPdB
0:P:402Z2A00[`X>0;<83P2k3180[@P=098D603:VId0cIbT0;XO:P3<4AL0c14B0=LE5`3N61X0iQXM
0?0P7P3m;R<0oSLZ0?lk;`3k>S40oeA@0?a?AP3oHU@0og=Q0?nCP`3ob/D0onO/0?o/mP3ohND0ojRV
0?mlM03oKF00of]N0?mGC`3nAd@0odE20?`k<@3aKQd0ij`L0>F^6`3A@`T0fQXH0=0C5@3?51P0^d93
0=c@d03;dM@0bM7C0=7:d01k9S80N0lF0:^=T`2W]l00//;70;g<cP2halL0/;k009JV[P1kSYL0H6Me
02/E901<>440CR/b06863P2A1P`0R@<707T21@1I0P80C`8305410P1@2@<0@4l22Oooool0101@T7P0
oh000?n0002P8?030?n000030=1@N02P8?00d51h00d0oh000P3@D7PT0?n000@0X23`0P3oP00<0:0P
l0P0oh0000<0d51hooooooooool01_ooool>003o001;05>J5`0M71@03@hO03475@0B1al00Q5300<M
J`018Gl00B:4008OP0028XH00R:=004RRP018hX00RB>008YU@02<9`00cJJ00/nU00UDY@0AFZB06=n
T@1fRi40LHF607N:RP24UiL0V:VY0:Zi^`2/_;l0Z;Fj0:B//02PXZD0RhR807]dL01eK680Mf]M07IZ
F@1iL5/0Ng9N07E]F01`Je<0KF]B06]XC@1YIT/0JFE:06YVB@1ZITP0IF5206ER@`1SHD<0Hf5406=P
A@1THd`0IVMB06MWEP1WJ5@0IFE?06EXD@1TJ580HVA?05iPBP1MHDT0G5Xm05UG=P1HEC<0FUHd05QE
>01CEcl0D5M404=E@`0eCSl0:4Pi02AK;003l`800?l000Sooooo3P00o`030:0Pl0030=1@N02P8?00
X23`04<0X23`00<0:<Pl003o0?ooool02_ooool000[ooooo05P02_H305@P1P0a0P40<@8204@5101K
20L0E@L902h20P0>0@40;04306/41`200PL0P0@707@21@2>1@/0Y@P=0:/73@2Z1P`0Z`D;0;062@2f
1PX0/@X>0:@c=@3X/[P0_TQA0=HL803K6a/0gA/K0>4K6`3Z81h0lR<O0?`[903n=BL0oSXZ0?`h;P3i
=2l0oTDo0?Hi=@3lAT40ne1;0?UHEP3fJ6l0mGF30?MkS@3dL7T0n5mT0?eBEP3kBDP0oDY50?i1?P3m
>cT0ncHe0>hm7P3_W2<0hK@I0=^B6@3?:0h0faXL0=HF6@3>71l0dhF70=7Be@3;dmD0bM7C0;nQZ@25
6280UdQ:0;:Z[`2KZk<0WZjf0:Bb^P2a_<00]lC60:Rg^`2`_l<0LW9j02X@6P0h8bl0@1hY05/63029
1@`0P@8507P51`1G20T0C0D604P20@1C40H0?U412Oooool00`0Xb3`0j6Pl0?n000040?n000030=1@
N02P8?00d51h00d0oh0000<0j6Pl0?n0003oP000703oP0000`3@D7P0oh000?n000030?n000050>QX
?02P8?00X23`0:0Pl02h>;@00P3oP00<0:0Pl0P0oh0000<0d51hooooooooool01_ooool?003o001:
04Do3`0S3A006`TG00<B=@0375h00Qie008QO`028X@00Aan008IO@016h<00R6:004SR0039hH02363
02I>R@18JhT0JhFA07V>TP20TYD0PiFD09FWY02S]K@0Y;>f09bTY`28RhX0LW1]06UTE`1YIU80KVMC
06]PB@1XGcl0K6I606UPA01/I4T0KFY>06e]C@1cL5<0K6a?06e]D01/IT/0J69106MTA@1UHTD0J6A6
06UTB01XI4D0IF=406ASA@1SH4D0HUe305eM@@1OGT80IVE=069UC01SITd0I6MA06AWE@1TJ5H0HFEB
05iSD01LH4X0FEe305MK?P1GFSh0EU]204UC?`18DCd0?dTc049C>`0hCc/0;DPc01Fi4@00o`08oooo
o`l00?l0B02P8?000`1@T7P00?l0ooooo`0:ooooo`002_ooool0F000o`00CVP>03X90P0k1040FPX7
064:2@161@H08@4200T10@0O0@80I@D:08832@1i0`D0JP4308L21`2Q1@T0Z0<80:/42@2^1@`0/`H=
0;h;3`2h5AP0jX690<MDG@365aX0cQDG0<hE603>5AT0cQ8H0=TF6P3Z71X0nRHO0?h^8P3m;R80n2LS
0>8M703W;Bh0eadN0?<d<P3k>300oCde0?dm=P3j>cD0oT8k0?do>03l>S40nbdY0?`_;03m<RX0oBlY
0?`^9`3f<1l0iVdG0=ZZ3P3@X@X0_EL>0;XD402o3QD0^``B0:TS903J`/<0b=;D0<GBdP39cm80VUeW
08<L8P30Wj<0[;Vo0<;Ae`3=f]d0^/G80;[6b02ja<L0ZkRl0:Fb]@1^J6d0>aLM03053@1810d0J0H<
07`42P1d0PD0H`L907Y4A`0n10@0F@L405@?0@0/SP09ooooo`03003o003@D7P0oh0000@0oh0000<0
^3Rd0:0Pl02h>;@0:`3oP0000`2h>;@0X23`0?n000040?n000060;Ph]02P8?00X23`0:0Pl03@D7P0
oh002`2P8?000`2h>;@0oh000?n000030?n000050=1@N03oP000oh000?n00020`0002?ooool?003o
001:03>`2@0c5`T02Q@T008KB0028Vl00bAm008RP0027X000Qj3008MO`018H800RAn01DhO010Gh<0
JhF@07^?T025VYH0R9^J0:2a[`2Q[K40V:2R08>6QP1cM700LVeT07E_H@1fL5X0MFiF075]E@1bLEP0
LFiG07A_E`1aKE@0LG1H075^F@1aKeT0KfiF06i_D`1]KeH0Jf]A06ETA`1XHTD0If4n06AO?@1PGCl0
HEdn06=L?`1UH480Hf51061P?P1PH480H613061O@01PH440HF55065QBP1SIDh0HV==065SC@1PITl0
GVA<05]SB`1IHDT0Fem:05MLAP1EFT80DeU104iMB`0bACP0:cl]041?>@17Dc`0?Dhh02Uc8P00o`08
ooooo`l00?l000<0N5Rd0:0Pl02P8?00AP2P8?000`00o`3oooooooooo`09ooooo`002_ooool0F000
o`00@7l803l70@1>1`@0H0`905P:200b0@40700100`1000B0@40A`4506/2101W0P80HP4107l00`2R
1@X0ZP@90;062`2c1`X0^0X=0;/:3P2n72<0`C<k0;HC6P303Q80_`dB0;l>5@2n3QD0``hE0=TF6@3/
7A/0nRPS0?`/8P3m:b@0nR/U0>8_;@3UI6L0b1`O0?@_;`3l=2`0o3T/0?`h:`3k=RX0nSH[0?/g;P3m
=b/0o2hU0?`a:03l<RL0nR/R0?PY703Y<`h0mZdZ0=Rb3@3FW1D0Zb/30;482`2]1Ph0X0H<0:13A03>
cLl0`LkA0;o?d03<cm80OC0j088`=P2SW:80Rj6Y0:c0b@3<gN@0c=[Q0<_Gg03DgN80bmSL0;G1a026
NWh0G38i04063@1[2Q<0R18I088;4@1]0@@0F@<505LE6@1P1`L0J0H305PB0`0_T@09ooooo`03003o
003@D7P0oh0000@0oh000`2P8?0[0?n000030:0Pl03oP000oh0000@0oh00102P8?000`3@D7P0oh00
0:0Pl00:0:0Pl0X0oh0000<0P<00ooooooooool01_ooool@003o001904=83P096S800QmK008SLP02
9Gd00bJ5008SQ0028H@00b5h01dmN01DLHP0PIBG092OW`2BY:<0WJn]09NTYP25SXd0L71/06QSF`1l
Nfh0U9>60:RXY036`l<0`Kg10:n]/02QXIl0SY6:08V;O`29RG/0QXIe08:3K`1mOf`0NWU/07EiJ@1^
MF<0KWAR06ecHP1[Lf80JFmL06E[E`1PIDd0GV57061RB01OH4D0GEm505aPA@1IH4@0EE`n05UM@01I
G4@0G5i405]LA01KGTT0FUm<05]RD01NHdl0GF9905]SBP1LIDd0H6MB05eRC01KH4X0Eea7051E@@1B
G4T0@E=502i4=@0oDd00CUm>051RD01@F440?dPZ003o0008oooooa000?l05P2P8?000`2h>;@0X23`
0:0Pl00_0:0Pl003003o0?oooooooooo00Wooooo000:ooooo`1H003o000dV@H0A@T105@<1`1A2@D0
A0L502X0000Q0@404`4100l20@0[0@80C`8505L20`1T0@D0P0450:852P2^1`/0[`T<0;0;302c2@`0
]0T<0;4;3`2_2Q40]@X?0;`=40303Q40`PhB0<XC503I6AP0jRDQ0>lZ8@3`<2H0kcH]0>`m<`3V?SH0
gFIT0>2PY@36DU00e4a20=9>@`3>DdH0be=50<aFA`3<EdP0ae=40<YGAP37DD80b5130<Q<?P3<BCX0
dDPf0<YI;`3EZd40d;8d0=2A<02h=1D0_QlL0:@A4P2C4Q@0[g=d0<O>d@30cm80aM;E0<K1aP1]6200
P3m40;>h_02N/kT0`M;J0<CEg@2ocmH0b]KN0<[Ih`34e^00`loG08UeO`1F41T0GPL=06L42P2220h0
Q`@906`10P1F0@80HPT;07X:1`1X2080EQD102^R0@Wooooo00<00?l00830003oP0000`3oP0001@3@
D7P0X23`0:0Pl02P8?00d51h01T0oh0000<0d51h0?n0003oP0003@3oP0000`3@D7P0X23`0=1@N004
0?n000030=1@N02P8?00X23`0080X23`00<0oh000=1@N02P8?002@2P8?0;0?n0000306RX??oooooo
oooo00Kooooo4000o`00B@0lQ`h03a`a008QH@04;8800BN200<]T0029X804C5d04]TO`20T9D0TZ2O
09RUY@2CWj00PHV806Q]IP1WHe@0K6A<06mUBP1gLEH0M75K07QdI`1mNW@0Ui6D09ZCV@29Q8H0PGik
07YjK`1jNV`0NGYY07EiI01aM6<0L7AT06ieI`1`NF/0LWa^07F3MP1_OW80I7Q^05meK01JKVL0D6MP
04]RE`1<GeD0CV5F04]OEP19GED0BEmF04IKC`18Fdl0B5Y@04QKC`16F4d0B5UD04]OF@1?HeX0EV=E
05mUE`1VK5`0HVeK06=^G@1WKUh0FfAA059LB01@FDH0BUY>03I<@00lE440D6AD05IWF@1IK640FfMD
03]^9P00o`002?ooool@003o000307QH]02P8?00X23`04D0X23`00<00?l0ooooooooool02Oooool0
00[ooooo05P00?l002S61`1?5000APX403<20@0]0@80:`4102X20P0Q0P404P4101X1001:7Ql0Mcm2
06H32@210@H0W@H;0:`<402d4a80]14@0;D>3`2k3Pd0_A0?0<0D50346aL0aRHN0<4`:030?CD0_DTm
0<=MD02oKUd0]gIU0;AnL02`QgX0[Xj10:ZCR@2PUi40VIbK09FCS02FTHL0Ti6808j>Q`2<S8<0Rhb3
08N9P026RX00QHUo08>9P@21QW`0P8Ai08>4N022PW80OWi^07YnJP1hOV<0OWQO08MbH@27J5T0OUi?
07YJCP25NWH0TIZM09^XZ`2U/KD0XiNJ07XQ8P2OM7P0[;_20:c1c@2eb=@0a=KP0<cKiP3Bg^P0c]_U
0<cLi@3<eN00H4ME06P?5P245QL0QPlB0:DA5@2P20/0OP<406@10@1U0P<0LPD306H?0`1M7@406l`0
2Oooool00`00o`00D91h0?n000030?n00080d51h0`2P8?000`3@D7P0j6Pl0?n0000>0?n000030>QX
?03@D7P0d51h0080d51h00<0^3Rd0:0Pl02P8?00502P8?030=1@N0D0X23`00<0oh000=1@N02P8?00
2@2P8?0;0?n00003052@N?oooooooooo00Kooooo4000o`00B@0RePX0:BHQ008QG005>iX013NK00Hd
R00ZAg00IgMo086>RP25THl0OXZ706]bK01THe80KfQ?06i/D01^Je00KfU?071XB`1aJDP0KFE206mS
@`1eJ4P0NF]@07m`E`20Le/0OWEL07YdG01jLe/0Lg5H075cF`1^Lel0Ig5U05a/I@1;HUd0?5MD035>
C00bD4`0<E9=03YIE00hEE40;D]702U6@@0X@cd09Clj02@m>@0P>SH07CXf01dl>00T?SX0<T@k03Y9
?00cASP07cXd01Pf<P0hDDH0Cei>061[G@1NIeP0GfQH061YE`1RJUT0F69A04mOCP19Fe00?eI904]Q
D`1GJU/0GFaR05i]HP1KJel0GfMD02ZY6000o`002?ooool@003o0003052@N02P8?00X23`04@0X23`
00<0N5Rd003o0?ooool02_ooool000[ooooo00T00?l000_g101KB`H0?`/102`20P0/0@80<`4202l1
0P0`0P400P0Q0@80C@1H;C00PTQ=06l62P230`L0Y@h@0<8R8`33:RP0_R/W0;DZ9@2]<RT0Wd<h09YC
B@2FHeT0SgY^08f:P02BU8X0UibC0:6YW`2W/jT0]L:i0;K0^@30al40_/Bo0;Bm^02ha<40]lC30;W3
`030alD0_<G40;c3a@2naLH0_lS70;_6a@2h`/40];no0:fj^P2W]KH0YKJb09RXY02CXil0RibH08>F
U01jSXT0MH^407>7P01_Pg/0JWeg06aoN@1[O7H0JGYc06IhM@1SMW00J7=Y07=ZG@1`Lg40NhZA08NG
X02HZkH0/<GA0;W?fP2gc=L0`=?M0;oBgP35d]`0S7En05/O902cQHP0N20V0:@?4`2/3@h0U0H807d2
0`1_0P40J@D206@H0`1_;`808=0100Wooooo00H00?l002S8?03@D7P0oh000>QX?03@D7P20?n00005
0>QX?02P8?00X23`0:0Pl03@D7P0203oP000103XJ3`0d51h0=1@N02h>;@c0:0Pl0030>QX?03@D7P0
oh0000P0oh0000<0D91hooooooooool01_oooolA003o001804mj7@0@9Td01dFT00PkS`0cBFH0GF=Q
07EhM@1/Lfl0H6AH06=RBP1bJ4/0KFA506mWC01]JE00JVI:06m[C@1_JDT0LVM707U[C01hJDH0MFM2
07EVA01aI400LfA507QZC`1eJe<0JfQD06=XEP1VK5h0GFaR03mCC`0K=c@0<4m806R3N`2Q]:h0a]7@
0<cBe02b]K80TI2907EgJ@1`L5`0KF]G06mXEP1[IU40K6]D06YZF`1SIUL0H6AC06EVDP1THe00HF9>
059IA@14Dd80=DPh051OC`1OJE`0G6ED05mTD01PHdh0G65A05AOD`1;GUL0D6AM05eaI`1TMF/0IgE]
06AdK01RLfT0H6eP069RA@0He0P00?l02?oooolA003o0280X23`0P2h>;@R0:0Pl003052@N000o`3o
oooo00[ooooo000:ooooo`800?l005H0C[<D04@B000h1@<0?P@304<3100g0@40>P8202X10@0S0@40
D0lC08LU:P211P/0S@P>0;0K702a:bX0XD5009=AC028HEL0P7=X07YoMP1hPgd0MhV107N>R@1kUI80
PYVG08nRX@2O[jh0[kjn0;G5a034dM80dMcP0=[RiP3Qin`0hn[b0=gSj`3Oh^/0fMcT0=CEh03>cMT0
c/oI0<k?f03;c=P0alOD0<W8e@3;bmH0b/_F0<oAe`3Gf=/0gMkO0=_Nh@3Hg^40dMWI0<WBdP2jb<H0
X;6_08jPWP20U940MH^506b2O@1UOGX0H7Ye061iLP1SNG00H7A`05icL01NLfh0GFm^069bN01cQXh0
Vjji0<3FhP2[`/l0Yko=09ZR[`0l3a`0Tf=b06X@6`2T5a`0[Q8C09`71`2;0`H0N`8206d80@1T8040
PD@4003o00Wooooo0P00o`000`2P8?00oh000?n000040?n000030=1@N02P8?00oh0000L0oh00>@2P
8?000`3@D7P0X23`0?n000080?n00003003o0?oooooooooo00Kooooo4@00o`00B00Bk0H0BCdd01Q1
OP0`A5`0EUU@069TEP1NH540HUi506]R?@1^ID<0LVM906YTAP1[JD/0KfY=06YUA`1`K4`0KfI406iR
>`1ZI480KVI706mU@`1aI440Kf<l079W@@1`ITH0K6E:06IWD`1LHeD0?4a501Tf<00nFeD0P9F?09BQ
WP2>U940S8V808n8Q02FRX00QGMV07maEP1lKe40Kf9206mR?P1jJ400PVTo08A/@P22KT`0Of]=07][
C01oKU00O71H079ZD@1bJTl0KFQ<06AVC`1GH500HVEE069VD@1PIe<0GfQM05a]J01NLVl0HWQa06in
N`1bPWl0KX1h0720N`1/NgH0J7A]06IXF01]JRh04^d6003o00Sooooo4@00o`000`0Xb3`0X23`0:0P
l0130:0Pl00302S8?000o`3ooooo00[ooooo000:ooooo`<00?l005D0EC<904@70P1N30P0H0T704/2
0P180P<0>0<403831P1F1``0QQ0C07HA4@1f92D0Ocdl07iKE@1gLV/0LGYb07>0N@1eQGl0MhV307N9
Q01fRXH0OHn<082BT@20U980QiRG08NCUP28TID0RI6C08N>S`1oQHH0Nh1n07j0P01dMgT0LWEf07Ac
L`1bLW<0LW9b07=aK@1fM6l0Mg9_07IdL@1bLVh0N7Md07elN@1mNWL0Ogij07]jM@1mO7L0OWml08R6
Q@2UY:@0_kc10<?4b02b]kX0X:6O09nNV@2QXI/0Uj2I09>NVP2<ViT0Q9RF07Z@S01/QH00Hgeg065k
M01MMW40GWIa05ieL01LLg40Igb308>GXP2CZ;L0HfIe03T=601L5B80O10I0:@M7`2V3`l0WP`;08/4
10231P@0MP/206d^0P0b_@<00?l000Wooooo0`00o`000`3@D7P0oh000?n000080?n00080d51h00<0
^3Rd0:0Pl02P8?00>@2P8?000`3@D7P0oh000?n000060?n000030>QX?02P8?000?l000Sooooo4P00
o`00A@0hYa<0@C`b055>>P1MG4D0G5m005UI>01NEc00IEP[06MN=01/HC/0KfI406eXC01/J4h0JF=2
06eWA@1`IT@0LfQ4079WA01eJDL0MFU:06eSA@1/I480KF@n06MP?@1_J4T0DUM204YGC01/OGP0C69H
06]dJ@1dLfD0MgAS07QdH01_LUh0TYN909RJS01lOFl0I6eT04QIE@0^ACd0;dHd05EK?`1hKD`0M6M6
07EaF01TJeP0F6AD05MTE`1JJ5/0EfAF05mRCP1fLU/0LVmJ06a^GP1UKE`0JgY_07>4O@1hRXP0N8b;
08>EU01oU940P96@07jAS@1hSXT0M8J506ejMP1TJ5T0Jf`c01[S2002003o00Sooooo4P00o`000`1h
F;@0X23`0:0Pl0110:0Pl00302S8?000o`000?l000_ooooo000:ooooo`<00?l005<0A5h604l<0`1`
4P`0LA4<068:1`1O2@P0B`P703@71`0j5140F3L`065LD`1QJf<0IWIa06n0O01dQh00N8Z707V9Q`1g
QX00Mh5j07=iL`1cMFh0LG5U06m_H@1`L600LW9Q07QdIP1kMfL0Og]W07agI01gMV80M7IQ07=fI01f
MfH0MgEQ07AbG`1dM6<0MGIU07IeH`1fN6D0NgYZ07akJP1hNfH0N7YY07IkK01gOFh0Oh5c08B6N025
RG`0T9>;09RKV02PY:L0ZZV`0:>TZP22QhH0Mga^07IgIP1jNFD0O7YW081hJ020N6X0OgU]08N2M@2@
Sh<0SY6508bCR@26U8h0NXj:06j6P@1RNgL0GgMf05ieM@1EJf/0DeeL04Tm>@1D8RH0Ma4F094D5P2]
>SX0WQHE08l91P2=30L0NA0305=A0P02003o00Wooooo0`00o`000`3@D7P0oh000?n000040?n000<0
d51h@02P8?000`3@D7P0oh000?n000050?n000030=1@N000o`000?l000Sooooo4P00o`00A00a[PD0
F48N06=G>@1RG3h0ADX^04]C=`1GE2h0IELV06UI:@1WF2L0K5``071S>`1aJTL0KFQ506iXB01`JT`0
L6U:06eR?`1]GSD0KV0e07EU?01dHST0LF8d079U=`1fJDD0FUTm07alJP1gMFP0JVeJ07=eH`1iMF80
IFaN04EGC`12ET`0@E5803M;A00eB4D0;49102Q3@00gDDL0F6UK071`F@1fKe@0N7e[07F3N@1TNW40
Fg1V05i/H`1GIEP0H6UH07EfH@1jO6X0PhUm08^GS`2HYZ80WZf]0:>`/@2KZJX0TJ2Q09:QX@2?X9l0
T:2Q08RHV01nSh`0M85k06e]G`1eL3@0<MD@0`00o`08oooooa800?l000<0D91h0:0Pl02P8?00@02P
8?00101@T7P00?l0003o0000o`0;ooooo`002_ooool3003o001C04J2201F4@<0KQ<;06/A2P1N30P0
B`d604PV7@15@3T0C5UA05AXG`1QLf`0J7Ye06^0N`1/P7/0J7I`06MbI`1YL5l0Kg1K07=`FP1iMF00
O7IP07efH@1lN640NgYQ07UgH@1kMV80NgEQ07YcG`1jMF40MgEP07IgH01fMUl0MgEN07IdG`1fLel0
N7ER07MfHP1hNF@0M7MV075gJ01`MfP0LWY[07YlK@20Ofl0QhId08J5L`1mOfh0O81_07UmL@1eNW00
Mg]a07amM@1oOG@0PX5]081kIP20O6H0NgUT07AbG@1`KEP0L6eF06eXD@1bKEL0OGIR07mgHP1nM5h0
PWIP08AlJ`29QWP0RHYn08:<QP1gRhL0IWil05]dL`1GJfT0E5iK05A2?01/9RH0TalU09dA3`2A2P@0
VAD:07<B1@0fL@000P00o`09ooooo`<00?l000<0Z8Pl0?n0003oP0000P3oP0000`3XJ3`0^3Rd0:0P
l0140:0Pl0030>QX?03oP000oh0000<0oh0000<0Z8Pl003o0000o`002?oooolB003o000g05Ii2@1X
EBT0JE/j03m3:`0S>BL0<4De051KA`1IFCP0HE/c06AN=P1YH3`0JV0k06]R?01^IT80LFa<07A^E01d
KU<0MW1C07M_D`1aJ4T0Lf]:079XA@1`Id00LF]607A^D01dJdX0L60k071P>01`KU<0OGaX07mlJ01=
FTd0>U5803UAB019Ge@0OHj70<S=c`2m_L<0QhZ307QgH@1aLEX0Ff9@06=`HP28Uhh0ZKBb08fLVP1_
OgP0LGYa0828M`2MXi40]Kfc0<K>bP36c/d0`L[:0<39c0020;_4aP0:0;K0`P2]^;/0[;Ni0:6_/02C
XJ80RYRI07YoNP1fK580Ji<]00_g10@00?l02?oooolB003o02@0X23`0P2h>;@L0:0Pl00302S8?000
o`000?l000800?l02oooool000[ooooo0`00o`00D`14Y`d0EQ@206dF2`1X4`X0Ea8:04D_7`1=Dd<0
DEaC051SF`1HKVH0IGUa06EfK`1NKF40Hf]K06mdG@1dN5l0MWQM07UdF`1jM5h0NGEM07egG`1jMEh0
NWIN07]fGP1lNF40N7IN07UdH@1kMF80NWAP07YhH01gME`0MWEK07MfGP1fM5h0NgIR07]hI@1dM640
K75O075hJP1^MfL0L7MV07MjJ`1hNf/0MWUV07UkJ@1fMfH0LWMS071dH@1cM6L0MGEW081oK@23OF/0
P7UT089iG@27Med0Q7AK08QkH@22N600LfaE07=ZDP1aJE80MVmH07A`G@1kNFD0MWAN07UdF`1lME/0
OGEN07acFP1mM5d0Pgi^08:6O@1jRXH0HgQh05E^KP1CJF<0F5MB06HV8P2?5Q80R`P309LI3P1P40@0
9hX100800?l02Oooool3003o00030830003oP000oh000080oh00B02P8?000`3@D7P0oh000?n00002
0?n0000308300000o`000?l000Sooooo4P00o`00@@1LP0`0LEl^05=C=@0jCC/0<DPg0317=`0dB3T0
BUQ405aRC01RIDh0I6E>06QYC`1/JDh0KVU?071[DP1dKUP0LfmD071ZBP1dJT`0MF]=07=^D01eLU@0
MgIG07UfF@1hM5/0NW5G07i`DP1mKTP0MV]707Q`DP1oMU`0PWUK0921G@2?OEX0TWmM08miF029LeT0
QWYS089iG@1jK4P0MW5D06E[E@1kNV<0Vi:00:jWX@2f/jl0c<[30>KWh@3en?40l_Gc0>S[k@3Pi>P0
f=kQ0=WOh@3NhnD0f=oQ0=;JgP32bm00/[c00:Rc]P2NZj`0RYBB07]hI`1fPC/0<mHD00H00?l02?oo
oolB003o02h0X23`0P3@D7P00`3XJ3`0oh000;Ph]00=0:0Pl003052@N000o`000?l000@00?l02ooo
ool000[ooooo0`00o`005P0Cj`@0I24406`I3P1N6a00Dc4S04Y@>`1<FdX0E69F05e]HP1OKf80HfeJ
06U^F@1aLe`0NWIL07UfFP1iMed0NWUP07eiHP1mNF40NgMO081fG`20N60207YfG00E07IcF`1hMUd0
OGQS07ehH`1iMed0OGUQ07agH01hM5h0MgEO07IdH01cMF40KgES06]bH@1YLF40L7EW06edHP1bMfH0
MgUY07EgI`1eMVH0LWIT0080KWAR02@0LGAS07AdI01iMF40NG=M07E[DP1eK500MFmA07YaE`1jLUX0
N6mD07I[C01jL5D0LFU?079[D01cKED0N7EP07YgH@1fLe/0N7AN07YcG01kM5h0LW1D07IcEP1kL5D0
OG1I07adH@1kOG80Kh1k061gM01HKVT0FUaF06DX8P256Q@0Qa`@04d<0@0UR`42003o00Wooooo0`00
o`001@0Xb3`0oh000?n0003oP000^3Rd04T0X23`00D0j6Pl0?n0003oP000oh0008300002003o00So
oooo4P00o`005@1YRQ@0JE`]04eG@`0mETH0@UY<049HB`0nED80@eE104]FA01GG4X0F5m=05eSD@1W
JeL0Kg9M06ebG@1aLUh0M7AO07=cG@1cLeh0NGQS07QiHP0207MgH@0X07UjJ01nPFd0N7UT07akI@21
PFX0S8ad08Z;M02:RW00Si5d09BEN@2IVh00WY^20::OQP2VYXh0[:nL0:ncW`2e]j80_/2]0<_=_03Q
gm40n?G[0?knn@3oo_`0o_on0?knoP3mo_d0moSk0>[/l@3KhNT0d]_R0<kIh@3>eml0am7E0<3;c`2g
`/H0ZkNh09bTX@2:PW00II@h03_=60P00?l02?oooolB003o02T0X23`0P3@D7P00`3XJ3`0oh000?n0
00040?n000030=1@N02P8?00X23`00T0X23`00<0D91h003o0000o`001P00o`0;ooooo`002_ooool4
003o000=04b31P1V<aT0FTH`04e<=@1AG4D0FFMD05aVEP1PIU@0KVmH07AaEP1eLeX0N7IN07EbFP02
07ihGP03081kH@1nNE`0OWQM0080NgIM03h0P7MP07egGP1nN5d0O7MM07aeG@1kMEd0NgEN07UgGP1n
NVP0NgES07ahI@1hMfD0MGUY06efJ@1XM6D0JGIV075kK@1fPW@0O8Uj082;OP1mR7`0NhQj07J2L`1/
MVP0IW9S06YfI`1YLfD0KG=T07AcG`1bK580MFe?079ZB`1eK500MG1G079aF`1bKeH0L6Y807YcE`1g
LEH0M6mD07eiHP1oOFL0M75H07MeGP1lMeh0NW9H07UbF01hME/0M75H07A_D`1`Jdl0K6E806AN@P1_
JE@0M7ET06]fJP1KK6T0F5aI04l/8@1B5`T0?Ph1017400800?l02Oooool4003o00030:R8?03@D7P0
X23`04/0X23`00@0d51h0>QX?03oP000D91h0P00o`08oooooa800?l002X0?k`<06]J:`19ET80B65C
04ENDP1>IE/0EVeN05U[G01LIeT0GfMC05YSCP1CGTd0EF9D05]WFP1QKf@0IW5U06]cI`1/N6T0L7a/
07EnL@1gP700NX9`07j6M`21Rgh0PXem08>>O@25TH00RIF3092IRP2CVhd0VJ:A0::^W@2_^j/0_lNk
0=7Ec@3Uin40l?;]0?Ggm03jnoT0o_kl0?gno@3nooh20?knoP0A0?cmoP3hnO/0k?3c0>?ZkP3KhnH0
e]gS0=?Kh@3Bfn40cMSM0<OBf036d=@0_/W;0;Fo_`2TZ:<0THI^06^I>00Yga402P00o`08oooooa80
0?l000<0D91h0:0Pl02P8?007`2P8?040=1@N0L0oh0000<0j6Pl0=1@N02h>;@0302P8?000`1@T7P0
0?l0003o0008003o00_ooooo000:ooooo`@00?l001T09m/;05m<8`1?Bbh0FUi206=UCP1JGTP0E5U6
065TDP1aKeL0N7EK07]iHP1mNEl0O7QL07eeFP1jM5X0NgMM07]fF`1lMUd0OGQN089jH@1mMU`0O7IJ
07]fF@1lMU/0O7IL0080NWIL02X0NWMO07YjJ01jO6/0NGa[07EiJ`1]MV`0JWYa06=fK@1GKVH0DfYS
04mYI01:IV40BV9Q04QRG`1:I5l0CfMS059YI@1PMFl0Jgaf06MgLP1WMVd0Jg=T06maG01cLEP0M75F
079`E`1^KeP0KVaD07E]D@1iLeD0NgIM07YiH`1mO6L0OgaY07EdG`1hMf40NGIM07YeFP1kMUX0N7=L
07McG01eL5H207EaF00:07=^E@1QGdH0EEQ304M=>@1GFDD0KfeL05YUF@1EGE00>RHE03XQ0@<00?l0
2Oooool4003o0003052@N02P8?00X23`04d0X23`00@0^3Rd003o0000o`000?l02?oooolB003o000T
00_g0`1jK200DE@e04YOD01BJE`0EV]R05U_IP1SMfd0Jg]`075mK`1/NFT0IgIU06MeIP1ULVD0IGAZ
06MgKP1[Ng<0JWad07>7P@1hRXL0Ni2:08>ITP2;WYT0U:JT09NZYP2W^k@0/lJm0<7AaP3EhML0k?7[
0?Sjm`3looX0o_om0?kooP3no_h0o_km0`3no_h0503mo_h0mo[l0?;fm`3/ko80i>W]0=cQiP3Lh^P0
e=cP0=;Mh@3Bg=l0cmSM0<WEf@37d]@0aM3B0<38b@2[Yj40XHig076MA@1?_bP05_093000o`08oooo
oa800?l000<0:<Pl0:0Pl02P8?006@2P8?000`2h>;@0d51h0?n0000:0?n00080d51h00<0^3Rd0:0P
l02P8?002`2P8?000`1hF;@0:<Pl003o000;003o00_ooooo000:ooooo`@00?l00100=<D=05I:7@1V
HSd0IfM7055A>01MGdH0Eee805eVE01_L5T0LW5D07MfFP1lN5h0OGUL07]dF@1kMU`0NgIN0P1nN5h0
?`1oN5h0OWIJ07aeF@1kM5L0NgEJ07]fG@1jME`0MgIO07IhH@1hNVL0LWQU06U`H@1TKV40DF9I05]c
K@0lF5@0940m02M4@016HU/0HWmd06f7O01lTHL0KXIk05MbI`0_CD807S`d01D_;00I<340;TM704eT
H01PK6<0JVeN071`GP1UIE00K6mH07QdFP1mM5L0Ng=E07aeE`1jM5`0PX1[07emJ@1cLeh0MgIN07Yd
G01jLeT0N79H07]dG@1mMf80N79K079/C`1fL5D0MW1H079]E`1NHD`0B5E302U0<P0V>Rh0EELo06Y[
DP1HI540@chY02i?0@03003o00Wooooo1000o`000`1@T7P0X23`0:0Pl01>0:0Pl0<00?l02?oooolC
003o000M01cS1P1[IR80CeQ104mUE`1MLFL0HGE/06EgK`1ZO780KGie07:1M`1dPWP0MHEk07N7O`1j
S8D0OY:<08JGT`2>XIh0U:JV09^^[@2S][D0[Kk00;O7b02ibld0a=KG0<oNgP3JinL0iNk_0?Chn03o
ool00P3nooh0603no_l0oOgn0?_lo@3gnOX0mOKh0?7dm@3/lO40i>_/0>3Wj@3Qj^X0gNOX0=kUj@3L
i>P0fmoU0<gFfP3=e]T0b]?F0<[Ae032a/D0/ZbP09jKM01R/Cd0@=0O00ch1@l00?l02?oooolC003o
000302S8?02P8?00X23`01P0X23`00<0j6Pl0?n0003oP0001@3oP0030=1@N0h0X23`00<0N5Rd052@
N00Xb3`03`00o`0;ooooo`002_ooool4003o001A042M201YG2l0JVLo05MJ>`13BS80CeDm05YRC@1I
IE@0JG1I079bEP1gMU/0N7EK07ajG@1mN5`0O7MJ07afF`1lMEP0NWEF07egF01nMUT0OWEI07agF@1k
N5/0NGUQ075dH@1_M6<0J7=P06A_G`1AHE<0?59702m7@00[ASd0<Tm5059XGP1QLVH0MX=i086>QP2D
XIh0[KFe0;k2a@33a/X0a<W;0;:l/P2GX9@0SIJ;065cJP0dCd/0Fg=b02`o>01EGDd0Lg1M07YcF`1m
N5X0OGII07eeF@1jME/0NgUQ07elI@1dMEl0LgEM07IeG`1lMeh0OWEJ07idF@1jM5X0OGAM07mfH01l
ME`0NG=I07IbE`1aL5L0KG1M05AOC`0cBS/08T0b02E0<00gB3@0IVI906eVC01FB38088d100<00?l0
2Oooool4003o000307QH]02P8?00X23`02D0X23`00<0^3Rd0:0Pl02P8?009@2P8?00101@T7P00?l0
003o0000o`08oooooa@00?l003804nd505j;8`1RGch0GV]K06QhKP1XNW40KX5f0763O01jQh40NXZ5
07nBS026Ui@0S:2L096TX`2GZZX0X[Bb0:Vk_02hb<T0^l[;0<OEe`3Dh^@0hnk]0?;hm`3enOT0loSg
0?Sjn`3en?T0l_Og0?7dmP3_l_<0koCe0>[`l03]m?@0jO7a0>_bl`3/l_@0i^k`0>;/k03NinL0f>7S
0=GOh03Bfmd0dm[K0=GHg038b<T0^kB/0:nORP26X5P0D/4_02gR5A<00?l02?oooolD003o000302S8
?02P8?00X23`0180X23`0P3@D7P40?n000@0j6Pl00<0X23`0>QX?02h>;@00P3@D7P<0:0Pl080D91h
4`00o`0;ooooo`002_ooool4003o001A05j54P1dIc/0Kg1A05MSC017Ed<0AUE304YIB01@GTl0HVaK
06Y^E`1bM5/0N7IN07ijH@1jLeL0OGQI081jG01oN5X0NgED07YbDP1kLeL0O7UP07AiH`1ZM640FfYI
04eOE@13ETh0<Ta202=0=P0]BCh0?5=4059RC`1OJ5<0JfY@079XC01dIdP0MfY607Y[AP1eK4l0OWY[
09ZISP2NWi<0Q7i`08EgG@2=N5H0TWaN09J>N01`LV<0Qhb106E/F@1DEch0MVa>085eEP1oN5X0O7QP
07ekI@1jNfD0MgIR07EdGP1fME`0OGQM07efG`1lM5X0OG9I07idG01jLe/0OgUS07YeH@1iM5h0LW1J
06]_F@1TK5X0EfAG03=;@00/Acd0<T`n03M??`0oF4T0GfYE071UA01aFc<08;4100<00?l02Oooool4
003o0500X23`00@0D91h003o0000o`000?l02?oooolF003o000/02CK2`1FV2L0LfU606]`F`1aO6h0
MHEk07^8P@1lRXD0PY>@08FHU02;Wih0TJBU09VZ[02Z^k/0]/G50<7?d038emT0dn;T0=k[k03ZlO80
kOGe0>kem@3`m_H0lOCf0?7em`3]lo<0k_Cd0>gbm03/lo<0io3_0>K_kP3Uk^d0i>c/0=oVj03Ji>@0
h>GV0=cRg`3@d/d0a/:h0;f`X02Q/7X0PZ]D05C2<00^haHG003o00Sooooo5P00o`000`1@T7P0X23`
0:0Pl00@0:0Pl080d51h00@0j6Pl0?n0003XJ3`0j6Pl0P3@D7P00`2h>;@0d51h0:0Pl00<0:0Pl080
D91h5`00o`0;ooooo`002_ooool4003o001A06:96@1aJD40MWiW061aG@1CIE<0CV1>04mOD01DHUH0
Gf]P06I_GP1WL5X0KW9L07QfG`1mN5/0NWEF07ehF@1nMeT0OWUM07mjGP28Q6T0O7iW06QcH@1<HE@0
=4m702=1>@0K=b`09Chc045GB@1KJ5D0JfeA075/B@1gIcl0QFdn089^@01hJ480MVI208UhD020MUD0
PX5]0:JSU`2g]jd0Ti5n089gF02AOEP0U7eG099kF02@OEX0OVe;07EV?`1iKdh0OgAL08Z4K@26Pf/0
OGaW07UjH`1eMUh0NgMM07ihG01mN5/0OWUM07mhG`1nMed0O7EM07efG`1lMf80NgMT07McH01eLEd0
JViK06E`H01BGe80@553039>?`0gDd@0?5I7049MC@1=IET0HW1P06EQ@01hIBl07mH400<00?l02Ooo
ool4003o0500X23`00@0D91h003o0000o`000?l02?oooolH003o000F00[g100fbA<0DZDX06J=?P20
N5T0OgYW0864M`22SHH0Q9B@08fLV`2DYJ@0Wk:b0:Zl^`2faLH0_lo@0<SHf@3@hN40fnKU0>3[j`3R
k>/0ino_0>O]kP80j?3_00h0ing^0>[/l03Yk>`0inOU0>7Nf`3Id/`0d/Nn0<ZlZ`2/^XT0S[QX0672
@@1:c2/0;N<H00ch1Q/00?l02?oooolH003o000302S8?01@T7P0N5Rd01H0X23`00<0^3Rd0:0Pl02P
8?000P2P8?001@2h>;@0X23`0:0Pl02P8?00N5Rd0080D91h00<0:<Pl003o0000o`006@00o`0;oooo
o`002_ooool4003o001A06B<6`1bK4P0MWm^06ejKP1RLfH0GVmQ05m^HP1RKVH0L7ad07f8O@1fPg80
I6mJ06IYC`1]JT`0L6]707A]B01iL500OGMM07ikHP1oNf80NGYP06E`F@0iCcd08C/^03Q??@1BGdL0
HFQ<06e/C01lL4X0RgQ908]e?P2=LCL0SWI105mF<P1EDS@0HE/n06IRA@1^KeL0NGYW08:0K`1lO6d0
KW9P06U[F01FFTP0AThj075YC024Ldh0RWI>08Ua@024K3h0PW5C085lI@1kO6@0NgUP07ikG`20O5d0
Og]M07ijG01oNE`0OgYM07iiG020NV00OWQO07YdFP1dL5T0KF]E06MTD01RIDl0FFEE04aOCP15EdH0
B5Y:04AMC019I5D0D6MM04eVF`1DK6<0HFiR06=R@`1oJBd07^D700<00?l02Oooool4003o0500X23`
00@0D91h003o0000o`000?l02?oooolM003o000J02cQ4P0Ug180B[XT04Bi:01^W480JJ1906ZTDP1k
YF<0WiEj0:NMQ`2_Y9<0/jRE0;f`V`2o/Ih0`k:N0<BcWP31[iP0Z;V708g1L`2=_6d0S;MS06C5AP1I
bCP0Cll_02kT700Tja<R003o00Sooooo7@00o`04052@N140X23`00<0N5Rd052@N01@T7P00P1@T7PR
003o00_ooooo000:ooooo`@00?l00500F:8H06mV@01hOV/0N8=g07R7O@1cQ7/0LX9i07J6N`1iRGd0
P92707b=PP1iRWd0JgMT06Q`E`1[Ke40KVa<07=_D`1hN5l0NWeV07j0J`21Q6d0K6]>06MT?`1_JD@0
NVi:07]aC020ME40RG]F08YhC02?NDT0TWU708md?P2?MdH0OG5=07E`DP1eLUP0KWEM05i_H@1dP7X0
OXV4055QG00X@3D0:T0b039;>`14FdL0JF]>08akD`2@N4X0RgA5091nD`26NUX0PWaR089lH@26P640
Q7mP08EnH023OV80PGaP07ehF01mMUP0MfiA07=ZC@1aId`0JVE9065SA`1JH4/0DV5<04UNC@1;HE@0
E6MH05]/F`1KJel0FFiT05M_I@1IKfT0GW9[05a_J01UKUh0Kf@m06:K80@00?l02Oooool4003o0003
07QH]02P8?00X23`04d0X23`1000o`3=ooooo`002_ooool4003o001@01kU201nIc40Q85V08B=OP23
T8T0Oi6;08:ET028ViD0QIJ?07nAR`1oTXT0Nhj607J5O01gPWP0N8Ak07N3N01eOfh0LgiY07AjI`1f
NFP0NG]X07a^A@2<L3L0Tg@m07m[@`1^KUD0LGQW07IlK@1hOVX0MG]U07YnIP24PfH0SHIU08f0G`2>
P5d0UX5R0::?M@2XWXh0ZZFL0:NSX02@SH40QGYP08QfDP21M4h0P7=908UhB`2AOU<0TH1H08n5HP2<
QFX0S8E/08R2J022O680OWUL07afEP1jLU@0Mg5D07=^D01aK4d0K6]=06]XCP1WJ580H6AB05YUDP1B
IE@0DVUL05=ZG`1GKf<0GgI[06MjK`1XNG40IWQc065fLP1ON7<0GgM_06EkL01UMFX0JfI707Ej:00D
kPH4003o00Wooooo1000o`000`0Xb3`0X23`0:0Pl01<0:0Pl00302S8?000o`000?l000800?l0cOoo
ool000[ooooo1@00o`00CP1EXAP0OFe608bAP02:VI80PIJA08JKV029WI/0Q9RE08>FU02<WIP0QIRD
086CSP25TXd0PY6<07^<P`1iRgh0OH]l07n<O@1kPgD0NWi]07mfE@25KSd0TG@k08idA01/Hd<0Hf9;
06YYF01kO6/0PHUj08>@P02;V8P0Tin?09NPS`2LWh/0XZ2809:5I`2DOeD0VX=F09b4GP2KP5X0VGm@
09Ag@@2ENdD0XI1Q09nFL02ITg<0U95e09:>M@2@S7D0SHI`08AlI01nN640N7=H07EaD@1fLU40M75D
07AdE`1bLeT0LWER06icIP1PK640EfQQ05e_J01HKV@0HGI/06MlLP1[P7L0J7id06UoM`1ZP7T0Igeg
06InM`1QO7@0IGac06aoM01[L5h0PFXd02cP3`D00?l02Oooool5003o04h0X23`1@00o`3=ooooo`00
2_ooool5003o001=01C^1P1YSb@0Q7IG08nGSP27ViH0QI^G08^QW`2;X9h0PYRE08NKUP2;WY`0R9fJ
08^NW@2;Wih0Q9VB08>FSP26UX`0Pi>:08NBS029ThL0R8mn08R:K`2<QEl0SgiC08QdB`27LDX0Qg1;
08]fD`1mMEd0OH1^08nGQ`2_^;80Z;>a07V;Q@1HJEh0FUm:08AdB02CNT@0UWa90:F?H@2gYGX0`k>:
0<2bS@2ZXX80UiEg08nBM02ATgX0U9F2096EQ028RWL0PhA`07n2KP1nQ6l0OhI_0864K`2:RGD0Vi>0
08^7M`22PWP0Mgad071kL`1[NWD0JG]d06QnM@1eRGl0LhIo07N:Q@1aQX40KXIn06j8P01_Qh00K8El
06YoMP1^Nfh0KW9O07YY?`0jcAD01P00o`09ooooo`D00?l000<0:<Pl0:0Pl02P8?00702P8?000`2h
>;@0X23`0:0Pl00Z0:0Pl00307QH]000o`000?l000@00?l0cOooool000[ooooo1`00o`002P0hbAD0
OWY80861M@2>ViD0T:>P08nSX@2>XZ00T:BR096UY02@Y:82092TY00n092TXP2=X9l0UZBQ09>SWP2?
X9/0S9bF09NUWP2AX9`0V:FO09fVW02IWXh0WI^809jHO`2OTW<0WHe[09R9I`2AR6`0S8Mn0861N@1a
MV<0NGaQ09:>K02`Z880c<>R0>WSbP3lnN/0mO?X0>cZg`3Qh=D0e=C60<S;^`2naK@0]Kn_0;:l/02/
^k40Y;B[0:>aZ`2M[:L0UJNQ09>SW@2HX9L0Y9nC0;BSU@2WV8P0V9>308j@QP23SHL0OXf507j?Q`1h
SXL0OIF?07RAS01hT8d0MH^807J<QP1`QGh0Kh1h06mmL`1ZLE`0KfQ606b9;P0MiPX7003o00Wooooo
1`00o`000`1hF;@0X23`0:0Pl00P0:0Pl080d51h00@0oh000>QX?03@D7P0^3Rd802P8?000`0Xb3`0
0?l0003o0005003o0<gooooo000:ooooo`P00?l002<05Nl805VV:028MDh0QX9^09FPV`2KZjT0W:j/
09Z^[@2K[jh0VJf[09nb/@2L[Zl0Vjf]09f^[P2IZjX0UjVV0:6c/02Q/[00W[6^09R[Z@2J[:`0VZf]
09Z/Z`2U][D0[K^h0;c4`P31bL@0`lo70=;NeP3Jhm/0gnOO0>W_i`3gnO<0oook0?kno0030?knoP0Q
0?gmo@3no_h0o_kn0?kno@3fn?L0inc[0=KRh@38eMD0_/_<0;O4a@2[^KT0X[Bb0:Fg/@2V/J/0YZ^U
0:j]Y02][J00Z:RM0:2VX@2BXYh0RIfI08RMV024ViL0Q9^H07nGT`1oUI80MXZ606j0MP1/N6`0K7=P
07A/BP1AY2D0:=l@00T00?l02Oooool8003o000302S8?01hF;@0X23`01d0X23`2`3oP0000`2h>;@0
X23`0:0Pl00G0:0Pl00307QH]01@T7P00?l000P00?l0cOooool000[ooooo2`00o`007`1fW2l0QWQH
09FHS@2PZjT0XK6`0:6c/@2R]K@0X[Bd0:6c/`2N/[80XKJf0:2c]02Q/k80Z[Zi0:Be/`2b`l80Z;^i
0:6d]02P];<0YKRg0::d]02Y^k/0^/K80<SFe`33dm<0bmcK0<oLg@3MinT0i^k`0??gm`3moOd00`3n
o_h40?gmo@0L0?kmo@3no_h0nOWj0>7Xj@3Fh^40c][J0<KDe02jblT0^<W60;k<b@32c/X0]<:n0;K2
^P2g`KX0/kZc0:Vd/@2JZZT0TJBQ08^PW@2;Wi/0R9^H08:HU01gS8P0IWE^06Q`G01/I4L0QFdl02WO
4@/00?l02Oooool;003o01`0X23`0P3@D7P;0?n001P0X23`00<0D91h003o0000o`002@00o`3=oooo
o`002_ooool<003o000R02SO4P1M[3<0PY5E09N?N@2TYid0Z;>a0:Fd]02/_Kd0ZK^l0:Rm_02X^kd0
[;jo0:fo_`2U]kL0ZK^j0:^m_P2^_/00[l;00;?3``2ca/D0^lg;0;o=c@34d]80bm[G0<gLfP3HiND0
fN?T0=[TiP3Tj^`0kO3a0?;em03mo_d0o_kn0?gno@<0oOgm0P3noOd06@3no_l0n?Wi0>kem03LinL0
fNKV0=OUi@3@gMd0e=kN0<cGf032d<l0_<W70;O3`02d_kd0ZKBc09n^[02IZJH0TJBP08VLU`1lR8@0
L7Y`06Y^FP1aMd@0DJDX03[>6@0Gl@X03000o`09ooooo``00?l000<0D91h07QH]02P8?006P2P8?02
0=1@N0T0oh0000<0j6Pl0=1@N02P8?004P2P8?000`1hF;@0D91h02S8?00<003o0<gooooo000:oooo
o`l00?l001805_4:04C78@1ZZdD0Xhib0:FKR`2/[JL0/kjk0;2n_P2``L80/lK70;73``2Z_[d0Zkno
0;31`@2hc<X0^lg<0;g?cP38e]H20<kJfP0;0=?Og`3Dh>00fnKW0=_Ri03Li^L0hng]0>W_kP3cn?P0
n__k0?[ln`3moOd00P3no_h00`3mo_d0o_kn0?kmo@020?knoP0C0?_mo@3_m_H0jO;c0=[Wj03Gh^@0
c]WL0<cGfP34cm@0^<C70;>m_`2^];L0XJNW08jBS01oPGD0MGMQ07ElCP1IW380AKTQ03?H5`0@003o
00Wooooo3`00o`000`0Xb3`0D91h0:0Pl00H0:0Pl0d0oh0000<0^3Rd0:0Pl02P8?00302P8?02052@
N1000?l0cOooool000[ooooo4`00o`006`0HlP`0<mPL07>^A@1kZe80Sj9Y0:fRS@2/ZY`0[k6Z0;Vl
^030b<D0b=?@0<[Fe037eMD0amKF0<cJf`3Dh>40fNCU0=oYj@3Mj>L0hng[0>?Zj03UkN`0kOGd0??g
m`3fnOX0n?[i0?cmo@030?knoP0C0?koo`3nooh0oOgn0?OhnP3[l?@0hNW^0=[Pi@38e=D0_LS90:ff
]@2VZjT0VIR@0929M`2?PfX0NXYB05bN=P17^2808m/@027Z400D003o00Wooooo4`00o`000`0Xb3`0
D91h0:0Pl00C0:0Pl080d51h2P3oP0000`3@D7P0X23`0:0Pl0090:0Pl0<0D91h5000o`3=ooooo`00
2_oooolH003o000F03GX6P1Obbl0Dl8/07^SA@2RR6D0YI9k0;2RT`2j]ZX0b<S20=GJeP3Hgm`0g^CS
0>GWj@3Vk>d0kO7c0>c^l@3/l?<0ko?f0?Kio03ko?d0n_cm0?cno`80o_ko00h0o?go0?Gen03]kNl0
hN7S0=;@dP2j^KT0Z:RT09VDS02<PW80S7UO09=kEP2MP5<0D;lY04SH8QX00?l02OoooolH003o0003
052@N02P8?00X23`00/0X23`00<0oh000=1@N02P8?002@3oP00<0:0Pl1X00?l0cOooool000[ooooo
7000o`007P0=nPL0<^LK02kS6P0ffal0E/Db07ZeB`27/EH0R;=N08^gI@2H]W<0aZV=0;V`RP35[YD0
aK2F0<JaUP33/9L0`ZnG0<2/T`2nZ8h0/jj608FhJ`20/El0P:iH07j/D`1b[TL0Cl8`0572;@0ndB40
;><H01Wc3Ah00?l02OoooolL003o000302S8?01@T7P0D91h0080D91h502P8?04052@N00302S8?000
o`000?l001`00?l0cOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {180.75, 0}} -> {-0.106847, -0.0454574, \
0.0105606, 0.0105606}, {{10.0625, 98.1875}, {176.438, 4.25}} -> {-17.4879, \
-6.49014, 1.7365, 1.7365}, {{107, 195.062}, {176.438, 4.25}} -> {-185.905, \
-6.57348, 1.73742, 1.73742}, {{203.875, 291.938}, {176.438, 4.25}} -> \
{-402.835, -31.6328, 1.97589, 1.97589}, {{300.75, 388.875}, {176.438, 4.25}} -> \
{-593.828, -31.5061, 1.97449, 1.97449}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1T, pdf1, 
          pdf2, {Red, Green}];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2T, pdf1, 
          pdf2, {Red, Green}];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1T, class1, obj2T, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44639 
%%ImageSize: 400 178.555 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0106283 0.238095 [
[ 0 0 0 0 ]
[ 1 .44639 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .44639 L
0 .44639 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0106283 0.245293 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0063C92C62C62962C62893AA3CC38F53
C39053C59055C48E55C58F57C48E55C58E56C18C53C28E5591AB3F61C52861C62961C72A
60C72961C82A60C62960C7295EC62800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC223
5AC1215BC1225AC12158BF20B58345B88146B7834AB47E46B58044B67F41B88141B68041
B27F40B47E43B37E43B57D42B67F42B47E42B17D42AF7C41B17E40B47E41B58043B38042
B38042B58243B68346B68346B68547B9894D5BC1245BC2245DC4265EC4265DC42700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDF1159C02356BD20829D31AD7E41AC7D40AC7D41AC7C43
AF7D42B37F46B38144B28146B28147B28048B5814DB3804DB17E48B68049B77F45B88148
B6824BB6814DB37E4AB6804AB7824BB8844EB37F4AB5834DB38048B58148B68248B38045
AF7C40B27F44B28045AF7D44AE7C43AF7D44AD7B41A9763AAA793AB07E40AE7C3EB07E40
B18143B28344B0834683A23658C0242CE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002EE11300FF0000FF0000FF0058BE2256BE22
54BC2156BD23829C32AF7C45AF7E43AD7D43AE8046AE8048AE8149B1824DB0834DB38251
B88452BE8757BE8958BE8A58BC8654C1885AC1855AC4885DC6865CCD885ECE875BCF875D
CE885ECA835BC88259C98259CA845BC8845CC8845DC9875FC7875DC5875BC08558BD8355
B98352B48353AF8051AD8052AE8252AD824FA97D48A67941A67940AC7D44AE7C44AA7840
A37338A37436A57538AA783DA9783CAD7B3F819C2F56BD2056BF2054BD1E809C2D56BD1D
2BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0058BF22AD7A3FAC7A40AB7941AA7941AB7D47
AA7E49AB7D4BAE7E4CB38050B4814FB98454BE8659C2875FC68761CB8861CF8960D58663
DD8965E08767E08566DF8363E17F5DE47B5CE5785BE4755BE57158E36A53E0654DE2644E
DD6149DF614ADF624AE1644DE36651E26651E26854E16B57E06C58E2725CDF755CDA775C
D47B60C27A5EBE8266BE896BBB8969BB8C67B78962B3865DAE8359AF8357AE8154AC8052
A77D4DA57C47A57942A4743CA27135A47335A16F33A27033A47335A87838A87738A97839
A978367F9A282BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0054BB1F7D9A2EA9773DAB7940AB7943AB7B48AF7E4FB48255B98458
BD835AC5855ECD8660D78766DB8665DD7D60E0765FE0705CD9624DD75741D44C38D44232
D53E2FD43829D23224CF2B1DD32B1AD42716D42716D52419D52117D71F17D51E14D72018
D82017DA2117D92014D81E14D81E14D92116D61F16D41E15D11E16CF1E17CC2015C52015
B420158D130A8118137C1D167F251A85302290402F974D3B9B5744A66651AF735BB37E61
B58464AE825EAD815BAC8055AB8051A57C49A27944A1753FA27239A27235A07130A37230
A57434A77736A8783654BC1929DD0B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DD107B9831A77743A87643A57443AC7747B27A4DBB7D53C17D58C87B5BD1795BD97459
D5664ED0543FCE4634CB392BCB3123CE281ED0241BD11E16D61F15D71B12DA1C13E01C15
E31C15E61B14EB1F15EB1E14EC2015ED2014E81C0FEB1C11EC1C12ED1B14EC1C13EE1C17
ED1D16ED1B13EE1C12EB190FEA180EF22015ED1B12EA1910E8180FE91A12E71A11E21912
CB120EA3030395040895080C950A0C8E07088B0A0A8409097C07087B0D0B77100C771912
78241A83382B924E3FA0634FAB725CB27F63AE8160AA7D59AA7F54A77D4CA27941A07339
9E6C30A16F30A16E2F9E6E2C9F712BA0712900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0029DD0F53BB1F52BB21799932A17544
A57647AD794DB1774FBB7653C47758C97052CB664BCC5943C44332C23427C6291DC92116
CE1E14D21911D71913DA1712E01914E11611E61911E6170EE91A12E91913E81810EC1B14
EB1A10EF1C11F22012F22014EC1B0FF42116F11F12F42015F31F13F41F14F62116F51F16
F21E14F21D12F62115F41F13F42013F41F13F41F13F11D12F21D12F11C11EF1C10E91C12
CC0E09AD0204A40205A30105A60408A001069D04089B03089703079002068F040A8C050A
8304087B060876070A710A0B6D0F0E721A167C2D258743369B604BA77357AA7C59A87A53
A7774CA675449F6F379A6A2F9A682C9665249E6D274FB61100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0028DC0E7B9930A97A47AA7B4DAE7B50B87955
C17656C56C51C65D48C14737BE3526BE2518C21D13C7150FCD1511D2130FDA140FDF130E
E2140FE41610E4130FE4140FE51610E71610EA1A10E9160EEA1A11EF1C15EE1C13EE1A11
F01C11F11D12F32113F42114F01E11F42116F52215F72317F72116F92217FB2419F62016
F62114F92317F72314F31D11F52111F82313F62114F62215F41F12F11C0FF11D11EB1D13
C90907B20203AE0306B00507AE0408A70105A60207A40207A002079E02079D0209990107
9601079302088F040B88030B81020A7B03097A070B71070A6A090869110D6F1F1880382A
914F3B9E634BA77451A374499E6E3F9A6A3597662A97662296661C4CB30B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DD117B9A34A87948AF7D52B67C5ABE775DBF634EBC4A38
B73024B61E15BB150FC4120FCD110FD3110DD7100DDA0F0DDC0F0EDE110DE1110DE2110E
E41410E61611E61611E51311E41511E5140FE91912EB1811EE1A12F11C14F42016F41F15
F41F14F31F14F62216F72317F42115F42116F22013F92519FB261BFD281BFE2A1CFC271B
FD291AFE2919FE2A18FB2616F92312FC2514F72012F62112F62012F62113F41F13EC1D14
C90806BD0809BB090ABC090BB8070AB00106AF0309AF050CA70106A70208A70108A20105
9F01059F04089701069101088A01088601078403088001067E01077D030C76030A730609
6C0707630A0764170E712D1D884B369C6448A06B44A16E3C9A69309565229260146B8307
47AB0300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029DC0D
50B81B53BA1F7F9931A97747B07B4FB97854BD6F50B459419C34249A1B15AF1B15BE1511
C7110DCE0E0DD30E0FD60E0FD90D0EDA0D0CDD0E0EDF100FDF100DE2120EE1120FDE0F0E
DC0D0DDD0E0DD90A09D9090BD70A0BD90A09DE0E0BE71610F01C13F41E14F72116F82117
F92217FB2519F92317F72117F92519FC281BFC2A1AFC281BFE2A1DFE2B1DFE2B19FE2D1B
FF2D1CFB2716FA2514FB2314FB2313FA2212F92214F92312F82211F82114F41E13EB1D14
C40502BE0908BF0908C30B0BBE070AB80509B40409B00308AE0308AD0309AA0206A70206
A60106A301059D02049500059001088B0008890107870105870006870109840107820207
7E01077901077604086E0506690808660F0A70221586422B9F6645A07245996B34936222
824E0E7B470542A90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DC0A7594219F7337
A67944AB7749B6784FBF7250BD5C42B43B2AB12518B0140EB3100CB90A0BC80F0FCD0D0B
D20C09D50B0BD70C0EDB0E10DD0D10DF0E0DDF0E0CE4110EE61410E3130FDA0D0CD30608
D20608D30609D30709D6080AD40708D80B0ADC0C0AE0100BEB1910F31E16FA2117FB2318
FB2517FB2415FA2515FA2619FB281AFD2B1BFD2E1BFC2C19FA2A19FF2F1EFD301BFE2C1A
FD2B1AFC2919FC2818FD2616FD2616FB2315FB2316F92112F92213F72014F31E12E51911
C20602BD0908C20B0AC30A09C1090CB70407B20408AD0207B2060BAE0307AD0308AA0209
A70106A80206A402079D01069801089301099002098B01078A00068B01078B02078B0208
86010787010889030988050A82040A78030776070A6B0805610D05702D1A915739A16C44
97653683531D6C3E047B4A074AAF0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DB0C9F7234A77D43AC8247
B4804AB46840B0462CAC2716B41A0EC0130DC30C09C50909CA0B0BCD0A0BD00D0CD10C08
D60F0AD60C0AD90D0DDE0D10DF0D0EE51211E5140FEA160FEA170FDD0D09D00402D20608
D30709D5090BD4080ADA090CD90A0ADC0D0ADE0E0BDD0D09E10F09EF1912FC241AFE271B
FD2A19F92816FC2C1AFB2E1EFA311FFB3521F93721F93522FB3522FD3321FE321FFF301E
FF2F1CFD2B1BFE2B1AFE2918FC2717FD2718FC2416FB2315FB2315F82212F52316D9130C
BB0404BC0A09C10C0BC30B0CBE090BB7070BAF0409AB0309B0070CAD0408A90207A80208
A8020AA80206A70308A20106A1030A9B01089501069101058C01058C02068E02078C0208
8801078802078B05098C04098A04088503087F02087C040A77050C70080A660A056E1F11
85442B99643C9163317D4E156F3E0260780525D70500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE0FA67B3CAB8145B0853CBC8F37
D0913CA23709AF1807BF100BC40B09C80A09CA0B0ACC0A0BD00C0DD30A0DD60D0CD60E09
D8110CDA110ED8100DDE1111E31411E81511EA1811EC170FEB180DE10E07D70A05D50806
D30706D40708D60A0ADA0C0CDB0C0ADD0D0ADB0D08DE0F09E3110AF21C13F92619F62C1E
EF3826EA3D2AE94331E84837E9503FE75544E85D4BEC6051EB4C3DF43628FD3121FD2F1B
FE301BFE2E1AFE2C1BFD2819FD2819FD2718FD2415FA2314F62513EF2A16E62C19CA160C
B60605BB0D0DC00E0DBF0C0DB80A0CAF080CA60307A20307A50408A70408AA0509A60207
A40107A60309A50207A102079C02079A0207980205910104880004850004890107870106
8201057C00037F01058202058604078202077F02087E02087F020A7F030A7B0409750609
6A09056A1A0A87482999643B8C5C2A74410C76400345A90400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0049AE049867197D9A2BAA7942AF7F3DBE8F33C39822CD9D18
DF9922AC3201B71001C10A07C10606C40707C90B09CC0909D20B0BD70C0CDB100EDC120E
DA120ECC0D0AEB2F2CD3100EDE120EE71410EA170FED190FEE1B0FF11C12E7160DD70803
DA0B08D80A06DA0C09DA0D0AD90D08DB0D07DE1109E01008EB190EF82418F4281DC41C12
EA7B6CFBAC9FFEB5A8FFC0B5FFCCC2FFD3C9FFD7CCFFD8CEFDADA3E24437F83522FF321E
FD2F18FD2C18FE2B19FE291AFE291BFE2719FC2615F72A1AD82312E45945F17F6DB53126
AC1711B5130EBF1311B80C0DAF090DA6060A9E0409980307980407A00609A40507A50205
A40206A20105A60308A00206940003930004970305940307870105820105840005850005
8101057700017700027900027A00027700037601057601057A01057C01057D01067F030A
7C050B720807660A026C210F8C533398643B834E1D6E370260740326D60300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB00A9B6A29AD7644B26F48A05127A96218D0991ACD9F08D2A306
E49D19AF3300BC1504C20B07C00607C40807CB0D09D00B08D40B0AD80E0CDA0E0DDB0F0E
D40F0EB70302C21210C00402DF1610E8180FEE1B10EF1C0FF01C0DF21D11EF1B0FE9170D
EE1C13ED1C12DC0E06DA0E08D80E06DE1108E7170CEF1D11F92518FD291CF22B20A6110F
B6766EFFEBE6FCEDE8FCEEEBFAF1EDFBF3EFFBF3EFFCF0EBFFDFDADF6258F23927FC311D
FE3019FE2D18FE2B17FE2918FE2918FD2818F82616E62D1E941206E0A193FFE0D3F6BCB2
C86A5EAF3328AE1D17AB1411A4100E9C0A0A9408088C0A098A0D0B870A0696100BA51311
A10707A20407A6060B9F02089801089201078F01058F0205870104840004860004890206
8601057F01037C01037D01047A00037701047300027200027501047A01067F0207800207
7E02087B03077703076D07065908026B2B189259398C562B7339087D420224D40300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00728E1A9E703AA56E499F4C35952614901600B85A13D79B10D0A303D3A405
DF9D17AD3500B71102C00907C00607C60A08CD0C07D10D09D50B09D90F0ED90E0CDC0F0F
D50F0EC6110FEC3C39D61814E51911EA180DEE1B0FED1A0BF01E0EF01D10EE1D10EC1E12
ED2316EE2618E22215D5190DDC2516E22719EC2C1CF32D1DF62C1DF92A1CF52E21C42721
833E3BFAE9E7F3EEECF5F1F0F1EFF0F5F3F3F3F0F0F7F2F1FFEDEBE98884EC3E31FC321F
FC2E19FF2C18FF2C18FE2A17FE2A17FC2A18F12E1CBE291A944437F4D9CEFBF0EAFEEEEA
FFE3DCF9C4BBDE8D85BB5750A1372D8E23188620157C20157422167E2F22B05A4DCC6158
96110E9B05099F040B9C020999010A9202098900058900058902058902048701038A0306
8901058701058502058301047F01047C01047901037601037600047B00067F0106810106
820308810107800209770307660103580400540C0371331A8E5631774011733901708109
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25D806996B299E7044854D30702011850E07A40F09A81103BD5313D89B0FD1A403D0A303
DB9D15AC3B01B71403BE0906C20807C90A08CD0B07D30C09D80E0CDC100DDB0F0BDF120E
DD130FDD1A16E52621E31A13E9180EEB170DEF1B10ED1B0EE81B0DE62113DC2718D32D1F
D33A2DDA4A3CDF5A4CE66C5CEC7867EE796AEB705EE86353E55444E34333E43C2CD33D33
711F1BDCC3C0F6F0EDF8F4F4F4F2F3F5F4F3F4F3F2F4F2F1FDEFEFF4B3B1E2443DF83222
FE301DFE2D19FD2B17FC2A17FB2E19EE2F1DCB301E9F3F30EAC3B8FBF1EBF4F2EFF6F3F3
F7F2F1FAF0EDFDEAE5FAD6D0E1B3A7D7A495CF9E8DCDA190D3AB9BDAB2A2E4AD9FAF5951
8209099203089802099600099400099002098C00078C01078B02078A0105870003870003
8A01078901078601048400048000047E01057F01067F0106800208810108810007840208
84020886020B82010A7500046800015E01005A02005405005A15087F44267B4116723700
6E7F0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310
9870338C633E5E2B185B130A700B07930709AF0D0BAF1102BB4A0FDB9D14CFA302D4A805
DB9F14AE3D02B61300C30B08C70907CE0C0AD00908D50C09D90E0BDD0F0CDD100CE0110E
DF130DE1160FE31810E8180FEC1A0FEB180DE7180DE21C11D42015BE291ECC584CEC9589
FBB8B0FFCBC2FFD6CDFFDFD7FFE2DAFFE3DBFFDFD6FFDDD4FFD4CAFFC1B8F5A499E2877D
8E5048B9A19CF6F0EAF7F5F2F5F3F3F3F1EFF3F1EFF3F2F0FAF0EFFED5D4DF5952F33628
FB311FFB301DF83320F03423E23727C03728BC6356F3CBC0FBEEE8F7F3F0F3F3F3F2F3F3
F3F3F3F3F2F2F5F3F2EDE7E3ECE0DAEBDBD3E9D8CDEBD7CCE9D2C6D2AFA4A2645D801A19
8B060A95040B9A020B9900099401079000069101089001078C00068901058901068C0107
8C01088A01078800078601078001057E00057F01077F0207800105810206830107850108
86020B8502098303097601046700006001015F02025C020155020050090174361B7F451A
7237016F7E0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718C16976E38
704B294317094007024D0305620102890307AB0A0AB11004B6410DDE9D16D2A602D8AB05
E1A414BA4708BD1703C90D08CE0C0ACF0B0AD10B08D60C0AD90E0ADC100CDB0D0DDC0E0F
DF130EDF130CDF1209E5160CE7170DE6170CDE1B12C22015AC342AE0938AFED3CCFEE6E1
FAEDE8F8EFEAF7F0EBF7F1EFF4F0EEF5F1F0F6F3EFF9F1F0F7EEEBFAECEAFDEBE7FFE8E2
F8E0D8EDDFD9F1ECE6F4F2EFF3F2F0F3EFEEF4F0EEF0EFEDF4EFECFEE6E4DF7E76DF4437
E73F30E03E31D34536CE5346D27064EBAFA6FFE4DCFCF1EBF6F2F0F3F3F2F1F2F1F3F4F4
F1F2F1F3F3F4EBEBECE4E1E0E6DFDCE6DAD9E8D9D5E6D1C9CAA89E91564E6F121085080C
95040A9A02099F040B9D03079903099501089802099301088D01078B02088E030A8D0108
8D01088B01078C01088900088401068001067D01067801047701037700027B01047F0107
8101098202088003077B02056C00006400006101015E01005B0202550201500600692911
81441B77370122D10100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718D178F6330593115
3B0F033805044005074802065D01057D0206A30909AD0E02B03608E49F1AD5A803D9AB04
E6AA14C3530ABE1601CC0C09CF0B0AD10A0AD00A08D70D0CD70A09DA0E0CD90C0DDC0F0F
DD120EDD110BDF130BE61710E3150DDE1812BC1A13932A20E7ADA3FADFD9F7ECE9F1EBEA
EFEDE9F2F0EEF4F0EDF4F0EEF5EFEEF6EFEEF5EFEDF6F0EEF5EFEEF6F1F1F5F1EFF4EFED
F6F0EDF8F2EFF3F0EDF3F2F0F4F4F2F2EFEEF2EFECF1EFEEF3F0EFFCF0EDF5C5BEE9978B
ED9B8EF3AEA4FDC9C1FFDDD5FFE7DFFDEEECF7F0EFF6F4F3F3F3F2F2F3F2F3F3F3F3F3F2
F1F1F0ECEDECE3E2E1E4DCDBE5DAD7E6D5D0DDC1BCC3968E88453D6F0F0B7D06078B0208
9702099A01069D02079A00049701069500079702089301098E00088C01088D01098B0108
8901088A01088C02098801078502087F0106760002710001720102730101750002790006
7C01077D01057E02048004077902047102036901016501026000015A0101550201510500
651F0C7E3C1678380124D30200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075901D9F76484C260E3A0D03
3806033601053C0206490105650408800307990505AB0C02AC2D02E39819D6A605D5A701
E2A810C75C0DBF1A02CD0C09CF0A0BD10B0BCF0909D50B0DD50A0BD90D0DDA0F0DDB100C
DB0F0DDD100CE0140EE1120CE0140DD018167E0504BA827CF9E0DBF8EEEAF4EDEAF7EAE9
F3E1DFF6D8D8E9C2C1DDAEAED3A09FD09B9CCE9B9BD7A8A8DFB5B6E6C4C3F1D7D5F4E4E4
F6ECEDF4F0EEF2F1EDF1EFEEF0EFEFF1F0EEEFEEECF4F2F3F3F1F2F4F0EEFBEFEBFDEBE6
FDEEE8FDF2ECF9F1ECF8F1F0F4F1EEF5F2F2F2F0F2F5F4F5F4F3F4F4F3F3F3F3F2F3F2F2
EDECEAE4E0DCE8DFD9E6D7D1DFC5BEC99F97AA6A64862D2A7508078105078601068C0106
9501069E02099F02099C01079801079600079502089200069101088E01088E0209890106
8600068600068802088200047C01037501027000016F0001710101740101760103790107
7900067901037901027B01047D02057C06097402046E01026901026200015A0000550101
530400671F0A75340D7E3F0327D60300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00759222B19065BFA59233140D340808
3504053601053F04084A00046C0509890508990202B10E07AC2300E5911AD5A304D3A601
E1A90FCA650FBA1801C90C07CB0A09CA0707C90506D1090BD40B0AD60A0AD70D0BD80C0A
DA0C0CDE0F0DDF100CE2120EDE150FBF15145F0606D6B8B5F9ECE8FAEBE8F0D0CCE3ABA8
DB8E8DCC6A6AB03A3BAD2A2BB02626B22527AC2325A92628A62C2DA33433A14241B06365
CA9093D4B2B3D9CECBEDE7E5F3F0F0F3F1F2EFEFEDF1EFF0F2F0F1F2F1F0F5F2F1F4F2F1
F4F3F0F4F3F2F4F4F2F4F2F3F4F3F3F3F2F3F3F2F3F3F2F3F4F3F3F1F0EFF4F2F2F6F3F2
E6DEDAE1CEC6DCBDB0C5978BAF6E64842E277C0E0C87070A8C030890030A8D01078E0205
9401059E0309A000099E010A9C010A9800079500059201079001078E01078D0106890106
8701058701058601067F01047501016F00016E01017001007401027702037801037B0004
7D01057A01037701017501017601027C04087A03077601047001026B01026501025B0101
5601005304006A230B702D0465710300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B717B89770D3C1B1C7B8B5321B1A31090C
3205083502083D03084801056C070A8D060CA10507B10B09AB1A01E28717D7A206D6AA04
E0AA0ECD6D11B51801C60A06C90B07CA0909CB0909D00A0AD40E0BD50A08D70D0BD70B0B
D90B0DDE0E0DE00F0BDF0F0BDD140FBB1514520202C8ACA9FDE8E2E5B7B1C06660B3302D
B81F1DC21817C81413CD110FD21311D0100ED21313D11315D21917D01C1ACD211DCF2B29
CA3A39952E31613837E3D6D4F2EDECF0EEEFEFEEECEFEDEEEEECEDF0EDEEF1F0EEF5F2F0
F5F2EFF9F2F4F5F2F1F9F2F3F6F0F1F7F1F2F8F1F2F7F1F0F8F0EFF8EEEDF9EBEDFDE7EA
DAB6B5BB827CA0524988261F8712108E0D0C900406930205930105930107910108900207
9201079A020AA1020CA1030D9E030C9901079702079302088E00068C00058D01068B0206
8800058801078301067C01037301016E01016C01016E01017201017501027A02047D0204
7F02057F02057A02037600037602067702077C040A7A05087100026D02036B0204630201
5C01015601005709006B22077731014AA70500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028DB0DB39065D5C4B3D4CBC7C8BFC13A282A2D0B0D
2E05083101063702063E00015B010484070C950104A90908A91703DF7F15D9A208D7AA04
E0AA0ED07310B11A01C40C09C50907C40708C60606CA0807D10C0AD20A08D40A0AD70B0E
DC0E11DF0F10E0100EDF100CDE140FC81717690304A46E68EEB6AABF5B52B61E19C8120F
CE0D0AD50C0CD50C0CD50C0AD60F09D70F0AD8110DDB110DDB120DE01510EB1F16F7261D
F22B22D2302C620D0BBDA6A4F3ECEAF3EEEEEFECEBECEAEBF0EFEFF1EEEFF3F0F0F5EBE8
FDE3E0FFDDE2FFDEE3FFDFE3FFDFE2FFE0E3FFD9DDFFD7DAF2C3C6E6B3B5DB9AA0BF7279
8D313688191B8C0D0C930708970507970306960305940102920103930105930208910108
9201099801099E010AA0010C9C010B9701079400069201079002078F0106910107900107
8E01078801077D01037400006F00016C00006B00006E01016E00017001017401017A0202
7C00027C0104790004760005740106750106750509780C106F060A6A0104670102610202
5E02015C02015704005B0E016D2403833C0327D50300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0028DB0BAC8559D2BFAED2CCC9CDCCCDD3CFD1463B3D24090C
2E070A3403093B03094202075301047404098A03069D0504A61503DA7915DAA209D5A802
DAA70BD47A12B11D00C00C06BF0604B70001C50608CA0709CD0708D20A0BD30B0BD50B0E
D70C0ED90D0ED90E0DDB0E0DD80F0CCE11129C0708AE3F38E47263B82016CA100BCF0A08
D20C09D40C0AD30A08D70F0AD40D06D80E0AD8110BDB120CDC140BE0160DEF2215FA291B
F72A1AEB34288F191489605BF4E8E4F2EEEBF1EEEBEFEEECF0F0EFF1EFF0F4F1F0FFEEEC
D19594D57274DE7276E17377E07375E07273D9686AC15356A23A3D9F3234A42C2FA12123
961211990D0A9E0B089D06049C04029A0403960202950303910102900104940409900107
9200069901089F030B9C010A9A020A960006930004920106920107940208940206910105
8E02068702067B01037100006F01016D01016E01016F01016E01016D0101710201770202
7902027A0204790105770106730004700003680305C1666AA549506A060B6201035B0000
5C01015B0201580201530400621302762A0145A00100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007A9A35CBB2A0D2C9C6CFCDD1CECFD3D4D3D65D5657250D10
2C08093503093C02064703085402086901077E0206990809A01303D37215DCA30CD4A804
D6A508D37D11AE1D01C10C07C50A08BF0405C70609CB0709CF080AD1090BD10B0ACF0A09
D30C0BD00A0AC90404CA0303CD0606CB0706BF0806BE1712D22C22C71009CF0C07D10A08
D10B06D10C07D20F07D41107D31005D31307D21608D31807D31C08D51F0DE2301CE63624
E53B28E04636AE4035815249EDDFD8F1EDEAEFEEEAF1F0EEEFEFEDF0EEEFF3F0EFFBEDEB
EBB8B3E18A84E78881E7857FE8867FE68379E47E77D87570CD6D68C96760C65E57BE544A
A73C2C9E2D19A028149D210E981907941404900E01900C008F09018D06018E0403910205
9301069800079D030A9801079601059803079702069802079802089501079000048F0104
8B01048001037801027100007002006D01016D01006F01006E01016C01016D0101720101
7401017601027801037A01077500056E010467020591373EB05C64AF565D7115185C0303
5901005802025301025101005B0800701E033C940000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004DAF119D7551D3C2BCCFCCCFCDCCD1CFD0D3D4D4D77C76771D0A0D
2503053502084003074501075201066D040B7D0206930406990C01C66314DCA00FD3A603
D7A407D38111AF2001C20B05C80909C7050AC70408CA070ACF090DCF090CCD0909CD0A0A
CA0807C50303C30201C40101C60302CD0707CE0B09C80806C80A05CB0B06CB0C03CD1005
CB1203C71505C51905C41F08C2230AC42D13C7371CCC4529D35539DA654CF38C78F79C8C
FAA798FCB3A5F9C3B9EDD0C7EFE5DDEFEAE7EFEEEAF0EEECEDECEAF1F0EFF3F1EFF4EFEC
FAEBE5FFEAE2FFE8E0FDE3DDFEE5DDFEE5DBFFE4DCFFE6DFFFE3DBFFE2D9FFE1D7FFDBCF
F1C3B1E3AC97E1A489DA9A7CD48F71C87E62C17257B55F46AA4D35A4402A9D2F1F8D0F0A
9105089501079B0309990106960105970308980208980208970106950106930208900008
8902077B01027501017201006D00006A01006B00006E01006F01016C00016C01016F0001
7101007401027601027801047501057001056C020667070BA851589B464F9F4B528A3638
5803025701035001015001015D07016E1604585A0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063720B8A6049D8C9C7D0CED1CCCDD1CDCFD1D3D3D69F9A9C251114
2C080D3604093B00054301074F010570070F7F020696060AA11104C35714DC9D10D2A202
D6A206D68513B02401BF0C03C60908C6060DC3050AC3060BC6070BC7070AC60506C60506
C60405C30101C20201C40203C60303D10B0DD30F0FCB0A09BE0A05BD1608BB1F0BBF2E15
C33D21CA4F35D26548DA7959E38D6EEA9F82EFAC92F6BAA2F8C4AFFBCFBFFFE2D7FCE6DF
FAE8E2F7E7E2F6EBE5F4EBE6F2EDE9F1EFECEFEEECF2EEEEEDEBE9EFECECF0EFEEF1EFEF
F1F0EFF1EEEEF4F1F0F2EFEFF3F1EFF2F0EEF2EFEEF4F0EEF5F1EEF4F0EEF2EFEBF2EDE8
EFE3DDE9D7CDEBD7C7EAD6C4EAD3C0EBCFBEE9CBB9E9C7B4E6BEAAE7B7A3E4A693A6493E
840707920308980209970209930107920108920007920007950106960107950108910009
8601067700017200007402016E00006900006D01007101007101007001016F01016F0101
7001007101017201017200027001026E01026C0104700C0FC3676D711A23A858619B4E53
7523235C05065100024B0101570400690F03711E0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00742C057C4C3FDACBCAC9CACBCBCCD0D0D2D6D3D4D8BFBCBF2C1B1F
2A080C3302063B02084303084C01046502077C02068D0305A41403C25112DE9C13D2A103
D5A107D68512AC2300B90A01C10604C3060BB60306AB0003B50407BD0305C00304C20304
C10203C20101C30202C40203C90506D30D0FCF0A0DC0090B920402B34733E28769ECA184
EFB299F2BFAAF1C8B5F1CFBBEFD4C1EDD5C6EBD8CDEADBD2EEE4DCF5ECE7F2EDE9F0EDEB
EFECEBEBE9E7EFECEAF1EDECEEEDEAEFEDEEEFEEECEFEBECF0ECEBF2EEEFF3F1F2F0EEF0
F0F0F0F1EFF2F1F0F2EFEEF1F3F2F3F0F0F0F1F0F1F1F1F1F0EFEFF0EFEFF0EDEDEAE7E7
ECE6E7E5DCDAE5DAD6E3D8D2E2D7D1E0D6D0DFD5CFDFD4CCE1D5CCE4D4CAECD0C6B3746B
7B0D0C8B020794040A8E01068B01078C0009910108920008950108980208970208930109
8601067700017200007300007101016D00006E01007002016F0201700101720201710101
7101007101006F00016F01026D01006D01026A02047310118C3034AD5760A5576074292E
994A4C7320235305084700014F0201640D056C18013A950000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0053B11A6C20096C332DD7C2C0A7A5A4CCCCCFD2D2D7D3D3D8CFCDD1372C2F
27090A3104083802074303084E010662030877050A8300029A0C00B7450EDE9C15D1A203
D5A107D88511AB2200BA0903C00604C20609B80407AA0103B00003BA0103BF0205C00106
BE0102C10103C30203C60405CA0808CF0B0CCD090CBA0A0C7202027D4134DCB69DEED4C1
E8D6CAE5D6CEE3D8D0E3D8D0E3D9D0E5DAD4EAE2DEEEE8E6F0EBE9F2EDEDF3EFEDF3EDEB
F2EAE9F3E8E7F2E5E4F7E9E9EFE9EBEDEAEAEEEBE9F2EEEFF2EFEFF1EDEEF2F0F1F1EFF1
F2F0F1F6EFF0FBEBEEFCEAEEFBE8ECFAE7EAFAE8EBF8E7EAF7E7E9F8E8E9F4E4E6F0E1E3
EBDCDDE4D3D4E4D2CFE5D3CDE4D4CDE3D5CDE1D6CFE2D7D0E1D9D2E2D8D4ECDAD5CA9994
7E1E1C87090B8C0B0C961A1B8D121586070D8B030A910208940108950108960208930308
8601067B00027702027501027302016F00016E00016D01006A00006D0001700001720101
7301017302027302027001026D01016A00016601029035359F4C4FBA6F75AB656E9B565C
A15A5E883B426E21284A02074A01015E0B06671301555B0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF002EE012B27A54621B0B62201AAF8D89918583CFCECFD1D1D6D2D1D7D6D6D84F4748
23080A2F050B3502084002074E04095901056C0306860708980D04A93809E09A16D2A104
D39F05D98612AA2100BC0B05C10607C5060CC3070DBB0409B80105BB0104C10408C10206
BF0303C00104C20405C80707CC0A08D10B0CD10B0DC10B0E8407085B2420D4B6A8E8D6CC
E4D8D2E5D8D3E5D7D0EBDAD0EAD6CDEDD6CEF4DCD8F7DDDEFCDFE1FDDCDFFDDADAFFDBDC
FCCBCCFFCDCFFCBFC1E3A3A6875E62BCAFAFEEE9E6F1EEEEF1EFF1F0ECEDF0EEEFF2F0F1
F2EFEEFAE5E7E8ADB3EC9FA5E79298D3828AD0838DCE848DD78D94D38B92D28E96CE9197
CE959AD0979CCE9696C48F87C69489CA9C91CFA69DD4B2ACDABFBBE1C7C7E5C9C9E1B0AE
8A2F2D7F0D0BCB605CE88280C35D5DCB62658812168A030B9102099101079301068E0105
8300037B00027701017601017301017000016F01016D01006D01016E0101700201730201
7301027401027301017001016E00026B0002670103721A1DC1777AA5626764232BCA8A92
9C58608A3F498A414B530F1447010158060569110570200000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0059C229AC80665D1C115D130D91625D8E7C7ACDCACDD1D3D6D1D1D5D5D5D7696367
21090C2C040B3302083C01074703075202076002047601038E0801AA380ADE9715D3A104
D4A005D98912A92300BB0B04C20709C6050BC3040BC2050CBB0106BA0105BE0206C00207
BF0205C30207C40407CB090BD00B0DD70C0FD90F10D00F0FAF1111690907E0AAA2F9D5D0
EFCEC8E6BDB6E6B4A8E4A99DE5A096E79B94EF9C98F59DA0F18F92E98081E47776E37172
E06162E35A5CDD5151D14C4A903432886663F1E7E3EFECECEEEEF0F1EDEEEFEDEEF0EEF0
F1EEEBFEE4E5CA7A7BC64D4FC63C3DB7282CAA1D25AE2027B4252BA91F27A2252D952B30
8C2E319033368B2D2C892C2481251A83291D822D22803229964C4AA55E61A86364AF6262
9732318C201EDC7B7AC56A69953A3CC96F72C15C637F040C8E040C8D00088F01088C0207
8301047A01017701017701017501017302027001016E01016D00006F0101700101700101
7201017201017100016F00016F01026D0102690204620408600E14934C539E5A6397545D
8A454E9F5860954E585B161C4801025704046910086E1C0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE8351A07C6761241A60120D87524FB5A1A1D7D2D7CFD2D6D0D2D6D2D3D6878286
200B112B060C3303083901073F01064C01085C03076D00018C0903A63509E09A18D6A404
D6A206DF9118AA2700BB0C04C40809C6050AC5070BC10308BB0105B90005BC0104C00207
C40408C6040AC9060ACC070BD20A0DD70C0EDB0F0EDA120FD31915B91D1AE87471F99997
E68580C55F55BB4F41B64234B63D31B83C33C1423ACB4A45D04F49D55751DA645DE16A65
DD524FD33733D5463EE1695FD38177C8A59EF2E6E2F2EDECF1EFF1F2EEEFF1F0EFF2F2F3
EFEFEEF8EAE8F5C4BFEA9D96E17A72C14039B61E1DBE1717BD191AA81A1B90211F9F4B45
C27F78DA9993DC958DD58C80CA7C6FBB695CAE5A4DA24A3F9C41399335308624217E0F10
870E10901F21CC6C6EC46E6FD986899B464DC3656E8B19228A030C8C01088C0208890107
8401057D01037601017401007401017201007001016F02026E02026E01016E01016F0101
7302037401037301037101017001026E01016A01016401035F020658070C6C2129C07883
752E38BF7982AC6570671F274D02045905046910096D18003E970000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC875C997B696C332B62140F814A4CDBC9CCD3D1D7CDD2D5D0D2D6D2D4D8AAA8AB
1C0E1225050A2B01043501063C01074B01085A0204760405940E07A02F05E19C1CD6A505
D7A405E0931AA82700BB0C04C10506C7060BC8080AC4050ABD0104BC0106C20308C9070B
CA080CCB080DC90709D00A0CD40C0EDA0E0EDC120DDE1810D6180DDB2319D82924CF2D2C
C5302BB02C22A93426BC5140CE6C5CE78A7FF4A39AFCB4AAFFC1B6FFCBC3FFD6CDFFD8D1
F2A9A59B2E2A9B4840FFD7CBFFE7DEF6E7E2F4EFEAF0EEEBF1EFF0F5F0F2EFEEECEEEEEF
EFEFEFEEECEAF4E8E4FCE9E2FFE1DAF8BEB5BF554FAC1D1BA21B1B6B110CB68178F3D1C8
F7E2DAFAE7E0F5E0D9FAE1D8F4D7CEFBDBD2F7D2CAF5CAC1EBBAB3ECB4ACDB948C98312F
911113870B0FD56E71C97277BA6A6ECE7A82C96B74901D2689020B8F010A8E0108890006
8501067D00037600017300007201017201016F00016D00016A00016800016801006C0101
6F01017201027501047401047001026C01016901026501026402045F02065B050D73202B
74242F6C1D28994F5A6F232C5A070B6006066A0E076E15003D930000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B918A0805DA88F817140395F14117E464BDFCDD3D0CFD4CDD1D5D0D1D6CFD3D6BABABC
1B14161901042501043203083D06094902086106097A0608940E07A02D03E29B1CD7A407
D6A505E0961AA92801BD0E07C00607C5050AC50509C5060BC30509C3040ACA090ECC090D
C90708CA070ACB0806D20C09D70D0CDA0E0EDD150FDF2016F24636E43123D42016BE1F17
A2271FCE796EEFB5A9FBCEC2FCDCD2FDE1DBFAE5E1FAE9E4F8ECE5F8EDE9F5ECE9FAEAE9
FBD9D69F56545C2A21DFCCBEF5EEE5F8F4F0F3F2EEF2F1F1F2F1F1EFECEFEEECEDF0EEEF
EFEFEFEEEDEDEEEDEBF2EEECF4EDEAFBE9E4F8C5C1AA45437C1B19633530E9D8D1EDE4DE
EAE7E4EAE9E7ECEBE8F0EDEBEEEBE9EDE9E7E8E2E1F1EAE8EDE5E2EEE1DCF9DAD6BA7372
8A1417920A10981C23D87179CD717AD5767FC45963870A128D02099101089201098E0107
8400047D00037901027601017401017401017201006E00006B0001690101670000690000
6C01017001037301037301027001016B0002680103640002620104610105630109660610
6707116509137B263077242D650A0F6807096C0C087115033C910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC226A98E719D8B818059555A1817652C34D8C3CACCCBD0CBCED3CED2D7CCD1D4B5B8BA
201C1D0F00011700002701063402054501065600046D01048B0C079C2D03E39A1DD9A607
D5A605DC9315AB2C00BB0C04BE0506C30709C5070AC6070DC40409C7050ACB080DCE0A0E
CD090BCD0809D30C0CD60E0BD90E0CDA100EDD1510DF1F15F34638D02318AF18108A241A
CF9489F2D3CCF8EBE5F2EAE6EFEBE7EEECEAF0EDECEEECEBEEEEEBEEEBEBF3EFEEF6EFED
F8E0DCAE746D531E13BDA391E8DBCEF1EBE6F3F1F0F1F0F2F3F2F3F6F0F1F9ECEDF8E2E6
EBDDDFEEE9EAEDECEAF0ECEBF0EDEBF0EBE8FDE3E0CC8A886C21215B3835E6DED7EBE6E3
E9E9E8E8E9E8EBEBEBECECEDEBEBEBEAEAEBE5E5E6E7E7E7E9E9E8EAE9E8F2E5E4DDADAE
86202394080D97080F8E0A14991E2B9D242F8E0E168C030A900107930208940208910209
8701067E01037900017700017701017501017100016E00026C00026A01016B02016A0101
6B01026C01016E01017001016F01016D020468010561010460000661010865010967010A
6C040C6C070E7D2027832A3166080D660507680A086C11033A8F0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC82EB7A08B92847F9C7E7B551A1C5A1F26C9ADB3C5C2C7CCCED3CBD1D4C7CBCFB4B6B6
322F2E0900000E00002001052F020541010755050A6503077707048E2803E19B21D8A506
D5A505DE9515AB2D00BC0D04C20807C30709C6080BC6060BC9080CCC080CCF0B0ED10A0F
D0090CD20A0DD40A0CD80E0FD70C0DD90F0DDA130EDD160ED91812C71B177506059F6E65
EFDAD1F1E8E4EFEAEAEDEBECEEEEEDEEEEEDECECEBEDEBECEEEEEDEEEBECF0EEECF5EEEB
FBE8E3D19D91612315886353E8D5C5E8DDD7E5E1E0E6E3E3E7E4E3F5E9E9E5BCBFC57980
85494DCCB7B8EEE9E8EDEBEBEAEAEAEBE8E9F3E5E5EDC0BF7E3B3B461818CCBFBBE8E4E0
E6E6E5EBEBECEBEBEBE9EAEAE9EAEAEAE9EAE6E5E5EBEAEBE8E8E7EBEAE9F0E7E7EDCBCA
9C46449710109E05099C040B99040D94030C9202089201079300089301099101098E0108
8801068001047B01027A01027800017903037201026D01016D01016E01016E02026B0102
6900016900016B00016C00017001026E01036600036101055D00055C00046301076B030A
6C040B6D050C700D1274121869090D630407620606680F0277270000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
88A943B29C8CA296948B706F541A1C521317BE9CA1C8C2C7C9CBD0C8CDD1C1C7C7B5B5B4
4A43440C01030F00002101042F02073B01074801055A02076903018A2901DC961ED6A306
D4A406DF9618AA2B00BC0E05C00705C6080BC30709C8070ACA0A0ACC090ACC0A0BCE0A0B
CC0707D1090AD40B0CD80E0FD80E0CD80E0CDB120EDB110BD9120EBE1616570101AA9089
F2E8E1EEEBE8EDEBECEDEBECEEEEEEEBEAEAEAEAEAEDEDEDF0EBECF1E6E6F3E1E0F9E1E0
FCDAD3F8BAAC7E3325572A1FE4CEBDE8DBD1E7E2DFE8E5E4E9E7E3F9EAE9F0BEBEC24D50
A33333916262F1E5E3EDEAE9EBEBECEAE9EBF0E8E9FADCDC9B5A59651E206E4A4BE0D6D5
EAE9E7EBEAEAEAEAEBEBECECEDEDEDEAE9E9E6E4E5EAE5E4E0D8D7E8DDDDEDDEDEF0D2CF
B067628C0E0BA1070AA30308A202099C00079A02099702089401079202088E01088C0106
8901048401037D00017C01017D01027A01027601017201017101017001016E00016D0001
6C01016C01016D01027102037503057202056A01046401055E01045C00036501076A0207
6802076903086D070C6904096B070C68090B610605630D0074260100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78F5DB29E929B929199818056211F511011A47E81CFC6CBC1C3C8C7CBCFB6BCBBB1B1B0
655E600B02031201012401053001073D0108480207590207720803842100DB981FD4A205
D5A507DF9519A92900B90C03C00705C50809C60A0AC70808C70807CB090ACD0B0BCF0A0B
CD0A08D20B0AD40E0BD70E0ED90F0CD90E0DDC0F0EDC100DD8110DC51818650403836260
E9DFDBF0EDEBEDEDEDEEEDEDEEEEEEEDEBECEBEBEAEFEDEEE9DDDDE3C0BFEEAFADF3A2A3
ED8F8DE7786FA93930500E06C3AB9AE7DACBEBE6E0F3F2F1F7F5F3F0E7E5FED7D5CA5A5A
BB3935702E2BEFDDD9F1EAE8EBEAE9EBEAEBEDE9E9F7E3E3CA8E8D81222368191C8B6669
E8DDDEECEBEBECECEDE9E9E9EBEBEAE9E9E9E8E6E5DAD0CED1B5B4D2A5A8D29EA0DEA5A5
E5928F981A18A20609A9040BA70309A101079B0208980106B41C20C22D3195060B8B0003
8B01048702057F00017E01027F02027C0102790101760201740101730101710101700101
7001017001016F01017000027200026F01026C01056701046001045F0105630105650105
64020566020768050965010769050B6B090C650908631205742A0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9363BBA79E928A89AE9D9B5A2E2B511011885B61D0C2C9C0C0C5C4C7CBAEB3B3B3B2B3
7D7A7C09010416010329050C34020A40030B4601075F030983110D801A00DB9820D6A406
D6A607DF9319A92800BB0C03C10906C50807C50907C70908C80809C90708CA0607CF090B
CF0B0BD00A09D30D0AD60E0ED70D0CD80D0DDA0E0DDC110FDB120ED41816A414145A0D10
BB9E9EDFD8D7F0F0F0EFEFEFEEEFEEEEEDEDEEEEEDEFECECEEDFDEDDAFADBC605DC94341
CD2F2DD02821C42B26680C08947567E3D5C6E9E4DCF2F2F1F0F0EFF3F0EDFEE8E7C97776
AE32306D1D1BCAB1ADF2E8E6EFEBE9EAE9E8ECE9EAF3E5E5E8B8B6932B2B9B1E2172151B
8F6268E3D7D9ECEBEBEAEAE8E9E9E7EBEBEAE9E9E7EADFDCCCA5A494484990292D9E2E31
B4383CA31315A7060AAA0308A80208A10006980105980104B21418C22327B41E248E0105
8E01078C01068501027E01007C00007B00017A0002790202780202730000710000710100
7201017101017202017101017101037001056D01056700046000035C00045E0005610106
61010662010566040866020867030A69060B650A0A6E21157E381400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9063B9A69EA69E9E8D807D734A49500E116E3A43D2BCC6C3C1C7BFC3C7AAACAFB0AFB0
928F8F0D050717020426030B30020B3801083F0007550209760D0B821D00D8951ED6A507
D5A605DA8F16A82600BA0B02C10705C70908C50807C80808C70607CC0A0BCD090ACF080B
D10B0BD00A09D20C09D60E0ED60D0CD90E0DD90F0CDB110DDE130DDE1410D41B19A41417
69161BAA888EE5DDE0EEEDEEECEEEEEDEFEEEDEDEDEDEBECF2EBE8FCE3DFF9BEB8D76E65
C53125D7261AD0231C96211D643930DCCCBEE9E3DAEFEFEEEDEDEDEEEBEBF8E8E6D89A9A
A332308729259F7A77F4E7E2F1EBE9EDEAEAEDEAEBEFE7E6F8D4D2A84746AD1C1CAD1A20
7E161E86565CDDD1D2E8E6E5E7E6E5EBEBEAE8E8E7ECE8E5F3DBD7D89C989A35319F1718
A90E13AB080DAA0408AB0408A90208A6020AA10309980305B11E23A8161D990A118E0209
9001089202068C01038100017C01017A0102770001760000770101760102730000720000
7101007000007101017101027201047301057002066701035E00025A01035B01035F0106
63030961020664030765010767030A66050B5F08096D2218CBA99C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE976BB6A89F9A9898968D8C8866664E0F13582028CAB1BBC0BDC3B8BBBFA9AEB0AFB0AE
A2A29F140D0C19040624040A2E030C38020B40010A4700075F0604761901D0901BD6A708
D6A807DA9017A92700BC0D05C20806C60809C40606C8060AC80708CB090ACA0607CE070A
CF090AD10A0AD20B09D60D0DD60D0BDB0F0EDB110DDF130EDE120CE2120EE11612D91A1A
B71E2175121B9A6A72DFD0D7E7E5E8EDEFEEEAECEBEDEDEDECEBEBEEEAE6F7E7E1F8CDC2
DF8676C53B2BCF2A20AC221E53140DD1B9AEE8DFD7F2EFEDF0EDEDF0EDEEF5EAEAEDC4C4
B05B58A5524D9A726DEFDDDAF0E9E7EEEBEBEFEDEFECE6E7FAE0DEC0706CAC1E1BBF1618
B3191E84191F79434AD5C4C7E6E3E2E8E7E6EAEAEAE9E9E8EBE6E3F5DFD9DDA59EA43C38
A41312AE0A0DAE0509AB0307AA0207A80109A50209AB151BCC4C50D65F6382080A850004
8F01069200059001048701037D0001790001780101780102780102770201730001730101
7201007101007000007101027201037101036D01036802035E0101590101590103580003
5B01065D01066102076101056605096505095C0507641B11C6A59800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE9B6FBAAEA58C8D8DA5A0A27C6363470F13451014B69BA2BDB8BEB7BABEAFB5B4AFB1AF
B4B7B32723211C0A0C26050C2D01093E040E46040D49020A5905046B1600D0911FD5A609
D4A506D98D16A52300B60701C20806C50707CA0A0ACB090BCB090ACE090BCD090ACE080B
D10B0CD20A0CD40C0DD60C0DD80D0DDD1010DC110CDD110CE0140DE2120EE41310E51512
DF1A18CA212492171E77343DC1A6ABE0DCDDEDEDECEAEBECE9EBEAEAEAEAEEEDEBF5E9E3
F3CEC2E89686C13D30BB2A24610E08A98C84EBE0D9F1ECEAEFECEDECE9EAEFEAEBF7E6E6
F9D5D0FBD5D0F3DCD7F3E6E5F2ECECEDEAEDEDEBEDE8E4E5F5E3E2E4A4A2A52422BD1211
BF1111B1161A881B2169393AC9BDBAE8E4E0EAE7E8E8E6E7E8E7E7EBE6E4F3DEDBDCA39E
A0342EA30F0FA60205AE0508AE0508A80106A40107A1070DBE363DC5494E9D1B1E910409
9201069301069401078E01058400037A00017801017900017A0200750100730001740102
7201017101007202017301017301037001036B01026802035F0102590003560003550004
5500035900055D02075E00056102066105075E070763180FC5A29600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB986BBCAFA799999B8A87889E8A8A4314163F0B0BA4878AB9B3B5B8BABEBEC3C5C3C8C9
CBCFCE3D3B3D1E0B0F28070E2D02093F060D430309480108610B09691300CC8C1DD4A309
D5A307D98A18A62000B50802C30B08C40705CA0A09CA0808CC0909D00A0CC70305CD090A
D00B0CD10A0BD30B0CD60B0ED80C0DDC0E0FDA0F0BDB110BDE130CE21310E41412E71712
E81812E51B16D7201EAD21236C1B1F967A7AE1D9D7EBE8E7EBEAE9EAE9E9E9E8E7EDEAE8
EFE2DCF4CEC3DF877AB632297D16107C5552EBDEDBEDEAE7EBE9EAEBEAEBECECEEEEECEB
F0E9E6F1E9E6EFEBE8ECE8E9EEEBECEBE9EBECEBECEBE8E9F2E5E5F1C2C3A83939B61715
BA1410AF18149A252262231E786059DCD2CDEBE5E4E8E5E7E6E5E6E6E5E6EEE6E7F1D8D6
D5928E961F1BA50C0BAA0507AF070AAB0409A70308A4020A9E040D99050C9C060B980206
9200059502079701089602088D01068201037C00017C01017A0100760101740101760101
7301017101007301017401017501037301046E0104680203610103590103560103550102
5300025801045C01065F000563030863050860070767180FC9A59900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9667B5A89F9897968E8A8AA08F8F4B1F1F41090A8E6B6DBCB4B5B9BBBFC1C6C9C6CDD0
D2D7D95152551B0B1124050C2D060A38060A3F0307460004610A07691301C68619D29F08
D3A008D78515AA1F00BB0A05C40907C80908C80909CA0A09CD0909CF090ACE0909CD0809
CF0A0BD10B0CD10B0BD60C0DD90E0EDB0E0FDA0F0CDA110CDA120EDC1211DC120FE21610
E91A11E61710E11E15CE271FA12E2863312BBFAEA9E4DDDAEDEAE9EAE7E7E9E8E6EAE9E8
EBE6E4F4E2DDFAC1B6BF4941A0241F5B2220E7D6D3EDE8E6EAEAE8EBEBECECEDEDE7E5E5
F2EAEAF2E6E6F0E7E9EBE7E8EBEBEAECEBEBEDECEBEBE9EAEEE7E7F6D5D5B8615FA5201C
9A1A12811D14AA6358C3998FDCC7C0E6DCD7EAE5E4E9E6E9E5E4E6E8E7E8E7E4E5EDE2E2
EDC8C6AE57529B1511A30508A60308A60308A60107A40107A10107A00108A00108990106
9100049301069802089902089301068B01048300037D0100790001760101760000790202
7702027301007301017501027702057401046E01036701026100025B0004570103550103
5601045801045D030761020663030665040863070966160ECFAA9E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99262C2B5A99897939B97968F7F7E552928480B0B794F51C1B6B7BFBFC4C9CED1CDD1D5
D3D8DB7072741B0F12280B0F2B04083505093F02084F050A5E0908641100CB8B1ED4A10A
D4A008D68315AA1E02BD0B07C30606C9080CC90B0CCA0A0ACE0C0BD00B0CD10B0BD0090B
D10B0CD20B0DD30C0DD4090AD80E0DD80D0DD90F0FDA1312D61313D20D0DD00B06DE140D
E21912DA1C15C72519B03327C27165DCB6AFE9DCD6EBE4E1ECE9E8EDEAEAEBEAE8EAE7E7
EEE7E5F3E0DEFDC5C1C84E49BC2C275C0C0BBCA3A0EBE2DDEAE9E6EAEAEAE9E9E8E7E3E1
EAD5D5D1A5A9A6777C7D6164D6CBC9EFECE9EEECEBECEAEAE9E6E4F1DCD9CD8E8B862522
530602B4897EF1D7CDEFDFD9EBE1DEEAE5E3E7E5E5E6E5E6E5E4E7E3E1E3E4E1E4E5DDE0
EDD4D3BF7D778A120F9905089C02069F0107A10108A000079F01059E01079B0106960005
9000048F01049300059600069300068F01068801038100017C00027A01037A0103790103
7600017300017300017400037401057301046E01036900026401025E0103580004540004
5200045100045300055A01046103066303085F0407621107AE756000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99161C3B5A99F9D99858281A99C9C5E37364C0E0D64363AC7B8BBC6C7CCCCD0D4CFD3D8
D5DADE86878B1B1112280C0F2C050A34040B40030A53040B5705045B0F00CD8F1FD6A209
D7A30AD57F15AD1F01BF0C08C30607C9080CC7090BC80708CD0B0BCE0A0BD10B0CD20B0C
CD0707D20A0CD40C0ED60C0CD60C0CD70D0DD90E11D40D10D00D0ED00D0BD20C08DA140F
D51B17A81612A14036E9B1A6F8D8D1F1E5E1EFECE9EAE8E6EAEAE8E8E6E7EBE7E5EDE4E1
F2DBD9F7C7C7F09191CE3533CD28237A100F8A6763E8DBD6EEE9E6ECEBEAEEEDEBF1EAE9
F0D1D09C4B4F9C393D561415A88886EFE5E2EBE7E8E8E7E7E9E7E5F0E3DFE0B1AF7B3130
420F0BD9C8C0EBE3DDEBE5E3E7E5E5E7E6E7E4E4E5E2E2E3E1DFE0E1DCDCE3DCDCE4D5D5
DDBEBBB8726C840D0B9303059401059600059901079C0209990006990106980107960107
9100058F01059101049401059301059101058D02058601038001047A0002780102780102
7500007501027501027501047300047300047001016D0203660102610104590104560105
5400055001054F00055401055A01045D03065A0101620D0384351400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9060C0B1A69E9B98908D8DA2989A6A4648490E0E522226D2C1C5C9CAD0CDD3D8D2D8DE
D5DADE9C9CA11E1415280B0E2F080D35050C3E020A580A125B07085D1200CE9120D6A409
D7A109CD7411AE1C00BF0C06C40606C8090BC8070AC9060ACD0A0BCE090BD10B0CCF080A
CE0808D20A0BD30B0CD60C0ED50B0BD80D0ED70C0ED90F10D8110FD9110DDE1510D61411
B31413630C0BD9B0A8F3E2DBF0E6E5EDEAEAE8E8E8EAE8E8E8E8E6E6E3E3E3D6D5ECCAC8
F2ADADE07174D13839E02624DB231F9D19175E2B29E3D4CEEFEAE7EDEBEBEFEEECF2EBEB
FDE0DFBE6668AC3132791B1A7F4D4BEEE1DEEAE5E4E9E7E8ECEAEAF0E7E6F5D2D3995353
4B0F0CAA9590E5E2DEE7E6E6E8E7E7E7E6E8E5E4E5E3E0E1E1DBDADBCECBCEB6B0C79E97
BF7D7696312C8E0807950204950104930002950004950106940105940106930007930108
9201069001059001039301049503069001048A01048601058001047A0002780102770102
7500017300007400017601037702057501047201026C01026401025D01025A0103570104
5300044E01044C0004500106550004570103570101650D0286311100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BA905DC6B7AC969593A4A1A5897F84856769430D0D48161BC7B2B7CACAD1CFD7DDCDD6DD
D6DCE2B0B0B51F181A22080B2D060B33030B3700074600085806095D1100D09320D7A60A
DAA40DC76D11AD1900C00B05C50706C50709C70509C90609CC0808D10B0CCF090BCF070A
CF090AD40C0ED40C0CD60B0ED40A0AD80C0FD70D0DD90D0EDB0E0DDF120FE1140FD71613
A10F0E4A1313D8C7C1EFE8E6EBE8E8EDE9EAE9E7E8E9E8E6E8E7E5EBE6E3E4D3D0D19B9A
B94C4BD03130E42722EA211CE5221CC02323560D0ACAB7B2EAE6E2EEEBEAEDECEAF1ECEB
FAE5E4D08585A82E2E96292862211FE3D1CEEEEAE8EBEAEAEBEAEAECE7E9F7DDDFBD7876
7F27265C2827CFC1C1E8E7E5E5E5E5E7E4E7E1DDE1E1DCDDE2D8D8CBB5B0AD8074913F34
8B1C158E0907950303990102990103970203940003920004920005910006910108900108
8F01078F01059001049000039001048C01048600038200028100028A0A0C840C0D730101
7402027401027401037300027801057902067501046C01036300025D00015A0002590003
5400034E01044900024D0004580207580206550001620A028A341600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78D59C3B5A8A5A6A589898E9E989C836B6B411211420D11B79EA4CCCAD0D0D7DBCCD5DA
D7DCE2BFC1C5201D1F240C102E070D33040C33010640010858090B651700D49722D7A608
DCA40FC56712AD1701C10C07C40607C60609C80508CA0608CB0808CE0A0BCE070BCE070A
D00A0BD20C0BCD0705D40B0AD50C0BDA0E10D80E0DDA0E0EDD0E0EE1100EE41412DD1512
B71613520203A7908FE9E2E2ECE9EAECE8E9E8E6E7EBE8E8E6E5E3EAE7E4EFE3E1F1CBC9
E28E88CE473DDD2E20E8241AE7221AD428256B0B0A9D837EEAE4DFEEEAE8EBEAE8EEE9E7
F5E6E3E7AFAC9E352EA3352E6C221ABFA79FECE6E2EAE9E8EBEBEBEAE7E8F5E4E4E8ADAB
9B302E7B1819733E42CDBBBDE6DFE0E3DEDEDFD9DCDDD8DAE0D8D7E1D0CBCDA295A04D3E
8D12099304029701019902039701029501029201029101039201069302089201098F0009
8E01088E00059101048F01048F0106890004840003890002980407B11E21D14B4EBE4647
7A0A097101037001027101007A0304870B0F7600036C00026700026201035E00035B0104
5401034D01014900014D0003550207590208550002610801903A1F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B58D57C3B7AAA2A5A4909497979697806F6F3E14143D080C987D83D2CFD5D0D6DAD2D9DF
D5DCE0C6CACE282628220B102C060E36050F3502083C0109570A0B691C00D79924D8A90A
DCA410C06010AF1601C10A08C30708C60609C9070AC90608CB0909CD090BCE090CCE080A
D20C0CD20C0AD10C07D50E0AD80E0CDA0E0EDB110EDC100CDF120EE31210E31310DF1310
D218159710115F1A1EC4ABB0E7E0E3EBE8EAE7E5E6E8E6E7E7E5E5E8E7E6EAE6E5F0E5E2
FCDDD7F2AFA4D66152D73226E1251BD524208B16176F4743EADDD9EDE8E6EDEAE9EDEAE8
F1E8E6F2D2CCC17F73C07468AA7164BFA69CECE4DEEBE8E7E7E8E8EBEBEBF3E9E9F8CCCB
A73F3AA71E1D86161B74353CC7ADB1DFD5D5DFD8D8DBD6D7DBD7D7E0D6D5E6D0CAD6A598
A850428C0F079404029601029501029201028F00018E000290010390000691000891000A
9202099101069101058E01048D01068802078400039A0207AD050CAF060BA5080AAB1A1E
AA272C7300017000027201027A02038E11157601046E00036B0204670103630204600307
5602054F01034A01024B00035100065600075A01026408018F361D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18954CABFB2A1A6A59EA4A6808181A193934824263B090B765A5DD4CED4CCD0D5CDD4DA
D5DDE0CCD1D52A2A2D1E090F28030B35030F37040C3A01074B0506621800D29823D4A608
DCA513BD590DAF1400BF0907C4070AC30408C50608C60506C80708CB0709CD090AD00A0A
D00C0AD10B0AD10C08D40D0AD70D0CD80C0CDB0F0CDD100BDB100AD80B08DF110EE21212
DD1212D01919A014196B1720AD868EE0D3D9E7E3E6EAE8E9E9E9E9E9E7E8E9E9E7ECEAEA
EFEAE7F7E3E0FBC6BDDE736ACE2F27CC1E1BA21D1E4F1717D9CBC6ECE6E3ECEBE9ECEBE9
EEEAE7EDE2DEF6DED9F9DDD7F7E0D9EDE1D9ECE6E2ECEAEAEDECEDEAE9EAEDE6E6F4D4D3
BD625FB21B19B4151A8D131A651F25AD9194D7CDCCDCD8D6D8D5D5DCD8D8DED5D4E7D3CE
D7AB9DA852458D120B9303039100029000039001048E01038E01048F0106910108910108
9301099302089102058C00038802047F02048000029D0408B10208B40406AE0203A90307
9F050A8401037400027602057D07098F161A7300046E01056C01046701026201025C0003
5501044F00034900024800024F01055502055A00026407018A2E1500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18651CFC2B5B6BABA8B9394999B9C8C83834D2F2E3C0A0A694B4BD8D1D5D3D7DBCAD1D7
D5DCE0D5DADD393B3F1C0A102A040E33020C3702093D0105520706641A00CF9825D1A40A
DAA114B8500AB01300BC0604C4070BC30409C40608C5070AC80708CD090BCF0B0CD00B0A
CF0C0AD10C0BCF0A08D20A0BD40B0CD70C0CDB0F0DDD100BDA0F09DD120CDF120EDD0D0D
E11111E01315D71919B91C207C111A864A56D0B8C1E1DBDDE6E4E4ECEAEBEBEBE9E8E7E8
ECECEBECEBE9F6E7E4FECBC5CB5C57BF211EB42121590A09B9A09CEDE5E2ECEBE8EBEAE8
EEECEAE8E6E3E9E5E4E9E4E4ECE8E6EDE8E6EFEDEBECEBEAE9E7E8E7E5E7EBE7E6F2DCDB
DC9390AB1F1EBF1214B20E149212195D1217957776D3CBC6D9D7D3DAD7D5DAD6D6DCD4D2
E5D2CBD7AAA0A44D448C0D0B9102049202059101058E00038C00038D01058F0106900006
9201089302098F01058A0103840205750102760001980409AF0309B10104AE0002AC0102
A802059403057C00017601047E0A0C9B282A7101046E01046D01046601025F01015B0102
5401025101044C02054701024A0103500104550001640802862C1100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8DAD49D3C3B7AFB2B1969B9E989B9B8881804B2F2D400C0D603C3EDDD3D8D6DAE1D5DCE3
D1D6DDD5DADF4042471D0A122F081037040E40030C4E070C600F0C681B00D39A26D2A50C
DB9F15B24708B21202BE0706BE0407C4060AC50709C4050AC70608CC090ACC090ACD090A
CE0B0ACF0A0BD00C0CD40C0DD50D0ED70D0DDA100ED90D0BDB0F0CDE120DDE110CE11110
E11110E31212E1130FDD1817CD1F229D17206E1D28A38083D8CDCCECEAE7EAEAE6ECEBE8
EBECE8ECECEBEDEAE7F9E2DFECA5A2B62B27C52423871110935957F3DDD9F0E7E4EBE6E5
ECE9E8F0EBEAECE8E6EFE9E8EFE9E8F1EAEAF0E9EAEEE8E8EFEAEBEEEAEAEAE5E6F5E6E4
F7C4C2A8312FB70E11C20E13B60F15941115570B0B81625FCDC4C1DCD8D4D9D5D4DBD6D5
DFD5D6E7D2D1CC9B9592302B8B05059201049101048E02048C01048B00028C01028E0103
9102079001098B00058700048302056F0103690001890308AA060CB00307AC0001AA0101
A902039B03048100027902057801047702047301036F01036D01036701026000015A0102
5501035101044C01044801034600024A000256000165060281260C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B68853D2C1B6A7A9AAABB1B58A8D8F9A95966147483F0A0D542A2DDACCD1D6DAE3D6DEE7
D1D8E0D5D8E14D4F551E0A132C040D39050E43050D4F060D510302681D00D49B22D2A308
DCA017AD4006B21103C00908C00609C2070AC30607C3050AC50609C9080ACD0B0CCC0809
CC0A0ACF0B0DD00A0BD10909D40C0DD50B0CD40B0AD80C0CDC0F0FDE0F0EE11211E2110F
E2120EE61411E71712E61612E31916D91C1EBB1F227A1517875858D9CBC9E9E6DFEDEAE5
EBEBE6EBEAE8EEECEAF8E9E8F6C0BFB43532CC241FBB221EA93E3AFDC2C1FCD8D8FAD7DA
F8D6D9F9D6D9F9D3D6FBD4D6FAD2D5FAD5DAF9D2D7F9D1D7F8D4D8EFCDD2F3D4D8F6D2D5
FFC8C9BD4849BA1315C20D11BB0A0EAC090E8F0D11580A0C795959C8BDBBDDD5D4DDD8D8
DBD5D8DFD6D7E1C8C4AC6661810B089003068F01038D01038C01038A01018A01018A0001
8C01028B010687000487010483020572020560000072010395050AA30306A60202A80203
A802059A03067F01037300047902087801057300047000036C0002660103610203590001
5501035101054A01034600014300014900015E02046F060384230C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CD37D2C3B6C0C3C59BA3A79FA4A78C888A6952523E0B0E491B21D9C7CED7D9E0D2DAE1
CED8DED4DAE1575A611F0E172A060E3302093A010A44010B4C04036D2502D49C20D6A509
DCA017A73700B21003BD0805BF0607C00609C20508BD0207BE0206C8080CCB090ACB0709
C90609CB0709CE080AD00809D30B0BD30A0CD40C0BD80C0BDB0F0DDA0C0EDE0E0FE31111
E61510E91611E7160FE81711E81713E61714E21C19CC252386171966393BD4C8C4ECE7E3
EAEAE7ECEAEBEDE9E9F5E4E4F0B7B8B83636C41E1ABC2B26C7544EBD605EC46B6EC36169
CD636ACE6067C85B60C15258BD4F55CA5D63CB5D65C65C63C35E66B95B63B96168C66C6F
D76C6DC53937BF1412BF0B0CB7050AB00308A6080D88101544050679635FD1C6C5DED5D7
DBD5D8D9D4D4E2D2CEBF8A837E14108D03059001048E02048C01028A01018A01018A0101
8800018801028601038500028201027602045D00015D01017501038701039403049B0304
9C04078A02057000016C01047802077B01067901077401046E01016700016100025B0001
5300015101044D02044801024500014B000162010473040386210B46990400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DCA34D1C3B7BFC3C69EA6AA9EA4A7848485725F5E3F0F11411116CFBCC0D4D7DBCED7DD
D0DBDFD5DCE25E636A190B1425050C31030A39030E43020C500805722A08DBA225D6A509
DE9C18A83300B20C01BD0808BD0506BE0307C3060ABF050AC1050AC50408CB090ACA070B
CA060ACC080BCE0A0CCE0809D30B0BD60C0EDA100FDB0F0DDA0F0BDC0D0CE11011E5110F
E5130FE5130CE7170DEB1811E71611E61510E91B13E11D19BC2525550D0CAB9792EDE4E1
EAE8E7ECE8E8F1E7E8FADADED9878CB8262ABD1D1B820D0CEDAAA3ECADA4D17F79C05553
BE4140BC3737B83231B52F2DB5312EB3322DB23432AA322FA333329E35359D3737AB413E
B13932B32920B91D15BA140FAF0807AD0608A404088E0A0D5607054B2922BFAEA7E1D6D7
DCD6D8DCD6D6E1D3CEBE8F867F18138F03069101038E01028D01028D02028C01028B0101
8902018701018600018500018400017D02036501015200005A00006A00017601037D0003
7E01057001045D00026400027901067F01057F01067901047101006C0002690104600202
5801025101034D00024901034701014F0000670305740402801A0544960200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CC37D8CABFB5B9BBB2BBBE848D8F929394877878401213430E13BCA8ACD0D4D6D0D9DF
D0D9DFD4DAE07074791B0E1724050B31030B38020A3F01074E0603772F0BDCA222D9A50A
E09919A82B00B50D02BF0808BE0608C1070AC30709C3050BC20409C8060AC9060ACA070B
CA060BCC080BCE0A0CD10A0CD30C0BD70D0CD70D0BDB100CDC110CDE110EE00F0DE5130F
E61410E71610E5140EE91610E81711E5140EE4180ED81A16A618157A342DDDC2BBF1E3E1
EEE1E2F2DEE0F6D1D3F3AAB0C04348C41C1FC61C1B941416894B49F9D9D5FDE2DBFFD5CF
F9BDB6EDA7A1D88E85D1867CCE867BD18C83DF9D95E5A8A1E8B1ABEEBCB5EEBCB6F8C3BB
F6B8ACDF9284D6786BB64338A31D15A5120E9C07077D0304590D07906755D1B9ADE4D4D0
E1D6D4E4D6D4D9BDB8AC6C647F0D099202039501039101028E01028C00018E01018C0001
8A01018701008601008600018601018402037D0A096409075608077223225E0B0B5D0104
5D01045700035200016301037B02068201058402078001057701027101016B0103640203
5D01035401024D02034701024301014F00016A03047302017C160246970300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D9CDC3BFC4C5A1ABAD959E9F8486867F7271441819481015B0969CD7D8DDCFD7E0
CFD7DFD7DBE27D8086190C1326050C2D02073805093D03074A0702813A12DCA221D7A308
DA8E17A82500B80D03C1090AC00509C4060BC5070AC7060BC60508C70508C9070AC80609
C9070DC9060ACD090BD0080AD30A0AD70C0CD80E0BD80D09DA110ADB100ADD100AE1120E
E3140EE81811E5140EE6130EEA1611E91710E81B14CB14119E1C1BE9A19EF8C5C1F9CACC
FAC3C8E99EA4D26C71C0373CC72020D11717D01715C11D1E87181CAD777CF1DCDCF6EAE7
F6EAE6F6E6E3F6E5DFF3E2DBF9E9E1F6E7E1F5E6E2F5E8E5F0E6E3F1E7E5EFE7E3EEE6E1
F0E6DFF4E1D9F7D7CFEEBDB4D1877EA94039991B17800906AB5247D09181CE9D91CBA19C
CBA3A0C89895BC7B7594302C8C06049301019401029101018E01018E01009001008E0101
8C01018801008701008600018601018601018205039B37306C211CD69A97CD92935C1818
4E00025200015C00016F02047D01058302068601068702077F02057401026C0102650001
5E01025500024F02034500013F00005000026E04067403017D150245950200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D8CCC2C6CCCDACB6B89DA5A7787C7B908684563232440D119F7F87DAD6DFD1D7E2
CED7E0D6DBE486898F1A0B1326050C2D02093301064003075107028C4312D99F1ADAA40A
D68416A71E00BC0E06C20809C3060BC7050DC6060CC8060BC70608C80708C80707C7060A
C7060BC80509CD080AD0090AD50C0CD60B0BD60C0AD90F0BDB0F0ADC100ADE110AE2120E
E4150FE5150FE6160FE7150EEA1712EB1713EA1B15DA1917E24748EF7678E76B6FDA5B62
C33D47BC2631C92228CF1A1BD61715D71414D51413D11516C31E23951E28AC6970EDCED2
F3E5E7EEE8E8EDEAE8EBE7E7EDEAE9EDEBEBEBEAE8EDEBEAEBEAEBEAE9E9ECEAEBECEAEA
EAE9E7EBE9E6E9E3E1E7D9D7EED4CFE8B7B0BB69628E211B971F1BA0302CA33B3AA64343
A441419B31318E16168E08079603049601029401029100009101009102018F02018C0102
8B01018A0100870000860101870101860101820202851613AA534E85423D995C596D2525
5F06076802057502077E02068201058B050A8E050B8B01088502067800027001026A0001
6201015901025101034801024200015401017104067401017F150547950300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8AAA45DACEC4BEC5C7C2CCD1838E90888F8F9894924C2E2C440D108E6972DDD6E0CFD5E0
CED8E1D3D9E38F8F981D0D182B071030020B3401073F0206580F058E4612DAA31BDCA30E
CF7712AA1B03BA0C07BF070AC20509C5050CC6050BC9060CC70508CA0708CA0809C9060A
C70609C90708CC0809D20C0DD1090AD50B0CD90D0CDB0E0BDD100BE2130FE3130DE71611
E51510E71611E1120DE5140FE7170FEB1812EB1A13E71814DF1D1BDE2323DE2325DB2026
CC1118D1131AD71718D61213D61312D51313D51314D71416D7181BCD2025AE222BA13F48
CA8890EFC1CAF7D8DEF7DEE3F9E4E9F8E5E8F6E3E6F7E1E5F9E3E9F8E3E7F4DDE2F6DCE0
F7DDDFF4DADEEAD4D7E2D1D3E2D4D3EAD8D6ECC5BFC0736E9019179C0C0F9E070D9B060B
9E080D9C06099A03069801039801029701029601029300019301029201018F01018A0002
8A01018B02028802018600028702038701048601048104078212139C3C39A34846A34140
9727287F04088301078601068901068E030A91040C8E02088801067E01057501036D0102
6401015901015300034B01024800005D01027502047702028014064D9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B0814ED7C8C0C3C8CDA9B4B98B999B8992948483825E42424911127F585FDED6DFCED1DB
D0D8E1D2D8E191939C1B0C172A050F31020B35030A3A01054504008C5017D8A51BDBA30F
C66A11AB1903B90B08BC0509C00609C4060CC6060CC7040AC80609CB0709CB0909CB0909
CA0909CE0B0DCF0A0BD10A0CD40C0ED4090CD90C0EE01011DF100CE0100BE3110DE5140F
E51510E51410E00F0DE71511E8170FE7160FE91810E91813E71612E81816E31715DA1212
D40E10D30F11D91516D20F10D31011D71515D31112D51213D91615DA1919D41C1ECA2126
B8262EB43844BB535DC96B77DE8791E897A0DA8691DC8693E38998DD8491DC7F8CD97B86
CB6A74C76A73C57279B06D73B27F84C5A0A2E1C3C2EBBFB9A54C46950B0AA60309A60107
A40006A100049F00049C01039A01039700029601029600029400039401039200048D0101
8C01038A01028701018600028601038600038700048600068201077E04077E0507840609
8603088802088A02098C020891040B95070E94060B9003088A01078101057801046E0102
6501015C01015501014D01015000006701027B03057D03047F12064C9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5EC935D6C6BDCDD0D5ABB5BAA1AFAF7E87887B7B7E84696C47101371474EDDD3DCCED1DB
CED3DCCED5DD8D9298160A1426060D32030C37010B44060D490A039A601AD6A516DEA412
BF5E0FAD1604B90807BC0508C1070AC3060BC20409C7070CC8070ACB090ACB0909CD0908
CE0A08CF0909D10A0AD2090AD60D0DD70B0DDB0D11DF0F10E0110EDF100CE1110CE61512
E2120EE2100FE41211EA1613E5140FE81711E6150FE91813E81713E61815DB110ED10D0B
D00D0DD4110FD51311D31111D41313D41211D71514D81312DC1814DB1513DE1A17DE1B1A
DB1C1FD11C20CE2126CC2329CB272DC6252EBF1E2AC3212EC21E2CC41F2DC31F2BC11B25
C21C22BD1B20B2181E9F141B8E131D7E1B2489464AC89694D58E868E1510A00406A40003
A20102A00003A001049E00049B00049A0105960003960104970106970107930003900102
8F00038F01058B01048700028500018501028701048601058601078501068700058C0208
8E02098E020991050B91030A91020A95030B96050C8F01078A0107820005790003700102
6601015D01015702015201015901016E02037D01037E03037B0D034D9C0C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC733D9C9C0C6C8CDBFC8CD8B9799858E90929296654E524B141864353DDBCDD5CCD2DA
C8D1D9CCD5DD90979E18101729081034030D39020D3B0105480A01A36A1BD8A414DEA114
B64F0AB11503BC0807BD0407BE0408C2050AC20509C20308C30408CA090CCC0A0AD00A0B
D00A0BD20A0AD50D0CD50C0AD90F0CDC100EDC0F10DE0F0FDD100DE0100EDE100EE11111
DE110EE51311E71512E61510E71611E4130FE3140EEA1711E91814E41614D70F0FD00D0C
D00E0CD10F0ED71513D31111D21110D51311D81511DC1614DD1713DE1716DD1715DF1917
DC1916DD1916DD1A16DB1614DA1717D81719CF0F14D21217D31115D7151AD31114D31214
D11113CE1012C30C0FB4070CAE0710A00811890C13761417C36461A42624A10408A50106
A101029D00029E01039F01049D01069C01089A0106990105990106970006940003930103
9100039101048D01048901028802028601028601038500048601058701058800038C0005
90010890010890020A8D010792030C96030D99070F93030B8B01088401067D0204740101
6901015E00015801015700006502027503037D00027D0203780B0149980800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC832D6C4BBC7CACFAFB8BD8E999C8E989A888A8D7C696C43101358282ED7C9CEC9D0D6
C3D1D5C9D3DA9AA1A61B111826070E33040C37020A390205400701AB7318DAA714DF9F16
AC3F04B51303BE0A07BD0307BD0408C3060CC4060BC5050CC6060BC60408CA0809CE0809
D10B0CD1090AD30C0AD60E09D80F08D70C07D90F0BDA0D0BDE110EDD0E0EDB0D0DE11111
E41412E41310E4140FE61511E71712E71713E61612E91813E51612DB0F0FD40C0ED10C0E
D40F0FD20D0ED41110D10F0FD00E0FD61414DA1714DE1816DE1816DC1514DB1615DE1818
DF1B1AE01A18DD1914DE1815DD1816D41211D41212D61413D71414D71314D21011D20F10
D10E0FD10F12C3090EB8070DB0040AAC0208A5040999070B960B0EA30E11A30207A50106
A101049E01039F0104A001059F01089D01099C02089A01079A0106990106960004920104
9100049100058F01058B01038A01038801028600018501028500018601028701038B0105
9101089101098F020A8B01088F030B95040D96040C94040C8C01088401057E0103770103
6E02036201025900005D00016D01017801037F01047F03057A09006B600A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59C42CD8C7BACCCFD3B2B9BFA5ADB17F888A8083859A8B8E3F13154B1C21CEC1C3C7CED3
BFCDCFC8D2D69DA3A71A121727090E2E030838040B3D050A450B01BC841ED9A510E29E1D
A83400B71104BE0808C00609C00709C4070CC50509C60308CA070BCA0709CD090AD10A0C
D20B0DD50B0ED50D0BD70D0AD70D08DB0F0DD70C0BD70B0CD90C0DDC0E10DC0E0FE41213
E41312E51313E2110FE61413E61511E71413E71512E51413DD100FD30A0AD30D0ED40C0F
D60F10D40E0FD71313D00F10CE1010D31113D71415D91415DA1515DB1515D91614DD1717
DD1717DC1615DB1513DD1716DE1817D61111D61314D81514D91415D61213D10E10CF0C0E
D00C10CF0E14C1080FB4030BAE0108AC0107AA0106A50106A50208A30007A50108A40107
A30106A10106A001069F02069D01069C01069B01079C03089A0107990106970106920105
9000049001069002078F02058D01028700018500018400018400018400018600038B0106
91020991010A90010B90040D91040B94030B94020995040C8D03098400057D0004780003
7001036702036101026801027201017801017E02037E0204780700902D0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C22ADAC9BCBFC1C7C5CCD58F979C7A82849497987B6D6F3B1214431317B9A7A9B4BBBF
B4C0C2C6CFD19EA4A81B141926070D2F030937040B3C0508470D00C28A20D9A410DF961D
A42900B70F06BD080AC2080CC3070AC40608C70606CA080ACD090ACD0A0AD00D0BD0090C
D20A0CD60B0ED70D0ED70B0CD70C0BD90D0FD80C0DD60A0DD80C0DDA0D10DC0E11DF0E10
E31111E41213E31110E20F0FE51410E81411E61412E41314DA0F0FD60F0FD81111D80E11
DA1214D50F10D61314CF0F0FCE100FD01111D31313D41313D71415D81415DA1716DC1816
DD1715DC1715DA1714D81412DD1917D71413D81515D71414D41112D20F10D10D0FD31012
D10D11C9090FBC040BB10208AD0107AB0106AD0309A80109A9030BA6010AA5010AA30008
A10108A3020AA101079F02069B00039A00039A01049A0105980004980003970103940104
9100049101058F01059101059002038B02018601018400028401028401028500038A0106
8F000891010A93030C95040E96050D95040A94040A93050B8C02098500078101077B0106
7200046A00036A00027602047901027701017A01017C02037407008F321500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC32CD8C5BBC5C8CFB3BDC48A95988C94967E838584797B3B13153F1013A99698B3B6BB
B6BFC2C9D1D4A0A7AC1810182C091331010B3703093902054A1300CA9525D8A50FD78A17
A62303B90F0ABE070BC1060CC5080DC30506C70807CD0B0CC90608CB0808CF0C0ACF0B0C
CF070AD50C0FD60C0FD3090CD50B0DD60A0DDA0E10DB0D0FDA0E0DDB0F0FDC1010DF0F10
E21010E21011E2110FE61313E81511EC1914E61612DF1210D80F10D81112D60F0FDA1314
D60F11D00C0FD10F10CF100FD11312D31514CE1110D11312D41415D21214D41514D51814
D71D1AD1201BCD251CCC241ECE251FCD221ECD1F1DD11E1CD31817D31313D51112D71112
D71114CE0C11C1080EB40209AF0208AC0107AB0209A9010AA8020BA50108A20107A30107
A10107A00007A10207A102079E01049C01039B01049A0105980104980103980204940104
9200049000068F01069000059001038B0101860000850001860102850102870004890006
8E010992020B92010B93020B93020A96050D94040B93050C8B01088700088100087E0108
7600057200037A00058401068201047800017801017802037007008F361700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BF29D0BEB3CBCED5ACB5BA9CA7A9777F826C7072A59C9E3E1C1E380B10A59295B8BABF
BCC5C7CDD6D9A2AAAE16101828071231030C35020A3601044B1800CE9E26D8A711CF7D15
A41B02BA0D0ABF070BC0060AC5080BC20406C20403C70507C9060ACD090CCE0B0CD00C0C
D20B0DD20A0DD20A0DD30B0DD30C0DD50A0DD80D10DB0E0FDA0E0DD90D0CDA0E0DDF110F
E1120DE41311E2130FE81612EA1611EC1A14E31711D80E0DD20C0BD30E0ED3100ED71213
CF0D0FCC0C10CE1011CD1012CD1010D11315C90E0ECD1212D01717C81516C41C19C0261E
B22A22AB362FBA554DCE6D65E5847CE6817AE47872DB635FCA3F3CC52420D01A18D81716
D31011D21012C80C11B9040AB10209AC0209A80107A60006A70106A50105A30105A40105
A101049F01039F01059F01059F00049E01059C01049B01059901049500029101058D0206
8F02079002068F00058F01048D01018A01008700018601028701028801048902068A0106
8E010992010A92010B92020B92020A94040C92020A8E020A8701078400088101087D0107
7701047A00038A02089403088C01037D00007800017803036E040092381A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C028CEBDB1C4C7CEC1CBD1929E9F727C7C969B9B7C75773D1E2031060B9C8B8FBBBDC1
C4CDCFCDD7D9A0AAAC1411161F070C29030A300208370706502103D0A126DCA918C26D15
A11601B90A08C00809C2070AC30608C90A0CC60808C70609CC0A0CCE0A0CCF0B0CD10A0C
CF090AD30B0DD10A0BD60D0CD50C0CD60B0DD90E10D80B0BDB0F0DDB0F0DDA0E0BDD100D
DE120CE2140FE51610EB1812E91812E1140FD80F0AD20C0AD00D0AD20E0DCF0D0DD41213
CC0C0FC90C10CA1011C90D10C90F0FCE1414C61112C01816BC201CAB241F9E332CAE5D53
DA9E95F3C8C2FCDCD7FBE1DCF9E1DDFCE1DDFDDFDCFED8D6FCC3BEE88E89C2403BC41F1A
D01514CF0F10CD0E13C0080DB5060CAC030AA80209A80208A70105A40104A20104A30105
9F01029F01039E01049D00049E01049C01059B01049B01039900039401038700047B0002
7F01048B03078E02058F01048D00028B01018700018701028600028901048A01058B0107
8E020992020A94030C92030B94070E93040C94050E8D030B8600068301067E00067A0104
79010285010497030A9C01089501038701017B00017702036F040090331800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C027D2C2B3C6CBD0C5D0D88B999B8E9898868E8D7671713E2022370B0EA18B8FC7C9CE
CCD4D7CDD7D9A0AAAC1515181A060B2703092C03082D0202532605D2A225DDA61AB65C11
A51404BC0C0ABF0708C10609C50709C9080BC80A0BCB080CCD0A0BCE070ACD0809CF070A
CF090AD20A0CD60E0ED60C0AD60B0CDA0C0EDB0F0FDC0F0BDE110CDE110DDF120DDC0F0C
E0130EE41811E71812E71410E51712DB100ED50E0BD10E0CD3100CD81412D41112D00F11
CB0D0FC90C0FCC1213CB1213C81312C51715BD1D1AAC231E9022199C4A42DAA59DF7D7CF
F6E5DFF1E6E3EFEAE7EEEAE9EAEAE8ECEBE9EDE9E8ECE5E5F5E6E4FFDCD8F5ABA5BC3E38
C71E1BCF1414CC0C12C3080EB6050CAA0107A70108A70108A60007A20103A000039F0004
9F00049C00039D01059D01049C01049B00059800029800029A0002940003890105780001
7300008301058C01068E01048E01038C01018800008600028700038901048900048C0107
8E010791010995050C8F020891060D91050D9407108D030B8600068200057E0105790002
7C00008F02069D0208A102079C03068E01047E01027602026C03008C2F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55C025D1BFAFC7CCD1ABB7BE95A3A68D99986771709795954224253E0E11A68D91CECFD4
CDD6DACDD4DBA0A9AC1211151A03092B040B2C02062B030162340ED29F21E1A61DAE4E0C
AA1303BD0B0CBF080AC10609C5070BC5050AC40608C9070ACD0A0BCD0708CE0809D1090B
D20C0CD30B0BD20B0CD60B0CD90D0DDB0D0FDC0E0EDF0F0CE3140FE3120EE3130FE21210
E3140FE61711E71712E71511E31510D9100FD40E0DD6100FD50F0DDA1516D41211D21111
CF1111CE1213CE1616C71615BE1C18AF211D9A27209F4B44C89187E8C6BFF1DFDAECE3E0
EAE6E4ECE8E8ECEBEAEAE9E8EAEAEAEBEAEBEBE9EAE9E7E8ECE9E8F0E7E5FADCD8DE908B
B5302BC81919CB0E13C60B11B9050DAF040BA60007A50007A60108A20105A001059D0104
9C01049A00049A00059C02069D03069900039800029900029C0204990104930205870306
7A00028302068D01078F01058E01038D02028A02038902048901048C01038B00038D0105
90010792010892020892030A8D020992060D92060E8D030A8701078402087F01067C0003
8601059A050AA10207A50308A00408910306800103730102680200862A1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C127CCBAA9C9CED2B3BDC59AA8AD768485798484888989452A2B3E0D10A4878BD2D2D7
CCD5DBC6CFD79AA1A7140E1422080D30040D34050C310402784816D5A21EDF9F1BAB4004
B01206BC0A0DBF080AC2080BC4070BC20609BD0205C5060ACB0809D10B0CCF090AD20A0D
D30B0ED60C0CD80E0ED90D0EDA0F0FDB0E0FDD0F0FE1100EE41410E4130FE51410E10F0E
E4130FE51410E61611E51511DF1411D50D0ED30D0ED71212D51211D61213D41310D11312
CE1513CB1A19BD1D19AA241D972E26A1564ED1A29AEDD3CCF2E5E0EAE4E3E9E8E7EAE9EA
E7E7E9E8E8E9E6E7E8E1E1E3E7E8E9E7E8E9EBEBEDEBEBEDECECEDECECEBEDE7E5F2D4D0
E49793B62829C61317C80D13BC070EB1060CAA040BA50108A7040AA30208A001059B0002
9A00029800039701069900059801039701039902049B02059B01039B0105990206910205
8701038801048F01059001048E01028B01018B01028B00048B00048A01048A01058C0106
90010792020893020995040B90020993060C92060C8D030A8901088300077F0106800004
92020AA2040CA20209A402099C02058E01048201037101026301007E250E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C026C6B4A3C6CACECCD4DC859398808E907985856C6F704D3434400E129F8186D2CED5
CDD3DACDD4DD9A9FA5170F1623080E2B030B2F030B2F02028C5C1ED6A41BDA981AA32F00
B10F06B80508BE070BC00609C00607C0070ABB0302C5080ACC0A0BCD090AD00B0CD40B0E
D60B0FD70D0DD70D0BD80C0BD90F0CDA0D0CDB100DDF100DE3130FE31110E51410E61312
E61511E3120FE41611DF140ED70F0CD30E0FD00C0ED20F11D41212D21211CE1711C21A14
B8221DA92B23A03F36B7766CDEB7AFF0DBD4F2E8E3ECE7E6E9E8E8E7E6E8EBECEEEBECEE
E8E9EBE9EAECECEDF0E8E8EAEBECEEEAEBEEECECF1ECEBEFEDEDEFEEEEEEECEDECF1EAEA
FBD6D6BF5C5DBB1C1DC71012C10C0FB3050AAA020AA70308A60208A50108A000059C0104
9B01049A01049700049700059A0105980004970105970104980003990005990106950106
9301049302069201059001048D01028900008901028C0105890104860002860003890006
8C000790010892010996030B96040996060A94060B8F040B8901098100067F0005880106
9C040DA3050E9D00089C02089602058A000281000273010264010081250F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C025C8B4A2C1C5C9BAC4CC9EACB0909EA05A67669397974F39393E0F148D6F76D3CED5
CAD0D6CED5DD9A9DA21C111822070E2702092C0307330704976A1DD7A61BD38E1B972000
B10C08B70307BD060ABF0708C00607C10609C10607C40608CA090ACD090AD20C0DD30B0E
D50D0FD70D0FD40D0BD80F0DDB110DDA0E0DDB100CDF120FE2120EE3120EE51511E3140F
E3140FE2130FE21913D40F0BCF0D0BD01010CE1010CC1311C91713C6231BB2271DA53A31
B2645BDBA59DEACCC3EFDED8EDE4E0EAE6E5E6E6E6E5E4E5E6E7E6E8E7E7E8E7E7EAE8E9
EAE9E9EAE8EBE5E7E9E5E5E7EAEAEBECECEDEDEDEFE5E5E7EAEBEDEBECEEEAECEEEEEDEE
F5E4E5EEB0B0B02D2CC31414C30D0EB50609B0060BA70308A70409A50308A101069D0105
9B01039A0103990105980106980106970004950003930104960106970106960106930104
9401049402059301059102078F01068C01048C01048B0004880003870102870102870104
8800048C010791020994020A95030A96050C95050C90030A8B020A850006880106940106
9F030A9B040B8E02088B01058F02068C01048302027301016701007F200A21CA0200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD22C8B3A1C3C7CBBBC5CEA8B5BB7A8588818C8D9296984F3D3F3A0F157B5F66D5D1D5
CCD2D7D0D7DE91969B170F1423080E28030B31040A3A0702AB791ED7A51BC278159B1B01
B20C09BE080DC0070CC0060BC3060AC40409C50709C8070ACA0809CD090BCF090AD20A0C
D30D0ED40D0FD31010D91716D81211DB1011DB0F0DDF120FE1140FE0130FDB1811D61B14
D81C14DC1D15D51A13CC140FC81610C61B16C3241DB4251CAF3328BE5B51D7948AF1CCC5
F6E2DCF3E7E3EAE6E3E8E7E5E7E7E5E7E5E6E7E3E7EAE6E8E8E5E6E8DFE2EDDDE2EDD5D9
E8C9D0B595A0B2A1AAD4D0D6E2E2E4EBEBECEBEBEDECEBEFECECEFEAECEEE9EBEDEFEFF0
EFE8E7FBD6D5B95353B61616BF0C0EB9080BB3060BAD060CA50208A50309A20107A10109
9D01059B01039A0103990103990105950105940105910003920003920005930006920105
9100049201069000058E01058D01068D01098C01068B0004890103880102850001850002
8901058C000790020992020994030A96050C97070D8F02098A00078B000795010A9F010A
A0030B8D01077700038914178504088B04088202037501016A01007C1D0843950300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59BF24C3AE9DC7CDD0C5D1D998A5AB8A949891989B6F7174564448350B1483686FD3CFD4
CBD4D6D3DCE1889193110D1220070F27020B2B0205431102BD8A21D8A31AB35F11A21602
B40909BC060BC0060BC4070CC5060BC4050AC50709CA090CCC080BCC090BCE070AD20C0D
D20D0DCC0A0BC90F0EE62E2FCA090CD90F12DC0E0EDF120EDE1310CD0F0DBC1F19E96E66
D35A4FCA4B40C74639C6463DC85348CC665BD57D73E7A399F4C4BCFAD9D4F7E6E2F2E9E8
EDEBE9E9E6E5EAE9EAE9E8E8EBE9EAEDE4E8ECDDE3F2D9DFEEC9D1E8B1BDE69DABD87B8A
C35765A63D4C601C2A61454ED1CBCFEDEDEFEAEAECEDEDF0EFEFF2EBECEFEBECEEEDEDED
E8E7E5F6E0E0D28487B02022C41316BD080CB5050AAD040AA8040CA5010AA20008A10108
9F02069A01039A01039A01059600059001048E0104920206910102910102910005920106
9202069001058C01048901028A0104890105890104880003880004860102820001850203
8B02078D02088F020894040C95040C98060E97060F90030B8D010895010AA0010BA5010B
A0040B8401057402058B181D7901058203077C00037001016701007A1C0843950400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BE22C2AC9BC6CBCFBAC6CEA4B1B59BA4A969737592969A58494E320B13836870D6D2D8
CDD5D9D3DDE280898E140F1421050F2B030B280001411300C79525D9A01AB0530FA61203
B7080ABF070DC3090CC6080CC40709C4060BC4090CC1070BC1080CC4070BCD0B0DCF0B0C
D20F0FC00808B91010BA1313C2080ADB1012DE0E0DDF120DDD110FCA1010870202B66C68
F1BFB9FED4CCFFD4CCFFD6D0FFDCD3FDE3DBF9E4E0F6E7E3F4EAE9F0EAE8EFEDEBECEBEB
EAE9E8E9E5E5EDE4E4EAD8DBE8CBCFE3B2B9E6A1ACDB7F8BC3525EB6303EBA2634C3212D
C81E26C32026901B213D050DAA999FEEEDF0EAEAECECEDEFEBEDEEECEDEEEAEBEDE6E7E9
EDEDEDF6E9EBEBB2B6AE2C31C7161AC80D12BE080DB20308AB030AA6020AA20007A10107
9F02069A01039701019901039701068F01038A0005900208920106930106930205910104
9100058F00058C01058800028800028700028901038800048801058601048001017F0101
8601048A02068D010791020894030B98051096050F94040D97010BA2020DA9030CA70108
9C030A7D00027702077A02077500047802078413166E010266010076190843970600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
53BB1EC6AE9DC4C6CABAC3CAA9B4B97A85898A9598989FA35C4F533A131B80646DD8D2DB
D2D8E0D5DCE57D838C1810182707102F030A3305054C1C01CE9E29DA9E1EA13B05A30901
B70809BF090DC2090DC00508BF060ABD060AB7090CA502089D0106A80407BD090CCB0B0D
D20F0FC30D0FC32828DD4646C91512DA0F11DE0E0DE0100CDF100CDA1614B61112750B0E
965B60DFC1C6EEDEE0F2E6E8F1E9EAF3EAEDF1E8EBF1E9EAF1EBEBF3E9ECF3E9EBEEE2E4
F1DCDCEEC8CDEFB5BEE897A1CD656CBE4048BC2C36C3222DCB1E27CA151EC91318D1171A
D11818CD191AB022235B090D644649E4E4E6E7E8EAEBECEEECEEF0EBEEEFEAEBEDECEDEF
EBECEEF3EBEEFCD3D7B84B4EC31B1ECC0F13C40B0DBB080BB2050AA80209A30006A00005
9F01059B0004980002980102980103960207920209920108930107920006920004910104
9101059001068E01068C01048C01048D01058C0206870104880106880105840103820102
8400048801058E020690030795060C97050E95020B9A050CA3040CAB050EAB020AA50108
9603097700017602067C040977010777030876070D6F03066701026E120542950500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD20BEAA97B8BCBCC6CFD6A1ADB488959B9DABB06E757A675A5F3811197B6068D9D3DC
D5D9E2D7DDE7767C85140E1625070F2D030B3406055B2B0BD2A22CD59622972A00AB0D08
B50709B9050BBF070EBF070CBB080CB1070A9D0104BB2E34D5585DB027299C0405C30E12
CF0E10CC0F10E1373AE23A3ED21516DD1112E11110E21210E2120DE11411D81414C1161B
95111A882937B56F7CD198A4DFB0BAE2B7C2E4BBC4F4CBD1FACED5F5C0C9EEADB9E49AA5
D67B85C4525EC13944C62935CE232ACE1C22CF191CCF1418D21518D4141AD41518D21516
D31716D3191BBD1C1D8A1A1D441113C8C5C6E7E9EBEAEBEDEAEBEDEBECEEEDEEF0ECEDEF
EEEEF1EFEAEDFADFE2D07A7DB92023C81014C50C0FC0090CB6060BAD0209A60007A30109
A100089C0106990103960001950001960105960107940109920108910108920107910006
9000069101079001078F01068F02048D01038C00038A00048B0005890105860004830103
83010387010490040A8E01088F020A93030B97030BA40710AB050DAB0209A90209A30108
97030C7500036D020578050B7600057B04096E02076B01046901026C0B0142930400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52BB1EBFAB97BABEBFBBC7CEADBAC2A8B5BC6D7C7F91979C695E62331117785E64D6D1DA
D5DBE4D7DFE9696F78160D1621060E2C050D3106046D3E14D2A129CF8C21901C01AB0909
B6080ABA060FBB060FBA070EAF060A9F0103A00308C82C35C63038B524288B0000AF070A
CB0D0ECE0B0DD00E12D31116D81012DD0F10DE110DE21210E1140FE0110FDB1111D20E11
C81115C01620B71F2AAF222FB02D38AE2E3BB13642C84C5AC44654C13846C02F3BBF2530
C5222ACA1D23D41E20D5181DD5161AD41517D01312D31315D71618D81519D71619D7161A
D41416D01317C7191CAE2225580A0C948889E4E8E8E8EBEBEBECEEE9EAECEBECEEEBECEE
EBECEEEBEBEEF4E5E7E3A3A6AC2327C81416C60D0EC0080ABA080CB3060AAA0108A50108
A101069C01049900029600019701029601039501059301078D01068B02088E0209910208
9000069101079001078E01068D01038C01018D01028D01038D01058A0107870005850004
8500048800068D020A8E010A91010A99060E9B020AA8060FAE060EAC040BA702099F0007
98050C7501045D00026A060C7302087B050B8E24286802036F0305700B0142920400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B81BBFA893CED1D3BFC8D2B2BFC88493998291939DA5A96C6368341218775C63DBD6DF
D1D9E2D7E0E95D626B1B0E1627070E2E050C34060589571AD5A325C1771A8E1301AA0A0A
B5080BB8060EB80811B207109D03079C0104B50710C00A13BD0912B10A0F8F0000A90609
CA0E0FCF0C0DD30E0FDA1014DA0E11DF0F11DE110FE0130FDF120DE01410D7110FCD0B0B
CB0B0ACD0E10CD1114D01417D11618D2161BD2191FCF171FD01921D2181FD51A1ED3181B
D11718D11515D71616D81918D51817D81D1AD31915D31C18D31D1AD31917D71F1CD6191B
D41518D21419CB1618BE1D227B1216614547E1E3E4E5E8E7E7EAEAE9EBEDEAEBEDEBECEE
EAEBEDEBEBEDF0E8E9F3C6C9AB373CC11719C60E0EC20A0BBD080CB6070CB0050CA8000A
A301089D00049900039801039802059400029301029201058801037C00018301038E0207
9102068F01058D01058D01058B00038A00018C01028E02068B0106880004880004870103
8600038701038E020890010A98040CA70B13A7050CA70309AD050DAA030AA301089F0007
99030A7C040A5C090C4C00046301067C050D810E156F0004700203720C0243930600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
29DB0DB59A84CBCDD0C6CFD89EABB3839297A6B4B7747D826A616836141B7A5E66DED9E2
D3DBE3D7E0E950555E1C0D1527060C2D0508360904A4741ED7A525AE5C138F0D00A60708
B1050BB3030BB0070D9F040B8D0002A8060CBD0710C4060FC0070CAD070A8C0000AC090B
CD1011CC0809CD0708D80D11DC0E11DC0E10DB0D0DDF120FE0140FDC1210D00C0BCD0E0E
C90C0CCB0B0CD00F10D21010D61411D61414D61918D21817D31D1AD31D19D61C1AD51B19
D21715D11513D01918C9211DC62D25C9372FC5382DC63E33C8463AC8493FD14F46D2433F
C61F1FD4181CD2171BC7171BA21F22451114D3CFD0EAECEBE9EBEAE7E9E8E8E9EAEAEBED
EBECECE8E9EAECE9EAF6DADCB65B60B81C20C40D10C30B0DBA0409B5050BB3050EAD030A
A702099E00059A01049701049400049100029200019200029002058501028501028C0103
8F01028E01028B00038E01068D00058C01048D02048D01058B01078900068C01058B0003
86000187000290060C93030AA30811B00811B0070FB1080FAB040BA80309A40109A00107
9B020981030AAE5C615D23255903077E040A86060D7C020674010370070044920700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC8F74C7C6C6C3CCD5AEBBC1AAB7BD7D8C91868F956C656A32141B7B626ADDDBE4
D6DEE7D9E2E94A4E561D0E1427060C2C0508340800B48421DAA5279B4009970E02A70608
B0040CB0040CA9090E8A0205880203B10A12BE060CC3050AC1090DA60407890000AE090A
CD0F10CF090CD10B0CD40D0ED80E0EDA0D0EDB0F0EDA0E0EDF1514D30D0EC9090AC8090D
C70B0CCC0E11D01013D01112CE1813C9211BC52D25CB4339CF5247D2554BCF4B41C73830
C52A23C9231EBA1F1D7D0908D98A83F5B4ABF1B4AAF3BCB0F5C3B7FCCDC4FECDC6FDBCBA
BA3E3ECB1C1FD11518CE171ABC22245608099B8B8CE8E8E7E9EAE9E7E8E8E9EAECEBECEE
EBECECEAEBECEAE8EAF3E2E4D28E90B12528C51215C1090DB9050BB4040BB4050FAF030C
AA020AA200089E02089901059500049401049400039500039201038E02048C01048E0303
8D01018C00008D01028F01069202089101078E00058C00058C00068C01068B00048C0105
8B01068900048E01069E060DAC080FB70B14B4060FB30810AC050CAA040BA60108A10108
9C01088C040C85232B954F565C030883040D86010881010678010371050044910600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00947452CCC9C6C2CBD1C0CBD492A0A884939896A1A76C686C31161B79626ADFDBE7
D6DEE7D6DFE63C3F471D0C1429070E2F06083E1000C6962CD79E278D2C019B0C03AB060A
B2050EAE050F9F080F790001890205B1070EC1070DC6070CBD080BA003048E0000B80C10
D00E10D50C0ED50B0ED60E0ED70F0DDA100EDB100ED60E0FD61011CF090DC8080CC80A0E
CC0E10CD0D11C71113BD1918A7211AAE493FD99085FECAC1FDD4CBFFD6CEFECDC5F9BCB6
ED9F98D17068A6453F4B100E98817DEBDFDBEEE2DFEDE4E1EFE6E4F0E7E5F4E8E7FDE0E0
C46C6FC5262BD3191BD11617C71E1E7911136D4F51E8E7E8EBEBEBECECEDEDEEF0ECECEE
E8E9EAE7E9E8E8E9E9ECE4E4DEACADA32B2EBC1316BD0B0EB8070CB4050BB3050BB1040B
AD030BA70109A201069D01059A01059800049702049601039201028F0202890001870101
8C01018D01008D01018D01038F00049101059201069001068F02078C01058A0004880103
8901038C0002960105A50409B1080EB5070FB1020CB2060EAC0209AC020AA70108A00106
9C010895020A91151D710C1473040B89030C890108810004790103730600655B0700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0084623CD0CCC8C5D0D5ACBBC2819299A8B8BC7681896A676C31151B816770D3CED9
D6DEE7D3DCE52E3038210C1429050C320604512000CA992BC98E26741500970A07AB060C
B1030CAE071193050C710001890307B2090FC3090DC5090FB9090E970103950102C10E13
D10E0FD40C0ED70D0DD90F0FD40D0ADA100ED9100CD91211D00C0DCD0A0EC9080CCD0C0D
CD0E0EC91010B41416780B08A86960F1D0C9F7E7E3F2E9E7F3EDEBF1EBEAF4ECEBF5ECEA
F6E6E2F7DBD5E6C5BE8D7671766D69DCD7D6E5E3E5E7E6E8E6E5E7EAE7E9EBE7E8F6E4E6
D49295B72A2FCE181AD41719D11E20991A1D4A1C1FDBD8D9EBEBEDEDEDEFECECEEEAEBED
E6E6E8E8E8EAE7E8E9EDE8EAEFCFCFA7474AB0161CB6090EB3040CB60711B3060EAD020A
AD040BAA0209A70208A203079B00049800029600029100028E00018D0101890000880101
8800008B01018B01018A01018E00029101059100059201078F02068C0104880104880001
8C0001950103A00105AB040AB40810B4060CB5070EB3070DB0060CAD040BAA030AA30207
9F01079B010991040BA5262C8F0E178B010A8B010880000476000173060085220600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F6C46C6C2C0BBC6CDAABAC1ADBDC4798990808B90716E7133151A816970DAD6DF
D8DDE8CDD6DF2B2C35210C152B060C360803693810CE9D2DAC721F6B0C01900708AB080E
AF050CA908118904096D0003810206A7060DBA0A0DBC0B10A8060B8E00029D0506C60C10
CF0C0DD40E0FD20C0BD0080AD40C0CD50C0BDA130FCF0B0BCB080BCB090CCC0B0CCE0E0D
CA0C0BC213148A0D0E612A28E4CFC8F2EBE7EFECECECECEDECECEDECECEDEAEAECECEBEF
EBEAECEDE9EAEBE6E4E6E2DDD8D4D0D3CFCFE6E5E8E7E7E9E7E9E8E8E8EAE8E7E8F3E8E8
F6C8CAB53D41C91B1ED11318D2191DB620274F070CADA3A4EAEDEDEDEEF0ECEEEEEAECEC
E5E5E8E9E9EBE9E9EBEAE6E8F2DCDEAC6266A41C1EB40D11B60910B4060EB2060FAB020A
AC030BAB0209AB0309A702069F00049900039701049302068E00018D01018B0202880001
8901028A01018B01018E01029001049101069301099101088D00048B00048C01048E0002
980104A20208A80208AC0209B40510B5050FB6060FB2040DAF030BAC0309A90308A70209
A30107A001089A030992030B8D020B8A00088902077E010373000073050089230900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0093714CC7C4C2BEC9D0BAC9D19AA7B07D8B9195A1A475737432151A866C73DBD8E0
D6DEE7C5CBD32220292007102C060C33050481511BD7A5349A5B1B760C02940407AC070E
AF060EA6060F820207650001760105920309A10409A1040A9002078300029E0607C90E12
D00C0ED40C0ED20C0BD20C0DD50D0DD50D0ED10C0FC60408C6060CCA090DCD0D0DCE0C0C
CD0E0FBB13156907077F5F5DEAE0DDF1EFEEEEEDEDEEEEF0EAEBEDEDEDEFECEAEDECE5EA
DECFD7E2D2DCEBE3E9EAE8E8EBEBEAE2E1E2E3E3E5E6E6E8E7E9E8E7E8EAE7E8E8ECE7E8
FBDEE0C4656AC12023D21A1FD3171AC51E226E0E147A6368E9ECEDECF0F1E6E9E9E7E8E9
E8E8EAE8E8EAE2E2E4E5E2E5EBDEE0CA92949A1F22B21014B1070CB0040BB0050EAB040E
AA030CAC030AAE0209AD040AA501079C01069701069400049100029001008E01018C0103
8A01028A01018B01018D01018C01038E01059100099100088F0005900104930005990104
A40106AA0108A90108AA0109B1020CB5050FB60711B3050EB2050EAE040CAB040BA40106
A202079F020899020993010A8E00088901078803077F010472010070040088210900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C6B46C2C0BDBECBD2ABBABF7D8990A9B7B97784886E6A6E34161C8E747BD9D6E1
D1DAE3B0B7C119131E21060F2E040A3506069F6F20D39E2E853A0E8A10079E0609AC040C
B0060EA9051088050A6400026C02067F02088701098602087F01057E0001A3070AC50C0F
D10C0DD30B0DD20C0BD30B0DD50E10D10B0DC70709C3040AC7070ECB080ECF0D0ECC0A0B
CE0F10BA171A5C0506917B78ECE7E5EDECEDECEDEDECEBEFEBECEEEAE7ECEDE3E7DEBBC1
9D56638C3D4DA26879D4B9C4E6E1E6E9E9ECE6E5E8E5E5E7E7EAE9E5E6E8E3E4E6E9E7E9
F4E3E5D79096B9272DD42124D7191ACC1B1D93191E50272CE2E1E4E9EBEDE6E7E9E6E7E9
E8E9EBE9EAECE6E4E7E4E2E5EAE2E5E6BDC19F363BAE1318B2090FB2060EB0040DAE040D
AD040DAD030CAF020BAF020BAB040B9F01089901069500029401029301029102018E0202
8B01018901018902018C03028B02028F01049301079301079200039601059C0105A10005
A70206AA0208A60208A40207AE060CB3060FB90A13B3060CB1050BAF050BA90209A40106
A000079A02098B01058D040A8D03098700038701057F01057401016F030080190400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B6A46B0AEACC4CED5AAB7BDB1BDC27E8D8F7D878D716C6F33151B947A82D4D3DE
CCD5DFA4AAB51C141F280A162F040A3A0A03B6852AD29C30711A00910C09A4060BAF050C
B3040DAC030E8F040D6400036201066F01087A040C78030A760105880105AA0409C60A0D
CE0B0AD20C0BD10B0AD50C0ED30D0ECC0A0BC7090CC5060DC7080FCB090FCB080CCE0B10
CD0E0EC0191C610708866F6EEAE8E6ECECECEBECEEEAE9EEEAEAECEBE8EBEEDEDFBB7A81
AC2A35B8202BAB2634822735956F7BDED7DEE8E7EAE6E6E8E7E8EAE6E7E9E3E7E8E7E8E8
EDE3E3F0BDC1BA373FD2242AD71A1DD0181BB01E244A080FBBB3B6E6EAECDEE0E3E8E9EB
EBEBEDE9E9EBECECEFE5E5E8EAE7E8E4C9CBA24F52A21519AF0A10B30810B0020CB1040D
AE040CAB0109AE020AB0020BAD030CA501089E02069A01039501029100019001018E0101
8C01028B01008801008700008A01018E00039200059500069B01089F0207A40207A40106
A501079E0206900102950306A6050BB3070EB6080EB5080EB1050AAF0509AC040AA40006
A001079902098600048001048803088700058701068100057701026D01007D190500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00856143BBB8B8C3CCD6C0CED69BAAB178888D959FA57A757A33181D947C84D6D4E0
D0D8E18F94A0150D192306122C0307411200C79735C48B2979180298090AA80309B2060C
B4050CB0040C9E08116D00055C01056B0C138A2E33882D337002089B070FBB0A10CA0B0C
D10C0BD20A0CD20A0DD70E11D30E11C6060AC10609C3060CC7080DCA090ECD0A0ED00B0F
D00E0FC2151A72090C705355E7E2E3EDEBECE9EAECE8E8EAE5E5E7E8E5E7EEDEDEBD7A7E
B02529C5171BC7181EB62029711521725761D8D6DAE4E4E6E2E2E2E4E5E7E4E7E7E9E9EB
ECE7E6F8D5D8B95257C6282CCF191CD2171BBC1B20610A0F7D6C6FE1E4E6E1E5E6E7EAEB
E8E9EBE9EAECE6EAEBE3E5E7E7E7E8EADADAB5767992161AAC0B12AF0610AF040EB20710
AE030CAD020AB0040BAF020BAA010AA8030AA502099E01079701059200048F01018D0001
8D01038C01018900008901018C02028F01039500049D0106A4030BA60109A60107A50004
A200059600038301027C0001940308AF0810B60810B5070EB2050AB00509A90105A60208
A101079C01088F01088200048401068801078600068201057901026F01007A150400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00896547BBB9BAC1CCD5B8C5CE77868EA7B6BB7D878F6D696E2F1318977F87D5D1DD
D2D7E07C848D110C1520050F2804054E2105D19F3BAB6A1F750C019D0A0AAC060BB4080C
B5060BB3040BAE0A12830307620204C97E85FEC3CAE3A1A8760F12AE1316C00A0CCB0A0C
CF0C0DD30D10D20D0FD00A10C7060BBF0308C00609C2050BC80A0FCE0C10CE090FD10A0F
D31013C815198A0E13532F32E1D9DDEBE7ECE7E7E9E5E5E7E5E5E7E6E3E6EBE0E0D09C9C
A62A2CC01619C81217C2151B9E1B243D080FB0A8AAE1E1E0E5E5E5E7E7E9E6E8E7E7E7E9
EEEBEBF7E2E2C97E80AC272AC92023CE171BC3191D8013194C2C30DADADCE1E4E5E3E8E8
E5E9EAE6EAEBE6EAEAE6E8E8E2E3E3E6DCDDCFA2A48D2327A80F16AE070FAB030BAC020C
AB020BAD040CAD030CAC030CA6010AA50109A502089D0206970109940108920104910104
9101049102049001038C00018E01019200019D0104A50107A60108A70109A60007A40104
A201059E020698050B840104880204A90A11B80C15B60610B3040CB0030BAE040AA80208
A100089C01099301078700058601068801068701048402057B010370010079130300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00967053AFACADC9D1DBB3BFC8B0BDC587969B7F8A906D676B3313199F868CD5D2DB
D2D8E267717A0F0B131C050B230203623715D7A43E9149137F0A039C0509A70207AD0305
B4060AB20108B5080F9F050B81080D8C343C934D557B2E32AE3C3BB91817C40C0CCD0B0E
C9080CC20206CD0D0EC9080EC2040AC1070AC3070BC5080EC5060ACB0A0CCD0B0CCF090D
CE0C0EC710139E13173F0B0DC6BDC0E7E4E7E5E3E6E7E5E8E5E5E7E3E3E5ECE6E6DFBCB9
9E3D3AB81C1FC41217C7151AB41B2057070C706061DCDADBE6E4E5E4E4E6E4E5E5E8E7EA
E7E6E6F0E3E6E2AFB1A03539B52024C31216C012189F1C233F080FBAB4B7E2E4E5E7E9EA
E4E5E7EAEBEDE8E9EBE4E4E6E6E6E7E4DCDEDBBABD983E42A41419AC080FAB060DAC030C
AB020BAA020BAC030DA9020BA60109A40108A10107990105940006980108980105950104
9201039101029001039101029300019C0104A50106A90108A90109A60007A50007A40105
A10103A100049F02069303078A0004A0060DB20910B70911B3040CB3050CB0040CA70109
A0010B9C010A9701079001068901058600018601038301047B01037201007A120200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956F4BBBB5B2C7CFD7C3CED8A8B6BE7C8B9097A2A8767376301319AD979DDAD8DF
D4DCE5525B65130C1420060D2504027C4F1DDAA43F8331078B0C04A2070AAC050AB0050A
B5070CB8060CB6050CA90107A41015BB4349BB5458D16464BF3333BD0E11C70B0DCA0A0C
BF0106BF0207C90C11C4060BC10609C0060BC40A0DC5070DC7090BC90809CE0D0CCF0C0D
CE0C0ECA0E13B41A1E4B020597888AE3DDDFE8E3E7E5E3E6E3E3E6E5E5E7E6E3E3E6D0CD
B26864AA2020C01616CB171ABE161B7E1017422325C8C5C5E5E5E3E7E7E7E6E5E7E9E7EA
E7E5E8F0E8ECF7D6D7B66669A62427C01419C11116AF1A2053060B88787BDBDBDDE5E5E7
E5E5E7EBEBEDE8E8EBE4E4E8E3E3E5E1DDDFE0CCCDA55F6198151AAA0911AD070FAE060E
AD040CAB0109AC020BAA020AA70209A50207A40208A3040A9F02089F010A9F01089A0106
9500039000018F00029601029D0003A50207AA0107AA0107A90108A60007A50107A30106
A00004A00105A001069E02099A0108A5030AB1060CB6080EB4060EB5050FAF030CA60009
A2010A9D01099800059401058B01038701038402048301047F02057400017B110300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805A32C4BDBAC3C9D3B9C4CE7F8D94A7B6BA8290946464672F171AB6A2A9DADAE1
D4DEE5454D57150B131E0509250503986C24CB9234771E018A0602A20409AE060DB3050E
B8070FB9050EB6030CB00108AC050BB0151CB52529AC1519B60C10C3080DCA0A0DC8080B
BE0005C00309C3090EBE0409BE0508C1070AC3080BC6060BC80A0CCB0A0CCC0C0ACE0D0C
D00F10CB0D12BC161D67070C62494CD9D2D4E7E4E5E5E3E6E4E4E5E4E4E6E4E3E2EBDEDB
CC99939F2B28B81615C81516C5171A9D191E3906089E9999E1E1DFE6E6E6E8E8E8E7E5E8
E6E4E5EEE8E9F3DEDDE2A6A9A53638BE1A1DC21016B8181E74111851363AD2D0D3E2DFE2
E4E2E6E6E6E9E6E6E9E3E3E8E1E1E5E1DEE1E5D8D8C48F908F1C1FA60B12AD0710AE040D
AE030BAE030BAC020BA9020AA70109A70109A9040BAA040BA8030AA6020BA3000B9F0108
9A0104980103990002A00104A40004A80107AB0209AC0109A90108A70107A50107A30106
A00004A00104A20107A6020AA7030BA90209AD030AB5080EB5070DB4050EAD010BA7020A
A001089C02099701079101068A01048400048100048201057F02067600027B0E02439002
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008E643DB4ABAACED6DFBFC9D2B0BCC38A9A9D828E916763662F181CB8A9B1D8D9E1
D2DBE22F3841120B131B05092B0C02AF8330B47A27690B01900806A6050BB0060DB2030A
B6050DB7030BB9050DB40208B6040ABF0A10BE0A0FBE080CC3080BC8080BCA080ACC0A0D
C40609C5080EBD030ABD0409BE050AC0040AC4070BC50609C80A0CCC0B0DCB0E0BCD0E0D
CC0D0EC80C11BF1216830E13401D1EC9C2C3E8E4E5E6E4E5E6E6E6E3E3E5E4E4E3ECE6E4
DDBDBA9A3F3DAD1618C81419C7141AB1181E57080C655658D8D7D5E4E6E5E5E5E3E4E2E2
E8E6E7EAE7E8ECDFE0F1C9CBB05557B91F21BE0F14B812198D161C380C10B4AFB0E2DFE0
E1E0E2E3E3E5E1E1E3DEDFE0E0DEE2DFDCDFE5DDDED4AFAF922F32A61016AC060EAE030C
B1030DAF040CAC020BAA030BA70209A6020AA7030CA6020AA60209A5010AA5000BA60109
A50107A50106A60206A50004A70106A70007A80108AA0108A80106A60106A50106A20105
9F0003A00103A40007A70108A60107A70106AC0209B50811B70A11B2040DAC010CA5010B
9C00099800079200068D01058700038201047D00047F01057C0104750101790B01418D01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00855A31B8B0AFCBD3DCCAD4DDB1BDC67081868D999E79767B321A23C0B4BCCDD2DB
C7D2DB1C242E110A101F0708371500C3943D99591D6B08018F0709A8060DB1070DB5060D
B6040AB90509B90509B80308BA0308C4070DC80B0DC50809C40907C7070ACA090BCA090D
C5090CBC0308B80206BA0409BD050ABF060BC3090CC00409C10408CA0A0ECA0C0CCA0D0D
C90C0DC2070CBF0B10A1141A3C0307AEA4A5E2DEDFE5E5E5E5E5E5E4E5E7E5E6E6E7E4E5
E5D3D1AF6967A92022C5161CC71318BE181E7C11183C1C21BFBCBDE2E3E1E2E2E0E3E2E0
E7E7E7E8E7E8EDE5E7F4D8DBC57E80AA2224C21617BE1114A51A1F4403078B8183DCDBDB
E2E2E2E2E2E3E1E1E3DFDEE0E0DFE1DEDEE0E1DDDEDBC1C29D4C50A0141DAE0913B0050E
B2060EAC0109AC030BAA020BA70209A7030BA6020BA60109A7010BA7010DA9000BAF010A
B3030BB10409AD0207A90006A90105A90108AA0107AA0107A90107A60106A50105A20104
A00004A00105A30108A50109A50105A60004AE040BB3070FB3050EB0030DAC020DA4000B
9D01099801089200068D01068801078100057C00037C00057A0105720002750A02428F03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF007A4B23BEB3B1C3C9D3C7D2DA7E8D959DACB2838E94625E61301922C7BAC5C8CED7
B7C2C8151B22160A0E2206054F280BD19F46803A0D750A038C04079C030AA8050AB1070E
BA080DBC080BBE080ABD0409BC0308C6080CC90B0DC30809C20708C8080CC6070AC1040B
BA0308B50208B60409B50309B9050BBC050BBE060BBD050BBF050BC1070CC5090CC3080B
C40A0CC0070CC10810B2141B570709796769D7D7D4E5E5E5E4E4E4E3E3E5E5E4E6E6E2E5
ECDFE0CB9998A32E2CC21B1CC81517C315199B192039030A8F878ADCDADCDFDDDEE0DFDF
E3E4E3E4E5E7E7E5E4F4E4E5D8A7A8A12B2EBE1819C01113B3181D610A0F584548D1D2D3
E0E2E1E1E2E2DFDFE1DFDFE1E0E0E1DEDEDDE1DFE0DECDCFA5686D92171EAA0A12B20810
B2060EAD030BAD040CAE050CAA040BA6020BA6020CAB050FA7010CAC010DB2020DB7020B
B9040AB8040BB3020BAD0109AA0108AA0108AA0107AC0309A90108A60006A40106A20006
9F01059E0004A10106A50108A50106A50106AA0108B2050EB80A13B0030DAA020CA4020A
9B01069700069300068D01068801088001067D01067C01067C0306740103730801438F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956A42AFA49FCDD3DBBFCCD3AAB9BF92A0A57B84885A5555341C23CEC3CCCED4DD
A5B2BA0F131D18090F2205046E471ECD9A437025047A08058E03089300059C0105A60107
B5070EBA060DC0090DBE050AC1070AC90C0ECA0C0DC90B0EC40709C7070CC5070CBC030A
B6020BB1020BB0030AAE010AB2060DB9060FB7020BB8030BBB050DBE060CBF070AC2090D
BF070AC40A0DC50D12BC141B790C1346292AC5C3C1E3E1E2E2E0E1E5E3E6E2E2E6E5E3E7
EAE3E3E1C1BFAA4B49C02322CA1618C9161AB0181E5A09125F4E54D5D2D5E3DEE0DFDEDF
E0E1E1E0E4E5E1E3E3EAE3E2E9CACAA54549B41A1FC01217BB161D7F11173A181BC0BEC1
E0E1E1DFE1E1DDDEE0DEDEE0DFDFE0DDDDDEE0DFE0E3D9DAC4979B8C2126A90E14B20810
B0060EAC020CAD050DAC040BA9030AA3020BA3040EA6010CAC020BB4060EBA040EBB030C
BD050DBC040DB8030DB3010CAD0109AB0209AA0107AA0107A80007A70108A60209A4020A
A10107A00106A10207A00107A00109A40108A80108B1060FB20810AB030AA60108A00006
9C00069800069301068D01058601078201077D0107780104780102750202740700418D02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF009B7048A79B95D1D7DFC3D2D9B6C7CE75858C8A92976D6869372228D2C9D0CDD4DE
8F9AA611101C18080C2106028B6529B48538530901800B0D93040B9C030CA3040BA90108
B4040CBA050EBF080EBD0409C1070AC80B0DC90B0BC9080BC6080AC50608C3080CBA050A
B5020BAE010AA702099F0108A00308AE060FB5040FB9040FB9040DBD050DBF080DBD060B
BF080DC0080DC20A0EBD0F16921016330506A5A09EDDDDDDE2E2E1E1E0E2E2E2E3E5E3E5
E6E4E2E8D4D3C07A7AB22627C7191BC51014BA171C7A0F1838191FBCB8BCE1DFE2E1E0E2
E1E1E3E0E1E4DFE0E1E5DFDFECD8D9B56D71A51D23BC1119BF141B9C181F3B0307A59C9F
DEDDDFDFDFE1DFDFE1DCDDDFDEDEDFDFDEDFDDDBDDE3DCDDD1B0B294373CA71318B2090F
B1070CAE050BAF050EAC020BA8040B970004950106A5040CB2070FB8070EBA040CBB030C
B90209B90209B9030BB4020CB1030BAB0006A70105A70105A80107A60108A50107A30007
A10106A00105A001079801069201089A0109AB050DB1060FAD040CA70107A60108A00107
9B00069901079502078B01058301067D0106780105740002740101740101750700418E03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805328C9BBB4C6CCD4CAD7DF80929A95A5AC818A91534C513B242BD4CBD2D3D9E3
767E8A130B1919050C1F0501A37B37905E245707057D0509900007A3040BAB0309B3040E
B7050DBA050CBD060BBC0309C0080AC7090DC9080BCB090CC8080AC6080DBB0509B20207
B0030AAB020A9D00048F00028B00019C0107B0060CB5040BB8030BBC050DBC070DBB060B
BD080DC20D12C00B10BE0C14A7141A4704067F7576D4D7D6E1E3E2E0E2E1E1E0E1E2E0E1
E2E1DFECDFE0D0A1A2A23032BC1B1CC51719BD181A951A1E3B070C978F91DCDBDDDEDDE1
DFDFE1DFE0E2DEDFE1E2DFE1EFE1E3C49193972429B11119BB0F17AE192254050A6E5D60
D6D6D9E0DFE1DFDFE0DDDDDEDDDDDEE0DFE0DCDCDDE0DDDDD8C3C2A3595A9C1419B00B10
B2080DAF050BB0050EB0040EAE050DA3040A9B0206A8050AB60610BA050DBA030BB9030B
B90308B90509B70208B5030AB20409A80004A20004A00004A60208A40006A20006A20107
9E01059E00049F01059802068900038C0003A9090FAE050DAC030BA80208A501069E0006
9900069401059101058901047F0004770104760205740103730101740202760A02418F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00825021B5A59DD0D6DEC2CED7ABBAC392A1A97F878E51464D462F37DAD2D9D2D8E3
5F6571180C1820080D2A0C00B28841743C1A63080587050D9C050DA8030BAF030BB4040E
B6050DB8050AB90409BA0308BD0508C7090DCB0A0DCA070BC6080ABE0409B20207A70004
AB020AAA010BA40208A003099E0408A20206B3080BB40408B40309B6040CBA070FB8060C
BA070CBD080FBE0912BB0913B01119660A0D493234CACBCBE2E4E3DEE1E2E1E2E2E3E2E2
E4E4E2E6E1E2D8BEBEA55756AA2D28B62D25B12F289B342E5E2B2780706ED5CFCDE3E0E1
E2E2E2E0E1E0E0E2E1E1E0E3EAE2E4D5B1B2973538AC141DB90D16B5131E710D15402729
C5C6C9DFDFE1DFDEE0DFDFE0DFDFE0DEDEDEDEDFDFDEDEDEE0D3D4BA838591191DAF0D13
B50910B3070DB1050AB00207B7060CB90910B1060BB00308BA070CBC050CBD050DBB0409
BB0409B90408B50207B20306AD0205A501049F01049C0003A10207A10005A10107A20207
A100059F0004A001059E02069A050A920107A5070FAA040BB00710AA030CA602099E0107
9600049301058F01058700047F01047500027201027100036F00036F02027B150C46960C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00814B1AA08D83D2D5DDC3CED9BCCAD676868E838C936C6369533F49DCD6DED0DAE5
424A56170B13230706472108BF90465C1F0967050591060FA7060FAF050DB3040DB7060C
B60509BA0609BB070ABC060BC0080AC8090DCC0A10CC0A0FC3080CB70309AE020AA70007
AB0209AD020BAD030BB0040CB3080DAF0407B7080AB80509B6060CB3040DB5060EB8070E
B8070DBB080DBE0B13BB0914B40E158B141832090CB4AFB2DFE1E1E0E1E3E1E3E2E1E1E1
E1E2E1DFDEDEDFD4D3C49F9BC58B80DA988CD99E91D2A296C7ABA2C8B9B5D1C9C5E5E0DF
E3E2E0DFDFDFE1E2E4E0E0E2E5E1E3E4C8C9994347AA1820BA0E16BA131A8A151A310A0B
B4B4B4DCDDDDDFDDE0E1DFE2E0DFE1DDDDE0DDDDDFDEDEE0E5DCDFCDA3A7922930AF1118
B70911B9080EB9080BBA060ABD070CC0090EBE080EBB050CBD060BBC040ABD040CBD040A
BA0208B9030AB60409B30409B1050BA90208A201059B0001A10206A10006A30107A60108
A50208A20005A10106A00006A2040B9F010AA8050EAE050CB0050EAC040EA6020C9E0007
9800059201068D02078601057E00047701047402056F01046A010369010273140D44980F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00834F1ECBB8ADC4C9D0CCD8E28898A18F9EA5899297544B525D4A53DAD6DECBD7E0
2E3741180C132107056A4421BC8B4454110070050790020AA8060DB0030CB3040AB8070C
BA070ABD0709BD0809BE070BC2070AC8070FCA0910C8090EBF070BB40209AE010AAB0209
A90007AD020AAF040BAD0208B20509B20407B6070AB60609B3040AB3030DB1030CB4030B
B8070DB7060CBA0B11B80812B50912A5171E4B020778636ACFCDCFE2E1E2E0E1E1E1E1E2
DFE1E0E0DFE0E3E0DFE7DEDBE9DDD6EEDED9EADFD8E9DED9E7DFDBE6DFDEE3DFDDE2E0DF
E0E0DEDEE0DFDDDFDEDEDEE0E2DDE0E5C7CBA0484FAD171FBF0F16BB0E149B1419380002
888284D7D8D9DEDCDFE1DFE4E0DFE4E0DFE4DEDDE2DDDDE0E1DCDFD7B7BC9E444CAA131C
B7080FBF090EC50D10C2090EC3090FC0090EBB050DB8050DB9050EB7040CB9030DBB040D
BC040DB7020BB5030BB2030BB1040DAB0109A501079D0003A10106A40007A50107A70106
A90108A70108A50106A40007A30109A6010AAB040CAD0309B0050CAB020CA6010C9F0109
9901079201088801077F02067A01057501037301046D01046800036401026B110C4D520C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B5323B8A49CC9CFD6C3D1D9A4B3BA9AA9B07E868B41353D6B5962D9D7E1C0CAD5
1A222D180C132007068E68309D692F5E0A017C040798060FA9080FB1040DB5050CBA060C
BC060ABF070AC0090BC1080CC1060AC6080FC3060DC50A10BA0409AF0006AC0109AD020A
AE030BAF020AAC0208AB0106B10408B10207B4050AB2050AB0020BB3030EB3030DB8060E
B7060CB5040CB80910B70711B60910B01017820E174B161FAE9AA3E0D9DEE2E0E3E1E0E3
E2E0E1E4DFE2E4E0E2E4E1E1E6E2E1E4E1E2E2DFE1E4DDE0E6DEE0E5DCDFE2DBDEE2DADE
E0D9DAE0D7DBDDD4D8E0D3DADFC9D0D89FA9982630B1111BBE0D13BC0911AA101955050A
5A4B4DCFD0D2E1E1E3E1E1E4E3E2E7DFDFE2DEDDE0DEDDDFE1DEE0E2CCD1B86F77A2161F
BB0A10CA1114C90D10C6090FC2080FBF090FAE0309A40207AA040CB3060FB2020CB5030D
B6030EB4020CB5030DB2030DAD020AA90108A502079F0104A30207A50107A60007A90207
AC0309B1050BAD0209A70007A50107A70208AD050CAD040BAD040BA8010AA6010AA00109
9901069001088100057601057600087601077101066A00046701026300016A0F0D5B0F0D
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00905323AD958ECFD4DBBCCCD3C0D2D974858D6A7379493F46786972DAD8E3B3BBC7
13182214070E1F0602AB8243743C1971120888060A9A040CA50209B1060EB4040CB9050B
C0090EBF060CC0080BC1090BC0090BBE060BBA0209BC080FB3040BAD0109AD020AAE030C
AC0109AD0208AB0205AD0208AE0107B00209B2050BB2050BB2050CB2020CB3040CB6050D
B6050CB7070FB5060DB80A12B5080EB60C13AB131A7E0D186C232FB1838FDBC1C7DECAD1
DECACFD6BFC8E0C7D1D9BCC7CEAFB8CAA7B0C9A1ACC89CA8CF9FABCA96A1C68F99C38793
BC808BC0808BBD7987B97080B76271A63540AB1721B60C13B9080FBD0A0FB40F15710B10
3A2122C6C8CAE3E4E6E3E2E5E0DFE4DFDFE3DFE1E4DFDFE1DFDEDFE4D8DACE9A9D9D2125
C11416CA0E12C6090EC6080FC3070EBE080FAF050C9D0106A00006AB020AB0040CAF010A
AD0009AE010AAC0109AB0109A90109A70107A40207A00005A40107A60107A50107A60005
AC0208B4060DB2060BA70104A60105A80208AA020AAB010AAA030BA80209A50108A10107
9901049303088302067600067801097300066E01066B01036501015F00016309095F100F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00874B1AB2978EC4C6CDCBD7E08FA1A8768A8E7884883B373C837680DBDAE599A1AD
0E101B1304092D1001B78B4A5B220A60060285030A9E050DA60309B0050BB4040CB7030C
BB060CBE070CC1080CC1080BBF0709BC060AB60308B4050AAB0108A90007AC0209AC010A
AB0208AB0307AA0407AA0208B0050BAC0109AF040AB2050BB4050BB3030DB3030DB6050E
B6070EB6070EB3050AB70A0EB70A0EBA0E12B70E14B0111AA21621931F2DB65864BD6775
B45F6CAB5160AB4E5CA84556A03A489E3140A330429F2A3AA02836A22735A62534A7212F
A81F2DA71D2AA71D2AA91B2BAF1A27B3141CB80F15BD0F12C00D11C51114BF12168F1217
310508AFB0B3E5E8EBE2E3E5DFDFE2E1E2E6DFE0E4DEDFE3DBDDDDE4DFDFD4AEB09F3537
BD181BC50E12C20A0DC2080CC0080DBA040BB3030CAB030BA70209A80108A90108AA0108
AA0108A80007A60006A60007A40006A50107A30107A10107A50109A60109A60108A70107
AB0208B5070DB4060CAD0106AB0207AB0209AC030BAD050CA90309A60108A70208A20106
9A01069201078901087F00077F02087802067001046D010467010260010261080664130F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00894A178E6C62CFCDD4CAD6DE9CAEB493A6A6828B8A292324978B92DBDCE67E8691
100D19170407492913B78A4B4D12015D010287060E9E030EAA050AB0040AB4040AB6050D
BB060DBD060BC1080DC1080BBC0406BC060AB8070AB20409AB0109A70107A70108A80108
A90209A80208A70208A70309AA0308B0040AAE010AB3040EB3030DB2040DB2040DB4040F
B60610B80811B4070EB5090FB70A0EBC0D14BB0C13BC0D14BD131AB5111BAE131EAC1623
AC1723B11926B21722B51823B3141EB2101BBC1823B91722B7131DBA131EBC121DBC121E
BB111BBA121BB61218B81019B70E16BB0F14C01315C11213C71417C91115C81518A6171B
4102058C878BD8DCE0E5E6EADFE0E4E2E3E7E3E4E8E2E3E5DCDDDFE3E0E1E5CDCDB15E60
AE191DBD0D0FC00C0EBD070ABF0A0EB7030AB20108AE010AAB0109A90006A70004A80005
A80007A70007A60107A50107A40107A10006A20107A30107A60209A70108A60108A70108
AA0209B1030CB4060DAF030AB0050CAE030AAE030BAC030AA80208A80309A60207A10106
9A01059200078B01088601078001067900047201036B00026800036201026103025F0A06
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4816886256D8D1D7BEC9D0C0D1D87E8E92767B7D2C2024A79AA1DADCE5626975
120B141B04046845259A69364D060174050C8F030DA0020DA80209B1050DB3040BB7060E
BC070EBF070DC0090CC0080ABB0405C00B0DB40407AE0107AC030AA90108A60104A50006
A70208A60208A001069F0004A60208AF0309B1020CB5040DB3030DB2040DB0020BB4030E
B4040EB80611B70711B4050DB60A10B5090FB70A13BD0D16BD0F15B80C13B80F15B20C14
B71217B61116B81317BB1418BA1316BB1218BD1318BB1319BA1318B91117BD1519BC1317
BC1517BB171BB61719B8181AB61415B81515BA1615BC1415C11517CA191BC61717B11D1C
5E0C0E5F4E51CED0D3E0E2E4E4E6E8E5E8EAE4E5E8E3E3E6E0E0E3E1DEE1E7D9DBC48589
A42123BB1010C10E0FBC090BBB080EB4040BB1030CAC0109AC020AA90107A60103A80104
A80007A70007A40004A40105A40207A00006A00005A30106A70208A60107A40007A50008
AB030AB1050EB1040BB0040BAD020AB0030CB1040DAB0108A80007A80108A70209A10108
9B01079400058E01068701067F00037701037001026B02026601026202016001015C0502
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F4A18A27A70C6BFC6CCD6DE96A8AF7E8D9384848B2C1D25BAADB6D8DBE5444A56
180C15200404916B3B784322620C0485080E9A040DA6030CA90109AE0209B3040BB8060D
B9050CBD050EBF060BBD050ABC070BB60409AC0106A80107A90209AA0108A80206A90209
A80309A70208A40107A30108A70209AF030BB4040BB4040AB20309B3040DB2040DB4040E
B60610B70510B80711B5070FB1080DB0090DB30D10B71212B71112B61213B61514B41513
B11712B01714AE1914B5211CAF1D19AE201CAD211DAE2320AB261FA6251FA82A21A92B25
A82E28A32D27A23029A33029A4312AA6312DAB3631AC3730AE342EB53531B83733AC3B36
732D294B3633C3C2BFDFE1E0E1E4E3E5E6E6DFE0E2DFDFE3E2E0E5E0DEE3E2DADECFA5A8
942829B31615B80E0DB90E0EB2070AB0040BAE040CA90108AA0209A80107A50004A80106
A80007A60007A50106A40105A20106A20107A40007A50108A50107A30006A30009A6010A
AA0209B0050BB4070DB2040CAF0209B1030CAE030BAA0108AA0209AA010AA9030BA4010A
9D01099401078A01078402067F01047C01037401036A01016100005F01015E02016C1813
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00934E188E655CCCC7CFCDD9E28D9EA58B989F82818A2E2028C2B8C2D2D5DF2C303C
190B12270902A87E475C230D5F070184060B9D060EA7040DAA040BAE050EB40810BA0811
BD0810BC050DBF070DB80209B6050CAF020AA70007A30005A60006AB0209A80106A90209
A90209AC0107AD0108AE020AAC0209AC020AAD050BAE0407B2060AB3060CB3060CB5050F
B3040DB70810B4080EB10C10AC110FA81610A51A12A41D13A22116A3261AA62E23A9372B
A63E30A44538A74F42B9655BB7675CBF736AC87F76CC867CCE8E84D4998FD79E92DAA59A
DFAEA2D2A69BD9AEA2D9ACA3DFB3ABE4B8B2E8BCB5E7BBB4E9BAB3E9B7B2F1BEB9ECBFB9
DABDB6CABFB8D9D7D3DDDCDCE0E1E1E1E2E2E1E2E3E0E0E3E0E0E3E0E0E2E3E0E2D9C1C1
975451992B27A1211BA11A15A117139F100FA00A0CA20409A30107A60107A70107A80109
A80108A60007A50106A40008A5010AA5000AA50009A40008A40106A40107A6020AA50108
A80308AF0609B30509B3040AB2040AAE020AAA020AA90109AB010BAC030EA8010EA4010C
9E010A9300088001057701027C01057C01047600026D01026300015E01015B02027E2E29
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00944D17895C50D1C9D2C1CED6BCCBD36C7A8168666E30202ACDC5CFC3C9D2191F27
17090A381707B185514B10005B03027E030899040DA3060EA1060B9C0207A20408AE070D
B7090FBC070DBD0810B2020BAD0109AC010AA80209A50106A70108AA0009A80108A9020A
A90006AD0107AF0207B1020BAC030AA601089B0103A00105AF070DB0030CB3060CB60610
B2040DB40A10A10A0E88100FA23F35AE5648B56858C47F71CC9080D59F90DDAB9DE5B7AC
EAC4B8E8CABDE9D1C6EDD6CEECD8D1EBD9D3ECD9D6ECDBD7ECDCD8EBDEDAEBE0DAE7DFD9
E3DFD8E4DEDAE5DFDBE4DEDBE5E0DDE4DFDEE5DFDFE8E1E1E6E0DFE4DFDEE6E1E0E7E2DF
E1E0DCEAEAE6E6E6E6DEDEE0E5E6E8E3E4E5E1E2E3DFDEE2E0DFE3E0E0E2E3E2E4DAD3D3
D3BCB6C99F97D09891C0817AAE6961A1544C9B3E3A9018179A0509A50108A50007A60007
A80108A70107A40005A50108A50009A50009A6010BA40008A70308A60107A50109A40109
A60308AC0509B20409B5060CB3050CB00309AF040BAD020BAC020BAB020DA8010DA4020B
9D010994010A8102057100017701057A01067601037001036701026002015A03027D302B
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00954D1883534ABDB2BCCDD7E0A1B0B86F7E836B6C71332730D4CED7AFB7C110161D
18080654301C98683B4806006305067F020898040D99030B9100068E00078E0005990005
AA040BB8060CB9070FAB0109A50009A9020CA8030AA70107AC030AAB0209A9020AA80108
AB0207B1040AAF0207B1020CAD040BA8030B9C01069E0006AE070EB1040DB4070DB4040E
B3050EB10911920B0F450201AE8B82E4C8BEECD7CEEBDAD5E7DDD3E6DCD3E6DDD7E5DBD9
E4DCDAE3DDDBE1DDDBE3DFDEE3DFDFE4DFE0E2DDDEE2DBDDE5DFDFE5E3E2E0E1E0DEE1E1
E0E3E3E2E1E5E0E0E2E0E1E2E1E3E2E0E2E4E2E3E6E0E1E4E1E2E5E0E1E3E0E1E3E0E3E3
E1E5E5E3E6E6E5E6E9E2E2E5E4E4E6E2E3E3E1E1E3E2E0E4E0DFE4DFE0E4DFE0E3DCDBDC
E4E0E0E1DADAE4DADAE2D6D6E1D2D1DECBC8DAB8B5A55C5C890A0E9E0108A60109A70108
A70007A60107A60107A40107A30108A50108A50009A50109A40208A50108A3020AA0010A
A4020BA70108B1050EB2040DB0040CAF030AB0030CAF040DAD030CAE060FA8020BA5010A
9E01099201088601087A01037801037C02067600046E01036500025F0101570100792A24
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0099511C78473DB2A7B0CFD6E0A1AFB78C9CA06E70743E373ED7D3DC9099A20B0F16
1706047650317746274D0A015E020483040D9A050F98020B9101088F01098F00059B0108
AB030BB6060DB5060DA70008A10008A50107A60108AA0208AD0208AB0109A70107A80108
AC0308AF020AB0010BB2030CAC0208AD030AAC040BAB020AB3060FB4040EB3050EB4060C
B5060DB50811A11117430103786767D3CBCBE4DFDFE2DFE0E1E0DEDFDEDCE2DEDDDEDCDE
E0DEE0E1DFE1E0DFE1E2E0E3E1DEE2E4DDE3E1DBE0E0D8DFE3DADFE0DAE0DCD9DDDAD5DB
D9D4DADCD3DBDED7DCDCD6DBDFDADDDCD6DADAD2D8DCD3DADDD5DCDBD4DADCD5DBDED8DD
DDD9DEDBD7DCE0DAE1DFDBE0E0DDE0E2DEE2E4DEE5E6E0E7E3DFE3E2E1E5E1E0E5DCDCE0
DFE0E4DFDFE3DCDCE1DCDBE0DAD7DCD9D4D8DDD0D2AB7A7C7E10159C030AA60109A70209
A60108A50006A50106A40107A30108A2010AA3010AA40109A40008A400099F010B980009
9D020AA40109AD030CB0050EAC020AAD010AB2040EB0050FAF050FAB040CA70209A40107
9C01069000068801088201067D01047B01057501036C01026301015E01025801016E1E17
2F880200FF0000FF0000FF0000FF0000FF00
00FF00954A165B291EB3A6ADB3BBC4BAC7D08B989F4E4F54494349D8D8E06A737D0B0A14
1B0705936B454F1F0C4807015B000180020B98040D9701089200069400089C020AAB040E
B5070FB90710B3050BA80107A50107AB020BA70107AA0107AF0309AC0209A90108AA0108
A80108AB0109AB0106B0040AAA0108AE030BB0030AB4050CB3050BB3040BB2050BB40710
B4060CB7060FB2121967070D503436C9BFC2E8E2E4E6E0E4DFDADDD9D1D5D9CDD2D3C6CC
CDBFC4D0C0C5C4B0B7C3ABB5C7ABB2C4A2ABC19FA9C29AA7C89DAAC799A7C0929EBF8C9C
C18C9BC78E9CD599A8D699A7D697A4CE8C9AD593A0D5909FD995A5D592A2D695A6D092A1
D69BAAD09AA8D39EADD1A1AED5AAB5DDB4C0D8B3BFD4B2BCD1B2BBD6BDC6D2BDC6CEBFC7
D0C4CDD4CBD3D3CED5D8D3DADCD5DCDBD4DCDCD2D8B591947E1E239A060EA60109A8020A
A8010CA60008A40006A40107A40007A3020AA3000AA3010BA3010CA4010CA3030D980109
980009A1010AA60108AD050CAE040CB2050EB2060EAF060CAD050CA9030AA7030AA30108
9A00068F00058801078301067D00057A01077400056C01026201015D01015701016F2019
2E870100FF0000FF0000FF0000FF0000FF00
00FF00924A185C2B23AC9DA2ADB5BC929FA8808B914F4D525F575FD5D6DF3C455007050D
1F0B019B724A400F014B030169020686010A99040C9C01099B0109A1010AAB060EB00610
AF0810B20912AD060BAB040BA90209AC020BAC0209AC0109B0010BAC0109AC020AAC020A
AC0208AC0109AD0208AE040AAE0509AF020AB3040BB3040BB3040AB3040DB3050EB4060F
B5060DB80711B40A14900A13520B0FD9AFB5E6C4CAE0BBC4D1A5B0C68F9DC28490BE7A85
B56A77AA5A69A34F5B9E4351A03E4B9F39459B343F9F31419B293A9B25379C24359E2133
A12133A51F30AC2233B22233B72433B61F2EBC2432B82130B92233B71F32B82134B21F31
B22233AF2332AF2638AC2A3AAE323FB23B49B54152BD4B5EC25465C55D6FCA6C7EC47183
C3798AC88495C18897BA8B98BA909DBA97A2BEA2AAB48A8F8F343996070EA6020AA7020A
A6000AA60009A50107A30006A50108A40109A2010AA2000CA1000DA3010CA3010B9F0109
A0030BA00008A40007A9020AAF050DB2040DB3070EB1070AAD050BA60108A6020AA2020B
9B02099100068901078001057B00047800057401036D01036501025D00015701006C1D13
31890200FF0000FF0000FF0000FF0000FF00
00FF00944C1A4D1B11A09295A5ACB06A767B838B91605D636E666ECFD1D9252C35050205
351F137F59373B05005903077D040C90030B9C030CA1010DA5020CAC040FAE050EA4030F
940107970309A10409A70308A90209AA0108B0030CB1010AB20309B00208AE0106B0020B
B2040AB00108AE0108AD0107AD0107B1040AB1040AB3030DB2020DB2010DB4060FB4040E
B5060DB60711B60811AF0D1699111AB84752B64A55AC3A49A42838A62132A51B29A81928
A61322A5101FA50F1CAA111BA90E17AE121CAF141DB1131CB1111AB2111BB5121EB40D1A
B70E19C2111CC9121CD0141FD3151DD31319D6151AD4131AD3131DD2121CD3131CD0111B
D0111BD2141ECB111BC60F19C20F18C2101BC41121C41122C91724C11221BA1425B11324
AE1526AE1B2CA61C2F9E20309927369C35459F414FAD515DAB343F99030DA6020AA60108
A50108A40007A30006A30106A30107A30109A2010AA3010CA3010BA4010AA40009A30009
A20109A20108A00005A50107AC020BB2050FB3060EB1060DAD050CA70109A301099E0109
9A01089201078900058000047A01047801047401036D02036301015B01005601006E1E14
31890200FF0000FF0000FF0000FF0000FF00
00FF00964E1B4D1611A492988A8F968F999D7A82853532397B777DC1C4CB14181F0C0102
593D286A432B3D020164030886050B95010A9F030EA5020DA7010CAE040DA9050E95010A
85000584000498050DA5020BA50007A80107AF0309B2020AB50309B30308B20208B5020B
B4020AB70309B60208B3020AB00106B20408B00509B1040AB3030DB3010DB4040EB4030D
B5050DB60610B60610B50710B40A14B8111BB9131DBB111DBD0F1BBF0E18BF0F17BF0D19
BB0A16B80813BD0E16BA0D13B80B13B70A13B70C14B91217B71115B71014BA0E14BF0C15
C40D14CD1017D21118D20E15D50F14DA1315DA1113DB1318D40D14D60F15D70F13D50E13
D30E14D00B12CF0C14CC0B13C90B12C60812C80914C80A13CE0E15CA0A11C50911C40913
C10712C10B15BB0714B50715AF0915A80915A006159D09179D0511A3020CA70209A60008
A40006A20005A50108A40107A20105A00005A00007A4020AA30109A20109A30109A4000A
A4020BA10007A00105A20004A70007AE040DB2040FB2060FAA020AA9030BA5020A9C0106
9601059101068A00058001037900027501027200016B01026001015A0100570100701D15
31890200FF0000FF0000FF0000FF0000FF00
00FF00974E184F170F927C828F9097727B7F5D65672221268F8B92AFB2BA0C0B11170403
805B3D471A104904046B020786000798030C9E010CA4010DA7020CAB040EA3050B8C0006
7E000380000591020B9F010CA20108A80207AB0004B20207B50208B40109B50309B7030C
B7020AB70208B70207B60209B10107B2040CB1040AB3040BB4050CB6050FB5030CB8040F
B8050EB90711B7070EB8050EB90810BA0A12BA0911BB0712BD0913C00B14BF0B13BE0A13
C00D18BC0811C20D15C00C15BF0E16C00E16BA0B13B70C13B70D12B60B0EBF0E12C91115
CB1113D21118D41217D40F13D71113DE1718DD1416DB1217D50E15D30C12D71014D60F13
D50F15CE0B12CC0913CA0811CE0C15C90913C70610CB0911CA0810C6040DC80811C50811
C2060FC3080FBE060EBA060FB1010AAF040BAA030CA9030BA6020AA7010AA70108A60107
A30007A40107A50108A50108A30108A10007A10108A3020AA10109A0010AA2010BA2000B
A20109A00107A00005A20006A70209AB010BB0040EB2070FA9010AA7020BA200099C0005
9801059001068A01078001057801027401017201026C02036301025C0100590101711D17
388F0800FF0000FF0000FF0000FF0000FF00
00FF00964E19481108947D8295999D596464535C5C26232899929B92929C0B070D1D0602
8F66463C0A0254060A73040C8A040A97030B9C0109A3010BA9020CA9040F9B040B860106
7E00068300088F030B99010A9E0108A50107AA0107B1020BB3020AB7020BB70209B8030A
B70408B60309B6040AB40409B2030AB2020CB3040BB20109B20208B5020DBA060FBC0510
BB060FBE0710BB070EBB070EBD0910B8050DB90710B90510B8070FBA0912BA0A11BB0C11
B70910BC0A14BF0B14BD0914BE0D15BF0B15BD0C14BB0B15B6080FBF0F12C71113CE1214
D11013D31017D41116D60F14D71113DB1415DE1718DB1317DA1217D70F15D60E13D20B0D
CF080DCD0810C8060ECC0813CC0915C80611CC0812CD0911CA0810C6040DC70711C40711
C1080EC2090EBE060CBA060EB4040CB0040CA80107A60107A80209A90109A90109A50108
A50007A50108A50107A50107A10007A00109A00007A001079E00079F0009A3010BA30109
A20106A00007A00008A10008A40109A9020AB0050EB40811AB020BA60109A201099D0107
9600068D00068700077F01067600037301017101016E02036702035F00015B020168120D
3A910A00FF0000FF0000FF0000FF0000FF00
00FF0067720E4610059881837375796A747562686A141115A29BA2636369070207260F09
82573E3401004D00046C010788020A9401099E040CA5030EA6010AA7030F920107800004
7F010883010A8A0109A3101AAD151D9D0007A8020AAE010AB2030DB3020BB50209B70209
B70408B40309AE030AA20207A00207AE020BB7060BB60309B30208B5020CB9050EBE060E
BD050DC1080FC20A0FC40A10C30A10BE050DBE070EC10A12BE0B10BE0D13B90B11B80B13
B2040DBA0A15BD0C14BD0912BE0C14BF0B16BC0914BF0A15C10D13C40D11C70F11CF1116
D21017D20F17D41015D71015DA1315D91214D81114D71014D91116D70F15D91116D71012
D40D0FD40D11D20C13CD0911CC0912CC0912D30E15D00A10CC0910C6070EC1060EBD050E
BB040BBD060CBB060DB6030DB0020BAC030BAA030CA70008A80109A80109A70108A50007
A50007A50106A50107A50108A10109A001099D0108A002099F0107A00208A5010AA50109
A30107A10107A00108A00009A10109A4000AAB020DB10512AB020CA50109A000089C0007
9600088E01088700078001087601046F01026F02026E02036701025F00015A0100610905
388E0800FF0000FF0000FF0000FF0000FF00
00FF0066700E490F07886D6D7472756C7275525757141113A9A3A8434348040102351F19
653D2A3B05034E00066D020A87050C8B010797020BA0020CA7020CA7040D8F0005800004
80010880010A7E010695061099070F950106A5030AAB020AAC0109AE020AB2020CB6040C
B7050CB30309AB03099A0103920000AC040AB9070AB90509B70308B7040AB9050EBB060C
C30B10C90C13C6080FCA0C12C90C13C5080FC50B11C50D12C00D10BC090EB90A0FB7080F
B80911B80712BB0712C00B14C10A14C10A16C10C16C60E18C60E13C90E12CA1013CB0E14
CD0E15D3111AD41016D81317DB1416DA1313D61112DA1417D81015D60E12D60E12D60E10
D81013D70F13D20B11D00B13CC0810CD0911D30E15CD0912CA0810C4060DBD040BBA030C
B9030BB70209B7030BB5030DAD020AA80109A8010BA8020CA60108A60007A70107A60007
A50106A50107A40107A10107A00107A00107A00008A001089E02089D0106A2020AA20109
A100089F00089D010A9D01099E010AA00109A5010AAE050FAA020CA6010AA2020A9B0109
9501098D01088700078101067301036600006901016D01026A01026301015C01015D0501
378B0600FF0000FF0000FF0000FF0000FF00
00FF003995015318107F63628B8788595D5D4244421C1717A5A2A526262A05000150392A
3F1B1337000359030C7A050F88030B84000492020B9F030DA5030CA2040D8F0107840005
8001077C020970000482071085050A880005A1020AAB030BAD030BA90108A60006AA0108
AF0308B5050AB2050CAC030BA60308B3040BBB050BB90308B90409BA060DB50109B50106
C30B0FCE0E13CE0C11D31016CD0C13C6080EC50C11C30C12BD080FBD0912B8050EBD0A12
BC0A11BD0C15BD0914C00912BF0810C40B16C70F17C70E15CC1216CD1114CC1011CC1215
CB0E12CE0D15D11116D41215D31012D91516D71213DB1618D91415D81113DB1416D91013
DA0F13D81013D50D11D30D14CC0810CD0B13C8050FC7050FCB0913C3050EBB030CBA030D
B9010AB7020AB8040CB3020BAE020BAB0209AA030BA6000AA7010AA60107A60004A70207
A40107A40008A20108A00005A10006A30107A201079F01099901069701069D02069F0105
A102089D01089B01079B01079B00079E0008A20109AB050DAB050FA6010BA1010B9A010A
9300098E00098800088101067802046B01016B01026D01016B01016602015E00015B0200
33870200FF0000FF0000FF0000FF0000FF00
00FF003B9701430A038163636B66675A5B5C6362612D2727A8A7A91212140600005E4433
2706013901055E010A8003108C030C8C000895020B9C010AA0020A9C020A8F0107870006
8501067D0106670103620104690001830105A2030BAC020BAA0308A10004A00004A40005
AC0207B5050BB30209B30109B5040ABA050CBE050DC0070DBE060BBF0810BA040BBE070C
CA0C11D10E12D51114D50F14D51118CB0B12C3090FBF0910BD0910C00D12BC090EC00C12
BC0B0FB90B0FBB0B10C20B12C70F15C80F15C71015C81115C81113CB1215C91014C81215
C51413C71517C71517C71416CA1616CE1816D21B18D41B19CF1513D01512D71919DA1719
DC1317DB1014D90E13D40B11CD060FCC0811C90712C6040FC80712C2050FBB020BBB020B
BB030BB7010AB5020DB2020CAF030CAD020AA90108A70108A60108A60308A50207A40107
A40108A20108A10107A00006A10106A10107A101099D01089401059200039700049B0004
A001099F01089E01079C01069C00069E0108A1010AA7030CAC0710A6010A9E0209900107
8C02098D020A8801088101057A01037202026E01026F01026D01016801016101025B0100
65100300FF0000FF0000FF0000FF0000FF00
00FF00399500460A027251536E68696A6A6C4544443E383A9B9B9D0708090B0401533D2E
1C01003A01065F030A7F010E8D010C92000A9B040D9D020A9A000997020A9101098E0108
8D01088A020A7A060E9F3B4295282C93060DA4020AAB020AAC0408A70104AA0306AC0308
AD0306B5060CB60409B8040BBB040BBC0309BE050DC0060DC0070DBE040DC0060CCB0D13
D00D13D41013D00E0FD20E12D41014D00E14C90E14BF0810C10F14C11214BD1111BB1212
B71412B71613B81614C11617C31415C51215C81316C70F13C91113CA1217C1121AAC161B
AF2C27B23631B13835B43B38B63D39B9413BBE443EC54842BF3F3ABE3D3AC33C3AC52A2A
CD161CD10B11D60D12DA0E16D30B15CF0913CD0912CB0811CA0710C60610BF040CBE050C
BD040CB8010BB3010CB1020CAD020AAD030CA9010AA70108A50007A40109A20008A40007
A50108A30107A00106A00007A00108A1010AA1010B9C00099902089401049601059B0106
A0020BA1010B9E01079D01079C00089C00099F020B9D0109A1040DA1030D970209820004
7D00048301098001067D02067A01047400027200037100026F01026901016302025A0100
64100400FF0000FF0000FF0000FF0000FF00
00FF003A95004A0B04714F51877F7F5E5C5C3835324D45477C7B7E0201021C130E432F25
1800003601045D02087F030E8E020D93010B99020B9C010C96010A93000B92010B92010B
93010B93020C950F1AB73B46A31D269F040BA60208AC020AB10409B20308B20308AF0208
B00209B30309B70409BA040CBA020ABC040CBE070CBE050DBE050BC4070EC70810D00C12
D20E13D41014C8070CCE0B11D00E11CE1113C41013B81015B4191BAF221DA92C25AD3C35
AA4138AF473EAF433BB03B35AD2C28B12320BE211FC21817C71515C81518A70D13590001
AC7774E1B6B1E5BCB6F0C8C4E9C2BDEFC7C2F3CAC5F2C8C2F3C7C2F3C4C1FBC4C4F1999B
B92A2DC60F14CE0A0FD50C12D60E15D00910CF0910D00C10CF0C11CA0A11BF040BBA0308
BD070DB5020CB0010BAE030BAB0209A8020BA7010BA6010AA50009A5010AA40009A40008
A50007A30106A10106A20208A2010AA1000B9F010B9D010A9C01099B01099800079A0108
9C01099E010A9D00099D010A9C000B9C010C9C000B9501099100089C061195030E840308
7A00057C01087300046F00037402067501047100036F01056F0105680103620202590100
630F0300FF0000FF0000FF0000FF0000FF00
00FF003B96004B0B017C58596D656452514F4742405952556160630401022F211C2A1714
1900003700015B00047C010A89000A92020B97010A99010D92010A91000A8F010A91010A
91010A93010B91010C95030EA1060FA40208A80307AC0209B0040AB2040AAF0307AF0209
B4050CB5020AB60309B6010AB9040BB90109BA0207C0050CBF050BC60910C6060ED00D12
D20E10D40C0FCB080BD00D11CF1215BF1314AB1B1A8B1A1B933E38BE7E75DBA9A1EEC5BD
EACAC0EAC9C0E5BFB9E7BCB7DCA8A3D08B85C06962B1413BB62A26BF2120A71B1C450204
665A5EC8C8CAE7E3E1EBE5E5EBE6E5E9E5E4E7E3E3E4DFDEE9E4E4E5DFDFEFE3E4F5CCCE
B5494EC1171CCB090FD50D12D50D12CF080ECF0B10D00D11CB080EC5060DBD040AB9040A
B9050DB2010AB0030CAD030AAA020AA7010AA7010AA70108A70109A50109A20009A10109
A10107A10107A10108A20209A20109A0010B9F000B9F010A9C00089A0106990007980007
9A00069C01089C01089C00079C01089C01099E020A9C010C96020D95030F88020A790104
7C02077F01077B03086C01036B00027301047001026E01046D01046801036202025D0200
67120600FF0000FF0000FF0000FF0000FF00
00FF003B96004B09006F4D4D6961636B6A6A353331706B6C404043040001402E26190503
2200024502056002057701078201058F020B94020A95020C8F00098D01088F020A91010B
8E010B91010B91000A98020BA00309A20106A60105A80106AB030AA80107A40005AA0106
B20409B7030CB20107B6020BB8030ABF060CC1060DC2060DC2080EBE030AC2050BCC0B0F
D00D0DDA1214D40F11CF1415BD191B8A13117B322CB68D86E0CBC3E7DCD7E9E1DFEAE4E4
EAE5E4E6DFDFE6DFDDE9E2E2E6E0DDEADDDAE8D4CFE1BAB5D2918CBD5D599F3835521215
2E252BB9C0C4E0E3E5E3E2E4E8E7E9E3E3E5E3E3E5E5E5E7E8E8EAE4E3E5E7E3E4F0DADC
C67478BD2128D41219D50D10D30C0FD10B11CD0910CB0810C5060DBF040BBA030ABA050C
B6020BB3020BB0030BAB0208AA0209AA030BA9030AA60107A80209A40008A10108A00008
A00007A001079D01079F01079E01079E010AA1020CA2010B9D0109990005990106990007
9A00079900059B01069D01089C01089D01079D01079C01099B030F91010D810108760001
82020789020A85030B7B02097300067503077001046C01036B01036902046201025F0301
6F190D00FF0000FF0000FF0000FF0000FF00
00FF003C97004C0A01664142857C7E605F601E1B1A8B868728282A070000412F26150100
2901014A02066101047101047C00038B010893020993020B8E01078C01098E010A91010C
90010E92010C94010B97010A9C020A9F0106A20106A90309A90209A50108A10004AB0209
B5070CB6040AB40309B7020BB9040CBD040CC1060DC2050DC2070EBF060CC40B0FCC0E0F
CD0B0CD30E11CC0F11B61418760A0C7B4544D9C5BFEBE5DFEAEAE4E2E3E1E2E4E3E5E5E7
E7E5E8E6E2E5E4E3E4E4E4E4E3E3E3E2E1E1E2E1E0E6DFDEEBDDDAEDD1CED7AFAB614242
131216A4ABAFE1E5E7E7E8EAE3E3E5E6E5E7EAE9EAEAEAEBECECEEE6E5E8ECEAECEFE3E5
D2969AB1292FD81C20DF1418D50D11D00A10CB060FC5040DBF030ABB030ABC050DBB040D
B9040DB4020AB2030BAE010AAC010AAC020BA80209A8020AA70109A50007A20108A10008
A10107A001079F000A9E010A9E0008A10109A1010AA0000A9C0108970005990106990005
9A01079B00079B00069B00079C01099B00079B010798010996020D8D020B820207830207
8B040A84010681010880030A7501066F02066A01046701046A01056801055F01025D0301
74201400FF0000FF0000FF0000FF0000FF00
00FF003F98004C0900754F50736A6B4F4C4D251F1F928D8F1413140E0806362520160000
2C00034E01056703077201047B00038A02088E02088B01088A00078B01098C010A8F010C
91010D92000B96030D97010B9801099B0006A10107A8020AAA0209A70108A50207AB030A
B1030AB6040CB7030CB6020DB8030BBD040CC0060CC5080FC3080EBD050ABB0407C70C0E
CB0C0FCF0F14BE1014820C0E4B1919C7B5B5ECE7E4EBEBEAE2E3E4E6E5E7E1E1E3E4E2E5
E4E2E5E6E4E7E2E4E3E3E4E6E2E1E2E0E0E0E2E2E0E3E3E3E3E4E2E7E5E4E9E5E3D5D2D0
6E72718A8F91DFE1E3E9E9EBE4E4E6E1E0E3EBEBEDEAEAECE9E9EAE8E8E9E8E8E9EAE6E7
E8C1C6B04149CB1A22DC1219DA1016D20B11CB070FC3020ABF030ABE040DBA010BBD060F
BA050EB6020BB4020AB10109B0030CAB020AA70108A70109A70109A60108A40107A30107
A20006A10007A0010BA0010CA10009A3020BA1010B9F020C9A0209940005970106970005
9900079C01099D01099D010A9B01099A010798010793000596020A90020A810004850208
8B030A8301067B00027F02067600046D00046801056501046902056501025E0101590100
66120700FF0000FF0000FF0000FF0000FF00
00FF003D98004D0A00744F4D655D5C5854552C26288D888C09070919100F241311190101
3101035001046902067401057B000484000784000784000785010988010A8800078B0009
8E010A92010A92000A94010A9600089B0106A10209A7030AA60207A40107A30106A80206
AF0108B5040CB3030BB5010BBA050BBE060BC2090BC5080EC6090FC1070DC2090EC4080E
C6080FC60D13B0181E4E03048E7877E0DAD9ECEAE9E8E8EAE0E0E2E6E4E7E4E4E4E1E0E3
E0E1E0E3E3E5E1E3E2E2E2E4E3E2E5E4E2E4E3E2E4E4E4E8E4E5E9E5E8ECE5E8E9E6E7E8
E6E8E7DDE0DFD2D6D7E7E8EAE7E8E8E4E4E5E9EAEBE9EBEBE6E8E8E6E8E8E7E9EAE7E6E9
F0D8DDBD6871B91B24D6131BDA0F18D70E14CE090FC6060BC3070CC0050DBF060FBD050E
B9020BB8030CB6020AB4010BB1020BAD020AA80108A60108A7010BA6010BA50109A30107
A40108A30108A2000AA1000BA10009A2010AA2000BA1020D9B030B920006940106980006
9A01089E010AA1010A9D00089C02099B00089A02099701099B030B9C040E93040B8A0107
8B00088D020A8701068601068202077301056601036301026401026402035C0202540100
5F0E0400FF0000FF0000FF0000FF0000FF00
00FF003F99014B0A00613C39756B6A6D69692B2428827C810501022A1B1B1B08071D0000
3300015401056C02077100057701057E01097C01077B00097E000B85010A8903098A010A
8B02098E010A90010A97030C9A010A9B02069E0007A40208A101069E00059B0003A10003
AE040AB4030DB2020CB5020CBA060CBE060CC0060CC5090FC1060CC3090EC60A0FC4070C
C80C13B90A10880C11360E0EC3BCBAE7E6E5E6E6E6E8E8EAE8E8E8E8E8EAE6E7E7E2E2E4
E0E1E0DFE0E2E1E3E2E6E2E5E6DAE1D2BAC5C7AAB9D0B9CADACEDEE4E1ECDEE1E7E2E6E9
E6EAEBE8E9EADDE1E2E0E2E1E7E9E8E3E5E5E6E8E8E4E8E8E3E7E8E5E9EAE5E7E9E7E7E9
EDE0E4D597A0AD242DCB1119D71119D70E16D30E14C9080FC2050DC10610BD030EBB010C
BB020DBC040FB6010AB6020BB4030DAF010AAA0109A60109A50009A5010AA6020DA5000A
A6010BA5010AA4010BA3010AA3010AA2010AA2010B9F01099A0209940106960208990108
9A00089E0009A000099F01099E010A9D01099D010B99020B9302079C050CA0050C9E040C
9B030C94020B90030A8E02088602087702076802036002035B00015B01025602034D0100
5D120800FF0000FF0000FF0000FF0000FF00
00FF004099014A09006E4A47766C6A534F4C392F306D666B0500002C1919140101230102
3D01025E03076B02047001047402047601067702077800097D010B83010B87020C86010B
82000681000788000895010A9B010A9B02079E0008A7030AAA040BA60108A10006A30005
AC0208B6050FB0000AB3040BB9060CBD060DBF050CC3090FBF060BBC040BC1080FC1060D
C1070EBA12186C080A3C2727CDCBCBE3E3E5E6E6E8E8E9EBE9E9E9E4E5E7E8E8EAE5E3E6
E2E2E2E4E3E5E7E4E8E8D8DEC38F9AA34659982A3E91294286354C925E74B09BACCACAD5
DBE0E5E4E6EAE4E8E9E5E6E8E5E7E6E3E5E5E5E8E9E3E6E8E4E7E8E4E6E8E7E8EAE5E5E7
EAE2E6E1B6BFA7343FC71821D7131BD40F17CF0C14C90911C2040DC1060FC0060DBE050C
BA030AB90109B8020BB7030CB5030BB3030BAD010AA70008A50007A40109A4010CA5010A
A7010BA5010AA3010CA1000BA2010AA2020BA000099C020A9203098801078F030A96010A
9A010A9C010A9F010AA1010CA1010DA1000CA1010C960108850002900206A80810AB060F
9F040E8801078402078E030B8101056B01026502045B00015400015800025802044E0000
62160C18C50100FF0000FF0000FF0000FF00
00FF003F9A014A0A007553516A625F5854514A42444C474B0801023522220E00001F0001
4705066003046A020270010271010373000574000779010A7C020A7D010B81010A82000B
80000680000689020896020B9D010A9F020BA00108A8030AAE040CAC030AA60107A80208
AC0208B3040DB10309B00309AC0106B30309BC070CBC050AB50105BA050DBD060FC20710
C60A15B40E175D0305493638D4D1D4E6E3E6E8E7ECE7E8ECE5E9EAE8E9E9E7E5E9E6E4E7
E5E3E4E6E4E7EAE3E7D1AFB79E3946BE1F2DCA1823CC1827C6212EA61D2E6F11226B394B
A89AABCECEDBDBE0E5E2E6E8E1E4E4E2E3E4E3E4E6E4E5E7E7E8EAE7E8EAE7E8E9E4E4E6
E6E3E5E9CED3AE555EB81A23CA0E15CC0C14C80910C5080DC3060EC4060DC4060BBC0208
BB0409B8030BB7020BB6020BB50209B10109B0020BAC0209A80108A7030AA40108A50009
A50009A20109A20109A3010AA3010AA2010A9F00099A01088500046C00007301058D030C
9801099B01069C00089D000AA0010CA5010CA6010D9F020D920208940208A70710A9050E
98050E78000372000188050A8503096D01026402036002045B00035B0103590202530100
61120A318A0200FF0000FF0000FF0000FF00
00FF003D9900460A006847477269696965675E595B2F2C2E110807251313100000250001
4000015B00016900016D02026D01037001077201077301077101077400077F020A84020B
8401078300058A01079A040DA2030DA0010B9F0008A50109A90209A90108A80206A90209
AA0106AF020BB0030AB4060FB0020AB30209BA060BB90308B70207BF0810C1070EC60A13
CB0C18BB101A660509412E2FD6D4D7E8E6E9EAE9EBE9EAECE9EAECE7E7E9E8E8EAE6E4E7
E8E8EAE8E6E9EAE1E3B5858CA82A33CA161FD01016D61215E01D1ED81B20C11922981625
5D0D1F69485BA7A7B3C4C9D1DEE3E6E2E4E6E4E6E8E2E5E6E5E7EAE3E7E8E4E8E9E3E5E7
E4E5E6ECDDDFC28089A91F27C10C14C70B11C6090EC70A10C3040CC8060DC7080DBF040A
B80109B7020BB7020BB6020BB3020AB1020AB5060FAD010AAA010AA7010AA7020BA6000A
A50008A50108A50108A50008A4010BA2010CA0000A9C01098F04097703056A0001800207
96020A9B01059D01089F010CA3020DA6010CA6010CA3020C9E030B9A0108A1040DA3050E
96050A7F01047A020584010889020A7802066B01026A0205630001590001550202510100
5D0D0632890200FF0000FF0000FF0000FF00
00FF003F9C03440B006C4B4B83797B4440466C676B1F1A1C180B0B1906071A0101350304
4B02025F02026A02036D00036B01056F01067201057201076D00037201057C010984010A
8201058500078B010897030C9F030E9D01099E0007A20008A40106A60107A60107A60006
A80007AC010AB0010AB3030AB5040BB8050AB9070CB4040AB8060EC20A12C1080FC10810
C1040EC0121975090C31181AC5C1C5E5E2E8E4E4E6E8E8EAE3E4E6E7E7E9E7E7E9E7E6E8
E7E7E9E9E8EBEFE6E8CC9CA3A82731CB161DD21014DC1417E01819DB1417D71618CA141A
B117227310203615256F6B78BFC3CADFE3E5E1E5E6E1E4E5E4E5E7E4E5E7E3E5E7E5E7EA
E2E3E5E7E1E3D1A5ABA02B33C3161CCA0F14CB0C12C90A11C4060FC3050EC4070EBF050B
BE050CBA030AB70409B60309B20209B1010AB0010BAF020BAC0009A90008A80108A80109
A70108A70208A40107A00007A0010BA1010CA0020C9B01099401078701057A0103840106
9602089C02059C0106A0010AA2010BA40109A4010AA0020A9801099B040C9E030C9B0107
A00A0E8F04098803098801078802097B01057100047101046D03055D01025000014D0000
580C042E880100FF0000FF0000FF0000FF00
00FF003E9A01460A007E5A5B7166673E393B767072100A0B2517151302021D0000390202
5302026503036C01026D00036C02067101077602077502087101057400057C0107830109
82000588000989010892000A99010B9C01099F0006A30106A50004A50106A50108A50008
A70209AC010AB2030CB5020CB3030BB00309A90206A40005A80107B80710B5030BB5010A
BE060FC01019890C122A0507B1ADB2DFDEE3E8E9EBE8E8EAE6E7E9E8E9EBE8E9EBE8E9EB
E9EAECE6E6E8EDE5E6E4B9BFA52E37C6141BD41216DF181CDC1519D60F13D30F12D20F14
CC1319B11A235306101D070F9D9CA2D8DCDDE2E4E4E4E4E7E6E5E9E3E3E5E5E6E8E5E5E9
E3E3E6E5E2E5DDC1C7AA4D54B7171FC60E13CB0D13C60910C0050FBB000BBC030DBF060D
C0070DBF060CB90308B70309B5030AB4010AB3010CB1010DB2010CAF010BAA0109A80208
A60107A60108A30109A00108A00109A0000B9F000A9C01099702078F00048901048F0106
9801089B00079C01089D0109A2020CA2000BA2010A9D01098F00069102099D060E9B0309
A0090F96040C8F020A8D02098403087903077402077302066F0205660304590100510100
580B0430890200FF0000FF0000FF0000FF00
00FF003F9B02480B00795455625657534B4E726B6F080102180A0A1101011F01003B0002
5802026802046B01036A00046C01057402087802087400087501087501067C010781010A
84020A8B010B8B010891010A96010B9E010BA20209A60208A60107A30107A20106A20109
A50107AB010AB1020BB4010CB5050DAF020BA80309AA040AAD0309B8050CB8030ABC030C
C1050CC30A12A6141A3A0102847A81DBDADFE6E7E9E8E8EAE6E7E9E6E7E9E9EAECE6EAED
E6E8EAE4E4E5E7E1E0EDCACDAC424BC71922D41118D8141AD61317D00C13D31016D41016
D01017C4171D7E0D142A00046B6269D0D3D6E5E6E8E6E5E8E5E5E7E6E6E7E2E2E5E4E3E8
E4E3E7E1E0E3E4D3D7B56F77A81B23C30F14CB0E13C1040BBE040CBC030DBC030DBD050E
BB030BBF060EBE060EBC040BBC060FB7010CB5010CB5020EB3020DAD020BA8010AA6020A
A60209A50108A10107A20108A20108A001079F010A9C0109990107940104900003950106
9901089B00089C01099C01099F010AA0000AA1010A9E020B96020B90010798030C99050D
91020995070F8B01088802097401066401026800036E01036C0103680203600201580100
5C0C05328B0300FF0000FF0000FF0000FF00
00FF00409C034809007B56548074743B31356A5F62090302180C0C110000280101460102
6003046901056901036801046A01057202077600067500087700097801097801077A0008
8401098E020B91020A9100099500099E030B9F0009A10109A20008A10006A30208A40009
A50108AA0109AE030BB0010AB2020CB2020DAF050DB0040AB7050CC1080DC90B10CB090F
D30E13D8131AC41C215B050748363CCFCDD3E6E7EAE2E3E5E5E7E6E5E6E8E8E9EDE6E7E9
E9EAECE5E5E7EBE7E7EBD3D4B75E63C31F26D11319D4121ACF0F17D10F17D20F15D31016
D31115CB131A9E131A470005382328C9CBCFE4E5E8E4E4E6E7E8E9E3E5E5E4E5E8E6E6EA
E3E3E7E4E4E6E7DEE3CD9CA2A12A2FC1161AC80D11C80B12C2060DC1060EBF070EB9020B
B8030DB9040DBA030CB9050CB60209B7030DB5040EAB020BA4040B9F050E9A040D9F0610
A2040DA4020BA4020BA50207A30106A101089F010A9D020A9A0108960006920004960207
9A02099B02089A01079B01069C01079F01099F010A9F020C9E020D96000A8D01088F060C
8F050C91050C92040C8A020A7702086001036401037104076B00026300006002025A0100
600E07338C0500FF0000FF0000FF0000FF00
00FF00439C044A09008B6663776A6A372C30584E4F0601010902021702023704054F0202
6102016701046302026201026701036E0104730105750108760107750108740005790105
8302098A010A8E020B91000A9400089A010A9C00079D0107A001099E0007A00105A4010A
A60108AA0109AB0109AF030CAC010AAB020AA90108AB0108B00109BC050ACD0D11D30D10
DB1013DF1318D1191D7E0A0E2B1013B6B5BAE1E2E5E6E7E9E8EAE9EAEAECE6E7E9E7E8EA
E9EAECE9E9EBEAE8E8EBD9DAB36E72B6252BC91319CF1118CF1118CF0F16D10E13D20E12
D31013D01218B6161D6D07102C050AA7A6ADDBDDE2E5E5E7E9E9EAE7E7E8E3E3E7E4E5E8
E3E4E6E0E0E2E5E0E4DEBEC3A34147BA181EC1070DC50710C50811C0060EBE060EBB030C
B8030CB6030CB5020BB2020AB2020AB0030BA7030B8B02057A0102A12129CC4B57A6252F
8C030B9E050EA4020CA40107A10207A1020A9F010A9C0008990106970007930006910106
9502089A01099D02099C00079D01079D01079E00079F010A9E010B9A020B8D0106880104
970A0F9703089F070E95040D85020A7101066B00027301066E02056100005E01015C0201
5E0C06328B0500FF0000FF0000FF0000FF00
00FF00419B034A0800886061604F52463B3F3C3437080101080001180000380101530203
6103016302035C00015F01036601046C00057102067301087300077401077401067C0108
83010A8701098B010892010A9401089800079C02079B01069C02059C01079C0006A00108
A50108AB010BAE030CAD030CA60006A40005A70107AF040DB10208BB050ACC0B10D91114
DE1215E01318D314189D12172D0002928F95D9DDDFE9EAECEAEAECEDEDEFE8EAE9E6E6E8
ECECECE6E6E8E7E5E6EDE2E2D5A4A7A92D34C3161BCA1116CC1116CD0D14D10E16D30E14
D10F11D21015C4171C95121A4201076F676DCDD2D6E4E8EAE6E7E9E5E5E7E3E3E6DFDEE2
DFE0E1E0E0E3E4E1E5E9D4D8B2666CAA181FC00B12C2070FC1060FBF0510BD040EBC040E
BA050EB6020BB5020DB3020CB0010BA9020B96060C7000017302069008149A101EAC2B37
7B01078B02099F030BA40209A100099E010B9F020D9D010A9A01069401068C0005850002
8C00059A01099D01089D00089E010A9E010A9D00099C00089E020A9F020B9A020B930108
9A080E9E060CA0060D95020A8600077B02067201027301057202056602025D01015B0201
5B050032880300FF0000FF0000FF0000FF00
00FF00449D054A0800855B5D7C6A6F4E41452A25260F05050F00001B0000380101530101
5F02025F01025B00005B01016201036B01076F0107700107700006740106780106800108
8601088801088A00078F010A9201079500079701069801069700059A00089D01099F010A
A4010AAA010CAE030CAC020BA90109A70108A60006B4050EBC0810C4080FD00D12DA1115
DD1317DA1014D31015B315194602035A5358D2D6D9EBEBEEEAEAEAE9E9EBE8E9EBE9E9EB
E4E6E5E7E7E9E1E1E2E8E2E1E2C0C4A64249BD1921C91218CD1218CC0D14D01018D00D14
D20F14D31015CA141AB1161F61050C3E2C31C1C5CAE6EBEDE2E4E7E3E3E6E6E6E8DFE0E2
DEDFE1E0E1E4E2E2E5E7DDE1C692979E2029BD0F18C30A12C0070FBF050FBC050DB9040A
B9060CB7030BB6020DB7030FB5030FAA040E8403096800018B09129F030EA1020E9E0614
87030B81010799050DA2030AA2010AA1020D9E010C9C010A9A01089400059101068C0205
9001069901089C01079D01089C00089C01099C01089C02099D010A9B010A9A010C9A020D
9C060F93010899071090030B8101067902056F02056C01056E02046801025F01015B0100
5E070234890400FF0000FF0000FF0000FF00
00FF00449D04510B00875D5F705F635045471510100C0101130101280202430202580202
5D01025C01015901005A00025E01016901076D01066D01056E01047301057A0105810108
8401078701088800088D010A9101099201069400069601079700079A00089E030AA0000A
A3010BA7010BAB020AAC020BAC030DAA020EA60009AF020BB40309BD030BCD0D13D41013
D71112D60E12D20F14C0151A680A0C2C1C1EB9BFC2E6E9EDE7E8EAE6E5E9E3E4E6E0E0E2
E0E2E1E2E3E5E1E2E2E5E3E2E4D3D4B86D73B01D24C8131BCD1017CE0C15D10F17D10F16
D10F16D00E15CA0F17BE141B820F1328060AA5A6ADE1E5EAE3E4E8E4E5E9E3E4E6E2E3E6
DFE0E3E1E2E5E1E3E5E6E3E5D3B1B5963139B20F19BE0811BE0811BD060FBC060DBB070C
B6050AB3030AB5020BB7020CB7050FAA07107301055B0002880910A0040CA5020EA2030F
91070E73000287040A9E040EA2020CA1010B9E020A9B00089B0008990108960106940106
9A02099B00079C01079C01089C01089B00079C01099C010A9C030C920008920109960109
9A050F89010785020988030C7900046F01026701035D00016403056402045F01025D0102
60080466140800FF0000FF0000FF0000FF00
00FF00459E03520D008B61615648495247480A07070400011000013002044C03035C0204
5C02015A01015801005900025C00016700046B00066B01056C0103730107780105800009
8401098700078801078C00098D00099100099200079500089801089A00089E020CA0010A
A10109A00006A60207A90108A60108A5000AA9020CAD010AB40207BA0207CD0C11CF0C0F
D00D0ED20E12CE0B13C00E167F0A0F200305888B8FD1D6DADFE2E4E2E2E4E2E2E2E2E0E1
DFDFDFE0E0E0E2E4E3E3E3E3E8E0E0CB969AAA292EC8161ECE1018D10F17D41219D10F17
CF0D16D00E17CE0F16C40E15A3161C3B00066C676FCDD1D7DFE3E5E4E7E8E4E5E7E2E3E5
E1E2E4DFE0E2DDDFE0E0E0E1DDCBCE9C5257A4141CBA0B15BA0611B9050FBB060DB70309
B6040AB3040CB3030DB3020CB6040FA90A126B01044700006C060B90050E9B040C9A020B
8B080E640001730307990510A1020DA0010B9D01099D01079B00069B0207960006950108
9801099B00089B00079C00069E01089E01099C01099C010B9A010D920109910007960109
9A050E8A02097C00048302097F010876010673030A6101035B01025B00016001015F0102
61080566160A00FF0000FF0000FF0000FF00
00FF00469F044F0B007953506A5C5B483D410402020600011401003201014B0201580201
5802015301005101005401015A01016701066B01066E01066F01047300077B010881000B
85020B88010A8801088C01098E010A90000992000A9301089401089700079B010A9E010A
A10109A40108A60107A90209A60107A70008AE030CB8040DC60C0FCC090FD10C10D00D11
CC0B10CB0B12C80B12BD0B139711163101025C595DC1C5C9E1E3E3E1E3E2E1E1E1E1E1E1
E1E1E1E0E0E0E1E3E2E1E2E3E6E3E2E1BDBFA73D42C51921CD1117D20F17D00F14D00E16
CF0D16CD0B15CF0F17CD111AB7151D5B040A3F2E35C1C6CBE7EBEDE6E6E8E4E5E6E1E2E4
E1E1E3E1E3E4DEE2E2E0E2E1DFD8D8A67477931A1FAF0911BA0812B8040FB9060FB6030C
B7040CB6050EB4040EB1020CB2020DA907107403073E000044010366030B7B050C7D060B
6A0408500101680207910410A0030FA0020D9E020B9D02099B0106990208930107910006
9501079901089B01089D01089E01079E01099E010A9D010C9A010C97010A97010A97010B
9D041096040E85000786020B84020B7E02087903096A0003630103630203610101610102
60080467190D00FF0000FF0000FF0000FF00
00FF0046A0064C090086605F695A5D433A3D0200010800002002023D0303500201560100
5201005101025000015101015800006400036C02066D01066E01047201077A01087F000B
84010C87010B8600088A01088E010A90000A92000A92010A9500099800079C020A9E010A
A10109A50109A9020AAA010AA70007AE010AB9050DC2060ECD0C11D20C0FD10B10CA0810
C3070EC40A12C30A11C00B12AA11174F030734272BB6B7BCDDDEE1DFE0E2E3E3E5E2E2E4
DFE1E0E1E1E1E2E4E3E3E3E5E5E3E3EAD1D3AF5B62BA1C24C91217D10F17D10E15CF0C12
CF0E14D00C15D21019CE0D17C2111C7D0A1329080C9EA1A6DEE3E5E4E6E8E3E4E7E3E4E6
E0E3E4DFE3E4DEE2E2DDE1E0E0DFDEB9999A8E2B30A80D16B40710B6060EB70610B6040D
B4030BB5030DB3010EB1010EB1030EAC050F8A060D4D01013400014200044C00034B0002
3F000240000367020B9405139F020E9D010B9D020B9C01079A01069600089001068E0004
9400059900079C01099C01089D01079D01089C010A9E020D9B000B9A010B96020A900107
91010A94020D8901088302097E02097901077501067001026D0103670102620001620202
5E020162110900FF0000FF0000FF0000FF00
00FF00459E054B08009169664E393B372A2C0300000B0101230100400201500202530201
5100005101025201005501015901006300036801056800036C01037100047A02087E000B
82010A86010A86000989000A8D010A9000099100099201089601089900089C0109A0010A
A20109A6000AAA020CAB010AAB0209B4030CBB030AC70910CC0A10CF0C11CB0A10C5080F
C0060DC10610C30913C00910B50F17700A1020080B9C9EA2D3D7D9E2E2E4E2E2E4E1E1E3
E3E4E6E5E5E5E1E3E2E3E3E5E4E3E4EDDEE0C5878DAF242DCA161DCF0E16D20F17D00D15
D00F14D00D15D20F16D41018CF131BA0141C380107747177D4DBDCE5E7E8E2E5E6DEE2E3
DFE3E4DEE3E5DEE3E4DDE2E2DEE0E0D1BEC191454D9E131EAF0711B4050FB3040CB4040C
B3030CB3030EB30111B20312AF040EAD040C9F060D7503094800026124276427293E0507
3300033D00016B020A9604119E020B9C010A9B01099B01099B010A9601099101068E0003
9300049800069B00079D01089E010A9E010A9D01099C010B9C010C98020C8F01098B030A
8C020A90020B8802087502076801066801056B01037202037303066601025F0001600202
5D030062100700FF0000FF0000FF0000FF00
00FF0047A006500900734744553F3D271A1B030000090000240203420202500101520100
5201005100015101005801025B01016200036A01066B00046F01017300027A02067E0109
80020B85020D84010A87000B8A000A8E00099101089502099801089B02079C0109A00008
A10008A6010BA9010BAB0009AF040DB3020CBA050DC50A10C90A0FC90910C3070CC2070E
C0070CBF060CBF070DBE080EB90D14890D132B00036B6A6EC0C5C8DFE1E3E1E1E3E1E1E3
E2E4E3E0E0E2E1E3E2E1E2E4E2E1E1EBE1E4DCB2B6A53138C51A1DCC0E13D21116CF0D15
D11015D20F17D10F14D20E14D11117B7181E55030941353AC2C7CCE1E5E7DFE3E4E0E3E5
DFE3E6E0E2E6E0E4E7DDE1E3DDE0E0DFD4D5A26971911723AD0C17B1060FB1020CB3030C
B4050EB1030FAF0211AB000EA9010AAC030BA70409990C10811E208D4B4DCD90937B3C3F
42000159010584050D9C030D9F010A9B00079800079B000A9B010A970109930107930106
9601079800089A01089B01089D010A9D010A9C01089B010899020B8D010A7E0005810108
8A030C8C030B8503096800025100015C00056D02057401047303056502035B01015D0201
5C030165140A00FF0000FF0000FF0000FF00
00FF0048A206520C0071433D5C4643160D0D0100000700011D0000410203550303550101
5302015401035302005700015E00046501046B01066E0105700103730105760207770109
7201077502097A020A83010B89010B8A010A90020A9501099801089A01069B00069C0108
9F0008A40009A60009A90209AD020BAF010BB00106BF070CC4080DC60A0FC1070CBF060B
C0070CBF080CBF090DBE0A0EB90B119F11194202063C353AA6ABAEDEE1E4DFDFE3E3E3E5
E1E2E2E2E2E2E2E2E4E3E3E3E4E3E4E6E1E2E1C6C7A74C52BC1E23CD1318CD0E13CE0C14
D00E16D00D15D10E16CF0C14D00F16C1131A780B11290C11A7AAB1DCE0E4E1E4E6E1E3E5
E2E4E7DDE0E2DFE0E3DEE1E2DEDFE1E4DCDDB98E9389202BA70C17B10812B1030DB2020D
AF020CAD030DAD030FAA010DA9020BA80109A9030BA2060CAB2E32B1565C8F464D7E2F36
811D2386070F9B040EA4010CA1000B9C01099B01099B0109980108950108910006950007
9800089700089900089C01089C01079D02099B01079A01079402098201077600057F020C
7E01097C010584040B77050A5D01045A00047004087501037002045F01015801005D0201
5A03016A1C1100FF0000FF0000FF0000FF00
00FF0048A3094E0C008E615F4029270F04040100000A0000210101410203530202550204
5201005201005201005701025E02056501056A01056C01066B00046B00046C01067A0E14
A33D428220296501057B020A86010A8A00098D01099301099701069A01069C01079D0009
A10109A50108A50007A90208AE020AB4050CB5040ABF070CC3090EC2090EBE060CBE070D
BD050DBE060FBE080FBE0B0FBC0C12AB121A5D080C1F1012868A8DD8D9DDE0E0E0E2E0E1
E1DFE0E4E2E4E4E2E5E4E2E5E6E4E5E3E1E2EAD9D9BB797DAD2025C71315D11317D00F14
D31018D30E15D20D14D10E14CE0D12C8131999141B33000579787FCDD2D8E3E4E8E2E3E5
E1E2E4E2E3E5E1E2E4E0E0E3DDDDE0E1DCDECFB4B88B3840A0121CAF0811B50812B1030D
AD020BAA020BAD030EAA020CA6010BA5010AA5020BA7040FA30815981321A12A39A12836
9B131E9F0610A5010CA6020CA101099B01079A01099A010A97000995020A920006960107
9901089A010A9B00099E020A9E01099F020A9D01099A00069703098701078100058B030F
88040F7800067D020A7B02096E05085D00026904086D03066702045C01015900015A0100
590200681A0F00FF0000FF0000FF0000FF00
00FF0047A2084F0D017C4F4A361D1C0C02010400011101012601004001014E01024F0101
4F00015101025201005500025A01026301066801056A010666010363010266010289151D
89161F760C165D000571020B86030A8C010A9000099301089601079701079B01089E010A
A20109A40107A50107A90108AE0309B8050CBC050BC1060DC3090EBD040ABB050CBC070F
BC0711BD0713BD080FBF0A0FC00C11B410157C0D132001046B6B70C4C5C8DFDFDDE2E0E1
E1DFE0E3E1E4E3E1E4E3E1E4E6E4E5E2E0E2E9E1E1D0A3A5A42C2EC6181BCE1314D01015
D00D13D10C13D20E13D00D11D10F13CB0F16AF151C4F020A494147C2C9CEE2E4E8E3E3E5
E1E2E5E2E3E7E0E0E3E0DFE1E1DFE2DFDCDFDACBD09B5E6696171EB00C14B3070FB2040E
AF050DAE040DA9010BAA030DA8030DA4010BA2010BA4000DA5010FA505159F04139F0313
A40211A7030EA7010CA5010BA3020C9E02099C01069B0008970009940109930007970108
9801079900079C01099C010A9E0209A1010AA1010A9F01099C010995010991010997030F
93030E8600097F020B7600057103066501045E01025D01015D01025D01015E01025D0101
5B020164130900FF0000FF0000FF0000FF00
00FF0048A3084F0D0171453C2813100801000500001701013202024702034C01014C0102
4C00015001015501015701025801015F01056501046801056201035A000163000382040E
8A040E83040F6401056401067E020B8A010990010994010997010A9600099901089C0009
A00108A10108A3010AA7010AB1030DBC060DC1080DC80D12C2090EBC040ABA040CBD080F
BA0610BD0811BD080EC20B10BF090DBD1117950F163401034D484DB2B6B8E1E2E1E3E0E1
E4E1E2E0DFE2E2E2E4E4E3E5E5E5E7E5E3E5E8E3E3DEC0C1A74548BE1A1ECD1317D11218
D21017D31019D10E15D31116D11015CE1016BD131A730B122A1218A5AAB0DDDFE4E2E2E5
E1E2E4E1E2E5E1E2E5DEDEE0DFDFE2E1DEE2E2DADEB1878B8D2127AC0E18B50B14B2070F
AF050DAF070EA80209A60009A8020BA40007A5010AA5010CA4010CA3010CA4010DA5010C
A6010BA8010CA8020EA5010CA4010CA2010C9F01099B010798010898020996010898020A
9801089800079B01079D01099F0109A10009A1000AA2010CA2020B9D020C99030D960510
90010B8E030B8A030B7E01087701076F00066B03076101025F0102640204650303600101
5B010063100717C30100FF0000FF0000FF00
00FF0049A4094D0C00825A5121120F0601000901011800003903034D03034D01014D0101
4F01015201015801015901005701005B00036201056701085C02054D000069020885020D
8D020A87040B6B02065C00047A020A8901098F010893010797010798010A9801089A0008
9E030B9E010AA4030BA80208B4040ABC060BBF060BC1070CBE050BBC060DBA060DC00810
BF0811C10A13BC070DC20B0FC00A0FBA0811A710194F04092F22279D9EA3E0E0E2E1E1E1
E1E1E3E0E2E3E2E5E4E3E4E6E4E5E7E5E3E5E3E2E2E5D2D5BB7076B51F27CA131AD2131B
D3111AD00C17D31018D00E16CE0D14CF1016C5111995131B30000875757DCBCED4E1E1E5
E4E4E8DFE0E3E0E0E4E0DFE4E0E0E4DEDEE0E4E2E4C9AFB18D363DA5131FB00A14B10710
AF060EAB040DA9030CA7010AA9030DA5000AA20109A3010CA2020D9F010AA2010CA3010C
A5000AA6020AA7030CA4010DA2000DA0010C9D00089D02099C02099A0108970108970109
98010A9900099C01089D01089F0109A2010AA2000BA6020DA7040FA1050E900108860108
89020A90030C8C01098601088102097C02087A03097001056C02056401035F01015F0203
5901006C1A132E860000FF0000FF0000FF00
00FF004DA70C5310037A4F491709070400000800001B00013901024B02044900014B0102
4D00005300005701005901005701005B000062000363020654020444000169040980030A
86020A7F040B6302055A00047B040A8C020991010A93010A94000898010A9701079A010A
9C01099D0008A10107AC040AB4030AB9040ABC070CBB040BBB050CBA060FBA050EBF0610
C0070FC00711C0080FBF080DC00B12BD0A14B1101A6B070F21070E8B8A90D5D5D8E1E0E2
E0E1E1E0E3E4E0E5E4E2E6E7E4E5E7E5E5E7E4E3E6EADEE2CF989EA7262EC6171DCE1017
D10F18D40F19D31018D00E17D00F16CE0F16CA1119AC161F4902084C424ABABEC4E2E5E7
E0E1E3E0E1E3DFDEE2E0DFE4DFDEE3DDDDE1DFDFE1D8CACD97585E94141EAC0A14B10812
AE0610AC0510A7000CA6010DA6020CA2010BA00009A1020DA0030E9D010B9D01099F010B
A1000BA5020BA50109A3000AA1010CA1010B9F01099D01099B00089B010A9A000A9A000A
9901099900089A01079B01079F010AA2010DA4010DA9040EA7050DA6081397040E870106
8C030B91010A8A01088601088601098002087E02097801057301046702035C01015E0202
58000075251E2E870100FF0000FF0000FF00
00FF004FA90D561303683D381204030300000800002401013B01014A02014800014B0102
4F01025702025902015C02015B01016202046500056202084C020437000057030773050A
73030A6302075101065601047A020B8B010992010891000995000998010A9B01099D020A
9F010AA00008A50208B1050DB8040CBA060DB8050BB8040DBA050EBF0A12BC070EBC040E
BE070FBD050FC10911C20911BF0A13BE0B16B50E18870D172A000769646CC4C4CAE3E3E6
E3E4E4E0E1E4E1E2E4E2E3E3E5E5E6E5E3E6E4E4E6E7E2E5E3BFC3A43A40C11A1FCF1319
D31319D31019D20F15D20F17D00E16D00E17CE1019BD17216A0810291217A8ABB1DCE1E4
E1E3E4E0E0E2E0E0E2DFDFE2E0E0E2DDDDDEDEDDE0E1D8DDAD7F85871A22AA0C16AD060E
AC050DAB040CA9030DA6020DA4010CA2010B9F00099E01099D010A9C010A9C000A9D010B
A0010BA4010BA4020AA2010AA0000BA1010C9E00099F020B9D010C9C010B9A00099A0008
9901089900079A01079B01079E0009A2010BA8030FA8030DAA050EA90512A2041095020B
90010991020B89010886000786020A7900057401057701067301046B0205630103610101
5A01007020182E870100FF0000FF0000FF00
00FF004DA80D521202754E4B1006050300001001003303044902035003034A01024B0102
4D01015402015801015C01025A000063020568020864030B4703062800003801014D0205
4E01054400034100025801037D020B89000790010892000A95010B9700099801079C000B
A0020BA3000AA8030AB2060FB6070FB8080EB6050CB6020CBB0710BC070FBD080EBB060D
BE090FBD080FBE0A10BB060FBE0912BF0A15B609149F121D45020C3A3139B9BAC1E2E2E5
E1E2E4E2E3E7E3E2E6E4E2E5E6E4E5E5E3E4E5E5E7E5E3E5E6D0D3AA5C60B81E25CE131B
D01218D31117D11014D10F15D41318D00F15D01219C313198D111A2E0109858389D1D3D8
E0E1E4E1E2E4E0DFE1DFDFDFDEDEDEDDDDDCDCDCDCE1DDDEBEA0A4842831A5101AAC060E
AD060EA9020CA7020CA5030CA5020DA3010C9F00099E02089D01099F020D9D000C9E010C
9F010CA2010BA3030DA0000B9F020D9D010C9E010A9F020C9E010C9B010A990108970006
9801089901089A00089C01099F0109A5020AA8020CA9040EAA0712A3020DA60611A0030D
97020C87010783020988030A88020A7B02087200047401066B01035F0102630305620102
5C02016D1C132F880200FF0000FF0000FF00
00FF004FAA0F521406724E4C0802020300001601013B03044C02024E01014C00024D0101
5001015400025801005D01015B00016201036701046302074C0206260000260000330102
3901043A00044600026803078101098A01088F010892000A95010996000997010A9A010B
9D0109A5020BAC080FA20309A10409B30912B70611B8040FBB0510BC0710BC070FBC070F
BB080EBB0710BB080EBD0912BD0912BD0814BB0C15AC111C640811231017A3A6ABDDDEE1
E1E2E4E1E2E6E3E4E8E3E2E6E5E5E7E4E2E6E4E3E5E3E2E4E7DCDEC28990A9252CC8191F
CE151ACD1418CE1519CE1519D0181ACE1518CD161AC6181AA91E2546040B594F55C6C9CD
DFE0E3DFDFE1DEDEDFDFDFE0E0E0E0DDDDDEDFDFE0DFDCDDD0BDC19148529B131FAE0A13
AD0610A8010CA9040EA7030BA5020DA3010EA1020CA2040EA0010D9F020D9D010C9C000B
9C010A9C0109A0030D9E010C9D010C9B010A9B00089C010A9B00099A0108980007990107
9A00089B00089B01089B01069E0007A40109A8040CA7030EA807139D010BA50712A6040F
9D030E8402067700048202088301077B01077A0208740205670203550000570101620204
5D0001600C0430880200FF0000FF0000FF00
00FF004FAA0F551709623D390900000400001600003901024B01024D01014C00024F0101
5301015900025900005E01025F01016301036501036301035803053401012901015C3033
8355583E05085D03077A03098701088D010A91010A92010A920108930108960208980108
9A0106A7050DA8050C9702038D0001A7050FB4040FB7030EBA0611BB0713BC0611BA0510
BA0710BC0812BB080FBC0811BB0A12BF0B14BA0A12B40F18810F162101047D7D84CDD1D5
E2E3E7E3E4E9E1E2E6E3E2E7E2E1E6E1E0E5E3E3E8E2E2E4E7E2E4D5B5B79A4042B32D2F
B72A28B72A26B52B28B42B28B22B27B32C29B5312CB02F2C9D2F2E5C222345393CB3B5B9
DEE0E3DEDFE2DCDFE1DBDFE0DDDFE0DFDFE1DEDEE0E0DEE0DED3D7A06A728C1520A90A15
B00812AD040EAB040CA9040CA8030EA5020DA3020FA2010EA2010E9F010B9D020A9C000A
9C010B9B00089D020B9E010C9B000A9700079900089B010A990109990109990109970108
9A010A9B00099C010A9F010AA10108A3020BA7040FA90411A8091499020B9A050EA20611
9B030D8F050C7C00047E03087901047300047803097201056B0204610305580000630203
630203630C082F870200FF0000FF0000FF00
00FF004FAA0E551607542C250D00000B00002202014103034F03024E01014D0101500102
5401005A01045B01035E01025E00016201026201026201026304064B0203380309996B74
8E6269621D24760A1285020B8B020A8D01098E0109920108910106900106940008980009
9D000AAA050EAA040CAA080EA40409AF060FB70610B90410B90510BA0612BA0410B9030F
BB0711BB0812B7060DBA060FBB0A14BB0712BF0C16B90E179C161D3701044C464EC2C5CB
E1E2E6DDE1E5DFE3E6E4E5E9E0E1E5E3E2E7E1E2E6E0E1E5E2E2E5D9D1D0BB9996CC9491
D89B97D59B96DFA8A1DBA39ED69F9AD8A39ED7A29CDCA9A3D1A6A1C2ABA8BCB8B8C0C0C3
DBDADEE1E1E4DDE0E2DCE1E1DBDFE0DEDFE2DEDDE1DFDDE0E1DBDEBD999F87222DA50B16
B0050FAF030DAC030CAE0911AB050FA8040EA3020CA3020DA1030E9C01099E030B9E020C
9C010C9C000B9C010B9C010B9C010B9A000A9B010A990109970008980108980208950006
9901089B010A9D000BA2020DA4020BA2010AA4020DA7040FA807129C060F8F0109980911
9101088D03097C00047A02077C030A7300066F01056B0204690204680405600102630103
63010268100B31880300FF0000FF0000FF00
00FF0050AD0F591D0D5E3C370900000D00002C02014904045002024B00004D0101510002
5601015901045801025D01045E00015E01015F010262010266030461070C752D377C414F
8D4C5B7D202D7E030E89010C8C010B8E010A8F01099100089002068C00059302099A010C
A0010CA8020AAE030CB0040DB2060EB5050FB9060FB8020EBB0511BD0713BB0712BB0712
B90611B80711B80810B90611BA0913C00C18BB0914BA0B15AB131C56060A2B1C21B1B2BA
DFE2E6E2E3E7E1E5E8DFE3E6E1E2E6E3E2E7E4E4E6E3E1E6E4E4E6E3E2E4E2DEDEE7DFDE
E7DFDDEAE1DFE7DFDDE9E0E1E8E1E1E4DEDDE5DFDEE8E2E1E5E1E0E4E2E2E3E2E4E2E1E2
E2E1E3E1E1E4DEE1E3DCDFE0DDDFE1DCDEE0DCDDDFDEDDDFE0DDDFCDB5B88E3940A20F1B
AF0512AD020BAD050DA9040CAB050FA8020EA6020FA2020DA10611A20C159B020C9D010D
9E020D9C000C9C010C9B000B9C010C9D020D9C010C9A000A9A00099B010A99010A990009
9A01089C01099D020A9F020BA1000AA3020AA5030CA6030CA9060EA70A1292040B840208
90080F90030A8201057A00057E02097B020A6D01066200025F0001630103650102670203
6501016C120E358C0700FF0000FF0000FF00
00FF004FAB0E6026175B3C380800000E00012A01014601015002024B00014B0100510102
5C080A5B080A5201015901025C01035E0105630206640104640103620105680B16721827
6F0E1D7A051386020E8C010D8C000A90010A91020892010A8E01058C000592010699000A
A2020DAD040CB1040CB3050EB2050EB40911B90910BB0710BC0612BB0713BB0712B80711
B60610B70711B70812B60610B90911BB0A15B80712BB0A13B7111B7A0A142402098E8D97
D1D4DAE0E4E7E0E4E4DFE3E5E1E2E4E2E2E6E3E3E5E4E2E5E4E4E5E3E3E5E3E3E5E2E2E4
E4E3E3E3E1E2E3E2E3E2E1E2E1E1E3E1E0E3DFE0E2E3E3E6E4E3E6E3E2E5E2E1E4E0E1E4
DEDEE3DFE0E4DDE0E2DBDEE0DBDEE0DCDEE0DDDEE0DFDEE0E2DDE0D8C1C494444BA1121C
AD040FAB020BAC030DA9020CA7000DA90310A5020EA2020DA106119E05119D030E9C000B
9C000B9D020B9D010B9D010C9C010C9B010C9B010C9A000B9C020B9C010A9C010A9B0009
9B01099B00089C01089E020BA1010BA5020DA8020DA9030CAC070EA8060E9D061087020A
86020994040B8E02088501098002097402086B0309600106610204660103690103690102
6703016C120E358C0700FF0000FF0000FF00
00FF0051AC105A1D103F1E1C0800000F00002C03014604034E01014C01034900014D0002
5002064A01025202025701015A02035D020561030761010564010464010369010770010B
77020B82010F8A020F8E020D8E010C91010B8E010991010A8F01059100059601079B0109
A4020BAC040BB1060BAF050BAA0309A80309B40710BA0810BB0610BA0612B80711B7070E
B4060EB3050FB30811B4070FB5090FB3040EB6060FBD0B11BC0F179D111B4302094E404D
B9BCC4E1E4E9DFE3E3DEE2E3E0E2E2E0E1E3E3E3E4E3E3E5E4E4E5E3E2E5E3E3E6E3E1E4
E4E2E5E2E1E3E2E3E6E2E3E6E3E3E5E1E1E3E2E2E4E1E2E3E1E1E3E4E3E5E1E1E5DFE3E6
DDE1E4DEE0E3DDE0E3DADDDFDBDEDFDCDEDFDCDCDEDFDEE0E3DCE1D5B9C1903B44A3111B
AF060FAE030DAC020DAC030EAA020DA7020CA2000BA3030D9F020C9E010D9E020F9D020D
9D010B9E030B9C010A9B010B9A000A9B010B9A010A98010998010A9A010A9B01099B010A
9A00099C010A9E020DA0020DA2010EA3010DA6030DAA050EA8030BA8070EA507109B0810
8C010992040D90020A8A02097E03076400015801055701055F02056602056901046C0203
650200640B074B4E0600FF0000FF0000FF00
00FF0052AE125C1E1042221F0B00001300012B01014201014A01014B02024A01014D0102
661B1F530A0E4F01035002034E03044E02055303075702075F03066802066B0004740008
7E010B89010F8D010E8F020E90010C93010B8F010990020A9001079301069802089C0008
A60309AF040CB2030BAE010AA90208A50208AE040CBA0A14B6040FB80511B80711B5040E
B2030DB1030EB40812B0050DAF050DB60B13B80A0FBD0C12BD0C13B4111B820F19390310
7C6B79C6C0CDE0DFE4E1E1E6E2E4E7E2E2E6E2E2E5E3E2E7E5E4E9E6E2EAE5E2E8E5E0E7
E3DEE2E3DDE4E0DEE4E2DDE5E4DFE6E5E0E6E1DBE2E1DCE2E2DDE3E1DCE2DDD9E1DBDBE2
DBDAE1DCDBE2DBDAE1DCDBE1DDDCE1DEDCE1E0DCE1E2DAE1E0CBD7BD8693901F2CAA0D16
B1060EB0050FAD020EAD030EAA010AA7020CA2010BA0030B9F020B9F030E9D010D9F030E
9D010B9E010A9C010A9B010C9A000B9B010B9A00099A000999010A990109990107980108
9900089B0109A0020CA2010BA4020DA4020DA3010BAA050FA7040E9F010AA5060FA2050D
97030B8A01098703098101057C02066D02065B00035301025801025D0103600102680202
660201600702600F0400FF0000FF0000FF00
00FF0054AF136528194225220C00001800003402024B04054C01014D0101510201500103
5F10145404094C01054300023C02035B1F226223274C080C4C01036001046D0002790109
85010E8C020F8E000C8F020F8E010B8F01098D01078C01088D01089201079501079E0107
AA040CB2030DB4030EB40410B1040EB2060FB4060FB1030CB60710B80612B70610B60611
B0020CB1050EB3050DB0040DB0050DB60B12B70A10BB0C13BB0A11BD0F18B1121D890D1D
5B081C773F56B389A0D1B2C6C7B3C1D1BFCBD9C4D0D5BDCADBBECCDAB8C9DAB7C6D7B1BF
D5AAB8DDADBDDAAABFD7A7BDCE9CB1D7A4B7D19EAFD6A3B3D9A5B5D8A5B7C596A8CB9DB1
C095A7BA92A3B78FA0C59EAFC9A4B4CAA4B4CDA2B3CC98A9B66B7D9C2C3DA50F1BB20710
B2030DB0030EAF0510AA0109AB030AA60108A5020CA4030FA0010C9E010A9D000B9D010D
9E030D9D010A9D020A9C010A9C010B9D020B9C010A9B010A9B010B9B010A9A00079A0107
9A01089E0308A2040CA2010BA4020CA2020BA2010BA6030EA60510A0020CA5040FA6040D
9E040D8701057E01037F01067C01067302066B0006660205620003620306590001620203
6704046A100C691A0F00FF0000FF0000FF00
00FF0054B011672D192F14100D01001A00003801014E03044C01014B00024F0202500104
5102045103054A01024901038030389B4854A4505E9C48554C01035900036F010682020D
89020D8B010F8E020D8D010E89000A8800088B01088C00098D0209910109940106A20208
B1060FB4030EB50510B50512B50510B5040FB80711B70610B70711B80711B6050FB0030B
AD0209B0050DB3070DB3050EAD020CB50710B80B11B80910BB0A10BE0C12C00E17BB121D
AE14239D142A9319349E354FB1556CBA6076C05F75B9546ABF5268BD4A5FB84458B53D52
B6384EB7374EB33149B33049AF2C44B12E44B02C3FB02B3EAF2A3DAC293DA9273DA7273E
A6273FAA2D44A52A40A62E43A73246A83248A83047A8253CA81729AE0B1AB60811B80610
B4040EAF020BAF040DAE030CAB030AA60109A6020BA6020DA4010DA1010C9E020D9D020E
9A000B9B010B9A010A9B010B9C010A9D020B9B010A9B010A9A01099700089A01079D0209
9B00089E030B9E020BA1020DA2020DA3020DA2010CA4010DA90710A7050FA8040FA7040C
A0020B92010A8A020889030A7E02057200037503097303076F01066B03075A01025C0102
640304650D096E211600FF0000FF0000FF00
00FF0054B1126229122A0F0A0D00002101014304044D01024A00004B01024B00014D0103
4B00014901014E000262040871040D7804137A06167A05156D040D6001046E000781010D
87010C89010D8C020F8D020E8800088901088C00098C00098C0108900007960005A40208
B0050BB4050DB3030EB4020EB90611B8040FBC0712B9050EB7070FB4050CB3040AB2060C
AF0709AF060DB1060EB1060FAF040DB2040DBB0D16BE0F16BE0B11C00B14C20B15C30E19
C00E18C0101BBE111FBB1322B91528BD192AC2192AC71A2BC91928CD1828C91825CA1725
CC1725CD1724D01926CD1524CC1522CB1421C91420C9131FC8151DC5141DC2101CC00E1C
C00F1EC00F1EBE0E1DBF0F1EBC0E1CBB0C1BBA0D1CBB0B1ABB0915BB0612BB040FBA0610
B3020CAE030BAC020CAA010CA9010DA6020BA4010BA4020BA4020CA0000A9E010B9C010C
9D020F9C020E99010D98000B9D020B9C01099B01089901079700079A02079D03099C0108
9C01099E020C9D010AA1030DA2020CA3020EA2010DA4020DA8040EAA050FA7040FA4030E
9F020B9801099402098F02098501077801047401047501057502067102056201035D0001
660405660A07701F1600FF0000FF0000FF00
00FF0056B2146C3219260B070E00002702024703045002014C00004D01034D01014B0102
4701024500015A02046E02057401047D01097F010A81010B7C030B6C02066C010881030E
86010D8A020D89010B8D030D8800078B00098D010A8A01088C00059300079C0108A80309
B3060BB4050BB5050FB5040EB6050EB6020DB90510B90510B4040CB5080EB5080DB1050C
B1070EB20710AD030CAE030CB20610B5050FBA0A12BE0E18BF0D13C30C14C20A13C40D16
C20E14C30F14C00D12C40F17C51019CB141BCB1217CC1017CE1119D0111AD01218D01217
CF1218D11218D3141AD3121AD2121AD11119D01016CF0E15CE0F16CA0E14C80F14C90F15
C60914C70A15C90C16C30912C30912C10911C10811C00712C00714BF0614BB0411B6030D
B2030DAD020DAA020DA6000CA6020EA5030FA3020DA1000BA3000CA1000B9F010D9C000D
9E020F9C010E9A010E98020D99020B9B01099B01089A01079701079701089A020A990008
9A01089C010A9D020BA0010AA0000AA3020CA1000AA2010AA6050DA90710A6040EA4030D
A3030D9E020B9901099301078C01078202077701047201056F01046D0205670204630002
6501026506036C191000FF0000FF0000FF00
00FF0054B2137E482B1F0B070C00002801014B04045303024C01014B01024B01014C0102
4501034801026302047402057801037C000681020B84010982030A6C02066401057B030D
84030D87020D88010B8A010B8801078C00098D010A8C00089101089601079E0008AF080F
B1040BB2020BB4040EB90912B4040DB7030EB70610B60410B4040EB4040EB60610B4060F
B0040FAE020FAD030EAE030BB3050EB70711B70711BB0B15C00D16C20C14C30C12C20D13
C10E13C11017C00F16C10D16C61118CA1116C70E13CA0F16CB1117D1151BD01317CE1115
CD1013D21318D6151AD31017D41119D10E16D10F15D00E14D00D15CE0D15CB0D14CD0F16
C80911C80813C80A13C50910C2080FC20910C10711C00711BE0511BA0310B90410B4030D
B1040DAB010CAA010EA8020FA6010FA3010FA40410A2020EA5020EA5010CA1000D9C000D
9B010D9C020E9B020E97000C9A020C9B010A9A000899010998020C97010A950109940008
9700089900099E040D9F0109A2000BA3010DA2010DA3020CA5040DA6070EA60D11A50D13
A1060E9D030C99010A9701079000068700077E0106730105680003640103640103680103
680102650200630D0500FF0000FF0000FF00
00FF0053B3136B381A1905020F00002C00004E03035302014A01014801014B02014B0204
4001024A01036703047702067800037D000682010885010C81030C6802055D000376030C
81010D84010E88010D8B020D8A01098C00089000099202089201089300069B0106AC050C
B0040BB3020CB6060EB5030EB6040FB8040FB70610B5030FB70610B4020EB50410B2030F
AD020BAE020EAC010BAF020BB2040CB90914B70712C1101AC5121CC30B15C50D15C20E14
BF0D13BC0B15BA0A14BF0D18C40F18C91019C70E15C70E16C80F15CE141AD01317CF1216
D01215D41316D41115D61319D41117D20F15D20F15D41218D20F16D00C15D00D16D00E16
CB0B12C90A11C6070FC60A11C2080EC20910C0070FC10911BA040CBA050EB9050FB6050E
B3040CB1040DAC030DA8020DA3010EA1000FA2020FA5030FA6020DA5010CA0010C9B000B
99000A98010B98010B99010A9B010B9A020A980109970108940108930108920208920109
95010B99020C9C020B9D020B9F010CA1020CA3020DA2010AA2060D9D1213A12F29A63E3A
932222900B1295030C9601099200098A01088301087A02076F0104670103660104680104
6A03046A030169110800FF0000FF0000FF00
00FF0054B314622F121C04001800003B03045403035402014D01014A0002480101440202
3600014601026703057601067B010681020683000881010B78040C5E01055A010477040D
83030F89031188010F8A010D8E010B8E01099201089401099401079201069D0108AA030B
B0040CB5040EB6050DB5050EB5050DB8060EB5040EB60410B5030FB60410B5050FB0020B
AC010AB0020FAD020BB2040EB3030EB40610B60611BA0913C00F18C00C13C00B14C20D16
C10E17BB0B15BA0A14C1101AC20E17C50D16C70F16C80F15CC1218CF1218D11217D11118
CE0F14D00F14D00F12D00D13D51217D20E13D20F15D41118D31018D20E17CE0B14CD0B13
CE0D13CA0A11C5070EC60A11C3080FC3090FC20910C00811BB060FBB050EB9050FB7050E
B6060DB0020AAE040CA7030CA1010DA1010DA3020EA3020DA3020CA4030D9F010A9B0009
9B010A9A00099A010A9A010A9B010B9B010C98010A96010894010A92000992010894010A
96000B98000A9B010B9B010A9C020A9D010AA3040DA2040C9A0C10A53F3CE5A9A3E8B4B4
E09AA1A24249870B1290050C8E030A8701088300087E01087600066F0105670102610001
6702026A050379231C00FF0000FF0000FF00
00FF0055B4147341201C04001E01014303045704035401015002024C01014601023E0102
2E00014002036304057301057A01057F01087C020875030960020649000155010672020B
7F010C84010D86000E8B02108D010C8D00089201099201089401079500089E0108A80209
B0040DB6050FB4040CB3040BB3050CB90912B4040EB3030EB3030DB3020EB3040EB0030C
AD020EAD010DAC000CB0010EB3050FB50711B50710B80812BC0D14C00D13C30E15C40D17
C00D16BC0C16BC0D16C01118C10F13C40E12C70F12CB1116CB1014D31318D21116D10E16
D21114D31016D11015D21015D41116D51216D20F13D41118D10E16D00E17D00E16CF0F15
CA0B10CA0B12C70910CA0D14C70B11C4090FC1080FBF060FBC050FBC050FBB030FBA040E
B9060EB10309AE040CA9040EA3020DA0020D9D010A9C00089D010A9E010A9D01099C000A
9C010A9C010A9C010C9C010C9C010D9A010D97000A940109920008910008910107940109
96000999010A9C020B9B01099A00089D020AA1050CA2080F8E1115C98486E0BEC3A67380
802F42C86C7987252B89212383191B79050B7E02087E01077901067300036E0104640002
66010168040175201900FF0000FF0000FF00
00FF0056B4146A35141E03001E00004002035201035100024E0101480102410101390203
2300002C01015003036803066E030571040A6A04095B01074500023F000159020777030C
7E010B83010D87010E8C01118D010D8D010A8F0109920007950006990008A2030AAB030B
B2050FB3030DB2020CB3040DB3060DB50610B2040DB4040EB7080EB1030BAF030CAF030E
AD030CAE020EAD010DB2040EB20310B50711B3050EB4060FB90B12BE0D13C20E16C10E18
BE0E18BF101BBB0D16BE0F15BF0D11C60E13CB1115CC1215CB1012D51318D41116D41117
D41115D61319D31017D10F17D21317D31418CF1116CD1119C91218CC1519CC1318CE1418
CB1015C60B12C60B14C50A13C50A10C3080EC30810C30A12BD050CBD060EBB040FBA0410
B9050EB2030BAD040DA9030EA4010EA0010D9C00099B00079B000A9B00099B00089D020A
9B01099A01089B010A9D020D9D020D9A010A96010792010791000793010893010896010A
97000A9B010B9C020B9B02089A00099B010A9E020A9F0911841318DAA3A9DDBBC67F3747
8B15298C1D2BBE6F75D4999ABD7E8197444872070C7D050A7A01057800037601056D0103
6B0202680201741C152C860000FF0000FF00
00FF0057B4145B22031E01002201014203035001035001024C00024300013D0000390204
2001011E00003701014A01034F01035200074C01083F010535000244000567030B7C020E
80010C84010D88010F8C02108E020E8D000B8F01099301099701079D010AA6020CAE030D
B1010BB0010AB4040EB1030DAF010AB2040DB0020BB3040BB4070CB2050BAF030CAD010D
AE030CAE020EAC010DB0020EB2040EB2030FB0030DB40711B60C13BB0E16BD0D15BB0B15
B90D16B90E17B50912BB0C13BB0B11C30C13C90F14C90F13CE1014D10F16D31117D41217
D11115CE1015CE1219CC141CC8181EBF1C1FB01B1EA81D20B2302FB5332EB22C28B42421
BB1D1EBD1218C10D14C40B11C60B11C50910C1060FC0070FBE050CBD040DBB040FB7010D
B7040EB2030CAF040EA8020DA3000BA2000CA1010A9E01099B010A9A000A9C010A9D020A
9B01079A01079B02099A00089C020A990108950107920006930007940006970108980109
9801099A00099901099900089B01099F010AA1010A9E070F831319DCA6ACDAB3BC792432
94101D8C0F18AF6168DCB2B9683A42B8797F7427297D2023700509780206790104720103
6E01026901006C130B2E870100FF0000FF00
00FF0059B6145A24021B00002600014602035001024B00004601014301014001013D0303
2201011800002501003505033905043903083601092F000436000254010772020C7D010D
80010D83010D86010C8A020C8B020B8D010C8E00099301089801089E0009AA040CAE020A
B00108B1020CB5060EB50510B2040DAC0109AF030BB3030DB5050EB1020AB40610B1030F
B0010EAE020EAC010AAB010AB20710B1040EAE030CB0050EB50C13B80E17B90C15B60711
B70912B80C15B90E15B80A10C31118C50F17C50E14CB1116CF1115D3121AD11318D11419
CA1619C2191CB31C219F1B1E8D1D1F8B3434A46160C38C8AE2B1ACE8B7B2E4AFA8D79992
C77571AF4341AA1E1FBB1518C30D12C30910C0070FC0070FBE050DBC040EBB030FB9020E
B5020CB3040EAE030CA9030CA3010BA1010BA1010A9F00099B01099801099A010A9C0109
9B01089A00089B01099B010A9C010A99000997010A960109960009960108960107970208
96010798020997010999020A9D0109A00109A3040D9C040B881319D79CA2DDB4BD7C2331
950D19900B13974148DEB0B85F2D37935960A37273C48E8F691C1F6D0A0C720305710101
7101036A0001660C052F870100FF0000FF00
00FF0059B7155D28061D00002B01014C04045202014F0102490102460102460101440305
2C02011901003A2120A9908DA9929032161A2902092E00044701056B040D79020C7D010C
7F010C80000C84000B8C030D8A01098A01098D01089101099500089D0008A80109B0040B
B10208B3030AB60610BD0C17B3040EB0020CB1030CB4040EB6050FB5040EB4040FB1020F
B0010EB0020FAE030CAB010CAF0510B30811B40A12B60B13B60D14B50A13B70912BA0C15
B70912B80A14B90A14C00F19C20F19C50D18C60F16CD1419CB1217CA131AC4151ABB1B1F
9F1A1E841B1F883C3DA87173C9A5A4DFCCCAE5DBDBE6E0E0E5E1E0E7E3E1E7E2DFE6DEDB
E6D4D1E1BCB9C37D7BA83334B01217BE0B14C00710BF070EBE070FBC0610BD0612B7010E
B9040FB4020DAE010BA9020BA3010BA1010B9E00089D01089B01099701099A020C9B010B
9A00099800089900099E020B9E010C9D000B9B010A990109990109970108950107920107
9301079401079601099600089700079E030C9F020DA005118B0C17C67E86E4B7BF802B38
920C189309138F3038E4AFB768323D7E464FBA979BB4979B6F4447B5777A6716196B0509
7102056B010270160E2E870100FF0000FF00
00FF0059B8175726071D00002F01014B02025101005000024C01004A0102490201490102
3E02022501025A4247CCBDC6C3B7C038242D2D010844010762020B76020D7D010B7D010B
7E000B80010C83000B89010C8A01098C00098D010A92010B9500099C0009AA030BB4040E
B4030BB4030DB5050FB4030EB3050FB2040DB4040EB6050DB7060EB3030CB3030DB1010C
B1030CB0020EAE030CAA000BAD030EAF040EB1060FB40911B60C13B50812B50710B50A13
BA0E16BB0B16C00D19C3101CC20D19CD1420C81019C8151BC0181CAE1A20921B1D7F2626
8D5654C9ABA9E1D1D0E6DFDDE6E3E2E6E6E6E1E3E5E0E2E5E1E3E6E1E5E7E0E3E5E3E3E4
E2E1E2DFDBDAE2CFCED29D9DA2383DB0161EBD0C16BE0811C00812BB030EBB0410B6010D
B5010CB2010CB0020EAB020EA6020CA2010A9E00099D010B99010A94010995000997000A
9A020C9B010B9A00099C010A9D010B9C02099B00089B010A990109960106940007950009
9601089601079601079501089300089B020D9F020E9F020F950917A44753EFB9C28F414C
900F1B960611841721E09FA9773E497A434DC9AAAFAD9B9E8A7577BA9C9FA97D81722C31
69090E690204741A122E860000FF0000FF00
00FF0058B8175120031E00003201024F02035201004D01014700004800014B01014D0102
51060B481215290811462D3F371D2E37101D601C2463050C70020979010A7D010B7E000B
7E010980000A84000B89010D8A010B8C00098E010A92010B95000A9C000AAC040FB4030F
B3030DB3030EB60811B3060DB1030CB0030BB4040EB5060DB4060DB0020BB1030CB2030E
AE020BAD020BAD030BAA0109AC020BAE040DB20810B60A12B70C12B90B14BA0C15B60B14
BE101AC10F19C41118C30E19C5111BC01019B9161AAA1E21881C1B7E3534AA7F7CD4BEBA
E1D9D5E4E1DFE4E4E4E3E3E4E4E4E6E2E3E6E2E3E6E1E4E6E1E3E6E1E3E6E3E4E7E2E2E4
E0E1E3DFDFE1DFDDDCE4D6D4C29191982B2FB21118BE0912C00612BE0510BA020CB8020E
B4010CB3020EB00210AB020FA6010BA3020A9F020B9B010A99020B94000A94000998000B
9B000D9C010D9C000A9B00099B020B98010898010999010A970108940105940108950109
97010A94010994010995010993000A9A010E9F020EA3030EA009148D1924E49FA8AF6772
87111E970813870C19B6636F985C657C4A52C8ACB1A5949AB9A6AC8F777DB598A0AF8089
782B306203037319112E860000FF0000FF00
00FF005ABA195828092000003701025504055601024F0101480102490102480100500103
550108681D267B424F7341547D46577D34436D0D1971020C7501077901097E010C7F020C
7E010881000A86010C8C03108D010C8D000991010B92000B95010B9C010AAD040FB2030D
B4040EB4040FB4060FBD0E17B1050EB1030DB4040EB4060EB3060CB1040BB4070EB3060F
AD020BAD020BAD040BA90209A80109B00610B30811B40912B50A10B60912BC0C14BB0C15
C0121BC31319BE1217B9161CB51F2495181881231F864740B28E87D8C7C2E4DFDBE5E4E2
E4E4E3E2E2E3E2E3E5E3E2E7E3E2E7E5E4E9E0E1E4E3E4E6E2E3E5E2E3E6E3E4E7E2E3E5
DFE0E2E0E0E2E0E0E0E1DFDDDECECEB172749B1A1FB70D14BE0712BD040FBD050EB9020D
B8040FB2010CAF030DAB020CA8030BA6020CA1020C9C010B9C010B9A010B99010D9C020E
9C000D9D010D9C010C99010A9601089500079701079A0109980208920004910005920007
94010993010A92010993010993000997000B9E010DA3020DA30711940B16A4434FE59CA6
7D1E27871118A83940791B26BD747FA4717BBC9AA4A48C96B69CA5705158BC98A16E3A44
7F2F37610203670C0630880200FF0000FF00
00FF005ABA195E2D0E2500003E03035302025601024E01014601004800014B0001520102
5A02045F030C620D1B671626680D1D6F041376030E7500077400067801097A010A7B0009
7C010680010A86010C8C02108B010A8E000892010994010B98010A9F000AAE050FB3040E
B3040EB3030DB3050FB1030CAE030CB3050FB2040DB4060FBC0E17B5080EB2050BAE030B
AB0209AA010AAA030AAA040AAE040DB20612B10610B30912B20A11B10910B50C12B81117
B31316B11C1A9D1E1B87211E853934A27169C9B1A8DFD6CFE5E1DCE5E4E2E1E2E2E4E4E7
E1E1E2E3E3E7E3E4E7E2E1E6E5E5E9E4E5E9E1E3E7E1E4E6E1E5E6E1E3E4E2E4E5E1E3E6
E1E2E5E0E0E3DFE0E2E0E1E2E3DFE0D1B1B4993740B0111DBE0814BD050FBB030CB7020C
B8030DB4020BAE0109AA020BA8020CA5010CA2010E9D010C9C010A9B00099C010D9C000D
9C000A9C000C9D010D9B010B9901089901079B01099D020A990208940207910106930208
93020A92010A92010992010993000997010B9D010DA1020DA3030E9D0510900E1AB7535F
CB757F924247DB8C9273121E7E1726A24A5C7D3A4AAA7E8A9A76806F474EBE929B6D2F39
610A1066020366080331860100FF0000FF00
00FF005BBC1C5624092A00004503025602035201014A00014601004800014E0101530101
59010162020564010867020B6F010A77010A7A0109760006740107770109790208780107
7B010780010B86010C8C020E8E010A8F000993010B99010C9B020A9F0008AC030CB4040E
B4030DB4040FB1030CB1030CAF040DB1020DAF010AB50510B50710B70911B0050BAE040C
A7030BA4050DA0090CA20C0EA60A0DB10F16AF0E15AD0E13A60D11A81417A418199B1C19
90221C8B382FA16E63C8A9A2D9CAC4E3DFD8E4E4DFE2E3E1E3E4E4E2E4E6E1E4E5E4E3E8
E5E3E8E4E3E8E2E1E6DED9E0DDD6DED3CAD3C3BDC9CACBD5D8DEE3E1E5E7DFE3E5E2E4E8
E1E4E7DEE0E4E0E1E4DFDFE3E0DFE2DBCBCFAB676EA31823BA0914BE0610BB030DBA020C
B9040DB1010AAC010AA70009A6010CA6010FA2010DA0000B9E020A9C000A9C010D9B010A
9C01099D010A9D010C9D010C9B00089C01089D020A9B010A9B030C970108940006930107
93010892010891010890010791010795010A9A000B9E010CA3030EA0020CA00913940C1A
992736B65867C86E7C80111E8604138406176F091AAE717D8E666E895E67AA7E858B545A
5C0A1065030571130D33870300FF0000FF00
00FF005CBE1D4D1A042B00004703025603045001004A00014A02024E02024F0101530002
5A01015F01026001026400036D00077600087B02097500087400087900097A0108790109
7901077E010B85000E8C010D91010A94000B97010B9B010B9D010A9E0008AC050EB4050E
B4040CB1010CB0020CAF010AAF040CB1030DB1030CB50510B5040EB3040EAE030BA9030A
9B030A810409903230953F3B902F2B95292592241F942822912D27963E39984E48AC7269
C59D93DDC9C0E3DDD5E4E3DFE1E4E1E1E4E4E0E4E4DFE3E5E0E4E5E1E4E5E1E2E6DBD8DF
DCD2DADDCAD4DFC0CCE4B7C9E0A5B6C67F93652A414A3445ACAFB8DBE2E5DFE3E5DFE3E5
DFE1E5E1E1E5E0E0E4DFE0E4DDDEE1E2DBDDBD929695232CB20B16BC0710BD070FB8020D
B80410B2020EAB000BA7010CA6000DA6010FA2000BA0000A9D01079C01079B01089A0008
9B01089D01089F030B9D010B9D010A9C010B9B010A99000999030A980109970108960008
9501099401099201079402089301069701099B020B9E010CA2030EA0020CA206119F0511
9706158C06188905178D04128C010D8A020E76040EAF6A72956771A6727F96656F8A5860
722C3260050772150F4B4D0500FF0000FF00
00FF005EC01F4D1C072900004302015301025201005002024C00004E01014D0000520002
5800015C01015F000164010370010878010A78010A7400077400087D020C7C0109780007
7600077E000B85010C8C010D92000A97000B9B020B9D01099D020A9E010AA50109AE020B
B2050CB1020BAF010AB2040EB0020CB0020DB1030CB2020CB2020CB40510AC020AA70209
98050A6401034517178E7576D2B7B6D8B7B2D5B1A8D7B2AADDBDB4E4CDC5E7D8D1E8DFDA
E5E0DEE5E3E1E2E2E1DFE3E3E0E4E6E1E4E8E0E2E7DFDEE5D8D3DBD8CBD5DEC5D3E2B6C7
D792A5C86B80BE4D62B7364DB5253BB51E2FA11F2E44040F686066D2D8DBDFE4E5E2E5E7
E0E0E4E0E0E3DDDEE1DEE0E2DDE1E2DFE1E0CFB8BA9B434CAA111DB80811B8030CB8040E
B5030EB0010DAF020FAD0311A80110A6010DA4010CA001099C00089C01089B0108990007
9B01089C01089C01099D010B9E020D9B000A990009970108970008990109970108960108
95010B9300099401079702079800079B00099D010C9E010CA0030EA104119C040D9A040F
94030D8E030E91031092010C92010A8D010A79030CB66872A86B787429397C34429C666E
8A4B515A040671151061120700FF0000FF00
00FF005EBF1F501D072E00004503015502025401015302014D00004D01034E0101530102
5A02015D01016402046A01057101077501087500077401087400097A000A7E020C7A0108
7800067F010A88010B92030D95010B9A010B9C010AA1010B9E01089D010AA30109AA030A
AD020AAD020AAF010AAF010DAF010BB1030CAE0108AE0207AF0409B0020BAC0209AB030A
A1030A84060D4B010442202A887B88BCB8C2D8D7DBE1E0E0E2E0E1E3E2E2DFE1E0E0E2E4
E3E4E7E2E4E7E2E4E7DEDEE3DAD7DDD9CFDAD6C2CFDCB7C9D69EB1D4869CBB546CB6364F
B91F38C4182EC81225C80D1DCE111DCD1018BF161C70090F351D1FC3C6C9E0E4E5E2E4E7
E0E1E4E0E1E3DFDFE1DCDFE0DCE1E1DCE1E0D5CCCDA867709E1421B70A14B9060DB7050C
B4030CB0020CAF010DAE030FA8010CA5010BA4010CA2020D9D010C9B00099C01099C0109
9C01099C010A9C010B9E020A9D010A9C010A9B010A99020998020899020A970109960108
94000A9201099501089801089800089B010A9D010C9E010C9F020D9E020D9401098E010A
8701087D000481010A8A020B8F020A8B010982040C8D2532AB4B5B7507176E0613A3535E
9347505E04086B0F0A63130800FF0000FF00
00FF0030E0104E19053200004B03025903035901005601014D00014B01024C0000550101
5C01016101016701036C00057102057500067602067500077400067A000B7D010B7D010A
7D01058401098B020A93020C96020C99010A9C01099E010A9E010A9D010AA20209A9030A
AF040CB1030DAF010BB0020DB1020DB1030CB0020BAA0105AC0207AF010AAE030BAD020B
AA030CA2050E8F06106C0714520D206B3F5794778DB19EB1BAACBDCABFCCCDC7D0D1C8D0
D6C7D2CFBCC7CEB8C5D9B6C6D9A4B6D2889EC86982B8435BB3293EBC1D33C71A2CCB1424
D21422D6121FD20E18CE0913D00D13D00E12C91217971017320106939298DADEE3E2E4E8
E0E1E5DFE0E4DFE1E4DDE1E3DBE0E1DCE1E2DDDADBB78A90921C27B20D15B7060EB5040C
B3020CB2020CB0010CAC010AA80108A50009A4020EA1010E9D000C9C010A9A0107990106
9C010A9D000C9D010C9D020A9C01099C010A9B000A99010897010897010998010A960108
9301089301099701089600079500069800079A00099C010C9D010B9D020D95020C8B010A
8A060F7C01097A01098201098602097C020777030979030D8003108803107F030D71060F
700C136A030665060263110600FF0000FF00
00FF0030E0104A16033500004F02035C02035B01015901015101014E0101500102590203
5F02036302046500026A01056F01067601067800057800057801077C010B7C010B7F010B
81010887010B8C020A93020B96010A9B010B9C01099D020B9B01099A00099F0207A70208
AE030BAF010CAF040DB1030DAE020AAC010AAC020AAC030AAD0307AE0208AD020AAD020B
AA0108AC020CAC050DA50813960C1A840C207911297D213A7E2A448F4059AC627ACD8097
C8738AC86B82C15B71AE384FB0273FB61A30C1172CC91526CD131FD4151FD2121AD31119
D51219D30E17D20E17CD0A10CF0C10D10E11CC0F14B0131B50030964575ECACDD3E0E3E6
E1E3E7E0E2E6DFE1E4DDE0E2DCE0E2DCE0E2E0E0E2CDB2B68F3039A80E18B3030EB6030E
B6020DB3020DAF020BAC020AA80108A50109A4020D9F010C9D010C9C01099B02099B0008
9C010A9D000C9D010D9E010C9E010B9F020C9B000997010795000696000998010C940109
9100079201089401089601089600089701089801089B01099E010C9E010E96010C850005
87040B81020A7F040B83030C7C03096300015A00017003098101098A020B830108780105
7201046E0103640100600B0300FF0000FF00
00FF0000FF00521C073A01015202025E01025E01025A0001530000500102500100560101
5E01036000026401046500036A00027700067C02077A01087802087D01097D010883020B
83000888010D8E020D92000B96010A9C030B9E020B9E0209980008940008980008A8030D
AC010AB0020DAE030BAD020AAD020AAC020BAB0209A90107AB0207AA0106A90108AB010A
AA0209AB0109AD030BAF050FA9030CA70410AA0A17AF1422B11728B1182CB2192DB61A2F
B9192DBE182DC11628C81525CB131DCD121CCD0E19D21019D11016D21018D10E16D31018
D10F15CF0C14D10F14CF0B11D10D11D00D0ECD0C10C4171C73090F391D21C5C7CBE0E5E7
DEE2E4DFE2E4DEDFE3DFDEE3E0E0E4DBDCE0DFE0E3D0C0C49A535A9F121EB20512B6030F
B6020CB4010DAD000AAA0009A70108A40108A0010A9C010A9D010C9C010A9B02089C0209
9C01099C01099C01099E020C9F010C9D020D97020B94020892010797020A97020A920108
92000892000A93020A9301089600089600079700069901079D0109A0010D9D030E8F0108
8F050C8001067300037C030A7701076C03065B010264010579020981030A800308780204
7201026D0201640200610B0300FF0000FF00
00FF0000FF00511D073B01005D05046402025F01015A01015301005301024F0000520102
5D01056301046401036700036900027501067B02097500057300077E020A80010A84000B
83000A89010F8F011092000E95000A98020A9C01089C0109950007920009950008A4030D
AA020AAE020BAF040BAF040CAB030AA80208AC030AA70007A60107A90007AA030AAA0009
A80108A60107AA040CAC050CAD040BAF050CB60B14B70D15BC1018BE0F19C5121CC7111B
C8121AC8121AC71016CF1519CD1016CF1118CC1015CA1217CA1517CC161ACB181CCB171C
CA171CC71418CC1A1CCB1617CD1316D01014CF0C11C911179613183203069D9BA0DADEE1
E0E1E4E0E0E4E1DFE4DEDDE2DFDEE3DCDCE1DDDEE1DBD3D5A8747B901723AE0814B4040E
B4030DB2010CAE010CAB010DA8010BA6020CA2000C9F020D9C010B9B01099B01089B0107
9B01099A01099C01099B010B98030D8E030C83030A7E010687030992030C94020B940108
9200069201099201099101079300079601079701069901069C010A9E010C9C010B99010A
99050E90050E7F01067D02077D01057D03087004086000026A03076C0104710205720103
6D0101690201620200630D0400FF0000FF00
00FF0000FF004C15014100016907086702025E01005A0101560000560102510100520001
5B01036101036501036801046900047501067E020A7B010879000780010A84010B86010C
86000989000C90021095011099020E99020B9A010898010A92000991000994010A9D010A
A4010AAA0209AE050AB1060EAE050CAA0108AC0309A70107A70208A80007A70007A70008
A70209A50007A70209A70108AE050CB50A12BB0E14BB1016BA1217BC141BBB171BBC1C1E
BA1D1DB91D1DBD1B1AC51819C9141AC91319BB1113A71717B03630B6423CB64440BA4949
BE4F4EC05450C55A53D15D58C63B3CC4181ECC0A12CB0C13AD131A490204645B5FCBCED2
E1E1E6E0DEE4DEDDE2E0DFE4DDDDE1DCDEE2DADEE0DFDDDFBD9DA188262FAA0E18B3030E
B3030DB1010CAF020DAC010CAA000AA8020AA4010D9F000D9D010A9D020A9D020A9B0109
9800079801089A010B95030D84020973000693262C9C353971060A83040B900109930107
9301069300079301099201099201079401069801089901099C020C9D020C9D020B9C0109
9C020B9A050F90020A8E030A8401067E0206790408660002650104650203620101660102
670101680102630200630D0500FF0000FF00
00FF0000FF005216044E01016F06076801025C00005B0000590100580100540000570003
6002076101036602046800036E00047A010883010986010A84010983000B85020A85020A
8600078A010B90010D97020E9B020D9C010C9A020994010991010791010A90000A99010C
A3020BA80208AE070AAE030AAF040CAA0009A90209A60006A60105A60104A60107A60107
A70109AB040CA80108A90009B0070EB50A12B60F17AF151AA11A1B941E1DA7433FBF6761
BE6F68BC6B66B15451AB3B3AAE2929B11E21971415510303CBA19CE1BFB8E1C2BADFBFBD
E3C3C1E3C5C1E8C9C2EBC1BDE4989BAE2029CB121CCD0B15BE141C6B090E372125C4C4CB
DEDEE3E0E0E3DEDEE2DEDFE3DEDFE3DCE0E3D9DDE0DCDEE0CBBABE8D4048A0121BB0030D
B4020EB3010DB0010DAE000BAD020BA9010AA4010D9F010C9D010B9C01099D01099C0109
99000896010895020B88030A710002760108890D18A22D37A2343B7901078E030B940209
9501069401079301089100069301089300089601099801089E030D9C010A9C010A9C030B
98060E95060E99040D98030B8703077A01047F04097501047201056C02055D0001570001
60020266020263020165100700FF0000FF00
00FF0000FF005415045402016E04046701025E02015F01025901015301005601015C0103
6503076401036601036A00047201057E010786020A88000C88010C82010B800109830108
88010A8E030E8E010A95010C9D050D9C010B9801089401099101079001078D0006950109
A10309A90207AA0404AD0409AC030AAD030BA80108A70007A60106A80108A80107A90108
AB010AAE040DAC050CB0060EB0060EB00B159E1219720F116A2825AA7E78D2B7AFDCCBC5
DDD2CADDCECADAC3BED6B3AFD7A39EBA736D85433F270A0B7A7A7AD9DBDAE1E2DFE0DFDE
E1E0DFE3E0DFE3E0DDEBDFE1E7BFC4A83942C3151FD00F17C6111A8C10162D0307A09EA4
DDE0E4DFDFE2DFDFE3DCDEE1DEDFE3DEDFE3DCDFE1DBDDDFD2C9CD9A626B931420B00712
B4030EB2010DB0010CAD010AAC020AA70009A4010DA0010E9D010C9B010A9B00079C0108
9A010997020A8D030C7601077501068B040D92010D91030E8C08117B0005890309920108
93000794000695010795010897010A96010A9300079600079C010C9C000A9B0008950108
8200037C010490030B99040E8304086B02037604067E03057C0103760205630203510000
560000610302620200630E0500FF0000FF00
00FF0000FF005413025703016D03016601025D01005C02015701005300005600015B0101
5E01025E00016601036F01067401057E010786020C8A020E86010C81000A7D000682010A
8A020D8C010B8F010A96010C99020B9A000B9701079401069101079001078F0107950006
9F0107A80407AA0608AE090DAC050CAC030AAB0209AA0109A60007A80108AA0108AD020A
AC0109AB020AAA030AB30811B20711A10C1962060C442121B0A39EDDD9D4E0E0DBDFE0DE
E1E2E0E2E1E0E1E1DEE3DFDEE3DED8E2D8D1CBBEB8817D7B6C7273D2D9D9DEE3E2E0E2E3
E0E4E3E2E3E4E1E3E2E5E2E3E4CDD0B7626BB51922CB1018CC1319A7131B440206716A70
D0D5D9DEE1E4DEDFE2DDDEE1DDE0E3DEE0E4DADDE0DADDDFD9D6D9B08991881C28AB0B18
B30510B2020FAE010BAC0109AA0209A70108A3000AA0000D9F010C9D010A9B00089A0107
9A000895010A8002096400017D080E91020B96010B96010B90030B7F0105820206900209
9401099501099502089400089401099401099601089701079901089B010A9C010A98020A
8C030B7B010587030A92050E7601045500005A000077020688050A800307680002580000
5901006002025F02006310072C860000FF00
00FF0000FF005311005803026F05046802025D0000580001550101550101580101590100
5900006101026901027201057300007E010683010888000A86010B81000A81010884000A
8C010C90000C94020D99020C9C030C9801099702089300069101078E01088D0005930105
9B0206A50509A50207A80208A90209AA0108AB0209AB0009AA0108A90007AA0109AC010A
AE050CAC040BAB030AB40A12B00D15870C152F00027D7578D3D3D1E0E1E0DFE1E1E1E1E2
E1E1E3E0E0E2E0E1E2DDDEE0DFE1E2DEE1E0E1E3E1DEE0DFC9CECCC7CDCBDDE3E1DFE3E2
DEE4E2DFE3E4E0E3E4E0E1E1E4D9D9C98D92A42028C41218CC1217B5131A61080E3C2B31
C4C9D0DDE2E6D9DBDFDEDFE2DCDFE1DBDDE1DBDDE1DADCDEDDDBDDB99FA3872E39A20E1C
AF0613B20411AE010BAB0109A90108A70209A4000AA2000CA2010C9F010B9D010A9B0008
98010896020C7B050B59000175070C8F030C96020D96010B91030A7B01047901048E0308
9300069401079300069101078E02098E02099302099601079901089B010A9D010B9C020B
98020C8B030A8601068F050C82040A6802055700006E01068A050D850308710102680202
6502026101015B010067160F2A850100FF00
00FF0000FF005514015D04026F03026601015C0000580100540100530002570102590101
5C01006400026C020373010677010480020685020689020989020B85010C84010B87000C
8C010C93020F95010D9B030E9A030B9801089701059400069101098C01088B00068D0004
9401049D0207A00004A50107A80108AA0108AA0108AC010AAB0209AC010AAB0109AD020A
AA0008AB030BAA0108B10710A80A13700810200707A09EA2DFE1E1E0E0E2DFE0E2E0E1E4
E1E2E5E1E2E4DFDFE3DAD7DFCDC3D1D7CDDCDFDEE7E0E4E9DFE3E5D8DBDEDCE2E2DEE2E3
DEE4E4DDE1E4DDE2E2DFE1E3E3DEE1DCB5BB9E3239BE181ECA1215BB11157D0E1526070D
9EA1A8D8DDE1DCDEE2DBDCE0E0E1E5DEDFE3DBDDE1DCDCDFDDDCDECBBCBD934F5695101D
A90613AF0412AE020FAB010CA80009A60109A5010BA3010DA0010DA0000C9F010C9A0009
9B010B97030C79040A5000015D020681050D8D020A9001098A03097101036F0104890209
9201079501089401088F020980010575020481030791020999010A9D010D9C000D9D000B
9B020C91030A87020884010687020A82050E6801046C010484050B7F02067402046E0303
6B02026301015B010066160F2A850000FF00
00FF0000FF005A17016003027003026701015E02015902015401025101014F0001590101
6502026901046D01047201057601057F010884000788010884010B7C020C7B020C83020C
8B010B92010C95010D98000C98010A9B01099701089402078E01068A01058800028B0103
9301069C0107A10006A70209A70208A80108AB030AAE030BAE020BAF020DB1040DB1040A
AD0208AC0209AF040CB30711A6091469070E220C0EA7A6AADDE0E1DFDFE1DEE1E3DCE0E3
DBDFE2E0E1E6D8D1D9C39DAE904A63782F4D8C617AC2B7C8D9DCE5DDE0E5DFE3E6DEE2E5
DDE1E4E0E4E7E0E4E5DFE4E4E2E4E5E0CACEA55158B31A21C61114C00E139A151C330005
6F6D74D0D6DADDE1E4DADCE0DCDCE0DEDFE4DBDCE0DCDDE0DADCDCD6CED1A4727A891624
A60917AB0310AB020FA8010CA8020AA6010BA5020EA1010D9E010C9D010D9C010C97000A
9A000B98020C7C030A4A000143000362030A79030B82040B7A070C5E020463010485030B
91020994010896020A9102098202076C01026D01018802089601099C020D9B010D9C020E
97020D8A01088303097E010685020889030B7B04097301057D0408710001640001600100
6801026702015E010067160F2B860100FF00
00FF0000FF006119016503017604046801015D01005900005501015001014E0001580101
6702056B01066E02066F00027300057E010A84010A86020B7702086100035D010477020B
8A020D93010D96020D9A010D9B010B9B010B9601099001078A01058800068801058B0103
9101039B0006A60209AA020BA9020AAB010AAB0209AC0108AF010AB4030EB5060EB5050F
B10309B1040DB1070FB10711A609156E08111F070C9B9BA1DADEE0DFE0E2DCE0E3DBDFE2
DEE2E3E2E1E6D9C7D09B4D5FAA2035B11C358C1730601F38907E93D5D6E1DDE2E6DFE3E6
DEE3E6DEE3E6E2E6E7E0E4E7E0E4E7E4DBDEB77A82A72029C41217C40D12B0151C520308
4A3F45C0C8CEDAE0E3DADDE1DBDDDFD9DCDEDCDDE1DCDDDFDEDEDFDEDBDCB2919882212E
9E0A18A80410A7020BA7010AA7010BA6010CA4010CA0010C9E020C9C010A9B010B9B010B
9B000B9B010D8B060F5402053100013F00055201075802084E02054000005B010584020D
91010A91000794020896020A93030B86040A79000489020897020B9A010B9C020D9B010C
98020E8601087D01068304098702068D03088001057E030589080E7801046601015E0001
630101690203620201620C062D860100FF00
00FF0000FF006C1F066E07027703026800005D00005A01005601015201005201015A0103
6502056A01066A01046C010375000680020B87020B89040D7602085D01055200026D0109
89020C96010C98020B9B020A9C01099A010B9601078E01068801078900078A0206880002
900104970105A3030BA9020AA80108AB0209AD030CB0030CB2020CB70511BB0A14B4020C
B4050DB4050EB30911AD030EA808137E0D17210004838489D5D9DBDFE1E3DBDFE2DBDFE0
DEE2E3E3E2E4DECACFA6545FB31825C5121FBF1621A0192C4E0B206F6475CFD5DCDDE2E5
DDE3E3DFE3E6DFE4E4DFE1E5DDE0E3E2DFE1CFA7AC9C2931C3161CC80F15B91016750C10
291013A6ACB1D8E1E3D7DDDDDADEDFDBDEE0DBDCDFDCDDE0DADBDDDBDADDC4B1B7873B46
960E1BA4030EA9050EA7010DA7000CA7010BA4020AA1010C9E010C9B000B9A010B9A020C
9C020A9D020B92050E6704093801014212153A070B2E000429000233000160010789030C
93010B9100069201059501069501069001078B01078F01079601089801099C030D9B010B
9A020D90030D7E00048102068A02078702048002048102058B070C8002057202016A0101
680101670001630201610A052D850100FF00
00FF0000FF006C20066F08017704026A01015E01015A01015701005400005301005B0101
6301036601036700016D000177000381000887000A8B020C85030B7B040D6F0208770108
8D020C97010D9B020C9D020C9C020A9D020C9602098C01078700048901078D02058C0104
9002069300069D0107A6020AAA030AAC0209B0040CB3030EB5040EB5040FB60410B3030E
B3030EB2040EB20710AD030EAC09118D0E18310106625F67C8CDD0DDE1E3D9DFDFDEE2E5
DDE1E2DDDEE1E0D5D8B26F78AC1B28C40F1AC9121ABD151F8711212D0918A7A9B4E0E4E9
DFE3E5DFE3E6DDE3E3DFE2E5E2E3E6E4E2E4DEC3C7A3444DBA1820C70E13C00E13971419
3100037B7B7FD2DBDCD9DFE0D6DADDD8DCDFDADCDEDADDDED8DCDDD8DADCD2CACD945E66
8C1421A50715A6020EA4010CA6020BA50208A2010AA0010C9D000B9B000A9A0009980108
9901089C010A96030C800B10540B0DB58689A4808424070923000041000270030A8C0109
9101099000059301069501069401049301059401079601079701079A010A9B010D9C010E
9A020C94020C8401068001048602077E01027900027B0104770103790305750203710202
6C0101690101660202650D082B830000FF00
00FF0000FF00631B027108037A03026D01015F01015A00015500015301005301005B0101
6101026501026901027101027A01038000078601078D020D8B010A85010A82020A85010C
90020E99020E9B010D9B010B9C000B99010A9201098B01088801058800048A00028D0006
9101089400089A0007A60209AE030CB0030DB2040EB4040EB80410B8040CB7060FB4020E
B3030DB2030FB1050FB50B14AF0A11981019430207413940B9C0C4DEE3E6DCE0E1DDE1E2
DCE1E4DBDEE3E0DCDFCA9CA2A42833C5141ECD121BC8121DAB172243020D635A68D7DCE3
E0E4E6E0E2E6DDE3E4E2E6E9E1E4E6E3E3E5E5D6D7BA7278AD1C25C60F17C30B12AC121A
4F020853494EC9CFD2D8DCDFD9DEE1D6DADDD7DBDED6DCDFD7DCDED6DADBDAD6D9A9838A
811926A00917A3010EA4010BA30109A3010AA1010C9D000B9D010A9D020A9B0108980006
96000799000A98020C8B0710A2434B793C4585555F420F154901046C030887030A910109
92010890010790000694000696010696010597000597000598010799010B9B000C9C010C
99010B95020B8402067D02048102067C02047900047F03097401047302047102026D0201
690101680100630100670F092C840000FF00
00FF0000FF00681C037006017B03026D00006100015C00015701005401005201005A0100
6101026401026901027002057601037E01078601078C020C8D010A8700078600098A010C
8F010C97010D9C020E9E010E9F010D9B020B9401098E01098C01068A01048800048E0209
910009940109980007A6040CAD040FAE020EB1030DB4040EB8040CB90509B5030AB2010A
B1010BB1020CB3050FB2040FB0080FA20D175D060F24141BA3A8AEDBDFE2DDE1E2DDE1E4
DAE0E0DBE0E3E1E1E4DCBEC3A8454DBE1B24CD121CCE111CBD161F6B0A133A2430C8CDD4
DFE5E7E1E4E8E0E4E7E3E4E8DFE2E4E0E3E3E6DFDFC49296A1252CC5141CC70D14BB131D
6F0912321B21B1B4BADBE0E3D9DDE0D8DBDFD7DBDED8DCDFD6DBDDD4D9DBD9D9DBC0A7AD
7F2B36990C19A4020FA4010BA4020AA2010A9F020A9D010AA0030D9E010A9C00099A0008
9901099A010C9A010C95030E90121EA3404CA44A588825327C050F8C040C910109920108
91000591000693000793000695010797010899010898010998010A97010B9B010C9C020D
98000A9201078001047300027902057500017E020584020A7E0108710104650102630101
660100660100620100660E092D850100FF00
00FF0000FF007223057909017E03016F00006201005E01015900005800025801005E0101
6501016701016800016D01037200047C01078501088C020C8E020B88000A8700098C010A
91010B98010D9D020FA202119F010F9D020C97020B9100098D00068B00058B00058E0008
910107930109950107A0020BAA040DAF050DB2040DB4030DB8030BB8050BB7060CB2040B
B1010BB4050FB3050FB4040FAF030DA3061175091421020A84878ED2D7DBDDE1E1DCDDDF
DCE1E1DDE2E5DDE0E1E5D5D8BC757AB22029CA131AD01219C6151B8F121A2F0610A8A7AE
DBDFE3DADFE3DDE2E3E1E3E7E0E1E4DDE0E1E4E2E4D7B6BB9C343CBF1821CA0F16C01017
870D162A020984848BD4DBDEDCE0E3DADDDFD8DADDD7DBDED8DCDED7DBDDD8DBDEC7BBC0
89485191101CA30511A5030EA2020CA1040C9D010A9D01099D020A9D010A9D01099C010A
99010A98010A98010B99010D95020F8D05138A08178D061492030E93010B93010B930109
9300079300079501099301069200059501099801099901099A000A9A020B98010A9A010B
98010A93010A8A030A7901037C03077901037C02048202088102087603065F01025C0202
6903026A0202620100630A052E860200FF00
00FF0000FF00701F047B08018104017301026200005D01005B01005C01015D0101640101
6902036B02036801046B01047101067C01078501098C010C8C000B87000988010A8F000D
93000C98010CA00311A0010F9F020E9A000B9401098F01078C00058C01088C0108900107
92010A95020C94010A9B010BA6050CB0060EB3040EB70410B8030CB7030CB4030BB2020C
B3040DB2050EB1050EB20610AC030EA706128B0E1732010850505ABDC5CBDBE2E2DDE1E2
DDE1E2DADFE2DDE2E3E3DDDED5A9ACA62D35C81B21CF1218C81316AC1A1D4503096F676F
D4DADDDBE0E2DDE3E3E1E5E8DFE1E5DFE0E4E1E1E4E4D0D5AD5D66B31A26CC141AC61117
A4161F3E0107625C62D0D7DADADFE2DADDE0DADDE0D5D9DCD6DADED7DBDFD7DBDFD3CED3
996B74861520A20814A60611A3050FA1030DA1020DA1020E9F010B9C01099C010A9B0109
99010C97000998010A99010A98010B95010B95010C95010B96010A95010993000894010A
92000893010895020A9201088B01058C020893000999010899010797010797010998010B
97000B9300088E02098201058002068003067702057001067603077503065E0102550000
6602026A0202660101610702550A0100FF00
00FF0000FF00701C037C09018102027000006301015E00005C01005C00015F0202620202
6802026901026501016900047200067E020885020889010B8B020C8B000B8D010C93010E
93000A98000B9E010B9E020D9B010B94000B9101088E01098D02098E01098D000691010A
92010893000A94020C97010C9D020BAD050EB3050EB5030DB6020BB7030EB3020AB3030D
B1030CB0040AB0060CAD030CAD040FAA0411970B164A050C2F262EA3ABB3DAE1E4DBE0E3
DBDFE2DCE0E3DFE4E5E3E2E4E0C8CCA94D54BF1E25D0131ACF1419BF1A1E6D0C13402A34
CCD3D8DCE4E5DCE2E2DFE3E6DEE2E3DFE2E3E1E2E5E7DEE2C88F99A7242EC6141BC71015
B1121B5B050C403035C0C5CADBE0E4DBDEE0DCDDE0D7DBDED6DADDD8DBDED9DCDFD8D7DB
AA8C9380212E9D0C19A30611A2050FA2030EA3020FA3010EA1010C9D010A9B0109990109
99020B9901099A00089B010A98010994000793000895010A94010B93000A950108960107
9401089401079200059002088200027E00028F020999010A98010796000597000897000B
98010B9501089002088101057A00047D03086B02045300005A01016D04056602035B0001
650203690102660001640904590B0100FF00
00FF0000FF00771F028009018203037300006500006301025D01015B01015900005D0101
6501036600026300006801017201047D01078200068700088D020C8E000B8F020B92010C
93000A9B020CA0020B9E020D97010A93000A9102088F010A8D01088F020A8B0005900209
91010894010897010A96020C970009A20209AE030CB5040EB4020AB3020BB4040BB4040E
B2040DB2060EB1060CAC010AAC020DAB030F9A061064070D1E080D8B9099D7DCE1DCE0E3
DBDFE0DDE1E4DEE2E5E2E2E4E4D8DAC68589B32429D0161ED11219CB171E97151E310510
ACACB5DCE3E6DEE4E4DFE3E4DEE2E3E1E4E4E0E3E4E5E3E5D6B2B7A0343DC21923CB1219
BC10197F0E172D0C11A5A9B0D8E0E3DBDFE2DADDE0D8DCDFDADCE0D7DBDED9DDDFD9DBDE
BBA7AD813340970D1DA40613A2030EA3050FA0000FA1010E9F010B9C01099C0109970009
98010B99010B9A020B98020A97020993000794010A94010B94010A940209930007940107
9401059200049201059101058C02078601058D0106970109970108960107960107970109
98010A97010A8F01058301047500047201057206096204075500016303056A0306630102
6802046A0103660101660B065D0E0400FF00
00FF0000FF00792003830A028403027500016901006802036202025C01025B0101610102
6701046B02046701016800017000027D000687020C8A000C8E010D90030C8E010A91020C
93000A99020BA0040D9E030E95010992000990010891010A9000098F00098F0107920007
94000799020B9C030D9A020E98020B9B0007A7030AB2050EB1020AB2030AB2030CB0010A
AF040CAE050CAB030AA90109AC040CA70209A1060E83101826000563626EC2C8D0DADEE2
DBE1E1DEE2E5E0E2E3DDE0E1E1DDDDDDB2B6AB333ACA1921D4141AD2171CB71C234D030B
726771DEE2E4DFE5E5E0E4E7DFE3E5E1E5E6E0E4E5E2E4E5E8D2D6AE5862BB1F2BD11620
C8121C9D141D36000784858CCED8DBDBE0E3DADEE1D7DBDED9DDE0D4D8DBD9DEE0D7DADC
CDC2C791545E901321A50615A5030FA5030FA1010DA4040F9E010A9B00099B000A9A000A
98010A96000A93010994000895000895000795010B920009920008940006940006910006
9100069100059101059101069001078F0107900107930108930007930006930106960107
9801089701079201068C02067C02046E00027301057505085F00015B0001640103690004
6C01026D0202680202670D0860120900FF00
00FF0000FF00792104830C028603027801016B00006701006200005E01015F0101660103
6900046D01046B01026C000375010680010A8A020C8C010E8C010C8F020D8E010C90010B
92000B97020C9B030C99010D92000A92000A91000A93010B92000B93010B93020993020B
96010A9A010B9E020D9E030F9D050E9D010AA5030BAF050FB1030CB1010BB2020CAE020B
B0080FA9030BA60108A40007A50107A70208A203098D0A123B0207322C38A6AEB7DBE1E6
DDE1E3E2E4E7DEE2E3DBE0DFE0E0DFE7CED1B75962C5202AD6161ADB191ACE1F237A0E16
4B333BD8DADFE0E4E6E3E7E8E0E4E5E4E6E8E1E4E5E0E2E4E7DDDFC48690B32833CD161E
CF1219B81A2254040C61565EC8D0D5DCE2E5DCE1E4D8DDE0D8DDDFD9DEE0D6DCDFD8DBDF
DBD4D8A47981841624A40918A70310A6020EA5020EA4040E9E00079C01089C000A9D020C
98010896010995000A97010B98010A97010A95000A93000A9100089200089200078F0005
910006920106910105900106910108910107910208900209920209920107950209970108
9802099401079101068B01038303057A01057C01067E04066F01016502036602036C0304
6F02046E01016A010266090663120A00FF00
00FF0000FF00782403850D028A04027E0103700100690101650101600001600001670105
6A01056D01056F02057101067400057D020985010C87010C87010A8C020E8C000B8E010A
91010A95010B98020D94010B91000992000A92000A93010A92010A93010B94030A92000A
95020C98000C9C010C9D030D9B010B9C010B9F0109A8020CB30710B2020CB4050EAC010A
AC040DA9030CA40208A40108A80209AC030CAA050DA00D165D070F201019929AA4D9DFE5
DEE3E5DEE2E3DBE0DFDFE4E5E0E2E2E9DBDED49197BC2A33DC1E21E51C1EDC2025A61923
3F0A15C2BDC2DFE3E4E2E3E5E2E3E5E3E4E6E5E7E9E2E6E7E6E2E4DFB4BAAA343ED01E25
D9151BCA191F770C133D242BD0D6DBDCE3E5DEE4E5DBE0E1D8DDDED9DEE0D9DEE1D7DBDE
DDDCE1C2A4AD872936A30D1AAE0814AA0310A6010FA3010CA2010BA0010C9C010B9A0008
9A00089801099700099B010C9B010B98010A96000A94000B930109920109910107920005
9201069201079000068F00048F01059000088D030A83010586010691010A96010A950008
9400089401099203098502057601027A02048302078402087A0103700203650102630101
6D01037002036B0101640301630F0700FF00
00FF0000FF007B2304860D038903038002047301016D0101670101630102610102640003
6500036D020570030671000672010578000680010A82010B80000887010A89000A8E000B
92010B94000A94010B91020B8E010992010892010892000A92010892020B910208900109
94020C97010C9A020B9A010A9C020C9E010C9F010BA6020CAE030DB2030DB3040FAC0209
AA040CA8030AA6020AA40106A80108AF040DAD030DA909157B0812240109727682C8CFD8
DDE2E5DEE2E3DFE5E3E2E6E7DFE4E1E9E3E1F6CBCEC24B51DE2A2FED2729EA2B30D02F3A
67111DA18F97E4E7E8E6E8E7E4E7E7E5E7E9E6E7E9E6E7E9E6E5E7F4D9DDC1616AD82D34
E61D22DC1C219D161A3A0A10C5C5CBDDE4E7DEE4E6DBE2E3DADFE2DADEE2DADFE2D7DCDE
D9DDDFD3C2C7934751A2131FB10812B1030FAD0410A7010EA6010CA4000D9F000B9D0008
9C01099A010A9B010A9B000A9B000998010997010A97020A96010A930209930008930108
9200079100069000069000069101088F01078C02087F01037E000490020C9A020C9A010B
96010A9301078E01068101046D0001730103840207820105780103710304670204620001
6C02026E02016B0101660201600B0300FF00
00FF0000FF00822809890B038C03048301047601016F01026801026400036101025D0001
6101016A01056C01036C00056E00037600067E020A80010C7E000884010988010A8E010E
92020C92010C90000C8E010C8B0109900009900009910009910207910208910208900009
93010B96010C99010D9700099D020DA2020EA3010CA5000BA8010BB1040EB30610AD020A
AE050DA80007A70108A80108A90108B1030EB1020EB208159B101B45030E4D4552BEC3CD
E0E5E8E2E6E7E0E6E5E3E7E8E2E5E6E7E5E6F6E2E3DA8F91D34F51E15050E65D60DC626A
A95D65B19DA2F4F4F4E6E7E9E8EBECE7EBECE7EBECE7EAECE6E6E9F7EBEEEEACB2DD454B
F53133ED2728C9262854030CAEA2AAE0E5E9DFE6E9DDE4E6DDE1E4DCE0E3DBDFE2DBDFE2
DBDFE2DDD3D6AD6F79A11A26B70915BA0612B70511B50511AF050FA8000DA6020EA2010D
A0010C9D000A9B000A9B000A9B00099B010A9A000A99020B970109970108960009930108
9201089201089101079101079201089101079001078D02088B000894020B9C010B9B010A
9701089200058C00048702077C02067901038201057D02047001036501016903036A0002
6E01016D00006A01016605026A170E00FF00
00FF0000FF00862A088C0C038E03038502037601016F01026901016101015E01015B0000
6202036A02066A01036B01056C00057401087D020A7E010B7B00078100098401098A010B
8F020B90000C8E010C8F020E8901088C01098E010A90000990010891010A8F020A91010B
92000A94010B97010A99000A9D010BA2020EA3010EA2000BA4020AAC050EB0070FB2060D
B3070EB1040BB1030BB2020AB8050EBD0711BB050EBD0B13BA18217D132040202DC5C5CD
E4E8EBE1E5E7E5EBEBE4E8E9E7E8EBE9E8EAF0EBEBFBE7E7F9D1D1FFD7D7FFE4E4FFE6E8
FFEFF0FFF8F8FDFCFDF0F1F3EFF0F2EFF0F2EFF0F2F1F2F4F1F1F4F2EFF1FFDADEE7696C
F64340F73831E73835780C158C717CE1E4EAE1E6E8E1E6E7E0E4E6DFE3E5E0E4E6DEE2E5
DDE1E4E3DEE2CF9CA6A32230C20F1DC60916C20614BE0612BB0610B2030CAE030DA8010C
A4000CA1000BA0010B9E010B9C01099A00099B010B9B010B9901099A010A99010A970106
96000697020B93010992010892010791000693010794010996020A99010C9C020E9C010C
9A010A9600079301078F02098601068301068402057B01036C0001630102670202700203
7201017001016801016003016D1E1500FF00
00FF0000FF008125048B0C018E04018302027400016C00016901016502025F01015D0001
6101026502036600016B01046E02047702077C010B7C000A7900077E0009830009880008
8D020B8F010D8E010E8C000C8800088A030A8E020B8F010A8F020A8E010A8E0109900009
94000A9600099A020C9D020DA0020DA3010DA5020DA1000BA1020BA8040BAD030AB70A0E
BC080DC60D13C70C11CD0F15D11117D7171CCE1115D81B1FD72127B9252F651927C8B6C0
F2F2F5E7EBEEE9EDEEEBECEEE9EAECF1F2F4EDEEF0F6F4F4FAF7F6FCF9F8FEFCFCFFFDFD
FFFDFEFFFEFEFEFEFEFEFEFEFDFEFDFAFBFBF7F7F9F5F6F8F0F1F3F6F5F7FFE8EBF08383
FD5951FD4F42F84843A12029916571F8F7FCE4E8EAE3E6E7E6E8EAE1E4E5E0E2E5DFE3E7
DFE1E6E3DFE3E6BDC6AA3441CC1926D00D19CC0816C80714C10511C00712B7020DB3040E
AB010BA9010BA6010BA0010A9C00079B01079D010A9E020C9D010B9C010B9B010A9A0008
9B010A99000B95010A9201099000079101079301089600099A010B9D020E9D020F9B010C
9A00099801079500059001088400058001048302067C03057302046A02046401026D0203
7201017001016801006003006B1A1314C200
00FF0000FF008426078C0D038D03028001027101016B0101680100640101600001610103
5F01016001016401016D01017101027500067B01097900097A01087F010B83010A87000A
8A010A8D010E8D020E8A010B88010888010A8901088900088D02098E010A8F020A8F0008
9701099D010C9F010CA4020DA6020CA9000AAD030DAD030DA90109AE020CB4040DC40C13
CE1016DC171AE0171AE2161BE81D20EB2023EB2225F32A2EF33034ED3C43B03040BE8096
FEF7FEEEEDF0EFF1F3ECEDF1F2F3F5F1F2F6F5F6F8F0F1F3F5F7F6F5F6F8FAFCFBFBFBFD
FBFDFCFCFCFCFCFEFDFBFBFDF8F9F9F6F7F7F5F5F7F2F3F5F0F1F2FAF6F8FFD8DFEC7176
FA514BFC453BF43C37C332397F4451F4F0F6E2E6E7E4E7E9E3E5E8E4E7E9E2E4E7E0E4E6
E1E3E7E3E0E6F5D6DFB54A58CB1F2CD10F1AD10C19D00C18CC0915C60510C50712BD050E
B7030DB2020BAD010CA9020CA300089F0007A10109A2010BA4030DA0020CA0020D9D010B
9C010B9B010B97000993000891010791010995010A99010A9B010B9B010B9C010D9B010C
9900099901089700079301088701077C02057603066E01036F02026D0205600001660001
7201027001016801015F02016F1D18298400
00FF0000FF008D2B0C8F0D038A02017D02026D0100690101640101610101610001650105
6501056601036901037100057401047A01087B02097A010A7701097C000A85010D89010C
8D020D8C010E89010B8A00098A02088900088800088C01098F010992010A900007940006
9B0006A5020AAA040BAC030AB4060FB6030DBD050DBC050DBA030AC20710C60A13CD0B15
DB1319E71B1FEF2023F11F22F52225FA282CFD2E32FD2F34FF3B3FFC3D44F14554B93552
E39EBAFEEAF8F4EFF2F1F0F3F0F0F2F3F1F6EEEFF1EFEFF2F4F4F4F7F6F8F8F8F8F9F9FA
F7F9F8F7F8FAFAFBFBFBFBFDFAFAFAFAFAF9FBFAF9FAF7FAFCF6F9FFE9EFF199A3ED5559
F7463EFB4036F63733CB2F34692431D3D0DADFE6EAE0E4E7E1E5E8E0E2E6E0E2E5DBDFE1
DFE3E6DCDCE1E8D1DAB05363C4202ECE0F1BCD0C16CC0C14D00F18CB0D14C80B12C10910
BE0912B9050FBB0A15B0020EAC020DA9020DA6010DA5010CA5000AA7020CA8040FA5020D
A2020D9E020D9B010B97010A95010993000894000999010D9B010C9C010C9E020E9C010A
9C010B9B010A9900089501078C02077601055E00006101026D03046B0204650103690101
7201026F01016500015A00005F0E072B8601
00FF0000FF008B27098C0B018803017A01016A0000680100640101640001670102660003
6501016801026C01027101057501067C010B7901087501087001087A010A85010C89010D
8B020C8A010D8600098A01088C01078E000991010A94010C96000B9C020D9E030CA10108
A70107AF0208B30307BF080CC5090DCB0C0FD00E11D31014D00C13D20E17D31019D7111B
DA111AE71A23F11F25F52024FC2729FD2729FD292CFC292FFC3134FA2F35F9353DEF384A
D4405BE989A2FFE4F2FFF2FCFFF5FDFFF3FCFFF2FBFFF0FAFFF0F8FFEEF7FFF1F7FFF3F7
FEF9FBFEFEFFFEFBFDFBF5F7FEF2F5FEEBECFEE5E6FFDEE1F9C8CCF0969BF16C6DFC5851
FC4C3FFC4538FD423ADE373A701B26C6BDC6E1EAEDE1E6E9DDE2E5DFE2E6DEE1E3DCE0E2
DFE3E6DEE0E4E3D3DCB56675BB2132CE1321CF111BC90C13C80D14C50B13C10812BF0712
BB0511B80510B70612B50612AE020EAA020DA7010DA8010EA8010EA9010DAA020CAA020D
A5010EA1010D9E010A9C010C98000B96000996010999010B9E020EA1020EA2010CA3030D
A0020E9F020D9D010B9701088E02087F02076902056400036F04066801016501016E0102
7301027101016901025C01005F0D062D8601
00FF0000FF00822506880B028502017800006A0000680102670001690102690102640002
6401016801026B02037001047600097D010B7C01097200056B000479010885010A8C010C
8E020E8B010B8800088B000892010A96010D99010D9B010DA2020CA7010BAB030AB0020B
B5030BC00810C4080CCA090ED30F10DF1817DB1513D81012CF090FCD0812CB0711D10C16
D00A14D30A15E4161FF01C21F11A1DF82223FE282AFB2729FA2C2AFC2F30FC3336FC363B
F63A44EB495BEE7286F38EA5F497ACF492A7F290A2F292A1F295A0F8A0AAFDB0BAFFC7D3
FFE2EFFFEBFAFFEAF8FFDFEAFFC9D2FCAAAFFD9F9FF99090F97F7DFD746EFF655CFF594D
FF5146FF4940FE413BF140447E1724C3AEB8EBEEF3E4E8ECDFE4E7DFE3E6DEE2E5DCE1E4
DBDFE2DCDEE2E7DCE3BF7D8BB12232C91320C90E19CA1017C60C13C60D16C10915BD0614
B90411B70512B50411B2020EB2070FAA0009A8000AA9010EAB0010AD0210AD020EAB000D
A7010DA3000BA101099E000B97010A9202089402089801089E010CA4020FA5010DA6030D
A80611A606109F020B9A01098D01058402057B04086C01026F03056E02046F0103760203
7701027101016A0102610100630D062E8500
00FF0000FF007E2306870A008401007A01016B0000670000670001690102690102620102
6000016700036C01057000067801077F010C7F01087A01057600067E01098601098E010D
90000D8D00088D000791010797010A9D020EA1020FA4010EAA030EB1040FB5050FB8030C
BD040DC2060EC7090ECF0D11D10D0ED00A09D6100DD20A0BCB050BC4000AC6020CC9040E
CE0912CC050FD60C15E7151DF51D23F82125FE2B2BFF3030FF3530FF3631FE3838FC3536
FE393BFB3E46F84C5AF55264F35566F85B6CF75B69F45B67F7646CF5686FF36D7AF2798A
F389A0FE9CBAFC97B3F4879EF07686F26870F76567F8615FFB5B57FF5953FD4D47FC433F
FE3D3BFF3B39F93334EE383F821424997D8CE5E8F0DDE3E7DEE3E7DDE2E5DDE2E5DADEE1
D7DBDEDDE0E4E3DBE2C58B9AA72334C21221C50D1AC60E18C60E18C60E1ABE0714B80312
B80413B60511B3020EB1010CB2050EAC010AA9010BA7000CA9000EAC010EAE030EAB010C
A8010BA6010AA40009A1010C9100078500048D02089801089E010AA3000DA70210A80210
AB0714AC0C15A5080F9A020A8D00068700058202077200026A01036B0204730306790203
7902027001016900016201006811092D8500
00FF0000FF007F2204890C028503017B01026D00016A0101670101670102640102610101
6101016800036E01057300057C010784020B84010783010882010887000A8B010993020D
97061196030D9401099B030B9F020CA3020DA5010BAA030EAF040DB4040FB4040DB4010A
B8020ABE0309C0040AC6050AC90508CD0607DA1512D40D0ECC080DC9060FC9070FC8040E
CE0913CF0B13D50E18E61621F31D28FA242BFD2C2DFB2A2BFC2D2BFF322EFD3230FE302F
FD312FFE3436FD3A3FFB3B44FA3D46FD414AF83C45F93F45FA4449F64349F64651F14655
EE4B61EE4E69EE4B67F14B5FF14554F44149F64144F94342F53C3BF93C3BF83637F52F31
F42A2CF62A2DF0272CDC28308213235E4153CCCEDBDEE4E8DDE2E5DDE1E3DCE1E4DADEE1
D9DDE0DCDEE2DED9E0B18390972131B71120BC0C19BD0B17C4101DC00C19B90615B30313
B40514B20410B1040EB1020DB0040EAD020DAC020DA7010DA8010EAC010DAC010CAB010C
A8010BA5000AA40009A1020C8F01077C000185010698010B9D010AA1000BA5010FAB0513
AF0B19BC1E27A70A12A0060D9402098B02078502087A01066700016401016F0103760102
770102700101690102620101650E082D8500
00FF0000FF00862905860B018203017B01016F0100690100630101600000600001630101
6501016C00047201047A010582010788020A8701078801088A01098D010A92020CA20E19
B11D27A50D19A10610A5040DA9050DA9030BAA030BAC030BAE020AB0000AB00109AD0006
B10106B90107BC0208C80A10CB080CCC0A0DD31614C80A0CC80A10C3080DC60B12C10610
C30712C40712C90B16CD0916D80F1DEB1C29EE1E24F12024F72629F72429F9292AF92728
F82827F92A2AF62A2BF62A2EF42C2FF42C2FF42E30F63234F43333F02F32F33437ED3237
EB3539E7343AE9343DE73137E73236E83438E93738E0302EDE2E2CE02F30E02E2FDB282B
DA282AD9292ECC2327C129307E1D2A3A2030B0B6C1D8DFE3DCE0E4DCDFE2DADEE1D9DDE1
D6D9DDD7DADEDBDAE0A68590831F2DAA1321AC0915AE0813B00814AF0513AE0513A90111
A7010FA7010EA6010CA9030EA6000CA7020EA7010CA5000AA7010BAA020BAC010CAB010D
A6010BA3010AA1010AA0010B97020B8701058A010799010C9F020BA10109A4010CA60010
AA0415B41220AC0D18A60A119A040C8B02097E00047E03077403066800026F0103760103
7702036F01016700015F01006A140D2E8601
00FF0000FF00832504850A018002007901026F01006701016101005F0101610101650101
6700016E01037802067F000783010788000A88010888010B8B010991020C9F0C16B01924
BF2731AF111FA90814AA050EAB040CAB020CA90108A80108AE020AB20109B4020CB20108
B7050ABE070DBF060CC4070DC1050ABA0309B00102AB0103AC0107AB0007AB0209AA0008
AB000AAE020EB20410B2030DB90512C90A19D81620D9151DDC1B21DE1D23E02226E3272A
E32A2ADF2C2BDC3131D83234D43537D83D3CD63E3BD54340D84A47D84D4BDD564FDA5A53
DA6259DE6C63E1716BDF6E6AE0726EE57976E57B77DC746FD46F69C05B56DA736FDC7673
D26E6EC06060B55758A55051854C525F50588C9398D5DCDFD9DCE0D8DCDFD8DDE0D7DBDF
D7DBDFD4D9DDDADCE1AB99A16F293490192599141C990E149D0D15A10C15A20613A20412
A0010E9F010D9E000D9F010D9E010C9E010D9E010C9F010BA4010BA9030DA8010DA70210
A2010E9F000B9E000BA0020C9D020C9201079501089D010AA1010AA40109A30009A6010E
A60111A40111A103119C06108D030B86050E7904097702057F04077600027801047B0103
7B02037201026700015F0100650F082F8702
00FF0000FF008425058509017E02017601017002006901036202005F0101600101640100
6900027201037B01058101088601088801088701088700078A0008980510A50B18AE0F1B
AF101CA70614A90510A8030EA8010AAE020EB0030DB0030DB2020CB6030DBA040FBA050E
B9050DB20107BC0810B9060DB10209A90107A102049C00029C00049D01069C0206990006
9900079C010B9F010B9E000AA5040FA8010EB00915AC111CB2292DB53738C14A48D05E5B
DD706CE4807CEA9391EFA4A3FABCBAF7B7B5FBC1BBFDC5C2FCCBC8FCCFCAFAD0CAF9D3CC
F9D9D1F9DAD4F9DDD6F8DDD9F9E2DEF8DEDDF8DDDCF8DFDBF3DAD5EDD5CFF4DCD7F0D7D5
EFD6D6E7CFCFE6CFCEDDC8C6D4C7C6CBCBCAC6CCCFD7DDE0D7DBDFDBE0E3D8DCDFD7DBDF
D6DBDFD7DCE0D7DBDDB6B2B48467698D53568D46478B3C3D8A30348B282E8A1A22900C16
9A040F9B010C9A010C9A010B99010A97010B97000C99000B9C000BA2020DA2010F9F000E
9E010D9C010C9B000B9B010B9B010A9A010A9B010AA0010AA3010AA5010AA4010CA50110
A502119F000F9B020F8901087500027A030B78080F6A00017A03067D04067B02047F0205
7F03057501026B01016200015E07012E8701
00FF0000FF008223058108027C02007401017001006900025F00015B01015D0201640102
6D01047601047C01038301078801078801068801068A00078F010B99020EA90916AD0914
A70610A1000CA2010BA8030FAB030DB30512B50510B4020EB4030DB4030DB6040CB4050C
AE030BA80108AA010BA80008A101069D02099901079600069301059201059102038E0005
8E010692000A93000997000B9A010D9C0310950715650109864C53D0ABAAEAC8C3F4D4CE
F6DBD7F8E2E0F4E3E2ECE0E1EEE7E6EFE8E8F0EAE9EEE9E8ECE7E7ECE9E8EBE8E8EAE9E8
E9E8E7E8E8E7E8E8E7EBE9EBEAE8EAECEBEDE9E9EAE7E7E9E7E8E6E6E7E5E3E4E5E7E7EB
E7E7EAE6E6E8E4E6E6E1E4E4E2E5E4DEE2E3DBE2E3DDE4E6DADFE2DDE1E4DBE0E3D9DDE1
D9DDE1DBDEE1DCDDE0D7D9D8D3D0CDD1CAC7CDC2BEC9B7B5C5ADADC0A1A2BD8C8F8A2F37
8F08129B030C9C010B98010A94000793010894010A96010C99010C9C010B9D020D9C010C
9B010B9A000A9A010B9901099A010A9900099C01099F010AA3000AA6000DA7010FAA0312
A502109D000D97010B8A030976010578020879040A6E0105720509680203670203770305
8002057A02046B00006200005E0501444902
00FF0000FF008126067E08017801007401017201036901035A0000530000580101620102
6D01037801057F00048501078901068A01068A00048D000894010C9E0410A70612A8040D
A6040EA1020DA2020EAB0512AB030FAE0410AF030FB0030DB2050EAF040DAA030AAB060E
A1030A9B0008A1040C9F01089601079201089101079200088F01078C00038B0103870003
89000690010B94010C9A010D9C020E9F04129A0C1A5F0514442D3BCECFD7E5E8E8EBEBEB
E9EAEAEBECEDEAEDEEE8E9EBEAEBEDEAEBEDEDEEF0EFF0F2F1F2F4F6F6F8EEEFF1F1F1F3
EDEFEFEEEEF0EEEEEFEFEDF1F0EFF1F2F1F2F5F5F6EDEEEFEDEDEEEAEBECE8E9EBEBEBEF
EBEBEFE7E9ECE6E8EBE4E8EAE3E7E8E1E5E6DFE4E6DFE4E8DCE2E4DADFE3DBDFE2DCE0E3
DCE1E4DDE0E3DDDEE1DBDDDFD9DCDDD8DDDDD7DCDCD4D9D9D4D8D8D4D6D6CFC6C88C545D
8A0F1D9D020EA0010C9C010C96010993010793000896000A98010B9A020A9A000997000A
97000A99010A9800099600099501099600089A01099E010AA4020CA90210AF0515B20A19
A804109E010B9801098D01087600037502057E05087301046D03085300004D00006D0205
8002067B01036F01016501006006025B0D03
00FF0000FF007C24057B07017902017301017201016C01035A0101520000560000630101
7000027B00048101068600068901068C01078F010593010797020B9D030EA2040EAC0A11
AD0C12AC0D15AA0F17A70714AA0813A80410A5010EA7020CA7040CA1020A9D01099C040C
8F00078E00069601079601069200059100099101089200089000099100078F00048D0005
8F000797010CA10510A60411A7040FAB0510AB0C17860F20370F1FC4C1CDE7EBEFEBECF0
ECEEF1ECEDF0F0F1F3F2F2F4F1F2F3F2F3F5F4F5F6F6F6F7FBFCFDFEFEFFFDFEFDFFFFFF
FDFEFEFDFDFEFDFEFEFDFCFEFDFDFDFBFBFAFBFCFBF8FAFAF4F6F6F6F6F7F5F5F6F2F2F5
F3F3F5F5F7F8F1F2F4EBEEEFE8ECEDE8EBEDE3E7EBE1E5E9DEE5E9DCE2E8DCE1E8DDE2E7
DAE1E5DAE0E6D9DFE3DAE0E3DADDE2DADDE2D9DDE0D7DCDFD4D9DCD3D7DBD3D1D59B6F79
891424A60615A80110A4020E9B010999000999000A9B010C9C000C9C010B9C010C9B010D
98010D97000B97010A94000893000896010A99010A9E010BA4030FAC0715B6111EC01C27
B2101AA2030E9B010A90020A7801046E00027A04097201046F04066405075600006F0307
8103067C01027201016700006307025D0E02
00FF0000FF007D25067905017601017201017201007103036302025C00016301026E0103
7801038001058200058801088C01088B000791010796020999030997010AA0050EAA0B14
AE1117B41B21B62228A7121CA20814A10311A1030F9D030E9600099100089001088D0109
8700068800069101079400069600059B00099C020A9A00099901089D00099A00069E0109
A2010AA7020CAE040FB40611B70510C10D17C3111AB31C2A58091CCBB9C8F7F5FBEDEDF2
EEF0F3F9F9FBFDFCFFFEFDFFFDFCFEFFFCFFFEFDFFFFFCFFFFFCFFFFFCFFFFFCFFFFFBFF
FFFAFFFFF9FFFFF8FFFFF8FFFFF8FFFFF6FFFFF5FFFFF5FFFFF4FFFFF4FFFFF4FFFFF2FF
FFF1FFFFF1FFFFF2FFFFF0FEFFEEFEFEE8F9FDE6F9FAE1F4EDD9ECEAD8EEEADCF2D9D0E4
D9D5E7D4D3E3D2D4E1D2D5E1D4D6E2D4D7E1D5DAE1D6DCE3D4DAE2D5DBE2D4D3DAB98D9A
8C1829AA0615AE020EAB030FA3010B9F000AA0010BA1010DA2020E9F020D9D010C9D010D
9B010D98010C96000995000895000997010A99010B9C010CA20311AA0917BA1B26BD2029
B2141EA509139B040E8F030B8003087700057C030A6C00026B0103700508670002780206
8402058101017701026B0101670602610F03
00FF0000FF007B21057905017701017400017701027700026F01026A01016E0102760105
7E01058201068401058A01088D02088C01088F020792010A92010993020B9E0713A00612
A20A14A8121DB01F2AA3111E98051197010D96010B95020C8F01098C0009890107890007
8900068F00069801079F0008A40208AD050BAD040AAE0408AE0207B4040CAF010AB5040E
B8040FBC0712C00A13C60F18C60D18CF121FD0151DC91C288C1026A96A87FFE4FAFFE3FB
FFE7FDFFE6FDFFE4F9FFE3F9FFE4F8FFDFF4FFDEF3FFD9EDFFD8E8FED4E3FCD1DFF9CFDF
F6CBDBF2C5D7ECB4C8EAADC1EDABBFECA2B6EA9AAFEA94ABEA92A7EC92AAEB8CA8EA84A2
EC85A4E8829FE8809AE87B99E77797EC80A0E47898E47799E0799DD97AA1D37BA4D184AA
D28EB0D598B6D7A3BFD6A7C3D7ADC9D1ADC6CCADC4CDB2C8D0B9CFCCBBD2D0BCD1D299AD
94172AB20918B5040FB1040EAD050EA7010AA7020BA6010CA5010CA5020FA0010C9F020D
9C000C9B000B99000999010A97010999010A9900099B000C9F010FA60514AB0B19B0131F
A90D199F051191020B8000067F040C81040D81050D750106710103720305700002810206
8801048400027A01016F0001680401600C01
00FF0000FF007A20047805007701017801017E02018102037C02027501017301017A0104
7E01048200048500048A01068D02088B01088801068B01088A01078B01098F010D930210
95031299061798081796041694021293020D91000992010A8F01088E01098E010895010B
9B010A9E0008A70208AF030AB40509BB080CC61212D11918C50C0FC70C12C10710C50A15
BF050FC10712BE050EBF0711BD0511BE0512C40A16C20D1AB10F23AC284BBF517BB64B79
BE4D7CD15787D65A86DD608AE2698CE36A89E36D87E57085E37782E48086E2878CE18E96
E29CA9E5A5B6E3A0B0E398A5E59099E98287EB7478ED6B6DED6065F15B63F15562F04D5B
F14C5AF14C58F24753EF3D4EF03C4FEF394DEC3449EA3148E42D46DC2945D42445CD2645
C42443BE2444B92849B52A4CB12B4FA92D4EAE3B59AB405FAD4A6CB1597EBC678AC85E7A
9E0B1EB30513B4010CB2020DAB010AAB010AAA0109A90109A70109A8020DA7020DA5020C
A2010CA1010C9F00099D01099B000B9B000C99010B9B000C9F020FA30412AB0B19AB0E1B
A60A179C020F91020C7B00076E02066B03087201077901067C02067601037B0103880205
8A01038500027C01027201006C0401650D04
00FF0000FF007720037606007701017A01008201008801038801028001007900007B0002
7F00048601078701058700048D030A8A01088702078603098000057F010781010A85020F
85010F8D03129707159F0C1A97041298041096030D9401099301089601089C020AA6020D
AE050FB0020DBA070FBD070EBE080DBF080CC60F0ECE1614BD0407BC0309B70107B7010A
B5000AB4010AB5000ABA010EBA010EBC030FC10612C30713C60B1BCB132ACD1A36D72442
D92342E62D4EF44160FD536EFF5A6EFE626EFE6B71FF7977FF867CFF9689FFA89DFFB8B6
FFCED5FFD7E6FFD6E6FFCEDBFFC1C5FFA19CFF877EFF776BFF695EFF5C56FF5653FF514E
FF4D49FF4E48FF4542FE3C3DFE383AFF3537FB2C30FA272DF9272FF11F28EC1B28EA1C2B
E31A28DE192BDB1A2ED7172ED0142CCB142AC31225BD1125B71029B31231AC0F2EAC0A25
B30619B6020FB4020DAF010BAC000AAB0009AB0109A90008A90108A9010BA9030BA8020C
A7010DA5000AA30109A000099D010A9D010D9D020D9B000C9E010EA20311AA0B17AF131F
AA0F1BA0051295030E7E01086100014F00005F0206740308790409790205800203880205
8901038601017F01007601016E0300680F04
00FF0000FF007722027306007901027E01008701018D01029001018D0101870102830003
8101038802068601058301048903098801088000047F0007790004780106790007760008
720008840714A81D29AF1B28A20B179C05119A020E99000B9B0108A1010AAB040DB0020C
B3030DB2010CB6040EB7040DB8030CB50106B60203BF0907C00A0BBB0309B90209B50009
B8030FB6010DB9030EBC0410C20814CC101DCD1119CE0E18D8151FE51F2AE9222CE21C27
E82430E42232E32837EB3442F23E48F8484CF5494BF75451FE625CF7615AF66763F1686C
EF6C79EF6C82EB677CEE6578EE5F6BEF5356F54E4BF64742F63F3AF93A38F83636F93333
F93231F73030F3292AF02526F02425EE2223EB1D20EA1B1FE5191EE1161CDE141ADA111A
D20F17D1111CD0111FCD0E1CCB0C1AC80A18C50A16C10916BF0817BB0718BA081AB60314
B90514B70410B70511B1020EAC000CAB010CA9010AA90009AB010BA9000BA7010AA8010C
A7010CA6000AA6010BA3020A9F00089E01089C000A9C010B9E010DA20210A40413AB0D1C
A80B1AA3081695020E85010976040B5B01035801036100026200026E01047F0206870104
8801038701027F01017801017307026A1103
00FF0000FF007828077407007D01008601028E02039102029601029801039502058B0003
8401038602068202058102078101088201087F02057C01067A00057B00067D0209790109
75020A7E0410A31D2AA6131FA00A169C04119C020E9F030FA0020BA4010AAA020AB0010B
AF0009AD0008AF0109B2010BB4010AB80309C00B0BCE1814CF1A18C30C11BF0911BB0712
BC0814B90611B80510B80511B4030EB80612BC0812BE0711C50A15C80B16C70D18C20714
C40D1BBE0918BD0A19C3111DCE1925DC222EE62833EC2C37F4353DF6393FF83C41F73F42
F84046F93F4BF73C47F3363EF7383DFA3A3BF83835FB3632FA2E2EFC2C2DFC2B2AFD2C2C
F9282AF01F23EE2023EB1F20E71C1EE31A1DE0181EDA141CD31019D11018CF0F18C80C15
C60E19BE0A17BC0916BC0915BB0713BA0713B50310B20210B20312AF010FAD010CAD010B
AF030DB1040FAF040FAA020CA6010BA6010CA7020BA6010AA9030EA9020FA8010CA6000B
A6010AA6010AA30109A1020A9F02099E01089D00079E010AA0010CA0000DA20111A20213
A003129D021196020F8F000B8B040D7503076401026602046301036901037C0205850203
8701028501027F00017801017106016C1502
00FF0000FF007829097505008101008A01019001009200019902039C01049D0306960307
8701037C01037800027B02057B01057D00067B00037C000680010785010987020A900812
950E1988051295101B96071494020D95010C96010B9B010CA1010BA50007A90007B20309
B3030AB00109BB0810B8030DB5040DB7070EB6070AB40709B0060AAC0309A70109A8020C
A4020CA2000AA4020BA3010CA0010AA0010CA5010FA8000DAD020FAF0310B30815B40716
B30716B00615AF0614B40B15BC0E1BCC1626DB1E2BE7222DF02730F62D34FB3838FB3C38
FC413CFC3C3AF93936F93833FB3A34F93933FC3A35FB322EFC2D2BF82726F82724FD2D2B
F42424F12023F22225E71A1DE3181BE1191FDB161FD91621D0111CC90E18C80F1AC30D19
BD0C16B30612B10511B20711B30611AF0510AA020EA9020FA8010EA7010DA4010BA40108
A5000AA6020DA2000C9F010B9C00099C00099D00099E000AA1020DA5020FA6000EA5020E
A3010DA2020B9A01079301069701089C02089D00079F010AA0010BA1010CA20210A30514
9D020F9A000D97010D93010A91020A8203087101037303066F02046F00027A0103810204
8001017F01027D0102790201740A016C1600
00FF0000FF007B2A0D7B08018902028F01029401019501019903039E07089B0708940307
8702057700017300037601037901037C01067C01058001088601088A020C8D020B91040D
93060F8D020D85000989020B8B01098D0008910107990008A40209AD040BB00208B60609
B6060CB2030BB80911B1060EA50109A10109A000079B0007990007960007920007920008
91010790000891000794000B95010B99010E9D010E9F010EA40310A90412AA0411B10818
B20815B50815B80B17BB0C17C00E1BC81321D61A26E7262EF22F35F6383AFB4944F84D43
F64F45F54F46F45148F65149F34D42F64D41F94E41F13A2FF7382FFC3832FB3530FB3430
F8302EFB302FF72B2CF02326E91B20E61A22E41C26E11B25D5151DCF121BCC121BC50E16
C00B13BC0A13B80913B30511B10410AE040FA8010CA6010BA6020CA5010BA2010BA1000A
A2010D9F010D9B000B9900099800089800089701079700079900099C010D9F010E9F030F
9C010C9D010C9401088900039001069801099C01089C000A9C00099D01089C000B9C010D
9B020D97010A9200079101059000078501067700017601027400027600047A00047B0103
780101790101780002730201720D026A1900
00FF0000FF008231117C09018E04039502029A02049B02049705038D05057F02017F0306
7F02067500017200027701057B01047E0107800108810108840106870108890108890007
8B01098B010A8701078701078801078C00069301069B010AA5020AAE030CB7070FB5060E
AB030CA2010B9E020998000792010791000891010A90000A8E00088A0007880006870006
8800078B00088C01089100099300079A010BA1020EA4010EA7020EB30917B00412B70613
C4111CCA141CCF181DD51A21DB1F28D81F29DF262CEF3A3CF74D4BF76057F87364F67D6D
F38879F38F85F5978FF4968EF39085F48876FB846DFC725BFB5F4FFC5449FF4E46FF4A42
FD423EFD3E3BFC3A39FC3738F92F33F62A30F3262DED2227E92226E21D22DE1C22D7171D
D11319CC0F17C60B15C00713B90510B50611B0030FAF020EAF030CAC020DA7010BA6010E
A3010E9E000D9C000C9A010998000799000797010794000693000795000A97000A98010C
98010B9801099201088E000692010898010B98000999000999000999010896010895010A
95010A9201078E01038C01028D01048B02068201047F01047B00047B01057B0104750001
7200007401017401026D0100711205681B00
00FF0000FF00893A187C0B018D0201980102A005079B04058E0504800A0BAB43457B1316
7202047401037200017401037B01047E01067F01067D01057C0004810005870108880109
89010A8901088701078701068702048D01079401089D020CA4020DA8010DA9020CA80410
9A010B93000A8D00078F010A8901088801088A00078D00088D01098A00088B00078C010A
8E0008900009940208990209A00208A8040CAF020DB70612BB0711C10A14C80F18CF121B
DB1A21E9262CF02E31F7383DF73940F73F48FD4F53FF5F60FF736EFF978BFFAF9FFFBDAF
FFD6D1FFDEE3FFE1E7FFDEE3FFD6DAFFC1BEFFADA2FF907FFF786BFF6861FF5752FF554F
FF4E4AFF4947FF4647FF4446FF3A3DFF353AFF3236FE3035FB2E33F82C31EE2429ED232B
E72028E51F29DA1621D61520CE121CC20A16C00915BC0511BE0712BA0711B3020EAD010D
A9010EA5000DA2010CA0010B9F00099D00089A010697000596010797010999010B9A010C
99010B97010895010893010994010A95010C95010B98010B98010B97010C93010B910009
9000088D00058900018A01028B01038B01048901048501058001057B0003790102770102
7400017201017202016F05017216046A1C00
00FF0000FF0094471C7810018C05019C0305A70A0B9905058101019421239A29307D0C13
6E01027B02057A01037600017A00037E01057E01047900027A00027F0105840107850109
8501098701088803098B080E96141897101695061198020F9D020FA204129E020F98000C
91010A8A00078900068E030C8901088C00089000069500079700079800079A01089E0008
A1010AA3020AA50209AB030BB1030CBB0711C70D17CC0F19D5151EDD1D24E72329EE272E
F0292FF63138F7323AF7353FF63744F63948F7414DFB4B55FC5B61FA676BFB7A79F98081
F4858FF48698F38297F17B91F07285F06674F66066F14F4DF84846F43C3CF83838FA3837
FC3939FC3638F93134F92E33F92C31FB2D32F6272CF6272CF4262CED2027E81D27E81D29
E01822DF1823D8121EDB1824D1101BCC0E1AC70A19CA0D1BCA0C19C10612BF0713B80310
B4020FB1010EAE010EAA000CA9010CA50009A000079D00069D02079D01099F020D9D010D
99010B98000896000695010990010A88020B8B020C9A05129D03149B031594011091010B
8F01098C00058701028700028B01048D01048D01048A01058301047D01027C01027C0002
780103720000700200750C037117056B1F00
00FF0000FF00429D02751B02830A019A05059F05079303037C01017D030688050B810409
7000018001048803058101037C00027F01048101048300058100038001058001057F0006
81000889040E98121DA01C28AC2D37A11F29970F1B96061595000D94000C92000A8F0009
8D01078C00078D000593010A96020A9D030BA40209AB040BB1070AB70C0FB3070BBA0A11
B70811B80913B90A14B70811B3040BBD0B14C50F18CA0F1AC70A14C60914CE1019CE0E19
D1131DCF111CD31420D41323D31625D51525DA1A29E82533EF2A37ED2C38F33943F6434A
FA4C55F84B58F54453F33C4CF43948F73943F7373BF43030F82F2EFD302DF92924F92723
FB2A27F82727F42224F21E23F82429F21E23ED191FEC1A20E6161CE2151BDC131CD7121C
D00D18CF0E1ACD0E1BC70915C20512C30815C00614C20715C10713BE0511BB030FBC0411
B80410B7020FB60210B4030FB1020CAD020BA80109A50108A40108A40108A5020DA2010D
9E000B9C01099A01099601088C010A7500037B010A960617A1091DA0091D9C081995020F
9000098C00058801048700058B01058E02059002068C02058401027E00017E0101800202
7D010376010172040179150A671501349000
00FF0000FF004FAF0A9D56287C18078F08049102028902037701017A02038A0307820205
6E00008101059202058F000387000286000290030894040A90050A8602077E01047D0106
81010A8A0311970F1E9D1627A423329C1A28950E1C9106138F010C8F010B92010A93010A
95020899020A9B0109A1020AA7020AB0050EB6080FBF0E13C31214C61919BB0D11B5070E
AD040DA50308A30108A400089F00059F0108A5010CAB020EAF040FB00310B10210B50412
B60410BA0512BD0512C60B19C70B17CB0B17D8131DE1161DEF1F27F6262CF72B2FF62F31
F83736F93A3DF6393CF7383AF73637F93635F83531F7322CFC342CFB3129FB2C22FB2B22
FA2C27FB2D29FA2A28F52222F82324F72222EE1A1BEC171AE81419E61519DE1115D50D14
D00C15C80813C70B16C30814C00713BA0310B6010DB6010CB6020DB2000AB2000AB1010B
B1010BB2010CB3010CB1000BB0010AAF030BAB0109AA010AA90109A8010AA7010CA8020F
A5010BA3010AA0020C9A010992020A7F02077C00079404159D04199D04199B0417990211
96010D9101098B0107870005840105850203890004890104870102840102830202820102
7C010177010174070176170A621500369300
00FF0000FF002EDE0B7F410E6712018309038801027F0102730000750102870405830305
6E00008302069A0307A303089F04079801059902079B040A9202078501077E01047E0107
80010C8C0313950919990E1EA82331A11B29950B1A9003108B01088D000998030E9C020B
9D0208A10209A6030AAA040CAE050DAC020BAD040DAD050CA70408A10306990104970007
9400078E01038F000394010490010493000798010A9D000AA2010CAA0210AE020EB3020E
BA040FBD040FC90B14D5131CD61018E0181EE92022F22A2AF93331F73631F53834F13C37
F2463FF3504BF35955F15855F15652F4544EF65147F64A40FB4B3FF84234F83D2DFD4234
FC4036FD3E36FD3932F9312AFC312AFD302AF62823F82624F62122F31E1FEE1C1BE51517
DE1117D30C14CF0D16CC0B17C70A16C00712BC050FBB050EB7030DB4020CB4020CB3030C
AF010AAF000AAF000AAD0109AA0007AA0007AA0109A90109A8010AA8010CA8000CAA020D
AB010DA8010CA5010BA1020B9A01099101098E00099702109E04159C02169A01149A0111
99020E93010B8D01098502077501037402037E0105850104870104870102870102860102
7F0100790100750A036B1304671B0000FF00
00FF0000FF0000FF008548156312007F0B038101007E01027501017201018506087F0305
6E0001820306A5090DB1060BB3080DAE060CA202079B03088E01058101068002067D0108
83030E88020F920616990F1CA6202A9D14209206108F010C90020C92010A98010A9C0109
9B01069D00059E0004A00105A100059D00069900079600059300048D00038A0002890003
8B00048D01058A00028F00039401069D0108A6030CAA010DB2040FBE0814BF060ECA0A12
D30F15D91217E81E22EC2024EF2527EF2A2AFA3B37F94339FC5246FC5F54FB6C62FA7B72
F58881F59994FAAFACFAB4B5FAB0B0FAA5A3FB948CFD8174FE7264FD6859FD604EFF5F4C
FF5649FF5246FE4D3DFF4C3CFF4939FF4336FF3F35FE3730FD2E2BFD2C28FB2824F6221E
ED1819E6161BDC111AD9101CD30F1ACE0D16CC0D16CA0E15C30911C00710BC040EBB0510
B5030EB2010BB1010BAD0108AA0007AA0108AA0109A9010AA8000AA8010CA8020BAA010B
AC020CAA010BA70108A300079F00079E01089C010B9A010B9C010E9C011199021097010F
94010B9001098B00088201076B00026500027701067F00048401058600028A01028C0204
8702037D0201760B0467110050580000FF00
00FF0000FF0000FF004CAD0D6A1E00790E017E03018201017E03026F0000780505750304
6500007F0304A5080BAD0207AE0308B2070EA9050B9A01078D02077E00047B02067E020A
84040E880310910A1796101C900B148C040D8B02088D01098F020B91010A930208940005
9800069D00079F0004A10005A20004A100049F00069900049600039301009701029A0204
9D02059D00059B00059D0206A50209B2040ABB050DC70B15CF0E16D9121ADE1419EB1D1F
EE1E20F52727FB2B28FD3332FE3B38FF4843FF534AFF6057FF6F66FF827CFF918FFFADAD
FFCACFFFDBE4FFE3EFFFDEECFFD9E6FFD4DEFFB7BAFF9992FE7D73FF7168FD685CFF6255
FD574BFE5749FE5243FD4E3EFF4C3EFE4338FC3A30FF3830FC2D29FE2C28FE2B26FB2420
FB2322F01D1FE8181FE41722DD151FD50F19D4101BD10F19CD0C16CB0C15C30611C20814
BE0713B90410B6030CB4030AAF0008AD000BAD000BAD010BAC010BA90009AA0109AC0008
AE0109AD0009AA0008A50007A20005A10005A101089D00089B00099B010C97010A94010B
92010A8D01088A02068601077703076E00027801047F01048400048801048D01048D0204
8A0102810201780C036D15001DCA0100FF00
00FF0000FF0000FF0000FF00914C177111007C04008803028605047102026802036A0808
5F0000800304AA0F10A90407A50005A70108A9030A9E020A8C01067701036A0104720209
7E020C82010C83020C81010B8401098600078600068700058700068800068A0006900005
9C0109A7020CAF030CB2030AB7050ABA060BB9060BB00209B10709B20A0ABA0E0DBC0C0E
BA080DB8050EB80811CC2027C11018CB1016D00F15DB141BE0141AEB1C22EE1E22F72528
F62426FC2C2CFE2D2BFD312FFE3B36FE423BFA463FFB4E4DFC5758FB5B62F86169F76D7B
F4798AF6849CF2809AF17792EE7188F16F82F9707AF96668F85855FB5653FF5954FD524B
FD4E47FF4D44FD4A3FFB4037FC3D35FE3C34FE372FFC3029FC2825FB2522F31D1AF41D1A
F21B1AEE1A1DE4161DDC111BD8101CD40F1BD10D1ACE0D19C90B16C70B17C20815C00714
C10815BD0512BB050FB6010AB6010CB4010CB4010DB4000CB5010DB6030DB6020AB80309
BD060DB7020AB1010AA70107A20005A20106A301079E01069A0006990008970008930007
9101068C01058A01048901058002057B01027F01048101048301048701038900048B0103
8B02028404027B0E066F180000FF0000FF00
00FF0000FF0000FF0000FF004FAB0D751D007F09019007048F05037D04046A0D0C7E2F2E
5C06048D0C0CA6090AA70305A50006A50107A80108A8060E9402077300025900005E0002
7402097D0209830C11860C14830209820005830105810004810004860208850004920106
A30109B2030EBB040EC0030BC7070ECF0C13D21216C3080EC20C10C50D10C81012C50D11
C0070DBD060FBF0A15B3030CBA0811C30A12C3060ED10D15D00910DA1218DB131AD80E18
DF141CF12127F11E20FA2929FC322CFF3932FD3A33FD3F3CFE4142FA393FFB3C44F73D48
F53E4CF84656F64352F43E4EF63F4CF73E49F94146FE494AFE4645FB4240FC4543FD4543
FB3D3CFD3E3BFD3C37FD3733FC342EFD322BFC2E28FE2B28FA2423F61F1DF6211EF11B19
EB1517E8161BDA0D16D00A14D10E1ACC0B1AC40815BD0815B10713AC0915AA0613B10513
B6030FB90411B6020EB70410B5020DB8030EBB0410BD040DC20712C30611C70811CD0D14
D10F16C90A13BA040DAC0108A40006A50107A100059E02059A0004990106970005950105
9301058F00038E01038B0103860004860105870104850104840104840104840003870204
8B0608820604780D026F1A0000FF0000FF00
00FF0000FF0000FF0000FF0030DE0D782402800E01950D059405018E0709822124ECA8AB
6A1315930D0FA40609A70308A60208A50007A70107AE060DA7080D8500036F0103680002
7101077B01067701037B01058101068000048300058401058401038500048A0004970106
AC040CB7040FC30812CC0A13CF0A13D10C14CE0D14BF060DB7040AB5040BB1030AAF0208
AC0008A80009AA040DA5010AAD0710B90F19B4030FBC0410C30913C2070FCF0E18C80714
CA0511E71B21F21E21F92423FE2F2AFC2E29FB2D27FD2E29FC2F29FA2827FA282AFB2D2E
FB302FFC3132FC312FFD3330FA2F2EFE3333F62828F92D30FC3436FE3A39FE3B38FE3A38
FD3534FD3433FB312FFD312EFD2F2AFB2B26FA2724F62121F62121F21C1DF62222EF1A1B
EE191CE7151AD70D13CA0811C60815BF0715B40615A3030FA7121EDB515DAE26339B040F
AD0411AF010FAF020DB1040EB2020DB7020DC00711C40912C60810CB0A12D00C13D30C12
D40F14CE0B12C10510B2020BA90109A30107A001069C0104990003990104960003950103
9502059302059201049102048D01038D02058C02038700028501038301047E00027F0102
8607088009067D180854540000FF0000FF00
00FF0000FF0000FF0000FF0000FF007F3008871D099717079A08039A080B800D12701A1E
720A0D9207099D0204A00105A30105A60106A80207B3060DB6090FA20207940207870207
7B00037F00048001038402068601068901078E01099002098F01079001079802099F010A
AC060EAC010AB6030AC70A11CB0A0FC9060FC1040EB30008A90007A301089E00089D0008
9A000795000697010995000A9500089E020DA7020EAF020EB3020DBE060EC7080FCC0B14
C9030CE61A1CF01C1CF51F1EFA2523F5211DF7231DFA231EF6211BF8221FF92323F72422
F92622FB2A25F92A23FD2D26FA2B25F72824F32123EE1D22EC2023F32928FB332FFB322E
FB302CF92E2CF92D30FA2D2FFA2C2AF52725ED1E1FE91A1DE7181CEA1A1EE91A1EEB1B1F
E9171BEA191EDD1219CB0812C20512BA0513A704119000099C0A17A00E1FB126368F000B
A1020CA7000BA9030BA90108AE000AB8030FBA010CC10710C30610CE0E16D20F15D10D10
D10D10CE0C13C30812B0020BA80209A100069D0205990104980104980004970104960104
9101048901048E02069402069301049000028C00018A01018701028201047D00037C0003
7C02037B0901771804388F0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00883F0E8C2E119E23109B0A02970404901112962C28
89110C9304039902029B0002A30204A70106AC0107B5040ABC080DB30309B1060BA9050B
9801059001068C01058F02069101079501089801099C050D98020A9701089B02099D010A
A0020AA40108AC0309BD060EC4070EC4060DC70913BD080FAA00069E00049A0005970007
9300079000089101078C00078E000798010AA00008AC0109BB050BCE0E11D6100FE31718
E41615F0201DF6221EF3201CF2221EF72923F42A22EF271FED2921E82921E52C26DE2A23
DF2C24E1302AD52721D42720DB3028D32923D02723CA2220C5221DC4231BCF2C26D6322B
D42E28CD2722C11C1BC82325C82221C62120C11A1ABF1518C51B1FCA1E21C7181ACE1A1D
D51B1FD81A1ED3171DD0161EC50E16BE0C17AB0C158700088C06109A08189A071597010B
A7060EA90209AD0209B00209B9050EBF0711BE060EBE050CBF050EC60610CD0B14D00D12
D10F12CB0B11C10912AE020BA401099D0005980003950005970106960005970106980106
8E02047900018001039201089501079101048C01028B01018801018501038000047C0204
7903037D13076D170238930000FF0000FF00
00FF0000FF0000FF0000FF0000FF00965116792403901B059E1107910301870402961D17
910D079402019801019C0001A30104A90007AF0208BC070CC0090DB90209BE070DC30B11
BB0A0EA70206980004970207990109980108980108990108950107920006950107960007
9D0107AC060EAE020BBA050DC20910C50911C80C13C30911BE0B10B90D10AB0407A10007
9A0007950007920005900004970104A20307AF080AC10F10D61D1AE3261FE72920E5281E
E83024E32F24E03226DE362ED6382FD43F33D44437C63C30C9483CC85244BF5345BD594C
C66457C6685EC26A5EC77064C77165C47066BD6C60BE6E60BC7061B97061B66D61BD7165
BE6F63B6685BB06157AE5F57A85951A5554BA250489F4943A149429E423C9C39339B322C
9D2D27A029259F221DA3201CA21B17A319199A1A1A791312CF787AA240467D0A128E080B
AF1418B30B10BC0E13BF0D13C50E16C20B11C1090EC60D12C2090FC6070FD00D16D00D13
D00E13CC0D13C00910B0030CA3000A9B0108970106960008940007920006970107990107
9103077E01037F00039202099401088F00048C01028B0101890101860101810204790103
7607037E1E0E6D1F0300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A203762801871A03940F058B0201850001870200
9207039601029B0102A10003A90206AD0106B40408C40D0FC2090CBE050BC3090DD11013
CC0E0FC10B0DA801049F00059C01099800089300069300079201088F0007910008990109
A5030AB90B15B80710C10C14C0090FC20A10C40B11BF070DBD060CC61316C31214B50B0E
AE0D11A50C109E0E0E9F1211A81B17B2221CBC2D26BD2F25C13A2DC44033CA4D3EC65141
C65C4CC76757C56D5CC47467C47E72C3887BC18B7EC59588C39C8EC3A393BAA090C0A99C
C2AA9DC1AAA0C6B2A5C7B4A8C4B4A7C3B3A6BEAFA1BDAEA0BAADA0B6AC9FB2A99EACA398
B0A599ACA396A69C91A1968D9D93899B90859D8F879B8A8398887E948077998076987B71
96766C926F638F685A936555945E4E9256478C51447B4E44906F6AA07A785F282473221C
8C231B9218139C1613A31412AC1615AD1010B81213C01314C20E10C90F14CE0F16CD0D13
CE0E14CA0C13C60D14B7070FA5010B9C000B99010B96010B930009940108970107970005
9301068C01058D01069502099201078E01048E00038C0103890102860101800001780101
760B03751C0967210000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028D8067A36027F2203830B03860202870200910705
9606039B0301A10102A60103B00609AD0002B30204C91111C10809BD0409C50B0DD11011
CE0D0CCC0E0FBC070AAD0306A100059C010993010995040E96060D95030C97010A9F010B
AC040DB4050EB7070EB8070FB8080CBA0B0FB80E10B10F12AB1011AD1915AA1C15A51F18
A227219E30279E3B30A14A3EA85649AE6153B16D5EAF7466AC7C6DAB8071AA8575AA8A7E
A78E82A48E83AA988DA89A91A79D96ABA59DAFABA3B2B2A9B2B5ABB7BCB0BCC0B6C3C6BC
CCCDC5D1CFC7CDCDC4D0D1C9CDCFC6CDCEC4CBCCC3C7CAC0C3C7BEC1C5BEBEC4BDB3BBB3
ACB4ABACB4ADA9B2AC9DA5A29FAAA69AA5A1969E9D9097978B93908A918C8A8F88878C85
85888281857C84857C817F747F7A6C80786880796878756776766B747166796E60806859
8763548A5B4D88524487473A8C3F33852C218F251D9F241DA51B15AD1514B61214C01417
C51316C60F14C51017B70710B00612AA06139F010E97000C94000C96020C970108980207
9702099401089401069200059100059001039202049102048B00028801028302027A0201
78100567160133910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00925616782C04720C007F02018B0401960702
9C0702A20402A70301A80101B20808B20406B50304C81010BF0709C0070CC50B0DCA0B0B
CC0D0CCF0F0FCC0D0FC50C0FB8090DA9050B9E090F9D0E15A41418A40E14AB0D15AD0A15
AE0911AF0A11A90B0FA10E109D1310981613941F188F29228F382E964A3D9B5B4B9E6756
9F71629E7769A081709B837497847695837994867E958D8692918894978E95998F999E97
98A0989FA39E9CA39FA4A8A7A6ABA9ADB3AEB3BBB7BCC4C0C8CECAD2D7D1D6DAD4DCDED8
E3E4DEDDDCD8DFE0DBE1E2DEE2E3DFE3E4DFDADBD7DCDFDBD9DED9D2D7D2D0D6D0C6CEC8
C5CBC5C0C6C1BFC6C0ACB3B0ABB4B2A4AEAD9DA6A599A2A1969E9E939A988D938F8A928D
868F8B848D8A838B897D848178807A798279798277768276747F73767D71777A6F7A7B6D
787A6B7574667471647971637E6F617D68588262528A5B4D90514490433A91342E952723
9A1D19A41A17A61415A40C0FB9141BB80B17B50B19A705139C000E9A000C98010A950107
9602089400079301069101059001049201049403049102038C01028801038502037A0101
771206691C001BCB0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B61678390B6810017F0602940B07990200
A10401A80503AE0604AD0403B30606BD0B0CBA0608C40F11BD070ABD050AC3090BC90B0C
CC0F0DD0100FD11011D11013CE1315C51518B01113AC1A1EAE2023AD1D20A8171B9F1418
9414148F191887221E86342C8C4B3F955F54986E6198786B967F729180728F84768C8777
8A88798D8B7E8F8C808B89818C8E868F908C92928F939493929794939C9998A29C9BA49F
9EA8A2A5AEAAA6B0ADB0B8B8B5BEBDC0C7C5CCD5D3D5DBDCE0E4E4ECEDEDF2F4F2F7F7F6
FAFAF9FBFBFAFBFBFAFEFDFDFBFAFBFBFBFBFCFCFCFAFBFBF8F9F9F6F8F8F4F6F6EDEFF0
EEEEEFECEAEAE2E2E0DADAD8D1D2D1CBCDCCBFC5C1B6BBB6B5B9B6B2B5B1AEAEA9ABABA6
A5A6A29B9F9B969D9A949A978D928F868E89848C86848C857F867F7F847D7B8078798075
747D71767C75747A73737A7271796E72786C76786B787568786F617A6B607C655C846258
87594E8A4B438639358123209B2122AE1D21B5181FB7131DAB0712A5020EA0020C960006
9300059301089001068A01038A00019101049303049001018D01038A01038301027B0400
791605378E0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009056236B17028A11069B0C05A10302
A60301AE0606B40907B40707B20502C00F0CBB0808B60407B50207BB0308C80E10CB0D0E
CC0E0FD11012CF0F12CF0F14D2151ACF1B1CBC1D1CA724239F2D2E942E2D8F3330873B35
8D534998695F9A786F917E718D85768C877B89867B8B897E8C8B7F8D8C828B8D838B8E84
8B8E838E8F878F908A8E8F8A91938E959894969996989C9C9EA4A6A4ACADADB7B5B6BEBE
C4CDCCCCD5D6D8DFE0E3E8EDE8EEF3F1F5FAF6F9FFF7F9FFF8F9FFF5F3FBF4F2FBF3EFF9
F2EDF7F0EAF3EAE6EFEBE4EFE9E3EEE5E0EAE0DAE6DED7E3DED7E1DAD4DED9D3DCD3CBD3
D5CBD3D7CAD3D7CCD1D5CCCFCBC4C6D0CDCCCDCBC7CBCAC5C9C6C3CAC6C3D1CBC8CEC5C2
CDC3C0CDC7C3C7C2BEC2BEB9BAB6B2B2AEABADABA7A9A5A0A29C999D969197938C8E8E84
898D8283887F83877F7C81797B81787B83787B8277787E73747B6F767D73767B73757870
737469756C6577645E7C5D5586544B8C423D943230992122A51B1FAD151BAB0E149F0309
9B02079302068901038601028700008D01038F01048F01028C01028900018502027C0501
7D1A061EC90000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A4672D7B2707961E0BA21004AB0A03
B20A06B60907BB0B0ABC0C0ABC0C08BD0B08B80705B00203B40105C1080CCA0D0FCD0F12
CC0F10CE1113CB1314C81619C01C1DB32421A4332C94453F8E5953936D669579728D7E74
8882758B877C8B89818A8B82848A7C8B8D838A8C828C8C828E8F858F8F8791938D92948E
979B93989C959B9F9BA0A39FA5AAA5ACB2B0B4B9BAC3C8CABFC7CAC4CBCFC5C9CFC4C8CF
C0C5CDBFC1CBB5B6BDAEADB5A5A5ADA09DA99B99A79D99A69C99A4948E99948C98948898
9688969A8C99988A969487959589969B8F9B988B958F808891838895878C9284888E7F80
9583828F7C7C8E7C7A8D7C7991827F9086818D8780918983958A869185808E807B8F807A
94847D8F827B958980978B81A0918B9F918CA59891B2A29BB2A29CB2A099B2A299AEA197
A79E92A6A1959F9C8F9B968B9794899390868C8B8086877B82877A80857C7E847E767E79
757F7772787176797376756E76726A7667607B5D5883514D853C388A2C2891211E951313
9F121593090C8902058A01048801018800018700028801018A01018601018103017C0800
791A0400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0050AD0F782704901D04A41303B41006
BE1109C5140DC2110AC3100ABE0D08C30F0DBC0C09B80908C00C0CC60E0EC60B0DC90F13
C61314BF1816B01B189F241F99393298544D966E64917D738A837985837B84857C82877C
83897D888B82888C848B8E858B8E828E8F8692938A92948B9899939B9D999DA09DA3A7A4
A2A9A4A8AEABAAB1AFA8AEAAA8ADAA9EA0A19495978E8F9288898C88878A868585878485
8784858A8687918B898B83828F87858D8382887F7D90868491868191857D90837B968680
92817A9180789B8C869A8D86988D86A19590A0938B9A8B7F9485789B8C7E98897B99887A
9A8978998877988977928273988A7B9E9385A49D8FA69D909D92839A8C7D9A8A7C8B7A6B
8D7C6A8979668879658777628A78668C796A8A77678975658D78688C75658D75648E7765
94816F9586749C8C7CA29283AA998CA8988CA39689A4998C9D968B9A958D92908C8A8B86
868A8181867B7C81797C817B797F7B75787672706D70696571605A745850744A4072312B
751B1981151485080B970A0F9303068900018301028401018601018302017F04017C0E03
6E160300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B742B018621039D1703B71509
C21508C7160BD12017CF1C16C5120CC20F0CBC0C0BC71919BC0B0BBF0E0CBB110EAD1110
A31E1B9830299B4F479E6E64987F768D837C84867D83877E848A81878E84858C7F898E84
8B918690938C8F938990928B91938C93958E9899949598939A9B9898999794969490908E
8A8B898485848C8E8C9899948A8982918F87938C85938D84938D83989287948D80989184
9D96899992849E9687958C7E9B9383988D7F9A907F9B8F7F93887590846F8F836C978973
968871978A758C826F9388759D907F998D7E958977968973988B76978B76998D789C907A
998C769A8D77978E779B907CA29585A198879D968499917E9B907B9587718F7E678C7A63
8B7A608A7A5D8B7A5E8A775C8C7B608E7B628C785F8D785F8C775E8D765C8B73588A7056
8C7259896E578B715A8B725C8E74609077658E7A6A9584759A887CA19288A1948CA0948A
9B93859590808E8C8085877D7E817B797B7975787675767373736E6C6D666A6760695A54
694A4367322D6F1C198B1716960F0E8B03048100018001018101017F01017E06017C1407
34870100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007E3C05772200982108B2190A
C82214C3160CC6180FC81611C6130CC1100CB80E0DBA1B1AAD120FAA1B149A261B913C30
8F584C9071678B7B7289837C858882818A827E8980848D858A958B8D978D8E978A8D948B
91978E90948E90938A8C8E87898A8583857F80817C7D7C777E7B7687817A8E8A808E8A7F
93908599958D9A988FA29E959894879B9587999281968D7C9C94819C94829A937F9B9381
948D7A918A7698927D978F7EA29B889E9885A19A889E938499917F98907B98907B988D77
988D77908670989179A1957F9C907D988B7B958675948671968A77998D7C9A907E9D9581
9F9883A09884A199859F9684A29888A39C8B9F988698907C9B8F789080678E7B638F7C64
8D7B60917F62927E618F7B5F8B795D8B7A5F88755B8A785E8C7A5F8A775A897458897258
8A71588B70588A70568E74598C7156927960A08C77A392819789789081718D7C6D8D7C6B
8F7E6C988877998F7D948E7E918D8187867D81817B7B7C7677787373746F6C6D6A686865
62615B60544D62423A6B2E25791B1487120E8506067E00017C00017B02017D0C02751507
2E850000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009A59187A2E04871F03A91D0E
C6291DBC1D13C3251DC11A14C1140DBC140EA7120D9F261F8C281C9247378D6151806B5E
78736880807A85878083857F878D86838C848A958B909B918E9B918F99908E958D888B86
8588827F807977776A78766A8582778B887D929084959083968F81988F8098928096917D
9693829B9788949083949183908D7E979181999581928C7899927F98907E99927F9B9281
9B938298927C96907A99917E9B94819892809E97869C9284A19786A097859C94819C937F
9C937E978E7A99917C998F7D9C927F9C917E998B789D907DA39985A096849E97849C9783
9D97849E9785A09887A099889F998AA39D8EA0998999917F948973918067907C648F7B63
89785D897A5E8B7B60897B5F8A7B60887A6085785E8479628276607D725B7F715A7D6F59
7D6E5980705A86735C89785D90806297866D9A8A76978A77958976978A7695857191816B
8B7B6387775F85755E8576628B7C6B95897A91877B8E887C8A867C7D7B737575706F716D
666B6561645D615D55614F46623A2F6A22197B16137F07087E03017C0500801406671204
29860000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029D808803B077F2708A93729
A91F18B32523E86D6CAE1916B71A11A71B128C261B985B4E8663547A6B5A727162707569
797E76848681868882888B84898E878A90898F948D8A8F87858C827E82767C7D727F7E73
8381758A86788C88748C867397907F9189799B938498928097917E958F7D9A9581958F7B
928D79928D7B958F808F89798E8B7A98928194927D9994809D96839A92809A927F9C9383
97907F958F7B96917B9C9481A095849D9583A19B899F97879D95849C9281A29886A19886
9E9784A19C8AA49E8DA49D8DA39C8CA49D8AA69D8B9E96839E9783A19A889D98869C9986
9F9A88A39C8C9E97889F998C9D9B8D9F9C8E9F9C8D9A9585968E7C8C7F6B8A7C67887A64
847962847D65827F6683816A85826E84806F817E6E83837483847786877A8E8E80908F81
959285908C7C938F7C98927D97917A968E78988E7B988B78978B77998B769B8D78998B75
978A7096886D93836A8A796187755F84725D8575618B7D6B8F8574928A7B8B87797E7D72
74766E6A6D6662635E5E5D585B52495C43375E281F6F1712810F0A7E0B027E1B0E560B01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A6692F793717D18076
992B27A52324E06367A5201BA3281B933D2E875A4A7565586E6B5F6C70636F7969757C70
82867C8B8C848C8E86888A8384867D83827B7F7D747C796E8280708A8876948F7D96917E
9D98859A938098937E99937D9A94809C94839A93819A9380958F7A94917D99958198917E
968E7B98917F9A9382968F7D958F7C9994819995829A94819B94819E95849E96859E9885
9995819996819E9A86A19A889C95839C96859F9B889E99879F99899D95849D9584A79E8E
A09A89A09B8C9D9B8A9E9A8B9C998A9C9989A39F8FA19E8EA39F8EADA797A5A1919C9A89
9F9B8E9C988B9B988B9B988D9A9A8F97998B999C8E98998C98988B979587949584979987
949787999F8FA5AE9EA7B0A29CA499979D968E989186938E7C89857D8A877F8A877C8481
808782858A81888C818A8B7E8C8A7B928D7B948D7A9C917EA0947E9F917BA0907B9E927A
9C90789D91789B8D779687719989719180678C7B638B7B648D7E69857763897D6B8B8171
8C87797D7D726F6F686667605D5D5657524853423657291E68170C751709651204500C02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0066CB2F91603EB1746B
A74945AC2B27A526209B32258F4C3B80614F726958706E626F736671786A767F6F7F8376
85877A86867B8180747D7B6F7C7669867E6F948B7A938B79928D7894917A95917C97907D
97917E9A93809B948198907C9B948196907D99947F98917B96907C9A94819A95829B9481
99917F9B948297907E968F7C98907D9B93839F9A8799927F9A93809A93829B95829A9583
9795819A98869A98859B97869896839694829696839795859E9A8BA09C8C9E998CA09A8D
9B978A9D9C8E9B9C8E99998A9E9E919D9F929A9C8E9A9B8EA5A398A9A79CA9A89DAAAA9F
ACACA2AFAFA5AFB1A7ADB0A8ACB0A8A8B0A7A7AFA7A7AFA7A6AEA9A0AAA597A39C9AA69D
98A39B99A49C98A39A98A19791998F848D837F89807B847D77817C727F7D737F7F798584
7C88867A868477837E80888085867B8F8B7C928A789C907E9D917C9F917B9F907A9B8F78
9C917A9E937C9D907A9E917C9C8E789989729A8B739585708F7F6A9889739384707D715F
827968857F6E8A8577827D716D6B605F5D53575247554335552A195F1E0D500E00268601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C6966D7C4030
9033299E2A1F9837278C53437862506D6A5A6A6C5E7072627379687B81707E8472808172
807C6D807869827D6A8F8876948A789387738C7F6B9B907C96907B96927B908C76948D7A
99927F97907F9992809A9280968F7C97917E96927D97917E96907E9D96859B96869B9787
9D99889D98889E9A889E9988A09A8AA29D909E9B8CA49F91A39F8FA39E91A6A092A39F91
A09F909E9F91A3A294A6A6979E9F8FA2A395A4A798A5A79CA4A59BA6A89FADB0A7AFB2A9
B5B9AEB4B8ADB4BAB0B5B9B0B3B8AFAEB5ACAAB2A7B0B7ACAFB4ACB0B4AEB0B6AFB3B9B2
B8BEB8B6BDB7B5BBB7A5ADA9A3ACAA9FA9A898A4A195A09E8794937D8C8B778580758179
7E8780868D84898D818E8F818C8C7D8081707A7969777263706E5F696A5D68685F64645D
5F645F5B65625F6E686F7B75797E778382778F8878968B7A9C907C9E917CA1937C9F927B
9F937EA0927E9D907B9A8D77948770998C76A0917BA3937D978871988B75938876827969
746D5D6B6656726D5D807A6A827C6B777262655F50574F3F513E2B572F1C460E01248601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8BF59804527
782A18914433875645705A4C6B66556C6D60707363787C6A7C806C7F816F7B7967827C69
8A816C8E836C938871968B77978D79998E79998D78978C7A98907B908A71928D7499927F
9C95839893839C9888A09A8BA6A090A8A192A7A495A7A294AAA597A39F92A19E91A19E92
A2A0939D9C8FA5A4989E9C959999909F9F98A2A49CA3A39CA9A79FB4B1ABBAB5AFB3AFA9
A3A39C9899939B9F969D9F9793978E8F938C919590929995909895919E9992A19C9BA7A3
AFB9B3B9C1BCB5BFBAB3BABAB1B9B8AEB7B3AAB5ADAAB2ACAEB6B2A8B1ADA7B0AAA6B0A9
A1ABA5909A968189857C82817D8482727B7967726D5D69625A67605D69616B776B7E887C
8E9488A8AAA0BBBBB1CBCAC0CBC9BFBBB8ADA8A294958E7C847C688B7F6B82705D7A6754
695B49544E3F4D4F42575E566870697A7D728782749187769C917E9E927DA1927C9C8D77
9D8F7A9C8F7A9C8F79968971998C739A8E759C90789D8F78998C75958B77979080817E70
6A6A5D5D60544D5245535444736D5B887E697D735F685E4E584B3B5A402C451606248701
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003AEB1DB07D51
6C3E237F5D486E5B496D6252736C5C7774647A7A677E7D69797864726F5E76725E918874
958A7292856C988C75988D79978F7A958D799A927E968D7A9F9582A39A86A39D88A19B89
9D99889B988A9A988C99968A9C988D9D988E9A988DA5A196A4A095A5A195A6A497AAA79C
A9A69AAAA89CAEADA6B2B1ACB0B0ABB3B2AEB8B8B5BBBBB9D2D0D1E5E1E4E7E0E5DAD5D8
BFBEBEAFB1AFA0A6A4969D9D8C93938893918D9999919D9F8F9E9F8D9F9F96AAA98FA09F
92A09D949D9C96A09E989FA09CA3A29EA6A3A2AAA4979D98949996929893969D95A1A79F
A4ACA4A4ACA4A8AEA8AFB5B0BAC0BBBCC4BDC3CCC6C6CDC8CCD2CCCFD5CEC2CAC2C2C9C3
D6D8D6EFEEF1F4F2F7F5F2F8ECE7ECDAD4D3BBB1A89C8E7F9A8974A78F76A284689B7A5C
8E7153816A4E6F61495953425453486A685C888270918674958A749F937C9E90779D8F77
9E8F799E90799C90799D927B9B90799B90779E947B9C917B978C769289768E897C76766C
646961444E443A453B3E46394D4C3B6D644E8879628577636E604C59442F4E281600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C99D68
755A386C5C42695E47766A577F7462827966827C6478735E6964526864557A7866908976
938975988C76988D77978D79938B76A199869A948198927F968F7D98907F989281979382
989385999287A29B939F9A919F9B91A7A29BA4A198A39F94ACA59AA7A095A6A293A8A295
A49F92A49F92A5A094A09B92A49F95AAA29AAFA8A2B0A9A5B8B1AFC3BABBC1B8BDB6AFB5
ACABAE989A9D8A9396848F957D89907584896E808469797E6778796373745C6D6C657571
7D8A83939F989FA7A1A6ACA7B0B5B0B4B9B5B7BDB8C3C7C2CFD1CED4D7D5DEE0E0EBEEEC
EBEEEDE6EAEAE4E8EBE1E5EADADEE1CCCFD2B2B2B6A5A2A5969093888280736F6B736E6A
7B73738C8287948990978B9294868892827B8D7A698D775F8F75599070518F6E4B8E6C48
8A69438768438368457C65496E5E4660553C75684F9182699C8D75A597809F937A9E927B
9C8F789C8F79998D799B907C998E7A988E79978C77958A75958A77938D7C88867D6A6C69
4A555039483E3C4A3D414D3F474B3C54513D6D664C82765C83735A68553B5D3E2400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007D9D33
6E57306C5D3C786A4D81725A83775F7A6F5A665F496A6451696755666557787868878272
8E8674958A769C947E928B768E8971948E7A97927E999582938C7B958A7A948B7A97907D
9A918096887B9C91849E94889D9789A19E919E9B8D9D95889E96879E95889E98869C9685
9B95849994829994829992819A91819B8F81999080988E839A9087958B83938C85898484
7B7E8161696D5A676E5062694D5C6348595B4E5F5D4F5C5966706C79817C8F9791A6AEA7
BDC6BED0D7D1DBE1DFDFE4E4E5EAEAEBEDF2E9E9F1E7E7EEE2E0E8D8D3DCC7C2CBB8B3B9
ABA5AA9D979B938D928882867E76787B6F6D7D6D677C685F7E685C836C5C84705B8A7760
907F6892806D9B8879A08F80A18F7FA18F79A18E74A08F6E9E8A689B8664967E5D8F7756
8E735095754E98764D93724B8B6E48876E4879633F8C7657A5947BA3967F9E927B9E927E
A0937F9A8D799A8E7B9F97829E937E978B769487749B907F9791828C8A816A6D6B4C5654
404E484352464755454A55454D53455355466C6D587D775E84755A826E4F6A4C2D00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6025
755A3179684584755384765A6B6248504A354F4C385A594763655565675B7A7B6E888576
8A8371978C7998917B8D88728E8C759B96828D8875807A68978F7C9C8E7B9385708F816D
91836C8F7F6993836E918572938B7896917F9590809B938498917F968F7F97917E96907D
9A94809993819994819B93819B93809C95829A927F9A928099917F958E7C888778767871
5A61604551513748483445433F4D48545F5762695E83867A98978CABAAA3C2C1BBD2D0CE
DAD8DADBD9DECECAD2BDBAC2ADA9B1948C94837881776A717B6C6E7F6E6E7F6D68836F65
8C77688E7868957F6D947D68987F69997E63977959987955987852947854917A5A988666
9B8C6C99896B9E8D72A09177A2947C9D90799F947C9F957F9D947D99917D908A77807968
7A6F5C856F509B794F9F794C9D794B9978488E6F457F6443A8947AA59680A1937DA4957E
A1917E9D8D799C8D788E81688B7C628E7D65887866877C6F8C8A83686E6C4C5758475552
46544C4B584B4E5B4C50594B535A4B596253737B6B9394817D72588F7A5B7B5B3800FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0C7D551C
81643D897551887A586C61444D4A2E4A4A33484A364B4D3D55584A5B5E5374756B818073
86816F958B799C917E8C8571928E7998927F8B8572938A7691856F84755E8E7F669F8F78
8F816790806794846E998B78978D789089758D8774908776938C79908876958B78978B77
958974928873958B77988B779A917B9C927F998F7C9D9480948C79938C7B858677686E64
535953404742444E43545B4E646959979989837F6F92867791837484776C7D70667E706A
7D6F6E7C6F6F7D6F6E80726C81716B87756C8D7A6E8E7B6A957F699B8066A185659E825E
9F8461A99072A99074AA9072AC9370A98F66A284569D7C4C9E7F51836C4882765F877F6D
8D8571918872958C779A9581ABA695B1AB9B9B96889190858C8B8282847B787B7270746A
6D6C5E7261459C7A4F9F7644A37B479F7845967344876944A18A7097856E98856D947F67
927D658C775D867257816C517D6A4C796A50756A5877756B6268644B59594857544B5851
4F5A50505C50525F525662545C6759616D5F737F7393998B95927D8774578C6A4100FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310835F2B
8C6E488C785673694A5550354B4C314B4D364D4F3A4E4F3D4B4E3D5052466263597F7F75
8A877A8D84729C917F988E7C9993809D96849189759E937D958B738A7C639080669A8A71
9A8C7294846B8B7A638C7A6390806792856B968970988B7395897194876C96846999866B
99856B98856A98866B98856B99886F9D8F7A9F917D9F917D998C78988E7C8A85736D6D5C
5B5A4A6360526F6B59746F5B7B755E887D66817158826C538870548D7458977F629D856B
95836B8D7F6B948573AB9D8BC5B7A7CABCADB2A39192846B8A7A5D9A8361A289639A855F
8E81627E76627F7766867C68968971A99776A58B6098794A9C7E51816F4E69665671746B
76766B7F7E7286867A949288AEABA2BEB9B09B998F8F8E8786857D7C7C72787A6D6D6E5D
6660487C6743A68453A27A44A97F4AA37A45997342987B549C8467927B618E775A897154
877151826E4E7F6E4E7F6F537F725A7F7967707366555F584C5A554C5C544E5C53535E53
5861565961565763565B675A6570636E7A6F7480768D968BB1B0A1816F5494704400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047B110916E3D
9477518471526E684F53523E4A4D364A4E374D503D4F51414F50415153455355495D5E57
7979708683778A85759C958496907D948D7B9C94809D937EA59A858E816B95856D9C8C72
9B8D72988A70847157978167A38D73AA977CA1927395876B95866A958564948361958161
9681619881629781619781629984699A88719989729D8C769F8E799E8E78988B73766D54
7E73598274597D6E4F7F6D4C8874519B8361A48C66A28963AB8E67AF8F6AB0926DAA8F6A
968160908168A19581AFA391BCAFA1B6ABA0A19689998F7B94896E96886C938669928B6F
91927D6D7468787F7593978A736F5F796A50AB916B9B7A4C99784A96805B544F3A696D63
84867D807F738783778E887DA0998FA49D919993868E877B81796B6E6A5A62614E66624B
8576569A7F53A3814DA37B46A77F4AA07B489D7E51947E5A8976598B785E8C795E917F64
96886C9B9076948D75898573858378666B6257615A52615B526257536153535F52596656
5D685A60695E606B616772676A746A757F77737E768D948DACA99B836F5498724200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3742C987441
93775283755A7C7B695156474C52404E54424F54444F544550534555594B54594B515449
5659526F716A7E7F748685788F8C7B97907F938B779D9581A69A889D918090846E94876D
97896E9D8E769C8C728C7A609B8971998A71A5997DA2967D9C8F77988B6F998D6E9A8E6F
9C8D709D8B719D8C6F9B886A9B896D9B8A739A8A719B8B729D8E74A1917A9D8E74847356
8E7855896F468D70429C7F51B5996EB6966EB59770AD9069AD9069AC8D6CAB8D6CAD9170
AA9273A590789E8F7B9E92829E94839A938298917F9B957F99947C9490798F8C76949581
A5A8989EA3979DA29698978B746B5A847054AD9269AE8C5E987442A2845A78684C5D5647
736E60786C5A8776608D7F68968E79B2AB99A29E8E8C8779837D707771637E7B68857C62
8E7A569B7E509D7D499B79479C7D4FA88E66AE9C7DA89B81A69A84ABA08DAFA696AEA798
A29E8E9391838384786D71686067625C65605D69625C695F5E6B5C5F6A5A5E695A5F6D5D
626F61646F6468746B6A776D717C7376817979847E8E928B9A93848E76569F753C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB8169D7844
917753857C657F817462695C545A4D515749535C4B50584752594A555C4E565E4E555B4D
545A4E5A5E57686C648788819293889491838C87769B95829F9786A9A292A8A38F9D967F
988D77988D799F9581A99F8B9E937E988F7BA39B87ACA593ADA593A39A88A7A18CA69F8A
A49E89A39A86A29682A1947E9E927A9B907C9B917C9D937A9B93799F957E998E76857254
8B6F4891703FA3824EBB9D6DAF956BAB8F68B2926CAC8C66A88962A48866A088689E8568
A186699E866F8C80708F8A7E88887BA6A897A1A191A9A998BEBEADC1C1B1C0C0B0B5B3A4
A09D8E91918280807079725E8D7A609C825EAA8C5FAC89589F7944A581519F845F89775D
968771A59178AC9378B5A289D7CBBCFDF8F3DFDDDA928F8A7169606A6051746951897858
947B54967C519B8255A68F68B6A586B4A891B2A998AFA89AAFA99EA8A59D98989194958E
86898071766C646B5F626960636964636B64626C64616A61656E626971656B7569657368
63716768766D6E7B746E7A75727E797B857F878D8795928A897B6795774D7C9A2900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051B9169B7741
8D7853827B657E7F746E7369596055585E51555C4D51594A565F50555E4F535B4D595F52
585F52585F535A615963656074756F8D8D859595899493859A97879B98899895859C9586
A39C8CA59F91A8A393AAA494A09A88A9A291A6A090A49D8F9E97879D94869992829A9382
989180A1988A9990829C93839B947F99907F98917E97917B97927C99917E9E9683AFA08A
A68F6FA1835AB4986DAB916AA68F69A58D67A98B66BB9670B7926B9F8362978265937D63
9F8368A58A727368597E7C74868882A9ADA4B5B9AFAEB0A7BBBBB4B5B5AFAFADA79B978D
817B6E7671607B745D827356967D59A4875DA78859A78552A47D49A47F4DA384589A825C
947F5E9B8264AB8F72A68E79A9968DB6A9A99A908E897E738877658B785E927E5F9F8868
A89272AD9B7BBAAE92B6AC96ACA697ADA89DABA99EA2A199A6A6A18B8C887C807C6F736F
676C65666D636A73666A7167686E676E756E6C766E6C766E6D766E6E766E6D787068776F
6879716A7A746F7D79717C7A7B8482858A858D8D858A7F718E76599C763F2ADD0C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BF1A9E7840
A18C67877F6A7E807270766A626A605F665B5A6156575D53596256505A4D555F515C6357
5A62555A65565B67595E635A63645E66676273756E898B82A19F97ABA89FA9A59CA39E94
979388919084918E81969284989584A09B8DA39F8FA39D8EA9A393ADA596A7A190A6A08F
B1AA99B0A69BABA195A89E90A59D8AA39B8A9D9886A29E8C9B96849A93829891809F9685
94826C8D7254967B579E845FA28B66A08965A78B68C19A77BE9776967D618F7E65937C67
9B7E67B0917A9A86768C817AC2BEBBD2D1D1C6C7C4C8C7C5C5C0C0BBB3B4AFA5A392887D
8A7F6A88785D917B599C8057A18256B19469B3986EAA8E62A68659A28356A3885BA48D62
A089639B82619C83649B856A9785719786779A89769B896F9A846AA59277B5A38AB8A993
BEB19EB1A999B0AC9EABA9A0A3A39D9C9C9794958E888C84767B7570736D70746E6D726C
6F766D6F776C767E737980767F857D79827A737F786F7D756D7B74717D766F7D76677A73
6C7F7A72817D7984807F8683888A868A8A81857D7085735B98774B56BF2000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A1773B
9C845E9187707A7C6C73796B697267646E655C655A5F655D5A6357545F535761555D655A
5D685A606C5B636D5D676D626568606668626669636669646E6E697D7B788C8A869E9D96
A3A39BA2A197A5A397A19E91A19E909E9A8D9894889994869B96869A95859F9A899F9B8B
A6A090ADA598ADA498ADA499B2AB9DAEA99CAFAD9FB9B7A9B7B2A5B4ACA0BAB3A5B1A999
A699849681648F7853957D549781589C865FA08663B08F6FAE90728F7B628A7A628E7A65
947B649A7E679D8571978679C0B5AEBBB3B0A09893958B858E807A8C7A718B7667907B63
927C5C96805A987C539B7F53A0875DAA946FA89574A99677AB9677AE9A79B0A07CAD9E7C
AB9D7EB1A386AEA086AFA289B0A58CB9AB94B3A48CB4A58BA89A82B1A593B2A99BB6AEA4
ADA79EABA79FA3A29C9899958A908A7E847F7E837F787D78747B73797F777B7F777B8077
7A8176838B7F878E84898E87868C8478827B737F7A76847F71807B71807A75857D71837C
6F817D7787837F89858589838989808B857785745D94764E7F9E3300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA1A
947647AA9C807C786571736570796B6C766B636F65636E655E6A5F5E6A5F5B665C5F6860
626C60656F626870646C7369686E64676A62676D63686F66686D64696B64696B646E7169
797A7489888298958E9E9B929F9E93A7A39BABA69EA4A1979D9D8DA0A08E9E9D8A989584
9994849D95889D96899B9589979385908D7F9390829690839C9486988D819A90829A9180
989078968C6F998C6A9C8C6695835C98855F9884609781619A866893836884765C8A775E
917C61957D6297836897866D9E8E7A9E8F7DA2927EA79680A89780AA977FB19B82B7A384
B8A582BCAB89C2B190BEAF8FBEB092C3B99EB7AD97B2A994B4AA96B8AF9BB8B09DB6B09C
B4AD9AB8B1A1B3AB9CB2AB9BAEA593BDAF9FBAAA9AB9AB9AB8AA9DB5ACA2ACA69EA6A19C
9E9A9693908B8A8A86878984858A8480857F82858381848283888281877E80857C868B83
848B818E968C8C938D858B88828B8876827E74807B7884817884817C87827D89827A8882
7E8B8884908B8890898B8D85807A6D87775F96754E79982D00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9F75389A7F5B8C7F686F6D5C727668787D72717B736A756D626E66646F66616D64626E65
6672686772676973696E766E6D766C6E736A6E74676F776A6E7669696F636D70646D7065
6C70676F716B76777175766F7C7D75817E79938F8B999892999C91A0A297A5A69AA8A699
A9A799A9A499A9A498A7A296A7A396AAA697AAA797AAA595A59D8DACA292A79D8CA39C88
A7A289A5A086ABA58BAEA58EB2A68DB0A389B6AA8EB9AB91BDB095BCB397BCB598BBAF93
C3B698CBBCA0C7BB9FCBBFA4D4C8AFD8CCB5D8CDB5D9CEB4D7CCB3CDC1AAC5B8A1C6BAA3
C4BAA3C7BEA9C3BBA7C3BEAAC4C1ACBFBCA9B9B6A6BCB9A9BBB8A9BFBCB0B9B7ADB8B7AB
B6B5A9BBB8AEBCB6AEB9B1A7C3B6AAC8B6AABFACA3B7A59DA699929F96909A948F938F8A
98959195959192938E8F918C8D918B9295909192908F918F8F948E8A9089888E87898F88
888F8889938D86908E828D8D808D8B7A89857C8B857F8D86828D89858D8989908B87918C
8B93908D928F94958E8C857788745B95714786A33700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2CDF0F99713A987F5B887D687B79697E7F747E847D777F7B707B756C767063716966736C
63716868736B69766C6F7A726F7A706D7568707768787F72787F71767C70777B6D74786A
72786D72766F70766E75766F73756D74756F7979747577727C817B83878291938F91928C
9FA097A5A6A0ABABA5B1AFAAB3B1A9B8B8AFB5B7ADB6B7ADB7B7ACBAB7ABB5B1A3A5A190
B6B3A2B4B2A0B5B2A3B6B1A5B7B2A5BBB6A5C2BDABC3BDABC3BFACCAC6B2CAC6B0CCC8B2
D2CFB9D9D2BFE1DBC9E1DCCBE4DFCFE3DECFEAE5D6E8E3D5E4E1D1E1DECFDAD5C7D7D2C4
D5D2C4D8D6CAD1CFC3CACABCCDCEBFCCCEC0C8C8BDCACBC1C5C7BEC2C4BEBFC1BCBCBDB8
BBBDB6B3B4AEB3B1ABB2ABA2B8ABA2B8A89EAF9F97A69993A49B95A29C979C97929B9792
A3A39D9C9E98969A959DA09D9B9F9B939795969997959A978A928C8E97918E98918E9690
88918B87928D86949182918F82918F83948F84948D7F8F8784908B8C958E8D948D929790
93959094918A8E82728E7756A1794729DD1000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDF0F9B753B957C579A8D77908E8085898080878279837E75807B6C79726B7770
6B776E6D77726D7871707B74707D73737F71737B6C7D8377787E727E8176808378818478
84887E7C817A72786E73776F72796F7579727478717279726F7771737A76747876787975
7B7D797B7F7E7D8183828787888D8B8D94939BA2A1A6ACACAEB4B2B0B5B0B7BAB3B3B6AD
B4B6ADB5B9AFC0C1BBB9BAB3B8BAAFC0C2B4C3C6B8CDCFC2C8CBBED3D5C6D2D5C5D9DACC
DFE0D4E2E0D7EDECE3F4F2EBF8F6EFFAFAF3FAF9F4FBFAF5F6F6F0F0F1E9EDEDE6E8E9E2
E5E6DFE3E5DFE1E3DDE3E6DFDDE2D9D5DCD4CAD2CCC6CDCAC1C9C6C7CECDBCC1C2C2C6C6
B0B3B2B8B9B7BABAB5BCBAB2C3BCB3BCB3ACB7AFA9B9B6AEB7B4AFB5B3AEB1B0AAA9A9A3
AFB1ABA5A7A4A3A7A6A0A6A59FA6A59BA0A0979C9B99A09D939D99929D99939D9B919B99
8A94928894908C98948B99958B99948F9C98909C988A989386918D929792979A9396968F
958C808B796192734982A33700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE2107294289A7F57A498819898898B8F85888E87848D877C878078847C
77837A707975737D7979868076847B79857B717C707A81787F847C7E847C81877F878E85
8C91898E938D797E76767B74787E76747B73737D737682787580787C868178817E7E827F
7B817E767F7E7680817B85887783857C87898491928591938793948E999A95A29E98A3A0
9EA8A4ABB4B0ADB4B1B1BAB7BBC4BBCCD4C9CFD8CFD0D9D2D8E2D8DEE6DCEAF0E7F2F4EF
F7F9F4FCFCF9FEFEFCFEFEFDFEFEFCFEFEFEFEFEFEFEFEFEFEFEFDFEFEFDFEFEFCFEFEFC
FDFFFDF5F7F6F0F1F0EAEDEBDEE3E1D9E2DFD7E3E0D4DFDED8E2E2D2DCDEC4CDCFCDD4D5
CACECDC6C9C8D2D4D1D2D2CDCDCBC5CAC8C3CAC9C4C3C5C0C4C8C3BEC2BDB8BCB9B4B8B5
B4B7B5AAAEACA6ACABA6AFAF9CA6A59BA4A3A0A7A69CA4A2959F9D939E9E949F9F95A09F
8E9A998E9A97929E99929C99939E9B929C99919A978D948E8E938D97958E978F838F7C67
9476527A9C362DE11300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0050BC1E9B7C4DA59377A0988792908691948C8A938A848E86
838F85818B857E89867C8B867A8982808C8577817A7C837F7E85827F8883818B8587918A
89928A8C928C898F8885898380857F7A817A818C837D88808A958E929C98828C89878D8B
7A83817A83837C86877B86898693948B999A8B99998795968797968D9B9C91A09F99A5A6
9FAAA9A8B1B1B0BAB9B5C1BFC0CEC8C5D0CDCAD4D1D7E1DFE1EAE7E3EBE8EBF0EFFBFDFC
FDFEFDFEFEFEFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFEFEFDFDFEFDFDFEFDFDFDFDFEFEFD
FEFEFEFCFDFDFBFBFCF5F8F8EAEFF0E3EAEAE3ECEBDCE6E5E4EEEEDCE4E5D0D9DAD7E1E1
D2DAD9CFD6D5D6DBDBD8DADAC7C8C6CDCECBD1D2D1C9CDCBC1C6C4C0C6C5BAC2C1B5BCBC
B4BABAAAB2B1A1ABAAA5AFAE9FA9A7A2ACAA9FA9A79FA9A89FAAAA96A1A299A5A598A4A3
9AA5A395A09D99A19F979D9C9097959095928B8C868C877C8A816E88765B92744D7C9D38
2EE21400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002EE213799C359B7D55A6947AA299889A988B909488
8B958A8B948D727D757E8B8488948E87928E828E8A828B897D8786848E8B89948E8B9691
88938E8E98938C95908D938E939994949A95939C968D9794939E9B9CA5A49099989EA6A3
98A19F7D88877D898A8490908F9C9A919D9C939F9D94A1A094A1A098A5A49AA5A5A8B0B1
B0B8B7B7BEC0C6CFD0BECBCAC6D3D2D0DAD9D7DFDFDBE2E4E3E9E9E7ECECF3F7F8FCFDFF
FEFEFEFEFEFEFDFDFDFDFDFEFDFDFEFEFEFEFDFDFDFDFDFDFDFEFDFDFDFDFDFDFEFDFDFE
FEFEFEFEFEFEFAFBFAF2F4F4EFF4F4E8EEEEEEF4F4E2E8E8E1E7E7E0E5E6DAE0E2D6DDDF
DBE2E3D8DFE0D9DDDFDDE0E1D7DAD8D2D5D3D5D7D7CFD2D1BFC3C2C2C6C7B9C0C1B6BDBE
B8BFC0B2B9B9AEB5B5ACB5B4A8B1B0A9B1AFA6AFAEA3ADADA5AFB09BA6A7A0ABAB9CA6A5
9FA6A59A9E9E939395918F8E89867F8C847886776189724F95764452BF2500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DE113799A3498774F9C886A9E957F
9B9A8A98998D878B808A92888F98918F9793909A988F9A9888949189939286918C919B99
8F9B988F9B9A909B9A8C9695949C9A9AA29F98A19F9AA3A39EA8A7A0A9A98F9A9A949D9C
A1ABA787948F82928D8E9D9997A7A2A6B1AFA3AEABB4BEBDB7C3BFB6C0BFB5BEBEC5CDCC
B5BCBCC2C7CAD1D8DAD4DBDED8E1E3D9E1E0DBE1E1E5E9ECE4E9EAECF0F1ECF0F1FAFBFD
FFFFFEFDFDFDFEFEFEFDFDFEFDFDFEFDFDFDFDFDFEFDFDFEFDFDFEFDFDFEFDFDFEFDFDFE
FEFEFEFCFCFCF0F0F1F3F4F5F1F3F5EAEFEFE9EEEEE8EEEEE3EAEAEAEFF0DDE2E4DCE3E5
E4E9EBDEE2E4DCE0E2D5DADAD9DEDECCD1D1CACFCFC9CECFC4C9C8C5C9CBC0C5C7B4BBBB
B5BBBCBABFC0B5BABAB3B9B8B0B5B6AAAFB1AAAFB0A9B1B2A9B2B39EA7A89EA6A79A9FA1
9797978F8A858C7F788D79698D73589A78507C9F392CE11300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050BC239E7B4C
947C589D8B71A094809B95869C9A909A9B96999D9A929995949C99969E9E949C9B919A9A
949F9D97A4A3899797808B8C949F9E96A1A19BA6A4A0ABABA5AFAE9FA9A97B87867D8889
A1ADAAA2AFAA92A19A929F9B9DAAA6ABB6B4B9C2C3C5CFD0C8D3D2C5CECECFD7D8D7DFE0
CAD1D1D7DBDEDEE3E5D4D8DCD4DADDDEE4E4E1E7E7E7EBEEE8ECEDE7E9EBF1F3F3F7F7F9
FCFCFCFFFFFFFEFEFEFDFDFDFDFDFDFEFEFEFDFEFEFDFEFEFEFEFEFDFDFEFDFDFDFDFDFD
FEFEFEFAFAFAF7F7F8F3F3F5F2F5F6EBEFEFEDF2F3E6ECECEAF0F0E9EEEFE0E7E8DBE1E3
E6EBEDDBDEE1DDE2E3D5DDDCD1D8D7CED7D4C9D1D0C8CECFC6CCCEC4C8CBC3C9C9BBC0C0
BCC1C1BCC1C3B8BDBFB8BEBDB0B5B6AFB3B6AAAEB1A3A8AB9EA1A4A0A0A19A97938F877F
8B78698F73589D79534CB9255CC52900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB921A17C4D9A7C5B9D866DA1927FA2998B9E988F9A98929897969B9D9B9CA2A0
9BA2A0A1A9A88D9896818B8B9CA7A69DA8A7A4AFADA4AFB0A6B0AF9FAAA7838F8A7F8B89
A2AEACB3BEBCB2BEBBAEBAB7B7C2C2BDC6C7BDC6C9C3CCCFC7D1D3C8CFD2CFD7D9DBE3E5
D8DFE1D4D9DCE1E7E7DDE3E4DCE3E4E3E8EBEBF1F1EAEEF0F3F6F7F1F2F4FAFBFBFDFDFE
FDFDFDFEFEFEFEFEFEFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFDFEFDFDFDFDFDFDFDFDFDFD
FFFFFFFCFCFCFCFCFCFAFAFBF3F6F6F3F5F6F6F8FAEAEEF0EEF2F4E9EEEFE1E7E8E1E7E9
E1E5E7DDE2E4D5DBDCD4D9DAD0D6D5D3DBD8CED3D2CDD2D3C9CED0C3C9CAC6CCCBBFC4C3
BDC1C3B9BDC0B3B7BBB3B7B8B3B6B6AEADABA4A09D9C959091857A8E7A67967A5CA38054
52BF282FE31600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0062C92C51BB24A47D4D9A7953997E61A08B76A29184A1958AA49D95
A29E98AAA6A4A8A6A2A7A8A5A8ACA8A6AAA8A8AEADABB2B2A9B1B0AAB3AEA4AFA8A9B3AE
B0BAB7B2BABCB5C0C1B3BDBFC0CACBBDC5C8BCC6C8C1C9CDC7D0D2CBD0D4C9D2D4D6DFE1
D1DADCD5DCDEDBE4E3DFE7E6DDE6E4E7EDF0E8EEEEEFF3F4F4F6F6F7F7F7FEFEFEFDFCFC
FEFEFEFEFEFEFEFEFEFDFDFCFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFEFDFDFDFDFCFDFDFC
FDFDFDFEFEFEFEFEFFFCFDFCF7F9F8F8F9FAF4F5F7EFF0F3EAEEF0E7EBECE3E8EAE3E7EA
DFE3E5DCE1E2DBDFE1DCE0E1D8DDDCD2D7D6CDD2D0CDD1D1CCD0D2BFC4C5BDC2C5BCBFC2
B1B3B4B0AEAFADA5A4A79C959E8F7E99836A9B7F61A47F584EBC2A5DC73034E71900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC42982A23DA881559C7A559A7C5E
9F886EA5907CAE9C8BB1A397B1A89FB3ACA8B5B1AFB3B2B0B3B2AFBCBBB8B7B9B4B5B7B2
BBBDBBB8BCBDBDC3C5BABFC3B7BEC1BBC1C5BFC6C8BFC6C8C3CACBC9CDD0CBD4D5D0DADA
D0DADAD5DBDEDAE0E0E3ECEBE0EAE9E7ECEDE9EEEEEFF2F3F5F7F6F6F6F5FCFCFCFEFDFE
FFFFFFFDFDFDFDFDFDFEFDFCFEFDFDFDFDFDFEFDFDFEFDFDFEFEFEFEFDFEFFFEFDFEFEFD
FEFEFEFEFEFFFEFEFFFEFEFEFBFCFCF7F8F8F8F8FAF2F3F5EFF1F3E9EDEDE7EAECE4E8EC
E2E5E9DEE1E4D8DADED9DBDED2D6D8CDD1D3CACBCBC3C0BFBAB7B3ABA69FA0958DA19185
9A8673998067A07E5E7CA04354C12C63CC3235E71900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE315
57C1274EBB24A98151A27E59A18262A58A71AC9682B29F8EB8A598BEADA1C3B5AAC7B9B3
CABDBCC7C0BFC4BEBFC1BCBFBDBBBDC1BFC2C7C7C7C5C6C4C9CBC9D0D3D3D1D7D6D0D6D5
DAE1DFDBDFE0DFE3E4E6EDECE5EDEBEBEEEFF2F4F3F7F7F8F9FAFAFBFBFBFDFDFCFDFDFD
FEFFFDFEFEFEFDFDFDFEFCFDFEFDFDFDFDFDFEFDFDFEFEFEFDFEFDFFFFFEFEFEFDFDFEFD
FDFEFEFCFCFDFDFDFEFDFDFEFCFCFEF6F6F9F7F8FBF2F3F7EDECF0EBE9EDE8E6E9DFDBE0
DAD7DAD2CDCFCAC3C2C0B6B1B9AEA4B0A195AD998AA28B74A28666AB8A6282A54757C22F
61CB3468D03400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005DC52B54BE28BA8D5A7E9F3FAA8158AB8563B59075
B59380B49686BBA193C4AB9FC9B3A9CEBBB3D0C3BAD7CCC3D8D0C8D8D2CEDDD8D6DCD7D5
E1DFDEE7E6E9E6E7EAE9EAEDE7E8EBE6E6EAEEEDF1F9F8FBFEFDFFFFFEFFFEFDFEFEFDFF
FDFEFFFFFDFFFEFEFFFFFDFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFCF9FB
FCF8FAFBF6F7F7F1F2F4EDEEEEE5E5E4D9D7DBD0CCD0C2BDCDBBB5C4B0A7BAA497B39A8A
AF947FAC8F76AD8D6FB38E68BB916259C63262CC3768D1376BD23300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0037E81A6CD036
66CC345FC63159C22E55BF2D55C03052C03280A84DB3916CAE8E6DAF9075B2967FB79D87
B9A290BBA698B8A799BCAA9FC8B6ACC6B4ACD0C0B8D3C2BBD8C8C0D6C6C0D5C6C1D8CBC7
D8CAC8D6C7C4DBCBC6DAC9C4DBCAC4E0CEC8DECBC6D8C6C1D5C2BDCFB9B5C9B2AAC1AA9E
BBA393C0A492BB9E88B99B83BB9B80BC9979BF9973C0986D5BC8375DC93663CD3967D038
6CD3396CD23637E91B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0106283 0.488926 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0106283 0.732558 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE1152FE11600FF005DC32B
5CC42D5DC52F5AC42E88A645B8895CB8885C5BC533AF875FAF895FB08C60AD895EAF8960
B0885E59C533B18860B0875EB1885F58C43359C4335AC53400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002EE1165DC22C5CC52FBA8A5DBA8C60BA8B62BD8C65BC8F68
BC926DBC9472B89472B89676B9987CBB9A82BB9E8B988579887D73A194829889758F7E6E
A99686BDAA98BDAB9ABEAD9CC2AF9BC3AD99C6AD9AC4A9976ADD5767DC5466DB5361D64E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32C
5BC430B6885E89A84AB98F65BA9068BD9773C29F7EC6A488CEAD95D5B29BCDA991CBAA91
CDAF99C5AC9AC5B19EE0CFC1D1C6C2A8A0A1CCC4C75554632C364F76808DC7C9CCAFB3BA
9CA6B4B9C6D5BAC9D5778994CCD6D8D9D7D3D9D3CEDBD4CFDBD4CFD9D2CCD6CEC8D5CDC8
D7CEC7D1C9BDD1C5B8CFC2B49ACF8769E35F68E05B67DD5863D8525DD14957C83F51C136
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32D88A5445DC734BA9168BE9977
BF9B7FC8A68CD2B298C8A992C4AA93E3CFBBE7D5C8DAC6BBDBC7BBDCC9BBCBB6A7C8B3A5
E1D2C7E3D9D2D3CAC4D9D1CCB8B4BA676673B8B4BAC6C2CBABB2C6A6B4CCC8D7E8AABCD2
223D661B3C696683A75069858D9FB3CCD5DCD3D5D5D5D6D5D3D2D4D1D3D4D0D2D2D0D2D1
CFCFD0CECDCBCFCDCBCECDCACDCAC9CDC9C7CEC9C5CEC6C4CEC7C3CAC2BCC6BBB4C4B6AB
BCAB9DB3A08EB29B8A86B36758CB4150C13500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002FE1155DC52D5DC52FBA8C62BF936DC19976C7A386C6A68DE5CBB6EAD7C5
D1BCABCBB3A3E5D3C6E7D6CCD1C1B6DFD2C9E1D5CDD1C4BCC6B6ADDDCFC6E4D9D4D7CBC6
D8CEC9DFD7D3B9B1AEC7BFB9D9CFD0DED8DDCCCACEDCDADFC0C6DA364A714A6388A1B2CC
4E6082354E766F88A7C1D2E7A5B6CBB3C5D5CED7DDD4D8DBD4D5D9D3D4D6CED2D5CFD3D5
D1D2D6CFD0D3CFD0D3CBCECECDD0D0CBCECDCDCECDCACBCCCBCACEC8C9CAC7C6C5C5C3C0
C4C1BDC4BEB9C3BCB8D2CBC6D3C9C1CDBFB6C1AEA2AE968454C43D28DE1900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE116
5DC42E8CA747BC8F64C59870CBA17DCEA68ACEAB94E2C7B4EFD9CBCFB8ACD1BCAFD7C6BC
DCCCC2D2C2B9E7DAD1E1D6D0D8CBC1D0C2B7D9CEC5E3D9D1DBD0C9DED3D0E3DADADED4D3
CCBFBBD4CAC6DFD9D6D7D3CFDBD6D3E0DFE1A9ADB7ACADB8BDB9C87276936D7996BCC8D9
C7D6E7A6BCD46F8DA8A3BFD76B85A14B6B87C3D6E2D0D9DDD6D8DBD4D7DAD0D4D5D0D5D6
D3D5D9D1D4D5D1D2D6CACED1C9CED0CBD0D2CBCFD1C8CBCECACBCFC7C8CBC6C7C9C5C6C8
C4C4C7C7C8C9CBCCCDCACBCCCCCCCDD0CECED0CECDD2CACAD0C2BDC1ACA583AF6829E11E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42E8DAB4BC0926B
C69976CCA284D2AB8FD5B295D9B7A0E2C1AFD3B6A7D8C1B2DCC9BBD4BFB1D1BDB0DFD0C7
EDE1D9E0D2CAD6C7BEDBCBC4DFD3CBDACEC5DFD5CEE7E1DCE8E1DED4C9C8DDD3D2E0D7D6
DCD2D2DBD1CFE4E0DDDCDBD9CDC8C6D2CDCCAAA7B0ADA8B2D1CBCDDAD9E2B3BFD38195AE
ADC4DB4B6580183B642B4E739AB0C9657B94AABECFCEDBE0D3D9DCD1D6D7D1D3D5D0D4D5
D1D5D8CFD4D7D2D6D9CDD1D4CCD0D3CBCED3CBCED3CACFD2C8CCD1C9CBD0C6C6CBC8C7CC
C5C4C9C2C4C6CBCCD0CFD0D2CED0D4CDD0D3CBCDD0CBCED0CECDCECEC9CBCDC4C3C8B9B6
AC979048BE3A24DD1900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC22C5DC52FBA8C5FBB9266C19B77CBA588D3AE93
D3B098D3B29DD7B6A1D9B9A1D9BBA6E2C6B4DAC0ADDAC1ADDAC5B5EAD9CBDFCDC0DCCCBE
E0D2C7DDD0C7DACBC1DFD1CAEAE0DCE9E0DCDACFCCDED6D2DFD7D4DCD2D0DED4D3E9DFDF
E9DFE2D9CECEDBD3D1D0CBC8CDC7C4D3CBC8E7E2E2DEDBDFC9C9CCD4D4DC717C9720375E
6C819DA0AFC46E7F9B6C829DC4D5E7C5D8EA87A0B6B8CFDBD1DADDD5D9DCD5D6DAD4D8DB
D3D6DBD2D6D9D3D7DAD1D5D8D1D2D6D0D1D5CFD0D4CBCFD2CACFD2CBCED3CBCCD1CAC9CE
C2C3C7C1C5C8C7CBCECED3D4D1D5D8CDD2D5CACED1C8CCCFC9CFD2C5CACFC9CBD0CCCBCF
CAC6CCA6A2A9938B8B78675A5883301BD30B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF005AC42EB98A5FBE8F67C39A72C9A07DCDA889D0AE94D4B59DD0B39D
D2B6A1D5B9A4DABAA5D9B9A4D6B9A4D8BEA8DCC3ADDCC6B1DFCCBBE6D7C9DECFC1DECDBE
DDCFC3E9E0D7E8DED6E2D7D2E7DDDAE6DDDBE2D9D5E2DAD6E9E2DFE9E3E2E3DAD8E2D6D7
E4D8D9DDD2CFDBD0CCE8E1DEE7E3DFDBD7D3E0DBD9CED0D579808BB5B7BEB7BAC68692A8
9FADC0CBD9E5D0DEEB9BB0C75B789992AFCE28486A6989A3CCDBE6D4D8DDD6D7DCD2D6DA
D1D7DAD2D6D9D3D5D9D4D5D8D1D4D8CFD2D7CED1D6CDD1D5CCD0D2CECFD3CDCDD0CBCCCF
C9CBCFC7CCCFC9D0D3CED5D6D0D4D8CED3D7CDD0D5C9CDD2C5CBD0C6CED1C7CCD0C9CBD0
CCCBD58081933B425B3942526363637467533CAF2100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
88A44489A749B88E64BC956AC59D77CAA483CCAB8BCFAF94D2B39ACDB199CFB59ECFB5A0
D4B9A4D5BAA5DABDA8DCBEA9D9BEA9DBC3AEE4CFBCE0CDBCE0CDBEDECCBFE0D1C4E5D5C8
E7D9CDEDE2DAEAE0DCE6DAD6E3D9D4EBE3E2E8E3E2E1DBD8E7E0DDE8E1DEE0D7D5DCD2CF
E7DFDDE9E3E0E0D9D6E5DFDCE6E4E0CFCECACFCBC8D8D4D5C2C1C8C6C5C9D9D9DACBD5E0
7189A0668199ACC0D3566D8A11346454759A95AEC87490A7C5D9E7D2DAE2D4D7DCD3D7DB
D2D7DAD0D4D7D1D3D6D3D4D8CED2D5D0D4D7D0D4D7CED2D5CDD1D4CED0D3CDCED0CBCED2
CBCFD2C9CFD2CAD2D5CDD2D5D2D3D8CFD2D9D1D3D8CCCFD4CACFD3C1C8CBC7CACFC8CACF
CACCD1B7BAC6575D71838EA36F7A89878C8FA2989066944600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42F8AA84A
BB8E6ABF9773C29E7BC6A382CDAA8DD1AF94CDAF96CBAF97CAAF96CDB399D4BAA2D1B7A2
D4B9A6D9BEA8DEC4AFE1C7B5DFC8B6DBC6B4E1CDBAE4D2C0E6D4C4E6D5C7EEDFD5EDE0D6
EADDD2ECE0D8EBE1DBE9E0DCE6DDD8EDE6E2EBE6E2E4DCD8DFD5D0E2DBD6E8E4E1DFDBD9
E2DEDDE6E3E1E0DAD7D9D2CCD9D6D2DAD9D9D9D4D3E2DBD9E2DEE0CFCED2C3C2C4B2B6C3
304668223D637D91A8B7C2D67489A88CA7C3CAE0F494AEC57091AAC7DAE8D2D7DFD2D5DA
D2D7DAD0D4D7D1D5D8CFD3D6CED2D5D2D3D8D1D3D8CED1D7CACFD3CCD0D3CCD0D3CBCFD2
CACED1C9CED1CBD0D4C9CFD3CED1D6CED3D7CDD2D8CED3D9CAD0D6C5CACECACDD2CACED2
CACFD3C7CCD1AEB6C28E9CAD90A1B297A7B6A1A9B1ABA5A26E9C521CD20C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0059C22D86A646B58C61BA926BBE9774
C29C7EC49F82C6A386CAAB8DCDAF95CDAF98CFB29DCEB19BCFB29BD1B79ED9C1A6D6BFA8
D8C0ACDCC4B0E1C9B7E2CABAE4CDBDE1CAB9E4D0BCE6D5C0E3D6C4ECDDD0ECDCD4EDDCD4
EBDCD2EBDED6ECE3DCEEE8E2E9E0D9E6DAD3E1D8D0E3D9D4DDD4CEE4DDD7E8E4E0E4E0DD
D6D0CCDBD6D1E0DCD7D9D5D0E0DCDAE8E5E5E3DDDCD7CCCBD7CED093949B9B9CA1D0CED2
B1B6C6A2ACC1B0BBCCD0D9E4ACBED34060857191B26A85A425466CA2BBD1CED7E0D0D4D8
D0D5D8D1D6D9D0D5D8CED3D6CFD3D6D0D1D6CED2D7CBD3D6CAD1D4CBCFD2CCD0D5CCD0D3
CBCFD2CACED1CCD0D4CDD1D6CCD1D5D0D5D9CED3D7CDD2D6CED3D7CFD4D8CACFD3C8CDD1
C8CDD1CBCFD5999FAD293A513E5570364A654153677E8891958C8B8F74651ED41000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002DE117B3885EB88E68B8916CBD9876BF9A7AC29F84
C5A289C7A58CC9AB91CAAD93CFB39BCEB39DCEB49DD0B7A0D1B9A3D2BBA5D8C2AAD9C5AE
DCC7B4DAC6B2DFCBB8E1CBB9E2CCBAE4CFBCE7D3C0EAD7C5E8D9C6EBDBCCE9D7CCE9D7CD
EFDFD6EADBD1E7D9CEE7D9CFE3D5CCE2D4CBE7DCD6EBE3E1E7DEDBDAD0CBDFD7D1DED9D2
DAD3CDDCD7D2E8E5E3E7E2E2DAD1CFE0D7D4D5CCCBCFC4C3D4C9C7DAD5D7D4D0D3CCC8C7
DCDDE2BCC6D3697D948196AA7F92AC1C3B6737587FC0D2E88C9EB49CB3C5C5D8E1CCD6D8
D3D8DBD3D6DBCFD3D6D1D5D8CED2D3CED2D5CED2D6C9D1D3CCD1D5CDD1D4CDD1D4CBD0D4
CBCFD2CACECFCDCFD3CBCFD2CACFD2CED3D7CCCFD6CCCFD5CBD0D4CED1D8C9CDD5CBCCD5
CBCED6C9CCD3BCBECA5F697D7B8BA1576A7E8191A488949FA6AAAFBCB4B2A98E851ED511
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0058C12C57C12CB1885FB9926DB99574BD9B7DC1A183C1A386C5A88D
C7A78EC9A991CEB29BD0B7A0D0B9A2D1B9A5D1BAA7D6BFACD6C0ADDAC5B3E0CBB9DEC9B6
E1CCB9E2CDBCE2CDBBE0CDB6E0CBB5E2CDB9E7D2BFE9D7C4E7D6C4E8D7C6EBD8C9E8D5C7
ECDACDE9D7CAE8D6C7E6D6C8EBDED4EADDD4E7DDD4EADFDBE1D7D2DCD0C8DED3CCE8E3DC
E7E4DEDAD3CEE3DBD7E3D7D6DECDCCDACDC9E9E0DDE6DEDBD2CAC6E1D9D7D8D5D7AFADB0
C6C3C89FA2AF44516E5E6D86D2D6E6A2AAC18998B4B8C9DCB8CCDE496A8390B1C6C8D9DE
D0D6DACFD4D8D0D4D7D1D5D8CFD4D4CED2D5CED3D6CDD2D5CBD1D5CBD0D3CDD1D2CBCFD2
CDCFD4CACECFCFD0D4CDCED2CBCED1CBD0D3CDD0D6CBCED5CACFD3CACFD5C8CCD5CACBD5
C7CAD2BFC2C7CBCCD3ACB3BF8996A793A6B68494A68797A29DA5ACAAACAFC1B7B89A7F75
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0083A243B2885FB68E65B69067B99570BB9878BB997CBD9D82C0A28BC0A48DC4A68E
C9A992CFB199CFB49FD4BCA9D5C0ADD5BEADD6BDADDAC4B2DBC7B3DDCAB8DDCBBADDCAB7
E0CAB7E1C8B8E0C8B8E1CAB6E3CDB7E1CBB8E6D1C0E4D0C0E5D2C0E8D5C3EBD9C8EAD7C8
EAD7C9ECD9CAEAD8C8E7D6C7EBDDD2E8D9CFE6D7CDE1D3CBE9DFDAE7DCD8DDD1CBE5DDD8
E3DED7D6CDC6D6CBC5E5DBD6EBE0DEDBD0CDE9E0DCE7DFDDCFC6C4CCC3C2C5C6CE92939F
C9BAC3EDD7DFDCC7D5D9C2CFD9BDC6DEC6D4675F7C2E3E618198B53551724C6D8CC6DAE5
CED6D9D2D7DACED3D6CED4D7CCD3D6CCD2D5CFD4D7CDD4D6CCD1D4CBD0D4CBCFD2CBCFD0
CCD0D3CACFD2CDCFD3CCCDD1CDD1D4CBCFD2CCCFD4C8CBD0CBCFD3C5CBD1C6CBD1C8CBD2
CACBD3C2C5CCCCCBD39D9FAD2D37504C607B2B415A536779808F9B878F969C9A9FA19492
668E4500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C12C
86A749B68D68B8936EBB9672BF9C78BE9A7ABD9C80BD9E84BFA288C0A58DC3A791CEAF9B
D1B39ED1B5A1D0B5A4D7BCAED9C1B3D6BFB0D7C1B0DCC7B5DBC7B6D8C5B4D3C1ADDBC7B2
DFCAB5E1CBB8E1CABAE4CEBAE2CCB7E2CFBCE7D4C4E7D4C4E4D0BEE6D3BEEBD9C6EAD6C6
E6D1C2EAD8C9EAD9CAE7D3C5E6D2C5E7D6C9E5D6C9E0D3C8ECE2DAE8DFD9DBCEC6DACCC3
DED5CEE2DBD5D9D0CCE8E0DDEAE4E1DAD0CDD8CCC6D7CECAC9C0C0C7C1C771778E7F7B9C
AF7C96C47283CE7082C65F6FB74956B64C5A9F5066513B59959EB4B8C7DB8A9FB4B9D0DE
CBD6DDCFD8DACFD4D8CAD1DAC1C8D6CBCED9D3D0D6CFD0D4CDD0D3C9CFD2CACFD2C9CFD2
C8CFD2CACFD4CBCFD3CACED2CDCFD3CDD0D5CBCDD2CBCBD3CCCED3C8CDD1C8CDD1CACDD4
CBCBD1C9CCD1CBC9D2B5B0BD5E5F756C78904F60778798AA8998A5AAB5BDBCC0C7B9B8BB
B5A29F44B22B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002AE015AA8559B28E65
B8926CB7916EBA9776C0A07FC2A282C1A184C4A38AC2A48CC4A891C9AE98C8AC98CFB2A0
D4B6A4D6B7A6DAB8AAE4BBB0DBB0A4DFBBABD8BDAAD8C1ADD9C3B1DBC6B3D7C2AEDFCAB5
E1CDBAE1CEBEDECABCE4D0BFE6D2BDE6D4C1E8D7C7E9D5C5E7D0BEE6D0BCE9D2C0E9D2C0
E8D3C0EAD6C6EAD7C9EBD6C8E8D5C6EDDCCEEFDED2E3D2C5E1D1C6DCCFC6DCD1C9D7CBC6
E4DCDBE7E0E0E2D6D4DACAC7E1D2CFE1D1CFD7C7C3E2D5D3E6DCDED9D1D987849E463766
8F416CA3203CB6172ABB111EBF0F1CBA101BAB202EDC9AAC9894A8B7C5D96B839E496B89
BDD3E2CCD4DACED3DBB5BFD1464D6E806D8BCAA8BAE0C8D2D5CCD1CECFD3CCCFD3C8CED3
C5CED5C6CED8C8CFDAC9D0D6CDD2D4CACFD2CACFD4CBCFD6CACDD3CACDD2C9CED3C8CCD4
C8CBD1C8CBD0CAC9D2C2C0CA9F9EAE737C90919EB38A9BAA909EA9A1AEB5ABB5BAADB2B7
AEA6AAA68D8400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02DAC855FB18E69B49270
B69271B89376BE9D81C2A488C3A68BC3A68EC5A691C7AA96CCB09CD3B6A2D5B6A3DAB9A7
D9B1A0D5A598E1A89DCD867DBD7166E0A694DBB7A1D6BBA6D7C0ABD7C2ADD6C1ACDBC6B2
E4D0BEE4D1C2E1CEC0E0CCBBE2CEB9E1CFBCE9D7C6E8D3C2E6CFBDE7D0BEE9D4C1E9D3BE
E9D3BFE8D1C1EBD4C6E7D1C3E8D4C4E7D3C4E6D2C4E2CFC1DECDC1DDD5D0E5E1E1D5C9CF
CCB6BFDEBDC4ECBCBFEAB2B2F9C2C3FCCDD0F6C9CDEABEC1F0CDCFDCBFC4C2ABBE513A64
854673A22C4AB81425C50B14CA0B13C80C13B80C18BE4D62503056556285788CAD243F63
9AAFC7CAD5E0CCD3E08E96B138265182355A8B1F3BB0596DD8A0AFDFC0CCD6C5CFC4BBC8
ADAABD8B8AA36C6A83A9ACB7CACED3CED2D7CCD1D7CACED5CACDD4C7CCD1C7CBD3C5C9D2
C7CAD2C8CBD3C7CBD2C9CDD27E8291232F484C5D75394B6160728396A6B098A3AB9EA0A7
948F9497828042B02700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002AE017AB835EAE8867B08D6EB39274B79578
B89478B9947BC2A188B19176C2A38CC3A693C4A695D3B4A1D6B3A0DCAE9EE1AB9BD39787
DE998AB56959EC9A8DBB5E54CA6B5DDA927DDFB49CD8BCA5D3BBA5D8C2ADDBC5B0DCC7B3
E2CEBCE4D1C2E3CEBEDCC5B2DFCAB5E0CEB8E4D1BFE8D3C3E5CDBDE5CBBAE4CCBBE6CFBC
E6CDBAEAD0BFE9CFC2E7CFBFE9D0BEEAD0C1E4CFC2E5D6CCD6CDCDB9B4BFA18EA3AD768F
C16279C85062C7404EC83743CB3847CE4151D04858CF515DD76972DE838FECA4B79E6485
722B53BD5271B51A2CC50C15C7070FC90810C20711AF1C2C95516E5E5B78CAD5E9A4B5C9
95ACBEC3D4E3BEC6D94D45666E3455951C31A3091BA20B1F9A172DA2364BA74C628D425B
7A334F77334E6E30479C7D86D3CED3D1D0D5D1D2D7CECFD4CBCDD2C9CDD4C8CBD2C8CBD2
C7CAD5C6CAD4C8CBD2C8CDD49294A05C6173687386425062808E9D93A2ABAAB3BBBBBFC6
B3B1B7B1A3A891746900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB82350BC2A7CA043AA8662AE8A6BB18F72B19075B3937AB6967C
BA987EC09F87C6A78FBB9A83CAA995CFAC9AD8AFA0DEADA0E5A69ABC655AB64F43D36C5D
D2745FBF654EED927CB85545DD7767C87663E2B29BD5B7A0D5BBA5DAC1ACDBC4AFDEC9B6
DFCAB9E2CDBCE4CCBBDFC7B5DDC8B4E0CCB7E5D1BCE7D2BFE1C9B7E4CBB7E2C8B4E6CBB6
E6CCB6E9D0BDE9CEBEE8CFBEE8D0BEE9D1C2E4D1C7D4D0D58685A17F5A82B35476C03143
CB212AD21F23D21B1DD21B1CD31B1ED21A1ED11A20CE1A22C71823C41E2DC0263ABD2F49
B42C46DB4B5FCB2732C80D13CB090FCC0910C80910B20D15DC7B88A6889C87879F8A93AD
2E3E62757CA16852757A39589C263BA70917B0040FAF030FAB0311A60615A308189D0A18
980C1890151B852E30D3AEAFD3CCD1CECECFCFCFCDD0CFCECBCCCEC9CCD0C8CBD0C7CCD2
C8CDD4C4CBD3C4C8D2C4C7D0B1B3BC9295A07A818D858F98879199879198979EA5A6AAAF
A4A3A9ABA6A9B1A19D43B42B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0047B6267F634992745BA88668AB886BAC896FAD8B72B08F77B09076B5967C
BC9C83C1A38CC6AA95D1AF9CD6AB9ADDA899CA8477AC5448DE7C6EC35B4CC65544D8634D
C95D45D26F56E28069BF5944E27968BA6451E6B09BD7B7A1D9BFA8DBC2ACDEC6B4DDC6B6
DAC3B3E2CBBBE0C9B9DFC8B8DBC4B3E2CAB8E7CEBDE7CEBDE2C9B5E3CAB4E2C9B3E4CBB5
E6CDB8E7CEBBEAD0BFEAD1BEE9D0BEE7D0C0DFD0CC8C90A85B4D7FA94C79C62438D41D20
D21D17D0221ACD251DC92623C32626C42A2CC4282CC22229C21F28C21A25C21823C01421
C01420C2121BC81217CB0B0ECC080EC8050BC7060CBF0910B728349740585C2B4D805579
6432597E375C9C324EA5192AAE0915B3030EB3020CB1020BAF020AAD020AAD030BA90509
A00D0E91241DC48C85DCCCCACFCDD0D1D0CAC3BEA5CBC2A6D0CDBFCDCFCDC7CCD1C6CCD4
C7CBD4C5C9D2C4C6D2C4C7D0C1C3CF6368792E384A64738346586467767E9CA4ABA4A8AC
97959A938D9193878546BC3600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25DB11648D3C5C4D4A272429766C65A38974AA8971AB8A73AC8C76AD9079B0947EB69A84
BDA18BC3A792D1AF9CD39E8FB86A5EDA8272B45845C6604CC9624EEF8F7BD7735ED2614D
BE4C37E0705BC14F37BE5339F08F78AA5540E7AD97DCBAA5DABEAADBC1AEDBC2B1DBC4B4
DCC5B3E2CBB8E0C9B7E0CAB5DEC9B3DEC9B3E5CFBAE3CBB8E1CAB5E5CDB7E3CAB3E5CDB5
E7CEB8EAD0BCEAD0BDE9D0BCE8CEB9E7CDBCDCCCCC5A6183684E86AC3459CD2225D02E21
D04938E17364DB8074C97C76C98585BB787FB5717DB26979AF5F71AC4E61AC4252B03947
AE2A38B32430B41923C01218C60B10C9070EC9060EC4060EBB0A15B81C2CB02437A51C30
A4152AA80E21AD0715B2060EB3010BB5010AB4020CB00209B1050BAD0509A9080A9F0F0D
972A24C4897FDAC7C3CFCECECECED1D3D2C5B7AB7DB8A65DCEC392CFD0BDCACFCEC7CCD1
C9CDD6C7CAD2C6C8D4C8C8D2C7C8D6676A7C585C6F5B67783E505D80919A9DA9AFAFB8BA
C5C8CDB3B2B7B1A9AC85726800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0024DB13
816850403C400E19360A173569676EA08A7AA78973AC8F78AF937EAC927EB49B88B99E8E
BDA291C5A896D4AB99B16B5BBB5646B44835D87A61DF836ABE5942D26755C45743D56A53
B0432EB94C35CB6A4ED7896DEEA88FA45A42E5A891DDB8A2DABEA9DCC0AFDBC0B0DDC4B3
D9C3B0DDC5B2E0C6B7E0C9B6DDC7B1DDC6B0E6CEBAE3CDB8E0CAB3E2CDB4E0CAB2E6CEB6
E6CEB7E8CFBAE8CFBBE9CFBCE7CEBBE6CDBCE2D1D06D6F8F5D437CA3395BC63935EE8570
FDBFADFAD2C5E2C1B4E5CABEE7D0CADAC5C2D2BFC0E0CCD3DCC6D2C4A7B6A9829492697E
8458747C4B6A823F5FA83A4FB5121EC3070FC5040CC7050DC4060EBF0811BB0911BA0A10
B8070EB9070EB6040BB40309B40209B3030BB1050CAB0608A70B0AA0100C9B1F19A64E45
D5A39DDBC9C5CFCECEC9CED0CDCFD2CFD0C8C5BC98B8A255C0AB5CD2CB9DCED0C2C5CDCC
C6CDD3C7CDD5C4C8D3C6C9D3C7C7D59594A38887956C727D7C848A8C96988F979A999EA2
AAABAFAEADB3B6B2B8A496941AD10E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC12765F48
2D2E390D1E42011648031541595B6B9F8E82A88E7AB09681B29A87B69D8CB69B8DBEA294
BDA18FBD9F8ACAA28DAB6D59DD8673B14C39D6715BCE6851C65A45BA4834C0543FE48E74
D1896EDC9C7FDDA98CDAAE96DDAE99BC8770DDAD95D7B69FD9BEAADCC0B1DCC0B1DEC4B2
DBC1ACDDC2AFE2C8B6E2CAB9DCC5B4DDC7B4DFC9B4E4CDB6E4CCB3E4CBB3E5CBB4E5CAB5
E6CAB8E7CCBBE8CFBDE7D1BCE8D2BDE6CFBDE4CFC6A69CAF5547728E516CD27E78F3BBA6
E6C9B6E5D2C3D7C5B5D6C4B5DCCFC5E8DEDADCD1D1DED4D3E8E0E0D7CBCDCAB7B7CEBFC0
C9C1CE9D9AB646436D603C69A12B47BB0C19C70710CA0810C6030CC1040BBD0A0BB6110A
B2110DB0110FAB0D0DA90F0FA80E0FA5100FA01511971C159C332AAE5F53CE9A91DBC2BD
D4CBCACDCDCFCBCED1C9CED2CBD0D4CDD1D2D2D0C2C7BB8DB7A159BFAE69D0C9A3CACDC2
C7CBCEC6CDD3C2C9D1C4C8D2C4C8D4AAADBA52566A303A4D74818B5C6A71869197A6ACB0
A6A5AAA29FA6A09AA292848737A82400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0094725542393E
0A183F061D5601165604184E454E679C908CA79082A89181A89381B79E8FB99D8EB99E8B
B59A83B89C84C09F87C99B85C87E6CB34C3CCC5746AD3B26E57D66C15B46D8735FD4866E
DBA68AD4AA8FD0AC92D0AF97D2B09AD2AF99D6B69ED8BCA6DAC0ABDBC1B0DCC3B0DAC1AB
DAC1AADBC0ACDFC6B3E1C9B8DDC6B3DBC4AEDFC6AFE5CDB6E4CCB5E3CAB4E5CBB4E5C9B6
E7CCBBE7CEBBE8D0BAE4D0B7E4CFB7E2CCB7E4CDBDDBC9C7847784C3A7ADE7C0B3E4C6B1
DDC9B3D8C7B4DECEBED8C6B9DCCCC3EADED9DDD2CDCEC2BBD2C6C1DCCFCED5C7C5DBCFCC
E1DADEE0DDEC888BAD322A6195446DB01327C40912C7070DC8050DC00609BB1911D55846
B75344AE5044A447459F4A49AC5B54B1685DB97B6ECA9A90DAB8B1DAC7C3D3CBCCCECED0
CBCED1C8CCD0C8CDD1CACFD3CAD1D7CAD0D6CDD0D1CFCEC0CFC09BB8A666C1B071D4CDAF
CACCC7C6CBCFC3CAD0C2C9CFC5C9D2C0C4CE40425843455D595F6F525D688C98A1B0BAC0
B6BBC1C3C4CCC3C1CAB3ACB05A894500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC10A6835D937B6D4B475B
06164902175901185E051B5A333D6290878AA69184AE9785AF9783B59A88B49685B3947F
B79A7FB99C80BD9E85C59C84C47E69A43E2AD25B4AC85744E68570CA6A56A4442CBA6D52
D4A285D0AC90CEAD93CCAC94CFB09ACFB4A0D5BBA9D6BDACD8BEACDAC0ACD9BEABD9BEAA
DABFAADCC2AEDFC8B3DDC7B2DDC6B0DCC4ABDDC4ACE5CDB7E4CEBAE2C8B5E5CBB6E1C7B2
E4CAB7E5CCB8E8D1BBE6D0B8E4CEB8E4CBB9E4CCBBE4CEC0DAC5BBDDC8B9E1CBB8DCC8B2
DAC6B0DAC7B6E8D7C9DBC8BBD7C2B5D9C5BBD8C8BFD6C4BCE0CDC8EDDCDBEDDADCD3BCBD
E2CACCE3CCD4C7B0C6553C678A426DB12239C20A16C6070DC30409BF080AAD0D0CDB6B66
8F4C4C916266AA838E5A3D4EC8AFB7E1C8C8E0CAC8DBC9CAD4C9CBD3CDD1D0CCD2CDCED2
CBCDD1C8CCD0CACED4C9CDD1C8CDD1C9D0D2CCCFCECDCFC6D4CDB6D3C58DBBA854CABB7B
D0CBB2C9CCC8C6CACEC6CBD1C4C7CFC8CBD371717F72707F6E717A868C938D949C9398A1
9C9FA8A2A5AFB4B6BFBCBAC18C7B7900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006E973BAF957E917F7B54546B
06174A01155C011764031B6124305B968C94AC9689B19886B19583B0907DB08F78B39178
BA997DB8997CC09F84CA9D87CA806DBE5A44CE5C46A93A24B3563DD68E72D29679D4A587
CCA68ACBA98DCBAB8FCBAC93CCB39DDAC8B8E7D7CCE1CDC2D9C0B2D9BEACD8BDAAD8BFAC
D9C2AFDAC4B0DBC5B0E2CCB6E0C8B1DBC2AADEC7AFE4CDB9E3CBBBE4C9B7E1C8B4E2C8B4
E6CBBAE2CCB9E5D0BCE6D0BCE6CDBCE7CFBCE6D0BBE4CDBBE2CBBADEC9B7D9C9B7D8C8B6
DAC0B0DFBCAFE2BCB1E1B9AEE7BAAFEABBB5FAD0CEFACBCDE6B1B3F1B8BDEEAEB4DB9096
D48288E48F98E6909FAF516BB43A57C62739C10812C4060DC2050BC2060CB6050DBE2932
A32C3B953243B55D707E2E47B36E85D296A4D59FACD9A9B5DAB3BEDBB9C3DDBFC9DDC6CE
DAC7D0D5C7CED2C8D0CEC9CECCCCD0CACCC9C2BDACCDC49ED0C387C2AF51C0A82DBFA938
D3C582D1CBAECCCCC4C8CCCBC4CACDC6C9CE8C8F9D464D60616E7D81919E73828C97A0AA
AFB2BDA6A6B09E9EA69A979F7F6E7000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007CA44BAF98819484749D8F8B4D4D62
0D1F53021962011668031763192654968E96AA9387AE9383AD917FB3937FB49279B59277
BA987DB8997DBD9C80CD9B839A4832A8482DD57F60CF896CD59B7FD0A387C8A489CAA98F
CAA98FC9A98ECAAA91CAAD94CCB8A4E9DFD5E7E0DDEADED9D2BFB4D4BBA9DAC0AED9C1B0
DAC4B1D8C2ADD6C0ABDEC6B2E3CBB5DBC3ABDEC6B0E1CCB7E3CDBBE2CAB8E2CAB6E2C9B6
E4CBB8E2CAB7E4CEBCE4CFBEE5CFBFE6CFBDE5CFBBE3CCB8E2CAB9DCCABCB8B5AFB6B0AF
D5AFABE19590DE7F7CDD7272D45E62D05259D24E5ACB424FC4343EC32E38C22631C01D27
BF1921C31C24C21822BE141FC00F1BC20A13C4070DC3060AC1060BBF040BBD040CB6050D
B10813AA0914A70A17A40A1AA00B209C0D229C122898142B981D339924399D3046A34456
A95566B16877BF8290C599A5CFB4BBD4C8C1B7AB8AB39F57BDA43BBCA21BBEA40BC0A610
BBA528C4B45CCCC28EC8C7A7C8CBBCC7C8C5ACABB32B2E415E6577505C6C4B596895A3AE
AAB1BDB2B5BEAFB2B7B6B7BC998F9118D00F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0079A246A89480A99D919D9388AAA19C595D6F
172B61021A6702156501145D1524518C868DA28A80AA8E7FAD8E7CAD8E79B5957CB7947A
BA967DBA977FBD9A82C3987EC2886BC38666CD9A7CCBA289C8A58DC5A78FC2A690BEA58F
C5AC97C3A991C6A990C8AD93CEBBA8E7DED5E7E0DEE2D6D2D0BBAED4BCA8DBC2ADD9C0AF
DAC4B1DAC3ADDAC1ACE1C7B6E1C9B6DBC3ADDDC3AFE0C8B5E1CAB7DCC8B2E0CCB4DDC9B4
E2CDBAE1CBBAE3CCBCE3CCBDE3CDBDE0CBB6E2CCB6E2CCB5E4CEBADDCDC3787C8A4E5472
A46B82B12B37C92226CB1B1DCD181AD0191CD0181AD3171AD31518D31617D31516D21414
D11312D21513CD1310C9120EC81211C30D11C30C13C3070EC2050CC2050CC1030ABE030A
BC040AB7060AB6090DAF050AAE060DAC060EAD0611AA0611A90814A80714A90A19A00716
9C09179B0C1A950E208D1627842E3BDAB4B5D5C8B8C8BC92C3AE5FBCA228BCA209BBA202
BDA508B8A213B59F28B2A343C3BA77C9C297C2B99E6E665B7370737173797D8388888F96
8C8F97909197949298A1A0A6AB9FA435A82600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00769D40B4A28B9C9087A79D969489819D938E757485
09194D02166100115D0112540D1A457D7882A0877EA7887CAB8C79AE8F7AB5927CB8967E
B9977DB9967EBD9982BF9A80C39A7FC2997EC39F85C2A38EBDA28EB39D8D9C8B7D8D7F73
958A7DAEA18EBEA890C7AD93CEB6A1D8C4B8D9C6BDD5BFB3D1B8A6D8BEA8DABFAADBC2AD
D8C0ABD8C2ACD9C2AFDDC6B4E0CAB4DDC5ADDDC3AFE2CAB8E0CAB7DDC8B2DDCAB1E0CCB4
DFCAB5E2CBB7E3CAB7E0C9B5E2CCB5E1CBB4E1CBB4E3CDB5E3CEB6DEC9BCAEA9B6364066
996D90B22D3DCF1E1DD41912D51A11D31B11D21D12D11E13CF1E16CE2119CB2318C72318
C5231BBF2219C1281EBD291EB62722A11721A61325B80F1BC10710C2050CC1020BBF020B
BB070AB51711AB1B15A41B14A11B149D17139E14129E1212A01111A20F0FA50E12A40B0F
A50A0EA2080DA108119E0914870D19C18286DAC9C5CFCCC2D6CDAFBCA957BCA31ABDA304
BFA603BCA004B39904B19B0DB19D1CB2A02CB29E3A8A783A45423769727B8896A0818F95
A8B0B4AAABB09C99A08D898F8B7C8235A72600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0051BE2AAE9882B8ADA69A9491C1B9B699908DB8AEAE92909F
13204E0B206401155B0214560B18477A7681A38C83AB8D80AB8C7CA98A77B3937FB4947C
B29378B9967EB99781BA9B83C1A187BD9E82BFA188B99F8C9D8B7B82726686766B877A6F
766C65726B61A89C89C5AF98D0B6A0D2B8A5D2B9A8D1B7A3D5BAA5D9BEA8DAC0AAD9BFA8
D5BCA5DBC2ADD9C0AFD9C2AEE0C8B2DCC2ADDBC1ABDFC7B4E1CBB9DFC8B5E1CAB4E1C9B1
E0C7B1E2C9B3E1CAB4E1CAB4E3CCB5E3CCB5E4CCB7E3CDB9E4CEBAE1CBBBD5C7C667657D
81637FB5545CC03226C7331FCA3D27CC482FD2563DD8624DDA6D5DDE796BDF8474E28F7F
E6988BE49C90DF988CDA988AD49A957A4459742E53A82841BA0A17C1030DC2020CBC0208
AF0808D85F54D08075B1756DB27E7A9A69699D6A68AE716AAE6864A95B57A34949A03D3C
A034319928249720219116198B181D90494DDEC7C8CCCBCCCFCDC5C6BA89BAA130BFA50B
C0A402BFA404BAA00AB39D06B39C04B39D06B19B0DA39025332C084B5056505D6B62727C
A8B2BAB5BBC1B1B4BAAAA8AEABA1A440B63500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0026DC11AA8F70B3A49DABA4A3ABA7A79B9797ADA6A6988E8F938E9A
232C5303155502145B021459061448726F819E887FA68A79AA8E7AAB8D79B1917CB2937A
B4967CB6987FB79881B89A82B89D81B99E82B8A08A9E8D7B8274669D8D7EAB9886AC9989
94857B6E6861797368C3B19FCFB5A0D2B8A2D3BBA4D2B9A2D6BDA6DABFA9D8BDA7D7BDA6
D7BDA6D8BDA8D8BDA9D8BFAADEC5AFDEC4AED9BFABDEC4B2E1C9B8E1C8B7E2C9B4E2C9B3
E2C7B3E1C9B4E1CCB7E0CCB5E1CBB4E2C9B5E2CBB7E6D1BCE4CFBAE0CBB8DECBBDC3B2AD
C1A5A3DEAA9FE09C89EAA793E9AD99ECB5A0ECB8A2ECBBA6E7B9A9FDD3C7F1CAC1E1BBB3
F3CEC5EBCCC3CEB4ADBAAAA6D0C0C5B397AC622B51B3435FB60D1BC2050CC3040BBF0409
B2080BBB4140DC9EA255374968647C7A8397657080CDD0D7D0CCD2CFC1C7D7BEC3DCBBBB
D9B2B0D0A7A4C59795BA8482AA70718F6466D2C2C4CCCDD1CBCCCBCFC9ADB9A44BBCA511
BFA504C0A90E8F7B079E8F11AC9E10B7A40AB39B04B09B198B7C337B776474787A858E93
90959B8F949893959A908F94A69FA2806D6800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0078A045BCAB9EBBB3B39E9C9DC9CACC989799CDC9CB91898CBCB8C2
39406102124C01145A011459051348625F7298827AA68875A88975AA8B77AF917AB0917A
B2937CB3947CB7967FB99980BB9C80BB9F85B19D8A7D7164918577A99787AE9985AF9C89
9F9084766F6B69645FBAAA9DD0B6A3D3B9A3D4BAA4D3BAA4D7BFA8D4BCA4D5BBA4D8BFA7
D7BEA7D7BCA5D7BCA6DBC1ABDCC5AFDDC7B2D8C1AFDBC5B3E1CAB7E0C9B7E0C9B7E1CAB7
E4CCB8E1CAB5DEC8B3E0CAB5E1CBB7E1CBB9E0CCB9E4CFBBE4CFBAE3CEBBDEC9B8DCC6B5
DBC1B2DAC1B2D3BEB4C6B3B0B89D9EBF9998D9A7A1EDB1A7EDABA6F4B1B1EDA4A7DE8E90
D08080C48281E0B9BC6460757A7595A8708DAB3E56C32F3FBB0A14C4060DC3050CBD0409
B8070DAD131DB740527C2542572A4DA297B079859B899BB75C648271617D9A768ACCA4AD
D4AFB5D8BABDDCBEC3DEC3C6DCC6C7D3C6C7CCCBCDCAD0D3CBCFCFD1CFB9BAA858BBA414
BDA504BDA7127D6B183D38035B570C9E971BAD9F0CAF9E0EB09F31867F4397987D9AA295
A6ABAAAEB3B5ADB0B3A4A3A8928B9179646600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0029E015AC967EB4ACA9A8A6A9A3A5A8B9BDC0AAABAF9F9CA18E868C908893
40435E031146000F530211570312465B5A6E99847DA08472A38673A78A75AC8C77AD8C75
B2927AB4957DB6957DBB997EBB9C80B99E859A897A736961978B80AA9889A99887A9988A
96898278717068635FB3A496CFB6A0D2B8A2D3B8A4D6BCA7D6BDA7D2B8A1D6BAA3D7B9A3
DBBEA9D7BBA5D6BBA4D8BFA8DCC3ADDCC5AFD8C2ACDCC4B0E2C9B7E1CAB8E0C9B8DEC8B8
E0CBB7DEC8B3E1CCB7E1CAB5E2CAB7E0C9B5DFCAB5E2CDB8E8D3BCE6CFBDDEC8B8DCC6B6
D9C4B6C9BFBE8587977B6A80BA7C8EC86370C94A51C83A3DC93238C62A33C4232CC42026
BD1D23AB2227DC868E957E993E356590476EA9152ABD0A15C5060FC4030BC2050BBC0509
B7060BB3060FAB0614A10A1B931D32B67A879E94A920264C60436B86304D8E192E901826
91212F932E3D9A3E4DA15262A66976C5A7ADD1CCCFC8CFD2C9CECDD1CFB6B6A34DBAA211
BDA503BEA8117C691B100C001519013335028F8814A79A14A99916948614978931928B4B
81805AB2B3A3B4B7B3B7BABCAEACB1998C8F18D10F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A48862B5AEA3B1B1B2A0A2A5C7C9CEA6A9AEC5C6CB8E8A8EC1B8BD7E737D
7E7D950C184702104F01105206134955526A9B8582A28677A28671A78B76AA8E78AC8E76
B09175B3947AB6977CBA997DBD9D82BCA18B8C7C6F766E668F867E9E91879A8E848F8780
817C7A686868696660BEAD9DCCB29CD1B59FD3B8A2D6BDA5D5BDA5D1B9A0D4BAA2D7BBA4
D6BAA4D6BBA5D8BEA7DEC3ADDBC1ACDFC7B0D9C4ABDBC4ADE1C8B3E4CAB7DFC7B6DEC9B7
E0CBB8E1C8B6E4CAB6E4CAB5E2C9B6E2CBB6E0CAB3E1CCB6E4CFBBE1CBB9DDC6B5DBC4B7
D6C7C37E8699505479B57998B73242C81D26D2181ED6171AD71319D8131AD51014D51313
D01312C21815B93637D39BAA3F325E7E4C7BA31C35C10C16C6060CC6070CBF0709B8110F
A80E14A20716AD0717AF0310A60916A43B46966E851C123C7C4C70871127A10614A4030F
A405129E05119B06139A0B198E0E1C8B3943DDC1C7CCCDD1CBCECDCFCAABB39F3FBDA50F
BDA402BEA7127E6A1A1B140324280E33380A807C28575207898317A59B19AB9B14AA9A1A
A39228A092459791679392848D8B8794898831A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF004DB926A59384A6A7A8ABB1B4A8ADB1BFC2C7A7A8ADB7B6BB908A8FA2989D837780
7A7890091345010F5101115306154C504F689784809F8372A58770A78A71AA8C75AE8E76
AF8D70B59378B6967BB9987DBC9B82BB9C898A776C6D67637C7875847E7B827E7B797775
6D6F6E5F6260817C72C6B19FCCB29CD0B69FD3B9A2D2B8A1D4BCA4D5BCA5D0B59ED4B8A2
D5BAA4D6BCA6D7BDA7DBC2ACDAC1ADDCC6B1D9C4ACDAC3ACE1C8B3E0C9B4DFC7B3E0C8B5
E1C9B7E1C8B4E4C8B5E4C9B6E2C7B5E3C9B8E1CAB6E1CBB6E4CFBAE4CFBBDFC9B9DCC5BA
D3C7CA4755775D5F8EAE5E79C1232BD61719DA1312DC1412DC1112DD1315D5120ECF1A10
C61D11BD2012AE291DCB817F75617E4A37689C3A5BB9121FC6080EC5090BB70A07DA5951
B1565E690F2B8C0A28AB0517B104109D0B16AC53684221436A43618422329F0913AA040C
AB030CA60109A5010BA4020A9E070E861219CA959BD4CBCDCDD0CDC6BE9FB49F41BDA415
BDA405BEA60E8A72162D1C05343216141600847E3B302B001B1D00636414A2991CAB9A10
B09D11AD9A18AC9D3CBBB17B9F977F84776B31A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00729D45B0AAA6A3AAAEA5AEB0C3CACDA7A9AEB8B9BDA2A1A4B9B4B58B8383ADA4A7
66667B18255403135301105204124848476097857F9F836AA9895FAD8D5AAD8C5DB59265
B08E64B29171B5957BB8977EBC9982BA9A87967F7567605F6B6B6D7271736E6E6E696967
6667636E6A63AE9F90C9B09BCDB19BCFB59FD1B7A2D0B7A1D3BBA2D1B69FD6B7A2D5B9A3
D4B9A4D5BBA7D4BAA7D6BEAAD6C0ACDAC7AFD9C5ACD9C4ACE0C8B3E1C8B4DFC5B1E0C5B3
E2C9B6E2CAB7E3C9B8E3CAB7E2C9B5E2C9B8E1CAB9E1CCB8E1CEB7E0CFB9DCCAB7DCC8B9
D8CAC7656E8D444E7EB2809DB22D36CF1B1ADA1714DA1310DB1211DA1411D02216EA6753
E88169E1876FDC8C77D5A093B29FAB36335F824774A7172CC20A14C3070DB5090CD66160
C1848D5D3350630E38A00C24B50712AF080FA125309B65793C244081465C8E1622A0040E
A9020CA70008A8030AA3080A9A0E0D8A1718945154DBCBCCCED0CFCDCCBCBFB379B8A536
BCA513BDA70AB59B185F44063F2F052922008D823C3A3205181902292C0777722070660D
A69A18AA9B09AE9C14B6A73AB2A35CA798703FB42800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00967F689D9FA2949FA5AAB3B9B8BDC398999FB0AFB3A5A4A6B6B2B3888382A49B9E
6E6C7D16204B02114F021050020F45424058978377A58756BC993FC39D33BA922FC59D44
BC974FB79462B59374BC9982BC9985BC9B88AD9284726460646163636165656263736D68
84796EA08F7FC5AD98C7AB95CCB098D2B6A0CFB39ED1B6A0CEB49CD1B49DCEB19CD3B9A4
D4BCA9D2BBAACEB9A8C7B5A3CEBEABD5C4AFDEC9B3DDC4B0DEC5B2E2CAB7DEC6B5DFC4B3
E4CAB8E2CAB8E2CCBBE3CABBE2CAB9E0C9B7E4CDBBE3CCB8E2CFB7E1CEB8E2CDBADFC7B6
DEC8BCBBB3C1515D836B678EB67389B52E36CC1C1ED81514DB1412D71411C71F18FB8F83
F3AC9AE1B09BDBB39ED2B5A3C9BBBB5A5C7D5B42749C304EBB0F1DC5080EBC080CAF2225
D2888B8A6A7C42103B870D31B00518B2040D9E0C15B467727862773E2A437E3D4E8D131E
A0050EA60108A304079F1C17BB6058A36359895F5DC7BCBCCCD0D2CCD0D1CECCBDC7BE89
B8A941B9A415BEA50DBA9F179B82164936009A882F4F410E211E031D2200928F4359500E
6F650FA29919A79B0FB3A316AD9A20A08B3746B92000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
27DC13806E628F93999BA3ABBCC1CA9D9EA8B1B0B7A9A6AAA7A3A5B1ACADA8A1A2897F82
8F899711173C020C46020F4C041143434356978369B39440C3A11BC8A50EC7A017BD9528
BE9A46B79359B49170B6947DB7957FB8977FBA9984A1877878655E7A6B6593847A9F8D7E
AE9884C7AD97CAAE98CCB198CEB29BD0B49ECFB39DCDB19BCEB39CD1B69ECDB29CD3BAA5
CCB9A7B5A495AD9B8DAF9E8FA8998ACBBCABDAC5B3DAC1B0DFC5B4E3CBBADFC9B8DDC7B3
E1CBB7E1CBB9E0CAB8E1C9B8E4CABBE4CAB8E4CDB8E7D1BBE5D0BBE2D0BBE0CDB9DFC8B6
E0C9BAD9C7C1BAB4C0626687695F85B27993B3414CC42226D31618D71314D01416C82B2B
E0706AEC9E93E3AD9DD4B4A3DDCDC7A6A6B9332E5F914C73AA1526C00810C1070DAD0E11
D37274BE95A148244A6F0F3AA80820B50310A8050E9D2F35B1878D8579884B344B7F3B4F
89111D9D060DA2040A921310D58D88D7B7B2BEB2AFBCBCBDCBCFD4CACED7CBCDD2CECDC0
C8C08FBAA843BEA518BEA307BDA30CB49C12B59C1D6853102D24011B1B00807D36554E05
58520384801F756D09A59817B2A014A28C1848BB1200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
50BF309A928D858E98A5AEB8B2B7C19B9CA3B1B0B6A8A5AAA9A3A7B1ABB0A9A2A58D8286
A19CA8192042020D45010E4B0311444343549A8554BE9E29C8A70CC7A704CAA613BA922A
B28F4EB08E64B08E71B39279B4937CB5947DBB9882BA9984B69886AF9484B39985BCA089
C6A991CEB099CDB09ACAAE98CBB099CCB29BCCB19BD0B69FD2B7A1CFB49ED1B7A1CFB8A4
B19F8EBEAB99D2BBA8D4BCABC4B2A2AC9C8DDBC9B9D9C3B3DBC4B3DFC8B7DDC8B6DBC8B4
DECCB9E0CBB9E1CCB8E2CBB8E0C8B5E2CAB6E2CBB5E6D0BAE2CEB9E2D0BCE1CFBCE3CDBC
E2CBBADEC9B8DBC9BECEC3C58F8CA05A547393738EBB6778B62E35C91B1ED31418D01318
C61B1FC12E2ED6645FE7A299DCBAB2D1C6CD44466B6444709C2740B90B15C1070DB90B11
B93740B86F7F7B4A6A680F3AA10A25B2030FAF040D971017C3868AD5CAD0938F9F48324C
7D3D5287142399051099081090222ACC939ADAC7CBCCCDD0C9CDD2C7CED4C9CDD5C8CDD0
D0CFC2C4BA87B6A235BDA30EBBA203B9A103B7A008A68F1465510A2E22008A7F2F706510
665E0F7A74205F5704675D0BAEA11DA997127AA71800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
729B457C7A7C697581A8B2BF8A8E99B1B0B7ACAAB09C9AA0B7B5BB9B989EACA3A89C8F95
867D8B33375803104801104E02114342434A9E8742C19F1BC9A707C7A602C8A50DBF9826
B5904EB08E6DAE9078AF927BB1927DB59681B99981BF9D86C09F89C0A18BBFA08BBFA08B
C9AA95C9AC97CEB09BCBAC97CCB09BC8AE97CDB19CD0B49FCDB19CCFB59FD0B6A0C5B09C
AF9A88D4BCA8D4B9A5D6BCA9D5C0B0A49284D7C4B4D9C3B1DCC4B3E0CAB7DEC9B7DDC8B7
DDCAB9E1CCBADFC9B5E1CCB8E2CFBBE1CBB7E0CAB5E2CDB9E2CFBBE1CFBBE5D2C0E6D0C0
E3CCBBE0C9B7DFC9B7DAC6B8D7C7C1BCB1BA736E89665A7CAB7C97B74E5DC02128CE1317
D01013CC1114C11719C13D3BE0908ACFADA890899F362E5A944467AF1122C00710C0070E
B40C15C13C49BB4B63981B37AA0B1EB2020CB2030BA007138F36449A8892CFD0D99C9DAD
49385174395187192A9807129A07148A1B2AC48A96D5C5CACBCCCFC5CBD0C7CED5C5CCD4
CBCFD0CFCDB8B0A559B9A523BDA50EB8A002B69F02B6A108AF98148D780F917D17807012
615508665E1D696210716C0E9D951E9C90119F8A1352C10F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
B4997F9699A196A5B6A9B6C39098A1B7BCC2A8AAAF9C9CA3B6B7BC949298BAB5BAA69DA3
918A9555587803114501114B0710394C4633AF9533C3A40FC4A502C6A802C5A405CAA41D
BD9642AF8C68AB8E7AAB907BAF937CB3967EB89880BB9982C09D87C29F89C09F88BFA08B
C2A691C7AD9AC8AE9ACAAD9BC9AB98C8AD98CEB39CCFB19CD2B39FD0B49FD0B5A1C7B19F
AD9A8AD2BDADD3BDACD3BDADCCB8ABAE9C8FD9C5B4D6C0ADDCC6B4DEC9B8DDC7B5DDC5B4
DDC7B6E1CCBBDFC9B6E3CEBBE2CCBAE1CAB6E0CAB4E1CBB6E3CFBBE4D2BFE3D0C1E2CDBD
E3CBBAE1CAB7DFCAB7DAC5B3DBC7B5D9C6BCD1C4C9989AB3494F78886A8CD16D7CC11F22
D01211D10F0ECE0E10C41416B62E2BDD948CDCC5CE3C3A5F7547729F1D35BC0915C2070D
BD050DB60911AE0713AE0816B0050FB4030CB4020BAA040F931B26885A61CFCDD1C7D0D9
9FA6BB382D49783D528A13209D0512990614881B2AC6909BD3C6CCC9CCD0C6CCD3C4CBD4
C8CCD2CACBC4B2AD82C3B663C1AC38B8A110B8A104BAA403B49B03B19908AE950BA68E11
6550047465216D631D444000958F26867D0E28E20654C51000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
BCA99777808D697B8F6B7A8987919A9DA3A99D9FA6B0B1B695959AACABB0979298A49CA3
867D89393A5904114208143E1F20207B6822C1A31EC4A606C4A902C6A900CAA804C7A215
B48C35AD8A64A98A76A88C79A98F79B1937DB6967EB9987FBC9B84BD9D87C0A18BBFA08C
C5AD9DD2C1B3D6C5B8CFB8ABC5AA9BC8AD98CDB19BCEB29CCDB09AD4B5A0D2B6A2D4BBAB
A59084C6B4A7CDBBADC7B4A5AE9C8DCAB7A8DBC7B5D9C4B2DCC7B7DEC8B7DCC2B1DEC4B2
DFCAB8DFCCBCDCC9B9DECAB8E0CBB7E2CCB6E3CEB7E2CEB7E3D0BBE5D2C0E3D0C0E4D1BF
E1CCB9E1CCB9DEC9B5DFCAB6DCC9B8D5C6BECBC2C6AEACBE736B908F688DE38194C6282D
D01311D3100CD10D0CC80B0AB91511B95145DAAFAC776E8A42315F9C3F5EB10E1CC0070F
C0040ABC060BB40B12A80C14A30716AB0514B1010EAD020B980911A5565DC1B7C3ABBDD0
7783A2443956753E54A83D489B0510A0020B980813882430D2ABB1CECACDC7CDD4C6CDD7
C6CAD5C6CBCFCCCEC5CFCEAEC7BB75BFAB36B9A414BAA307B39C02B59C03B09802AF9707
A38C0C9B87148270184C40039E922E897D1054CC1400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
CBB9A788919D798A9D83909EB0B9C0A2A6ADA1A1A9BDBDC48A8A8FC5C3C98C8990C4BFC6
918A95454866132146282A26806E25B99C1EC2A00CC2A30BC4A707C7A802C9A903CAA614
C19A36AE8A58AB8A71A98C76AA8D77B1937BB6987FBA9B83BC9C85BE9E88BDA08CC4AD9D
DDCEC5E2D9D5DFD6D2E6DAD3D3C1B6C7AD9BCAAC96CEB29BCEB29CD2B6A1D4B9A4D6BEAB
CAB5A4AE998CAE9A8DB39D8ECCB7A4D7C1AFD9C4B2D8C3B0D7C3B0DEC8B6DBC5B2DDC7B6
DFC8B9E6CFC1DFCBBADECCB9E0CEBAE1CDBBE3CFBCE2D0BBE3D1BCE2D1BEE4D2C0E4D0BE
E2CCB9E1CBB7E1CAB9DEC9BAD5C5BEB2B1BB72758F907491C87B95C54C60C2242FCC1418
D2100FD00E0ACD1108C3160AB32412C06451D1A69BBAACB835315A854D75A4192EBC0815
C0050EB2080ACF524FC1666E6B122F880B2DA70519AD020CA5050F93253658385A232C59
4B3E6784435D902434990F18A1020AA60108A4050C900C13985255D9C8CBC9CCD2C5CDD7
C4CBD6C3CBD4C6CED1CDD2C8B9B286BEAE56C3B13BBAA51CB8A00CB49C03B59E04B29D03
B19B04B29A08AB94117B670B7C6A1292841781B52100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D5C3B0848A985B6B7E6D7D8C919CA591949DADADB59E9CA49E9BA29E9AA29C98A09A949B
847E8743465C131C21746A2CBB9C1EC3A10DAD910F7D6601B49A10C5A605C5A208BC9615
B79234AF8B4CAD8A61AC8C70AB8B76B3927DB99882B79982BA9B86BD9F8ABCA292DACAC0
E1D7D3C7BBB7C1B2ABD5C6BFE3D3CBBFA898CBAD97CFB09AD1B49ED2B7A2D3BAA6D3BCA9
D5BEACD7BDACD5BCACD7C0AFD9C3AFDAC4B1D8C4B1D7C3B0D5C0ACE0CAB7DDC6B5DEC7B7
E1CABAE3CCBCE0CBBADFCEBBE1D0BEDECDBDE2CFBEE4D1BEE4D1BDE3D2C0E5D3C3E5D1BF
E4CDBBE2CCB9E2CCBADDC8BBCFC5C8536180676892B56B87B62332CE1A21D51418D41112
D0100DC60E06C32011D1553CDA866BE7B8A1CAADA1D5C6C6646280543B69982E4FB30C1C
BE0811B00B0FCF6466EFC5D0493057590F429A0B29AB020FAC030E99101F80395B1B0D3B
6F4C6F7A14279D0915A5030BA70208A70208A5070B950F0F7F3130D6C0C0C7CAD0C4CCD6
C4CDD6C0CAD4C0CBD3C5D0D1C8C9BAB9B488BDB371C7B864B7A336B19B15B39F0BB19F04
B4A104B6A003B8A005BAA410A9950FA1911A998B1F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D3C0AA7F838D48586980909D8B959EA4A9B0B6B8BE8A898EC3C1C5827D83C7C2C7807B7F
B9B4BA494B54272708A59127C2A10CBFA011826906604D088C740CC4A50ACAA614AF8B16
B99430BF9B3ABA964DA98860AC8B75B3917DB99883B89882BB9C87BC9F8AC1AB9BE5D8D1
D2C6C2BAA79FC0A99CC4B1A7E4D2C8C1A89BCEB19ECBAC97D2B4A1D4B9A8D4BAA9D4BBAB
D5BBACD5BAACDABFB1DBC1B1D8C0AEDAC4B1D8C4B1DAC6B3D8C3B0DBC6B3DDC8B5E1CCBA
E0CCBBE0CCBBE2CEBDE3D1C1E1D0C0E1D0C1E1CFBEE4D0BFE7D2C1E3D0C0E3D0C0E4D1BF
E3CFBCE2CDBAE2CDBBDFCABECBC4C83D4F74656897A85A75C2232ED41519D71013D30E0D
CE100BBC1005E55948F49D85DBAB94DFC5B1C8B2A5C1ADA6A198A53830598A456EA31126
B90611B70A0FAC2B31E0A9B545365C3A124A850D38A80315AE020DA00514A13B5237173D
553D5F792337970915A4030AA70108A404069E15119B4033A2766FCFC6C5C6CCD1C4CBD5
C2CBD4C1CAD3C1CAD3C6CFD8CAD0D5CACFC9CBCFBFCFCFB8C6BF95B8AA5EB0A233B3A61E
B1A313B3A30CB7A508BAA807C1AC1596821284751700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C7AF9693959B6877886C7D8C7C8995A4ADB5A0A5AA979A9FA8AAAE918F93A7A4A8837D80
A0999B4E4A41564C0EB89E1EC0A00AAC8F10594404604A07A5870DC7A407C8A40EBB9713
C49E1FC8A221BB9738AC8C5CAC8E76B08F7EB79683BC9B87BF9F8BBEA18EC0AC9EE7DBD5
CEBFBABEA99DBFA799CEB9ADDCCAC0C8B2A3D0B5A0CFB39CD1B49FD3B8A4D1B7A4D4BCA9
D6BFADD7BCADDBC0AFD8BFACD4BDA8D9C3AFDAC3B2DBC5B4D7C2B0D8C2AFDDCAB4DDCBB8
DBCAB8DFCDBCE0CDBEDDCCBDDECDBDE0CEBEE4D0C0E6D0BFE6D0C1E7D1C3E0CBBDD5C0B2
E5D0BFE0CABADEC8BADDC9BBD9CAC88589A3394674A684A7B14251C31C23D31417D30E11
CF0E0EC8120EC11F1AD35D51E59C8DD6AC9ACAAFA0C4AEA2BEACAE5049695D396794233D
B40A17BA070EA90E14C56C72C4A2B74D2C596E0B3DA3071FAF020EA9050E9718285F2748
261A426C415C821928990811A5030AA005089A2521D59F95CEBFBBC9CDCDC6CDD3C4CDD4
C1C8D2C0C8D3C0CAD4C6CFD9C5CDD7C7D0D6C7D0D4C8CFD2CBCDCBCCCCB9909168969955
959640ABA63CB2A625B5A611BDA811B39C19826D1482B21E4FBE0F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C4A786A8A5A857647555657586939FA8B2BB878F93B6BABE929398BAB8BD8E888CC0B6B8
8678729C8B6890781CBA9D13BEA111806409664E0C876D0DC3A112C4A008C29F17B39216
BF9F1DC3A01FBC973DAF8D61AB8B73B18E7DB18F7DB99A86BA9B87BC9F8EBCA698E2D5CE
DCD0CBBEAEA6C8B6ABDFCCC1CCB5AAC9AE9FCCB19CCFB59FD1B6A1D0B4A1D1B6A3D4B9A7
D3BAA7D4BAA8D7BDABD4BCA6D8C0AAD6BFABD8C3B1DCC6B7D9C5B5D7C5B2DBC9B5DBC9B5
DAC8B4DFCCB9E0CCBBDFCCBBDECCBAE3D0C0E4D1C1E6D3C2E4D1C0E6D3C2E3D0BEDFCCBB
E2CFBEDECBBCDECBBCDDCABAD9C7BCD0C5C881859F505277A47F9BB45262B7232AC71619
CE0E13D00F12CC1113BF1515BA302BD97B71EAB9ADDBC1B4BEAAA38C83933425508B3A5E
A91020BC0911B2090EBC444BFCC1D0915B7B720F399E061FB0030FAE040C9809148F4157
766786443A5A75425B841D2B980A149D050C8E0C11A95E5FD8BEC0CCCACDC5CBD5C2C9D3
C2CAD3C0CAD3C2CAD6C4CCD7BCC6D0C0CAD3C4CED6C2CCD5C4CCD6C6CDD2A9B3B59EABA3
B3BDA5B5BB92BAB772B5AC41B8A621C0AA1BA4900BC1AB2283AC1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
94BD64C3BDBF6E7C8D677B8C9DADB99DA8B191969CACADB29A989EB0ACAF978E8AB7A798
8D784FB99E4CB39419B99A129A8008AA9230654E00B3971AC3A10BB99513A88728A68938
B4963CB89942AD8C54AC8A6EA98975AE8E7BB09280B39684B89B89BD9D8DBDA193C9B5AC
DDCFC8E1D3CBD9C8BECCB5A8C9AE9ECBAF9ACFB49DCBB09ACFB49FD1B6A1D2B7A3D3B8A5
D3BAA6D6BEABD2BDABD1BDA9D5C1AFD9C3B1D8C1AFDCC4B4D8C1B1D7C2B1DBC6B4DBC6B1
DCCAB4DDCBB9E1CEBFDFCCBCE0CFBEE5D3C4E8D6C8E8D4C6E5D3C4E6D5C5E4D3C3E3D2C2
E1D0C0E0CEBFDFCBBDDCC9BADCCABAD6C6B8CEC3BFA59FAE645F7D7E6883B77484AE373D
BC1A1DC81315CB0E10CC0E10C41011B51C1AC95E5AE1A79BC7A89AB9A9A94842616F3F69
9B1C34B80A16BB050EAD0F19BF3D4EA72B419E0F26AB0515B2030EAE020B9E060FAB4959
C2A6BCACAEC354496573455C832131930C189908118A0F189C505BD8BBC4CAC9D0C3CAD1
C0C9D1BEC8D1C2CAD6C7D0D9C5CFD8C1CBD3C5CED5C4CDD5C4CCD7C3CBD799A3B2344451
727E776C7362919780929261B3A84BBAA823BBA914C3AF18BB9E2200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
60CF40D5CBC95B66766173848695A379838DB1B5BC959499B0AEB0A7A098BDAB8DA9904E
BB9B35BB9817BD9B12A688125A44016A57128B7208AD8E09C3A10DB08C16B18C3FA78653
A2835AA58764A78A71A88978AA8B7BAD8F7EB08F7EB69685B99A88BE9E8DC09F8FBFA393
BFA698C3AC9DC5AF9EC6AD99CCB19CCFB69ECBB19ACDB29DCDB19CCDB29DD1B4A1D0B5A0
D3BBA6CDBBAABBAC9DB7AA9BCCBCADD7C1B2D8C0AFDEC6B3DAC2B0DAC3B1DCC6B2DBC9B2
D8C8B2DDCBB9E2CDBFE0CCBDDECBBCDFCCBEE2CFC1E5D2C4E5D2C5E5D2C4E6D3C5E5D3C5
E3D0C3E0CDBFDECBBDDCC9BADBC8B7D9C6B5D7C6B4D4C3B9C6BBBF8D84985F516A9C7185
AE565EA82B2DBA1C20C71214C90D0FC50F0FB91817BE4D44DEA193C8ACA583788C432B55
973856B0111EBC080DB6040BB30814AF0713B20710B1030BAF010AAE0309A9060F951424
844B61C5BFCEBCBCCE5F546E6F465F822C3C8E0F189708148B0E1E9A4E5BD3B9C2C6C7CD
BFC8D0BDCAD2C2CCD5C9D3DCC7CFDAC8CFD8C7CFD8C0CBD4C1CCD6C1CCD798A4B44C596A
586262828A7F8D9590949789AEAA76B1A73DB5A71FC0B027BDA43125DB0800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
59C632DED0C88189987E8EA081909D8D97A0AEB4BA98999DACAAA8ADA38ABCA75EB39820
BA9C0CBC9B08B29212705807533E02796007BA9A13C3A00AC29E0FB38B1AC29C46AC8A54
A082689F8273A28578A58879A88B7BAA8D80AB8D7FB49584B89986BC9E8ABD9D89BE9E8A
C2A491C7AB97C8AD98CBB09ACCB09BCBB19AC8AF96C7AE96CBB199CDB39CCFB4A0D0B4A1
D2B9A8B3A294AEA195AC9F92B5A596D4BEADD8BFAED9C4AFDAC6B2D8C5B2D8C6B2DBCAB6
DBCAB7DDCCBBDFCEBEDFCBBDE0CCBEE3CFC0E5CFC1E6D0C2E5D1C3E4CFC1E5D1C3E7D4C5
E6D2C6E4CFC4E2CDBFDDCABBDAC7B7D8C5B4D8C5B4D7C4B5D3C2B7D2C2BFB9ACB5796C80
6D576DA27587AE5D67AD262AC21416CB1011C71010AF1611D3776BD2AAA0B8A6AE4E3E5D
8245609E212CB31519AF100EAD1010AA0F0EAD1010A90C0DA90C10A7090FA80A119A0F1B
883B4CB9ACB8CDD1DBC2C5D4685F7967455D7F2E418B0E1C950616860C1BA15C6AD0BFC7
C1C6CEC0C9D2C4CDD6C7D0D9C8CEDAC5CCD9C5CED8BECAD6BDC9D5BBC8D2B2C1D09BADBF
9FB1BFA2B0B6A4B0B5B0B9BAB5B9A6AAA86FB4AE5BC6BF72A89B59628D2300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
2ADF14DCCABE8F96A64D5E725D708099A7B0899197ABACB0AFAA9DB2A36AB39B29B89B0A
BC9D05B6990D8F770D7C67187F6501BC9B16C39F07C4A009B69219A58031A7844FA28160
9F8172A08078A48378A9897CAA8B7FAD8E83AE8F81B09382B69987BC9D8BC09F8BC5A691
C9AD98C9AB96CAAD98C9AD98C5AA94C5AB93C6AC92C6AC92CBB199CCB29BD0B49FD1B6A3
D4BCABA39183C4B6A9BCAF9EB9A896D3BFAAD5BEAADAC5B3DBC7B5D7C5B1DAC9B4DAC9B4
DDCBB8DCCABADCCBBBDDCCBBDFCEBCE0CFBDE0CEBEE3D0C1E5D1C3E2CFC1E6D3C4E6D2C4
E6D0C3E3CEC1E1CDBFDECABADCC8B8D7C5B5D7C6B6D7C6B6D3C3B3D5C4B7D3C1B8CFBEBE
9D91A15650695D4F6CB17386AE252FC51115CB1010BA150FC35A4DD7A99EB4A3A4ADAAB6
C2ACB5B37273BE625BBC5F51B85E51B05847AA5246A84E46A54843A442429C383C8B333B
804C56B9B5C0C6D0D8C8CFD5C9CAD77772875C415B7D3045890B1C9307167D0F1EB88C95
CCC8CEC1CBD1C3CDD6C7D0D9C8CFDBC6CEDBC2CCD8BFCCD5BFCDD6BECBD5ABBACE49617C
3B547457708667798587939A88908E969A86A1A587AFB49F7B7B71604D3900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00DAC2B0ABADBA4B5A6D6E7E8C9DA8B38D939AAEAEACB3A886AF9A40B29810B99A06
B7980B9B81135644005441019A7F0AC2A00AC4A005BF9A13A7842C9D7C55997965997C6F
9C7C77A17F7BA4827AA6857BAA8A7FAC8C80AC8D7FAD907FB89A89BE9E8CBF9F8BC3A791
C3A890C8AA94C6A792C4A590C2A58FC3A891C4AC92C9B096CFB49DCCB09AD0B59FD1B7A1
D3BCA7B9A491A59484B3A491D3C2ADD4C0ABD3BEA9D8C3B1DCC7B6D6C1AED9C7B1DCCBB7
DAC9B8DAC9B8DDCCBADDCCBBDFCDBCE0CDBCE1D0BFE3D1C3E4D0C2E4D0C2E6D4C5E3D1C2
E3CFC2E3D1C4DFCFBFDCCAB8DDCAB9DCC9B8D6C4B3D7C6B7D4C3B4D6C5B6D4C1B2D3C0B2
CFBFBEBBB6C54B51735D4D6FBB5B6BB9191BC31710B52113C76D5DDFBCB1ABA4A85B6A7B
BCC5D1CDB7B9C99E96C39A8DC19F95B69B92D6C0BADDC8C7C4ADB0D9C0C7AE99A5564859
817F8F566877B9CDD6C6D3D8C9D0D5C8CDD862637D563A587C23378C071588081588414B
D1C3C9C3CAD0C5CFD8C5CFDBC6CFDCC6D0DAC3CBD7C1CDD6C0CDD6BDCAD5B6C1D42C405D
415776475C726E7E8A8F9BA1929B9C999D989EA2998C91926D6F7C4E404400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00D0B39ABCBCC64F5D70788697707886A7ABAFA4A08CAF9F58AF961CB69907B89908
A0840E5B45005B480E998320BA9A0DC3A005C19D0EAE8C2398794594776694776F967772
9E7B79A5817DA5827DA4827BA9887EAB8B7FAB8E80AE9284B5988BBB9B8CBC9C8BC3A390
C8A895C7A894C1A58FC4A891C5A993C6AD96C9B099CCB19BCAAE99CEB39CD2B8A1D2B8A2
D2BBA6D2BCA7CFBAA6D3BEA9D2BDA8D2BDA9D6C3AFD7C4B0DEC9B7D7C2B0D9C7B3DAC9B7
DAC9B8DBC9B7DDCCB8DECCBAE0CDBDE1CEBEE2D0C1E1D0C1E2D2C3E3D2C2E2D1C0E5D2C1
E1CDBFE3D0C2E0CEBFDDCCBBD9C8B6D8C7B6D9C7B8D7C4B6D5C4B3D6C6B4D7C6B5D5C3B5
CDBFBCB1AEBB4D5674766C88A86066AD352BBD442FCB6E56D49F8CD3B9AEC5BBBC6F7588
525A76907A8CA67378D09C9CEEC3C9BFA3ACAA96A3A999AA937F94877087725B764E3653
6E5D738D8B9CB8BCC6CCD0D5CBD1D5C9D2DB9BA5BD221F427E425A800C198A0C1475262A
D0BFC0C5CCD0C2CDD6C2CED8C5CFDBC5CFD9C6CED8C1CBD4C1CCD6C1CBD5BCC5D38392A7
96A8BEA3B5C49EAEB8A3B0B8A7B2B5AEB6BAB2B9BCB1BABF959AA8514C552FA01A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00C5A285D0CDD36371837A8999747C86B2B2A8A1955DAA9427B09709B59706B0920E
7860094D390377631690760ABF9E09C2A00BB1921C9A7C3C93776093766F9577749B7A7A
9F7B7B9F7C7AA07D7AA3817BA7857DAB8B80AA8C81AB8D83B49488BA998ABE9D8BC1A08D
C4A28FC1A08DC2A58FC8AE97C8AF98CCB39DCDB39FCCB39ECDB39ECDB19CD1B6A0D3B9A4
D3BEA9D2BDA8D2BDAAD1BCAACCB7A4D5BEABDAC3B3D7C2B1DCC7B6D8C3B1D8C2B0DAC7B6
DAC7B7DDC9B8E1CCBBDFCCBCE0CEBEE0CFBFDFCFBFDECFBEE2D3C1E0D0BFE3D0C1E5CEC1
E3CEC0E1CEBFE1CEC0DECDBBDAC9B8DAC8BAD9C5B7D8C4B6D5C4B4D5C4B4D7C5B7D2C0B5
BDB0AE77737C6E6E7EBCADB3CDA599D8A28EDCAA92D4AD97CCAE9EC8B2A6C1B0A7B4A9AB
6E667C7561798F55658E3241A33B4CA64053A34055A03D54A13A529E364C9D2F45962C3F
9331449E4F60AF7787D2AFBDD8CAD5CACAD658627B3B3D58825766751D217D1B1C7E4341
CBC0BEC5CDCFC3CCD6C4CDD7C7CFDAC8D0DBC4CCD7C4CED8C2CAD5C3CDD6C2CAD96E7C95
374F6E657E94687B8A7E8D9689939B8790978B949B969FA79098A748475533A72500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF006ADB50D7D2D3707E8F63748497A1A399956FA59232B0960DB29703B3980C846C03
6E59066B5400A28613B6980BC09F0AB795159A7C2E9074578D716A917572977977987878
9878779D7B799F7E79A98480AA847EA9877EAE8E82AC8C7FB49587B79987BB9D8BBE9F8D
C1A18FC4A694C4A894C9AE99C5AC95C8B19CC7B3A3CCBCAFD0BCAFCBB4A3CFB7A2D3BAA5
D1BAA5D0BAA7D1BBABD6C1B1D9C3B2DAC2B3D9C2B4D8C1B3DAC4B4D8C3B2D8C2B0DBC8B6
DAC8B8DCC9B8DFCAB9DDC9B9DFCDBEDFCEBFDDCBBCDECDBDE2D0BFE2D1C0E4D3C2E3CFC0
E5CFC1E1CDBEE0CEBCDFCEBBD8C8B8D5C5B5D8C6B7D8C6B7D7C7B7D5C4B6D5C3B7D1C0B3
D1C2B7C6BAB1CABEB9CDBDB1CDB9A8CBB6A3CCB6A3C6B29FC2AB9DC4AFA4C7B6ACDDCDC7
B7AAB1776C7C755D6EA066749A38439B2027A1161EA9141DAA0F18A80C14AA0D16A40B14
A10A179A0D1B9211248B2239A96579D9BAC7A9A1AE8E8995958386937370977771AB9D98
C7CBC9C3CCD0C5CED7C3CDD7C9D2DCC9D2DCC6CEDBC5CDDAC4CBD7C2CBD5C4CCDC6C7894
1E335653698257677A8B95A19CA3AD959CA49CA4AB9098A18288983D405066514800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0060CF41DBD1D0757E8E5D6C78949A8B958940AA9515AE9703B19804B399127F6700
A38B20A5890BB8990BBD9E07BA9C13A587298F72488E73668F7370907373957775967775
9A7B789D80799E7E77A3807AA8837DAA857EAD887FAE8C82B29386B59A8AB99E8CBEA18D
C1A291C5A795C7AA97CBAF9CC5AE9CC1B1A4D7CDC8E0DBDAE5DDDCD2C3BBCBB6A6D0B6A4
D2BAA7D2BAA8D0B8A8D1BAAAD9C2B4D7C1B3D9C2B4DAC1B3D9C2B2D5C2B1D5C3B2DAC7B6
DAC8B8DBCABADBC9B8DECABADFCDBDDFCDBDDDCBBBDDCCBBE3D1C1E3D1C1E1D1C1E2D0C1
E3D0C2E2CFBFE2D0BDE0CEBBDDCCBAD5C5B2D7C7B7D7C6B7D6C6B7D5C4B5D1C1B3D1C1B4
D2C2B6CFBFB2D0BEB2D2C0B3CEBCB0CBB9AAC7B6A6C4B3A3C6B0A3C9B5AAC3B1A7C9B8AF
BDAEA7BAACAAA0969D85768394707CA6676CA1484A9F2F2FA12220A41E1AA01C1A9D1E1A
9B1D1C981F22961D268D1A28811C2F894253D3B5BFCFCBD0C9C9CBC7C3C5C2C3C4C5CCCD
C5CFD1C3CCD3C5CDD6C5CFD9C6D2DEC4D0DCC4D0D9C4CDD7C3C9D7C0C8D3C0CBD7AAB9CB
8294AB99ACBDADBBC8A4AFB8A5AEB7A7B2BBB2BDC7B2BDC7ACB5C63F485C6C605D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0057C330DAC9C18488956B757A99976FAA9830B19809B29B06B19806B29710776003
7E6809AE930FB99B07B69B0F9B841B8F76408B715F8E736D8E726F927374947274947273
9B7978997A759D7F77A3837BA6837DA5837BAB8A7FAF8F82AF9183B39888B99E8CBFA491
C5A896C9AC9BCBAF9FC8B09EB9A898A79E96B4B2B3BDBFC4DEDEE0DAD1CBCBB8A9D0B8A6
D1B9A7D1BAA8D1BAA8D2B9A9D4BDADD8C1B3D6BEB1D8C0B2D7C1B0D8C6B3D4C2B1D8C5B5
DAC8B9D9C8B8D9C9B8DECDBCDFCDBEDFCEC0DDCDBCDDCEBDDECEBFE2D0C2E1CFC1E2CFC3
E3D1C2E3D2C1DFD0BDDFCFBEDFCEBFD8C8B8D5C5B6D5C5B6D5C6B7D3C6B6D0C3B2D0C1B1
CEBEAFD0BFB0CEBCAECFBDAFCBBBACCDBDAEC9B7A9C5B4A4C5B0A3C7B4A6C4B3A4BEB09F
C2B5A7BBB0A4CBC4C0DEDCDEB2A8AD9482849177798D6A6BB2827EC18F84C08E85BA8C84
C59B96C09699A0797F9369708E5C67824B5B795462C6C0C5CACFD2C5CDD2C5CBD4C4CDD3
C6CFD6C3CDD6C4CED7C3CED7C3D0D9C1D0DAC2CFD8C1CDD5C6CDD9C2CBD7C1CDD98DA2B4
5F7A935B768B70859376838E828C95848D96858D998C97A28B98A73A485B6E666A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D6C1AE9F9FA1737468908840AB9715B19804AE9608947B02AE92128F760E
715900B4980FB79B118E7D16534816847261886F6B8C726E907471927371977675987374
9A75759977739E7E79A2827CA6857DA9897EA9897DAD8E7FAF9283B6998BBA9F8EB89E8C
BEA290C0A491C2AA95BDA8959A8D7DC3BCB5DDDDDDB3B6B9D7D6D5CFC3BDCDB8A9CFB7A5
D1B7A7D3BBACD1BBACD3BDAFD5BEB0D8C0B2D7C0B1D8C1B1D8C3B0D9C7B4D5C2B2D8C5B7
D7C7B9D5C8B9D8CCBCD7CABCD8CCBDDACEBED9CEBCD8CEBCDDCFC1E0D1C1E0D0C0E1D0C1
E0CEC0DECFBEDFCFBEDDCDBEDFCEC1D8C6BAD5C3B6D4C4B5D3C6B7D2C5B6D2C3B3D3C3B1
CFBFAFCFBFB0CEBEB0CCBCADCBB9ADC9B9AACCBCADCABAAAC8B6A8C3B2A3C2B4A4BEB1A1
D9CEC1C4BAAFBAB2AAC1B9B5B2A7A4AFA59DC1B9B5C5C1BFBAB2B3D9D1D1DCD6D8AEB1B6
C6CBD2949DAD3E4D64AFBBC8B6B3BE857B89635A6D848791C7D0D7C5CFD6C7CED6C3CCD3
C4CDD6C3CDD7C2CCD6C2CED7C3D0DBC3D1DCC1CED8C2CCD6C4CED8C2CCD7C3CEDB6D8096
3852712B4660697F906C7C869AA4AD9DA4AD979BA6939AA389909E424E626B686F2C9E16
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D3B897BDB6A5827C4EAE9F37B4A00FB49B04B29912755B00A88E18B3960D
B39509B89A0C9B851A342F043A3A347E7072856E6F8E72729173749071709677759C7A78
9C79759C7B76A07F7AA5837DA28079A6857CAB8C81AF9183B49788B49888B89B89BDA08C
C1A58FBEA28CC0A790B7A39096897CB2AFA8B7B8B89C9C9CBEB7B2C4B3A7CDB6A5CBB49F
CDB5A2D1B7A7CFB9A8D3BEADD5BFB0D4BFAED5C0AED5C0ADD7C2AFD8C5B2D3C0B1D3C3B6
CBBFB5BFB7ADAAA39AACA49DC2BBB2D3CDBFD9D1BED8D0BEDBCFBFE0D2C2DFCFBFE1D1C2
DFCFC0DECDBFDECDBFDDCDC0DECDC0DAC8BDD9C8BCD6C8B8D5C5B6D6C6B7D3C3B4D2C3B3
CDC0B1CFC2B5CEC0B3CBBDB0CBB9AEC9B7AAC5B4A5C5B3A5C5B3A5C5B3A5C4B2A6C0B0A5
C0B1A7BEB1A6B9AFA6B7ADA4D0C8BFBBB7AFC7C6C2D8DBDCCBCED2B9BCC1BDC5CE495D6F
63768963748B132D4E7993A9C6D4DFCAD1DB949CAB516070BAC9D3C3CFD6C7CFD6C6D0D6
C4CED8C1CDD8C2CCD6C3CDD7C5CEDDC4D0DEC5CFDBC2CED9C2CCD6C4CED8C2CDD692A2B2
7C90A48DA1B2A2B4C2B0C1CAA8B5BEABB7C0ADB6C0B2BBC3A9B3BD5C697B6B6D782EA11D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D0AC7DCBBA8D93842FAB9816B49F0AAC9504B0960F7C62059F8515B59807
B99905B498186257140D13133E3F517D6E75866D6F8E70729272779474799575789A797A
9B7977A07F7BA0827CA5877FA5847DA7867FAB8A81B09084B5988AB69B8BBC9E8FBE9F8F
BC9F8DBFA38FBFA48EBEA7938D7F728E867F918A87817974AA9D91C9B5A4D0B6A3CFB6A4
D3BCAACFB8A6D1BAA8D3BDACD1BEACD1BDABD8C1B1D7C1B1D8C4B2D9C6B5D5C5B6BDB2A8
978F899E968EA89F959F958F807B789C9991D1CCBDD7CEBCDDD1C0E1D0C2DFCEC1E1D1C4
E0D0C2DFCEC0DDCCBEDDCCBFDDCDBEDBCCBED8CCBCD1C6B5D5C7B7D2C5B4D0C3B4D1C5B7
CEC2B6CDC1B4CDC1B2C7BAABCEBFB2CBBBAEC2AFA3CCBAACC9B7ABC6B3A8C6B4AAC6B3AC
C2B1A9C3B5AAC5B9B1B8AEA6DDD7D1D2D0CCB0AEABBFC2C3A8ACB294969CAFB4B96B7988
6A7788BFCBD998AABD99B2C5C0D5E2C4D3DCC8D6DDA7B8C0B9C8D1C3D0D7C6D0D8C6CFD6
C5CFD8C3CFD7C4CDD8C3CCD7C3CCDBC2CEDAC3CDD9C4CED8C0CBD6BFCBD7BFCCD79EADBB
7A8EA36F879B74899A7A8D9A818F9987939C89929C8089927F8895536376646A7963493D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00C79A58C9AF61A9951CAE9B0BAB970D8B7701A38C11866D0C8F780DB59908
B5970999852128290E0711294A4B627F6E76866D6F907273917274927476947677987879
9A787A9D7E7D9E807DA1837EA48580A88883AB8983AE8B84B19389B89B8FBC9E91BD9E91
BA9A8CC2A392BFA28FBEA5919785779A8C80A59589AE9C92A29082CBB6A5D0B6A5D1B8A8
D2BCAACEB8A7D0B6A7CFB7A7D1BBAAD6BFAFD7C0B1D5BEB0D9C2B4DAC5BAC7B8B089817B
ACA49EC8BEB3C6BAACC4B8AEA19996767471A8A89ED5CFBFDACFBEDED0C1E0D0C4E1D0C6
DFCEC4DFCEC2DBCCBEDACCBEDACCBDDBCDBDD6C9B9D3C8B8D2C6B5D2C6B6D1C5B7CFC3B6
CFC1B8CCBEB4CFC3B7CBC3B4CBC0B5CDC0B3C9BBADC9BAABC4B2A4C4B2A6C2B1A7C7B5AB
C1AFA5C6B8AFCFC2BBB9AEA6BBB1ACB2ABA8ACA8A3ABABA6CECFD0C3C4C7C1C3C7D1D7E0
B1BDCA9CADBAA8BDCF3F607C99B8CFBFD2DEC2D2DAC2D1D7C6D3DBC5D1D9C7D0D9C6CFD8
C6CFD8C3CFD7C3CED7C2CED8C1CDD9C1CDD9BFCBD7BFCDD6C1CED7C2CCD7C0CBD8A6B4C6
3F5571435F79455E7081929F94A0AAAAB5BBA3ACB499A1A88B94A05666795C66756A554C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0065CE21C8A83AAF9910AA980C8172056B5B009B87147E6A0E79660BB2980D
B59B1F867A390F151B08133653536C7F6F77866E718D707391737691737596787A98797B
9B797CA28081A17E7DA2827EA2857DA98B85AB8C86AF8E87AE8F85B5988CB79B8DBA9E90
BEA290BFA18DBC9F8CC0A594978274B5A596B7A796A89686B3A090CBB6A3C9B4A3CAB5A4
D2BDABD4BDACCFB7A7CEB5A6D3B9AAD4BDADD3BCACD2BDAED8C3B6D7C4BD9C918F86807D
B7AFA9C7BEB4C7BEB3C7BBB4ABA0A07E7C7B888880D5CFBFDDD1C1DED2C2DECFC1E0D0C3
E1D3C6DDCEC1DECEC2DCCBC1DDCCC2DCCCC1D8CBBED2C8BBD2C8BAD2C5B8D2C5B8CFC3B6
D0C4B9CCBFB6CBBFB4CBC2B6C8C0B3C6BDB3C4BAAFC3B8AABBAB9DC3B2A4C2B2A7C0B2A7
C1B1A7BDB0A5B7ABA3B5ACA5AEA6A2CCC9C8D2CFD4AEACAFD8D4D8DBD5DAB2ABB1B4B3BD
6371872F44617F92AA203D5B6E91A8BFD5E1C0CED697A5AAC8D4DAC6D0D9C7D1DAC5D1D9
C5D0D9C0CDD6BFCBD6BFCCD8BDCBD6C1CED7C2CDD6BDCBD4C0CED6C1CED6BFCBD7A4B2C3
879BB271899F95ACBAA1B2BBB5C2CAA8B6BCACBAC0ACB8BEA7B2BD697A8C54627270625E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00C39F19B39B0C95840A5A4E005143009A86168C750B8D7609B09712
B49F3D877E610A112B09123A605F757E6E75856E708C6F7491717896767C97757B9B787E
9A76799E7A7B9E7C7AA1807BA68883A88B87A98B86AA8A84AD8D84B4978AB89D8FBCA193
BEA290BFA28FC0A391C2A595AC9284998676A09080A49081C4AE9EC4AFA0B4A196AC9C8F
C7B4A4D1B8A7D5B9ABD3B8ABD3BBABD2BCABD3BDAED6C2B4D8C3B8D7C3BD877B7B878383
AAA6A3B8B2ACBCB6B0B0A9A79894967A7B7B898981D3CCBCDBD0BEDED2C1DFD0C1E0D1C3
E0D3C6DDCFC1DECEC1DACABFDAC9BFD9CAC1D4C7BED5C8BFD1C5BAD3C6BCD0C2B9CFC5BA
CBC1B7CCC2B9CDC0B7CDC1B6CAC1B3C4BBAFC2BAAFC2BAAEC1B6A8C0B3A3BFB1A6BBB2A7
BBB0A7BAB1A7B3ADA8CDC9CB9E96A3978B9FA48DA4936F83B58995C2949CB88F93B8A0A3
9292A24C5A71A6B5C5A3B3C49AB2C3C2D4E0C8D4DBBCC7CDC7D2D8C7D2DBC6D0D9C6D0D9
C2CFD8BDCBD4BFCCD5BDCAD3BDC9D5C0CCD8BFCAD6BCC8D4BFCBD6C0CCD6C1CAD7ACBACB
7D92AB758FA46E85957D8E9A7E8C957F8B94838E97808A947D8692606F814D5E6F786F6C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0092B80DAF9B0F7B6F025D5201796705A7910DAC9509AD960EB19C27
92844368665F0B15380A163E6765797D6D7189727390727794737D96747D99767B987478
9B797C9C7B7A9C7B79A38481A48784A68886A98984AD8B83B18F84BB9A8EBC9D90B89B8C
B99B89C0A18DBFA28EC0A38FC6A796BB9F8FB9A190C3A999C6AD9CB9A597A4948CA7988F
B8A597D0B7A6D7BCABD1B9AAD0BCAACFBDAAD3C1B0D6C3B4D6C3B7D4C0BA897C7B827D80
8F8E919896999998999290937E7F837475749E9B91DAD0BFDDCFBEDFCEC0DECEC1E1D3C4
DFD2C3DDD0C2DCCFC0DACCBFD7CABDD4C8BDD5C8BFD3C6BDD2C5BCD4C6BED2C4BDCEC3BA
CDC4BBCDC3BACFC2BACDC0B6CDC1B6C8BCB3C4B8B0BFB5ABBFB4AABBB0A7BAB0AAB7B2AC
B6B1B1ACA7AE8D8595826E888253719A4C6A9E334EA4263CA21C2DA21F2D9F2C35AE5B63
E5BCC7D7CCD99096A3ACBBC87D94A7B9CFDDC9D6DFC8D2D9C8D1DAC4D1DAC4D1DAC4CED7
C3CED8C0CDD5BFCCD5BDCAD3BCC9D2BFCDD6BFCDD8BECBD4BBC7D3C0CAD6BFC7D8A1AFC3
213A594D6986536D8470839395A2ADA2ABB6AEB7C1A5AFBA868FA13E516A44576D7B7778
2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005FD00AAB9A13706200716101A08B0DAE9706AE9604AB9512C3B35E
8A81638A8C941922481019426F697D8572758D747590737792737A94757A95787B997B7E
9A7C7E9B7E7E9C7E7DA28582A48683A58684AA8984AA8981AD8E84B7978CB6968AB7998A
B89B8ABDA18CBEA28CC1A58FC3A793C3A694C5A996CAAD9AC8AE9BB9A4959E8E83A9998D
C3B09FCCB49ECFB5A0D3BDA9D0BDA9D1BFAAD5C4AFD4C3B2D2BFB1D5C2B6AB9B96776E6F
7C7A7F7F7D847E7D81797A7D727170847E76C5BAADDBCEBDDFCEBFE1D0C2DECFC2DED0C3
DACDC1DACFC1D9CFC0D9CDBFD5C8BCD4C7BECFC5BBCFC5BBD0C6BBD1C6BDD1C4BDCEC1BA
CDC2BCCDC2BCCDC3BACAC1B5C9BFB5C6BBB3C2B8AFBFB7ADBFB7B0B9B2AFB4AEB4A49DAB
81728B7C5C7B925576A54663A5243BA80F21B20A19B40814B60611B60711B00811A00C17
A2303FB26D80523D5372798E5D7288ACC1D1C9D6DFCAD4DBC6D0DAC5D2DCC6D2DBC5CFD8
C2CCD5BECBD4BECBD4BBC9D2BCC8D4BDC9D5BECAD6C1CBD5C1CBD7C3CDD7C1CAD7B7C4D5
374C68839BB48DA4B7A0B1BFB3C0CCB9C3CFACB8C4B0BCC89FADBF2D415E344663797A7E
32A72200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005DCB0D9A8409776703907D0EAD9609B09803AE9504B09920AA9C5C
8B857A64677809143C182047787085856F798D74788B6F749173798F717594787B957A7C
997B7D9C7D7E9D7E7D9F7F7DA48482A58482A6847EA8887FAC8F85AF9388B29589BB9C8F
BE9F8FC2A691BEA48DBDA38DBEA38EC7AA95CAAB97C8AB97C8AE9AC6AE9ABEA896C0AD9B
CFBDA8D5C1ABD6BFABD4BEABD0BEABCFBEA9D2C2AFD1C1AFD2C1B1D4C2B3D1BEB39A8B85
7E757580797A8A848298908B9B9188C0B2A5DBC9BDDDCBBEDECDC0DECEC1D9CABDDBCDC1
DBCEC2D8CCC0D8CDC1D7CBC1D7CBC2D4CBC1D0C9BDD4CBBFD1C7BCD2C7BECDC2BBCEC3BD
CDC3BDCBC2BBCBC2BBCAC2B8C9C1B8C4BDB7BFB8B5BBB6B5B5B0B69E97A57D6B85815978
A05574AB3B58A71A32AF0E1EB70A15B9080EBA060EB6030BBA030DBB050DB70309B2040B
AB08169B16269B5062907E8DC2CAD6BFCED7CBD5DECAD4DDC7D1DBC6D0DAC7D1DBC5CFD9
C1CDD6BECBD3C0CAD3C0CAD2BFCBD4BDC9D4C3CDD9C2CCD6C0CDD6C0CDD6C0CBD6BAC8D6
74859A899EB37E94A47E909C8C97A387919B848E9A848E997A83962B3C582F3F5B74787F
4C7D3500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6F03806C02A18D0EB09905B09702AE9404AF9929978A58
B9B6B45D637A07133D22294F796F82836F788B737A8A6E738D6F749072749376799A7B7F
99787D9D7C7F9E7C7DA07E7DA28281A88886A6847EA88680AC8C84AF9186B09387B79A8A
BDA08DBCA18CC0A791C1A590C1A590C6AA95C6AB95C5AB93CBB09AC8AD98CAB19CCEBAA5
D0C0ABD1BFACD7C3B1D2BDACCCBAA7CFBEABD2C0B1CEBCADCEBCADD1C0B0D9C6B6D2BFB2
BBA89FB0A096C1B3A8C9BAADD3C3B3D8C7B8DCCABDDBCBBEDBCBBEDBCDC0DACCBFDACBC1
DACDC4D8CBC2D5C8C0D5C8C1D6CAC4D5CCC4CFC9BED1C9BED1C9BFD0C9BED0C7BECDC4BC
CBC2BCCCC5BECAC3BFC4C0BBC2BFBFBDBBC0B3ACB990859980668196637EA9526EAC324A
AE172AB70E1CBA0A15BA0B10BB0C0EB70D0EB30C10B10C13B30710B7070EB9050AB7040B
B5040EAE09149A1F2AC0868F9E959EC7D1D7CFDAE0CBD7E0C5D2DBC5D2DAC5D2DBC3D1DA
C1CED7BFCCD4C2CCD4C0CBD1BDC7D0BFCCD4C4CED8C4CED8BFCBD6C0CDD8BFCDD9A6B8C7
6D839B27445D6D8A9F7A909F98A5B29FABB4A9B2BCAAB2BE9CA3B7303F5E293A56697076
6B5B4F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6C02A38E0BAC9706B09A02B09804AB930AAA97379F9573
8F8D925C617B08133D2C33567A73828370778870768B6E768E6F7592737994757B99787F
9D7C819F7D81A07E7FA28081A28281A38380A6837DA9847DAE8B83B6948BB4948AB6998B
BD9F8EBDA08EBDA28EBFA390C3A694C5AA96C7AB96C5AB95C8AE97CBB19CCDB4A2CDB8A6
D1BDACD3BFAED3C0ADCDBBA7CFBDA8D2BFADD2BDADD3BDAED1BFAED2C3B0D6C6B4D5C4B4
D3C1B3D9C6B7D9C8B8DBCABADAC9B9D8C6B7D9C6BBDAC9BCDACABCDACABCDACBBDD9CBC1
D5C7C0D3C8C2D6CBC5D6CBC5D8CFC8D3CDC8CCCBC8CBCAC6D1CAC4D3C8C0D4C6C1D1C2C0
CEC1BFCBBFBEC8BBC0BAADB7A392A294788E9B6C88A9607DAA4059A72134B11523BB121B
BC0F15BC1113B71311AF1812A91F17A72B23A73733A5393DA2252EA91019B4060DB6040A
B60208B40409A50A11A138417A5863BCC3CBCCD8E0CEDBE1CCD8DEC6D4DCC2CFD7C4D0D8
C5D0D9C2CCD6C0CAD3C0C9D2BEC7D2BCC8D1C4CED7C2CFD6C5CFD9C2CFD9BDCAD6A4B7C8
6C849D435F7887A1B49AAFBCA1B0BCB1BEC9B3BFCCAAB5C3A1ACC0384B692337535E6A6D
6D635600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00709702AD9508B09B05AC9905B39F19AB9927998B42C8BFAA
7B7A818A8FA708143A363E5B78727D816E758970758F7177906F7795737B97757C99787E
98787B9A78789F7D7DA07D7EA38182A28180A7837FAB857FAC8880B3928AB7998FB99C90
C1A192BFA18EBFA38EBFA38FBFA593C6AC98C7AC98C5AA94C8AF98CEB6A1CDB6A4CBB4A3
D4BEADD0BDACCEBBA8D0BBA8D2BDAAD3BDABD0BBAAD4BFAED1BFAED2C1B0D5C4B5D7C5B7
D4C2B4D7C5B7DBC9BCDECDBFDCCBBDDAC8BADBC9BBDBCABCD9CABDD8CBBCD7CBBDD3C7BC
D3C5BFD4C9C3D4C9C3D5CBC4D3CBC7C5C5C78E9CA9A4B6C5CAC8D2D1B9BCDFB8BBE2B3B8
CF9BA4C08896B4768AB66A81B85A72B64359B42C42B31B2BBB171FBC1315BC1716B51813
AE2019AE3328B54D3FBE6F5FCA8D7DC89788B68F8A6D505B794E639A3849A70C18B3040E
B60309B50309B0050E9A101899545FB5ADB5CDD6DDCFDAE0CDD8E1C7D5DEC6D3DCC3CED7
C6CED9C6CFD9C0CAD3C1C9D4C1C9D5BFC9D1C0CDD5C2CFD5C5CFD8C5CFD9C2CDD9AEBECE
7C8FA6748A9E8B9EAD7F909D808D9A7F8B97808A987E88957683932F405E24395457646B
6C665B16CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF005AC906AF9606AC9803AC980FAE9F34B6AA5EA2986AC1BCAF
7879808389A20711393D42607B727E846F768C727890727A92717A937179926F76947177
9874769A76769E7A7AA17D7FA58384A78584A5827FA9857FAD8982B3948BB79A91B89B91
C1A095C3A294C0A38FBCA18DBCA491C2A897C8AB9BC8AC98C7AD98CBB29DCAB29FCCB4A3
CFB8A7D4C1ADD4C2AED2BEAAD0B9A8D0BAA8D1BEAAD3C1ADD0BFABD0BEAED3C1B2D7C4B8
D1BFB2D5C5B8D8C7BDDACABDDBCBBDD7C7B9D8C8BBD7C9BDD9CCBDD9CDBDD5CABDD4C8BE
D9CBC3D9CCC5D6CAC4D5CAC4D4CBC7CBCCD065788F446287AFB7D4957182A95D6CB44F5E
B94656B83D4FB63347B42437B81F2FBD1D29C01A22BF1A1AC01D17B72015AB261AAE4032
BD6A5ACE9182C99B8CC1A293B59F91B29F91B1A19A8D86922D2745935A75941020AE040F
B4010BB6030CB1030CA50A119F4048BAA3AACED7DECCD9DFCED8E2C5D2DBC6D2DDBECCD4
C0CCD4C6CFD8C1C9D4C0CAD4C2CAD5C2CCD5C4CED7C4CED7C2CFD8C4D0DCC2CDD8B0BFCF
435A756E8BA36E88998599A59AA9B594A1AA96A2AE98A4B08D9AAA293B5B2A3F5B54616A
69645E2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE503AE9603AB990BA69625B1A761A8A37CADA99595938F
8E8E9859617B08163C484E697C737E826F768971778F737A92727A917078947278967378
9874769E79799E7A7BA07C7FA38183A58484AA8785A78481AE8C86AF9188B79A90B79A90
BF9E95C09F91C3A393C0A292BCA090C2A896C7AB9BC9AD9CC6AB97C9AF9BCBB39FCAB3A0
D0B9A6D5BEACD2BFABCFBCA8D0BAA9D0BAA8D0BCA9D2C0ACD1BFADD4C2B2D6C3B4D7C5B7
D3C2B4D7C6B9D8C7BDD8C9BED8C9BBD7C9BAD4C6B9DACBBFD8C9BCD9CDBED7CCC1D7CDC3
DBCEC6D9CCC6D6CAC5D7CBC7D6CCC9D1CDCDB5BECC5E73945E6C93A392B1A56C829E4253
A6303DAA2834B62834BB252DBB2329B72523B62A24B33228BB483BC76858D48677D69E8D
CBA595C2AA9CB4A397AFA497AAA195AAA294ACA29BAAA8B0393E5E6D54768B2436AA0A16
B5040EB5030CB2020CAE081098242D9C7481C1C9D5CBD9E1CFDAE4CAD7E0C5D1DCC0CED7
C3D0D9C6D0D9C5CDD8C1CAD4C3CCD6C2CED7C5D0DBC6D2DDC3D0DCC2CFDBC1CED9BBCAD9
3F56735C7D994F6E8295AFBD99AEBD9CAFBFA2B5C7ACBFD0A2B4CB2035582D435F5B6870
645F5C32A61F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE603B19B09AA9A1FACA55EA9A990969693BDBEC086878C
ACAEBA515C7519294B5259707C737E806E75866F768B71768D707691727797757B9A767B
9A76799C7878A17C7E9F7A7EA38081A78684A78784A78783AC8B84B09086B6998EB99C91
BC9F94C2A297C09F93C1A094BFA090C3A592C5AA98C5A999C8AD9CC9AF9DCCB4A0CBB5A0
D2BCA8D7C1AED0BBA9D0BDABD1BEADD0BCACD3BFAFD4C1B2D4C2B3D4C1B2D6C2B4D6C4B5
D2C1B3D7C4B8D9C7BBDBCBC0DACBBFD9CABCD4C6B8D8C8BDD7C9BED6CBBFD8CEC4D6CBC4
D8CBC4D8CAC6D9CCC9D7CBC9D4CAC7D6CCCBD0CACBC5C5D29BA2BA717792857C94A98B9D
B3828FBA7B86BF767CC87777D2827CD68E81DC9C8EDBA597D7AC9ECDAE9FC9B3A7C1B3A6
BAAFA4B7AEA4B2AAA1ADA69BAAA398AEA59CADA6A0D2D0D27F859F3131588D4D65990F1B
B1050FB2010BB2010BAF040D970C179D5B6A9696A6CAD9E2CDD9E2CEDAE2C8D6DEC6D4DC
C2CDD7C4CFD9C3CED8C5CED9C4CDD9C1CDD8C1CDDAC3D1DDC2CFDDC2D0DBC0CFD9BCCCD8
8699B453718D7799B493B4D17796BA5E78A25C73A0586F9D4B6293102554364C695A686D
5A595236AE2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CE07AE970BA89C3AA7A5809EA3A09EA2A8A3A6AD94989E
818590535C740A18395D62777D727D816E75856C748A70758F727794727899747B99737B
9C777C9D787A9D787AA07A7CA4807FA68480A6847FA6847EAA8981AF8E84BB9C91BA9C91
BB9F93BB9F93BA9D91BC9E91BFA190C4A491C8A996CBAF9ECCB1A2CEB4A2C9B29ECBB5A2
CFB9A8D3BFAED2BFAFD3BFB0D2BDAFCEBAACD1BDB1D2BFB3D2BFB2D0BCADD4C1B3D4C4B4
D2C1B3D5C2B5D8C5BADAC9BDD8C6BBD7C5BAD6C6B9D7C9BCD6CABDD5CCC1D8CEC6D7CBC5
DACCC6D6C9C4D5CBC6D3C9C5D6CBC8D4CAC9D0C8C6D3CBCACCC6C9CAC8CFBEBEC7B2B2BD
B1ADB5B3AAB0B8AAADC4B2B2D2BFB8CEBDB2CCBCB1C6B9AEC4B7AEC2B8AEC1B6AFBCB3AB
B8AFA8B8B0A7B4ADA3B3AEA2B4AFA4B3ADA4A8A39DAEAAA79D9EAE2A345872577A861A2C
A70612B0010BB2010CB0030CA309149B3E48CEBBC3CFD9E0CDDAE3CFDBE3C9D8E1C6D4DC
C6D1DBC3CFDAC5D2DBC5D2DBC4CED9C1CCD7C3CEDCC1CEDAC3D0DDC1CFDABDCDDAAEC0D2
8297B558749A31507E132F68031C5E01165C01155E00125B02145C011452273E63576871
5F615A5F4E3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CD08B29916AEA24F999A82A6AEAFB2B8C094979FABAFB6
8286926B748D0C1A396468797B6F79806C74886E778E727A92727A9371779571779A757C
9C757D9A75799C797B9E797BA27F7EA78280A5827FA5817DAD8883AF8E86BC9D94BB9D93
B99C8FBDA191BA9D8EBB9F90BFA291C5A593C8A896CAAB9DCBB0A1CCB2A1C9B19ECEB8A5
CFB9A8D3BEADD5C2B2D3C0B0D2BEAECFBCADCEBBADD2BFB1D0BCAED4C1B2D4C2B5D3C1B4
D0C0B2D1BFB2D8C6B9D8C7B9D7C7BBD6C6BCD6C8BCD8CCBFD5CBBED4CCC0D5CBC3D5CAC4
D3C7C1D0C6C1D0C8C4D2C9C5D2C7C3D2C8C5D1CAC7D1CAC7D2C9C7CBC5C2CBC8C4CDCCC7
CBC9C4CBC8C4C9C3C0C8C2BECBC3BDCAC4BBC8C0B9C5BDB6BFB7B2C0B9B2BFB6B3B7B0AE
B7B1ACB9B0A9B7AFA6B4ACA4B2AAA2AFA8A0ACA69FA9A5A0B0B0B65864833839648F4A64
9A0E1CAE050FB3020DB2020CAA05108E171EDBB0B4D6D6DACED9E2CBD8E2C9D7E3C7D5DF
C6D3DDC3D1DBC7D4DDC5D1DBC7D1DCC3CEDAC7D2DDC3CFDBC4CFDBBDCDDCB9CCE48CA5CA
29447807216000175F00125E01125F01125D01115D01115C01115C011359031749394C61
5C62615F544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0030E504B0971DA39A4E9799819AA2A39FA5ADA0A3AB9F9FA8
7A7B89565E7814213D6B6C7B7B7076816D76876E798B6F7A8C6C769573799874799C747B
9A70789E767B9E7B7BA38182A17E7EA4807FA78382A98684AB8784AF8D87B4968DB4978C
B4978ABB9D8EBD9F90C3A597BEA090C3A491C6A896CCAFA0C9AD9FCCB2A2C9B1A0CDB6A5
D0B9A9D2BDACD1BDADD6C3B3D1BEAED2BDAFCFBDAED3C1B2D2BFB1D3C0B4D1BFB3D5C2B7
D4C0B4D2BFB3D7C5B9D7C8BBD7CABED4C7BCD7CABFD5C8BDD1C7BCD4CAC1D3C8C1D4CAC3
D3C8C1D2C8C4D1C8C5D5CBC8D3C8C3D1C7C4D0C8C6D3CBC9D2C9C7CBC4C2CCC8C4CCCAC5
CAC9C5C7C7C4C6C4C3C4C1C0C5BFBBC8BFBACABEB9C3B9B2C2B8B4C1B8B6B8B5B99FA7B2
ADAFB8BDB0B0C0AAA7C3A8A5BEA29FBCA4A1C4B5B0B5AFABBEBEC0B1BCCF25325D806285
8B1B2CAB0913B2020BB1010BAE040F970B17BF7880DFD5D8D2D9E1CDD8E3C8D4E2C5D3DE
C4D2DCC3D1DAC6D2DBC6D1DDC5D1DEC4D2DDC6D3DDC2CFDBBFCDE2ACC2E06984B2142F6F
01196401166601126300115E000F5C01115C00105901115901105B011258010F4A0E1D41
545E655F594E15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00B09938908D58A6AB9DB1B8BC959AA4B2B6C09E9FAA
9291A14D546E2029447371807D6F7583717786707A876C778F707997757C9570759B7279
A1777CA47B7D9F7A7AA17E7FA38081A48180A48180AA8684A98581AD8B85B4958DB79990
BD9C93B9978CA9877BBE9B8FC1A092C0A291C4A997C9AD9EC8AC9CCAB09FC9B2A3CDB6A8
CAB5A5CFBBABD6C3B4D3C0B2CFBBAED0BBAFCEBCAECFBEAFD1C0B1D2BEB2D2BFB3D2C0B3
D4C1B4D2C0B2D6C5B8D4C5B9D4C7BBD5C8BCD5C7BCD4C7BCD3C8BED3CAC0D2C9C1D1C9C1
D5CAC3D3C9C3D1CAC5D2CAC3D2C9C2D1C9C3D4CBC8D3CBC9D1CAC6CFC9C4CBC7C3C9C9C8
C0C7CEB7C3D0A6AEC0AB9FB0D3AFB9DCADB2DCABAED8ABACD1AEAFC8B0B2B1A9B7384768
8182A1A47787B56670BB6066B75861B86269D6A0A2BCA9A7B0ACABA9AEB75563843F3D69
8C3E57A10F1CB3050FB1010BB0040EA3081298363FE7CDD1D1D6DCCCD6E0C7D2DFC6D2DD
C4D2DBC4D0DBC5D0DCC3D0DCC3D2DEC5D3DEC1CDDBB9CBE096AFD3314D84031D64011868
011265001263001160011360000F5A011159011158011058000F58000F56010E4D020F3D
3E4C5B5D5C532BA01700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00CCB67A80816E8690939FA5B0989DA8A3A7B29698A4
8687974A4E68252B45756F7E7B6C738573788670788A6F77907078927077977278987378
9F777CA078799E7978A37F7EA58181A48180A88584A88382AB8684AD8A85B5948DB79790
BD9C94BA988EB69489BD9B8DC2A291BB9F8DC0A593C6AB9ACAAF9DC8AE9CCCB4A5C9B2A5
C9B5A7CFBCADD3C2B3CFBEB1CBB9ADCEBBAED0BEAFD0C0B0D3C3B3D2C1B2D2BFB2D2C0B3
D4C1B5D4C1B4D7C6B8D9CABCD2C7BAD5C9BDD3C5BBD3C7BDD2C8BFD1C8C0D2CAC2D3CBC3
D3C9C3D2C8C4D0C9C6D1CBC6CFCAC1D0CAC2D5CDC7D3CCC7D1CCC4CEC9C2CBC9C3BFC6CD
7C94B0485D82867CA0B46F8CB8495BB3343FB4343EB73E47BE535CC77279D59CAC7D6587
654B7194455EA61D2EB41521B91320B11721AA3E43CFA4A1B5ACA9ADAFB293A1B6202E5A
8961838E1428B00916B4040EB1010AAD061090121DCF9CA4D5D2DBCCD4DEC8D2DDC7D4DC
C4D2DAC1CED7C3CFDCC2D0DDC1D1DDC0D0DEBCCEE57F97BF17346F011A64011667011365
01126200116000115F01135D011156021554021553011154010F5502125502114E010E3F
1E2D435C605B32AA2300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D3BB979297958896A199A3AEB3B8C39DA0AA9597A1
9294A1474E6132364C766D7B7E6E748571778870778C6F76906F75957177977177997378
9D767A9C74769D7676A27B7C9F7C7BA3817EA88584A88383AC8685B18A88B4908BB7978F
BB9C92BD9D91BE9E90BE9F8FBEA08FC1A493C0A594C6AB9BCBB0A1CAB2A1CCB5A5CDB5A7
CBB5A7D2C0B1D3C2B4CFBEB2CCBAACCCBAABCCB9A9D0BFAFD1C0B1D1BFB0D0BEB1D4C2B6
D4C1B7D3C1B5D4C4B6D6C9BDD3C8BDD3C8BFD2C6BCD0C6BDD1C7BFD0C7BFD2CAC1D4CAC2
D3C9C2D2C8C5D1CAC7D1CAC7D0C8C2D1C9C2D2C9C3D2C9C6D2CCC8CFCAC5C8C7C59FB2C5
2A4C797681B1AD779BAC233BC61927CA161EC9141CC6141BC01921B31C26AA2A38B55167
AC5B74D16C7DAB1421C20E15CA0E16C40F15A41619DB9794C3B3B0AAACADC3CED94A5A7C
584E7689314AA60D1BB4060FB3020CB0040F9D0A179F505BDECFD7CCD2DBCAD4DEC8D3DC
C6D2DBC4CFD8C4D1DAC1D0DCBECFDEBACFE5738CB60C2768021967011462011161011160
00115F00135D03165A0217530D1F4E28385F3C4D7711235B06195025386319275104123D
0B19365A6468568E4700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D4BC9DA7ACB0768593949EACACB2BD9899A39697A0
9096A13E4A5B42485A766D7A7F6D76836E778970788C6E73906E74926E759772789C757A
9D757AA2787B9F7678A07A7BA48182A4807FA78282A88282AA8382B38B88B28E89B6948E
B5968CBA9D8FC0A395BC9E8FBE9E8FC3A495C2A698C9ADA0CBB0A2C9B1A1CCB4A5CDB6A7
CDB6A8D2BEAFD1BEB2CCBAADCEBCADCCB9A8CBB7A6CCB9A9CFBDAFD1BEB0D3C2B3D2C2B6
D5C3BAD4C3BAD0C0B6D5C8BED3C7BED2C8BECEC4BBD0C6BED2C9C1CFC7BFD1CBC2D5CDC4
D5CBC4D7CFC8D4CEC8D2C9C6D4CAC5D2C8C1D5CCC5D3CAC5D1C9C6CECAC6C9CACC7A94AF
28497BAEA9D7A1506CBF1C2ACD121ACF1015CE0F16C71414C22523B73337A82E3D9F2539
9D2035C53E4DBE1924C91017CC0D14C70D12B10F13C15D5FD1ADAEAEA7A8A8ACB17E8CA2
263158865875911224AC0511B0010BAD020CA60713861A25DBB7BFCDCFD7CAD3DDC6D0DB
C5CDD9C5D0DAC5D0DBC4D2DFBBCFE87590BB0B2669011A6801146501126000115E00125E
02155B051D572A416D4C60807E8DA48492A6627392061B48223A606A7C8F6B74882B3552
04112F4755606A625A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D1B498BDC1C7808F9F9AA4B39CA0AC9DA0AAA5A8B2
6F7886233247484D62796F7C816E78836D77876E788A6E74907176906E74967278997279
9A7176A2797AA07879A27E7FA27E81A57F81A27B7BA98181AA8382B08A87AF8C86B6948E
B9978FB99B91BFA096BF9F94BF9F93C7A89BC3A79AC8AC9FCAAFA0C6AD9CCCB5A5CAB4A4
D0BAABD5BEB1D6BFB1D4BFAFD5C1B0CAB5A5CEB9A9CEBBACCEBDAFCEBEAFCEC0B0CFC1B4
D1C0B7CFBFB7CEC1B9C3B8B3C8BEBACDC4BED1C7BFD1C7BFD3C9C3D0C8C1D3CCC4D3CBC3
D3C9C2D5CDC5D3CCC4D4CCC5D5CCC5D3CAC3D6CDC8D5CBC8D3CAC7D1CCC9C9CACE859DBB
254579A4A0CDA85671BF1D2ACF1119D21115CF1015BC1713E87972D49494A26F7F965972
943C579D2037B51321C70F18CC0C15C50910BD0C13A51F25D09092B9A8A8A8A7AABFCAD7
3043666253787E2037A10916AC030EAB010AA8040E8F0C18BB7A85D6CED4C7D2DBC6D1DB
C6CFDAC4D1DAC4D0DCC2D1E87A93C00A276D011A6D01176A01146401165F01175C021C5B
0C255D6C8BB289A3BDA5B9C9ADBFD08CA0B7324871041C475A71897A8A92727B83606878
0B192F36465263625C13CD0900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C6A785BABCC18E9CAC9BA6B5999EAA9EA0ACAAAFBC
59667C091A3752556B796B77806D76826C75856D768970778F73789472789671789A727A
9A747B9A7477A17A7CA67F829F7A7DA67F81A57F80AB8385AA8283A07A79AF8D89B2928C
B99A94B89991BF9F97BE9F93C1A294C3A797C4A898C7AB9CCBB0A1CBB2A3CAB3A4CDB7A6
CAB5A5D4BDAFC2A896BCA38DDCC6B1CBB5A5CDB9A9CCBBABD2C3B4CDBEAFCEBCAFCFBFB3
D0C0B8C1B6AEA59A92ABA19CA99F9D9E9794C8C1BBD1C7C0D1C6C0D3C9C3D3C9C3D1C8C1
D3CAC4D2CBC4D3CDC5D3CBC4D4CCC5D4CCC8D6CECCD4CCCBD2CAC8D0C8C7CDCACDA7B7D1
26467A6974A7B37797B41F2FCE141BD11014CD1013B81A18EB948FCEB1AEC1B6BBA49BAB
6A547184506F9E324BB31524C50D18C60910C10A10AE1117C76B6DE6C9C8A6A5A5B6BFC6
647690272D547F4260920E1FA70411A9030DA7020B9B09148D2F3DDEC6CDCAD0D9C5D2DB
C6D1DCC5D2DCC1D0E294AAD0142F72031D7201186F011569011763021E5C2745737591B7
1E3B617D9DB95E798EA3BACD7B95AD4C698F021A4A1B3456697D897182866F7C7F6C787F
222E3E2D3B466B6C682FA51F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C29C75C0BCBF7D89998A94A2A0A6B2A5A6B2828897
29385408163758586D7769747D6971806A72846B74886E758C6F77916D7799717B9C777E
9D7B819B787DA07A80A47B81A0777C9E7779AD86899F777AAE85889D7675AD8A84B3938C
B5958FBF9F98BE9D95BE9F90C0A290C2A593C4A896C1A593C6A99AC5A99DC6ADA0CBB4A5
CFB8A8D5BEAEC5AA97C9AF99D9C1AECCB6A5CBB6A5CDBCACCEBFB0CEBDAFCFBEB1D2C1B7
CCBEB7A39892C2B8AECFC4BACCC1BCB1ABA7B0ACA6D1C8C1D1C6C0D0C6C0D5CBC5D3CAC4
D3CEC8D0CCC7D2CEC8D1CCC6D1CAC4D4CCC9D5CCCBD3CCCAD3CBC9D4CDCCD0CBCEC5CCE0
3C5B8B2A447BAA8FB4A2263AC91720D01015D01117BE191BD46F6ED6B2ADC1B7B5BAB8BB
A9AABA575879704F77A63D59B81422C20A12C30A0FB80D12A82D31D09B9BA79D9D929798
8A95A424335771557A80172D9F0516A5020FA5010AA10512830C1BC4959ED0CFD8C5D2DB
C5D3DEC2D0E0ADC2DE27427C021E6F021A7000176A001A630B2862567399A3BCD48399B0
5E758B61788B728696778CA14964880520520A204D556B7F6B7C82717F826E797C6E797E
35424F28373F676C6839B22D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0065D344C4BCB97279889FA8B4A9AFBAA9ACB77D8192
1B24450C1739626276766A747C6973816B74856C75856A7290717B916D7997717A967279
9C7A80A17C84A27A83A57C839A7076A1797BA77F81A27A7DB28B8DA27C7AAA8681B4928C
B3928ABA9B92BD9D93BB9A8FBF9E91C2A291C5A796C4A797C7AC9CC8AD9FC7AB9ECAB2A2
CBB5A6CFB8A9D3BBABD2BBA9D1BCA9CBB6A5CEBAAACEBCACD0C0B0CDBEAECEBDAFD3C2B8
CDBDB8A69A95CBC1B8CCC2B7CDC3BBBCB6AFACA8A0CFC8C0D0C8C0D1C8C0D4CBC3D2C9C2
D2CBC6D1CDC9D0CDC8CFCBC7D1CAC7D5CCCAD3CCCAD4CCCAD4CDCBD1CAC9D1CACBCBCBD6
778DB21E3F73767BA9A64F67BE1A27CF1219D01118C7161BBA373BE6A9A7C7B3B0BEB7B4
B1AFB4939CB52C3768966793A01B33BC0C18C0070DBD090DAB1318BA6466BFA7A59B9B99
B9C1C75C6C873B38617E365394091DA20210A5020CA4030F9208159A4D59DBCCD4C9D1DB
C5D0DFBFD0E74F689703216B011B70001A6B0120651C3E707C9ABAACC3D5B5C6D66D8296
98ADBF7E93A3A6BACD6D85A4132C5F0621533D567496AAB3849095748082757E80707A7D
3C495525363F596360675C4D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC735CFC2BA7E84928992A099A0AB989CA78F94A5
202849131B3D6B697C766A737B6B75816D77867078876D778E707B916F7A96717A97737A
96737A9F7981A07A81A47C81A17A7DA68083A78084A78083AB8587A07B79AA8483B28F8C
B4938BB8998FBF9D93C3A295BF9E91BE9E90C4A695C5AA99C8B09EC5AD9CC4A99AC7AC9D
CAB2A4CCB6A7CDB7A7CBB7A6CEBAAAD2BEADCCB8A7CBB9A9CFBEAFCDBEAFCDBEB0D1C2B7
CFC0BAA49894C8C0B9CDC7BDC9C3BCA6A198C1BBB1CFC9BECFC8BFD0C9C0D4CCC4D4CCC4
D3CBC4D5CDC8D3CDC6D2CBC7D2CAC8D2CBCAD1CDCBD2CECCD2CBCAD0C8C7D1C8C7C9C4C7
B3C0D63A5883374F86B383A5AE2334C9131CD01119CB1017BC1C23DB7D7ED1AFABC0B4AF
B6B0B0B0B3C14E5F8A5D568A953859B41222C10911BF0A0DB30D139E2D31E7BDBCB7B3B2
A0A7AA8D98AC1C254D7D5679820E25A10516A80310A5020E9C0613831C28D8B5BDCECFD8
C6D1E397ABCE0F2A6B021E70001A6D04256735598898B8D2B1C7D8B2C2CFB0BFCF435B73
6A859F6E8AA46280A51B3569031B56213963788C9C7B8B906974796C787971797C737D82
394854283A4256615C5C544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C12ADAC8BCA2A8B5A4AFBE9CA3AEA1A6B1B1B7CA
242D4D1A21426B6979766B7373646E826F7A826D76876F778C707990707A96717A946F76
98757B9C797F9F7C819E7B7EA58486A07F82A07E829E797DA983859E7878AE8786AE8787
B5918CBA968DBD9B8FBB9D8DBC9F90BDA191BCA18EC0A793C7AF9DC7AE9DC7AD9DC9AE9F
C9AFA1D0B8AACFB9AACCB9ABCBB9AACDBAABCAB5A7CDB8AACFBEAFD1C0B2CEBEB1CDBEB2
D0C0B7BEB1AAA29892AEA6A0A8A29CB8B0A8CEC7BCCEC6BCD0C9C1D0CAC2D1CCC3D6CFC8
D3CBC4D3CBC4D5CDC4D3CCC5D1CBC8CBC7C5CDC9C8CECACAD0CCCACEC8C6D1C8C6CBC7C5
C2C9D4889EBD27487D8F87B3A63F54C11924CC1019CD0F15C6141BBB393CE7A9A7C2AFAA
BEB7B2B4B3B6909DB92B386C93628CA1192EC11019C00A10B90A109D1319BE7778AC9A9A
98989B9498A540486A56486F7C264099081AA60311A5020DA10410890B18B37882D4CDD7
C2D0E744608F02216A011F6D0627685377A1A6C4DBB3CAD6B7C8D3B8C6D1B3C1D05B7088
2B466559779C0420530019521B335E63778F737E886F797D717A7D6A76766D777A6C7A81
293A492F444D5865605D564600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D7C4B3ABB1BE98A4B499A1AE9EA4B09A9EB2
292F4E2327446D69777569715E50597C6C75826D75846C738B6F758E6E76916C76957079
9B757D9B757C9D797E9D7B80A483879172779173789C7B80A68084A57D7EAC8484AD8585
B28C88B49188B9988DBC9D8FBB9F91BCA18FBEA391BAA18EC5AC9BC5AD9DC9B0A2D1B8AA
D1BAABCBB5A6CCB6A8CCBAABCCBAABCEBCADCAB8AACDB9ABCCB9ABCFBCAECCBAABCDBCAD
CFBFB1CCBEB3CCBEB6C5BBB4C9BFBACEC5BECDC5BDCEC7C0D0C9C2CEC8C1CFCAC3D4D0CA
D2CEC8D5CFC9D4CEC7D4CDC9D1CBC9CBC7C6CBC8C8D0CDCDCFCCCACEC9C6CEC6C4CEC7C4
C7C6CABEC9DC5B77A0485C8FB47A99B22131CE141FCD0E15CD1119B81A1FD87879CBA9A5
BAB3AEB4B3B1AFB6C6465A8564588B933151B40F21BE0914BA0810AC0F16AA4548C9A6A5
B3ADAEA4A6AD8991AA262C54814C6C8C0F22A10411A6020DA603119607148B3340DCC5D0
AEB9D5122F6902236C082B6D5D80AAB0CCE2B8CDD9BBCDD5BCCBD4BAC9D5B0C0CF96A9C1
50678D0F285800194E1F3D6671879EA6B6C0939DA4808A8D8690936B767769767A61737F
12243B4155615A67645D584C15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D3BBA6BBBEC99CA9BBA2ACBAB0B5C187899B
4449652A2D466C677473676F74656B7D6A737F6A71836B708B6F748D6F7596737D97707A
9A727A9F767BA27B7F9D787D9771798A696F896A6F896B6FA38183A68080AD8685AC8483
B28B86B38E86BC9A91C1A197BFA295BC9F8EBC9D8CBCA08FC6AB9BC8AE9FCDB4A5BBA392
C9B4A1CDB7A8CBB5A7C9B6A7CBB8A9CDBAACC9B7A9CBB8AACEBAACD0BDAFCDBBACCEBCAE
CCBFB0CCBFB3CFC1B9CBBFB8CFC4BFCFC5BFCEC6BFCDC4C0D0C8C4D0CAC4CBC7C1D5D4CE
D5D1CED4D0CBD3CECBD2CBCACFC7C8CCC8C7CCC9C8CCCAC6CECEC9CCCAC6CBC7C3CDC6C3
CDC6C8C6C7CFA1B2CA2545769F8FB89F3247C41622CF1218D01118C11118B63337D99D9B
BBACA8B4B2AEB2B5BA8A98B5303D738C5582A0142CBA0A17B90510B1081196161DC78B8D
D1C3C599999E939AAA2A355B6853787C1D349D0818A3020FA3010F99020E7C0C1ACEA1AF
9093B008215F0325684B709EABC8E1B8CCDABACCD6BACBD3BBCBD5BCCEDEA2BAD56983AE
163267021B51112C5866809A8294A196A5AB717D836F7C7F6C777A63727461737C3F536C
05193D48617557696B5C5E552CA21B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00CAAF92B9B9C2929EB09BA6B5A0A5B285899B
3E45602D324A6E687574696F776A6F7B69707E696F81696E856A708D6F7890717995717A
9A72799E7278A2767EA379838E646F9E757EA07D81866A6CA18586A48383AB8988B08A88
B69089B7928AB59389BFA195BDA093BEA091BFA091C1A192C1A595C2A796C8AD9BBEA490
C8B19EC6B1A1C9B5A6CAB7A8CCB6A8D1BAADCBB6AACDB6ABCEB8ACCDBAAECEBBB0CEBDB2
CABDB2CDC3B9CEC2BACCC0B9C9BFB9D0C7C0CFC6BFCDC5C0CDC7C1CEC9C1D2CEC7D3D0CB
D3D1CED1CDC9D4CFCBD2CCCAD0CCCACDCBC9CBC9C5CECDC7CDCDC7CBCCC7CCCAC6CDC8C6
CDC6C6CBC8CAC4C9D74D6892546395AE6E89B41D2BC91118CD0F14C80F15B8191ECF7070
CBA8A5B9B0ABB6B5B5B5BCCC4658864D3C6F89203EB3101DBC0912BA0B14A50D15A5474C
B395959B97989596A06069863535607D3E5D910C229E0212A1000F9B020E8A0714A15666
7F7192061C571B40779FC0DDB7CCDEBBCDD8BBCCD7B8CAD7B6C8DDA1BADA486698042562
031F581C365F6E839E657585738189707E816B747A6B767A6774795A6E763E51690A1D48
011345132A4E4E6473585F5C41752900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0094BE69C5C3C87B889897A0AE9499A4ABB1C1
1E27423B41586C697571686D74676B7C6A70806B71816A71886B768A6975916E7999747D
9D757EA37980A0757D9E757E8B626C9E767BA28182A18C8BCABABBD0BCC0B2979CAC8A8B
B38F8CB28F88B49388B99D8DBEA292BB9D8EBE9F91BFA192B79D8DB49C8EB9A496BCA897
C1AD9CC3B09FC4B1A2C5B2A4C9B2A4CDB6A9CBB4A8CBB3A8CBB5AACBB7ADD1BFB5CEBDB5
CDBEB6CEC2B9CDC1B9C8BEB7C5BDB6D0C8C1CEC5BECDC5BECEC8C0D0CAC2CFCBC3D2CFC9
D2CFCCD3CFCCD1CDC9D3CFCBCFCCC8CFCDC8CAC8C5CBCAC6CBCBC6CCCEC8CCCCC7CCC8C4
CCC7C4CDC8C7C8C6CE96A6C429477CA391B5A02E42C31820CC1016CE1016C7161AB43234
DEA4A2C1AFACB9B4B4BBBEC58998B630396B93577CA3192CB90C16BE0B12B20B13941A20
C39091CDC5C7A2A2AC8D94A9232D5776567B7B10299703159F010F9D020D970511811323
784B6E0C1A504971A0B1CFE8B7CBDEB6CADAB2C8DDA5BFDE748FBB1E3C73011F5C02255A
46618672889D9DAEB985939BA6B5BA7E8C928B979F71818C6376882F4561061843010F46
000B46000F4224375656606655493D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0061D245D2CCCE909AAAA4ADBA9CA1ACA0A7B7
1B26403D4A635E637565626E71656D7D6B717E6970836B748A6C79886674906C789D7682
9D74809F777FA37A8199717A8B666D957779B09B9BDACED0DBD3D9DDD3DAD6C4CBA5898E
AE8A8BB5918CB7958AB99A8ABB9E8EBA9A8CB99A8BB4998BA58F839481788C7B7391847A
B6A69ABEAC9CC5B1A2C7B1A3CBB5A7C9B2A4C9B3A6CDB6AACBB5A9CDB9AFCFBCB6D3C1BC
CEBEB7CBBEB5CBC1B9CBC3BCCBC5BDCDC6BDD0C7BFCEC7BECFC8C1CDC7C0CFCBC2D1CCC6
D2CECAD2CFCBD2CECBD1CDCAD1CDCAD0CDC8C9C7C3CDCAC7CCC9C7CACAC7CCCBC6CCC8C4
CBC7C3CBC7C5C9C7CBBFC6D544628E596997A76580B31F29C91219CB0D13C90E14B4171A
D17475CBA9A6BCB2B0B8B6B9B6BFD23D507B72608D952E49B30F20BD0A14B205109F0D17
B15F67C8B3BAA09FAB999CAA4551744B456D752643940B1D9F02119E020C9B010D880512
8237531D1B4D33598E9EC5EEA9C8EB95B3D76382AF20417903266401215C1A3C6C688CAD
89A6BCA7BCC891A2ADA4B5BF93A4AF8497A36F8295415773142850011145000C43010A42
010A43020E44091A444A5A685A564E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0059C837D4CAC6848E9B98A1AFA8ACB8858A9C
2632501F2F56142148313654645E6D7A68717F69718368728A6B778D6D7991707A977380
9C73829F7580A37A829A727B836268857072D0C5C6CFC5CBA497A1A89AA4E2D2D9AB9196
AC8A8BB18C87B7958ABD9D8FBB9E90B29486B19585AA948784736A9B8A83A5948E746964
9B8F86B9A799C1AA9CC2AB9DC7B0A2C6B0A2C5AFA0C9B3A6CBB6AACAB8AECFBEB6D2C2BD
D1C3BDCBC0B6CFC6BDCBC3BBCAC3BACEC5BCCEC6BED1CAC3CEC7C1CEC8C0D1CDC4D0CCC5
D1CDC9D4CFCED4CFCECFCBCAD0CDCBCDCBC8C8C7C4CECBC8CDC9C7CDCAC8CDC8C4CDC7C3
CBC7C2C8C4C1CBC9C9C5C7CE8B9FBE254577A490B59D2B3CC1141ECB1015CB0D15C21117
B53439DDA0A1C1ACABB9AEB1C2C0CB818AA847426BAF6884AA172BBB0A16B5030DAB0912
98252CB78B8FAAA2A99B9EA5747E99222A54744668820C1F9B03119E020C9A000C91040F
7D1C30563E620D245C193D7C1D3F7D0B2C6802226103245F1A3A6A647FA55978988FAFC8
2F4C6191A6B55D6E7C7B8A95637381596E86223960031647000C46010A4701094200083F
000A40020E4402123F41546761646010CB0800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0051BF28DBCFC39199A5A3ACBAADB0BD858A9F
2B355B020E41020C440A123E605D757767727E6A718068718669748E6E79907079987480
996F7D9C717D9B717A9B727A9C797E988083DCCFD5AB9BA5A189939A8289DDC9CEAA9396
A88A88AA8881B19086B8988CB39488B09184AE90849884797D716A9B8D8A978A8A736C6B
847C76B4A599BCA798C0AA9BC5AFA0C1AA9BC4AE9DC7B3A5C7B4A8C9B8ADC9BBB1CEC0B9
CEC3BBC8BEB6CEC4BFCAC1BAC9C2B8CDC5BBCEC7BFD1CAC6D0CAC4CEC7BFD0CAC3CFCCC6
D0CDC9D3CFCED2CDCCD1CDCBCECBC8CECDCACECCC9CCC8C4CFC8C5CFC8C6CFC8C5CCC6C2
CCC7C3C7C3C0C9C5C5C7C6C9BCC5D73C5B876170A0A05E77AE1A28C60F18CE0F17CA1117
B4151CD86F75D899A0CE9CA4CD9CA9C99CAFA87793D37C93B01E2EBB0B16BA0611B30610
9C1118AF6C6DDED3D4C0C7CF8B95AA2A3A6056466C70152B9307149C020D9A010C94020D
760814B98B9D6F71932C3F701D33681D36683C57816E88A8A3B9CEB8C7DA4D6177647C8F
657D8E7C939F899CA58091988999A71F355901134A010D48010946020A4502094100093E
000B3D01103E02113B32455B63686827A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DAC9B9949AA89DA7B79DA0AF7C8198
0E173F020B40010843030A3D514F6D7365737A676F7B666F836974886974916F7A95707C
976F7B9B707D9A6E79986B759E767D9E8287DFCDD49F8892A6878F9F8389D6C0C5A48C8E
A88986A7857EAE8E84B29287AF8F84AF8E80B09184917D737065627C7376756F72686262
7B726CA39489BBA799C0AA9BC3AD9CC3AD9CC4AF9EC4AFA0C7B4A6CAB9ABC6B9ADC9BEB4
CEC3BBCBBFB8CBC1BACCC3BACAC3B7D0C9BECEC6C1CDC7C4CFCAC5CECAC4CDC8C3D1CDC8
D1CFCAD2D0CBD1CECAD0CCC8CFCCC8CDCAC7CECBC9CFC9C7CBC4C1D0C9C6CDC9C5CCC7C3
CCC7C3C7C3C1C7C4C5C7C6C6C5C7CF8C9EBC2B477B9C88AE9A3044BB1823C60F16CB1318
C31218BA2129B2303BA92F3AA72A38A82A3AA52635B12431B6141EBA0C15B50910AF0A10
9D1116974A4AC1B1B5979FA78C96A65768862D305A703550880A1C9A030E9B010B96020D
8307119A5862D5CBD6BBC6D7B1C1D5B1C3D8BACCDCBACCD8B9C6D1BAC5D0A1B0BF8AA0B1
AAC2D56D8CA29CBACF748F9C9DB2C122395F00124D010C49010B4500093F000A3C010E39
0E1E3F293B5511254122364B636C6F2AA52100FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00D4BCA99EA1AE9DA8B98C91A27F859D
02083001063902074102093E4545667467797765717E6A72886F798E6D7992707C916C78
97707C996F7B9669739E6F79A0767F98787FDBC6CBB29DA3A2888ECDB4B9B69DA2A7898B
A5817EAA857DAD8981AD8A81AF8C81AF8F7FAE907FA48A7F6E5B58695F5F655E5E7B736D
9C8F849F8E80BDA799BDA797C1AC9AC1AE9DC4B0A0C5B1A2C8B4A5CAB8AAC8BBAEC9BEB4
D0C2BCD0C2BCCDC4BACCC5B8CBC4B8CDC6BBCEC6C2CEC7C3CDC8C4CAC6C3C9C5C1D1CEC9
D3D0CCD6D4CFDAD8D3D5D3CED1CECAD1CECAD3CFCDCFCAC9CBC6C4CCC8C6CECBC9CEC9C7
CAC6C6CAC6C6C9C7C7C8C8C6C7C6C8C0C5D46B7EA44F5882A0718C9F303FB22025B71B1A
B81E1BB4201EAD2222A82122A71F23A92327A82627A92726A62323A52324A1242299231F
8B28269E6664A297999EA4A9A2AAB9788AA118284F6B4C6F7A0F269504129C010D98020C
9107127A202BD7BBC5C8CCD4C3CFD8C0CCD8C0CDD8BBCCD5B7C6D2B5C4D1B3C4D7486381
43618D0421571C3B6E385B78648090374E6D02134B000F4B000E45000F3D07183B26394D
475A634F60662F4352182C3F5D666D55483F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CAAE94A2A2AB99A0B37E8599424966
01062E01043401063E02083F3F3F637267797B69737F6871886C768D6D788E6E78906C74
9770789B7179956A6F9C7177A0767DA07E83B2999DD9C6C9D1BCC2B69DA2997A7EAB8986
A5827AA9857DA9837BAD867FB08C81AE8D7DAE907DB194859F877B927E759180778D7B71
9A8579B59E90BDA596BDA896BFAA98C1AC9DC5B0A2C5B1A2C4B1A2C8B7A8C9BCAEC9BDB3
CDC2BAD0C6BECAC3B9CEC7BDC7C1B7CDC7BECDC7C1CDC9C2CBC5C0CDC7C4CFCBC6D3D1CB
D7D5D1D7D5D1D6D6D2D6D4D1DAD6D4D7D2D0D2CECCD0CCCBCCCAC9CAC8C7CDCACACCC9C9
CBC7C7C8C4C4C8C7C6C6C4C0C5C2C3C6C4CAB9BCCD9098B1827C91AA828DC57E7FC77872
C87770C77C71C58177C4837BC88781C88B83CB9189CD9690CD9691C8928EC48F8BBA8883
AF8985B5A5A2949698C0CAD1BBCBDA94A9BE31456748436872243E8E07179A020F9A000C
96030F7D0B18B8838DD2CCD2C5CED8C0CCD8BCC9D6B8C9D5B8CAD79AADBE72889E455E80
05225C02196201175D1835616B889A5C728C01154801134B05164220324D465864566668
5866645460603E4E5914253558676C625C5500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0098C26CACA8AF84889B84899F141939
02062E01043401063D020A3F3C3D5E7868797F6672856975886A758B6C76916F788F6870
986F769A71769B71759A70769E767D9E797E9C797DA08287A5878CA281859D7678A57F79
A7847BA27F76A58075A9847AAC8A7EB19183AD9080B09685B89F91B8A191B49C8DB59D8F
B99F92BDA395BCA394BEA895C0AA97C2AB9CC4AEA0C7B2A3C8B6A5C8B7A8C8BBACC9BFB4
CAC0B7CDC3BBCEC5BFCDC5BFC6C0B9CAC6BFCCC7C1C9C6BFCBC7C0CFCBC6CFCBC5D2CECA
D9D6D1D7D5D0D5D4D2D3D1CFDAD6D5D5D0D0D3D0D0CDCDCDCBCACAC9C8C8CCCBCBC9C8C8
CBC8C7C8C6C3C6C5C2C5C2BFC6C1C1C5C2C3C4C0C4BFBEC3BDBDC3BFBBBCC4B7B3C6B7B1
C7B6B1C1B4ADB9AEA8B8AEA9B7ADA9B2A8A3B0A7A3B6AEAAB1A7A5AFA8A5B1A8A6ABA2A0
A6A1A1D2D4D5B5BCC2A1ACB76B7B8D7083976779951F2850784868840B229903149A010F
9A02108F09168D3D48DCC9CFC8CED9C2CFDBBFCDD9B7C8D3B7C9D696A9B8768C9DA9BFD5
1B326503186102155F041A4E59758D748CA0071C41172C4F3E516654666C5B68685B6663
576160535E603C4A5415253257686D79797410CB0800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065D549BCB4B48A8EA1696D87070C2E
00042E020533010639030D3D3F3F5E766475816674866A77896A778E6C788E69748F6772
976F789B71799E737B9E737BA078809F767D9D7277A4797CA57B7DA1797AA27779A47978
A67E79A07971A37D71A68374AE8E80B39688B19585AF9585B39B8CBAA192B8A08DB9A28F
BAA292BCA395BEA697BEA694BEA793C3AC9BC2AC9DC5B0A1C9B5A6C8B6A8C7B9ABC7BDB2
CABFB6CCC2BACFC6C0D0C8C2CBC5BECAC6BFCAC6BFC7C4BEC9C6C1CECAC6D3CECAD4CECB
D8D3CFD9D6D2D5D4D1D3D3D1D9D6D5D5D1D2D0CED0CACACCCAC9CAC9C8C7C9C9C5CBCAC6
C8C7C2C8C7C2C6C5C1C5C4C1C3C2C1C2C1C0C2C0BFC3BFBEC0BFBEBCBCB9BBB9B6BBB8B6
B9B7B4B6B6B3B2B1AFB0B0ACAEACA9ADABAAAEACAAADACA9ABA9A6A6A4A3B6B7B6B9B8B9
9F9EA3A3A6AA989DA3949AA199A0ACB9C6D295A6BC23345D654E777715319405199B0210
9C010F9305107A1420CFA8B1C9CBD5C2CED8BFCDD7B6C7D1B8C9D5B8CAD8768DA1AFC6DB
42567F01135600125901164A4A6580657B884D60705A6D755D6F715A6B685B69645D6963
5B65655763672B3D481C303C55676A8B8F8C239C1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005CCA39C6BBB7737B8C4A516B000528
03072E16163C22234A070D35494965746374816A778569778766768864728A66738E6A75
956F7A9D747F9C727B9C6F7A9E727BA0747CA4767DA6787CA6797BA4787AA17477A37678
A276759F7470A47C71AC8879B19082B59687B59889B69A8CB89D8EBA9F8FBA9F8EB9A28E
BBA292BFA697BDA496C1A797C0A794C4AD9BC3AD9DC7B1A3C7B2A5C7B5A9C7BAAEC7BEB3
CAC0B7CDC4BCCBC6BDD0CAC2C8C2BACAC3BFCEC7C3C8C4C0CCC9C5D2CFCCD5D2CFD4D1CF
D4D0CDD3D1CDD2D0CDD4D2D1DAD8D9D5D2D3D0CCCECCC9CBCCC9CACBC9C9CBCAC8CDCBC8
C9C7C3C8C7C2C7C6C2C4C5C3C0C1C0C2C2C0C3C1C3C4C1C2C0BFC0B9B7B7BEB9BBBBB7B7
BAB6B5B7B1B0B7B0B0B5AEADB6ADAFB2A8AAB1A5A7ACA4A2B0A5A5AEA1A1A69E9DB1A9AB
ABA2A79F999EC4C1C5BCBABFB1B0BABFC7D79AAAC64152793F37617B2F4B8F0A1D9A0311
98000D92020E810816A2646ED3CBD4BFCAD3BDCCD5BBCBD5BAC9D5A0B2C12D435B5C7289
6B7D990D2051041853051B4860778C6E81886F7E816878775F6F6D5E6C685B69645D6A64
5B6867526067112332253D474B60618C94922BA52300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02ACDBBB0868B9A343C5902072A
0A0D2C49415A4E455E0E0E2C57536C7A6B7C7E6A77806875866576866172835F6E886270
9169759B717C9B707B9E727CA0727C9C6E77A3727BA6767DA4757A9E7073A07375A07275
A27575A37876A88179AD8B7DB09081B29283B49586B39587B39587B59889B69C8ABAA08D
BBA191BCA294BEA496BEA393C2A997C1AC9AC2AC9EC7B0A4C7B2A6C7B6ABC7BCB0CAC2B7
C8BEB5CAC1B9CAC2BBCEC6C0CBC3BEC8C0BCCDC4C2CDC6C4CCCAC7D3D3CFD5D5D4CECECD
CFCECED3D1CFD6D3D2D4D1D2D2D1D2D4D3D4D2CED0CFCBCCCCC8C8CAC7C8CCCBCBC9C8C7
C8C8C5C3C3BEC4C4C2BDC3C3B8C2C4BEC1C5C4BCC2C7BABEC6B4B9C6B2B7CAB1B7CEB1B7
CFAAB3D2A8AFCCA1A8CA9DA2CA99A2C9939DC48D97C08993C18490C0828DB97D84B87D84
B97C87B27985D3A0ACDAABBAB07F949C728C724E70866888623C5A9F4C638B08199A0212
98010E91010C8804137B2633DBC1CBC5CBD5C1CCD8BFCBD6B7C2CF7E8E9B9AAAB9708390
B2C2D066778F2F43643348628697A46C7C826E7D7F6C7A78677172626B6A5E69675A6867
5363692C3D5002132C314B594961646F7D7C51474000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0052B920CFB8A68A8C9D1B234203092A
23243B5E5260564A5C15122A645C7279687777636F7B6370816271825C6E7E56678D6272
906571986D77966B789A6D7A9B6D799F6F7B9D6C77A27077A17177A071749A6C6EA07372
A07573A57A76A9827AAA8679A98879AF8F80B49686B19585B59888B69A87B89D8BBAA090
BBA091BCA193C1A698C0A797C0AA99BEAA9BC1AC9FC1ACA0C5B2A5C5B6A9C2B9ADC6BEB3
C9C0B5CCC0B9CCC1BCCFC5BFCAC2BCC3BCB5CAC4C0CCC7C5CCC9CAD2D1CFD1D2D0CECFCD
D0D0D0D2D1D2CFCED0CFCED0CECED0D2D4D4D1D0D1CCCACACACAC9C7C6C7C7C6C6C7C6C6
C7C6C5C1C1C0C3C7C99DABBA658096B4BACDBF9EABCA8894CA7884C56D79B75966B54E5E
B34154B13A4BAB3443A52D3BA326349F1F2EA01E2D9C1A2AA0192B9C17279C16239B1824
9A16259A17279B1A2F961A30971B3092172E901A33891A308A1D2F9317299706169C0210
9A010E93000C8F02127B081AB67086C4A0B8C5B0C7C9BDD0C9C4D2A4A7B2BFC9D196A7B2
9EB0BC8EA0AA70838D6D7E8569767C6A76796F7B7C6F7A79676F71626C6D5D6A6E50616B
293A51041234000C2F152A42435A645666675B554E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B71AD4B6A08A8B9A101A39050C28
3D3C4B60555D5449571C172E6F657878657278626C7E63707E5E6D7A56668057688C616F
966A74966A75986C7A986D7B976C7B9C717E9D707A9C6C749D6E729D6E709B6C6D9D7370
A07772A67C76A88078A78276A78577AA897AAF907FB09384B39787B69B89B69C8CB89F92
BA9F92BDA294BFA697BEA797BEA99ABCA99CC0ADA0C3B0A3C3B1A2C1B4A5C1B7ACC3BBB0
C5BDB2C8BFB6CAC0B9CBC2BBCEC6BEBEB8B0CAC7C1CCC9C7CBC8C8CCCBC9D0D1CDD0D1CD
D2D2D1CFCFD0D0CFD2D0CFD0D1D1D2CFD0D0CCCCCCCBCBCBC9CAC9C7C8C7C8C7C7C5C4C3
C5C5C3C1C3C2C0C3C89DAEC42143728592BA92586FA42738B61E2CB91C26B91924BB1822
BD1623BD1421BD1422B7121DB61219B31015B4141BB01219AF1118AD1217AC1116A71012
A71013AA1116AB121AAA121CA50E18A40F199F09189B09179C0A169B09159F0A1799040F
9A020E96020D960212900416850C247A163279223E7B314A87495E8A65729E99A273808B
61727F7284886273776E7C7E6F787B727C7D75807F707B7A697274616C7054667420304F
010D37000735010733000B2F22364A54656A59565100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B414CCA88E827E8C060E2C080D26
5B566262545A514653201A2E72677876636F79616B7C5E6B7655647C5A69845C6B8F6473
966975986D78956F7E86687E7C637C8B6E8298717D9B6E769C6C719A696C9C6B6C9D706D
A27773A67C76A77F77A68174A68475A88776AF8F7DB29284B29588B09587B19B8DB49F91
B6A294B6A092BBA596BDA799BBA499C3AEA3C2AFA2C1AFA1C4B3A4BFB1A4C0B6ACC5BCB2
C8C0B5C9C1B7C9C1B8CCC4BCD0C8C0C4BEB8CBC8C4CBC9C6CBC7C6CBC9C5CBCCC7CECFCB
CDCECDCFD0D0D1D0D1CFCDCED0D1D1CCCDCCCDCECCCBCCCBC8C9C7C8C7C5C9C6C4C5C3C2
C6C5C4C4C4C4BEC1C2BAC3D24E6B973C5588AE82A0A22A38B81F26B71D1EB21D1BAF221E
AC2120AD2726AC2A2CA5292AA62F2CA6352FA43931A03B34A13D379F3E379E3F379B3E35
9B3E35A1443D9E3E3B9D3E3A973836933333923035902D328B242A851E24881C2386171C
8812198810178A0C168C0C188B0B1A890A1A880B1D850A1D7E0B206B18278C6F77A1A6AD
7E8C9395A5A78392948996977A83866E78797581816D797A6C76795A6973263854010D3A
01093B010836000734010A340616334559615257560CC80700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C79C7B7B717F060B2A0A0D27
6A616D64535B4B414D2C26376E667472636E775E697B5C68795664805B6A89616E8F6471
936775926C7E7B637D352F5916164A3831598E758A986C7698676B9766689C6C6BA17572
A47876A67876A27771A88277A58373AF8E7CB0907EB09183B09388AE9489AA988CAE9F93
B4A394B5A193BAA496BAA499BAA49BBDAA9FC0ACA1C1ADA1C0AEA2C1B2A7C0B5ACC6BCB2
C6BDB3C6BCB3C7BFB7CAC2BACEC5BFCBC5C0CBC7C3CFCDC9CBC8C4CECDC8CACAC7CDCDCA
CCCCCCCDCDCECCCBCCCCCBCBCDCECDCACCCAC9CBC9CBCECBC9CBC8C8C8C6C8C5C4C8C6C4
C5C3C4C5C3C4C0C1C1BCBFC794A4C12A44719A92AEAB7077BE6A69C77471CC817ACF8A83
D08F8ACF9791CB9894C99B95CBA09BC39F96C1A098C1A39ABFA29CBA9E98BCA09AC5ACA5
AB948CB49D96B8A09DB49D99AB9492B69F9EA98F91B0989AAA8F93AB8D90A78284A77C7E
A775799C656894575C8D4A4F8A41478133397C262E761A227415226416207D5C60BBBDC1
A7B4BB86959B8B979B6E7C7D707C7D6974746C77786875776572793F4F6504103C00083E
02083C010837010733000835000E302C41504D585A17921000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C092688F848B050C29171A33
5C515E64515B49414F36374B5A5B6E615A6C6F5D6B7357647A5A66815D6A885F6C8E6472
8D6476826480342C570A124C0610530D134B706180956D7A95656A9A6A6D9B6D6DA27574
A17271A57573A27570A87F77AC877AAF8C7CB49181B19082AE91869F8A7F8879707F746B
A99A90B5A195BAA498B9A397B9A499BAA79BC0ADA0C1ADA1BFACA1C0B0A7C2B7AEC0B6AD
C5BBB3C8BEB6C9C0B8C9C2BBCBC4BECFC9C4CCC8C2CECDC6CAC9C4CECDC9D0CECBCCCBC9
CDCCCCCCCBCDCBC9CBCECDCECECFCDCACBC9C7C9C6CACCCACACBCBC7C7C8C3C2C2C6C5C6
C1BFC3BEBDC0C1C0C3BEBFC2B7BBC88B98ACA6ABB9C4BABCCAB8B7C8B6B3C2B4AFC0B3AE
C3B4B3BDB3B2B6B0B0B5B0AFB4AEACAEACA9ADABA7ADAAA8AFA9A9AAA3A3AAA4A4ABA8A8
9A9C98989B99ACADAFACAFB1A6ACB1CFD7DEC4CED9ACBAC998ACBBC5D4DCC9CFD5C6C9D0
CDCCD4C7C4CAC3BBC2BFB6BBB8ACB1AA9C9FA48F929980867C5F6B755963756A6F8C9499
87959D6C7881717B816C777A6773746371716473736372745D6D7A142446020D43010840
01073C010837010833000A34010F351C2E444C5A5F28632000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B686539B8D90090F29323448
685C6862515B3A36472D36510E173A222543685D70715A66775A65815F6C886270896071
86627A59456C14124139396A20235B060D435A4D6F916C7A95666C98686B9B6C6E9F7071
A27372A97A78AA7E79A67E76A68075AE897AB08C7DB39184B4978C8C776DA6988F867B72
8F8279AD9E93B7A397B5A094B8A396B8A698BEAC9DC0AFA1C1B1A4BFB3A8BFB6ADC1B8B1
C6BCB6C5BBB5C5BDB7C4BFBAC8C4C0CCC7C2CCC7C2D0CCC7CCCAC7CDCBC8CDC8C5CEC9C6
CECCC9D0D0CECBCACACBCACBCACBCBC9CAC9C8C9C8CDCECCCACAC9C5C5C6C5C4C6C5C4C6
C2C1C4BFBFC0C3C2C3C1C1C1BFBEC0BCBFC0BABDBDBCBEBDBEBDBDBBBBB9BABBB6BAB9B6
BCB9BAB4B4B7B2B3B5B2B3B5AEAFB0AAACACA8A9AAABA9ADAAA7ABA4A2A3A5A3A59E9F9F
9EA3A2949B9AC7CFD1D0DADEA4AEB9B2C4D794ADCA7C97B357748BC0D6E5C6D4DFC5D2DC
C7D1DEC9D2DEC7D1DBC7D2DAC4D0D7C5CFD5C7CED5AEB7C4374458515D6D87929A839096
8E9AA38792997B858C838D9068747562737061746F5F707344556904123F040D48010840
00083C000C35020E300917360314331121384C5B6338333000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005EC631A28D8A1113292C2B3D
5D515A5E505A2B283F0E173D0109370C1239554F646E58647B5E6A836270876371876275
7A607C221842393259827191463D68090B3F5344678C64739463699A6A6B9E6D6FA06F6F
A1716FA67874A9807AA58077A58177AD8A7CB19181B49485B6998C8A756A85776D807066
8B7C6F8C8073AF9F95B5A196B7A498B6A497BAAA9ABDAE9EBCB0A3B9B0A5BCB3ABC1B9B1
C3BAB3C7BFB8C8C1BCC6BFBDCAC6C3CBC8C5CBC6C3CBC5C4CBC6C6CCC8C7CCC7C4CDC8C5
CCC9C6CCCCC8CCCBCBCDCCCECBCCCDC8CACAC8C8CACBC9CBC8C7C7C6C5C4C6C4C4C7C4C7
C7C4C6C1C0C0C0C0C0BDBFBCC1C0BEBEBFBDBDBFBFBABBBCBABBBABBBCBABABAB7B5B6B3
B5B5B7B0B4B6B0B1B5B1B1B4AFAFB1AAABADA9AAADA8A7ABA7A7AAA6A8A9A3A3A5A2A4A7
D1D5D7A6ABAEA7AEB4B4BDC698A2B07E8DA5304A6B768FAAA4B9CBC3D4E0C8D4DFC7D5E0
C5D1DFC8D4E2C3CFDDC4D2DDC2D0D9C2CFD8C6CFDA919CAB95A4B5708291AFBFC9B0BDC6
97A2ABA8B4BB738087768185677575657571637571607176253551000D42000944010B3F
02123A12263F344757475A6524354708182E4A5B663B3C3A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BD25AB8E831F1B2B2C2835
6F65695F515B1E193401063102093C050B35554D66735D6A7A5F6B7F5F6E826070856679
58486917103971607D876F89352C570B0D415B486C8E637198656A9A67699D6B6C9B6A69
A47471A67A75A47B75A58179A7837AAC8A7CAF907FB29382B095839682748D7C70AA9688
B5A293918276A5968BB5A296B7A498B8A69AB6A799BCB0A1BAB0A5BAB0A7BDB4AAC0B7AF
C3BAB3C3BBB5C5BEB9C8C1BEC8C3C2CBC7C6CBC6C4CDC8C7CCC8C8CBC8C6CECCC8CCC9C6
CCC9CACDCBCCCBC9CACCCACCCACACCCBCBCDCBCBCDC9C8CBC7C6C7C6C5C4C6C3C3C5C2C3
C4C1C0C2C1C0BEC0BDBDBFBCC0C1C1BDBFBFBFC1C4BABCBDBBBCBDB8BAB9BABAB9B4B5B6
B3B4B6AEB2B3B1B3B6B4B4B7B0B0B2B1B2B4AAABAEABACAFA7A8ABB4B8BAA7AAAC9DA1A2
A6AAAE9AA0A392989D848E97ACB4BE949EABB0C3D7BCD5EBBAD1E2C4D7E0C2D2DAC4D3DE
C4D3DFC6D3E0C7D5E1C6D4E0C3D1DCC1CFD9C3D0DB9EAEBAB5C7D3A9BCC68A9BA7A4B2BE
7A879178858C707C816E787B68737467767262737160727A122246010C44010E4303163F
20364D4961664F62614F5F5F44525B06162A475A663339380DC80700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD10B28D76463E48443F4B
62585B584C55120D2801053103093E030735564C69745E6D785B6A7D5D6D8262727B647A
2E254A372F5489728A7A64811712440E0C436E57778D616D98646A9A656A9C696C9A6968
A27571A27772A27872A37B75A9837BAB887CAE8D7EAD907FAE96848C7968A89788B29E90
B5A0939C8A7FA29084BAA798B9A699BBAA9DBCAD9EB9AD9FB9B1A6B9B3A8BBB4A9C4BBB4
C4BAB7C5BCB8C5BFB9C6C2BDCAC5C2CCC8C4CDC8C4CCC8C5CBC8C6C9C6C6C8C6C3C9C7C5
C9C7C7CECCCDC9C9CACBCACCC8C6CACAC9CDC8C6C8C8C6C9C9C9CBC7C6C8C5C3C6C1C0C2
C0BFBFBFC1BFBDBFBDBABFBBC6C8C7C9CCCDBEC1C4B7BBBBBCBDBEB8B9BAB7B6BAB3B4B7
AFB0B3B0B3B5ADB0B1ADAFB1ADB0B2A9B0B0ABAEB1A7AAADA8A9ADA1A5A99FA3A69A9E9F
979C9DA6AFAE9DA7A9A8B3B8D0DCE3B6C5D096ABBD59799983A4C0BFD6E2C3D4DFC3D5DF
C2D1DCC3D4DFC5D3DFC4D2DFC3CFDCC0D0DBB7C8D88298AF6F889A6E85925C6F7E7B8994
717E8777868A7683866D787B6873736474705E716F5D6F7A09193D010C42011040223651
4D6368546763566660535F5E4A576008182B425A672635390BC80800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B68A685E525666626E
685F654E46510A082402053102083D050A3B494161705A6B7C5E6C8261718264776C5A74
1510355F517290769056476D0B0C441B1649795D7790626E97636A9966699C6B6D9D6D6D
A07170A27672A77A76A37974A78077AC877BB18F82AE9283AD95868A786AA49388AE9C91
B29F95928074AA9788BAA597B8A699BAA99CBBAC9EB9ACA0B8AFA5BEB6ACC2BBB1C2B9B4
C3B8B6C0B6B4C4BDB8C6C0B9CAC5BFCCC8C2CECAC5CCC8C4CBC7C7C9C5C7CBC7C7CBC7C6
CAC6C6C8C6C8C8C8CAC9C9CBC7C6CACCC8CDCDC8CDC8C3C9C9C6CBC5C4C7C3C4C5BDC0BF
BBBEBEBFC1C2BABDBCBABEBDB8BCBDB8BCC0BDBFC3B9BDBEB9BABBB6B7BAB5B4B9B2B4B8
AFB2B5ADAFB3ACAFB1AFB5B6AEB6B7ACB6B6A9B0B2A6ABAEA0A4A8A3A7AAA1A5A89CA1A1
969C9CCBD5D4C8D1D6959FA99CABBE7E97AA8399AE2745656988A5C2D7E4C5D5E0C5D4DF
C3D0DDC4D2E1C2D0DFC3D1DDC6D2DDC5D3DE96A5B7394F6A415A709FB2BF8D9DA98A98A0
AEBDC375878A8A9A9B69777967737163736B5F72705F6F7B07153C010E410F2247506371
596C6B596A64566561556464465562091A313852660D20310C8D1200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B92C6E5A5C5A5563
635D66453F4E030223020532030B3D070D3B3E3954644F5E7B5E6B81616F826679534664
1C173B7865838E76952B2456070C473B315D89667A91616A915E659968699B6A6D9E6C70
A37174A37272A47571A47973A98177A98477AD8C7FAF9183B09586A38C7F88766C98877E
938178A59285B6A292B9A495BBA89BB6A499BCAAA0BAADA1B6ADA1BAB1A8C4BCB4C3B9B5
C4B8B5C2B7B3C7BDB8C8C0BAC9C3C0CCC8C6CCC8C7CEC9C6CAC7C6CAC7C8CAC7C7C8C5C3
C7C5C4C8C7C9CBC9CDCBC9CEC6C4C8C7C5C9C5C2C6C2C0C5C6C5C9C4C3C5BFC0C0BDC2BE
BBC0BDB8BDBAB8BCBABABEBDB8BBBFBCBDC2BBBBBFB7B9BBB5B6B9B3B3B8B7B7BBB2B6B9
B0B4B7AFB3B6B4B7BAA4AAAD868C8E909798ABB2B3A1A8AAA0A6A9A0A6A8AEB4B7BBC1C4
959C9F9CA6AA9AA4AD9199A5717F93748DA0AFC0CE90A3B1B7CAD9C6D7E0C8D6DFC9D6E2
C1CDDCC3D1DFC0D0DDBFD0DAC7D5DFC7D4DE93A1AEABBECD9BAEBEA5B6C1BAC7D07D8B94
94A2AA77878A6F7E7F69777569787466776F62747063747E09173D02113D374D63586E71
596C6A596B6859676753646B2C3C510B193B0D2144031432088C1700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052B927826B676E6876
68606E3730450203250209310913400A11395F586F6C5A65795F698163707E667A382F4D
322D4E816F896E60830B0D46070B455A486D8D6574915F67915E619867679E6F709C6A6E
9B686BA06D6DA3726FA47871A77F75AC887BAB897CB19083B29485B39889A99283A18C80
A99488B8A294B6A090B8A393B7A495B9A79BBAA99FBAAAA1B7ACA1B9B0A7BEB7AEC0B8B0
C1B8B1C1B7B1C5BCB5C8C0BBC6BFBED1CBCEB8B1B4C0BBB9C9C8C4CACAC6C7C7C4C6C5C2
C5C3C2C3C3C4C5C3C8CBC8CDC8C4C9C7C5C8C5C5C6C4C4C6C5C7C7C2C3C4C1C1C3BCBEBC
BABEBCBCC0BCBABDBBBABCBBB8B9BABABABDB8B7BBB5B6B8B7B8BAB5B7BBB5B8BCACB2B7
AFB3B8B2B4B8B8B7BC9392968F91928E91919FA3A4A5ABAEA2AAACA1AAAC9BA4AC8A99A5
929EA98C949CB1B6BFC8C9D4ACAEBACED4E0D5D9E4A4ABB4CCD5DEC7D4DCC6D4DDC7D4E0
C4D3E0C3D3DDC2D2DEC2D1DCC3D3DDC3D2DF9DB1C197ADBCA8BBC877899884929E75818C
7A878F7D8A90737E7F6E7A7A68777565757063737167757E11204107173A4B626F576C6C
5B6E6D56686A54656D3B4D61061236010C39000D39020F3409122900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057BB24876C6166606C
67616F252138020526121B3B3841621317386960746D5B66725C6679616C79667C201C3D
4C46657B6B8834305B050D4718164A785E7D8C5E6C92606892606399696A9B6A6B9B686B
9A65689E6A6A9D6C68A1736DA87F78AD887EAF8C81B39185B49386B69788B69B8CB19A8A
B59D90B7A092B39D8DB7A292B9A496BAA899B7A59ABCABA3BAACA4BAAFA7BEB4ADC2B8B0
BFB6AEC0B7B0C4BCB5C7BFBBC6C0BECBC6C7C8C3C5C7C5C3C6C7C2C5C5C1C5C5C1C8C6C4
C6C2C2C1C0C1C8C7CBCBC8CCC8C3C7C6C5C7C2C2C3C2C3C5C3C3C5C0C0C4BEBDC2C1C1C4
BBBEBEBCBFBFB8BBBBBABCBBB8B9B7B8B9B8B8B8BAB5B7BAADB2B7A8B3BDA7B4C1A0A7B5
A8A1AFBBA8B4BFA0ADA3858FA58D93A09094ABA2A7ADA9AEA5A7AA9DA6A998A3B02B4361
5F72908D8296B792A6CA9CB0B7869AB7879BC094A8A37E90C9B5C4CED0DBC5D0DAC4D4E0
C2D3E0C0D2DCC6D4E0C2D0DBC2D4E0B0C7D84764815E7B927A8F9D637583899AA49EABB2
7A88909EACB1707E7F6C79796976766675726976766A767E22324C0A1C3B526B77566C6C
566B6F4C616E2F405908163C000836010938010A37010D330F162E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD119B7866524850
67626F16162B0308252E324B47486125233C6B5F7074606B735C6777616D6D5D75130E32
5A5275675D820C1145060F4A392F5C83607A8C5E6B905E66915F6497646A9C676D9C656A
9A63679D6668A2706DA3756FA77F78AF8982B28F86B19085B59487B49587B5998CB59E8F
B49D8FB7A191B7A191B59F90BAA496BBA799BAA89BB9A99FB6A9A0BAAEA6C1B5AEBEB1AD
C0B6B1C1B8B1C6BDB9C5BCB9C6C0BDC6C3C0C9C5C5C6C3C2CBC9C5C8C5C2C6C3C2C5C2C1
C3C0C0C3C2C3C6C6C7C9C9C9C7C5C6C2C0C2C4C3C4C2C1C3C1C0C4BFBFC4BFBFC3BDC1C3
BABDBFBCBFC0B8BABEBABDBEB9BAB9B6B8B9B2B4B9ABB6C393A8BF6A7D9B6A6A89967491
AA6781B0566BAF445995283C9D394AB05B69C07C89C595A0B4979EB4A8ADA8AABA384E75
273A6C765A7C771D3B8915318E132C8F14298D152E8718307E3349D9C3CFCACFDAC3D2DE
C3D4E2C3D3E0C2D2DFC4D1DDC4D3E09BB0C14D67835E7890ADBFCDBACBD48B9CA5B7C5CB
84929A818F94717F826C797B6976776777766775756B777C424F630618354660734B666F
42596D17284B020D3B000839010636010736010936020B321D243A148E1300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6346584A4E
6E69770D0C24090A264D495D453F543A334972637175606B6E586277616F5B4D69110E35
656085302E5D040D4A0C114A655177805A70845C6A865C678D616897656C9B646A9D666A
9B64689C6769A16F6DA47772A77F78AD8781B39087AE8E81B29284B49688B29789B29A8B
B69E8FB6A090B8A293B7A193BBA597BBA799B5A498B6A99EBAAEA4BCB1A8BFB4ACBEB4AE
C0B8B2C0B9B5C7BEBBC5BDBAC5BFBBC4C0BBC8C4C1C5C0C0CBC6C7C7C4C4C5C3C3C4C2C0
C2C0BFC1C0C0C2C2C1C8C8C6C3C3C2C0BFBEC3C2C4C4C2C4C5C3C7BEBEC2BABDBEBABEBD
BCBDBDBFC1C1BCBCBEB7B7BCB6B6BAB1B6BBA9B6C47490B136527E7A7099914D709D2845
A61329AF0E22B70D1FB80D1DB40D1DB11123A41326A5273AAB4657C88290C39CAD807A9C
17225777638B7B1D3897071BA40414A60514A204139F0719860D21C18C98D4CFD9C5D1DC
C5D3E1C4D1E1C4D2DFC4D2DEC6D3E1A1AFBFBACBDCB6CADB8C9EABAFC0CB80929C819098
808C9379868A727E826F7A7E6B797B69797868777567767664717D101F3A253B5C213658
04123F000C4100083E01063A010536010734010B35010D3030394A1E9A1D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AC815C77696A
5A566609092219152E5E51623F3448453E5272626F745E695F4753776171463B5914163E
565B870B124A040E4D211F507C627D7856666749586247537A5A6492676E9A676B9D6569
9D67699C6869A47172A47574A97E7BAC867FAE8C82B29183B69687B49788B39888B59A8B
B79C8CB89F8FB59F90B7A193B5A294B9A799B5A699B5A89EB9ADA4BBAEA7BDB2ABBEB3AD
C3B9B5C1B8B5C2BAB7C4BCB9C7C1BCC7C3BECBC7C4CCC8C8C9C7C7C5C6C4C1C2C1C1C0C0
C3C2C1C2C2C1C2C3C4C2C2C3C5C5C4C2C2C1BFBFC1C0C0C3C3C2C4BDBDBFBEC1C2BCBEBC
BCBDBCBCBEBDBCBCBFB7B6BBB6B6BAAEB7BF839DBA2045797D7EAD974A6AA4172FB70D20
BE0917BC0712BD0610BC070FBB0510BB0511BA0915B40817AE0D1FA013289B2B42A75D7A
54325E553B638C4057930B1CA40210A8020FA5010DA3020E970817903D4AE1CBD6C8D0DC
C8D5E4C6D2E2C6D3E3C4D1E1C1CFE392A5BB869AAB8A9EAC778B9B8496A380929A788790
94A0A77C888D727B806E7A7D6A787968787667797565777565737B2F3E5A000E3D000B3F
01074000094200063D01083B0106350009320110331F33492E3C4429A92900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC83B837574
7272820809232B243A615260332A3C514C606C5E6E725D6A735A677860723F3456151E4D
26356A010D4B050D49473E657B5E73694A586A505B5F4A55553F4988666C97686D9B666B
9D69699C6869A37072A67778AA7E7EAD8681AE8C82B29284B59585B29685B09682B49A87
B49A8AB49C8CB49E8EB6A292B7A596B9A89AB8A79AB7A99FBBAEA7BCB0AABFB4AFC0B4B1
C2B7B5C3B9B6C3BBB6C4BCB9C4BDBAC4BFBCCAC6C4BDB9B9C7C6C6C4C4C3C1C2C1C1C0C1
C1C0C0C1C2C0BFC1C2BEC0C1C5C5C5C4C4C3BFC0C1C1C2C3C0C1C2BFBEC0BEBEC0C1C1C3
B8B9BAB7B8BABCBCC0BABABDB3B6BBA9B8C7375D8B34538AA2779E9C1933B80A1CC00914
C10711BF060EC00710BD060EBB060FBC070FB90913B50C16AE0D19A50A199F0B1D971025
922644863654B55B718F0D1DA10311A6010FA6010DA4010B9D051280101DD1A4AFCECED9
C8D3E1C5D2E1C3D1DFC6D4E49FB2CA24405F5E789199AEBD7F92A2899CA9C0D3DC86969F
95A1A978858A6F7C807180826A797A67767567787666777663737C1D2C4A010A3F010742
01064100073F01083E01093A000B3502123222384C4C636C28393B47463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064D1448A797A
4C4C610407233A344661566129263A4B4F6A403F5B64596E745F6F766075392E550F174E
091653020D4B16194E6F60806F54667559657659616F5660533F4B74595F8E666999686B
9C696B9D696AA06E6FA8797AA97E7EAB8580A9887EAE8D80B29283B09482B09682B29884
B79D8DB39B8EB7A091B7A294B8A697B8A698B7A598BAA9A0BEB0A9BCB0ABBEB3B0BEB3B1
C3B8B6C4BAB7C1B9B2C3BBB6C4BDBAC6C1BEC4C1BEBCBBBAC3C2C3C5C3C4C2C1C2C3C2C4
C1BFC0C1C0C0BFC1C1C0C3C4C3C4C4C1C1C1BFC0C0C1C2C3BFC0C1C0C0C2BDBEC0BEBEC0
BCBCBEBDBEC0BBBCC0BABEBFAEB5BB9DB2C81640776273A5964B6BAE1229BF0917BF060F
C20811C10612BF0511BC0510BC0610B70D13A7161BA42F379A37438E303E88202F8C1424
971125941227A92A3D9E12219F020FA4010DA5010BA3010BA0020F910A189F5563DBCDD7
CCD3DFC6D4E0C6D3E0C8D6E698ABC06D87A087A0B4A3B7C4C3D5E18598A391A3AE81929B
828E96768188707E83697C7D6A7A7A6D7B7B69777766767763737C293956010B3E000741
010743000A42010D40000F380618352D44524D646A52666A2A3B3D51514A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0061CB3BA28D8D
4D4D65060A254740505B505D1D1F3B17224E030B3C3433566A5C7069586F2E2650040843
010949030A453C37617E6982685061775C697758646D546050404B6751578B6467916064
9865699D6A6DA27072A7797AA77F7DA8827EAA867FAF8E84B19386AF9584B19683B09583
B49A89B39B8BB5A090B6A093B9A599B8A699B6A499BAA9A0BFAFA9BFB2B0BEB4B3BEB5B3
C4BAB8C2B9B6BFB7B3C0B8B5C2BCB9C6C0BEC6C2C0C5C4C2BFBFBEC0BFC0BEBDBFC1C0C1
C1BFBEC2C0C0BEBFBFBCBFBEC2C5C4C1C4C4BCBEC1BFC1C4BFC2C3C0C3C4BBBEC1BBBEC0
B7BABDB5B9BCB7BCBFB7BBBCB2B9C092A8C1133B77737CAF984461B21126C00716C00612
C00712BF0511BF0713BA020EB50510A6181BC47070A87E857963706A596B68506881556E
893D54851C308F0F219C0917A0020FA5020DA504109E010DA0020D990612811B2AD9B6C2
CDCEDAC5D3E0C4D2DFC6D4E392A5B6A4BBC9ACC1CF7B8F9C8597A283939C85959D87949B
7E8B917681866D7C7E6779796C7D7E6C7C7D6A797C6675786270783A4A62010A3B010941
000942010D4103143F192E463F55604C62644F636353676831424451554E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC22E886F6A
3A384F0F122B534958574B5B0C1032020B400209451B1E4B62597066566D25214C020944
0009471012456B5D7E776074624C5E7059686E57635F4E5A4A3C486850578A6164925E63
9D686CA26F70A17071A37676A37A77AB847EAA847DAF8D84AF9185B19788B29787B69A89
B49A87B6A08EB49F90B6A294B6A297B6A59ABAABA0B9A9A0BFAFA9C1B3B0BAB0AFBDB5B3
BCB5B3BDB8B5BEBAB6C1B9B7C4BDBBC3BDBCC7C2C1C5C1BFBEBDBCC0BFBEBFBFBEBEBFBE
BEBFBEC0C0C1BCBEBFBCC0C0BEC4C2BFC3C4BCC0C3BFC3C7BEC3C3BBC1C0BFC4C6B7BEC0
B2B9BCB4BCBFB8BDC0B8BCBFAFB6BD98ACC4163E7A616FA5954968B11327C10918BF0512
BD040FBC040DB9010CBB030FB20812AA3336C39594A59DA299A0A696A0AA7E879B515873
4B4665735572813C54831525970A169B030E9600099501099C010C9A020D880A1CB37685
D8CFDBC7D3DFC5D3E0BAC9DD647D97738FA3657F8D6D8592879AA493A3AA829097A7B2B8
808D93798589707E7F6372736B777B6B7A7D6575766574766573794B5B6F010C3C000B41
020E3E0C1D41394D64566B725163655165645267644E6563364C4D47504C1E981200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE115B09284
3F3B4F1B192F5C4E5D473C5103062D020942020947101343665D77675B731B1A48030A47
030D47312F5977637C7E66765848585B505E5A4F5A50475346374473535C8C5E64915D62
996568A06E6EA27372A57778A67B7AA7807CAC867FAF8D83B19387B19488B29688B39887
B49A88B69F8EB39F90B39F91B29F92B4A398B8A99DC0B1A7C0B1A9BBAEA9BCB1B0C1B6B5
BDB5B2BEB8B5BCB8B4BFBAB6C3BCBABFBABAC6C1C0C5C1C0C1BFBDBFBDBBC1C1BEC0C2BF
BCBFC0BEC1C4BEC0C4BABEC1B7BDBCBBC0C1BCBFC4BCC0C4BCC1C1BDC1C1BFC2C3B9BCBE
B9BFC1B3B8BCB4B8BCB6BBBFB1B8C0A4B7CB214880415A969D6588A7162BBD0816C10513
BF040FBE050DBB020DB9020DB20713A73338C3999AA6A1A19BA2A3BAC4C5AEB6BD959EAD
75859C3C4B694542637B547281273E8C091895020E98020B9C020B99010B930617822939
DEC4D0CED4DDC6D5E29DAFC918375B58799297B2BFA3BBC5899CA5B8C8D08F9BA5838D95
7B868C728083758183717E7F6C797A6877786778776678756776795A697905143904153B
2638514C616D5A6F725F7373596B69546765516868425C6038505835434525A21E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B89683
352E402C273C5E505F342C44010630020A43030A470B0F3D655E794D45630A0C3C020B45
0B11445E55767F65797E6473554B594B4857484453433B49543E4A774E578B565E965F65
9B656AA16E70A47274A57778A77A7CAA8080AA837FAE8B82B19085B19286B29686B19685
B49A8AB39B8CB49E8EB19D8EB7A397B4A398BEAFA4C2B4ABC1B3ABB9ADA8BBB0AEC1B6B4
C2B8B4BEB6B1BFB8B4BDB6B4BCB8B6C1BFBEC3C0BFC3C2C0C0BEBCC3C1BFBCBCBBBEBFBF
BABCBCB8B9BDBBBDC1B9BEC0BBC1C1BCC1C3BDC1C5BCC0C3BEC3C3BDC0C2BFC1C2BABBBE
BDBFC2B9BDC0B2B4B8B4B8BCB2BABFAEBCCC4669971C41829A82AD941D35B60A19C10614
C20410C0050EBF0510B9030FB50815A3272EC69495A7A09DA0A5A4A9B3B2A3ACAE939BA1
8D9AA596A7B9798BAB25315C785C827B1D34980818A004109E030D9C010A990312800C1C
C28F9ED3CFD8CCD5E49CACC17B95AF95AFC38EA2AEAEBFC983919C7D8893838C977C858C
7B868B737E82747F816F7E7E6C7B7B697979677A78677876677777617277273B4A3E5261
566972586C6D5C6F6E6174725C6E6E52686C425B69152C4223394E27394244413800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C49F84
382F3D3D374A5D515F231E38030732020A400109420D123D63607E282547010639020A41
25254E76647D816172826170634F5C4A3D4E4F42515A455276515C8350598F565E996167
9F696FA16E72A27074A5787AA4797AA87F80A98380AE8A80B49486AF9182B09583AE9585
B3998AB4998AB49C8DB39E90B8A59AC2B0A7C5B5ADBEAFA7C2B4ADBAAEA9BDB2AFC1B7B5
BFB5B3BEB6B0BEB5B0BFB8B6BCB8B7C1BFBEC4C1C0BFBFBDBEBEBCC0BFBDBCBBBABAB9B9
BDBEBEBABBBDB7BBBCB9BEBDB8BDBDBCC1C3BEC2C6BABEC2B9BEBFBBBFC0BDC1C3B5B8BB
B8BABFB9BBBFB6B6BAB5B9BCB3BABDAFBAC2809ABC16407F7078AC93425CAE1121BF0815
C20612BF040DBD030FB90311B204119D121CC27E82AB9F9D9DA3A2939D9E9DA8AAA3AAB1
8D97A0B8C6D1C8D8EE415985283064804D6D880B219703119601099D030C9E0211900819
914152DFCAD6CDD1DF8C9AAB97A9B98B9EAD788A99808C9787919C7A848E9FA8B2838D93
7782877983876F7B7C717F7F7281826A7A7B6679776879786978776175715C716E546768
596B6E5C6F705D70705C7174586F7A364E63091D40000F38192C492037424D4E4800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BF9570
3F31374840515B4F5E15122C020831010A3E010941151B4955577A0C0D3802073C060B3D
574F6F7D6274845F6E8C64728862716B49596B4957774F5B875661864E5890575F996167
9C666CA06C72A37175A27576A57C7DA67E7EAA8480B08C80B08F7FB19381AF9282B19688
B19789B3988AB49B8DB9A499BCA9A1C2B0A9B9AAA1C0B1AAC1B3ADBBB0ACBDB5B0BDB4B0
B8AFABBEB5B0C1B9B3BEBAB5BBB9B6C0BFBCBAB8B5BFBEBDBDBCBCBCBCBDBABAB9BBBABA
BCBCBDB3B6B7B5B9B9BABDBDB8BCBEBBC1C3B9BDC0BABDC1BABFC0BBC0C0B7BBBEB1B6BA
B4B7BCB6B9BBBABABDB4B8BAB5B9BBB3B9BEA7B8CC32558A2E4B86A57E9E99182BB90A17
C10610BD030CBC010DB6010DB3020DA70A16B05057B49999A2A5A48F989AB7C0C6D3DAE2
A3A9B4A6B1C0B8CADD6A81A611255B715E877818318D05148D000696020A9F0211980516
7D1223D4AAB7C6C9D9687C947B90A3677B8B7B8D9C8C99A3B9C3CD84909A919DA588969B
758085768183707D7D7684846E7D7F6A7C7E6779796679776878775F736C60746F5C6F6C
5B6C6C5E7274576F764C647721385A041644000C3F010C3C0C193C2035444E504E10CA08
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0069D547
5B48484F4354594D5E0C0A2702083005103D010A3B202855383F6901063A02073E1A1B45
6D5E767E5F6E8059678B5E6E885A6B8554667543537C4655844D5A8A525C9159609A6368
9D676D9F6B6F9F6C6EA27372A57979A67E7CA8847DAD8A7FAF8D80AF8E80B29387B3968B
B09589B0968AB29A8EB7A298B9A69DBFADA5C0B0A8C0B1ABBEB2ADBAB1ACBBB3ADBDB4B0
BFB4B1BDB4B0BBB5B2BAB6B4B9B9B5BABAB5BBB9B6BAB8B8BBBABCB8B8BBB5B5B9B5B5B7
BBBBBDBABBBCB4B7B7B9BABCB5BABBB9BEC1BABCC0BBBEC2BCC0C4BBBEC2B7BCBEB1B8B9
B5BABBB6BBBCB3B6B8B2B6B8B2B6B7B0B5B8AFBAC57791B51136727F7EAE913750B2131F
BD0811BD040BBD030FBA030FB6010EB107129D2029C28E90D2CCCC9EA5A9A1A9B1B3BBC3
9CA2AE8592A4617A92ADC7E0324A783C41727C3E5E870B1C92020C94010A99020C96010D
890A19A7616FB9B0C23F58757D98B0A6BBCBB3C3CF7F8D9597A4AD808F977482897A898C
778488707E7F6E7D7D6C7C7C7382846C7A7C6A797A6576756977766374726274715E7070
586D70576D7A354C68091D4900124A010C4A010B46000A3C04103622364C424A4E209914
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064CC3A
735A5557495850465906042204082D3137591A234825325D161F5002084002073B322E52
74607280606E845E6C845A69875A6B8351617843537D4654824B588A535E935B63996268
9A65699C6869A47171A57574A47676A47C7AA6827CA9887EAE8D81AD8D80B09285AE9185
AD9185AE9589B19A8CB39E92B8A69BBCA9A1C1AFA8C2B2ADBEB0AEB7ADAAB8AEABBCB1AF
BDB1B0BAB1AFBAB4B2B9B4B5B7B4B4B9B5B3BDB8B7BCBABABAB9BCB8B8BAB8B8BAB8B7B8
B9B8B9B8B8B8B8B9BABBBFC0B8BDBEB8BDBFB8BBBFB9BCC1BABCC2BCBDC2B8BCBFB2B7B9
B6BBBBB6BBBBB1B4B8AFB4B7B6BCBFB2B9BBAFB8BBA1B4C72A4D83324B88A475989C1829
B70A13BD060CBE0510BB020FB7010EB40310A10D15B46568B4A2A1A1A6A996A1A88D99A1
BBC5CC96A4B25C758BBDD7EA7B95B911265A745B8376112695061594000A97020C97030D
950713831A28AA8191929EB199AFC180939F8B99A17F8D927E8B937B8990758389718082
7A86896F7E7E7181816C7B7D727D7F737F7F6C78786975736C78786676766073745D7379
465D721C3156021144000C48010B4B00094D010A49010A3F010C37263C56313E4625A21F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064C933
8264575C4C5742394C02021F0C0D2C58566D262948222E5B020B40020741010336373152
725D6D7A5A6884606F835D6B815865875A677A4955804C58834F5B8E5965915A64925C61
9965689B6968A1706FA67575A57577A67A7AA47E78A7857CAD8C81AF8F81AF9082AC9081
AF9486B19A8BB39D8EB8A596B9A89ABDACA3BCABA4BBAAA5B9ACAAB7ACA9B8ADABBEB3B1
BAB0ADBCB3AFBBB5B1BCB6B5B6B1B0B9B2B1BAB4B3BBB8B8B7B6B7BCBCBDB8B9B9B9B9B9
B5B6B6B3B6B5B8BBBBB7BBBBB7BBBCB8BCBEB9BDBFBDC0C2BFC1C4BBBCC1BCBEC3B7BABE
B9BBBEBBBDBFB4B7BCB4B9BDB1B8BBB0B9BAB3BABCAEBAC36681A7133677837DAE8A2D45
AE0E1BB9050DBA020EB9010CB9020EB7020EAD0810A13136BE9698AEACAFA2ACB18E9BA3
D1DDE4C9D7E08DA1B1A0BCD287A7C91B396D454678752F4C8C071B93010D95000A97010B
98030E8706108D434D9388927F8F9D7E929E8B9CA59FAFB67D8A93A2B0B788969D738284
7A8788718080717F806E7B7C6E7B7B74827F6976756A777766777763797D5A6F7D344B67
0A1D4C000E49000A4B00084A01094A020B4E020D4C010D4107183C374D61233139453E34
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0065CA30
9B786562505637304103041D242036625769252441111B4B010A43010842010638393454
745E707C5C6C805E6D886170845B698256617F505A7E4B55824C588A535F8C575F905D61
9664679B696C9F6D6FA47173A57376A47777A67E79A7837AAC8A7FAF8F81AF8F82AF9184
B29888B09988B29C8DB4A192BDAC9DB8A69BBEADA5BDAFA9B7ADA8B7AFABB5ADA9B7AFAC
B3ABA7BBB2AEBBB2AFB8B2AFB7B3B1B8B4B2BAB5B4BAB7B7B7B6B7BAB9B9B9BABABCBDBD
B3B5B6B7BBBAB6BABAB6B8B9BDBFC1B8BBBCBFC2C1BCBEBEC4C5C9BEBFC4BBBFC3B9BBBF
B7B8BDB6B8BCB6B9BEB5BABDB3B8BAB4BBBBB1B6B8AEB6BB9BACC521447C3D528D9A6786
9C1426B60815B9040FBB0410B9020DB7020CB406109D121BB87479D5C8CCCED3D997A0A9
A8B6C0A6B5C08496A927486D5882AD5C7FAD12245C78567B790C249505139B030D970109
97000A92030C8018209B777F5E6C7996B0BC899EA8BACBD386959D7A888F7C8A92738185
717F807382826F7C7D6C79796B7A7B6778776B7C7D64797B59727A4C677C1F345B021247
010C4C010B4E01094E010A4D010C4D000D4C0110490D1F473C51645367701C29304A443D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B28C706856592B26350505193933446053621B1836040C3F010A420D184B1018442F2B4D
715F737B5E6D7E5C6B865C6C8759698657647F4E587F4C5587535D8C55618F5B63966467
96656899686B9D6B6FA26F72A47275A37677A77F7AA58077AC897FAF8D81AF8E83B09185
B29889AF9789B29B8EB6A092C1AD9FB9A69DB9A9A2B5A9A2B4ABA6B6ADAAB6ACAAB8AEAC
B6ADAABBB2AEBBB3AFB8B2AFB6B2B0B8B4B4B8B4B5B6B4B6B9B9BAB5B5B6B9B9BAB6B6B9
B6B6B8B7BABABBBDBFBABCBEB8B9BCB6B8BABDBFBFBDC0C1C1C2C6BABCBFBABEC1BABCC0
B7B9BCB8BABDBABCC1B4B9BCB3B8BAB3BABAB5BBBDB1B9BCAEBBC85C7BA21335738C80AB
8C263DAE0C1CB60410B6030EB7020DB7030CB4030CA709129F3C42BF9FA4A9A7AE9AA0AC
7585989AAFC1BACCDF3F5C7E557CA1A2C1E3173063524B7B71233E90081A9D02109C020B
99010B97030D870711925059A3A0AAB1C4CD8091998393997D8B917E8A907D898F7A888B
707F81738382707E7E6B79796C7C7C67797A6B7E845B74813954710D235400104E010B4E
020B5000094C01094D000C4E01104E03184A21375C50657658687056686C222F35474543
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B18565735D602A223308051B4E45535C505D13113202093D020A412C325F1E2048211F40
7164777F6372825F6E83596886596785586283555D804F578957618C58638C5860946266
96656599696B9C6A709D696FA37174A47777A87D7BA9837CAD8A81AC8B81AC8C81B19485
B29788B0988BB1998DB39C8FBBA498B8A59BBEAFA5B3A9A2BAB2AEB7AEACB3A9A7B5A9A8
B8AEACB8AFACB7B1AEBAB5B2B3AFADB8B4B4BAB6B8B8B6B8B7B7B9B7B7B9B9B9BBB8B8BB
BABABDBABBBDB9BABDB9BBBEBBBDC1B8BBBDBCBDBFBCBEC0BDBFC1C0C0C4BFC1C4BFC1C5
BCBEC0BEC1C2BCBFC2B2B9BBAFB5B8B5BCBDB2B6B9B0B8BAAEB9C095ABC5173B774B5A94
9C5E7C9D1122B30512B7040FB8030DB7030DB3020BAF051097131DBA7E85B7ADB4C9CED6
7F8EA1849BB0CDE0EE97AFC188A5BBC1DAF15268931F2A6274486E7D0A209803129E020E
9A000D97010D92051282242F9B7E868E969C909EA67D8C92A9B6B9838E938793988E9DA1
7181846F8080728283697A7B697B7D63777E566E81263E6303164F011054010C54000A50
00094D010A49020B4A000F49091E4C3B536F5D73815F7277617274596C6F2D3E453E4042
1D961000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D6B436F555422192B120E22594E5A564A5909072B02093C070E3F55547B2B284D151739
6E647979606E7D5C6B855E6C8A606D855A658557607C4B538351598C5861905C62956166
9765679D6C6F9E6C729D6970A06E72A57778A37A77A57F7BAA8781AA897FAB8D7EAD9282
AF9585B19889B29A8BB59E90BAA59AB4A398C0B0A6B1A49DB9ADABB3A8A6AFA5A4B6ADAB
B2ACA8B7B2AEB5AEADB7B3B1B6B4B1BAB7B4B6B2B2B6B4B4B8B7B9B9B9BAB9BABBB8B9BA
B8B8B9BDBDC0B8B9BDBCBEC1BBBFC1B8BCBDB9BBBDBDC0C2C0C1C4C0C0C4BEC0C4BEC1C5
BBBFC2B9BDBFB9BEC1ADB6B8B0B7BAB6BBBFB3B7BBAEB4B7ADB7BDABB9C84C69991A3879
9983AC8A1E33B10B1AB6030FB7020AB6020CB4020DB10410A10914A0464EC3AAB3D8D8E0
B3BCC98EA2B591ACC087A4B64B687CB8D0E39CAFCF1529605143746916308F06179A0212
99020F96010D970410800D19956168A3A2A7B0BEC585969DA2AFB48994977B878C768387
7281846D7F826E81846C7F84647A8548617A122957021454000C55010953020B53010A50
01094D020C4A020F470A2049476177677D86657A7C5F73755C7171566B6D3C4F562F3639
229D1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB21F7E625A2119261F192A60525E4A3F5006062A0107371F224B6A6582312E510E1135
6C647C78606F7A5B69835E6C885F6E85596785546085525C88555C8D59618F5A62925D65
98646A9A686C9D696F9E696FA37074A57579A57B7AA47D7AAC8680AE8B80AC8E7FAB9181
AC9385B19787B09786B49D8FB6A097B6A29AB9A89FB8A9A3BBACAAB3A6A4B3A9A7B4ADAA
B0ACA7B3AFADB1AEADB3B4B2B0B1AEB6B7B3B6B6B3BEBEBDC7C8C9C4C6C8BDBFC2BABCBE
B5B6B7B7B8BBB6B8BCB7BBBEBABFC1BBC1C2BCC3C4BCC2C4BDC2C5BFC1C5BFC1C5B8BCC0
BBBFC1BABFC1B7BCBFB6BABEB4B8BDB2B6BAB7BABFB1B5B8AFB5BAB0BAC389A0C0143978
5B669D8C48669F0C1FB20210B7020DB7030DB4020EB1020FAA0612941B25B7848CAAA4AE
9DA7B3687F982A51778BB3D08EABBEC5D8E6C8D7EC3F537F262E63744262800A20910213
93000C94010C96010C8A071286353D9F8F91ADB6BC8593997E8B907E898B7C8688758083
7281846D7D806A7D846379883C5675081F53001258010C5701095401095000094F01094C
01094C010B48031242415B72647C846B8081687C7B6076755E7374596D6F4E60651F292C
27A32000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB61D7458471E17202E283363555F39304604072D040A34413F5F6E647B3A355506072F
665E7A7760717C5D6B815C6A88606E8559668451608856628857618C5863915C66945F69
925E669561669A646AA16D72A16F73A57578A67A7CA57D7CAE8680AF8A80AE8E80AE9282
AC9282AF9584B19988B39B8EB59E96B6A29AB6A59CB9ABA7B1A4A3B7AAA8B2A6A3AEA5A2
AEA9A5ADA9A7A8A7A7979998939695ADB0AED1D4D4DBDEE0DBDFE3DBE0E3D6DBDFC0C4C9
B7BABDB3B7B9B2B7B9B7BDBEBABEC0B7BBBEB7BEBFBBC2C2BABFC1B8BDC0BCBFC3BDC1C3
C1C5C6BBBFC0BBBCC0B8B9BDB2B5BAB5B8BDB6B9BDB2B6B9AEB2B6B2B8BEA5B4C936558B
203D7F957AA28B172CAD0716B7020EB6020DB2000CB3020EB1030F9D0A18A553628D808E
CDD9E593A9BF1D446B6E99B6C6DEEDCBDBE4CAD9E7889BBB0F215667567F6E142D8B0517
92010D95020A96010B9304107D121CA1777986878A8793967A888A8D9B9B8A97996B797B
7182826A8081607A87355173061D5700135A010F5C010C57000C51020E4D010E4903124C
010B48000D431F335559727D657A7D6A7E7E677B7B5F74775D73775B6F73596C70152227
463E3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
58BD217C5D4620151C3A2F3A675763261F3904082E0A0E325B556F726478433D5D060834
50496B755F727B5C6A7C5B66825C698257648758658656628C5B668C58638F5B64905C65
9563699766699662679F6B70A06E72A47578A57A7DA88081AA8280B18B84B29085AF9181
AF9381AE9381B09886B0998BB5A197B6A49BB6A69FB6AAA5AA9E9BB0A5A1B0A5A1B0A5A2
ACA5A2A29D9B949392A7A7A6AAABA9C6CACACFD3D7BEC0C7BEC2C8CFD4DADAE0E7D2D6DD
B6BAC0B7BBBEB6BBBCBABEC0B8BBBDBBBEC0B5B8BABEC3C4BEC4C4BABFC1BDC1C5BEC2C6
BCC2C4BABEC0C0C0C5BCBDC2B9BCC2B7BBBFB6BABDB1B6B9AEB3B7AEB3B8AAB4C1788EB4
103373696FA18A3C56A50D1EB70612B6020EB4010DB5020EB5030FA90613922234876473
C4CCD8C8DBE97D9AB4769CB4C0DAE7C9DBE3CAD7E5BFD0E72C417033396C70355782091F
8F010E94010A94000894030C860813934951908184BEC6C98F9DA08796968A989D607376
6A7F81637F89304D70041D5900125C01115E010F5D010E5601124C061B492E456A1F3563
020E47010F40425D725D767A65797B6A7E7F657A7E59727C4B6777445E6C5069721F3138
3C3C3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0087604425141941333F66596717143203072F1E1F406C62767464774D4467070B3C
3C39607461767D5F6D825F6C8057668358668A5D69895A648C5A64905E688D5B65905D65
93616797676B97666A9C696E9F6D72A27377A6787EA67D7FAB8482B18C85B29185AF9183
AE9081B09281B29888B39F90B5A296B6A59CB1A29AB3A69FB3A6A2BAB0ADACA39EADA5A1
ABA6A2908C8AADABA8B0B0ABAFB2AED3D7D89FA2A8B3B4BCB7B9BFB6BEC2D8DFE3DADEE4
B9BDC4B9BDC1BCC1C4BABEC2B6BABEB5B8BCBABDC1C3C7CABDC1C4C0C5C8BEC4C7B9C0C4
B9BFC3BCC1C5BDBFC3BCBDC1BABDC1B4B8BCB7BBBFB3B8BBAEB3B7ADB1B6ADB3BDA2B2C8
2D4E822A447E997394931528B10616B5020EB6020DB6030EB6010DAF0310960B1AA86472
9C96A89BB0C37E9AB130566FB9D5E4C9DAE3CBD7E3C9D7E96F82A90F1E576D517C6F0E27
8B031393010D94000993000A900411841C279F777E98989C8993997B898C7482865B6D72
657C8938547403195702156200105F01135F02145B021651172E5746607A506983081D49
02134A051743526D7E60787B6A7E7F677C7F627886334B6A08204B041D4338546B2C4550
2D31330EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AA7F5E2C171A4D404A5850600A0B2B04082E3D3953695B6C6E5E7253496F06093E
2726536E5D757C5E6D805C6C8159668458658759648957628B58628E59658A5562915D65
9462699A676E9B676D9E696E9C666BA47275A97A7EA3797AA9847EAD8C83B19085AE8E81
B19285B19286B2978BB49F91B6A497B5A29AB5A59DB4A79EB4A9A4AFA6A2AAA29EABA4A0
AEA7A58D8987B0AFACADAEABB5B8B6CED2D39B9DA3B2B3B8B2B6BAB3BCBED5DFE1D6DBE0
B0B3BAB8BCC2B5BABEB7BBC0B8BBC0B9BEC1B9BEC1B9BFC2BAC0C3BAC0C3B8BEC1BABFC3
BEC3C6BCC1C4BEC1C5B9BBBFB7BBBEB2B6BAB6BABEB4B9BCB3B7BCB0B4B9AEB3B9A4B1BD
6882A710346F77749F872D44A80B1DB60411B8040EB6040CB4010CB1020DA50715932D3E
745E7A647E9DA3C2DB638398C8DEEBC9D9E1CBD8E2C9D7E3B4C5E01D3162413E70682341
85061994020E96000C94010C9402108408169B58628F8387838B8E808B8F76858A62767F
475F7D061D5801136001136400115E011559061E53314C6D556F82577182294061001344
1A35660A1D46557081627A7D667D82617A8833496D05174F01115001124A13294F3B5467
1C262A1E981300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE815A2C18154E424A453F5106092A0C0D2F584D62695B694D43595B5779080C3E
101344695D7A7D61727F5C697D5964875E6A895A678956628B57628C58628D58638E5960
9461679A676D9C686F9B686C9E6B6EA57476A6787BA97F7EA9857EAD8C82B19084B08E81
B19184B09388B1988CB39E90B39F93B09D95B1A299B0A49BB0A7A0ACA3A0ACA4A0B1AAA5
B2AAA78A86859A999BB1B1B3ACADB0C2C6C9B9BCC0ACAEB3ACB2B6C6D0D3D9E1E5C7CCD2
B8BAC1BABBC2B8BBC1B9BBC0BCBDC1BABEC2B5B9BCB7BEC1B7BFC1BEC5C8BBBFC2BEC1C6
BEC2C6BDC1C5BABDC1BEC0C4B8BBBFB2B7BAB3B9BCB2B9BBB4B8BDAFB3B7B0B4B9A7B1B6
9AABC2224479334780956384961126B00413B6030FB6030EB4020CB1020BA903118F0C1F
8C56713F4C6BAFCBE1C3D9E4C9DCE6CAD8E2C9D7E2C6D7E3C6D6E85C7095152255704A6E
760A1E90021193000C93000B93010E8B04128329349B8082999D9F939FA26D7D875D748B
0E285B03176302136603166401145719305F4C67805F788361778149637A061D490C2251
3A55800316404B66805D7786557085254169021753010F54000C50000F4A0214423A536C
121E272A631D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00BA8E5C311C11574B51352F430407281C1A356456655C526222223B5D61810A0F3C
050A3C544D6F7A61737C5966825D68855A698A5A6A8756638C5B6585555E8C59618D585E
9360659B68709D6A719F6C71A06F729F6E72A5777AA87D7FA88380AC8B83AF8F84B19084
B19186B3968BB0968AB29B8EB39E93AE9B93AB9C93ADA199ACA39DA9A19DA9A09DB6AFAB
ACA4A2A49E9E8A878A8E8D918D8E91B1B4B6D4D7DBD1D4D9D2D7DCD3DAE1BFC6CDB4B7BF
B7B6BDBBBBC1B9BAC1BCBDC3BCBDC1B9BBC0BBBEC3BFC4C8BCC2C5BEC2C6BCBFC3BABDC2
BBBFC4BCC0C5BFC1C6BCBDC2B7B9BDB4BCBEB2BBBCAFB7B8B1B8BBADB4B7AFB3B8A9AFB3
A8B5C05B769B12316F8376A386233CA90A1AB20211B5030FB4020DB0010CAC0210A00919
98394C99879D92A6BBC9DFE9C9DBE4CCDAE4C7D7E3C4D6E1C6D5E3A4B5D1132656534973
6D1D3685041390010C91000A93000C91020F7C0C17A06E72898484818E916D7F90263F69
021A60011466021463041B5B29416A587085657A8164797D5C74831C33590116482F476C
455D7F001244183061374F7C162D6201175A02155F010F58000C51020D49001042283E5E
192735312B2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0058C22C402615564A5028223B0408282F2C426356624841560A0F2F5A6084161A4A
01073D3A385E725D727958667E59667F56658557668B5A698856638857618B5A618D5B60
9360669663699C696E9C686DA06E72A16F73A77579A77B7DA98381AB8983AD8D83B09084
AF9285B09488B59A8EB59C90B5A096AA978EA3948AA99D95A99F9AA19796AEA4A3ABA2A0
B1A9A7B1ABA8ABA7A5ABA8A7B2B1B0ABABADABABB0B0B3B7B3B7BDACB0B8A6ABB2A6AAB0
B2B3B8B8B9BEBCBEC3BCBEC4BDBFC3BDBEC2BBBDC2B7BBBFBCC2C3B8BCBFBABDC2BABEC3
BCC2C6BAC0C4BCC1C6BDC0C4B9BCBFB2B9BBB6BDBFB1BABAAEB7B8ACB5B7AEB6B9AAB1B4
A8B1B993A7C018377145548D9055749B1125B00314B50210B3020DB0010EAD0110A70411
92142595687C5F6E83C7DDE9CADAE4CBDAE3C9D9E2C7D7E0C8D6E1C4D5E742587E2A3262
6F3E607A0B1E8F021093010C95010B94010B8706108B3F439581817D868D576D89051C5A
011767001563051C5A365073627989697C81687B7C627880324B69021949112853576D83
52677F03154800135600115A00115D00106101105F021059010D52000E49000F4217294C
2736482F2D2E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF005EC42B5433205547511C1834070A2C4A43596557672D28450409324E537A212452
030940161845685A737B5D6C7E5D69805966825663875564824D5D8854628B5A658B5A62
91606596666A98696D99696E9E6C719D6C70A67778A67B7CA67F7DA9857EB08F85AF9184
AE9284AF9488B1978CB49C93B39E96AB978FA6958CAB9E96ACA29DA09795ABA1A0A69C9A
ACA3A1B5AEABB4B0ADB6B3AFB5B2B0A8A6A5A6A5A7A0A0A1A3A2A6AEADB2A5A6ABA5A9AD
AAADB1ADAFB3B1B4B9B7B9BEBDC0C4BDBFC4B6BABEB9BEC1B9C0C1BAC0C3BBC0C6B7BDC3
BDC5C9BBC2C7B9C0C4BCC1C4B8BCC0B3B9BCB2BABCADB4B7AFB5B8AFB7B8ACB5B8A7B0B2
A6AFB5A2B1C244608F1735748D79A1891D35AB0718B60412B50210B1010EB0000DAB020F
980818944B5CB1ADBDCEDDE7CDDBE4CBDAE4CAD7E2C9D7E0CBD7E0C8D6E296A7C2142451
634B7370142E8A041593020E95010B9200098D030D7A151D9E767C7F8595223A68021A65
02196905215E3D597B637A876A7E816C807F6B7D85496078081F4C051D4B455D786B7D86
657685132750021358010D5D020D61000C5F011060011058000F4C071A4B0719410E1D3C
3748572C2F310EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0067CA306D48354F414D13102E0F0F305B516660546915123903093840446B32355E
040A3E05093B4E48677661727A5A697C56647F53618553618A55658C5767905F6A8A5B64
8F606794656C996A719D6D759F6F749F6F72A37676A67E7CA98481A9847EB18E85B09085
B09489AF958BAF968DB39E93B09D93AD9992A8958EAB9C97A89E9BA79E9CA89F9CB0A6A3
B1A9A5B4ACABB9B5B4B6B5B3B4B3B1B4B2B0B0AFAEA9A6A7A09EA1B4B3B7A7A7AB9DA0A3
A3A6A9A5A7ABABAEB2B2B6BAB7BBBFB2B9BCB7BDC0B8BFC2B6BEC0BDC4C7B8BEC3B9C1C5
BCC3C8BAC1C7B7BEC1BCC2C4B9BEC1B4B9BDB4BABDB1B6BAB4B8BCB0B6B9AFB7BBA9B3B5
A6B1B4A7B4BE8298B9133573525C918E49679E0E20B30513B60210B4020EB1010EAF0210
A40516922A3AEEC6D5DCD3E1D8D1E2D7D2E4D5CFE1D2CCDED4CCDFD3CADFCDC5E0494168
583A5D84334A8404168E010E93000C92010B8F020C7D06108E505D77758E0A1F5B011867
0721643D5C80627B88667A7D6C81826D8389596D8510265200154826405F657B876E8183
6D7E883F5471031551011059010D5B010E5C01115B0217530F2651445A7534475E07172D
42555E2A31321C941100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007F593E5448530B0A281C1A3665596B50465E070833030A3936395C474668
02053401063B262850695F75765C6B7A55627F546181505D8854638A55648C58658E5D66
93626B9A6871A06E779E6C75A07074A47478A5787AA57C7BA98380A98580AF8E85B09188
B0938BAF958CB0998FB29D92B09C93A9968EA99791AC9B96AC9E9BB1A6A4ACA39FAFA7A2
B5ACA8B3AFABB4B3B2B5B7B6ACADACB4B3B2B0ADAEACA7AAACABAFAEB2B4ABAEB0A3A6A8
A9AAADACAEB1A6ABADB3B9BCB3BABDAEB6B9B5BBBFB3B9BCB7BFC1BCC2C6BBC1C5B3BBBE
B6BEC1B3BBBEBABFC3BEC3C6B9BDC0BABFC1B4B9BBB2BABCB0B8BBAFB7BBADB5B9A8B1B4
ACB3B7A8B3B89FADC23453861935739578A089162CAE0A18B90613B3020FB1000EB20211
AF04179C0C21B44C66AA57749E5170974C6A9548679145669043668E41648D3F637C2C4F
862E4A8B1E328903138F010D92010D91010B8F010D8806147A2435624E7008195C031E64
37537F678091697E83677C7E678188567289142D5800164B142D535871816B7E836D8080
6D7D82697C8B21365C01144E0012550112560218511C395E4E687C5369714D5F6B041626
485C632B3536219C1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00946D4B4539430607242F2842695A6C332D48050C35050C374B4A68595370
05063102063C080D3E4F4B6B6F5C6C7A5A647C535D804F5C804B59854E5D8A55618F5C65
92616996656D9B6B739C6E759E72779F7578A6787CA97E80AA8281AA8682AE8D87AD8E88
AE928AAB9289B19A8FB39E94AD9991A7948EA8968FAE9F98ADA19CA79C9AB2A9A5AFA7A3
B1ABA7ACA9A79D9E9F9B9CA0AAABAEADADAEB7B5B6ABA7A9AAA9ACB1B4B6B1B4B4AEAFB0
B0B1B3A6ABAEA3A9ACACB2B5B2B9BCB3BABDB7BBC0BABDC1B8BCC0BBC1C5B9BFC3B8C0C3
B5BDBFB6BEC0B8BFC1BAC2C4B9BEC1BBC0C2B4B8BCB3BCBEAFB9BBB2BDBFADB6B9A9B1B4
AEB3B8AAB1B6A6B1BC798FB112326F6267998A415D9F1021B40715B2020FB2020FB0030F
B20212AD0417A70720A00B26990823980B249507229407229005229007238D04208D051C
8E05198F021390010D92010B92010B90000A8F000C8B0310780E20643F630B1758112D65
65809A6F848D6D8286677F88527089123160011D540C28534D677B667A806D7E7E70817E
6B7B7B6F7E83607382263E5B0C234D1029512E4A66607D895F787C536B6D495E67071B28
485F6533424126A31E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0072943B3A2D35070823423B51675A6E1A1936020B3414183C5F5771685D76
0B093101053B01073E191C485D536E795D6B7E556181505C84505C8954618C5865905F68
906268986A719A6E75956D758E6A71967378A47C81A47B7DA88080A78280AD8B87AC8D87
AF938CAB9489AC978AAD9A8EAB9A91A8978FAA9A92AC9F99A69C99ABA19EADA5A0B2ABA6
ADA8A68C8C8A92949695989C828489AEB0B3B2B2B4A1A0A2B2B4B5AAACAEBCBDBFAEAFAF
B5B6B7AEB2B4A2A7AAA9AEB1B6BABEB8BCC0B3B7BCBABEC3BBBFC3BABEC3BBBFC3B7BCC0
BAC0C3B9BFC2B6BEC1B8C2C3B6C0C2B6BEC1B3BABDB2BBBEAFB8BBAFBABCACB5B8B0B9BB
ACB5B8B2BBC09DA6AFBCCADD425F8F203B778C779F86273CA51020AE0714AF0410AC0410
B00511AE0511AC0512A60411A306119E07129B05119604109806139404129203108E020F
90021190031090020C90020B8F030D8D020C8F020E8B030E7A0A196F42600E17521B386B
67869E69828E667D903F597B0C285B001F5A0D2C5B4B687E60797E677A7B6D7E7C70827C
6C7D7B6F7F7F6A7B7D5F767B5B747F5D747D60767B6279795B7172536A6C425864071C2C
485F663C4B4B41393000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052BF2F281C200A0C24514C5F5C5468080C2C030B322D2D4C66596C6A596D
1C163A02053901064102073D27264F6C576E78536182566183535E83505B8A576190616A
93646B96696F996F7687636A896B747C616A95777D9F7C7EA47E7FA68281A98785A88984
AB9086A99185AD988BAB9A8EAA9A91A99C94A79B94A69C96A09693A59B97ACA5A0AAA5A0
9B99979A9E9DCDD3D2CACFD191959BA3A6ABABACB09397999EA2A4A6A9ABABADB1A3A6AB
AFB2B6A6A9ADA2A6AAA2A6ABB3B6BBB4B7BCB2B6BBB3BABDBBC0C4BBC0C4BEC3C7BCBFC4
BEC1C7BABEC4B8BDC2BAC2C6B9C1C4B7C0C2B5BDC0B4BCBEB0B9BBAFBABBB1BABEB0BABC
BBC6C9D1DDE2A3ADB7A9B5C08AA0BA2E4D7E32477C8A70968A374F921A2A98111F9C121C
9D12189C1618961618961B1C911A1D88161A8B191E86191D851A1F7F171D7B131879141B
79121C760F187B12197C10147D0F157C0C12810D157A0C126914198566761924550A2661
3B5C8C416088213D6D031D5A021C59163260536E85687F86687E7F667A796D807E6E807D
6A7D7C6D7E7F6D7D7D697A7A6B7C7B6978766977776678775A6E6E53696E2E45550E2337
4D626B49595C43413B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0058C3303321201310255D566747435902072B060C315049616F5B69715C6C
3126460304370105410105410708385343617452637C525F7F525C82525A8A5B6291636B
94656E966A7190676F936E7795767F755E677D686E9E7D81A78184A88284AB8787AA8A86
AC8F88AA9186A99489A9978CAF9E95A2948BA0968D9B948B9F9791A0969297908B9E9A94
A8A8A4AFB4B5D9DFE2D7DDE2A1A5ACA9AAAFAEAFB39DA2A5A3A6A896999BA4A6AA9FA2A8
A0A4AB9B9DA39DA1A79FA4AAB3B7BDB3B7BBB1B7BBBAC1C5B6BBBFBDC2C6BCC3C5BFC4C7
BDC1C6B9BDC2B9BCC2BDC2C7BBBFC4B9BFC2B4BBBEB4BBBDB2BBBEB6C1C2CED7D9B3BDC0
ABB5BBAEB9BFAAB3BBA7B5BCA9BAC5B9D0E8415F8D2E42726B658589677D87576D986373
A56E71A56E6DAB7774AB7A77AA7D7CA67A7BA67A7DA37A7DA57E809D7A7C97787E94747B
8364707B626D8C6A6E895F5E8B5F5E8D5B5B8E57598453538565638480844B5A760B2259
021F5E01205B021F58082357334C7260788B6E82887080836D7F816D7E7E6E7E7E728282
6E8081697B7D6D7C7E6D7C7C6C7A796C7A776674746373735D7072566A75152C421F384C
4F676E4E616040463F0FCB0700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF005BC32C52392F1B1223665D6D36324D050A331B1C3E615668715C67735C68
4D3C5A0602330307400206400A0A395E4D69775364794E5B7C4D5881535B8C5E679C6E78
9C6E78976B758E646E936C77896A7677616B7A64699D7C7EA78082A98285AA8687AA8987
AD8F8AA88E86AA968CAC9B92AB9A91A6998F9B92889E968C9A938AA19993968E8A9D9A95
BDBDBAB7BBBDB6BCC1B7BDC4B6B8C0ACAAB0AEAEAF9EA2A39A9C9F9192949C9B9F98999E
989AA094989F90969B989EA3B8BEC2B3B9BDB2B8BDBCC1C8B7BBC0BBBFC3BEC3C6B7BEC1
B5BDC0B5BCC1BBC1C6BAC1C4BEC5C8BCC2C5B9BEC2B7BEC1B5BCC0B2BBBFB7C0C3B3BABE
AEB5BBB3BCC2CED9DEA7B7BF9CACB7C9DBE6A9BED47F98B87D97B2A3B6CB617595425A79
C0CED8CDD2D4D1D3D4D2D4D6D3D3D6D2D4D7CFD2D8D0D3D9CFD3DAC7D0DE7389A1ADC0D6
5362754155658B959D7E8182868A88A0A19F8785878B8D8D9CA2A07985867A8892576A84
334A6F2C466B405A785D75896E838D6E82857081847181846F7F7F6E7E7E6F7D7E6E7F7E
6E80816D8082697A8064757A6576766273706476746274745C6F7745596E03163A27415E
48656F506665424B43209B1300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE01361412D271C246860701E1E3C040B3131314B6B5D68705B62755E69
5F4B620D063103063D01043A12103C6A567076506180536183545F885965936571986A76
996A779A6B77956B7687626D836570775E658B6D70A07A7BA67F7FA88282A78484A68785
A88C88A38B84A8938BAB99929E8E869D9187A2978EA1978E9F978D9D958C98908A93908B
ADAEADD6DADCD1D6DAD5D9DFBCBDC4A9A9AEACADAFA3A8A8A0A4A5A2A3A3ABABADA0A1A5
989B9F93979D888F93969D9FB2BABCB0B7BBBABFC7BBBDC6BCBFC5BEC1C7BCC0C5BEC4C7
BDC2C6B9BDC2BABFC6BBC2C7BCC4C7B6C0C1BBC0C4B5BCBFB5BDC0B2BABEB4BBBFC2C8CC
BDC2C8B0B8BFD2DCE2AFBCC798A6B3A0AEB9ADBFCB97B2CA5F84A7B7D9F46384A45B809F
C7E2EECEDFE5D0DDE4D1DCE3D3DBE3D0DAE2CCD8E1CAD7E2C9D6E2B4C5DC223E655F7D9A
74899A6B7E8BADBDC5A3B0B688959BC5D3D994A1A77B898C808F917787897B888D76848B
73838E6F828C7084897183867484877083837385867284856F7F7F6C7D7B6D7E7C6F8280
6E82816B8182566B76364F5B5B72775E72705E72715870754E657A12244A000D4001123E
233C554E686F4755522F6A1E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006F4929342225695F700F0F2F080C304D485C6F5C61715C5E755E65
6C586A1B133702043503063A19174169546D7753627F545F8355618659658E606C92636F
9969759A6B76986E78946D77906D759A787D9D787BA57D7FA67E7EA67F7DA4817FA48683
A18681A18A83A8948BA39189A6978EA4988EA1948CA2968E978D85958C839A918997918B
989594B5B5B7C0C2C6B1B3B7A0A1A4A0A0A4A6A8AAAAAFAFA6ABABACB0B0AEAFB3A5A6AA
9B9EA2999DA2888F929DA5A7B0B7B9B2B7BBBABFC4BEC2C7BDC0C5BBC0C6BAC0C5BBC1C4
BDC1C6BDBFC5BFC1C7BCC2C7B9C1C5B9C1C4B8BFC3B7BFC1B6BCC0B4BCBFB4BBC1D2DBDF
CAD0D6AFB6BDAEB7BDB1BBC4AEBBC995A9BCC8DDF0728FB50D39735982ADA3C2DAB2CDDF
CDE1EAD0DFE7CFDCE4D0DEE5CFDDE4D0DCE5CDD9E5CDDAE6C9D7E4B1C0D3596D8AA1BBD1
B8CBD9899AA8A8BBCABFD0DE7E8E9B83949D808F9678888A798A8D79888C7A878D768286
7785887585887284857385857386866F84836D81817688887282816F827E697B796F8281
6E81806A7E7F3F56650E273E57747D566E71556D763B546A11254E020F45000945000B41
03143C3B576848595B3C372B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00875A31422A2763576B09082B131435655969715C5E6F5A5A715C60
6F5C6934294703033103053A1B17416C566F7854638157638458648D626D91656F93646F
9969749B6D77996F789970789D747B9F777BA37B7FA67E80A67D7EA57E7DA3817EA58582
9D807CA3898299837BA6948BA3948B9E9389978C839A8E869A8E869D928A9F958E9C948D
948F8B9995939998989A9A999A9A97949493A3A6A7A4A9AAACB1B2A5A9ACAAADB1ABADB1
979A9F95989C8E92969BA3A5B3B9BBB3B8BBB6BEC1BAC2C5B5BDC0BDC5C8BCC4C8BCC4C7
BAC0C5BAC0C6BAC0C6B8C0C4B7BFC3B8BEC4B8BEC3B5BBBFD1D5DAC2C8CEB2BBC1B5BEC4
B2BAC0ACB7BBA6B2B6CBD7DEAABDD5415F81A6C0DB9CB5D343648E6489ABA5C1D2CCE2E9
D0DFE8D1DEE6D0DCE5CEDEE5CEDDE4CBDBE3CCD9E5CCD9E4C9D8E2C3D4E399ADC55D7D9B
98B7D19AAFC45B6E828393A47B889476848D88969A8191927B8A8D99A8AB768588798789
7583857382847584847383847283836F81826F82847283857181816D807F6C7D7E6E8182
6D7E81697E7E4F6573051B354E6C7E4D6A7B2B4262051643010B44010A45000944000B40
000D3C243C564B60633F3E3400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006986254D332954495A0606282626426B5E68725F60705D5F6D5B62
715C6A5647620604300104371C1A416C59707955647F54618459658C626C906670946973
956973986C769B717A9E757D9D747C9E747AA2787CA07678A47B7CA37B7DA47D7DA58181
9D7B799B7E799B857CA08E83A6968DA4978E988E85948A819C9389A39A90A0978F9D968E
95918A9B9891989691A09F9A93938E91928E989B98A3A9A8A9AEB0A7ABAFA5A8ACABAEB3
95999C8D8F938E9195959C9FB4BABDB8BEC1B0B9BBBAC3C5B6BFC1BCC4C8B9BFC3BCC2C6
BBC2C8B1B8BFADB5BD9FA9AFB4BCC2BDC3C7C2C8CCB7BDC1BEC5C8B8C0C4B8C1C5AFB9BC
BCC8CCCADAE0A4B7C1C1D3DDB8CCE2607A9A92A9C29FB4C4B6D0E56388A4A6C4D6CAE0E7
CEDFE7D2DFE7CFDBE4CEDDE5CDDDE5CADBE3CCDAE4CDDBE5C9D8E7B2C6DAA5BCD61F3E63
40617F8298A9798895909EA9B4C2CA808E969BA9AF9FACB17C898F78868B768589758384
7683857684867681837583847583846D7D7D6F80837080857281856F81836B7C7F6B7D7F
6A7C7E667A7B5E7280081D3C314B6F102851011145000945010846000842010B42000C41
010E3C10223E496062484B3F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0047AF195B3D2D453B4C070829403C536E5E676F5E63594F5A544B5D
6C5C6E64546C110E3604083919183F6E5B737C5967835B678C656E8B636C8C646C936A73
966C769D737B9B72799F767F9D737C9A6E779F757A986F71A0777AA57D81A47F829E7A7B
987876A38984A08D84A4948AA18F879C8C85988D849A91879F988DA1988EA39B93A29A96
95908B9E9B949D9B95A09F9A9B9B96999B96999C97A3A9A6AFB6B6AAB3B59EA5A7B4B6BA
A0A1A694959A8C8F938D9497B2B8BBB5BCBEAAB2B4B9C1C4B9C1C3BCC4C8B9C0C4BFC5C9
B1B6BDADB4BBB8C0C6B3BCC2BEC7CCBDC5C8BDC6C8B7BFC4B6BEC3B8C2C4BFC9CDADBBBF
BECDD3CBDDE6899DAAA5B7C2AEBEC9B6C8DB8EA9C793B3D0AACCE42A5474B3D1E7CDE0EA
D0DFE7D2DFE7D0DDE6CEDCE5CCDBE6CBDCE6CDDBE6CBD9E3CBD9EA677C948498AE768DA0
7E96A6BFD4DEA6B5BE909EA8BFCED98D9EA67B8A907D8A8F7A878D7A888C7A898D798889
7686867283827182817283837482837383826F81836E81847382866E7F816E7E816C7E7E
6A7E7F61767D556C830D204B011148000B48000846000846000845010943010D41010F3D
020F3C041533465E634C564A10CC0800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB41A6B4936372D3E080728524A606855605F5364171837101534
5A546A675A6D2E284904083614133E6D5B747D5C6C825D6A8E67728B646C936A73976D76
9970799C747C9B717A9C737C9D727C9E737C9F767BA0787B9D7579A0787DA17C7F9A797A
A08381A58F8A9F8F889D8D859C8A839C8C859A8E859A91879D968C9F989199928D9D9792
96908B99948EA2A099A09F9B9A9B979A9B99979997ACAEADA2A9AA9BA5A799A2A4B3B4B8
A7A5AB94959A8E95988D9699A7AFB1B4BBBDAEB6B9BCC4C7BDC4C8BDC3C8BCC3C7B9C1C5
BAC3C6A8B2B5B1B8BEB2BBC0B6C0C3B6C0C2B1BABEBDC5CAB5BDC2C6D0D5D2DEE6ABBAC2
AEBBC4B0BFC6B2C3CCAABDC9B0C5D2C1D8EE2C52831C4A808BB0D381A1BACBE0EFCFDDE6
CFDCE5D0DDE6CFDDE6CEDDE5CEDBE5CEDCE7CBD9E6CCDAE5C7D7E77A91AABCD4EABFD4E3
879CAFAAC2D3B3C5D27986957583917B8B947A898E86959794A1A77281859CAAAF8F9FA1
7486867286846F827F70817F7583847180826C7E8172868778878A7484866F7D826C7F82
687E87536C811B315B010F46000949010847010847010846000843010D4102153D142D4A
1025440113303D565F505D55219D1400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057BB1D7B563D2E202E0D0C275E54646A5B6639344E040B35030D36
464761675C6D4F455E0608320C0E396C5E7B7C5D6E86616F9269788D6571926872946A73
997078966D76966C75996E789B7079A4787FA3797F996F72A07779A2797BA27D7E987978
9F83819E88839D8D869D8F86A2948C9E8F889D8E889C90889A918CA9A29E9B979298958E
98948D9A968EA4A39AA4A39F9A9A99999998989898AAA9AA9A9B9D8E94968A9092ACAEAF
B1B0B49FA2A68B9396929B9FA6ADB0BCC2C5B6BCBFBAC0C3B6BDC1BABFC5BBC1C7B7BFC5
B5BFC4AAB5B9B0B7BDB9C1C6BEC7CAB6BEC2BCC5C9D5DDE1BDC5CDB6C1C9BECBD4ABB9C1
B1BDC3B2C1C6CCE0ED87A8C47598B7B2CEEA42648E2E588587A4C1CDE0EDD3E0E7D4E0E7
CFDCE5D0DEE6D0DEE7D1DFE6D2DCE5CFDDE7CBD9E8CBDBEBC6D7F15B749B5B729EA5B1D5
707696464B66969AAB9398A47D85917C8A9277858D8D9FA3BCCBD27E8C947B88917B898E
78888A7386847484817382817381836F7F807184847083847587897486886E7E86657B89
3F57780F2556011350000C4A01094A010848000845000940010C3D0B1D40324B604C6773
4A617105172E38515E4F5F5A336F2300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007C53342519211B182C675D69655968181736020A37030B38
34345465586A68596C1E183C070A345E55757A5F72866373916A7A8F6675916873946874
916770916870956B73996F789D707AA0737BA1757B996E71A07578A4787AA17A799B7A77
997C79A087839E8A849D8C84A5958EA3948D9E9089A09390988E89A59C97A39D97918E85
98958B9490889A98939999979A9A9A919190969595A8A7A79A999A9E9EA2929495ACAEAE
B5B7B6A2A4A4999FA299A1A59DA3A8BCC1C5BEC3C6BCC2C5BDC3C7BBC1C5B2B9BEB5BEC2
B2BCC0A6B1B4B3BCC1BBC3C9C1CACFB9C2C8BDC6CBCBD4D8B6C0C7B2BBC2B8C2C9CDDAE1
C5D6E0ACC0CBC5DBEC4165854A6F9298B1C9A6BED791B3D086A4BAD1E3EDD3E0E6D1DEE4
D2DFE7D2DFE7D1DFE8D1DEE7CFDDE8CBDEEEC3D6EFACC0E17880AE3C356C4F2F68683462
733256753754A16C84C8A4B69A889783858D8188917C8991818E9A74838B717F87758388
79878B7584847585847182816D7D7D708181708282718383748688728589637886253E63
03195601145A000F57010B4E010748000845010C4102143C1C304B475D6953686E586C6F
5D6F78142738364E5B50605F4A453700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00845B3524181F2822356C5F6B51475808092C030B3A020A38
312E4F6E5C6C6D56644E405B08072F45406379647889697795707F956C7A926673946773
916672916870986E769C727B9D727B9D737BA1787D9C74779F7578A4787A9D75759D7A77
9C7E7BA08682A28A86A28D879F8C869B8C859B8F889C928B9A90899F9590A49B95968F88
948E86928D8893908E9999989293928F908E9B9C99A4A6A49E9FA2A2A2A79B9B9FAFB1B1
B4B5B4B0B2B3A5ABAE98A0A39FA5AABABEC2B6BCBFB9C1C4B6BFC2B8C0C3B5BEC1B7BFC3
B9C1C4AFB9BAC0C9CEC1CCD1C9D5DCB1BEC6B4BDC3B6C0C2C2CCD2C0CAD0BFCAD0D2E1E9
8DA1B398AEBFAEC2CFA6C1D1A7C6DE92B1CABDDBF5486E8F7C9FB7CDE1EBD2E0E7D2E0E6
D2DFE7D1DEE8CFDEECCADDEEC6D9F4A2B6DB656C9B5B497C6A376B75214E7D0E35870726
8C06228807218209267D15317B2E448F677493898E81878E79848E91A0A67B898F788389
7C878B7A88897A8A89798A8A778688738484697A7A6B7E7D707F8272848A54687E02194E
00115D00105F020F5B000A52010849000C41081A3D2D46584F6A6E576D6C576869596A6A
5E6C74182938364F59526264514E4600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008D61362112143831416E606A3C324604072D030A3B030A39
312B4D6D58696E525E70596D20173A27244875657A816372906C7B9268759265718F636E
916672906670966B759C727B9E767EA17A819E767D9870759B7275A178799871729A7776
A0807FA186839E8581A18B859E8A839A89839B8E89998F899C928CA29894A49B979C948F
9C94909A94909997949B9B9A969796929492979997A2A4A59C9EA19B9DA1A9AAADAFB0B2
BFC0C2B0B6B8A6ADB0959DA1A9B1B3B3B9BCB9C0C2BAC3C5B6BEC0B9C0C3B6BFC3B8C1C5
BAC3C6C4CFD0C5D1D4B4C1C7B2BEC6B2BEC3B7C0C7BDC6CAD8E3E9D1DEE6B7C4CDBBC9D3
A9B9C7AFC3D0A4BCC6C2DDE9779DC12B5A8D769EC96E91AEBBD5E6CFDFE8D1DEE7D1DFE9
CDDCEACBDCF0C4D7F599AAD363639763497F783B6E801E478A0B2D94061E970115970211
95010F9301119201148D021786071B731526B88E97C7C2C7869198A8B6BC8C99A078848B
7B878D7C8A8B7B898A76868678878A77868A76858873858674858771848962758B04184F
01105D00105E010F5D010F55000D48152A50465F6C566E6F58706C5A6F6A576B69576C68
586A711525353A525C5366685555510FCA0700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006988271F0D0A413B466C626C262037050933010A3C030938
3931516F56687254606F536052425B1811326A5B737D606F8F6B7A916776916470936671
9265719468739569739B71799B737A9E777E9D757C956B729C73769F767A9770749A7778
987B799C817E9A827D9A847D98857E9B8A849C8E889A8E88988E889D9591A29B969C9691
97918D958F8C9E9B999999989A9B999294929C9D9D9C9D9FA1A3A5999D9FA8ABADAEB1B2
BCC1C3AAB2B3A4ABAE939A9EA4ACAFAAB1B4BBC1C4B3BABDB9BEC1BEC5C7B9C1C5B8C0C4
B4BEC0BBC6C7BDC9CAA9B5BCB6C1C8CFD9DCCBD4DAB6C1C6C2D0D7B2C2C9B3C0CAADBBC3
C7D7DFBCD5E787AAC4ACCEE93E66930D3B78416B97B9D5E7CCDFE9CDDEE8CEDEEBCCDEF1
BDCFF08C9AC6625E9367447D7F356A881B47940D2C9C061C9F02159F02119D020F97010C
94000C92000B91010C91000D90010F880619832D3DD0ADBA95949D7E8A907D8B907C8A90
7A888E7B898B7A888A78878B78888A76868978878B76868977858B75868C7083960B2052
01125A01125B0115560C215807164837506A577074576F6A5A70675B706A5A6E69576C68
50646D05172B425966566C6E5359561F981200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0043AC19250F06493E48685E6A13102C040935030C3C040A35
3C324F6E546272535B74555E6F57673628424F3E5880627386616F8F65738B606D956874
996B779C6F7B996C779C707A9B717AA078809E757B9B72749C7376976D7392696E977374
987A789C807C937B749E88819A88819E8D869D8E87978B849B928C9F9794A09A969C9792
958E8B8E88879D9A9990908F9395929394939A9B9C989B9CA0A6A69FA4A6A3A7A9A9AEB0
B5BCBDA9AFB1A0A4A7A5A9ADA3A8ADADB2B6BCC3C6B2B9BCB9C0C3BCC3C7BBC2C6BCC4C7
B5BEC0BEC8CAC6D0D2B1BCC1B6C0C6CED8DDC9D4D9B3BFC5B4C1C7C0D0D6C8D9E3B6CAD5
C4D7E4819DB81A426A84A6C28FADC886A9CE89B3D4BEDDF0C5DBEEC2D7F0B0C1E2898EB9
67568B6940787A2E6286173F960B2C9C061E9F05169E0512990511960813940B15890813
8805138C030E8F010A91010B93010D92021185081A7F303F9B808A808489808D91808F92
7C8D90798A8C79878D79888D78868A78868A7A868B768487738187738388738696152C55
021853051D532942695A728D1C2F502C445E5971765A716D5C716A5A6F695D706C586C6C
31465603162F4A626F586C6E53605B24A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004BB21C2A110451444B5D52600907260309302F345A0C0D2F
473B5272576376555D73545B775B66715B6C4E364A7E607085606E8C6370926773976977
966977976A77966A74986C769B707BA0777F9C7277986F71986F71966B6E966C6F95706F
967874947B749B837C9D87809A87809F8E87998A849A8E889B938F9E97959C97949F9996
968D8B968D8B9995918B8B879293908C8D8B979A9B959A9A9AA0A19CA0A39DA1A4A6AAAD
B2B6BAB5B7BBA7A9AEAEB1B6A3AAADA4ACAFBAC3C6BDC4C7BBC1C5BEC5C9BDC3C7C1C8CC
BBC1C6B9C0C4D0D7DCD1DAE1B6BFC5B6C1C6B5C0C5C0CCD2B5C1C7C8DAE4ACC8E07EA2BE
A9C0D39FB0C48CA0BAA2B7C8ABBED0A2BDDA4A6C95A0B8DD8F93BC7E719E7953867E3D71
802353841138910D2B980D209409168D08108D101784121880202685363B8848527B4153
7D374E7713258A041291020D95010D93000B9002107F0B1B965A648C8487858E91879598
7E8C917C8B907C8A9178868C7584887684897883897784896E7E8372848872848E29425A
1F385A4E6680657D8A687E882D42591D364E59727B5D72725E716F5A6F6A5D706D596D70
12263712273B4F696F576D6C58666135732700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0054B92031140355484F5A52640506260E11315C5A74171229
4F455470596275565D75545C755761785C677B5D6A7E5C6A845E6C9066748F64728F626E
976975986975986A749A6E78996E78A0747E9A6F769A727699717493686C93676996706E
93736F967C769D857F9B857F9A867FA290899B8A859A8E8A958D879994909D9894999390
938A8898908C96918C8A87828989848C8C88979997929797959A9C989B9FACAFB2A7ABAD
AFB3B7B8BABFA6A9ADA7AEB1A3AEAFA5AFB1AEB8BABAC3C6BDC4C8BFC4C9BCC2C6CED3D7
C0C4CAC1C8CCC0C7CCBCC3CAB9C1C7B5BEC4CBD7DDD4E3EAC5D3DCB2C6D7638AB14073A4
9DB9DBB2B2C7DAC8DBBFA7BD997D9B85678D7B59878653817F38668429548B1A40921234
99122B930C1E94111F8D18207F1D207A2C2B7E3F3E8053539075797B727E595E774A5476
2C2851693B5D780C2390041594011194010C94010E8D05168026349B8083818687808B8E
7F8A8F7E8C917D8B8F7D898C7C888B79898B77858A7381856F8083728586738588687D85
687D876B7F866B7F836A7E85455B6E0E263F57727C5D72736174735E736E5C716C5A7070
182D37385059546C6D5A716D56686146463800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDE103A1806594A52453F5504052522203A685F721B1325
5E525E6C555B72555B76575F7456617A5B677C5C687E5C6A896473936B7A8D6471926672
936571976874976A74996C77996D779B6E77966B73966E73956D7390666A92676997706F
95716E9576719E847E9F888299827D9C88839D8A86998B87988E8899928D9E9995999490
8F8885A29B988B86838B8884908C8893908C9898948F949291989999A0A2A9AEB1AEB2B5
A9ADB1B2B8BBA3A9ACACB5B7A1ABADACB6B8A7B0B2BFC7CBBEC4CABBC2C6BFC5C9C6CBCF
BEC2C6BEC5C8BBC1C6C4CACFD3D7DDC1C8CFC3CED4BDCCD4ADBDC6B1C5D27D9EC01B4C84
567AB38081A9774E6D823A5A872C4C8B24438D193694173395142D9213288F13238A151F
881C2380232884393D8954538A6967978683ADA5A5BEBFC5B0BCCA5E728A092247627EA0
2E436E3B3463681D3F85051A91011192010D93000C9003107C0C1A9D6A6E8B8787848E8F
818D8F7F8D8F7B8A8B7E8B8C7C898B7889897585867385856D7E7F6F8281718383718484
7184876F82856E7F826A7C815A6F7D0720375570795D72745E71715E726F5D726E576E6A
4258594F6766536967596F6B5A6D654D524700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004C220B57434B39334B040727363349685B6A1F1322
6B5A656F565C75575F72545D6E515B7657637959627C5A66825F6C8A6271916775926774
90636F946773946974986D779C71799C7079996E76966D74956C718F6367956A6C946E6D
9A75729B7875987B77977F7A9A837E9986819E8E88A2938E978D88968D899F9895938E8A
9F9B97A7A39F908C89938E8B918D89989694999B998E9392969B9C9A9EA1A1A6AAA0A4AA
9EA3AAB2BBBEA2ABADBCC3C6A8AEB2ACB4B7ABAFB3B0B6BBC8CED3BFC4C9C1C5C8C3C7CB
BDC3C6BDC3C7B8BEC6C9CFD6DCE0E7CAD1D8BAC3C9B8C4C9C8D7DDC3D5DDB4CADD779CC8
0E397E3B56937F79A7926C908D4D6A89364C892A398827338628338330377D383B7F4745
8E62609A7D7C9B8D8DB1B1AEC1C9C7CAD7D7CBD8DCC1CFDD49627594ADC0768CA49CB4C8
7C94B6131D516137617508218C021492010F92000B90010B850511863A40968283858A8B
808B8C7C8A8B7B8A8B7C8A8C7C898C7B8A8C79898A7284847485866F80806F8080708082
6F80817081827281836C7E816577821F38465772785C73755D72725F72715C706D5A6E6A
5B6E6D516866455C5B596D6B5C6E69575E541E960F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006032155842472C2640070A294E475A64545F291A26
6B586170575B7053586F51596B4D5670505A75545E7756607B586386606C8C636F8C606D
8E616D9669759268729970789970779B7077946971966D74956C7293686B9D73759B7676
9B78779977769B7D7A9A807B98827C96847F9E9089998F87978D88958B8899918E999590
9E9C97A4A19D99959299959191918C989D989CA2A18B909195999C959A9EA1A7AD999FA7
828992848C9299A3A6BEC7CAB5BCBFB5BABEB6BABFB4B9BEBFC5C9C5C9CEBFC2C8C5C9CE
D5DCE3D7E1E6C3CDD3B8C1C8BEC6CDBEC8CEBDC7CDBCC9CFCEDFEAB1CBDCADC5D996AFCA
4667946183B552719E596E95535C7E7E778B8A76818A6F799C838A9885899E9496ABA9A8
C3C5C4CAD1D2CDD8DACAD9DAC9D8DDC6D8DEC9D7E0BBCCDE658296BDDAE8C0D5E27994A6
8AA7C7152A5C4233646B173686031990010F92000C92010B8D040F77141C9D757988878A
7F8A8B7B87897D8B8E7B898B7D888E7B898C7382846C8081748589738184738284738084
7482837180807281836E7C817180876B7D8365797C5F77765D73725F73715E726E5D716C
5D6F6E586C6C33494B5268685B6D6B5A635B229D1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0076461C533D40201C370E0F2D6156675A4A56332637
5A4E5F5C4A556950556A4C536D4C56724E5974525D75545E7D57628259658A5F6A926570
946572956672966A74966D76966E769A7177976D73976D75976D75966D72986F729C7577
9A7879997B799E827F9D858098827D927F7A9E918A978D86948B848F86808F888197938E
A2A09BA4A19D9E9A9897969391938E989C979BA09F8E92968E95988F979B9DA5A97C848B
949DA39DA7AA889395B2BABDB7BEC1B7BCC1B9BFC4B6BDC1B2BABDC4CACFC4C8CFC0C5CE
C7D1D9C8D3D9BEC8CEB8C2C6BAC5C8D4E2E6D4E3EBBAC9D1AEC0CF516C8397AFC2B0C2CF
BED5E8A9CBEE739DCC8CB5DC7094AEC1D7E5CAD6DCCFD5DBD0D6DBD1DADFD0D9DFCEDADD
CDDADFCBDAE0C9D9DFC8DAE1C7D9E1C7D8E0C8D6E3C2D4E94968897092B294B0C5486178
37526F536A911C1F516C375A7A071E8F021292000C92010B8F020B7D070E9252588F8687
828C8E7F8A8B7E8A8B7C8A8B7B898E7A898C778688748588748388758386748386737F84
778286748284728084728084717E83707E836B7E80657B7B5F74755E72715E73705C706D
5C6F6D5D70702A41463E585E54696B59655F356F2600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002E970649343316162F1E1D38685C6A4A3E4C302C45
1818371C17315A4B5A674D566F4E586F4A56744F5B78525E7C5460835765895B678B5F69
8D616B91626D946772926772956D769B737A936A6F9B7176986D7592666C9B71739A7274
9B777A9F807F9D827E9D86829B858098847D9A8B83978B849188808A827B8B867D96928A
9C979398928EA49F9C9897959395919A9C9AA2A6A88A8F937B80837C83858F989A798286
8F989D8C969B949DA0B7BBBFC0C3C7B8BDC1B2BABDB4BDC1ADB6BAC6CFD2CAD1D6BEC5CD
B7C1C7B9C4C9CDD6DCCAD3D8BEC8CCC8D7DEAABCCAB5C6CFB7C6D0B7CBD8C5DDEDB4CEE0
B7D1EC3862950B408443729CC1DEEFCCDEE6CFDCE3CFDAE2CFDCE3CEDDE3CEDAE3CCD9E0
CCDBE2CADBE3C6D9E5C2DAE7C4DAE7C6D8E2CAD7E6AEBDD6142C59062250859FB7AEC3CF
90A2B3AABED7152451513C656C112D8A051692000E90000A90010A87050E7C242A9C8183
8287897F8A8C7E8B8C7C8C8D78888B78878B79868A77858878858A738387728185727F85
738085728084717F84728183707E827181866C7F85687D806276796074745F73725C716F
5B706F5A6F70324A5219343F465D645A69674E483C00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF003BA40F3B26220E0F292D2C43695F6A3931420F1131
04083005062B494157634C56694A526E4955724C5A76515D7A535F7F54618558638B5E68
8B606A8F626D9467739469749970799A727A997176976E7390646B94676C9A6E719C7376
9C777B9C7B7C9B817D98837E9A86809B8B829889819B8D869689859187838C847F958E8A
928A87928B88A2A09C92928F9599959BA09E909798838A8C828788888B8C7B7F8294989D
7E8488878F94A5ABB0B5B7BCC4C4C8BABEC2B9BFC4C1C9CDB6BCC0BFC5C9BDC5C7BCC3C9
B4BCC3C0CBD1D6E1E8D8E1EABBC4CDB9C5CFABBBC7C3D2DBBCCBD3C5DAE985A6CC5481B1
8DB3DB48709C285488779EBDC9E0EFC9DDECC9DDEECADBECCFDAEAD1DAE6D1D9E4CED8E1
CCDAE2CAD9E8A8BDD67D9EC1ACC6E5BEC6DFC4BFD7BAAFCB584D74373356AEB6C8C5D5DD
A5B7C48299B13349732322536C325580091D91020E92010A93010C8E030C7D0C159E6A6D
8883867F8C8C7A8A8A798B8D7A898C7C8A8D7C898C7B878B79878A708085738287728183
7281836F7D80738185728081707F806E80836C8082677D7D687B7E6276775C72725A7172
596E70556B6D415A603A5760415A615B6B6A56524900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BB119341C14090722403D537065722D253A030528
01042D0204293D344C644D5867494F6C4A53714D5774515A754E587D525E835561895A66
8A5C688C616D936874926772956B76946E76956F77966C7593656E95686E986F72997274
9C787B9B7B7C9E83819E8A849C8A839E90879A8B85978885998B899388868B828099918D
8E88848C898494938D8F908B90938F9FA5A37C858592999B7F8484919496777A7E95999D
959B9E98A1A2ACB4B8B9BDC0BFC2C5BDC0C5BBC1C7BCC4C8BAC1C4B9C1C4CAD4D5D6DFE2
C5CED5C0C9D2BDC7D0B4C1C9BDC7CFBAC4CCCDDCE6C6DDEFBFD7EBB0C7E0325789174A83
78A1C6A6C5DDB4D3ECC1DDF1C3DCF49CB9DC7186AE908DB1AD93B2AA86A3BC9BB7C9B3C9
D2C9DDD4D5E999A6C6122E623E4C7F563A64692A4F7126446B1D3B611E37826273A8AAB4
8494A23E5469647A9C0F1A4B6245706E0E268E051392010B94010C94010C8D09158A3B40
978586808C897B8B8B798A8B7A898B7B898C7B8B8B7A8A8B77878A75868A748285728383
7483846E7D7F6F7E816F80807082826C7F7E6A7F80697F7D687D7E6378775D7673587271
5A6F71566C6B4E64691A353F415B6358686963615C20960F00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056BB1E4428190E0920585067706273221934020229
01032E0304293A3047644B556B4D506C4D5170505572515777535C7F56617F525F855461
8E5F6C8C5F6B90666F8F6470936874946A75946B75976A759666719568719C73779A7577
A07E809E7F7F9C817F9D87849D8B869D8D88978884988B87948B85918B8788827D918C85
8F8A858884808C8A859693908D8B899B9C9B8186878E9497818589818588818588929699
949B9DA3ADADA9B2B4BAC1C3B9C0C2BABEC3BBC0C6BBC3C6C0C9CBB8C1C5C5CED1D1DADE
C2CBD2C0C8D1B9C3CBCAD6DCD7E2E9C9D3DBC0CFE15F82A4587EA3A6BED890AACA8EB6DE
9FC9F08CB2CF8EAEC4BBD8F26484B230497F614D817C37618623488B1F41841B3F7E2449
874062A26E8CB897B94032634331636B2E55780B2C81041B8204187A081B6B1F2F95828B
BEC9D099ABB8A6B9D02E436B38346268264385071994030F93000B97010C9405127D141D
A0787A8689867F8C8C7B8B8B78878A7B8A8D768889778A8B76888B77878A768587778484
7482837182826F81836D81816E82826C80806D81826D82816B8081657B796077745B7470
586E6D596E6C586C6D243F441F3B43546969626963229C1600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00583620160B1B6F63766E5E6F140C28020329
00012D0201273B2E45664D546A4D4F6C4D5170505672515977545F7E57627D525D825560
865A64895D678D626B8E636C956A74946872966A74956771966570986B749F747A9E767B
9E7A7D9D7D7E9C807E9A8382978382978683968985958D88C4C0BBCAC8C69D9B99888480
908A8687827F8D88859792908B86869796949799998081847C7B817C7C7F90919395989A
9A9FA29EA7A9A9B3B4BBC5C6BBC4C5BEC4C7B6BABDC4CBCDD9E0E3C0C6CEC3CAD1C5CDD3
CAD3D9CAD2D9BBC5CBCFDCE2C2D3E0C2D3E1B5C4D5809CB797B7D5C0D7F0AABFD97295C4
17498A245488A9CDEA99BBDD0F316D60629573284D90112C98081F99081D990C248F0B25
840E2B811B3B7117396E23477D3A5E9745607E0C228B061689010F83020F700816946771
CED0D6C1D1D97B8DA04960820F1A4A664263750A208F021194010C96010C950210820612
9552599286887F888B7A898B7B8A8D7C8B8F748688778B8B758788778789728081778585
7382837183847183867084856C80816E83847084857084837082826A7E7D667C7A5E7672
5C716F5B6F6C596C6B49656529484D4D6A6B5E6C6942382900FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00734A272412176F606E6A5B6C0B0521010327
00032A020225392E43654D54674B4E694C506C4E5570515974545D7A565E7C535C7F545E
875C688A606A895F688F636D9569739468729367719A6C7590616A9669719C7178A1797E
9E787D9F7D809D83819A848095807E9D8B87978B87B3B0ADD5D6D6D4D6D8BEBDC1817D7E
867F7E837D7B8A8582938F8C8A87859291909C9D9A8F8E8E8F8A8D8783868E8F91909397
91969B97A0A2A7B1B2B5BEC0B7BEC0CCD1D5B9BEC1C3C9CCC9D0D3BFC6CCBDC3CAC7CFD3
D9E2E7D9E3E9D0D9E1BFCAD3899BAAABBECBBECCD8B7CCDAAFCFEE89B0D88CB0D73A6193
0E3C80225082BAD9F47597BA0F316B7D729D7919369B0C1F9F0817A10C1B9B0B1C900F1B
84212C7223356C1E386E173378143290243E890D238E07168E03108A010C880C1A7A2C3A
A9959FA1A8B06F7D8A5667821928544538606A193488051792010C93000B93010D8F0513
80222E9E7E8483878A7D8B8F7A8B8D7A898D78888C798A8A778989778889728183738284
7281847081826F80836D81827083836E81836F82827083816E81806E82806B807E667B79
6376765D6F6F57696B476166193640415E625B6C6A47453600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008D5D303F2520705E685A4D6105021E030426
0206280202203F3345654D52694D506A4E526C4F5671555B74565C77555C79535B7E545E
825664875A67895D678B5F698D626C92677097697497697294666E91646A996D739C7478
A17B7E9F7E7EA186839A84809F8A86998782948884B7B4B4D3D5DAD4D5DEAFADB4817C7C
887F7D867D7B847F7B908C898787848989889998989392919492938786888A8C90898D92
8C93978F989BA6AFB1BABFC3B8BDC0C8CDD2BAC0C5C3CACDC4CCCFD3DADED8DDE2C6CED2
CBD6DCBAC9D2C5D0D9BDC6CEBFCBD5D0E3F0CDE3F5B0CBE0466E9B0E4380406F9C7FA1C0
7B9BBDA5C4DECAE1F37D99BB0D2C666C62907B1E3B9A0E219F0A1AA51222970B1B82191F
B98387A189926750664C2A476122456D11307E061E8F09198E02119103109005137A0E1D
8F5E6ABFBCC2BFCAD27D8B9C3F4E73191B486C3A5C7B071D91030F94020D92000B910210
7B0A189A666E8A86897D898D7A8A8E7B8A8C7A888A788789798A8C748589748487768588
7583867483847381847282827584857181826F81817185836D81816E82826E81816B7F7E
66787A5E7273586D6F3D545B0B2531415E625B706D4E524510CB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0046AF1C78594C735D6543374A03011D080722
2D2B4405021A473A496950566B4D506A4C526C4D556F515772525977545D7A535D7D535E
825463885966895A668C606A8D636C936970986B74956771936670946870966B729E777B
9F797BA17E7DA186829E89849F8D889B89849587849B9293BDB9BFB2ADB48A8285837A78
89807B877E7A807B788D8C888B8C888989869795959393948B8D8F86878B878B908A9094
88919497A1A3B9C1C3B8BEC1B8BDC2BABFC5B9C0C4C3CBCEC9D2D4D7E0E3D7E1E4C3CCD1
B8C4CAAAB9C0CDDAE1D4DDE5BBC8D698B3D15A83AD90B4D46E90B4416C9893BCDDA7C7DB
B4CBDCC0D2DFCFDEECA1B8D50F2C6756568B752948931023A30D1FA10C1F9107187A1C25
DCBEC2D5D7DCCCD2E18C92AB3D355A502D556213337A061A8701108E0110920312870917
7C333EC9BABFCAD4DA97A6B2657390101B4757406870142C8F051496020C95010C90010E
850515873C469282847F888A7A888D7C8B8E7A898B7685887384887284886F8283728484
76858676828475808475838579898B7485857183837185846D81826D81836E81816E8382
677C7D5D7274586D6E5267692A4248365052596D6950574A0FCB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049B11B84614E71585C2F2233030219221D2E
584D5A1006174F3F4D644C50694D4E6C4E536E4F576C4D5570505876515C7A535D7E535F
8354618959648B5C678B5F6990656E91666E93676E93666F9268719369729870789D767B
9C75779D7A7A9E837F9C88829D8A879D8A8A9786869183838B7E80887B7B887B78877B75
877D77867D78827C7885807D878581908F8B9797948B8E8D8C8F917F818683888D838B8F
8A91959CA0A6A1A7AAB6BCBFBFC4C9BAC0C5CFD9DAD2DCDEC0CACDCAD3D7CBD4D6C9D2D4
C1CBCDC5D1D6D2E2ECD4E5F3BDCCDF607E9E3260899CC1DCA9C3D9AFD0EF7DA8D55C8AB6
8EB3CBCADFEBD0DDE9C5D9EF2D4B803846817E4D728C162DA10E1EA60F2098091B7E1727
C3A0AAD4D8DFCBD9E0CAD8E4A7B4CE262E59422B576D1F3A860B1E9004129302118F0513
7913209C777E93999E83939B69798C323F652824506E314D80061690010B94000C91010C
8C031079171E9A76798083857B8A8D78888C7586887385877383867385896E8183728585
7786867584857282847184856F81857284857082837386866F81847083856F83846E8583
677B7F6175795B6D6E576B6A536968485E5D5C6D695B625720991100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B81E835D446C55552016270402163F3741
57484D1408135947526B4F556C4F536E51556C5157694C536E4E57714C5779525D7E545F
84576382545E8658638659658D616B92656F94676D94686D946870976D759971789D7479
9F77799C7A799D807D9D85829C8787A08B8D9A898990817F8C7E7B8E7F7B8B7D77867A72
877D76887E79847B77877E7D8B86848B8A87959593898B8B898A8E88888D82848B8A8F94
8D9197979BA09DA4A7B1B9BBBFC3C8B6BABFCAD3D5C5CFD3BBC5CAC0C8CED3DBDFD7E1E4
CFDCDFBDCDD4A5BBCB748DA4B5C6D7AAC0CEB3D4EAB5DBF7ABCFF07BA0CB114083083E7F
79A3C3CCE1ECD1DEE6D1E1F06682AC152D6C735F8C76173296091CA20D1C98081B830E22
945A6ADBD5DECDDBE1CBD9E1CCDBEA6B7E9F1E295C6E456C780E268F0615940111960414
83071785454D9E989CC3D0D3A3B3BF5E6D8A0D144268486D6E0D218A031091000B92000B
91020D7F07109252588E83867D888B76878977888B74868974858875888C73868A738588
7485866F80846C7F816C81826E82837083856C7F81708385748487738585708585708885
6C7F8364777B5F7172596D6C586D6B576B695F706D5E6661356B2100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002DDE108C6444604B49130C1B08051652454B
5342441B0D15634B566D4E556A4C516C4F536D4E556B4B53714F58734F5977525D7D5560
7C515D845664875867895A688D5F6A90646D90646C93666C94686E986C72976D72997072
9D75769F797A9E7D7B9D837F9C88869E8B899989858D7E798E80798F817C8D8078857A71
877D768A807C857B7A837A7A8781828E8B8B8F8F8E88898C84858A888990878990899093
8C94979BA3A59BA4A6C3CDCFD4DCE0BBC0C6C2C8CCC2C9CDCDD6DBC3CBD1CDD7DFD0DFE6
C5D5DBB6C6CEA5B8C6A1B9CCD0E2F1C3D6E19FBBD6356498285B97739CCC395E92385F8C
B0CDE3D1E0EBD1DEE6D0DFE9B0C3E219346D575D907333528F12259E0B1D9704188E0B1E
792032C9AEBAD0D8DFCDDAE2CAD9E1B6C7DC25386744396C6E1D3F88061C960215970415
8A0314731926A68C93C9D0D4BCC9D46F7D951B295240386368244080071790010D93000B
92010B8A050F7F252D9A7F837D82857B888C78858B77868D74878B7084877285896F8185
6E80846E81877084886D81826E82826D80836C80826D81837282867184866F84846E8685
7083856B7D806476785E72725C7070586D6B5D706E606B69433A2C00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008E65405D46430C051219121F5A4B4E
50404124131B664B566B4B516B4C526D4E556C4A536E4B54734E57734F5877525C7B555F
8057628257648457658457628B60688E646C90666F92676E91676C946B6F956C70996F72
9F77799D787A947472967C7899837F9B888499878396868091827C8F837D8A8078857B75
887D788B817D8A807E847B7A85807E8D8A898C8C8C88898B838589878B908A8F93858D90
90999BA7B1B29CA6A9A6B0B6B0BAC0B3BBC2BCC2C6CFD5DAD7DFE4CDD7DDC2CED79CAEB7
C2D3DAC6D6DCBDCAD4C0D4E7AFCDEAABCBE883A0C418447B24548F98C0E48EABC2BFD7E8
CEDFE8D3E0E8D2DFE7D1DEE8CFE0F44C69951F37717F648B841E3595071A9D071A9B0B1D
7F0A1D905764D9D4DCCFD9E1CCD8E0CEDBEA66779E19205B62315E7D0925930418950113
9002127B08178D5562949198919EA67C8A9B3C4D6F131A466B4464710A1D8C030E910009
93000A8F030C790C1598696D8885867F8A8D7E898E78868C74858975888775888C738689
7385896F82876E82866F83847183856D81836C7F837082867181877284896D83836E8685
72868670828466787C6376775F72725B706D687B7B6170704A463A00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009A6F46533E390A030F2A202A604D4E
453436322027664A4F6E4E516B4C516C4D546D4B526F4C53734F5777555D74525A78555E
7D58617F58627E5660835A63885E668D636B90666F9268718E656C90676D976F72997174
A1797C9C787A937272997D7B9E88859A86849E8B899583809587819086808B827C8A807B
897F7A867E7887807B87807D837F7C8A8787918F918A8B8C898B8D878B8F8F94998F9398
9AA2A5A5B0B298A4A5A5AFB3B6C1C6D3DDE0C4CDD0C5CBD1C0C8D0BEC6CEC4CED5BAC9D0
CEE2E8CFE3EACBDBE69BB2CC28518347739FA8C5E283A5C79AC6EE9CC8EF89ADC7C6DDE7
D0DDE5D4E1E8D3DFE8D3DFE8D0DFEC9AB3D213336D5E61917B334F9612269C06189C0918
8D0717701625C9ADB7D3D7DECCD6E0CBD8E5B0BEDA1F31674F3F7570193A8D071D950112
9501118C06167A23318C777EBFC9CFC0D0D96E809912214C55456C68172E88041393010B
94010B92020B860611883E4295848381898A7D888D79868B7A898C788A8C74868A718586
7386897184886F82866F82857382857486856D80826F82866C7E857386896E83836E8382
708484708283677B7B6477766679775F74726B807E6A7C7D4F514A0FCA0700FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00719032412D2807010C3D3035644D4B
3B2729422B2F6B4C4D6E4C4D6B4B4F6C4C516E4E546F4D5474535B74555C74555C78575E
7A535B805A627A556076515B845A658A5F688E636D9066708E646C8C6269926A6C987173
9772749C787B916F729C7F8098807F9D88869B88869483809A8C86958B839189828C827D
8B827C837D7687837D868481817E7F8683838C89898A898A878A8D858C90A5ABB0909399
8F979B8A96999EACACA7B3B3B5BFC3D3DEE3BCC5CAC3C8D0BABFC9D1D9DFD4DCE1BECBD4
AFC7D89CB8CEB5CBDEA6BAD05271978EB3D9C5E5FD89A9C93F6FA30F44883D6D9AC7E2F2
D0DFE9D2E0E8D2DEE7D3E0E8D1DEE7CADDF03A5B892B41788F698B85162C9C0D209C0A19
990B19850E1E9D5E6CDDD3DCCED5DECAD7E1CAD9ED5B709A232963703C65800A23940214
9A03119404137B0A1A90606AB4B4BDC2D1DB899AAE35496E2225536D39567F081B92010F
97010C97010D8F040F7A161C9D797C8485877E888C78868976858875888A7386886B7E7F
6F82847184877082866E81856D80837284846F82827082866F82887085886E83846E8282
7386866E8381687F7C607674657A786279776A827F687D7D575E581D960E00FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004FBA2937251C08030A493B3E604B48
301C1E533C406848486C4A4A6B4B4E6E4E536A494F6E4D5471525972525B73515C78545C
7A525A7C555F6D4A566C4A567B5561875D688C616B8F646E8E626A8E626891676B926A6D
946F719C797B9373759C7F809B83829F8A889784839A8B889A8D89948B85948C878D8380
918784857F7A87827F87848285828282807D8888868B8D917F87916975808B959B92989B
929A9D98A4A6D3E0E1C0CBCFA5AEB6A3ACB3B3BDC2BBC4C9B3BBC1D5DFE4D5E0E5C6D5DE
738A9F4E6C85AEC5D8CADBE7B1C7DD84A7D35D89BE719BC92C588F0B3D7C4C79A2C9E3F3
D0DFE9D4E0E8D2DEE6D4DFE8D2DDE6D1E0EB85A0BF133066746C95792942910E209A0C1B
9B0A1B960E20832237D3B3C0D3D5DFC9D7E0C9D8E79FB4D016295F5846777115348F0519
97011095010F8705138536428F7D87848E998294A15C708C0F1E4D6751766E11288E0515
96020E96010D94030F7E091193585D8B84867E898C79898B75868776898B7588896C7E7F
7382857282847385886F83856B7F816C80806D807F6F82836E81846F84876F8486708584
7085836C8280667E7B647A77607674607977728C89778C8B5F6A641F9B1400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C12E3520150E070C5142415E4A45
2716175B4648664B496749486A4B4E69494E6B4C516D4E53704F5875505C785260764F5B
7A535C77515C6F4F5B72525F7A5460855B658A5D6792636C9161698F5F66906368946A6C
9A72739B7878907271947B7A9C888695828094827F978884998D8898918A98918B918583
9186838A84808C87858C8786878281868381828384878F98516072687887828E94A4ADAF
9BA3A78C969BB0BBC29EA9B1A3ADB3A8B2B5D2DCDED6DEE2C0C8CFAAB8BFB6C6CBC5D5DA
B5C6D0B6CBDBC9E1F2C8E0F59EB8D61C457D0A3C84628FBF94B6D87D9FBCB6D5E5CFE4EB
D4E0E8D4DFE7D4DFE8D3DFE7D3DEE5D1DEE7C5D6EB2D4A784655877A4F6F8111278F0515
990819960818830B1F9C606FDBD4DCCCD6DFC7D7E3C4D5E84D648E252A61703A5F810921
90011093010B8D030F77101C936B75A1A6AEBFD1D99BAEC12A3E653A38636C2B4884081D
92011193010F93010D87060F7F2D349B83887F858A78898A778A8975898A738686738585
75858876878778878A7083867084866F83827183846E82826C7F836F83867285876D8381
6E84826E8382677F7C647B785F77736078756F88857A908E63716C346E2400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0061C83340271A190D0F5946435F4944
2616165D4D4D644D4F62484C67484F6A4B516C4D526D4D55714E57754E5A78505F784F5D
7A515D7D55626F4A566F4B568058618659638D5E6791636B8F5F698B5B648F646A956C6E
9A74759E7B7B937574997F7F97817E93807B93837C94858090857F99958C9A958D938785
8A807D8B8480918B8A958D8F8D8587807D7E7F81886B7A8C394F647B8A988D969DC8D0D3
B1B8BD8E969C8A939BAFBAC0C1CBCEABB5B7C7D2D6CAD5DBB6C1C8AAB9C1C2D4DBD0E0E6
C5D4DEA9C0D46E91B54673A38BB1D65E81AA4B72A59FC9EEB8D7F19EB7C4CFE2E8D2E1E6
D5E1E8D2DFE7D2DFE7D1E0E7D1DFE5CFDDE5D0DEEC748DAF132F67625886711A38890618
960515980717910B1A761B2BD2B5BFD1D5DDC7D5E0C7D7E59DB1D11225595945736C122E
8B051692010E90010F7E051383434E948D94BAC9D1A6B7C45A6C8C131C486B476A760D24
8F031492011091010D89040D720D179F727883848979878976898A778B8D75898B728688
75888A7286857384876E80837285867084837084857186876E81856F81847082846D8180
7084846F84846A7F80667D7D6076756279776E85847A8E9067767447413500FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0031E3174D2E1A251512604A43604640
3925234C3A3D5B464F3B242F5E444C694A516B4C536C4D5370505874515B744F5B744C59
784F5B8258638156617E545E7F545C8659618C5E6792636E91626D8C60698F666C977174
9A75779F7C7E9B7C7D987D7D947A798F7A768E7C769A8B849B92899B988F99938F948B89
89807D8B84818985828A8484878283828084788390324761667A8F89959E929A9E9AA2A5
989EA391979C8E979BD0DBDFD6DFE4ABB5BBA5B3B8B1C0C4C8D6DAC0CFD6BBCED9C8DDEB
BDD1E1A5BDD54266911F508597C1E2B5D3EC81A3CC4875AF3A659A95B5CFCDE0EAD2E0E7
D2DFE7D2E0E7D2DFE7D1DFE6D2E0E7D1DDE5D3DFEABDD2E82340732F3B71713D5D841025
920415940311960714871020A56A77D9D2DACAD6DFC6D6E38DA0B9364B762C2D5D6C3150
80091B90021091010D880410731A2497778080868D8D9BA58090A61A2B53504770681B33
88061790000E91010D8C020D79051188464E8B83857D8A8A78888C788B90788B8F738789
75898A7587877385877386887082857184866C7F826D80826F83847083857384866E7F7F
6D7F81697D7F687C7E6A7D7E66797A6176756C80837B8D926D7A7C53504600FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00563316331D18624A3F63483D
5C423D462F332B18233D283260484D674B4E6D4F536E4F556C4E536E4F5671505974535A
7E5F66A2848A83606B825864805360845964895F688F656E9267718B616A8E656D936E75
9672779D797E9D7B7E9576779073728F7773907D769588809D938A99928B9C9693918A88
88807E8F8A868884808C88848884857E838A51637D1E385698AABA959EA4929A9F919B9E
B3BABDCED2D699A0A6A8B2B9B9C3CAA6AFB6A6B1B8BFCDD1D2E0E4C6D6DF92A9BB4B6B83
A5C2D3BFD7E49DB7CD90B6D8ABD5F99FC6EA476DA10938870737807A9FC1CDE2EDD2E0E7
D2DFE7CFDEE5D3DFE8D2DDE6D2DDE6D1DDE4CFDCE3CCDFEC6881A510295E725F876C132C
880619920311990714930A1A7E2032D8B8C4D2D3DDD0D7E7717891979CBF312B557F4E6C
7B0E238F021193010D8D020D7707138E5961858185C6D2D6BDCDDC455A7D2229586D3B5A
7E0B208E010F91010B8E010B82030F721B2393787C7F868778898B788B8E788A8D76898B
75878A78878978898D74878974868A728286718386728486718483708385748386708181
6E8081687F7D687D7C6B7D7E6B7C7C65787A6A7E817B8E92738184585A530FCA0700FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00643B1841251A664B3D684C3D
6A4D444E373638252A5D494E5E464A694D526C4D526E50556D4F546D4C526F4E566B5258
A99A9ECBBFC4A089947B5365835566875B69845B668C636B9168708E656E8D656D97717A
98747B9D787F9572768C6B6C8D6E6E8C726E927F799887829E918B958B869B9390938B8B
8D86838883808C86838F8885868284767D8E182F51435A7782909B8991958F969B99A2A7
B8C2C5D1DAE09DA6AE87919AB6C1C7D3DCE2C5CED7A2AEB9B8C7D2A3B3BD9AAFBE7794A8
BFDDEAC9E2EDBFD7E75F83A921508E1C4D88769DCA294F854970A0B4D1E8D0E1EAD0E0E7
D1DFE6D0DFE6D2DEE6D2DCE5D1DDE4D0DDE4CEDDE3CCDDE6B3C7DE193362373D6F62304F
76081C8E0414960412940312850A1EA35266B37F97A475938655788D547889486B963F59
880D2191021194020D91020E810715925058ADA1A8A3AFB7AEBFCC6A8099172753685378
6C0F2889041390010C90010A8B020D74070F8F595E8883847D8A8C798B8D798B8D798B8D
76868B73838975848B76878C7584887281837283857587887284866F83856F82846E8282
6C807F69817E6C807F697C7B687B7C677B7C6D8285788C8D78898C5B635F219B1400FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075461C4B2A1E6C50416C4F3E
6B4D425C413F45333A362832463339664C517051566B4B506D4D53704E55714F58675059
B4ACB2C6C1C8A18E9C81596D865569875768865B688F64718D626E8A616B8C676E936E75
9872799C747B8F696F8B696B8F706F8F75738F7C799988879A8C8A938783968C898E8583
89837F86817C8D89858F8B8888898F505D7A132B516C7F96869096A3ABAED0D8DD9FA8AF
9DA5ACA2ABB2ADB7BF9DA7B0AFBCC4D3DFE7B8C3CF8897A47C8D99C8D8E0CBDAE2A1B6C6
A4C4E197BCDD92B5D64C709C0A377A21528BB4D8F788A9C87195B2C9E1EFD2DFE8D3E1E7
D1DFE7D0DEE4D4DFE7D4DFE8D2DDE4D1DEE5CEDDE4CDDCE4CCDDEC677F9F1228595D527A
631933820A1D9309189204148E0617870C2280112D80123282113384113089122D880B1E
8C07178D08128F09138908117E0D19753540998D967B858F818F9B8D9EAF33476B3B3C65
6B2A4781061990011092010D8E010C8305107E2E36978384808A8B778A8C77898B7D8F90
7A8D8F76898E79888F7A888E788689758486748387708284697C7D6E82836D82826D8283
6E82826F82816A7B7B687D7B6A7F8064787B697E81778B8C74878A5F6B69209D1800FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00299101522E1F6E51456C4D3F
6D4C41684A491F101827212E4F424B634C4F6B4D506B4B506A49506E4C546F4E56684F58
A2939EC3B4C285697C82566A855565885867895B6B8B60718B606E8B626B8A646B926E73
956E749A7178946C728F6C6D927573917977917E7F928283968A89998F8C968C88908681
8C857E88857D8988839090907A8396172E56324B6F8594A38A929899A1A8B1BAC39BA3AD
99A0A8B6C0C5D4DFE5C8D5E082909C9AA9B399A7B09CAAB38E9FA9CDE0E9CEDFEA8EA4BF
274E800E3F795A87B4B1D1F05B7FA889B4E393BBE75E88B64F7897CBE3F0D3E0E9D3E0E6
D4E0E8D4DFE5D3DFE8D0DFE6D2DEE5D0DDE4D0DEE5D0DEE5CDDBE5C4D5E5556B8C2C3B61
5A44626520337718247E161F8018207B1720801F2C7C1F2D7C2130802A3981303B873539
83323883383C81383B7D383A783D44856A71A7A8AE87919A9FACB5C5D3E07E90AD16234E
704A6E770B228D021491000D8F010B89030E740F17956D7183868878898C78888B7E8F8F
70828478898E78899077888D78898B77888B74858A7285876D81816E82826E83836C8183
6D7F83728184707F7F6D807F6B7F7F697D7D6B80816E84856F83845F6D6C453C3100FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00369D08532E1C6E5142684B3A
6C4B3F6B4C482E1B21180F1B261B24654E526B4C4E69494C67464C6A49526E4B546E4A57
7353617C5C6E7D5769805665865863885866895D6D865F7085626E855F67845E66946F76
9A7578956D718D6568906D6D917371977D7D9C87899585869B8D8C9C918F9A908B938984
9189828C87828D8B89959AA34A5D7F092957627C98C3CFD69BA1A58C939A8D959DB6BFC6
ACB5BDA0AAB3C4CFD9A4B0BC77879292A1AACFDDE4D2E0E6A3B4C0869FB38CA7BB94ADC3
47688D3F659198BCE1C6E4FE9BBBDC2C5892083C881D55919EC6E4CBE1ECD2E2E9D1DFE6
D5E2EAD3DFE6D1E0E7D1E0E7D2DEE6D1DEE6D1DEE6D1DEE5D0DBE4CFDBE4C7D6E597ABBF
6C798C776E7A927579906C6E90696C9874759C7D7EA1888AA9939B6D6273827B8A9E969A
9B9094928C918C898EACA7A99B9A9F929EA7C4D5DEB9C9D48A99A5B0C0CD899BB421345C
4E40686A193588051990010D90000A8C020C7C051086474C8C85847A89897B8A8F7B8B8E
7A8B8D7D8D917B8D92788A8F7A8B8F76888B72858974888A7185877488897286876D8284
7284866F80837081836A7E7E6D82816B807E667C7A6D82827386876470704B453D00FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A8105129146D513D6B4F3B
6C4A3E6B494260464643323B3A2C35654F53684A4B66464A66464C68454E6C46536D4551
71495579505E7C505E7E535E8256628459677D59686E536264505C6F58627F6067946F74
9A72769A7276936B6D957071917070957A79937F7F8473749788869A8D8A978C88978D8A
9289878F8887918F92858FA4102D5D193B6A7990A49CA6AB8C9295898E939DA5ABD4DDE5
C7D2DC87939F8C98A3ACB8C1BBC8CF9DAEB6C2D3DCC0CFDA9AABBC46647C7290A8CCE3F2
B3C8DD87A1C1799BCA537BB2709ACA204D8A073986376CA2BEE0F6CEE1EAD1DFE8D1E0E7
D1DFE7D2E0E8D1E0E7D0DFE6D2DEE7D2DFE7D0DDE5D0DDE3D4DDE5CFDBE2CCDBE3C6DBE0
C6DCE1C7D7DBCBD4D6CBD0D1CCD0D1CBD2D4CDD5D7CCD8D9BFCBD66B8299617E997992A6
9FB1BD6F8397617990C0D4DFBACDD78194A3A5BACAA3B7C57B8A977787938EA0AF586C8A
2227536933558008208F021092010D90010B890510772025967C7D80898A7E8E91798B8F
7B8E907B8E8F778A8B798B8D778A8E76898C74868A71848872858976898A728587738688
7486867185846F83836A81806D83826F85856D828270848576878B69757654504900FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B51951280B6B4E3A6C4D3C
6C493C6C48416347472C1B252E1F2C5F484D6A4C4D67474B67454C67444D6B45526C424F
7349547C4F5C80525E825662815763765160614453634E5C5B4C5A50434F6C57608A6A72
977078926770946A6F926B6F917274947A799985838C7C7A988A87988E8999918C958E8A
97918E9893938F919D4C5D840A2B673E5C8795A4B399A1A5B4BDBDBEC5C98C949DA2AEB7
8E9BA48A969F8B98A0CEDCE3D1DFE5A0B0BA8294A29FAEBAC2CFDC98ACC09DB9D2BEDAF4
A2BCDA7595BC15407E083D886495C892B8E0537DB279A8D2C2E1F3CDE0E9D2E1E9D1E0E7
CFE1E6D1E0E6D2DFE7CFDDE3D1DEE6D1DFE7CFDDE5D0DEE4D1DDE6CCDAE3CBDBE3C8DAE0
C7DAE0CBDBDFCFDAE0CED9DDCBD8DCC7D7DCC7DADFC7D8DEBFD0DC728AA523447234557F
B8D3EA6A839C344C6BA0B7C8B3C6D48395A47082929DAFBAA5B2BB818F98C2D2DCA9BBD1
19275361436B770F2A91051795010E92010A8D020E770A1296646A8787898090917D8F91
7B8E907A8D8D7A8B8B738685788C8C7B8E916F818477898C73858875868876888B76888A
7183857085856C81816A807E6E828371868973888A718586788A8E6C797B5B5B561F950F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005B2F056848346C4D3D
704D3F6B473E55383919050F39262F61464C6B4A4C6C484C6A464D6A434C683F4C704652
754C57784D5A7F525F7F55617C58656043516C5260785F6B75616C594E59544653826874
916B768F646E936A73906D758A6F758C767A968483988986938883938B85948D88958F8C
98938F9B999A858FA6142C640629666B86A69AA5B09FA6A9C8D0D3C3CCD2919AA4808B95
BCC8CECED9DF98A3ACA6B5BFABB9C3909EA9758690C0D0D9D3DFEABDCBE06A87AF2A5588
618DB69FC7E94972A02D5D9497C6EEA1CAEE5D87B4306089C1DFF1CDDFE7D1E0E7D1E0E7
D2E1E7D2E1E7D3E0E8D1DCE5D5DEE8D1DFE6CFDEE5CDDDE5CCDDE7CBDCE6CDDCE5CBD9E0
CEDAE3CED9E1CDD7DFCDD7DFCCD7E0CAD7E0CBD9E3CCD6E2C9D1E2939FBE182B6113275C
97A6C5B8C2D79699B2898CA09DA2B3B7BBCB8E91A3CACADAD3D1E1A1A0B1A9A6B8ADABC3
4C4B7150375C791F3A8E051997010F95010D91010D860612883A459785898890937E8D8F
7F8D938190928392937C908E7A8D8D7F91936D8083798C8E728485768A8A758989768989
7285866F84866C82836B82826B818273878A6D808473868876888B6D7D7F5A615C219B15
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B3B0C67472E6E503D
6F4F3E6C483D5A3A354327286245456847476B49496A47496A454B6D444D6C424D69414C
754D58794F5B7C525F79505C70515C5A44507359667E626E7B66716155614D4351796471
8B69738E677086616C7B5D67775F69806B748E7C7E988887968A879A908B988F8A928B86
95918C9A9DA257698B062665193B6F90A7BABFCACEA2A7ABA9AFB4959FA5A1ABB287939B
C8D5DCD3DFE79DABB68495A1A5B5BED1DDE4BDC9D38E9FAEA8BBD09AAEC65977A10D3A74
5E8CB6C2E8FFB1D1EB6D95C24274B1356CA86091C05D88A8CAE3EFD0E0E6D3E1E8D4E0E8
D4E0E8D2DFE7D3E0E8D2DEE6D2DDE7CFDEE4D1DFE5CCDEE9C3DAEEC3DBEFCDDAE9D2D8E5
D4D3E2D8D2E3D4C8DDD2C3DAC8B5D0C6AFCBC2A7C4BE9DB9BD95B6AE83A96F447170436E
8957798953708E506F8A4A68915370955976874869904E6E9A57788C4869874262884563
8543628C415F92223C91021698021194010C93010E8F04107F121FA76E75977F8790858D
8D868F87888D828A8C7C8C8B7D8E907D8F9274878B778C8D798D8D798E8D788D8E738988
73888972898B6D8685677F7F6B8282748A8C5C6E727284877B8D907082845C6865336C23
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00834D166844266C4D38
6C4D3B6C4C3D6B483C67443C6946416C4A446B4B4767474768454969434B6B444E6C454F
764E597B515D7C525E79545E614651604C58755D6A7A616E72626C5E576147414D75626E
8B6A748A656E7E5C659070798C72797D676E927D80968383958685998E8B9C928E8E8782
8F8B898C93A2223A6C0326693958839CADB9B3BCBEA9AFB3A1A7ABB7C0C4D4DDE2ABB8BF
8A98A2A0ADB4AAB9C196A5B0AFBDC8D1DDE7BDCBD87990A843617EB5CFE7B9D2EC6C8EB4
9AC4EB9EC7EA96BCE0406B9F073E920C489495C3E9BCDAEBCFE0E8D3E1E8D5E1E9D6E0E9
D6DFE8D4DFE7D3DEE5D1DEE5D2E0E6D1DFE4D2DFE7BED3E24667905D7DAC979BBE8E6D8D
955B7D934E6F883B5E8631547A22447E21447E1C41811A3E84173D7E0E347F0B2E810B29
8109258509268808268807248808258807278C0A2A8C09288D08298D09278B0724890721
8B08218B071D93041998021496011092010B93010E91020C8D0614841523822637853548
843E51854D5B87666F8A888A7E8C8E798C8E76898D768B8C798B8D7A8E91788C8F758A8C
74898B73888A6E84846F83836F838375898A65787A697D7F7D9193708486637071474035
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DA1086A4221704F3B
714F406C4B3C6C493B6A463B67433B6846406748446748486846496A454B6A464E6B4851
734D5779505B7B515B7A565F58414C584A556A5A656B5C66665F6854535C47424C79666F
88656D89626A83626891737890767A7E686C957E83937E82958585968C899B938E948D88
979799667391032162163A7D6883A7A2ADB7A3A9ACB7BBBFA2A8AEB7C0C7CCD6DCA4AFB7
8D98A1B1BCC2D5E1E7C5D2DC94A2AF93A4B099ABB58EA6B754748AC2DBEECCE0F295B4D7
2857940E45894275AF83AEDB2251923A70B1A1CEF3C9E2F3D1E1E9D2E1E8D2E0E8D4E0E9
D3DFE7D5E1E7D4DFE5D2DFE5D1DFE5D1DDE3D1DFE7CADEEF4869951035747170A367244B
871538971836930E2B971029950F258F0C208F0A208C0A1F8C0B1F8E0D218D0B1F8B091A
8F0C1D900D1C8C08198D0B1B8A081A89091B8809198709188A08188C0B188A09178A0916
8C09168E0B178F08178F08168D06148B06118C05118C05108A030F8A04128C05178A061A
86071A7F0B1E6B142296777B858C8E7B8E927B8E92788C8D788B8C72868875898C73878B
768A8E768A8B7084857084837385857589897286876C8183758D8E798F906C7C7D4C4A41
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047A90C72441F724D3A
7551446E4C3D6A49396C483B69443B67453F69484666474667474A6A474D69474D6C4A51
714D5676505A79505A78546057414D4D44505A54605C57625858624A4B56524853836771
8C656D8861698261688C7074816A6D867076947B83957F859786889A8D8B9A918C97918D
8B8F98293D6A03236D1232708DA0BCA8ADB4B2B5B8D6DBE0BEC5CE9AA3AE909BA4B8C3CA
B6C0C8A5B2BBC7D4DEB2C0CB8A9BA97C8F9BCADDE4CFE2EA9DB3C394AEC698B3CD85A5CB
184687073E8B376CAABDE3FF97BAE64C7CB92A5B93B1D3EDCFE2ECD4E2EAD2E1E8D2E1E8
D3E2E8D2E1E6D2E0E6D2E0E6D1DEE4D1DEE6D0DFE8CEDEEB9BB4D4153A7455649A6C3E5C
7E1A2E8C19268C18238E1E26861D2781202880232F7A232D81303881333B883C438C4348
8A434889464F8B485386434A89474E84464D86494F85464C84454987484B834247844147
864145864043873E42843B4181363C7C30367C2932792429741B1E75171B7710167B0F15
820E17800C176E0C1883565B8B8C8F788A8C7D90937B8E8F748789758A8B73878A778A8E
75888C73868970848672868770848474888872878973898C71888C768E91758989585C55
0ECA0700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B211724219724C39
744F42714F406A49396E4A3E69463B63423A67474566484863464863464967484B6B4A51
6E4A53714D54764F5A734F5E634958463C4B4A48564F4D5B51505C4C48546B5865896572
8B616B8C636B7F5B62795B608266698D7578937D81947F83978587968888988E8D999596
767F960B225E02206C2B4477A5B0C4B3B5BAABADB2BEC2CAA4ABB59DA5AF9FABB4D2DDE5
D1DDE58D9DA890A0AAB4C1C9B3C1CB8D9DAABDD0DCC5D7E47E94AB35587F4C749BC3E2FE
86A6CF4972A8699AD277A5D78DB7E71545841A4C8EB3D4F3CEE1ECD3E0E9D4E1E9D3E1E8
D2DEE4D4E0E8D2E0E7D1E0E7D2DFE5D0E0E6CEDFE7CEDFE7C9DCF143658E28497879768E
7C545F936064986869986E709874779F8286A68F92A79496B8A6AAA89A9EADA4ABA6A5AB
B2B2BB7E849A6E7791ADB2BCAAAAAE83858985878C888689888789828183ACACAEA6A4A6
8D888AB3AEAEA89FA1928A8C8E85878F8587998B8D928180957E7E9277748D6B698E6462
8C5A5B814B4E6F3E42745D5C848B8A798C8C7A8D8F7B8F90788B8F768C8D6A7F8174888A
788B9074888B6C8086697D816E818372878772878974898B73878C73898E788E915D6562
1F981400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774618704B36
724F426E4C3F6C4A3D6C483B6F4C3F68473D6545426648476246476146486446496A4950
704D55754E57764D5A77505E7353614E3C4A48404D4B44515C535F675A65856D788E6976
8F68738F676F8E696D8E6B6D947575937777957E7F958183908080958A889A94928F8F9A
46537A051E67031F6B50648FC1CBD8C7CBD0A6AAAF9FA3A9C4CAD0C5CED494A0A9B0BDC8
9FABB692A0AB92A1AAD0DDE3D5E1EAA3B4C27D94A493AABBAFC5DA46678B4F779CC1E2FA
A9C6DF7FA2CC1C4C900B4494598FCB517DAC426792C4DEF2CFE1EAD3E1E8D4E1E8D4E1E7
D3DEE3D4DFE7D5E0E9D2DFE7D3E0E6CFDFE2D0E0E6CFE0E7CBDCE9A9C4D87E9DB69CADBA
B0B6BCBEC0C1BEC2C3C4CACCC6CFD2C7D3D6C9D6D8CAD7D9CDD8DECDD8E18598B0527396
B1D0EF3455821236688BA9C2B4C7D28D9FA781949A9FB0B3B5C5C88D9FA5BFD0D9BFD1D7
8999A2A2B2B89FADB3919DA297A4A78E9B9D909EA28896978E969A8C97978891908D9392
909294888B8C8285877D84827C8B8B788C8D7A8D90798D8F7A8E92758D8E73878C74888C
768B8F72878A6E8286677B7E697D7F6E828274898A768B8D73878C728A8D758A8D5F696A
31682100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C4A16745035
7151406F50406B493E6C493E6D4B4068463E64433E64454262444464474A66454B6A4750
6C4750714854764B597C53607E586571535E5C45506A576179646E8870798F707893707B
8F6A758E69718E6A6D9674749876799173748F7776998683988A86978F8A9A97978E93A7
1629600220720B2E726B83A1919CA3A6AEB1AAB1B4A9AEB3D3DBDFD1DAE09BA5AF8A95A0
B1BDC5CCDAE1A7B5C0B0C0CBB4C4D19FB3C15772859DB8C8CCE0EEBED5EB6D8FB4608AB4
8BB6DD76A2CD114288064095528BC6AED5EEB2CCDFD0E3EDD3E2E9D3E0E6D4E2E8D4E1E7
D4E0E5D3DFE5D3DFE8D3E0E8D2E1E7D2E1E5D3DFE5D3E1E6CCDAE3CADEE5CCDFE7CADDE1
CDDCE0CDDCE0CCDADFCDDCE2CBDBE1CCDCE1CBDBE1CCDDE2CDDCE4CDDDEA89A2C50E3874
7198C97697BF4C6D95819FB9A0B7C6B6CCD68DA6B0B3C8D0C5D7E09EB1BD9AACB9ADBEC9
97A6B199AAB4A6B5BDA6B5BB9FADB4B6C6CC92A2A991A0A78B99A18C9EA28A9B9F8FA0A3
87969C80909885959C8090927C8D9074898C788D90798D9175888C778C8F74878D758A8D
71898B728989718689667B7C6A7E806C808173878B768A8D71858B72888D7A8D93677375
443D3400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00825117745030
72533E7051406D4C406D4B416B4A416B4A4166453E67464266474667484C65444C6B4853
69444F724755794D5D7F536480556480596682616A886A718F707790707894707B98727F
936D79936E768F6B7198767A98767C97787C987F7F978582998D889B928E9C979C727B99
061D6104267A1F44818399B1929B9FB8BFC1D2D9DDABAEB6A7ABB5A1AAB3AAB3BC8E98A0
C8D6DBD3E0E9AEBCCA94A6B4AFBFCACCDDE6A8BCCC87A0B3ADC6D796AFC5426693083B7E
4579AFB4E2FF83ACD84C7BBB4578B77FAFD9BAD9EED1E3ECD4E1E9D3E0E7D3E2E8D6E3E9
D2DFE5D4E1E7D3E0E8D4E2E9D2E0E7D2E1E8D4E1E7D3E0E5D2E0E7CFDEE5D0DFE6CCDDE3
CDDDE4CCDEE2CFDEE6CCDDE4CFDDE6CDDDE3D1E0E7D0DFE6CEDDE5CCDDEAAEC6E2315687
779EC99BBAD2B4D1E881A6C3A7C8DFC1DEEC748FA294AABABACAD89AA8B698A5B1ABB6C0
B5C2CBAEBBC6C4D2DCC2D1DA9BACB5A5B8BF92A5AC93A4AB97A7AF95A6AD8E9FA78C9DA4
85959E80919984959C899B9E84979B7B8F93758A8E778C8F77898F778A8E70828972858A
71878A718788708487697D7F697C8162757A6C80856C808472868A71858A788B906F7E80
48463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C5A1A74502C
71533C7053426E4E3F6E4C416E4D436E4F466A4A456848466A4A4C68494E694950694952
6A4651734A58794E5F7B4F627E51648459678A636B8F6C728F6D74926F78926F7B967380
99768198747C96737A9B797F9A787E9B7C819981839D8C8BA093919B91919996A0394671
031C6C01207727447B9AA7BB9EA1A7B5BBC0D0D7DDA7A9B19FA1AABBC2C9D3DCE3B2BDC4
9DADB49DADB6A6B4BF8F9FACAEBEC9D3E1EBB8C8D9728BA6597A9AACCCE67593B91A447C
5E8BBBB7DDFAADCCED648BC30131841E5BA49DC9EBCBE2F0D3E2EBD4E1E9D5E3EAD5E2EA
D4E1E8D3E1E8D7E4EAD5E2E8D5E3E9D4E1E9D5E3EBD2E1E8D1E1E8CFDFE6CFDFE7CEDFE7
CFE0E8D0E0E9D1DFE8CEDFE8D0DEE7D1E0E7D3E2E9D1E0E7CDDEE6CDDDE8C2D8EC9BC1E9
70A0D1A1CCEE9EC5E42255866090B8B0D1E798B2C69FB2C1B1BECBC0CAD4AFB9C3BDC9D1
C7D5DDB3BECBB8C4D1B3C1CF99A9B6A1B3BDA3B5BD9EAFB696A8B293A4AD91A2AB93A2AB
8B9CA48C9EA48C9EA3889B9F7183896F8388788C92819498899AA17D909474878E6F8388
6A8083687E806A7D826A7D8166797E5063695B7177617A7E667E8170848971858A708183
51544C0FCA0700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A60A744E27
6D51386F55406E513E7050416F50457053496E514B6F524F6D50516A4C50694B506F4F56
6947506D4753744D5A79505F7E5364855B688D646F906B75926E78906B7794707C977580
98767E9B767F9C787F9E7F83A081859E8184A0888B9E8D8E9C8F909D94988C90A5162863
011C7502207348608ECBD4E1AFB2B79DA1A6A7ADB2B6BAC0A3A8AFBAC3CBD1DDE6A8B5BE
9AA9B1A6B8BFD1E1E8C8D8E37D909E92A4B296A6B86882A1183E659ABBD8C9E1F897B5DA
6E99CB6090C493C1EF5B89BE0A3E8E1856A197C5E9CCE4F2D2E1EAD5E3EBD5E2EAD7E4EC
D7E3EBD6E4EAD7E4EAD6E5EAD6E5ECD5E2E9D6E3ECD6E4EBD4E2EAD2E0E8D5E2EBD1E1E9
D1DFE9D2DFE9D2E0E9D2DFE8D5E1EAD3E0E8D2E0E8D2E0E8D0DDE9CFDDE9C7DEF35D8AC0
0E4C9E437EBC9DCAED4877A375A1C5A1C2D6B4CBD9A9BBC8B7C8D1CBDAE0BFCCD5B7C7D0
CAD8E4BEC9D6B8C3D0ADB9C6A1AFBB96A8B2BACBD4A3B4BD9CACB897A7B195A4AF94A2AB
93A3AB8E9EA48E9EA286989E879AA17B8E9476898F788C91788C91768D906A8085637A7E
6A8084687E80697D836B7F826A7D8153686E556B735D7679657C7F6A7F836E86896C8082
5E605D1F961100FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A90B744C24
6E4F366E533D6D523E6C503F7053447255496D514A7155536F5454694F516B4F536E4E54
69464E714C5578515B7A515D805664865C6A8C63708D6876906C7A8F6A77936E7A97727D
97737C9C777F9E7A819F80839C7D809F8184A28A8EA28F919D90939C959E656E91061D69
011E7D01206D6D84A9B6C1CBA9AEB39FA6A9B1B6BAD6DCE2C9D1DA95A0AA8E9BA4B5C3CB
A9B9BF93A6AEC1D3DDB6C8D48296A690A5B5C9DBE9BFD2E76A85A4A2BEDEB1CAE399B8E0
164C930B50A32E71B4A8D5F76F9AC67FB5E4B3DFFCD0E6F3D8E6EED9E5EBD9E5EBDDE7EC
DCE6EBDEE8EDDDE7EFDCE9EEDAE7EEDBE8EED8E5EDD8E5EDD8E3EAD8E2EAD6E2EAD5E3EC
D5E1EAD6E3EBD5E2EAD3E1E8D6E2EAD7E2EBD6E2EBD2DEE7D0D9E8D1DDEACADEF5658EC5
134FA44683C2B5DEFABCDEF7BFE0FABADBEEC6DEECB4CBDAB7CCDBC1D4E0BCCCDAB2C3D0
B5C4D0C5D1DCC5D0DDCCD8E4BCCAD690A1ACA8BAC5A1B2BDA7B5C2A4B2BE9FAEB99AAAB2
99A7B1919FA797A4AD8B9AA380909971848A70828971858A7084896D8488687E83657A7E
6B7F82697E80667C80667E81687D804E666B4159605A727664797C677F806A8384697E7F
616867229D1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB01077491F
704E377054416E54416B513E7155457153476E514B7153546D5153694F506A50526D4E54
6C49516D495279525C7B535E825966865D6A8C65728D6874916C79906B79946F7A97737C
99777F9A7980A08085A18084A18185A4868CA0888DA190929E91969894A63A487B051D76
06268824468D798EAD97A0A6ABB3B4B3BABDAAB0B5C7CFD8ABB4C08B99A399A9B0D1E0E4
CDDDE376879390A1ABACBEC6AABCC7798E9BC7DAE7C6D5E899B0CF7899C789ACDAA7CAF4
3465A43773B95E98CCCEF1FFDBFCFF7CB4D786BBDCD0E7F6DEE8F0E0E8EDE4EAEEE7EEF0
EAEEF1E9F0F4E6EDF4E1EAF1DFEAF0DFEBF1DAE6EDDBE7EEDCE6EDDAE4ECD7E3EBD5E2EB
D7E3EBD6E3E9D5E2EAD2E1E9D5E2EBD4E2EAD4E0E8D1DFE7D1DEE8D1DEE8CDDEEDA9C9E8
79A9DD8FC4F4ABD4F1B9DAF45E86AF83ADCEB9D8EB9DB6C89EB4C8A6B9C9B1C1D0A2B2C0
C4D3E0C8D7E4ACBBCABCCBDCBCCFDEBBD0DDB5C8D3ADBEC7ABB7C3A0AEBB9DAEB8A4B5BF
A1AFBC9AA9B394A3AD90A0A98A9AA3798C92768A8F7284887083887084886D82866A7D81
6A7E7F6E8384697E82677F8362777B526B6E5B747A566F735F777A647D7C6279776B8082
64706E433B3000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A4917
704E336E513F6E53426C513E70524273524770524B6E504F6E50536E53546A50526C5156
6B4C566E4E5874515C77515D7E5561845B688B616F906974936D79956F7C936E7997757D
98787F9E8086A18388A5858BA4848AA5898EA0878FA08E939E929B9191AD182A6C031F80
0223841233758B9DB799A1A5CDD5D6D2D8DDA6ABB3969EA7B8C0CAC7D2DAA3B2BAB4C4CD
AEBFC883939D95A3ACCBD9E0D3E2E9B8C8D3A5B7C67F92A78EA6C7183E762D558CBBD7F8
C6E0F6C9EAFCBEEBFEA4DFF3AAE5F97FBEE197C9E8DAF0FBEAF0F8F7FAFCFBFCFFFCFEFF
FAFDFFECF2F7E8EFF6E2EBF4E0EAF2E0EAF1DEE8F0DAE6EDD8E4EBDAE4ECD7E3EBD6E4EC
D8E5EDD9E5EBD7E2ECD3E0EAD4E1EAD2E1E8D3E1E8D0DFE7D0DFE9CFDFE8CEDFEBC4DEF1
94C0EB326EB06BA3D6B0D9F647719A7DA5C7ADC9DCB2C7D6AFC1D1B7C9D7C9D9E8B5C7D5
B9CCDBBBCDDDA6B7C8A2B3C6A1B6C49DB6C2AEC5CEC0D1DAABBAC4B0BEC9A8B7C0A6B6BF
A4B3BE94A6B090A1AD8EA0A98C9EA47D9195798F936D82856F83866E8385708587708487
7387877286866C7E82697D8164797D566E706881825A7376637A7B617877667A7B657A7C
66757447473B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00814F18
704B2E6E523E6F54426F514273504476534872534A6D4F4D6E51537153556D52546B5154
694E566B4F5973545D73515A7C55618257678C61718C6471926D79926E7A96737E977580
9C7C86A1838AA2848BA08188A08088A3858D9D858B9E8B909D939E757CA108206D032288
0122812A4882A9BACD9EA5AAB7BCC1B4BAC0A2A8AEA0A8AECDD6DCD4DFE8A5B3BE8C9CA6
AEBEC5C7D4DCB0BCC3C5D2DACCD8E1C0CEDAB4CBE3A5C1DBC8DFF6849BBA93AAC8D5E7F3
EFFEFFE2FDFF88C1E34CA8D86BB9E1C2F0FFD4EFFDE7F5FCEEF4FBF5F9FCF7F9FCF3F6FA
EAEFF5E4EDF4E0EAF2DFE8F1DCE5EEDEE7EFDAE5EDD6E5ECD2E1E9D7E3EBD6E2EAD5E4EB
D5E2EAD5E2E9D6E2EBD4E0EAD1DFE8D2E2E9D1E1E9D1E1E9CCDBE6CFE0EBCEDFEBC7DDF3
6F9ACE1051A53777BBABD6F4AFD1E9AAC9DFB6CFE2C6DBEBBBCFE0A9BFCFC2D3E4A7B9CA
99AABEA1B3C4A0B3C29CAEBBBED1DDA8BCC69EB3BEB4C8D298AAB6A6B6C0A2B1B8A8B6BE
A2B0B998A9B37D8E998699A08EA0A67A8F95798E93768B8F708789708788748B8C768C8F
768B8C788A8B808F946F80866A7E82597072657D7D546C6C62777A61777763777963777A
6375744D52480ECA06
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00865317
6E482A6E503C70524173524774514874514973524C6D4F4D6D4E516D4D516C4E526C4E54
6B4D566A4D586E525D71515B7C55638458698D61708D6471946F7B93727C95767F987B83
997D859D81889F828AA2828BA08088A4858CA3888C9E898F9D95A64F5A89041F75001F87
0425834B689EC9D9EBA7AEB4A2A8ACBFC6C8D1D8DAB3BABFB2BBC3AEB8C2929DA896A2AB
CBD7DCDAE1E5CED5DCCCD6DDD0DDE5D3E2EEA6BED59BB6CBDCEBF5EDF6FBF0FFFFD0F2FF
AEDCF4B8EAFF92CDED7FC7E7ACDFF3EAFFFFE8F3F8E1ECF2E6EFF6E7EEF3E8EDF3E4E9EE
E6ECF1E1EAF0E2EAF2DFE8F0DFE8F1E1EAF1DBE7EED5E5ECD4E5EDD5E4EBD6E3EBD5E4EA
D7E4ECD6E4EBD7E2EBD5E2EBD2E0E9D2E2EAD0DFE8D0DFE8CFDDE8D2E1EBD3E2ECCDDEF0
9EBDE25887BF7EB0E4A2CCE9BFE0F88FB5D692B6D9BED8F09DB2C895ADBFA7BAC9AFBFCF
9DADBDC4D5E2C3D5E19DB1BDC6D7E4B3C4CF95A7B494A5B095A5B095A5AD94A3AB99A6AE
9BA6B094A2AC8696A07A8D94788A937D9199788B92768A9070858B71888C738B8D768F90
788C90788A8D7B8E9273868B6F83885A70745C7275506667677B7D667A7C64777B637678
607272565C551C950D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00657E0F
724B276E4C3873514075504475524875524B70514D6A4D4D684C4E6C4F506C4E526B4D51
694A52674954664B586D505C795764855D6A895F6B8F6670916C7594737B987A82967A84
987B859A7F889E838D9A7E86A2848AA28389A68A8E9F8C939B97AD28387205217F05258D
072A83516DA09DACBC9CA3A8A1A8ABC6CCCFD5DCE0C0C4CBAFB3BDB0B6BED1DAE0CED4DB
CBCFD5DADEE5D4DAE4D9E3E9E4EFF5D9E4EDD8E4F0EFFCFFF7FFFFF2FCFFC4E5F9559DD0
4495C994D1F1CFF4FFDDFBFFDBFAFFCAEBF8D1EAF9DAEBF2E1EBF1E8EEF4ECF1F4F4F6F9
F6F9FBF3F9FBEEF3FAE7EFF7E4EDF6E2EDF3DDE8F1D6E5EDD4E3EBD7E5EDD4E2EAD1E1E9
D4E2EBD4E2E9D4E1EAD5E2EBD3E1EAD1DFE8D1DFE8D0E0E8D1DFE9D2E0EAD4E1EACFDEEA
B4C9DDBCDAFB729DD16696C8B1D9FE35608B5178A3A2BCD6A6BACC9DB1C0B8CAD5CBDCE6
B9CAD6C2D3E0C3D4E39CAEBD9CAEBC9DACB995A6B19CADB69BA9B1909FA593A1A79CA9B1
99A4AD8E9CA4899AA2889BA1798D93667A8172868D788D93677E836E868A748B8C788E91
798E92768C9072888B748B8C72878963787D4D65695D7275667A7B647778647577637676
5D706E5D655E1C9610
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042A809
734A226F4B32734F3C74504275534673524874544F6C4F4E684D4C6C50506A4D50684C51
684C536245506147546549577B5967845F6B86606A8C676F916D7492717993737F9A7C88
9E808C977C87856E79836B76967B84A4868DA4888FA290989090A9112566021D80082A92
0B31885E79A7A2AEBAD0D5D8CACBCFB8B8BFB9BAC2B8BAC1BEC0C6CFD0D5E2E3E8E2E3E9
D4D6DDE1E5EED7DFE8DCE5EDEEF6FCE6ECF3ECF1F9F2FDFFCDE5F6BAD8F3B1DAF96FADD9
8CC6E7D1F7FFEAFFFFE3FCFF96CAE26FB7DAA6D9F2DAF0FBE8F3FAF4FAFEF8FCFFF9FCFF
F5F8FDE9F0F6E3EBF2E0E9F1DBE5EEDCE9F0DAE8EFD5E4EBD3E1EAD7E5ECD2E0E9CFE1EB
D0E1E9D1E1E8D2E0E9D2E0E9D3E0EAD1DEE7D1DFE8CEDDE6D0E0E8D2E1E9D3E1E9D1E0EB
B0C3D69FBCE316478E134B947CA6D28BACCC94AFCCA6BED2CCDEECC3D5E2B6C8D6C9DCE8
B2C4D299ABB99DAEBD96A7B496A7B3BACED5A2B5BEADC0C9BDCCD59FAEB493A0A68D9B9F
909FA48E9EA583979E83979D879AA06F838864797D6B83865F787A738C8E7B9093798E91
738A8D6F898C6D86876E8786708787708689677F816A8081677B7B637675627272647775
596E6B606D64336C20
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0046AA0B
754B1E6C4B2F6F4E3973524078574876564B7454516D4E4E694A4B68494B65484B65484E
684C545D434D644A566C4E5C7D5A6987617187626F8C67728C6A7291727993737E9A7A86
977A868B727E836D798E7985836B769D818CA286919F8D9A797B9E051C67011E8401228D
042A80748CB7AEB2BDD9D6D9D4D0D5BEB8C0C9C3CBDCDAE0DADBE0D5D5DAD9D9E0D8D9E1
E0E3ECE5EAF4D8E1EBDAE2ECE7EDF6EDF2FAEBF3FAD3E5F7749ABD8BB2D3D6EFFFE7FEFF
E3FFFFCFF5FFA8DAF4B7E8FE95D4ED80CDEBA7DBF2D6EDFADFECF4E0EAF2DFE6F0DDE6F1
DBE3EED9E5EDD7E4ECD9E5ECD5E2E9D7E6EDD6E5ECD4E3EAD3E2EAD4E2EAD1E0E8D0E2EA
D0E1E9CFE1E7CEE0E7CDDEE8CCDCE8CCDCE5D0DEE9CFDDE6CCDDE6CFDEE7D2E0E9D3E2EC
B2C4D78BA6C7486FA4406CA48EB0D5BFD8ECBFD9F08EAECBC0DAF0B7CBDD94A7BA95A8B7
9EAEBB99A8B5B8C9D4BFCED998A9B3C2D4DDB1C4D08C9FAB95A7B292A2AA99A8AE9AAAB0
8F9FA682939B85999F7F939A879AA175888F687D81647C7E5973746B8387798E917A8D91
768B8F718A8D6F878969818270888A738B8E6E8487677B7C68797A657676617474667B79
5D72705B6B6346402F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB111
764B1C6E4C316D4D3971503F70534372564A72544E6D504F6A4D4F694B4D684B4E65484E
674A52654A5360444E7254607F5E6B83606E84606F8A65738C6A7491717A94737D957580
9577828E75817F6A767C6A7478646E937D87A58E989E8EA15B629006227801248F022793
0C35889FB7DDBDB9C3CDC0C6CBC0C6CEC8CDD6CFD5E5E0E7DDE0E4D7DCE1D2D4DCD7D9E4
DBDFEAD9DFE9D7DEE6E0E7EFE6ECF5ECF4FCE1EBF4D1E0EFCBE0F4E6FBFFF1FFFFE5F9FF
A8D7F54F9BD2368ECE93D2EFCBF6FDC4F0FCBDE4F9CEE4F4D8E5EED7E4EDD8E4EED5E2EC
D6E3EDD6E3EBD4E2EAD5E3E9D3E4E8D3E4E8D6E5ECD5E3EBD3E1E8D3E1E8D1DFE7D1E2E9
CFE0E8CEE0E7CEE0E8CDDFE7CDDFE8CBDDE7D0DEE7CFDDE6CCDDE7CDDEE8D0DFE8D3E0EA
CDDDEAACC1D4B8D4F0AED4FA86AEDBB2D5F689AACD2E59839EBEDC97AEC39EAFC29EB0BE
CCDBE6B9C9D3BBCDD8CADBE8A5B5C2A7B8C2A6B7C491A2AF8F9FAB92A3AB8799A099ABB2
86959E7C8C947A8B92768A907A8D9671858C677D83647D805D767963797E72858B778B8F
778B90738A8E6D83886C848771878B768A916D80866C7F836A7D7F667978637876637C79
5D73715A6A634C493A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B714
774A196D4A306D4C3971524073584874594D70544A6B504B664C4C64494A66494C684B50
664B526B505871535B77596180616983616B835F6D8864728E6B778F6E78906F7896757F
9776819478846F58656D586486707A826B75A48F98A498AB4C578B072885012796012997
0E3A8DA3BDE2C1BDC7D2C3C8D6CDD0DFDDE0DEDCE1DDDCE1D1D4D9CCD3D7D8DCE3DFE0E9
DDE1EADEE2EAE7EBF0ECF1F7DEE5EECCD6DFD7E0E9DBE3EDE9F2FAEDFDFFD2EDFFBEE1FD
6FAADC2A7EC42781C6A1DCF6D4F6FFB6D9EB82ACCDCCE5F6D6E3EDD4E1E9D5E2EBD4E1E9
D3E1EAD5E2E9D3E0E8D1E0E5D0E1E8D0E2E7D3E2E9D5E2EBD3E1E9D3E2E9D1E0E7CFE0E7
CFE0E8D0E1E8CEDFE7CFE0E7CDDEE6CEE1E8D0DFE8CFDFE7CFE0EACFE0EACDDEE8D2E0EB
D2E2EEB7CCDCB6D3EE5E8CC31C529C7AABDE8CB2D848729B9BBDD9BED7E8BCCFDFA8BECC
CADCEAC5D7E7A9BECFB7CCDCA4B6C39DAFBAABBBC89CADBAA3B4BFB9CCD38B9EA59CAEB5
8E9EA686949D7C8B9383969C7B8E956D8188667E83657E8261797D617679687D806D8287
758A8F6D85896A82866F878B71868B788B9172858B6E8184788C8D667C7A647A78657E7B
5F73745868624C4A3B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A4A16704B306E4C3872533E74584876584C75574C6E524B654B48654B4B674D4E664D50
715B5E8B7579755A617D5D6583636C85636D86606E8864708F6F7991717993727C957680
9879839476817E636D8E6F79A2808A8F727CA08A92ADA3B545548C072B8F022B9F012D9D
0530878DA6CFBCBEC9CDC6CCD8D2D8DEDEE2DADCE1D4D6DBD6D8DCDDE0E4DFE3E7E0E3E7
E3E6EDE4E8EDEBF0F5E9F0F8D8E0E9D7E0E9EAF2FAEEF5FDE4F0FAB2D0EE4B7EB97AB0E1
A3D8F974B0E177B4E7AADBFDBBE4FF76A8D25B93BEC7E5F8D4E3EED8E3EAD5E2EAD4E3EA
D5E2EBD3E2E9D3E2E9D2E1E8D2E1E9D1E2E9D4E3EAD4E1E9D2E1EAD2E2EACFE1E9CEE0E9
CEE1E9CEE2E8CEE1E9CCE1E8CCE1EACCE1EACDDFECCCE0ECCBE0ECCAE1ECC9DFEFC9E1F0
C9E1F3ADCEE793C0E92965B3094CAF5793D7AAD4F7A9D1EFA5CAE5BFE0F8C5E2F9A0BFD9
B3D0EDA7C3E28FADCB9DBBD4A8C3D797B0C3B9CFE2AFC5D69EB4C5AFC8D5899FAB8A9FAA
8FA1AD8EA0A9899BA3889DA17D949871888C667E826B83866B80826981815D7776657E7F
738B8F6F87896F848A71868B72878D758A8D778C91758B8E7287896D817F647A77687E7C
5D71725C6B674C4B3C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
824E15754F2F724F3A72533F75574974564A75564A6F52486B514C684F4E684F525D4A4B
978C8CC0B6BA76636B7C5C68805F6A85646F8A66728C68748F6B75926E7892727B977783
97778393737E8F6E77AA8089B38791B18D97A9919AB3ABBE3A4986062A910431A90434AB
0432927E9CCDC9D1E0D5D4DCCFCCD6D4D4DCCED0D9D1D5DDDCDFE5E1E5E9E0E4E9E7EAF1
E1E8F0DBE5EDD5E0EAD2DDE9D4DFEBD9E3EDD8E2EFD0DEEFD1E2F89EBEE53368A56FA6D9
A9D5F4AED9FA90C0ED2565AF3C7FC87AB4E56C9AC0CBE4F5D4E2ECD3E0E8D3E1E9D3E1EA
D3E0E9D5E2EAD5E2EBD5E2EAD4E2EAD3E1E9D3E1E9D0E0EACADDEACBE0ECCBE2F1C8E4F1
C4E2F3C2E3F4C0E2F3BFE3F7BFE3F9BEE3FABBDFFBB3DDFBAEDAFCA7D6FCA5D4FF9CD0FB
96CDFA79B5EE4E94DC2C7BDD0754C64C96E675B3EC71ACE8649FE268A3E369A3E4457EC4
5187CC5588CB598BCC78A9E38AB7ED6691C68EB5E78CB2DF7096C2769CC181A4C57F9DBC
85A1BD7F9CB3819DAF829EAB809BA7718C95647C84687E836E85886F8A8A6F88896F8789
728A8C758A8D6F83896E868A71858C6C7F85768B90778C8F778A8C728686677E7D677D7D
596D6D5A6965545345
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8B5418754F2B73533C74554473544873544A7354487153486F514B694E4E6850525D4B4E
A0989DBCB7BF7967737B5C697E5E6982626C8664718C68748F6A7493717B94747F987985
987A859E7F8893707AB88B97C695A2B18D98A7929CAEA6BE314281032890012EA60334B0
03359C6789C1C6D1E4DEDDE6CFCCD5D1D1D7D6DADFDBE1E7DCE0E7E0E4ECDADFE7D2D9E2
CCD7E1D4E2EBD5E2EED0DCE8C9D6E0CFDCE5CCDEEF7791AE9FBAD8BDD8F39CBCE284ACD9
90BDE6ADDDFF6296CC0D51A7175CB09DD0F8C1DEF5D1E3ECD6E2EBD6E2EAD8E3EBD9E3EC
D9E2EBD7E2E9D6E4ECD3E4EBD2E5EFCDE5F2C9E6F6C1E5F8BCE5F9B4E5FBA9DEFE9CD8FE
8DD0FB7BC3F473BEF45FAEF056A9F04697E8408EE93586E42D7CDE2572D61D69D11865CF
1561CF115ACD0F54CF0E4FCF0B4ACC0C4AC5124ABE1249BB1044B91348BC1145B91041B5
0E3CB0113EAF0E3CAC0E3CAB0E3AA70B369E0E3A9F103B9C0C3795113E951643951D4695
29539F325DA13D67A34E74A85B81AC567C9F5C7C9864819668869461808A6B89906D888D
738B91758B9071858C728A8E71868B63787D73898D6D8589778C90768C906F84886A7F81
667B7B5F6E6B525047
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
40A60B754D2976533F74534373554972534875544A72514971514D6D514F654D4C5C4A4B
83787FAA9DA8735B6A7D5D697F5E6A8562718965738B677493707B95727E9473809C7C89
A3838FA8869197727FB9909EB7919E957A86AD9EA8AEAFC6283F80062E96012CA40332AD
083CA1799ED4BEC9DDD0CED8D0CFD5D0D2D7D0D4DBD9DDE5D1D5E0C6C9D7D2D7E2DBE1EB
D5DCE7BECAD5C4D1DFC5D1DDBFCBD4CCD9E4CFDEEF93ABC58AA5C0A2BAD1B2CCEC305A96
114B94437DBA94C7F34D84B865A2DCA7DFFFC1E5FDCDE4F0D1E5EED4E6EDD8E7EEDCE8EE
E0EAF1E3EFF5DEF0F6D2F2F9BEECFDA4E2FF86D4FA66C4F552BBF73DB1F42DA7F12098EE
148BEA127FE71B7EEA176DE11A69E21A60DE1E58D92457D4254EC92546C02B46C22D43BF
3446C03944BB3D3CB44037AE4436AC4635A4462F9C4F38A4462E9C49309C4F339F4A2E97
4327934128913D28913927903827943627913328912C278D26268C22268D1F29901A2990
14278E11288D1029900B278908268207287A0D2C76193A7B274C81395E89567A9C6486A0
7291A3728E9B718A93718B90748A8E697F836D85886C86876D8388788D90788D90718A8C
7286896C7A7B545049
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
45A90D764C2673543C74574472554775564A75544874544971514C6F534F664E4A634E4D
6750557258637658657D5D68805F6A8663708964728A677493727D9A78859C7B88A2828E
A98894B08B97AF8A95A4828D9D838CAB99A1BCB1BABABED5314B8A052D96022EA90234B1
0A40AC527ABBB8C5DEBFBFCAD6D7DFD4D8DFC2C5CFC7CAD5C7CCD7C3C9D5CED4DFDDE3EF
CDD4E0AFBAC6AFBDC8D0DDE6C6D0DBAEBAC8BACADAA0B2C79BB4CC9FBDD2C4E0FC436BA0
245A9B477BB0AAD3F3BEE7FE72BCE63598D471C5EFB0E9FEB8E8FBC0ECFCD2F2FDE1FDFF
E3FFFFD5FAFFB4ECFE7ECEF458C0F52EABEF1BA3F00F9CF20C98F80691F50790F90383F4
107FF4286EE55164DA6559CC6F54C4774BB78544AB923D9F9833919C2C86A02A82A02379
A11E72A41E6CA71D67A81A5EAA1A5BAA1856AA1551AB1652A81652A61951A51452A1124B
9F104998114995104A900D49900D4A8F0E498C0F4D8511508212587F175F7816666F1A69
651D6C561E71481F793A1C7D30207F231C791817731217730E1A73091D720723710F2F75
244983416792597A9A67889D6D8A976C868E698288697F84677C80687E81688082718A8E
84989E7D898D524947
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
49AD0C764A1D73543872574173574475564676554770534771534C6E5250634C4B624B4C
684D5275575F7556627D5C6985616D8A616F8D6472946F7D9B78859F7A86A3808CA3838E
A88A92AE8F9AB0909AB99FA7BEACB2CBBDC5C0B6C1B8BAD2425997072E95032FA9012FAD
0333A52D569EACBFDAB9BDC9D5D6E0CFD2DCB5B9C3B2B9C1D5DCE5D8DFE9BFC6D1B5BDC9
B6BEC9BAC5CDAFBDC4D1DFE7CAD7E0A1B1BC9DAEBAC2D5E596B4D0507697C2DDF6BBD3EC
BCDAEBD2F4FFC5EDFDA9E6FF4EB5ED2DB4F335B9F841BAF552BFF669CDF785DCFD78CDF2
59BBF134A4E51F9AE61297E90C96EE0496F00292F2008AF1018BF60089F50086F7067FF5
2A6CE68350BFBD368CD33074D92C68DC2B5EDD2652DC2047E02045DE1B3DDB173AD81539
D20D33D20F2FD00E2BCC132AC61A31BD1B30BB152EBB0F28B81A31BE3148AD1733B10F28
AD1329A9192EA50E28AA0520AF031EAE051CA8071DA2102899132F961333971235931135
9211368C0F37880C3D860C437E0D4675114A6810505A11574A115F3817651F126616166B
0D1A6D081E6E0926701A3D7A345786547392607B8F5F788162797D64797A64797D667E83
8A9CA381888C3E7432
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28D90878491876523774544076564577554777564B74544B71544E6E5350674E4D674D4F
6B4F536F515773535D805D6A855F6D8B6270966C7A9A75829E7B889F7C89A58391A68792
A68A95AC909EAB919FB8A3AEC8B6C0CDBBC5C2B3BFB4AEC64C5D9906278D02279F0126A2
062FA12A529CC4DAF6C4C7D3B7B5C2B0B0BCC3C7CDB3B8BDCED3D9D5D9E3B4B8C4A3AAB3
D0D9DED6DEE4ADB5C0ACB7C3ABBAC6A6BAC6AFC7D3C7E1F2B5D7F09CC5DAD6F9FFCBF0FE
A1DBF37BC6F052ACEE32A3EF28ABF91CA8F60F9CF60D99F30A96E919A7EB2BAFEE24A1E6
1593DE1A96E21B93E21E99E61C9FEC19AAF418AEFA12A9F80DA4F80BA1FB0C9FFE1995FD
5978EABE449DEE2A5AF5233FF41D37F21A2FF01B2CE21320E51523E11220DC0E20D30A1D
CE071DCC071ACA0819BB121EE4737AEE9FA3CD6C789A1C2FCC6473FFC1CAB65D71911D33
E18995EFABB4AB4357A00921AD0416AC05119B0C16DD7F86CF8F99C0838FB97986B06977
A758689D435594273E930D2899042095031D9304218C0727880C327B0C3768093E5F114D
4811553216611F1565101667091A680B246723427641637F5573815F7B7E61797A5E7579
7D8D92787A7B2BA320
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007B4B197451347958447655427755437B5A4C7757507255516F545069504D684F51
6C52567053597958607F5B67885F6D8E6671956F7A9D7B86997B859F818DA28593A48994
A88E99AA929FAF99A6B69FACC2A7B5C3A5B3C3A4B2B8A2BC505491072282032293011F93
0324921C3F8AAAC0DFACB2BEAFAFB7BABBC2D8DCE1C2C9CDAFB3BBB2B8C1C4C9D4B1B5BE
D1D8DED5DCE4B9C4D1B4C6D6C0DBF0B8DFFB86BAE3A0D9FE83C1F274BAEE5EACED3895E9
198BE61C98F90B83EE0576E90277E80885EE087FE70A87E60CA1F313A9EF1CA1E551BEE9
81D9EFAAEDFEB3F1FFAAF4FF87E9FF62DAFE3BC2FA20ADF7109CFA078DFA0782F71175EF
4956CDB42E82E31B3FE61424E20E20DF0D1CD70B19D00915D10918CE0818CB0516C60618
C10114C00314C00516A90B1CE28C98F2CDD3ECC6D085394FAA6176F6D2DDAF798F833750
EFC5D2E8CCD8AD5F79960A26A70215A503108C0D1CE3A8B2DCC8D3DAC9D9E0CADAE0C8D6
E0C7D7DFC5D0E0B4C09033489509209802139304119219238C1F2D7E0E217C0A217E0A26
7B0C2F710B37660D434E0F4D32125916105A0A135C061F5B21436B4D6F845A7680577076
6F81836D6F6D239A15
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007D4E1875533578584376554375564378594A7C5C557658567255536C51516E5456
74585C795C617B5C637F5E688A6573906B7794707B997982997D889A828DA18895A38A98
A68E9BAA92A0AD93A1B394A3BB95A6CAA0AFCCA0AEC39EB94D47820B1F7C021B84021B87
011D8513307894A7C4A7AEB7BBBFC3B6B7BED2D5DCB4B8C0B2B8BFC3CBD3D2DCE5CFD9E6
BECCDEB5CDE5A9CEF19BCCF978B5F2418DE01974DA1375E40F6DE30C5EDB0963E00473EE
017AF30183F90283F90287F7038DF7099EFA20B6FE37C9FB3BCCFC4FD5FF70DFFF91E8FD
9FE5FD96DCF76DBDED48A6EE218EE81382E81077E9106EE61468E5175FDF1E58D92C4FCB
5F41B1A71B68D51136D90C1FD40917D10918C50211C20312C50516C50516C40415C40616
C30415BE0212BD0314B6071BBE4055E3A9B6EDD4DFA7778C935771F2D2E2BA91A582445F
EBCCDBD7B8CB9035589E0928A80115A30211860919D298A6D1BCCE826181935F859B678A
A6799AAD93AAD9C5D495576C860A259003157E0611CE878BD1A6AB7E4F56A86D778B4651
8731447E152C8507258308277309305B0E3F37104C1311520418580D2B5C395977516E7A
5F75785C5F5912CC09
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0082521775523174553F7555427859487C5E51795C53795A56785956755755745758
7A5B607E5F667C5D6582626C8565718C6B7891737D927A8299848C9B88919C87939F8796
A68B99A68C9AAB8D9CB390A0B991A2C79AAACB9BACBE97B3473D7708157001127901177E
041E810F2870828FAEBEC2C9DCDEE2B6B5BDB6B8C1C0C9D3C2D1DFB6CCE1BDDAF9A1C5F0
7FAEE8518DDA2B74D31568D40B63D80461E10262E90267EF0060EB0865EE0470F00684FC
058EFF038FFC0699FF0AA3FF0BA7FF17B3FD22B6FA2BB6F81FAAFA1398F1168BEC1A7FE3
217AE12372DE2165D8235FD62D60DA395CD74951CD5849C16A44B7793FAD82349E933192
AB297EBF1450D20F30D60D1FD70B19D10B16CC0814C70512C80717C60413CA0815C70510
C70512C80614CB0815CB0C1CBE152BC3596CF6CFD9D5B3C386546AF0D1DFC7A4B6864B64
EECEDED1ADC18C2145A50724AD0216A402128A0618C68492D8C2CE876A7F84516C7F465F
743956704860D5BFD199677D830E2C8F03177D0514B98089C3B8BC827F83B6B1B6BDB4B8
CAB2BBA36A7A7A0D228904178A031782041C700A2E3D0D430D105402175B051E5333516D
566D775C605900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF006783157B583172553B70543D785B487A5D4F7C5E547A5C547C5D59795B5A795C5E
7C60657E626782666B81656E8468748B707C90798494808996868D9989939886929D8794
A18996A78E9BAB929FAD8F9CB593A0B6919FBB95A4AE8EA73F376E08156E00117501167D
031A7D11276E8A93B3A5A6B1BEC0CBB3BACCB1C0D9B7D4F895C1F15A91D73070C81359C1
0A54C80453D00356DB0257E0015BE70060ED0165F1036CF70574FA0A82FD0B8EFF0990FF
078EFF0289FC068BFB0286FA068BFB0886F60C77EB0862DA1262DC226CE42A5AD7435BD5
5451CA6246BC7946B5893EA79133999F3092A72986AD287DAC2474A8216FA624729F226F
9E206CAE1D60CC1542D91026E0101DDB0F18D80D17D40915D50A17D30914D40812D50913
D40814D50915D30713D40B18CD0F22B5283AF8BAC6EFD1DC936C7CE9CCD9D4B2C48B536E
EDCEDED0A5BA931F42AE0822B20213AB020F960516C37280E0C6D0D4C7D2D3C5D1D1C0CC
CCBAC7C0B7C1CFC8D5A5768D88133197041B8B0919A2606AC1B8BDAAB5B9AAB5BCAFB8C0
8D8A95AC8B9A6F13298404148C020F8B020F7F0419550C33160D4C04145A011555061D4A
3B5468535B5600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0044AB0D815C3373563A745841795B477D5D4E7F5E527E5E557C5D597D5F5D806164
816367816769826A6D81676D866B748E7581917A8795818D947F8B9A869298838F9F8996
A48D9BA48C9AA58A99A48997A58795AB8C98B493A0B295AD352F6705136D01157B011882
011C831939888DA5D199A8C492ABCE88AEE44E7FCA2763C00F53BF074FC70450CF014ED2
0250D70154DD0155E20158E60562F1066BFA056EFC0673FC0976FC0671F80571F6046CF1
0769F00B69EE1068EB1360E41E5EDE295AD4243BB32A269B4225977437A3923299A62F8C
AE2A82B62C7FAD2876AA2976A9307E9E307E903286873A8E773E966444A15852B34755B8
4155BC634EB1AB2D77E01C3EF11C27EE1A1FEB181DE8141CE6111CE4111AE5111BEA1722
E00F1ADE0F1BDB0C18DA0F1BD50F1FBF1B31E38F9FF2D7E1B097A4E5CBD9DAB7CA95617A
F0CFE1CA94AD9B1C3FB40820B80414B70613AA0A1AAA4052B78294AD8DA0A891A5B09CAF
B5A8BAC7C7D2CEC6D4AD738E890D2D990319930819984C57CBBDC5B6BEC4ADB6C1A9B1BC
AFAEBCB193A3731A3184041788000B88020B8004135D0C301C0F4B04105601115401164B
11274647525200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0048AE10865F367E5D447E5D487F5E4A81614F83635385635883625A836260866667
8568697E6465846D6F887075896F778B747F8F7985967E8D93798A987E8F9A80919C8192
A48A999D82929D8091A18392A88A97B493A0B6909FB495AF35306B061A77041F8A02208F
022493042E904671C23A68B71C57B51456C70445C00344C40145C9014AD30050D90253DC
0659E4055CE9055EEC065FEE065FEF055DEF0259EA055DEA0A59E60D50DB144ED51C46CA
2D42C43C42BD5145BB603BA97D38A0852D8B7313697516667D1A6A9226729C28769C317D
9739868F44918152A06556A45562B24067BF2F6ECD2676D91F7CE01A81E71685ED1588F0
1585F43876E9944CADE12C5CF5202FF11C20EE191EE9161CE7131DE4101CDF0C1ADC0E1A
DA0D19D60915D60917D30B16CF0A1ABE0F24C75E72F5D6E1C5B8C3E0D0DBD4B2C5A4758B
F5D0E5BB77969F1638B00319B50111B50410A70A19CB6A76E2B6C2CAB1BFBDA7B7B39FB0
A294A4C7C2CCCFBACB883C5B960C2B9D01179507189D4D5AD4C2CAC3C5CEADAEBB91909D
AEA5B3946D8078183389051B89010F85010B77010F5A0929230F4807135501125801134E
04163D3C444D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0050B315875B32835E47815E4A815F4B84645286665587655A87655D886965866967
856B6A836C6C86707387707889727D8A73808F77859379899376889C7E8F987989957485
9B79899D7D8C9D7D8CA1818EA98894BB97A3BA90A0BC9BB8403E7C061F8003269501289B
052FA50130A50434A90235B1033EC10141C90145CE0248D0034ED90657E4065CE70659E5
0655E10251DE014FDC064EDD094BD90D45D11340C82240C33337B3472DA065319A74288A
8925808D1F7295237095216B9A25709B317B7A2A784F21763C2D874C53AD455DB5456CBE
5481C97CA2D69AC2DE97CDE48AD8F068D0FB3FBDFF1FACFE0F9FFD0C9BFE098EFB0884FA
0476F81866E96A4ABAC42662E0122CE5121FDD0E19D50914D80B17D50916CD0111CD0613
CA0610CE0812CE0513CE0714CA0617BF0A1EB4384EF5CAD5CFC8D3DBD3DFC4A7BCBA90A7
F3CDE2A55274A51134B10317B30110AF020E9E0A18CE7684DEB7C6D1BECBD2C4D3D3CAD5
D3CAD5D2C8D5E6C5D89B42609E0B29A30216950817994752DBC5CBC2C0C9B5B3C0B9B7C2
C5BFC8AE8D9E7A1C3889051D8A010F83000875020C5E031A380B38120D4909165702124B
021239252D3600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDB0C895B2D836046825F4C83604E8865548C6B5B8A695E8A6A628B6E69866C69
826969826A6C846A73816674856B788E73818A6F7F90738590718391718291707F93707E
9B79879B7E8AA08490A48694AF8E9DB694A5AB8DA5AA9DC23C4A9007298E032CA0022DA7
022DA8002FAD0030B20034B9023BC30646D0054BD60650DA0551DA0450DA044DD80547D3
0842CD0C3EC71237BD1E33B53130AD4A2EA2612A94782583881C72951E68901B5F8E2064
82216579266D682B77583A8E4B4CAA3956B62D68CE1A70D6167EE12598EA47B9F078D9FF
A5F0FFB8F0FFADE6FE7DCBF040A5EE1D95F50886F30281F6027CF60279F6006EF10067F1
015FED0B55DF3834ABA22067D40F31D90B1DD50718CE0411CF0511D20714CE0412CE0915
CC0510CB0410CB0411CC0715C80A17C11523A52939EDBCC8DDD4DFDACDDDBB93ACCA98B0
EDBAD1983959A50F2EB20517B30210AB0410A01D28C275829C7284BDA3B4BAA7B6B6A5B5
B39DB0A6859CBF829E9D2D4EA60A26A704168F0B17C6848BD2C2C9A9A5AFBEBAC8B0AEB9
C8C7D2CAAFC28026458C06208E020F8802087A01066C020E5606223D103B1D1449050F44
05153B1F242E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008A5B28825F4284644E8665528A6956906F5E8F70638F726891766F8C746F
846C6B80656A765B657A606D886E7B876F7C8469788A6C7B8465758867788B65778D6879
9776859C808DA38A97A68F9FA390A69D94B17A7CAE40559D0E3293022C9F012DA8032FAF
0232B40234B70237BC0742C70540C7033DC60340C90442CA0741C8093BC21137BB1B31B1
2A27A344269A5F248D731D7B85196D8A17618A195C871E5F7C2167702E78512D7F34338C
2846A42355B52067CB1872DB1684EA1591F21198FC13A2FF0E99FA1598F61999F6168EF0
1B89EB187DE41478E50E73E8046AEA016AF00168F20169F30060EB0063ED005FEA005EE8
015BE70553DC2E46C08D257BD0133CDA0B1DD90915D90B16D90916DC0C18D90915D60914
D50712D30612D50A17CF0C18C7222AD2565EB76872DDC0C6DFD8E0B8A5B5AC8196B48298
C08BA1C0708AAD2D48B0081CB40210AB0513B84350F6C6CFD8C9D3CEC8D4D1CBD8D4CEDB
D7CEDBC4B4C4D6A6BC9D3350A30822A40513911621D2A0A6D3CAD2C6C5D1C2C1CFC0C4D0
CCCEDAD0B3C987264995062395000E8F010885020772020D550318410728340F36151039
0B163627262D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008D5C2585604086634C8D69558F6C5795725E987A6891776A988177927D78
87727180696B7C626A7C626D7E646F7B616C7F64708062708363728766758F6B788E6B79
9174839A83959588A08D8BAE616DA228428C103592052D9B0430A90130AF0231B20237BB
053CC20234BC0232B70136BA073BBF0737BA0F3ABA1836B4222AA4382295531E87711E7A
84186A8C135E8C12578616587C1B60651D684C287934358D2644A8194EBB125BCD1773E6
0E7BED138CF81495FF078AF71399FD0787F90381FB017BF80275F6016BEE0068EE026DF5
0166EF0166F10164EE0169F10166F10062EC0061ED0064EF0067EE016CF1016FF3006FF1
0476F8036BED235FDB80399DD62155E91627E9131AEB161CE91219EC151AEB151AE40F16
E51019E40F1AE4111DD81620DC525AFDC6CCEDD1D8E0D5DFDCD6E3DFD5E5E3D2E3E2D2E1
E1CFDEF3CCDFBA5772B2102ABC0517B60719BA3249EAA8B9E1CEDBBDB8C7B6ADBEB5ABBB
BDB9C7D1CDDBE4C0D69A3452A60C26A4081892262FD2AAAECAC2CBA29EACBAB4C4BEBFCB
D1CBDCBD8AA8951E44A408239F010F9701088B01097004133C04231C03262A0B2D281633
19192C1F5A1C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00966326875E3E87614E906854916952947059987B6798817296807496807B
877270806A6E7D666E7961697258627359647A5F6B7F626F8564728968768E6E7C8E7383
8A79907A779B4D58901C3685092D8F042D9C032CA1002BA50436B50438BA0438BC063BC2
0438BE022CB00428A70B2BA414289E1F1F90381D85632583801F728E165E941255901351
8015546C1B615221713827812231941740AA1350C00D5DD11070E90C73F20B78F90A79FB
0370F50472F40577F70575F7016CF10069F20168F40063EF0469F5005FEB0061EE0066F2
0067F1026BF2026DF00577F40376F20677F1077EF30883F30788F2068CF4058EF6038EF6
038DF8058DF81C83EF785EC4D7346EF72739FA2328FC2324FB2125F91F22F41A1FF11820
EB121CEE1621EB1521DF1822DB4453FEAEC2F1B2CAE6ABC8E1A7C7E3A8C6E3A8C8DEA7C5
E1A8C7ECA4C5BF4568B70D2BBE0417BD0519B30B26B23B57F1BACFE0C9DDDCCCDFD9CDDF
D7CCDFD8C0D7A961839B1A3CA6071F9C0817AC565EDAC5CBC9CBD2C0C3CDA8A7B5C6C5D2
D7C1D79E4D729F1136A9071DA704119F020A91020D71071D2F08310C0A3D0C09331C122F
271B2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0043AA0E855B368B684F906E56936F558E6C559F8573A994869D8A80917C77
89727182696B775E636E575D765D657258627B606A82666F846772866C7C85728B726A8D
495083152973072584062B980129A00129A3032BA6012AA8022DAD0331B30534B60632B2
0C2EA80D1D921C168335167756166E751564830E51901350911754851E606C2571462376
2E2C861B34991340AE0A47BD0F5ED6106AE60863E70765EA0565E9096CF30162EC005CEA
015DEC005BE60060E90060EA015FEC005EEE0061EF0169F20069F1026FF60374F6057CF4
0981F00F86EC198DEB2294EA2D9DEC38A9F23DB2F443C1F33CC3F533C5F62AC2F928C4FE
1FBDFF12B0FF1B9FFD6682E5C04089F12A46FA222CF91E24F0181EEE151DEA121DE7111E
E20E1DE3101DE20F1FD80C1DD2152FCC254AC82956C22556BE2054BC1F51B81E4FB62050
B41E4EB51A49B61036B80620B90417B80316B5041CAE102EB1375DB04F7AB4628CBD759B
CA85ABB86088981840A60827A60215970614C66F7CDDBDCAC4BAC9CFC9D6C4C0CFC4BECC
B690AA952E53A50C29AD0817AC0610A3030C9203106E0B28270A3F07104E0310460C1136
2C1E2B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004CB112895D308C6B4B9273579E7F659C816BAB9787AD9B92A8989090807C
8975747E6566755B5E795E657457637458647D646E7E67727C6D7C6F6987464A7B142166
031B7003228601259402299F0128A10328A20125A00227A20427A50927A611269E181786
2F11744E1266690D567C0C4A830E467E0E4871135257155F43267E2C339A2043B60F41B8
0A45C1074ACA0851D40553D80455D90559DF0151DE0152DD0256DF0051DA0155DF0054E3
0054E30059E6005FEA0167EE0069F1006DF50174F70384FB0488F8088DF41295F129A4EE
54BDF180D6F1A2E6FAC0F5FFC8FCFFC2FFFFA7F7FF7FE7FC62DDFA32C0F61BB4FA0EA7FB
059CFC0393FB0682F6326FE58A41A1D1275CE51B35E41628E11427DE1328D40E26D2112D
CD102BC8112BC51030C00F31B90E35BB153FB61243B11245AD0F45AB1045A70E44A61043
A30F41A10E3F9F0C379D0B309C082B9F0729A1092B990729950831950B39970E3F971041
9A14429D0E37A4072BA6021CA401159C0317981B36C46F8AAE6D8DB582A1CFAEC7DEC6DA
DFADC7932645A80D26AD0613AD050EA2040C8D0313640F361D0E4F06155D021456061243
251D2E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADB0A895B288E6A47937558A489709E8773A39083A1928AABA09B9C8F8D
8C78787B6263785D5F7D61667B6069785E697765747069804D5278172562031566021A77
021F8402238E01249703269D01259D0121980521990D2297151A8B2D19824D1571711663
7D0B47850C407E0D41680C46511558361C6B2224801128921237AE0639B90D53DA0651DB
0247D30247D2024AD40149D30048D3024BD70048D5004BD9004ED90256E20057E30059E5
005FEA016AF20271F4037EFA0284FB008BFA0397FC0BA7FD1DB6FB3DC9F96BE3FE98F7FF
B4FAFFB7F5FFABEBFD9EE3F883D5F459BEF22DA2ED1497EB0F97F20690F5048FFB0289FC
017FFA0179F90272F81067ED434FC885328DAC2365B11D54AB1F53A522589E225E922062
8E256C81266F822D7D772C7E6A267A6C2D83642B84612B895927875325834F25814B247D
4B227C4A20784F21774A1C6C4D196B4E16644F146053155A5610535F0F516910516F0F4D
770E497F0D428409398C0A328D07288F0625910828900E319011388F163D9B3459C26A8F
B14C70A01737AB0A20AD0612AA040CA0040E87051B520E3C15135B04146403176304154D
1D1F3300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF008A5C228F6B45907355A28A72A692809E8E83A99F99BCB4B2A19494
8771727F65657C63637F686B7D6A72726275585475222A5F06145E02156B021978011B82
02208C011E8F011D91031E94061E930B188A19147E3713715E1164841359900D4689093B
74093B590D4938125D201C75101F870E2E9D0832A70837B30332B50031B80B52DA0552DD
0145D20244D10145D00146D10046D20149D7014CDA0154E3015CE90164F0026DF60272F8
027BFB0484FD058BFC0698FC09A6FF09AAFF0DAEFF12B3FD1DB6FA20B4F62AB5F82DB0F6
2AA2EE2399EA1A92EC168FEC118CF00987F20587F90384FB0180FB017AF9027BFC0174F9
016FF8026AF60366F30360EE115AE42C53CE4249B94848B13E42AA3843AD2C3DAB253DAF
233DB21F3DB41D3EB81A3FB9173DB8163CB8153CBA123ABA133ABD123AB91036B51039B4
1135B10F31AC0E2DA50F2BA10F289C11289812269410218C132088131C81171B811C1D82
221D7E291D782D197233166640155D4C10515A0E47670C4172093A7D0934880D368F1136
9C0F31A50A22AA0619AD0612A8030E98020F800A244714480F156102176A051D6E021757
171D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF009565258F6A419174569A846B9C897C9D8F89BAB4B3BEB8BA948687
846E6E856E6C836F6E7A6C746E697D3C3F690A155402105F01136E021778031B7F001981
001A85031C890518870D16821E12763C0F67620E57820E4A8D0B3F8A0E426F094448094D
250C5D1214730D1F8A062899042FA70732B00126A50029AA0A41C5033CC5074BD6044BD8
003DC9003EC80044CF014BD50254E0015AE8015FEC026AF20575FA0278FB0482FD0688FF
0890FF0794FF0796FE089DFF059BFD0294FC008FFA0494FC0592FA028BF70389F80489F9
0586F90383F9047EFB0279FA0176FA0178FB0277FC0072F90271FB026DF8016BF60169F6
0166F40161EF015AE80159E60258E30756DC0A51D40A4FD0084ACC084ACE0647CA0547CA
0443C80240C40342C60648CB0343C60341C30645C90441C70340C50340C2023DC0023CBD
0137B90235B50131B0022EAA022DA5032DA3022BA001279A04279A01249604269905269A
05249506249508249309218C0C1F85101B7F141A781A177126166832105B470E505F0E46
770D388D0F2E9C0B23A208199F0312920413740B2936134B081562021C70042173021B5F
141F3D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB0128E6437927052957A668773689B8B88B3AAAAAAA1A08F7F7C
8B77718A79768A8189636580202B5E03145801156501146C03167701157A01167B02157A
041475080F6B170A623A0C5B660E537F0C43830B3C760B426013543A105F1D0E6910187C
08208C04239604269D0228A1022AA7032EB00732B40131B5033EC50042CE054ED9034CD8
0044CF014AD40154DF0462EC0469F3026DF80371FA077DFE0683FF0685FF0584FD0380FC
017CFB017AFA027FFC0182FC0280FC007BFA017DFC017CFB017CFC017BFB0176FA0176FA
0276FB0173FB016DF90168F80269F9016AF7046CF90066F30163F00163EE0062ED0163ED
0260EA015AE30157DF0056DC0259DC0255D70354D40252D0034ECE054DCD064BC80447C3
0647C00747BD0645BA0745B80743B30741B00A42B0083FAA0B46B00B46AD0B45AC0B44A9
083EA3093D9F083A9B07369409359207328F07308F072E8D062E8D072D8C052D8E042B8E
032A8F032A9304299202258D01218B02218B021F8B041F890620870A1D800F1C78171A70
2818673C16575C10477A113A890C2A810720650B31280F4D061564021E72032477031F63
181F3F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0C956533916C4C9276608A7467A4938E9B8F8EBBB2B0928682
8F827E8D888E5F6686152763041B6C02187301167301147203167501147404147208106A
160D5C2703424C063A6D0B38750936690B3F470C5127116617197D0A1A85061F8F052296
05249A02209A011E9901209A00209D0127A60231B30039C00347D00251DA075FE90159E4
0259E4045FEA0369F40574FC0678FE0677FE0473FD0275FD0276FB0478FD0174FB0272FB
0270FC016FFB026FFB016CF7016EFA0272FA0375FC0374FC016EF80070F90170FA006EF7
026CF80166F70161F30261F2015FF0005CEA015EEB0261EB0362EA0262E70462E60360E3
055CDC065BD7085BD4085CCE0C5AC80C56C01058BC1357B71454B31A52AD1F54A82358A5
2858A22E5BA1315FA136639E4169A04368994C6A98516F9B4F719C4F709B4D6E9B4D6F98
496B934B6B9248688D46668A47658C43648845638A3F5D843957803656802F5380264B7D
254A801C427D193C7D13337A0C2C7907297906267D03257F042381021F7F021E83042085
0720850D2081161A752A196745165556124449124816105303176802227803287B06276C
1E234100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00758E249069438B6E558F7666917C748E807CC5BCB99F9997
9998A05A64830B205D052074031F7E021B8001177C021476010E6C070F651209562D0A4C
47083B58082B5C09294F07323506431F1061121C7F08239106269C03249B012198011E94
001B93001A94001C9600219B0126A3012DAB0339BC0243C9034ED70258E20766F10769F5
0464F00567F3036BF70471FC026EFB0168F70267F80166F70269F90269F80167F70165F6
0062F40162F40161F20060F10062F10267F20165F20369F40265F20063F00165F20265EF
0062EF0265F10462ED015DE50560E6055EE20860E00962DD0A61D60C60CD105FC71762C2
1E60BB2764B53269B23E6EAC4C73AA587DAA5C7DA45F7FA36582A26D85A26D849E70899D
73899C75899C748B9C748C99778C977C8D97808D967E8D977C8C967D8E987C8D977B8E97
788B957588906B7E87667A826578826A80886C7F886A7C8664768060757D60778159747E
5B75805F79855A7281556B804C637E435D7C3952782C487327437527437E113075062776
04257C02237E0323810826840E237F162176141E70071E7403227D032883042D81092A6B
24264000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002ADC0D94693987694A8E72618A706692817AABA4A1BDBDC9
535F841022600F1C6A0D1A75051B7C041D8302187D0816730E0D5B1F05464107395D0B2F
5A0826430424250231160B500B136C051983032295032AA30128A30126A001259F01249D
02249E0228A5032BAC012DAD0130AF0136B60343C6034CD30758E20459E6045DEB035CEB
015AE8015FED0465F50162F4005EF1015DEF035DED015BEC015BEE025FF00263F40261EF
015EED015CEB015CEA015CEA025EEB015CE6015DE7015EE70260E80160E80464E70766E3
0864DF0963DA0E62D4105ECA1860C42265BF2867B93871B84B79B8547FB06186AE6A8BAC
728FAC7892A77E96A48599A384959F87979F8C99A18B9BA18D9CA28A989D849295899A9B
91A1A390A0A38FA0A58A9B9F8B9B9E86959595A0A2929FA192A0A38E9C9F88979B93A2A5
929FA38E9D9D879496829193808F93899A9B8D9B9D8895988390927B8A8C7C8E90778B8B
768B897E94917F93928294977D909576899072858D6579825C6F7C5A6F8050667E3F5979
2D4A741D3D70113475082F7D082F89072F8F062E91032B8F022A8F012889042C820D2A67
2E263900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00AC814986654289695489706194847AA7A5AD6A779E
142464281B644A1B624316641A106D0A177B0B12731D0B5C39063E52072D5A08274A0528
28012C0E023C080C5A031672021E8503239502279E0127A30128A4032BA7032BAA022BAB
022DAE0230B40135BC0741C70541C4013FC20546CB0248CE0146D0034CD8014CDB024FDD
004FDC0155E20157E70157E80156E7035AE7035CE70157E4035CE9035CE9025BE80159E4
0158E30156E10158E30158E2025BE20560E10661DE055DD50D63D41165D11764C5236ABD
3170BA4379BA5A84BC698BB77590B47B93AE8197AD869BAC8999A88A9BA58D9FA48E9FA3
8F9FA49AA9AB99A7A897A5A49DACAC96A3A49EAAAB97A1A39BA6A99BA7A798A2A2929E9D
9CA8AA9AA7A9A0ADB099A6A898A4A69CA7A8A1AAAC9CA6A8A0A9ABA1AAACA1AAACA4ADAE
A1A9AAA9B2AEA8AEAEA6ADB0A3ACAEA6B0B0A5AFB19DA4A89CA3A59BA4A695A1A297A2A3
8894958D9C9B8A999A93A3A391A1A193A2A394A3A5879798879697879697819294778B90
687D86576F7A4B6376415D7D2343750C3579073489043291022D93022C8C052D7C172A5B
16901A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009DB84C966F4984614B8F7466998C8C6B7390202F6B
2E1C616A17508F0E39870F3E500F54270E61330A56590D44650A2F520628320330190742
06064D020B5E031775021F8600239001299A012AA10129A30128A4012AA9012CAF0233B6
063CC0033BC10139C3013EC60647CA013EC1013ABE013CC0013EC30141C90245CD0246D0
024CD60151DB0354E00455E40256E40153E10154DF0155DD0155DE0154DD0156DD0257DA
0458D80455D30759D40C5DD20F5DCA155FBF2367BA336FB54D7EB6618AB67697B8829CB4
8FA4B696A8B894A4B297A5AEA0ACAEA2AEAFA2ABADA2ABAEA5ACAFA3ADACACB8B5B2C0BB
B4BEC0B2BCBDABB5B6A7B2B0A3ADABA5ADACA8AEADACB2B3B4B8B6BDC2BCBCBFBBC5C9C5
C4CAC9CDD0D1CCCFD2CFD4D7D1D3D6D3D2D4D3D1D4D1D0D2D0CED1D1CFD1D2CDD0CBC8C9
CBC8C8C6C5C3C6C3C4C7C5C8C0BEC1BFC0C2C0BFC3BEBCC0C2BFC2C3C0C3BABBBCBBBABC
B9B9BBB0B5B5ABB1B3B0B7B6AAB1B0A8B0AEA3AAAA9CA4A4959F9F95A0A0949FA08D9D9C
7E9091788D8C718385687C815A727E415D75284A74123C7A073182053285082B6F202748
0CC70A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0035E617B38251856044927A6E80798722295A2E1E5D
6F1E519A0E2DA90617A5091E840731690A41690A3B66093048072F23063D0D0A53071166
02136E021676021D8301228E01279802299F0028A1012DA40130AA0333B30336B90339BB
0138BC043BC1023AC1013AC00240C20341C20338BB0236B80137B7013ABC013CBF003EC3
0248CE0555DA0254DB0150D90151DA0252D90355D90255D50355D20656CF0B58CB0E57C0
1B5FBC2664B9356CBA4B78B55F83B27491B27D96AE8AA0B096A7B3A2B2B6A7B4B6A6B3B2
AFB9B8AEB7B7A9B2B5ACB6B7B4BCB8BCC4BEC0C5C3BFC4C4BDC3C2C2C9C7C9D0CED0D4D4
D8DBDDD2D6D7DBDFDFE1E3E3E8E8E9E9E6E8E3E1E2DFDEDEDBD5D7D2CFCFC4C0C0BFBBBC
B4B0B2ABA4AAA199A298909C9489958F828C887A8384777D82757B82737A837178847276
817374786C6C7A6C70786B70776A6C736969776E70766D6C7E74757E7777837B7B867B7C
867C7D8783828D8988938F8D9996969896959F9D9AA4A49FA5A8A4AEB2B09DA4A397A19F
8D999781908C7E8D8B7788876C80806076785B7178435E702545681136640F2A56292636
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0060C52787603B8F79733C3A562B1D54631A4D
980F2FAC0816B40812AC050F9D021687062662072E3706381406420A105B04156C021775
01157501177B011E880224930025990028A0012CA5083AB10336B00232B40135B90136B9
0133B60134BB0238BE0239BE0138BC023ABB0032B30131B10234B30036B5013BBB013FC1
0248CA0048CC014DD10454D50353D00551C90A54C20F56BA1F60B92E68B44978B3668BB5
7792B3859CB790A2BA95A4B39BA7B1A9B3B99DA6ABA3ACAEACB2B4B5BDBDBCC4C1C0C7C4
C6CBC9CBD0CEC4C7CAC5C8CAD6D8D6DEE1DEE7E9E8ECECEEECEFF1EDEEF0EBECF0E3E2E9
D6D4DCC3C2C9B5B2BEA49FAC9891A08E85918376827F727B7C6E75766A7072666B716566
7164646E64636F6362706564726464716261756563766A62776A6073665C75655D77665E
75675F74675B75675D74675D796B6274675C71685C6F66596D64586D6358695F55665D56
645D53635D51625B50635B52645B56645D596B625E756F6A7A7572817D7A817E7B878582
868883868A828489837A837D71807B687975627370596D6C4C636639535B20333C139313
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0034E515976C427765662A2049541E50921837
AA0917B50A13B1040DB1060FA704137B0423360537120F51020C56021366011A73021C79
01187800177C01208B032999022BA1032CA6022FAB0330AD002CAB012EAF0131B20130B3
022FB50134B90338BC0136BA0135B7043BBA0239B70237B60239B7013CB9013DBC0242C1
0447C5084DC4084FBE0B54BA195DB72F69B2517FB67192B98BA4C09FB3C6A7B6C2AAB6BC
B1BBC0ACB5BAABB4B9ABB1B7ADB4B6B5BDBCB3B9B9BDC5C3C8CDCDD2D4D6DADDDDDFE2E3
ECECF0F2F1F3F3F0F5F2EEF6E9E4ECD9D4DFCCC3D2B3ACBC9F97A8908A99827B8B746F7D
6E6A756E6A716C667065616A67666C6D6B6A706B69776D69796D67776E65787066797167
786F64786F62797063786F63766C61756B5F7A6F647A71627A74627A7260766C5A7B6F5F
7A6D61766D5B776F5D796F5E766D5D756C5B776F5D766E5C786F5E746D5C746E5C6F6A5A
6A67576969576B69586D69586B6555696356645E53615A4F6058505D544D60574E625A50
6763596E6B5F75726676756973756D6F766C676F665D696251625B485F573D504427691D
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00809F425947503D1E4879193EAB1222
B70F15AE0D12A8080EB61017AC08177C06252F0A410C1A66031C7103207B022382012282
012084011E87012391032B9E032CA5032AA70228A60127A50127A6012AAA002FAF0231B4
012FB60335BB0235BB0336BB0035B60136B5023AB70239B6033DB6023FB50743B70A46B2
0D45A52657A54774AD6E93BB8EA9C5A1B5C4AEBCC3BDC5C8BCC1C4BEC3C5C4C7C7C4C9C9
C3C8C7C4C9C8C8CDCFCCD1D0CED2D1D4D9D7E0E4E3EDF0F0F2F2F5F1EFF5E7E5EDD3D0DC
C4BDCCACA3B39B8FA38B8195857B8D857A8B867B8A756F7C74707B74727C6D6E75717476
6F73726F7370696F6E626A6B636A6860685F6B6E63737164797265777160757361777563
76705F797260797260797160796E60776E5F7A6E617971607C7562766E5C7A71607C7361
7A705E78705C756D59736D57756D5B74705776705C726C5A756D5D766F5D76705D716D59
6E6A596E6C5C6C6A5C6C69596D6A596C695A6C66576D6859666154665E506A5E4E655D4C
625C4D5E58495E59495F5E4E6462566A6B5E6B6B5E676A5E5963584E6052465747434A38
12CF0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CA9A6F6243515A1F4990142EB8151C
AA1214CD5B5CBF4C50A8141CB10A179709235B14471C1B6906238202258B02278F022791
02299303289501269503299C0127A001239E00219D0227A30129A5032CA9032DAD012DB1
012FB50132B40031B20131B10133B30133B10236AF063BAC0A3FA513479F315EA55E81B5
8AA3C3AFC0D2BCC9D0C5CFCFC7CDCACCD0CCCED2CCD4D7D3D5D9D7CFD4D1D7DCD9DDE1DE
E1E2E3E4E4E8EDEDF1EDEDF1EBEAEEDCDAE1C5C4CFAEACBA9794A2867D8F766D7E6D6876
746F7C827D8797949DA4A5ABA5A8ADA2A6ACA0A4A9888E91737C7E697677687677667473
667473667473636F71646E6F636C6B5E686060675A65695A6F6F62777767767563787461
76705C78725D776F5F766D5E776D5C756E5B766F5B78715D79725F7A6F607C7062776E5E
797060776F5D766F5D756E5B726B566F6B53736E58736E5A756E5E736D5B746D5C77705F
766E61726B5F70695B6F69596C65556D66566F6A5A6D6B5869675768625169604F6B6450
68645165624E58594755594A494A3F4F504659584D6163546166565861514E57494B5040
37712300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065C836743F42721D399B1120B1191A
A12828F5ACB2DA8B99991928AC0B17A907188B113848185E13217E04278F012693002895
022A9801299801279902279E02269F0225A00226A00127A20127A2012AA5032CAA012CAD
0330B00130AE0031AC0234AB0537A708379F16429A30569A627FAF8CA1C1AFBDD2B9C3CD
C3CACDCCD1CFD1D3CED2D5D0DBDDD9DDDEDBD9DAD5E1E2E0E2E4E4EAEBEDEDECF1E2E0E8
D2CFDBC0BAC9AAA5B5928D9E7D7987706B7867636E66646C6C6C71797A7D8E8F92929699
909498878F907C8687717B7B6B7575687171697271626B6A5B6868596967586867586968
56686956696C56696D586A6C5D6B6C5D68645C665E5D655963665C696C61747264787160
77705C76715B756F5C766F5D726B59756F58756E57746E56746E59776E5D776C5C756D5B
7A725F756E5B746D5B756F5C726B586E6852736D57736E597B7565767061767062746E60
726C5E736D5E716B5C706A596F69566E67556E69566E6C596D68576C6553655F4868654D
676653666857565A4C50554A343A323239323F433A4F5242575A476163515F5E50535645
4D493312CE0800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF006BC82A8E472E8720279E171C9B1E1C
BB6767D097A0BC7B88B5505DA4131FAE0612A4081E7E13463619690D2488032896012597
02279801289A01289A02269C0226A002259F0127A10129A20129A20128A00129A3022DA8
032DA6052FA108329A143D952C5195546EA08798B89DA9BBADB5BEBCBFC6C1C4C6CACACC
CDCDCDD1D1D1D5D6D5D8DBD9DDDDE0E1DFE3D9D5DBD0CAD2BBB4C0A79FAD8F86967A7382
6C6573675F6D66606A63616866686C6E74728087857F8885798380737E796C757267706D
65696765696463675F64695E65675E66675D66655C67665A63645A5D62565A5E53575C55
5058554553544053544457594B5D605160605663605C685E60675B64675A6A685C756E5F
746D5B74705B746F5C777060797060776E5B746D57756F59776F5A78705C77705D79735F
756F5C746D5A726A55756D58746B58726954766D59756F5C767061736E607370616E6B5C
726D60756D5D716A596D68586D69586D68556E67546E68546E67576C67546A664F69654D
6362506B6C5F595A533A403B29342F28342D2D392E3C4535494E3D5254415E5D4B5C5E49
56533C29A31500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C0713A8D210C9D1E17B24E4D
D89EA2D9B5BDE5C0CBE3A2B0951C2CB10D19AD04119C09276E1752281B7509238F012596
01249801249902269A01259A02269D0127A00229A30128A000269A032899022799072D99
10329326408F4B5C97717BA1868BA19B9CA8A5A5ACA7A8ABB0B0B3BDBCBFC7C4C6C9C4C7
D0CBCFCDCACDCAC9CFC1BFC8B0ADB997919D8B808B80707A77666D7063676E6365716968
6D6C696B6E6C6E7474697474677272636F6B626C6B6169675B645F61665E67695F6A6A5F
6C6A5D6F6C5C6E6B5B6B6B596E6B5C736F5F77715F7A72607871617A75657D7464786E5F
746B5F5E5B54464A4439423D444D4A4854534D5C5857655D60695D6B6F62757168706B5F
706B5D6F6C5A746E5D746E5E766D5D756E5B736E58736F59756E57736C54756E5A756D5B
776D5C756F59736D56746C55786D5A7B705E776F5C706957726B5A746D5E7D7768898576
7D75697165567164546E65566E69596F6958716A577069576C65566E68586A645268634F
6B695A6465594D4D48373C37303C342F3E33314034424F414B53445355445354405A5B45
5D59412EA91B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007769079E2D18B8615E
A77278DAB9C2BE9EAAE1B1C0A34051AB101FB20410AC0619940E35511560161B82022192
02249901249B01259B01269B01269B02259D02249C01239803269208298B163286314386
585F8D7672918A8095928895968E94A0999CA09C9FA5A4A7ACABADBBB7BAB9B3B7B3ADB2
A9A1A8978F98837C88706773675D64655A5B75676183736983766A7D766B75736972756E
66706C6472715B6B6C54636457605E58605A5C615960635969695E6F6C5F736D5F726F5E
7877658B8B7AA8A59AC2C1BAD1CFC9D3D1C8D5CFC7CCC1B7BCAEA4B6A79AB2A193AC9888
A18E7F9181767E7466645F515A594E484C424651484E5E5458635A64675F7170687D7B70
767568686655736C5E766F60756C5B736C5A716C56706C56746B56766B57756958756858
756856756A56756D57756F56766E59716956776F5C746C58706956726B58756D5E746D61
7A7064796D5E786B5B776C5C777060726C5C716A5A70695970685B6F695A696454666554
64665B52554D41423B3B3F363842363A4737404E404855494D574D5961545F6251555540
5A573E2FAA1B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002CD506A04924CF8C85
E9BFC4EACCD5E1BECBF9C6D6AF475CAC1022B40512B30512A5071F78134A2B167108218E
02259702279903289C02269A0124970125940324910925861C33803E4B825D5D82746C84
8173828B7984917F8792818892848995898D9790939B959C9B959C958D93867F82767171
675E5C615451675A566E615A74675B7C6E607F71628076677F7A6B727067686C67586361
5162624C5F60495B5D4E59575F60576966586D6A5A6E6C5B7876678782779E9C8FB8BAAD
CBCEC3DCDBD8DDDADFCFCAD5BDB6C2A79FA8998F938D807F84726F7E6C647E685D7B6457
7865557A69587E6F5C80735F7C73616E6D5A4F5446414D434D59545B625B63665D6B6B5F
7C7C72817F74777367756E60786F5D766C58736E56726D55716952726B53756A58776A57
776854756955756A54746952776A57756B57786F5A756E59736B58706956726958746B5D
766B5F776B5D7C6F607A6D5D776F5E766F5F726D5F726E607772666F695D666154636255
5A5C53494C4342463943483B464C3F4853434D594C4E5A514C57525D6860696D635B5C4A
58543C2DAA1A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051AD19D19287
D9ADB4CBA4B1C88DA1B44E68AC1931B60C1AB7050FB7060FB108168C10393C15650A2089
02269501249401259602239203238C0726821B307D40477C635E7C6F62757D6C7A7F7078
84727889757B8E7A809181879085898D83868780857B72776C636364595662574D696050
7368547C6E597B6C597D6E5981725A84735C7F705D786F606D6B5F62655F555E5D485958
3A4F4D394C4849554E5D61556C695A7B78688D8A7BA7A497B3B2AAB4B3ADA7A5A29A9896
908B8F8781889187908A8187897F838881808A8180887F79847C737B7467695F516B5F4E
6C5E4D6C5C46746044755E417562487A725A6B6C5B4851453847404B59545B625B63675A
6E6F627D7E71858578807C6E76705D746E57747058736E55766B55776C53766D57756C55
766A54756953716753766E59776F5C78715E746C59756D5A756C5A746D5A756E5C746C5B
776B5E776D5E786E607E73657971607570607774667474676E6E63656156665D545C5A4E
4E4E424B4B3D4E4F40515445525848525C4B545F50525C52505C545D68616A7168676858
59553C2EAA1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C48370
B5838AECC1CFE19EB0A42132B60D17BB090FBA060ABF0F13AE0B1987123D3B1869091F88
02249201228E04268D072582182E79333F72525271685E6E74636C7D69707F6D727E6E70
807172857578847579817679756D6E6A6462605A5560564D695C4D796954806F5785765B
83765B7F73597E70577E6F5582735683735881715A776C5A686558595D56495350344441
33433C4553475B6354727466888579949187928D838A847C857C797F7976867E7B877F7C
87807C7F7C777F7D777F7E777F807A7A7D7478777271716B686C665C655D525A5350554C
515249514D3C6F6044856B4B7C5F3E7560426C624D686B5B464D443A464049554E556053
6367596A6C5E7070628481728784737C786477715E79705A756951796C547A6E59736B56
756A57736854746C57756E5A78715F776F5B706A54766F59766C5A76705B746E586D6652
756958766E5D756D5F7773617773637471647471667172686B6C6465655D5E5B51555045
5750445653435C5A48595B4B5E61525962535862575561575D675E6168616A6D656B6859
5E563C2CA71300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A96C4D
DBA8A9E0A6B6B54C61B71B27C71314C60E0EBE0A0CB40D1795102E5E19571E1C7907248E
02248B062581122B742E3A6E4746665F56676A5D666D5F62736565786969796E6D7A706D
796F6B756B686D6460675D5763594E695E4D72664F7E6F5686755A88765988755788755A
84745A8072597F70577F6F558474568272537E6E52776A536B63515555483D433940493E
5B64576A6F617274667E7B6F7A736A7A73697B756A7B776B7C776C828175808176797C73
777A72727A707079716B786F65716A646F67676D67656B64616A6359645C565D56545850
4D4F464B4A3C6D624B8671537E5F3F785B3974624477745C6265573F484037433F47544D
5961536367556B6B5D6F6C5D807E70878575817C6A7E7460786C54776B53776C57746D5A
766E5A766B57776D55746B54746C58746C59726A55756E57786D5A746A57716954746C57
796E5C78705E767160797766787468767468726F656D6F666869645A5A535352475B5649
60594A645D4D63604F67675964685D5C655A58635A5C665E5F655F5F645E696B636E6958
63573830A60F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0090A346
D39A97E092A1A62634C1181BCE1613CE1415BC121B95153261225D2423790A2989082A87
0D297724356B424765524C5B5E555A655A5D695C5F6D5E5F716362706661756C6570685F
665E535F5647675B4772634C7D6C518371558472548573558A785A8E7C5E8A76588B7556
87745881725A7F70597E6E558071528273517E6E4F776B4E71694F5D58435855446E6B5C
7774667571627672617972627774667473666E73677A82768C938A838E87717F7B677875
5F716D5C6C685C6B6557645C5A655B5A62556264586765566665546765536A66556B6558
6F685D726B5D84775F806B4D7D5E3B795A3679624174684B75726064675D4047423A453F
4C554B565E4E66685A6F6E5F7374647777667C7A677873607A725D7B715C776C58746C59
746955796C57796B53746A52746C58746D5A736B55776E56786C567C715D7F7463776E5C
7B6F617A72647975677777697674697372676E6D67656862565A5655564E5B584D655F50
6D6656716A5D6F6A5E6D6C6063675F5B635A5F69615F6A625F66605E645D65665C69614D
614E2840B11400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053AF19
C4796B95343EA61D24C41A17D11815C6171E9F1A3865296721257C0B2B8908297B1D326D
3B42634B4956554E516057576057555F5855645C596C625E6E645D6B6456665D4A665B43
6B5D417769497F6F4C847150867051856F508672548773558874568A775686734F88714E
86725383725A7E715B7C6E557D705387795A8374567C6D5074684B695F43766D537E755F
776E5A716853746E5C6A6A5D565E574F605B576D6B667D7B788B8D657B7E526A6F496062
485C5A505C575B5E566163536666536968526B6752706D557E7B648C877397918490897E
7E776C7C73617E6F577A6547796140836B48826B4A7B684873664E7673626A6C63454E46
444C44757B6F74766A6E6D60726F60726F5C706C586E6C57706B57746D5A7B735E807863
7B6F5C75665076634A76684D726951716953706650766B56786D5B82766880776B7A7366
7B73697771667370666B6C6167685F6868625F5F5C545753565B535F62556A675A716D5F
747162797669747367686C60636A63616C64636D67646F65636B6162655B655F516D5C41
76592627DD0D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D5226D6867CBE5051BD2221C31618AF203675336C292E800C2D84122F76293762454554
544C4D5A524D5C554E605852645C55666057686259625C4F645B476A5D4172613F7D6945
826D4B84704F8673528976568873548A73548972538872538B755687735384714E86734F
8673528573578072597F72587C6F547F70548371558270537361437E6D4F8473567B6A4F
796A50726751535041313832293B392E4946355254365359364E562E474D2D4346384945
4C554B5B5E4E656452706F5B7B7B68969684ADAFA0BCC1B5BFC0B8AEAAA59A908D837872
7B6D617B6A557F6B51877558806C4F7D67467A623D785D36745E3A7164497A7A686A7164
4E544B5D5E52706B5E756F5E756C59786D56766C55726A536E63506C614E706551756D58
8277657D6F5B77624874624473664B746952766C587B72617F74677B70647971647B7569
76746974756B72736A64675D575B53555853585B575F625B62655A686B5D6F6F63767669
7A7A6D7476686E71636A71636B74696C756D696F69686F63686B606561526E60486E5429
70932200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
23D003A6593DD47471AF2123B724328D386838348514368A1B336E3D415C50474B544A41
5F554A625A50635B50645D506E65576B634F695E486B5A4275603F79633B806840826A43
886F4D856E4F8573568A795F8373578473558573548B77588B7454887152846F4F887452
84714D83704E837051806F52807052816F50806B4D826D4F7C67498872537E69477C6846
807155655C454443333C413736413931443C2F443C2C403B2A3C392D3E3947534B656C5E
8284769E9F94B5B6ADBFC1B8BABCB7A6ABA58C918C7A7E7B716E6F74706E78716D7E756B
8275668878668B79658E7C63816B50745F3F785F3B795F34775D31705D36756A4E6C6C5A
7070675E5A4E706657756C55766A4F74654776644977664C77664F6B5C46756A53756E56
776E5B7E746082705977664A796C537971597C74607B7362746C5C716B596F67596F685C
6261555D6357575D53535A535159535A6259646B60686F616F766674776A7E7E737E7E73
76776C71746671746973776B72766D6C736A6B6E656A6B5F6C6B5B6A62496F5830678C1F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00807F1CA3321EA31A1BA134565A3C851E378D2036713F404F5B4D435D4D3A5A4D39
605843675E4C6D63536D62516B5F486D5E4075614078603E7A613B7B623A806845866D4C
886F4F87705289755888785B847558847657847655857252867154887356937E61897254
836B4B866E4D866E4C86704E806D4B7D6A4A7E6C4D816F53826D50856D4C7D663E7D6A44
827457787059716C5776705D7E7A69909382A5AA9CB4BAAFCBD2CCD7DCDACED1D0C9CAC7
B7B6B4A6A3A38A85897670706C68686D6E68787A71909389A8A7A29F9E9A84857F727268
716C5E8278678274649485729F907CB5AA9690826D7D6948796137735D30705E366F6446
6C68556A665471665075654775634077633E725D3C6F5A3F77654C76664C6C5F46787158
78725D79725F86776584745E7F705B776B567468536D614D675E49655F48605A485C594C
53574B4C594D525D5656625B5C686366716770776C727A6B797F717B7E757A7D74797B71
757770777A71787A7173766B6E71676F71676D6B616E685A756952735F37658C2000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009F390A91211E8545753B3D8A293A793F3C51594A3966513365503368563C
6F614772654C6E6049706046756345746340786542806B4A806C4A826E4C877352847251
8572538875568C7A5C8A795B87785A8B7C608473558370508670518D76568B7453866D4C
866E4A876F48867046836E44836F47816E4B7F6D4E7F6F5488775B8672508069417F6841
7C694B7B6C527B6D557F715980715B8C7F6D9A8E84ACA3A2BDB6BEB0A8B68F8894777277
7068686D645E786F647B7164756E6167685B929288BABCB2CBC9C4B5B0AC9B968F8F877D
7D73647D715E877A67877D6A8D8677BEBCB69D97958A7E718772547D66417761386F5B37
6C62457B745B70624677613D7B633A78603779603C745E3F6D5B3E76674873654B786E59
8076667D72628172607C6B5375644C71634B6C5F45655B41635E455F5E4A5B5E4F555C52
525F57586962596B656070696B7871737E76787F76787E73797F75797F76797E77767B74
797E78787D76777A707174676F6F63716F626E685974664F7B623A6A922400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ED608883825714C723F3F743B37505341366A53346D5631715A39776344
7766467164446D624277694A7B6A4B7C6C4B7C6C4B7F6F5083735684735784735786775C
89795F88755B8D795C88745593806088755886735486705188705088714C877049886F4A
836945846C43826B42826B41856D437F67417D68467D6D4C8070528A795A877150836B46
8068447D67457A6442755F3C77603F7D67497E6752816B607F6A667B6967766967706C67
82807B7C7B6F827C6B867A667C6E59837A648A816E8E8476968A7F968A7D9488778F8370
887A67827560877864857967857D6F847E77877F7A877C728E7F6A8E7B5E826D4B735B38
726142776A4F7564457C66437C633E79623A8068447A66466C5D3F77694C7667517A6D5C
8173667F71617F6D5977664C7162486A62466961476360486060515D64585F696057665D
59686261716E6A78776B7A7774807C78837B77817A7981797A81797B81797D807B7C7E77
777B7273776D74756B7371656F695C71685478684C7E633672962900FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0076892C6E4F524635424F3930644B2E7259327961397D65407B6643
786746685E3F6E674B766A4F7B6B4D7E6D4C7F6C4A7F6E4E81705484735A86755D82745D
82745B8A795E8B795C8D7A5C8D7A5D85745886745790795A876F4C846D44866E45866B45
846843876B44846B4285684084673E85693E7F663B7661367766408170509380628B7354
8B704F836845826741856A41856941856D44846C448269487E674C7A6A564B493E4B5552
838F8D868C88979589958B778C7C668A7B6491806992826B93836D94866E93846D8C7C65
8B7965897A638778628A7D6B877D6D867E728C82778E81728A7A68837358776343735E37
73613C7464457B6A4E8170537F6E4F806F508473567E7058796D557B6F587D705C7E7564
7E73637E715F7A6B577167516B66516A69566A6A5B666C5F6A716C6A75706B76736F7D79
6C79756D7B7772818072807F74817F79847F7A838178817C7F857F81867F80827B7C7C77
7D7C737B7A6E787569786F617B6B577E664789673650BB1B00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0F653C1B50341E5D412371552F7F633B8269407F67407E6A49
6F6247655E496A665075694F7C69497C67427F68428068447D6744836D4E837057817358
8274598475598B7C628C7C6084735585735585704F866F4C836A4482693F846B41846B45
876D48866E46826A3F836A3D83683B856A3C84693A7D6435775F3278633A846F4D90785C
8E7457917556896C4982663E856942846B41826A3D7F693C7E6943776A4D65685822322B
475654969B9BA8A29F978C80887A6A83725E86735B88775E8C7B648B7C65907E69907E69
8F7D698E816C897E6C857C6C857D708881748B82758B7F6F8B7A677E694E745E3B7C6A43
8776517C69487E6E537F735B817861897F69877E6A817A67827A67857C67857D697E7865
827C6B827D6D817C6E7A7A6C7C7D73757A72747D78707D78747F7A7F8A877F8989818C8D
7F8A897D88857785837383827A8888808C8B80888983888784868380827D7C7D787C7D77
807E787B756A7E72617E6C5084643C6E8F272ADE0F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00653D085B3B13674B227E6337856A407D663F6F5C3C63573D
6F6A585B5C4D6768556C634A7562427A633B7D633A7E623A7E633B7F66427A6748817156
8375597D705484765B87785E8775588771538169487F6841806A40836C42816A41846D47
846D4A826A44836C42856D41826A3C866E40836B3C876A3C8366377D63367D653F7F6A4D
8C775E8772558B7252876F497E643C7C61357C61327B63337B653B73674571715B828A7D
9EA49EEBE9E8AFA6A7877A7094826E9B83699C83649A846494816897826AA08770A28C73
95846F89806E8D86798E8B7F7F7B6F888478847D6F7E72617767517D6C508E7C5D948564
918363807152867860877E6B8A82708C85738B8676878371857B68887D678B826E8C8676
918E8190908492928B8A8B868B8F8D8A8E8F848C8E859191859190899495889294899294
83898B89939284908E7F8E8B808D8A828E8C83898C8285848385827A7C797979747A7871
7A756A7B6F5E7E65488A683650B91B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006B470F67481A7D5F3185693B80683D6959354C422B444030
5052445E64556269586F705C6F674D736344735F3C7A63417C66437D6A497A694B7C6E53
82745B80735986775C857458847154846F50816B467F6A407E6B407F6C44836F48836E4A
86714F856F4A867047886F45866C3E856C3C856B3A866A3A8569398367397C60387A6341
7A6648826F538D7A5B8C77548C724D8164397A5C2C795E2C795F3176643D72684B827D6E
8A878093908C8C827F8B7A68AF9375BC9B7AB99674BA9C7DAE967BAF977EBA9F84B89D84
9B8675877C6F888075857F737C7467756C5C74685482735A9282678F806386765B85775C
887C618E8769978F79938C7C90897A8B8475837E6E898370968E7AA79D8AB1A89AA9A397
A7A49BADACA5ADADA9A0A2A1969A9D9CA0A39A9EA1979EA1939A9D8C9596949E9F919C9D
92989A929B9A8E9797848F8D838E8D7D86867D85827D827D7C7E797777727A766C7E7461
7C6B4C846A3B72942700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0020D404704B157D5C2C89683884683B70613A59553A494839424438
3E4539445042576355656F626F7263706C5B746A55776B53786C517B6F557B6F567B6E56
7E705980735B82755A837157826D50816E4D806C46816B43867049866F4D846F4D857250
85735086714E89734E876D44866B3E84693B886D3F85693B896C3F85673A84683C7E663D
7B67407F6D4881714F8272518C77578F775181673C7E62347B613278633772613E766A52
80796A7F7C70847C6D9B8970C8A88AC8A485C7A489C2A68DB6A08AB09985B09682A98F7A
8D78677F70618174647C705B80715A83745B887D61887F648379628279618B806A958C76
99947C9390788C8777847D718B877A999789B0B0A2BEBFB1BDBDB0BBB8ADC2BCB5BFB9B5
B5B4B0BABAB8B5B5B5AEB2B2ADB1B4A4A8ABA7A8ADA1A5A8A4A8AB9CA4A7969FA399A4A6
97A0A28E989886908F838C8A7F87867D8383797E7A7B7D777C7A737C75667E6D5382683B
6F95272ADF0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA5067C531C89673388693B7A643E6A6248595C4B50574C4A5248
444E443F4B3E455245525D54676F6774776E7672687974647A776278745E76705B776E59
7B735D7A6F5A7E715B7F7057827055826F517D6A487F6B47856E4D856E4F8A76568C7859
88755387755387735287714C876F46866F44836C41876F44866D43876E45836B43836C44
836D4784714F8474538070518675589686679786648B78538470487C693E75623971613D
74654B776D567066507A6950987F669C816999816C94806D8574647F705E86736185735F
8373608779648578637F755E827861857C678C847096927E9C99859D9A8495907F8D8D7B
979985A0A591ACB1A4C0C3BBC5C7C3C8C9C5C8CCC7C2C6C1C5C7C4C3C3C1C4C3C2C7C5C4
C2C2C2BDBFC0B4B9BBAFB6B6ACB6B5ADB4B4B2B7BAA7ACB0ABAFB4A3ACAE979FA4919A9D
8B9396848D8E8088867C868078807E787C7978766F7E76677D6C558266426F942D28DE0E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA504875C218E6B3783683D72664868685660685C5C675D536056
535F554E5A4E49554948534A4D585260696380877F898F847B8173737668757466726E5E
75725F7B75627D745F796F5A776D567C6F567F715583725686735789775A8A785C87765A
87765A8574598574588675578674538876548877548979568979578979588B7C5D8C7F5F
8E7E618E7E628C7C6089795D85755B86775D8F80689589709B8F739A8F6F9488648E7F5B
9080608275567F7558807659887A608E7E6693836F95897598907DA59E88B6AC97BBB19C
B7AC98B2A994B1A997AEA898A8A394A19E919D9B8EA1A393ACAE9EBBBFAFC9CBC0D7DDD1
E0E7DCE0E7DDD7DDDACCD1D0CDD2D5C6CDCEC3CCCCBFC7C6C5CACCC3C6C8C7C9CCC3C5C8
C3C6C8BDC1C2BEC3C3BDC4C4BBC4C4B8BFC2ADB4B8A7AEB4A1A6AC969CA28E94998C9095
868A8E8183867878787579747979727972657A674E85673F7596302BDF1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0043A80593692A8E6D3A78633D79745E6B6F63687167657366606E63
616E645C695D55635655615855605956615C5A656263706C87948D8A938D7A7F78777B6F
797B6D8080707B79697A78667E7C69807B67867E68867D688A80698D836B8A80688E836A
8D846D8B836C8A836A8B83698E866B8E866C91896F90886D8C84698F876D938B71918B71
958E75988E769A8C7695887091846D8A7D67867863847961837860867E648A83698E876C
938A6F958E7299947B9C97809D9780A09783A49C8BA4A08CA2A18FA9A696B2ADA1BAB4AB
BFB7AFB8B1A8C1BEB6CFCFC8DDDDD7E9EAE3F2F3EDF9FBF6FCFDF9F6F8F4ECEFECE8EDEC
DFE6E6D9DFE0D3D7DBD2D4D9CCD0D4C6CFD1C5CED0C5CDCFC3CBCEC7D0D1D1D8DACED2D6
CBCED3C6CACEC6CECEB9C3C4B2BCBEABB6B9A4ADB19AA3A8979EA195999D8B8E92898A8E
8180837D78797F746E7B6D5C78634688693E4AB71D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AAF09956A2982613279674A82817170756E6A746C69766C6B796F
6D797069766D68746C68746F6A767163716C61706D60716E6471706A7674707C77858E88
8C948C8D938B888B82858A7E8B8F838C8D808889798786758785738987748A89778E8B7A
9591809493809595819A9A849D9B849B9884979681928F7A8D8A7289856D918C75939079
9B98819A978296907D9A947F9E98849F9B86A19D889F9B849E9B84A29F8498957B98967C
99937D98947E9A96819E9D89A3A38FB1B09FC3C1B4CDD0BFDEE0D3EBEBE2F5F5F0FAFAF8
FFFCFCFFFDFDFFFDFDFEFEFDFEFEFDFEFEFCFEFEFDFEFEFEFEFEFEF7F8FAEAEDEEE9ECEE
E0E4E6E3E8E8E0E2E5E2E3E6E2E4E6E1E7E8E1E7E7E3E8E8DEE3E6D5DCDFD7DEE1D1D8DE
CACED6BDC3C9BCC3C7B3BBBDACB3B8A3AEB1A0A8AA99A2A4969C9F8F9293858382807975
7C6F667968528265426D922E54BE2100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0029DA079C6C298564347F71537B7E6F7A857C6F7D766A79706A7972
717E7775807C767F7D7882817986847686847181807C8B8A7C87877C87837B8784778582
7C89867E8B8986928E97A29C9DA6A09EA49CA3A89FA6A99EAAAC9F9B9F929AA0939A9D92
9EA0959DA0929FA594B4B9A7C2C4B6BEC0B3BBBFB2BCBFB1B7B9A8B3B6A5ADAF9FB5B8A8
B9BDAEC2C5B6BCBEAFC1C3B4B9BAAAB7B7A7BEBFB0B9BCABBFC4B1C6CBB6C8CAB8CDCFBD
D5D4C8DFE0D3E9E8DEEEF0E5F4F5EDFDFEF8FEFEFAFDFFFBFEFFFBFEFEFCFEFEFDFEFEFC
FEFEFEFEFEFEFFFFFFFEFEFEFEFDFDFEFEFCFDFFFEFCFEFDFEFEFEFDFDFDFAFAFAFBFCFC
FCFDFDFDFEFEFEFEFEFEFEFEFDFEFDF8F9FBEEF0F3EBECF0E2E5EBDADDE2D3D6DDC8CFD5
C2C9D0BBC2C7B4B9BDACB1B7A9ADB2A2A8AB9FA3A69598998F8C8C857D767969587B6143
916D3F4EBA202BDF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF009E671F845F2C7D7151777B6A758076717E7874817D727F7D
7681807882827A8385818B8C838E8F8996968593938894958995968E9B99919D9B8B9996
92A1A091A1A28F9E9F9AA8A8A7B3B3AEB9B8B9C3C1C5CEC9CED4CEDCE3DBDAE0D8E1E6E0
E0E4DDD7DCD3D2DACFC9D2C7C6CEC5C4C9C4C3CCC5C7D0C9C6CEC5C5CCC3C7CEC5CAD1CA
CBD1C9D1D8CFD3D9D1D9DED6E0E3DAE2E6DDE7ECE5ECF1E9F2F5F0F6F9F1FBFCF5FDFEF9
FDFEFAFDFEFAFEFEFDFDFEFAFDFDFCFEFEFEFDFDFDFDFEFEFEFDFDFEFEFEFEFDFEFDFDFD
FEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFFFEFE
FEFEFFFEFEFEFDFEFEFEFEFCFBFBFBF5F5F8EBECF0E3E7EADEE1E7D7DADFD2D3D8C8CDD0
C1C6CABABEC1B6B8BCABADB1A5A7A9A3A3A296928C83796B79644C8B6D444BB8202CE011
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DB098F64287A63407F7D6B78817772807775857E778782
7B8987838F8F828D8C8A94938D98988E9B9C8D9C9C909E9E92A0A097A5A499A7A49FABAB
A0AEAF9BAAAE96A5A8A5B2B4B6C1C3B9C4C5C2CCCBCBD4D4CFD8D7DBE3E0DDE3E1E3E9E9
E5EBEAE8EFEBE7EEEBE3ECE9E6EDECE4ECE9E3ECE9E7F1EEE8F3EFE7F1ECE5ECE9EBF1F0
ECF1F1F4F9F6F0F4F4F2F6F4F5FAF9F3F5F3FAFCFCFBFDFBFEFEFEFEFEFDFFFDFDFEFEFD
FFFFFDFFFFFFFEFEFEFEFEFEFDFEFDFEFEFEFEFEFEFEFEFEFDFEFEFEFEFDFFFFFFFEFEFD
FEFEFEFDFDFDFFFDFEFDFDFDFBFBFBF8F8F8F9F9F9FAFAFAFBFBFBFCFCFCFEFEFEFFFFFF
FEFEFEFEFEFEFDFEFEF9FBFBF1F2F4EDF0F1E8ECEDE3E7E9E2E5E8DCDFE1D4D5D8CBD1D3
C2C6C9C3C4C5B9B4B49D9692877A6D846F578E6F49779A3558C12500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00748F1B8361307C6C527677686F7A6F79887E788881
7F8F8984939085929294A0A095A0A198A5A595A4A49AAAA99BAAA9A2AFADA6B1B0A9B3B4
ABB6B89DA9AB99A5A8A1ADAFB0BCBCBFCACAC6D1D1D1DCDDDCE6E6E0E8E9E2E8E9DFE8E7
E3ECEBE9F0F0E6EDEEEBF1F3E9EFF0E8EDEFECF1F3EDF3F4EBF4F3E9F1F3E9EFF1EDF3F4
F1F5F7F2F6F7F3F5F7F4F8F8F6F9FAF5F8F7F8F9FBF7FAFAF9F9FBFAFBFCFBFCFDFCFFFF
FBFBFCFAFCFCFBFCFDF9F9FAF9F9FBF9F9FAFAFAFCF7F8FAF8F8FAF9FAFCF6F7F9F5F6F8
F4F4F6F1F3F2F4F4F4F4F4F6F3F4F6F7F9F8F8F8F8FBFBF9FCFCFCFDFDFDFDFDFDFAFAFA
F9F9F9F7F8F8F5F6F8F2F3F5ECEDEFEDF0F1E9ECEDE7ECEDE1E6E8DFE0E1D7D2D6C6C0C2
ACA2A195847993775E9A764C4DBB242BE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00718D1E816135786C537A7D6D7D857C7A847F
828E8884938F8696948F9E9E98A6A69EACAC98A7A6A5B3B4AFBABCAEB9BBAFBABBBBC6C6
BFC9CABFC9CABAC5C2C0C9C9C6CFD0CDD7D8D6E0E2E2EBEDE5EDEFECF1F5E7ECF0E7EEF0
E4EEEFE7F1F3E6EEF2E5ECF1E7EFF2E8EFF3E9EEF3E5ECEEE8F1F3E5EEF1E5EDF0E5EEF0
E6EEF1E1E9EBE6EDF0E2EBEDE5ECEFE6ECEEE6E8ECE8ECEFEAEEF2E7ECEFECF0F4E4E8EC
DFE4E7E1E6E9E2E6EAE6E8EDE0E0E4E6E8ECE6E9ECE8ECEFEAEEF1EEF3F3F0F3F5F2F3F5
F9F9FBF7F7F7FAFAFAF5F5F5F9F9F9FCFCFEF5F5F5F8F8F8F6F6F6F7F7F7F6F6F8F7F7F9
F7F6F8F3F4F4F2F5F4F5F6F6F2F1F3F0EDF0F1EEF0E0DADDCDC7C5B5A8A1A1887E9A7A65
A47C5955C02B2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00708D1C8161337F71557D7C6B7F837A
8790898996928998968B999993A1A297A6A79AA8A9A5B0B3ABB5B9B4C0C3B6C4C6C6D0D3
C7CFD2C7CFD2C6CFD0C3CDCEC3CDCFC2CDCFC6D0D2C9D3D6CAD4D9CBD4DAC9D0D8CAD3DA
C8D5D9CAD7DDCCD7DDCED8DED0D9DECED7DCD1D9DCD1DCDED2DDE1D1DBE0D5DEE3D3DDE2
D0DCDDCFDADCD1DBDDD3DDDFD3DDDFD8DFE2D9DDE0DEE1E6D9DEE2D7DDE1E0E2E7E0E2E7
DAE0E3DDE5E7DCE1E4E2E7EAE3E7E9E4EAEAE6EBEEEBF0F3EAEFF2EFF5F5F2F6F7F3F4F6
F5F5F7F5F6F8F3F4F6F0F1F3F2F3F5F4F5F7F2F2F4F4F5F7F5F6F8F5F5F5F5F5F7F8F7FA
F8F7FAF8F5F6F7F2F3EFE6E8DCCED2C3B1B1B19A94A58778A9856684A5465BC32D30E215
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D90B88612B81674481755F
87847A8D938E7D8683848F8D8D9A9998A5A39EA9A8A2ACAD97A2A4B1BFC1B1BCC2B7C1C8
BEC8CBC0C9CDC4CCD1C1CBCEC1CCCFBFCACDC4D2D3C5D3D5BDCBCEC5D0D4C5CDD2C8CFD4
C6CFD4C5CFD5C6CFD4C5CFD2C6D0D1C1CBCCC7D2D3C9D5D5C9D6D7D0DADCD2DADDCDD7D8
D2DCDDD0DADBD5DDE0D7DFE1DBE3E5DEE4E7DCE1E4E0E5E9E1E6EAD9E0E2DFE3E6DEE3E6
DCE3E6DDE7E8E2E9E8E2E7E8E2E6E9E3E7E8E6EBECE8EEEEE8ECEFEAECF0ECEDF1EDEEF0
F0F1F3EEF1F0EDEEF0EBEDEFF2F3F5F4F4F6F3F3F5F8F9F8F6F5F6FCF7F9F8F1F3EBE1E4
D6CAC9C5B1ABB69A8FAC8879B3866EB889615DC53230E31700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B112876431
806C4C89806C8584767E8279858C8698A19C9FA8A5A2ABABA6B0B2ADB8BAADB8BBAFBABD
B3BEC0B6BFC2BBC5C9B5BFC3B7C1C4BDC7C9C3CED0C4CFD2C2CDD1C3CED2C5D0D2C9D2D4
C7D0D2CAD3D7C4D0D2C5D1D2CBD5D7C3CDCEC5CFD0CAD7D7CAD8D9CDD9DAD0D9DBCDD5D8
CCD5D8CCD5D8D0D6DAD2D7DAD2DADCD7DCE0D8DDE0D7DCDFD7DCDFD6DEDDDADEE1DBE1E3
D9E2E3D7E0DFDBE1E1DBE1E1DBE0E3E1E5E8E0E3E6E4E7E9E5E8EBE9EAEEE9EAECEDEEF0
EEEEF0EDEFF0F6F5F8F8F5F6FAF6F8F6F0F0EBE2E3DCCFCDCCBAB7BCA39AB69385B38A74
BA8D688FAB4A5FC52E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB517906B35866C4487785A897F6B918C7D9A9A90A4A49FA9ABA9A9AFB0B0B9B8ACB6B5
B2BCBCB1BCBBB6C1C2B7C5C6B3BFC0B9C4C5B9C4C6BCC6CABFC8CDC0CACDC4CDD0C1C9CE
C2CCCEC0CCCFBFCDD0BFCBCDC4CED0C0C9CBBDC6C9BEC8CABFCBCCC0CDCEC5CFD0C5CED0
C8D0D2C7CFD1C9D1D3C7CFD1CCD4D6CCD4D6D0D6D8D1D8DBD4D8DBD7D9DCDADBDCD7DAD9
D4D9D9D4DAD7D8DDDCD7DEDDD6D8DBD8D7DBDAD8DCDFDDDFE7E4E8EEEBEDF0EDEDF3EEED
EBE2E0DFD4D0D3C1BDC8B0A8C0A397B29380B59075B78D688BA9485EC63031E31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADF0E48B518906C358C6E448A7152907C66998A7BA79F93B0AEA4ACADA7
B0B3AEB4B9B5BCC1BFBAC1C0B3BCBBB3BBBBB6BCBDBFC5C7BEC6C8C3CBCDC1C7C9C0C4C6
C5CDCDBEC9CABBC8C8BDC8C8BEC8C8C0C8CABDC3C7BCC3C6BDC6C8C2CBCBC6CFCEC7CECE
C7CDD0C7CED1C9CDCFC9D1D0CDD2D4D1D6D5D1D4D3D4D8D7D6D8D8D7D8D9DADAD9DEDEDB
DFDEDCDCDBD7DFDCD8DEDAD7DFD6D4DACFCAD0C1BCC6B5B0C5B1AABCA498B29888B39582
B28D72B68C668BA9495EC73162C93031E31600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002BDF0F4DB61C47B31E95724390754F8C755A
907E689787759F9082AA9E94B3AAA1BCB4AEBBB4AFC4BEB9C0BDB9C9C6C6C8C4C4CBC8C6
CCCAC8C4C6C3C6C9C5C8CCC8CCCECBC6C9C7C4C5C6C6C4C5C9C7C6C9C7C5CCC9C7D1CFCD
D1CFCED8D4D4D7D2D1D5D1CDD2CFCBD5D2CCD7CECAD7CDC7CABFB7C4B9AFBFB1A9BAA89F
B8A195AE9584AA8E78A98C70AC8A6BB18B67B5885E88A7465DC6325FC82F61C82C31E416
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
56BF234FBA204AB61F47B4219D754A98754F95745293765695785F987B669C816D9F8470
A28977A08978A48E7BA48E7AA4907DA69280A5917FA8917FAA927EA78E7AA68D7AA38876
A38774A48771A98971A7866BA48568A0805FA3815FAB8660AE875981A33F55C02C59C32D
5EC62E2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0106283 0.97619 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 178.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000/R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooolR
003o000F01O`2@0]h140;^0A04C@6P1L`2<0M;<_08bS=P2bSdD0^hQ:0;f7C02mQdd0_HI<0;V5B`2F
W3/0Rj@f08ZT=P2;YCP0RjHh05g49`0^hA80;n8C02oR52000?l02OoooolR003o000302S8?01@T7P0
D91h0080D91h00<0N5Rd0:0Pl02P8?002P2P8?04052@N2000?l0cOooool000[ooooo7P00o`005@0F
k`T0F;lR08:M<@2]OT40[7e20:mm@P2cP4D0/X570;:0B02dPDd0]7m90;R0A`2fPT/0]H1<0;N1B`2h
Q4h0]85<0;B1B02ePDL0[ga00;:0A@020:mmA0070:]i?P2]O3d0[W`n0;60@P2aPdD0K[4]02cP4P0L
003o00Wooooo7P00o`000`1@T7P0X23`0:0Pl00K0:0Pl1`00?l0cOooool000[ooooo6000o`00:@0R
j0h0EkdP05Jm8@21WC@0Oide08fE>`2bOdX0]H9>0;R4E02lQEH0`XEI0<^7G03?Qel0chEL0=>2F`3D
Oe`0eg]J0=QfE@3FME@0eG9C0=IdE@3EMEL0eGQJ0=AlG03>OEX0agmI0;V0F`2fQUl0]8MK0:n2DP2/
Odh0[Wm<0:QjAP2UN3h0YgHk0:Ug>P27Sbh0OYX[09B:<`1eXbL0:mh>01L00?l02OoooolH003o00<0
D91h1@2P8?060=1@N0/0oh000P3@D7P=0:0Pl003052@N000o`000?l001D00?l0cOooool000[ooooo
5@00o`004`0ZgA40E;/R08R@=@2]NDD0/g];0;UmD`36OET0bGED0<eZC@3BGTL0ee0n0=U7>@3H?Bh0
fC8U0=`]8P3N:Qh0gbHI0>4T5@3O8A@00P3R7QH06@3S7aL0i1hD0>8L4P3V8AH0hAdD0=dL503G7A@0
`1TB098=2`2:5Q80RQ`E08hX802?=BX0Td8d09I@?@2MHdT0ZGIE0:anEP2WNdl0YWU40:5e>@2RLS@0
YG<c06nN7`1@^1D05@00o`09oooooaD00?l00P1@T7P20:0Pl0<0d51h703oP0020=1@N0030;Ph]02P
8?00X23`00D0X23`00<0D91h003o0000o`004`00o`3=ooooo`002_oooolB003o000b02WM3`1C^b00
SHLk0:UhBP2aMdl0`7MF0<Y[C`3<FD<0`c`]0<PU6P3>7Q@0eATB0=dH4`3T6140iQL>0>TJ4`3Z6Q80
jaX@0?4N4P3_7Q80m24F0?<P503d7a@0mR0F0?8N503d7a@0m20C0?@O4`3c7Q<0lQdB0>`L4@3<3PT0
Z@850:D31`2P0@H0W0@809@31`2?10X0R0D907T72@1_3@d0LQXF088h;P2QJU40ZWaI0:QiD02SLSh0
VVT^09IU901gTQ`D003o00Wooooo4P00o`050:0Pl2H0oh0000<0d51h0:0Pl02P8?00102P8?0D003o
0<gooooo000:oooooa000?l003L02oL505>l8`2ERd40/WYC0;UYB`2mC3P0`CT/0<DX7`3;6A80dA8>
0=LB3`3P4`h0ha@@0>DF4@3U5A40j1PA0>XG403^6a@0lAhD0?8N4`3d81@0m24E0?@Q5P3f8aH0nRDI
0?/V6P3j9AL0o2LG0?LR4`3j91@0mb8D0?DP4P3`7Q<0b@T70;L61`2e1`T0[0460:/42@2T0PP0XP89
09d11P2F0`T0RP8:0842201l1@T0M0P;07<A4@1m9Ah0Q3l]08mG=`2KIcl0W6Xc08Ej7`19/0X0;L/3
01400?l02Oooool@003o000502S8?01hF;@0X23`0;Ph]03XJ3`0:`3oP0000`3XJ3`0d51h0:0Pl002
0:0Pl080D91h4@00o`3=ooooo`002_ooool<003o000n00[g0`1@^AX0OITb09^9@02fLD/0]e8j0;8g
:02Y6a@0`A<@0=0>303E3@l0fPh@0=h>3@3R4@l0ha<?0=`>3@3G2P/0e`X:0=L92`3K30/0i1<>0?4M
503j8QP0nR@G0?/U5`3j9QT0oBXK0?d[6`3n;1d0oRhK0?h/6`3l:1L0o2DE0?/S503j8a@0nB8C0>hM
4`331P80`0X90<8:2`2h1@P0/@@90:l42@2/0`L0Z0870:@21P2G0@L0S`4908/21`290@L0R08708D2
20200`T0N@H906l92@1f7A@0Q4D[09EQ=`2DHB/0Jf4;03jU100Cj`<>003o00Wooooo3000o`000`0X
b3`0N5Rd0:0Pl0020=1@N3<0oh000P3@D7P20:0Pl003052@N00Xb3`00?l000d00?l0cOooool000[o
oooo2`00o`00@00Ek`P0QY<a0;25@02gKC@0/2lJ0;TH3`363P/0b@X:0<l;303D3@/0f10<0=T?3@3P
4140j1DA0>/G3`3U4`/0e0L60=<7203E2@X0fP/;0=d>2P3N3PT0jQH?0?/X703f<B00lcHS0?8n;@3a
AC<0lT/h0?Hk:`3n<Al0oc0L0?h]6`3n:AT0oBLH0?`T5P3g9A@0h1lB0;T51@2o3@`0_P/=0;<8302Y
10P0Z`D90:X4202W0PT0Y`<80:43202K0PP0U08608X11@2<0PL0R08708@21P2810P0Q0<807h32@1j
1@/0L@L707DM4`27BbP0ReTX07AE400i/0<=003o00Wooooo2`00o`00101@T7P0X23`0:0Pl03XJ3`h
0?n000040=1@N02P8?00X23`07QH]0d00?l0cOooool000[ooooo2@00o`00@`0Ue`80Rh4R0:Yi@P2g
QcP0b9/M0<IV4P2g4040`@P70<L9203<2@T0e@`<0=`A3P3C40`0jbl/0=TA3P3Y5Q00kAT?0?0L4@3O
3`P0fP/80=T;203J3@T0g@l80>0@203b7a<0g28H0>YkK03m/J@0olJl0?oCb@3of<d0l7U]0?`d803m
;aP0oR`I0?hY6`3n9aT0nRPH0=hn;03CF4X0[1LA0;XC402d2`d0YPH:09/4202L1@P0Y0D70:D21P2T
0PL0VP4509<0102F0`H0Q@4508@01@230@D0M`0207X00P1g00<0MP4507/11@1m0@H0OP@;06`91@1/
8@l0TU`g07U34013Y@<03000o`09ooooo`T00?l000<0D91h0:0Pl02P8?000P2P8?0k0?n000030:0P
l03@D7P0X23`00`00?l0cOooool000[ooooo2000o`00AP0ia`d0RWh^0:EF=P2H=1@0`g`F0=6S1P38
J@`0^Q<30<481`392`P0d@`90=L=303K3`h0bPd<0=LW9@3G4`h0k1X?0>hK3@3a7A00kA`@0>hP5@3W
7A80fAL=0>DO4`3a9AL0nRXL0=DU7@2MFUD0nncY0?S`k`3hlo40nO;_0?:^Z@3f=bD0oBlI0?l]603n
:QP0oBTH0>@[6`2oM6P0o=oG0>BWW@3=JF00ZbdX09DG4@295@l0PA/C0:<e;02[8b00X@D:09`22@2B
0PP0S04508P21@270@@0R@860882101o0@@0NP4407D10`1i0@D0O`870843201m0`P0LPD7064?201i
?240OTDD04b70P0Lh0<:003o00Wooooo2000o`000`1@T7P0X23`0>QX?0020?n000030:0Pl03oP000
oh0003X0oh0000@0d51h0>QX?03@D7P0:<Pl2P00o`3=ooooo`002_ooool6003o001901?/101iQRT0
OTh^070S5@2K3@T0[1430<]f4P3AY@@0a6d<0;LD0P332PL0cP/90=@<2@3K3`d0gQ4=0=lF4@3T7aT0
jAT@0>/I3P3X7100f28E0=YA@`3WNFl0kY:60?FZWP3fZil0m:2D0?:;O`3TJEh0P3Pb0>7Ac@3gm?<0
m??a0?Cbl@3kf]T0k48g0?da7P3l;a`0lc4O0=Lc8`37J5T0m^KO0?CclP3elo80n?3^0>kEcP3Q`;@0
g;b^0=ZhZP33RGh0T24P09L32P2F0@T0T04808l1202;0@H0R04508/11`290@L0P`4607h11@1o0PL0
P@8708811`250PT0Q@8:07H1101T0@40F`<1060J301h?1T0MDd901cO0P09003o00Wooooo1P00o`00
100Xb3`0X23`0:0Pl03XJ3`30?n000030:0Pl03oP000oh0001@0oh0000<0d51h0?n0003oP000303o
P000102h>;@0X23`0:0Pl02P8?0F0?n000030>QX?00Xb3`00?l000P00?l0cOooool000[ooooo1P00
o`00B@24OBL0FS4I04070P1H0P@0VPL90;4@103:Ka80eJT40<if3P2m5`<0c0d90=0;2@3F30X0f`l;
0=`>3P3O4`d0ga890>HG3@3R6@l0`R0E0<ITFP3ngML0n^gX0?S`j`3flNl0m_;`0?Wal03ikN/0o^[U
0?SPf03_i^00m?;`0??_kP3bl>h0nN_X0=mQE`3W?c00fT8d0=1RE@3[[jH0o^_T0?Gcl@3blo<0lO;a
0>o_l03Uh=h0i][I0>OEc`2^OgH0Ka8@08d62`2M0`X0V`<809D1202F0PT0S08808h32P2=0@P0S048
08L11`200@H0N`4507L10`1k0@@0P0480843201k0PD0J00006010@1H0P80D0H007Dg5P1=Q0402@00
o`09ooooo`H00?l00P2P8?050?n000030:0Pl03oP000oh0001@0oh0000<0d51h0?n0003oP0002`3o
P0001@3@D7P0X23`0:0Pl02P8?00d51h01L0oh0000<0d51h003o0000o`001`00o`3=ooooo`002_oo
ool4003o001=01kT2028PS00G38F03T7100n10L0E@<708l51`2/3@80bFL@0=NX103EP@l0_aP20<h<
2P3A2`X0eP`=0=P<303K3`h0gA4=0>0D3@3S5@h0^Q@@0:MFCP3eem40mNcZ0?7Wi03bgmd0ilc;0>?5
a@3Wc</0k=OF0?CWiP3fk^d0mO7^0?;bl03bl>h0l_3_0?Kal03fc/L0mLFk0?[Gd03kj^D0nO3_0?Kb
l`3dlo<0lo?c0>o_k@3Wi>40i=GA0=Rj]02eO7H0O1TF08841`2A0PP0W@8809X11`2F00L0U@8808l1
202>0PT0R@4708T220230PH0NP4407800P1c0@80MP4307X11`1l0P@0OP<607T31P1]0P<0HP4205P1
0@1H2`@0MC8<05690`0:m@401`00o`09ooooo`@00?l000@0:<Pl0:0Pl02h>;@0j6Pl1@3oP0000`2P
8?00oh000?n000090?n000030=1@N03oP000oh000080oh00103@D7P?0?n000050=1@N02P8?00X23`
0:0Pl03@D7P06@3oP0000`3@D7P0:<Pl003o0006003o00Sooooo8@00o`004@0<n0H0;n8G06Vn=@1Z
_SP0SJY<08^]D@2]V6D0Xj9W0:25J`2VSFh0YXY]08^hIP2gVWd0Y:]b092hI`0ekR/0<^`Y02L00?l0
2?oooolQ003o000402S8?01@T7P0N5Rd07QH]0/0X23`0P1@T7PW003o00_ooooo000:ooooo`<00?l0
04h05>d60:fOJP33[j@0<a4?03D41`0n10P0F`@809@5202a3@P0b5H=0=JV103GRQ00^1P10<T;203:
20P0d@X;0=D<2P3H3@/0g0h=0>0@303P4`h0R`d<0<nb[`3fg]T0dXF10<YGE@32=3@0_ahM0<0K702m
7Al0^bHU0;`m>`3:IFH0ZGYj0>kWiP3bl?40l>o^0?7_k`3dl_40mO?`0?Kcl`3fl_<0mO;c0?Kbl`3f
lO00nNk_0>3:b036V8l0XE1808TN6P2:1`T0T@8808l1202A0PH0W`8;09l2302I0@L0U@8708h11`2=
0@H0R@8608L11P1i0@<0K`4106h10@1e0P<0N@8407d21@1k0P<0MP4207P31P1j10P0K`8306P20`1L
0P40F`d306hX1P1:TP<7003o00Wooooo0`00o`00100Xb3`0X23`0:0Pl02h>;@60?n000030;Ph]03o
P000oh0000T0oh0000<0X23`0?n0003oP000203oP0000`2h>;@0d51h0?n0000:0?n000030:0Pl02h
>;@0j6Pl01`0oh0000<0T71h003o0000o`001@00o`08oooooa`00?l002005o0<03[K7P1e^d<0SK1H
0;NRL`30WGd0dkNM0=>hY@3C]j@0dKRV0=31]03Aal<0YJ2V07f0T@2[]L@0QYFZ06Z1W`1jT:H0`<W?
0=OEdP3Fdm40dm3=0=;=b03@bL40Z=:N09_DS`2GcHL0SKmf05cCB`1IcDD0>=l[01C`3Qd00?l02?oo
oolL003o000302S8?01@T7P0N5Rd01T0X23`0`1@T7P00`0Xb3`00?l0003o000K003o00_ooooo000:
ooooo`<00?l004l0K[Hi0=G8_@38_l40=1XL03031`0g0PH0C@4308d4202Y2@P0a4/<0=RV1P3HS`l0
/AX10<D;20351`L0bPP70=8;2@3F2``0gPlA0>0@3P3O4Ph0V@d>0:A^J03GRGh0_aPD0<h=2P3E30`0
ePh:0=P@303K4@d0gQ@?0?4S6P3b:b80VQlL0=S9a`3ck^h0k^_[0?7_k`3dk^`0oN?P0?oNh`3ogn<0
on3S0?oHg03/^kh0cHJ=08da=P2:4a@0U@H809L31P2E0P@0T`4409<2202B0@T0V`4:09h1302G0@L0
T`4709021`2A0@L0S`4708<11@1b0040K00006d10@1_0@40M04107/10P1k0@@0MP0507D11P1g2@d0
K@@706L10P1P0P80FP<105/>0@1h<0<05>X200H00?l02Oooool3003o00@0X23`00<0d51h0?n0003o
P0000`3oP0000`3@D7P0oh000?n000090?n000030:0Pl03oP000oh0000T0oh0000<0d51h0?n0003@
D7P0:@3oP0000`1@T7P00?l0003o0004003o00Sooooo6000o`009`0<n0H0>m/N08BdAP2/YVH0cJR;
0=>gX`3Nb[X0elBg0=_9_@3Mc/D0flk50=K9`@3Qe]40elc80=?;b03Ec//0cLcA0<;2c`1HIhT0WJc4
06j5Y@2AZ/@0Q9^b0<kHgP3EemT0d=CF0=7CeP3>d=<0blo@0<_=cP3:b/d0a/K60<G3`P37a<<0cl_8
0<c3_@2Y^Y80G<i:00_h200J003o00Sooooo6000o`000`0Xb3`0D91h0:0Pl00R0:0Pl00307QH]00X
b3`00?l001T00?l02oooool000[ooooo0P00o`00D00YgA00ak2L0=3>c`3DdM@0?2X/03462P0l0`P0
C@<707X31`2K1`L0_DD<0=RV1`3FT@h0/1d10<8:1`3110H0b`L90=092P3B2``0e@`=0=492@3C2PT0
_PX:0;H[9@3>=2X0c``90=8<203C3@T0eA080=HC2P3G5@X0fQX<0>d]7@3^<b40`cDZ0;^OV03bk^/0
l>o/0?7`k`3il>h0gZNT0=mnO03TOG/0hg]f0=I/JP2fDDl0/d0m09lW7`2N7100W18709L<102C2080
T0D309441P2B0PH0W08:09T22@2G0PL0U@8609D2202B0@D0S`8507l2101a0@40K@4106l10@1^0@40
K`8107H20P1i0P@0N@4707811@29:Bd0W45706X;3P1L0P80F0820583001Y6@808Ld11P00o`09oooo
o`800?l000<0D91h0:0Pl02P8?000P2P8?000`3@D7P0oh000?n000030?n000030=1@N03XJ3`0oh00
01D0oh0000<0^3Rd0?n0003oP000:@3oP0000`1@T7P00?l0003o0004003o00Sooooo5@00o`00;@0G
l0/0A]@T07Jm@`2kY7D0cjR<0=JdVP3N_j/0f;j]0=g:^`3Kb[h0im[@0=c=a@3Qe<h0h=G?0>CLf03K
dM00i=[K0=gEd`3Bc//0c/W:0<[6b`2e^lX0KhFQ07J:XP18Hh@0X[O<0:k2d@3CfM`0dmKH0=;Ff@3A
eMP0cm7E0<c?d`3:c]80bLW>0<?5b039c<l0d=?E0<c@d`3;c]00blW<0<>i^@1Z/V80=;XS00Od0`0G
003o00Sooooo5@00o`000`0Xb3`0D91h07QH]00X0:0Pl003052@N00Xb3`00?l001H00?l02oooool0
00[ooooo0P00o`00D01fORh0dl[90<k?dP3De=L0F4]>03052@0n0PH0B`4707L42P2E1@P0/CH<0=RR
2P3FT`d0/2810<@;1`361P/0a`L;0</8303:20P0aP@40<<20@350`<0d0/;0<X920343PH0aA/:0<LX
4P3;>B80dE8g0=U/D@3QP6H0jIAm0?Zl[`3jb;d0nM;:0?7Tg@3`kNX0l>k/0>o]k03cl>l0m^kZ0?W]
j03ij^H0n>_U0?[[iP3jj^D0nNKO0?3Ca`3V`:d0hKFM0=ZWT03BVH<0ah5/0<5[F@2C6AH0U`<909L2
1`2E0PP0U@4809H11`2D0PP0S@4807L10P1a0@40JP4006h1001_0@40KP4107010@1d0@80M@430741
101/1PT0WTI>0:ABFP1m:bd0EP8404h10@1S3@<0<ih01P00o`09ooooo`800?l01@2P8?000`3@D7P0
oh000?n000030?n00080d51h5P3oP000103@D7P0oh000?n0003@D7P80?n000D0d51h00<0j6Pl0?n0
003oP000603oP0000`1XZ3`00?l0003o0004003o00Sooooo4P00o`00<@0RjA40AM<U07Bj?`32Ug00
bZJ40=2_U@3A]Il0e;VT0=^lY`3I_jT0glZf0>7@`@3QdL<0h]C80>[Pf@3Uf]H0imoN0>GNf`3Vg]`0
hmSG0>7He@3Wh]l0em?@0;Vj`033a<X0VJRj09V]_`2L[l@0EGBJ06N4W`3>f^@0e=OL0=;Ff@3CeMP0
d=?G0<oCeP3>dM<0c<kA0<W>d@3:dM@0d=CG0<oCf03:c]<0a/_?0<[<dP1cMhX0I6ai07N?I@0JiA80
5P00o`08oooooa800?l000<0:<Pl052@N01hF;@0;@2P8?000`0Xb3`00?l0003o000D003o00_ooooo
000:ooooo`1B003o000Zf0d0LS<O0<W0_`3?cm@0dmCH07eeN00^1PT0>P8804P21`1_10P0R0840:h^
2@3HW``0eY<=0:`S002n20<0_@D90:/10`2h0PD0`@<50<420`330P<0b0D60=0;3P2m2P`0SB@K0>J]
T`3/a;80jlk00>[Fb03Zfm80k>;L0?;[i`3ck^/0lN_Z0?3Yi`3bjn/0k^c/0?3]k@3bk^h0l_3b0?7`
l@3eko40mng`0?G/k@3fk>h0m>c/0?3Wj03/hN80iMOE0>CFd03Re/l0hMK?0>;Gc`3/eLh0WTm:08d7
2P2?3100R@@;09022@2F0PP0U`8808d2201g0@80L`8106h00@1_0P40KP4107410@1b0@40LP820701
0P1]0@80MA<C0:EAE`2XGVL0TdU=070Q9P190@@0E`L405U70@H00?l02Oooool00`00o`00D91h0>QX
?0040:0Pl0030=1@N03oP000oh0000<0oh000P3@D7P<0?n000@0d51h0P2P8?001`3XJ3`0oh000?n0
003XJ3`0oh000=1@N03XJ3`0203oP0000`3XJ3`0X23`0:0Pl0050:0Pl0030>QX?03oP000oh0001H0
oh0000<0d51h003o0000o`001000o`08oooooa000?l003@0>=XM07>i?`2bVfX0`Y]k0<JTQ@3>[Y@0
c[6J0<jcV`3F_JD0fKn[0>78]P3Pb[T0i=:n0>OGb03]g]D0jmgB0>cQfP3Zh]`0j>3J0>7Hd`3Vh=`0
gm_H0>7Lf03Kem80h=cL0=gEe@2`/;D0VJ2a069eTP2^^/`0NiBa08nZa020W;@0dMKM0=7Ff@3@e=L0
d=?G0<oCf03;d=@0c=3D0<_?dP3<d=@0c=7F0<oDf03=dmP0b/oC0<W>dP2g_LH0HW>806alS@2<UXD0
<lLQ5@00o`08oooooa000?l000<0D91h07QH]02P8?00<02P8?000`1hF;@00?l0003o000C003o00_o
oooo000:ooooo`1301O`2@2bNU@0HQhC0:29QP3@d=<0d]7G09>?T00Y1`/0=@8804L3201S0PH0QPL8
0:4S1`3IWPd0eY<<0:XQ002o2@H0a0L=0;/42@2j0@D0`@<70<02103210D0bPT80=4;3@312`h0L1HD
0=k6^P3Tf=80iMSB0>_Hc`3afM<0mmgN0?gNh03nfm/0o<_<0?k6b02ePH@0_:n_0?3/jP3ak^l0lNo`
0?;_kP3abLd0jYVO0=>2RP3?Q8d0eHbC0=2@U`3>UIX0ciNI0<FBR03:W940dZbU0=k3`@3UbLT0]W1^
0:Dg=03FL6l0bf9U08T;4@2A0PP0T`4608T1101i0@80M@4107000@0206h10@0=07020@1c0P80M042
07010@1]0080K@h@0;=]L@1T8b/0/g5i08Y0BP1C3a@0D0@306dI0`06003o00Wooooo00<0D91h0:0P
l03oP0001@2P8?050?n00080d51h303oP0040:0Pl0030=1@N03oP000oh0000<0oh0000<0d51h0:0P
l03@D7P02`3oP0050:0Pl1X0oh001P00o`08ooooo`h00?l003L0;>0F09>QD@2jU780`9io0<FUR`38
Yhl0cK6H0=2fX03B^J@0eKnZ0=c7/P3Ob[L0hLbi0>;=^P3YeL<0jMW70>[Gb`3^gM80jMW=0>OIcP3W
fm<0j=kK0=gCc@3RgML0hM_G0>7Fe@3Ne=80elk;0=[EeP38a/T0[[C106AeS@24U:l0SZ>n08^R]`2k
cmP0d]KK0=7Ef03?dmD0cM?E0<cAe@3<dM<0bloA0<k@e03<cm80cM7F0<c@e@3;cmH0b/cE0<C6cP24
T:40O8jP09FOZ02dZZP0;]DR01@00?l02?ooool>003o0003052@N02P8?00X23`03<0X23`00<0D91h
003o0000o`004P00o`0;ooooo`002_ooool0A012dAl0YWiW05lJ4P2GMG80dM7D0=7BeP2VY:L09`P>
03<3200o0PL0E`<707810P2K80H0fYh>0=VG3P2Z9@00_`X70<D62`3210X0^`460;l21P340`P0a`D9
0<l:303I3Pl0eA4?0:TD4P3_Xil0jjZT0=B8OP3>LfL0e6iW0>1dL`3PKV`0hFi[0=mJF@3JBdP0aU]E
0:R6P@3bj^P0lNo`0?7`l@3`knd0k/?20=IXIP2l=3<0/adP0;4N8P2J;c40YeME0;ETH@2[Ed`0WdTm
09E1=P2KBDH0UdA309<];@2aBTX0_VIX0;9KH02T>400S@<:08h220280PH0NP4207H10@1c0P40L082
0P1_0@403@1b0P80L`4207010@1_0@80I`<506/I7`25?TH0UU1J0:QRJ`1Q6b80DP@406`E1@0Ob`00
1@00o`09ooooo`03052@N02P8?00oh0000D0X23`1@3oP0020=1@N0h0oh0000<0j6Pl0?n0003oP000
1P3oP0000`2P8?00oh000?n0000Y0?n00003052@N000o`000?l000<00?l02?ooool<003o000]03OJ
7P2YTel0^YA^0;bIN@2mWX<0`JF>0<^]U`3@/id0dkVW0=O0/03I`k80flRf0=[8]@3Qb[L0h/^i0>?=
^@3Wdl80i]?00>_Ha`3Xe<H0jmW:0>SGb@3Wf<`0i][B0>;Gd@3Qf=40f]7<0>WPg@3Ndll0e/g;0;>a
^P2STJH0fJFa0=>GYP39QY<0HT]W086D[P2F[/40cmOK0<kDf03:cmL0d=;F0<cAe03;cm80b]3C0080
c<oC00/0c<oD0<_=d`37c=40b/cC0<W:d@1hNX`0CEmh07V:V@2SZ:l0WYn=02;I5P0C003o00Sooooo
3000o`000`1@T7P0X23`0:0Pl00M0:0Pl0<0d51h00<0^3Rd0:0Pl02P8?004`2P8?000`1@T7P00?l0
003o000A003o00_ooooo000:ooooo`1C06R`=@2QQGD0J2LQ0:n:SP3@dMH0d=;F0<;3aP0N2Ph0:044
03T3201D0`P0N0D709XN1P3MXA40g9d@0:TX0@2o2PL0a`L;0<D62`300`P0b@L<0</82`3:20P0e0`<
0=`A3P3O71<0hRdP0<lV802d;2D0aVAH0>6JS03e_KH0nlo70?cJdP3lhM`0ml6n08dn>03egm@0mnkY
0??ak@3bko40knk^0>o_k`3`k>X0nN[U0?[Dc@34Ge`0NalL0>34_03aiMl0l^OS0??Tg`3dh]d0l][F
0>g>b03Z]k40W3<c0:8X;@3;L7H0dWR10:XkA02>0PX0T04908T11P1k0@<0M04107<10@1`0@40JP41
06P1001]0@40L`4407@10`1^0@80I`4306821@1O0`/0KQDO07XW<P1c92d0HPP;06hA1@0mTP001@00
o`09ooooo`0407QH]02P8?00j6Pl0;Ph]0@0X23`00<0d51h0?n0003oP0000P3oP0020=1@N1D0oh00
0P3XJ3`90?n000080>QX?02h>;@0d51h0=1@N03XJ3`0d51h0>QX?03@D7PK0?n000030:0Pl000o`00
0?l000<00?l02?ooool;003o000k06Zc=`2eT6T0^IAb0<6QP@33XXL0`jJ?0<V]V03B]:80e[NV0=nj
[@3M]ZP0f;n/0=[5/P3Ka[80hLjl0>7=_P3Vdkl0jMK60>O@_@3Yd/00j=?00>[Gb03Ze/L0k]g@0>;B
aP3Ld<P0g]CA0>GKfP3Nc//0g<c90>CIf@2`Zk`0JcaY0:<P?02i52@0_A0L0<AMK@2X[L40FWND0<GD
gP32bMH0Heem0=FhaP3Bc]80b/oC0<K>e`38cmX0bm7E0<[?d`3;c]D0b/kC0<S<d`39b]40/Jnl08:=
XP2=WJX0Y[:h0:j//@2VSH@04`00o`08ooooo`/00?l0802P8?000`3@D7P0oh000?n000020?n001H0
X23`4`00o`0;ooooo`002_ooool0D`22Z4`0WH^106di=P2ON7l0c<gB0<kBe`31aLL060h?01L0000^
0PH0CP4506d1102D7@D0gZ0B0=VM3@2[;000_@T50<@72P361`d0aPD:0<d93P3=2@X0d``<0=P>303L
4`l0galE0>8e:02M7QD0ciB90?GOf@3ajnL0kng[0>k/j`3^kN/0mNo^0?SPg021BD00dkn`0?7[iP3b
lO40mO7b0?WWjP3[gMl0k^_Z0?3]j`3`jnP0iKNd06@]:`3Yh]d0jNWX0>[ZjP3/k>`0j^[[0>KVi`3Z
jNP0l^GT0;9WJ@2F20h0U1@P09dT;`2=2A00TP8809@2202<0PP0O04207L10@1e0@40L00206/10P1[
0P40J`4206d10@1`0@40KP8306D11@1Q0@L0I@4906X32`1e51/0PbXa06H72P1Z3PH0>Xl000D00?l0
2Oooool20:0Pl080d51h1@2P8?000`3@D7P0oh000?n000020?n000030=1@N03oP000oh000100oh00
00D0d51h0?n0003oP000d51h0:0Pl0040?n00080X23`0`3oP0000`3@D7P0X23`0:0Pl0050:0Pl003
0?n0003@D7P0oh0001P0oh0000<0X23`003o0000o`000`00o`08ooooo`T00?l003h02oP606bc?@2`
SF/0]iAe0;fJO`2oX8H0a:JB0<naW@3J/Z00fZNF0<F7N@3FRWl0dHEf0=ZiX`3G`:/0flFa0>C@`03P
c;/0hLji0>SD``3Vc[d0j=6n0>S@_@3Zd/80j=710>OB``3Od<L0ako50<BFYP3GPhd0gWV00>B8TP3Q
TYP0fZFc07Y4K02`?eh0_Q8O0<T:4P2j82h0Ie1a08>F/@2``]<0VYje070[C@2P8cT0_Fam0;B4UP2;
Ih00KDeU0;Vb^@3@d]L0c<kD0<S<d`37b]<0b<_C0:V/]P1=F6h0EfMi09^X/@2YZ:l0Y9>D03G99180
0?l02?ooool9003o000302S8?01hF;@0X23`00D0X23`00<0^3Rd0=1@N03@D7P00P3oP00?0:0Pl003
0;Ph]03XJ3`0oh000080oh000P3@D7P40?n000070;Ph]02P8?00X23`0:0Pl03XJ3`0oh000>QX?003
0=1@N0`0X23`00<0D91h003o0000o`004000o`0;ooooo`002_ooool0AP2D[6<0VXf:07E9B@2=GfD0
bLS=0<[?d`2m`<009AdN00l0000X0PH0A`8806031`1n5`<0filC0=ZN3`2[;000_`/60<D82P371`/0
b`T;0<l;3@3@2@/0e0/<0=P>3P3J4@h0g1@=0<hG5026@Sd0lN7I0>o[j@3^kNd0k>c/0>g/k@3`jn/0
mNSV0?cQf`2[K5h0Zhem0>SLe03Whn80l>SV0=R@U02D?T00d;Zj0>c[j`3[jNX0lm_K078c<`31/Jl0
j>SV0>_[j`3[k>`0j^WZ0>WWi`3Wh^40kn?S0<^CT02I2``0W`@;09P22P2F0PT0U08909012@2;0@H0
O`4307/10P1j0P<0LP4206l10@1^0@8206`10P0;06l10P1b0P@0IP4505d11@1T0@L0J`<906d73@1_
2a40J0P;06@:101f9`401@00o`09ooooo`80X23`0P3@D7P50:0Pl0040=1@N03oP000oh000?n00080
d51h303oP0040=1@N0030;Ph]02P8?00j6Pl0080oh0000P0j6Pl0:0Pl02P8?00X23`0=1@N03XJ3`0
oh000;Ph]080X23`00<0oh000>QX?02P8?001P2P8?000`3@D7P0oh000?n0000I0?n000D00?l02?oo
ool7003o001001;]2P1/Tcd0WheO0:j<L02bTGL0^IQo0<BUSP3;Z9@0e::C0=B9O02oFD`0dVUD0<UZ
DP3BL5`0dG=Q0=fdWP3I`:X0g/Nd0>3:^@3Qb[T0glVf0>O@_P3Sb[H0i<Ze0>K=]`3Yckh0jM2n0>GA
aP2ASJP0ZDQ[0<dS:P3A8Ah0cB4Q0</R9P377BH0`Qh/0;dQ=03?;cd0bQDK0</83`312Q40]E]/07aW
Q@1RBFl0RCIB0:T?7P2a0`h0[0@?0:H74P2G5AP0YEeK0=G5a`3=bl<0c/_10<[=d038c=@0aLWC0;o1
b`1XKWd0KW^708VCVP2RXjP0WiZM07BVHA800?l02?ooool7003o000302S8?02P8?00X23`00D0X23`
00<0d51h0?n0003oP000103oP0000`3@D7P0X23`0:0Pl00;0:0Pl0030>QX?03oP000oh0000T0oh00
00@0j6Pl0:0Pl02h>;@0j6Pl1@3oP0000`3@D7P0X23`0:0Pl00;0:0Pl1800?l02oooool000[ooooo
04D0^IYl09N>S@1nG5X0M3m10<W3b@36bLd0/[Fe03hg>@0D0@80;@<904<22@1L0`P0OaH40=RN4`3K
WA00ZBT00;h:1@362@T0a`T80<T82@3>2PX0d0/:0=@>2`3H3Pd0fPl>0=`A3P3D5A<0NR8R0=:o_@3/
jNP0kno^0>k]k@3_kNd0i/_:0=YnO03MGed0bT4j08A?A03Uf<T0kncX0??`k@3TYJ<0]CHc0:IgL`3`
j^P0jn[Z0?7Wi`2bIFD0PBda0;bPX`3ZinL0j^[Y0>[ZjP3Vh=h0`I:C0;5TI`36J6T0XPlA0:T42P2Q
0@L0V@860;/P902U4QP0S@4508H2101n0@40O04207T20P1e0P800P1a0@40301a0P40L@420741101Z
0@D0G`4506411@1S0PH0IP@806H2201Y1P`0Ia8;07Ta3PD00?l02Oooool20:0Pl0030;Ph]03@D7P0
X23`00@0X23`00@0d51h0?n0003oP000oh000P3@D7P<0?n000070>QX?02P8?00d51h0?n0003@D7P0
oh000:0Pl0030?n000030=1@N02P8?00d51h00<0oh0000H0d51h0>QX?02P8?00d51h0?n0003XJ3`5
0:0Pl0030;Ph]03@D7P0oh0001X0oh001@00o`08ooooo`D00?l004<02OH505>R<@14C3l0ADA=0:J:
M@2]SgP0/9F00;^OS03<ZiP0_W=T0<MWE03<J580f71M0<IG@P3=GTP0bFI;0<]jH`3R/Y`0fl2]0=c3
/`3Na[@0h<Vg0=k8/P3Uc[T0hlbe0>C<]@3Wc[P0jM2l0>W?^`3Sc/D0I5V50;TcA03SKeh0ij:E0=RW
X@38W:00b9NT0;9_P02MBEd0V3Q=0:PY>`322a<0a`H>0;h=6@2c5B80/0dJ0;<63P2d0P/0/@@;0:X:
2`2S8Qh0`hR20=G;b@3=cm40b<>Y0<2^J03?ck/0algB0<K:e037bMD0MgV9065/N02>VYl0[[>f0;6`
]@2UVIP01o@401400?l02?ooool5003o000302S8?02P8?00X23`00H0X23`00<0j6Pl0?n0003oP000
1@3oP0000`3@D7P0X23`0:0Pl00;0:0Pl080oh0000<0j6Pl0=1@N03@D7P0103@D7P;0?n000030=1@
N02P8?00X23`00`0X23`00<0:<Pl003o0000o`003`00o`0;ooooo`002_ooool07P2jVh40YYjN081U
H`1O92X0bko70;o3a`2][[00D4Y;01L2100[0`/0?04805D22@1l5@H0eidC0=RK3P2X9P00_PT40<H9
203820P0bPP90<h92`3A2`X0dP`90=H>3@3I3`d0fa4=0=hD3`2l61P0JAHK0<Rc]`80kNk^03<0kN_/
0?OWi03XUXl0aC4U0=@U6`1m;BL0g<bn0>cYi03^k>`0j<700:<b<02CDTh0lnWV0>gZjP3^jNT0d8j<
0:dK7P1n5Qh0/YBG0>SVi@3[jnX0j^SV0>Jl^02J=C40Y1<F0:/62`2Z0`P0YP8:09d31`2]6R00V@XA
08l22@2?0PD0O`4107X10P1g0040M`4207<0001b0@00L@4107410P1c0@D0K08505`10`1K0@<0H@88
06<31`1U0@L0I`@;06HE4@3;ZI`01@00o`09ooooo`<0X23`00<0d51h0:0Pl02P8?000`2P8?00103@
D7P0oh000?n0003oP0020=1@N0h0oh0000@0X23`0=1@N03@D7P0X23`103oP000103@D7P0X23`0=1@
N02P8?020?n000040=1@N03oP000X23`0:0Pl0<0oh00102P8?0L0?n000030:0Pl000o`000?l000<0
0?l02?ooool5003o001305ej?00L8c`01QY>02XfF@2SSh<0[IJ30;RMSP2kWhd0`:290<N3L032F4H0
bUm90<EKAP3ITGL0f:>70=J]T`3@YI00fKJO0=_0[P3L`k00g<6]0>;9]`3Ma[<0h/^d0>C<]03UbkD0
il^j0>S?_03VdKX0i<jn09N9V`33SY80ilFa0=g<^`3Jb[h0hmSE0=[?c03Ea/H0eL_>0;nld@1HCGT0
ZB@m0<P840341@`0`B@K0;8b:P2V;2/0ZcTd0:mBBP30QGd0dkjk0<k=c`3:c]40bm3E0<kAc`37^i40
`kAi0<c=`P35bm40a<WB07n3T`1AF6T0L7f50:fb]`2c/[T0Zj>Y02G<6`0A003o00Sooooo1@00o`09
0:0Pl0030>QX?03oP000oh000080oh0000<0d51h0;Ph]02P8?003P2P8?000`3@D7P0^3Rd0:0Pl007
0:0Pl0L0oh0000<0j6Pl0=1@N02P8?003`2P8?000`1@T7P00?l0003o000?003o00_ooooo000:oooo
o`1C0;^RR02CTi<0T7in04dD6@30/KP0^;^o0:jb/@1UHf006`L902X42`0o0`d0B04906L?0`3CW1<0
f9/?0:LU002n2@D0a`P80<X82`3<2@X0c@P:0=4:2`3C30/0e`d=0=`A3P3N4Pd0hA<>0>4G503;71d0
Vbhd0<2TZP3Zj^T0k>c]0>c[jP3ehmd0jJZL0=1?@@2771H0_J>I0>kWhP3_k>d0l^3P0=FHU03<WYT0
lNOU0>k[k03/jNX0iKJd0;@K6P2i5AP0SR@Z0;bXZ03Xi^<0j^WY0>gUhP3X`[d0/DY60:X92`2]10P0
Z0480:H83P3:Be00T18D08h21`2C0@H0QP4307X00@1i0@80N08107<00@1c0@80L@4107810P1b0@<0
JP8305`10P1H0@<0F04505d21`1P0@D0I0D8064@3036Y9L01@00o`09ooooo`<0X23`00<0oh000:0P
l02P8?000`2P8?00103@D7P0oh000?n0003oP0020=1@N0h0oh0000<0j6Pl0;Ph]02h>;@00P2P8?04
0?n000030:0Pl03@D7P0j6Pl0080oh000P3XJ3`00`2P8?00^3Rd0?n000020?n000050>QX?02P8?00
X23`0:0Pl02h>;@06`3oP0000`2P8?000?l0003o0003003o00Sooooo1000o`00A01kXdX0LFI/00HG
BP025eh062UO09j?R`2`UhD0/iB10;JGO@2lWH80b8ii0<5D@033G4H0aWEL0<bGN`3>Zhl0cJbC0=:h
Y03MakT0f[n^0=VoZ`3K`Zh0glVc0=k5[P3Rb[<0i<^i0>?9]03UbkT0i/nk0>K?^P3Vc[/0hL^m0=k:
^03Ja[80hLJh0=o0]03Va/00i/C20>o7bP3IYZX0i:jf0:edSP2^<Th0a0PA0<862`30:Rd0UT==08iC
I@3<WjX0fkNm0=O1b03Fb<l0dL[@0<k;dP3;c=40bL[60=39Z@35/EP0c;ej0<_<`P36blh0XjF`069X
MP22SIL0WZ>]0:BV/02ZZ[80@kXk4@00o`08ooooo`@00?l02P2P8?001@3@D7P0oh000?n0003oP000
^3Rd01@0X23`00<0^3Rd0=1@N03@D7P0103@D7P40?n000040>QX?03@D7P0d51h0;Ph]140X23`00<0
D91h003o0000o`003`00o`0;ooooo`002_ooool0D`2kXXH0VIRI09J;R`144Q<0ZYNI0;Vk_`33b<X0
Rhf?01d;400Z1@`0?`D:04L11P1U3`D0cYDB0=JE402X8000_PX60<P9203:2@T0c`X:0<`82@3A2``0
dP/<0=P=3P3K3`h0fa4<0=hC3`3S5A40jATB0>4L5`2S9B<0Yhf:0>SSh@3[jNT0jnWX0>gTh03a_[@0
YBhW06`l>@3[h]l0jn_[0>c[j`3aj^P0lNWX0>gZjP3/j^/0k>_[0?;If@2_=C<0ZQLA09d`:@2ONG80
hMOB0>[ViP3Wi^L0jnGV0>S5``2Q9R<0Z@D90:T42@2V0PT0W`<:09h42P2F0@H0UP8809@21`270@@0
O`4207P10@1e0@40M`8207<10@1e0@80M@8406/2101N0@@0E`4305D10`1K0PH0H04606@4201U3``0
c:RL00D00?l02Oooool30:0Pl0030>QX?02P8?00X23`00<0X23`00@0^3Rd0?n0003oP000oh000P3@
D7P@0?n000D0X23`0P3oP000103@D7P0X23`0:0Pl02h>;@20?n000<0X23`00D0j6Pl0?n0003oP000
oh000;Ph]0040:0Pl0030>QX?03oP000oh0001L0oh0000<0X23`003o0000o`000`00o`08ooooo`<0
0?l004D0J;M50:>DQ01lMgl04REJ008HIP0=7UX0W8f;0:fAP02cTg`0^9Ek0;^JP02kPFP0a7YL0<jK
P@38YH`0aZVA0<JYT039[9<0flfn0>OMfP3C_Jd0f/6_0=[4[`3La;00glNa0>38/`3QbkL0hLZe0>?<
^@3Sc;/0i<jn0>C>^P3Sc;T0^k>_0:28U03?FE/0dd530=4e>`3>:C00bb0V0<TH703;6A`0aQDH0<@?
50342@h0`PH<0;d4302d1`l0[@TB0:H:602S3Ah0XADV0:<R<`2U=D@0ZTQH0:YUL@3?_:h0_jaQ0;fS
5P2mYA40`:i:0<:lR030_:`0Fe]R06=[MP2EWJH0XJ>[0:NW[@1UZU/04@00o`08ooooo`<00?l000<0
N5Rd0:0Pl02P8?00202P8?000`3@D7P0j6Pl0=1@N00E0:0Pl1@0oh0000<0d51h0:0Pl02P8?002`2P
8?0A003o00_ooooo000:ooooo`1C0;jTQP2LVYH0UXj=058O7P2JOH00`l?80<gAe@2XZjl06a0B02X9
300k10X0D@D;05h<0`3AV1D0eY8?0:`O0P312@P0b@T<0<T92@3?30`0d@/<0=4:303D30h0eP`<0=T>
3`3G4140dPl?0=L@2`3L6QD0^bHN0=F<P@3ZfM@0jnKT0>_Yj@3/j>H0l>7O0?K0_P38=S80J`h=0<Nb
[P3/j^P0k>WX0>gCd`2/J6d0UG=c0>oYiP3/j^X0kNCQ0:aVH`1;2`L0fl>j0>_Sh03Yi^D0iNGU0>?Q
hP3Tgn00iM7A0:94@02G0`L0V`4609h1202L0@L0VP4709@11P2A0@D0U04609011P280P<0O04307T1
0`1h0@80M04207D1101d0@D0K@4306<10`1I0@@0E04505411@1G0@D0G`<606091@2IECX01@00o`09
ooooo`<0X23`00<0d51h0:0Pl02P8?00102P8?030?n000030=1@N03XJ3`0oh0000l0oh0000D0d51h
0:0Pl02P8?00X23`0=1@N0030?n00080X23`0`3@D7P01`2h>;@0d51h0;Ph]03@D7P0j6Pl0?n0002h
>;@01P2P8?0I0?n000030=1@N000o`000?l000<00?l02?ooool2003o001605jm>`2YWI<0YYbG09RB
V00>7Dh011MP00LFCP2?PH80ZXam0;2@O02fUG`0^YN00<2MP`31WX@0]Yb909J5M`28O740T8Ih0;fX
TP3B^ZP0eKj_0=JlY`3J`J/0fL2[0=[3/03Oak00glJb0>3:]P3Pbk<0h<Vc0>;:]P3RbkD0hlbf0>C>
^03A`Kd0KUim0;he>03?:A/0dCHT0=E3=@3FDD@0eUa@0=9OE@3>HED0ZTQ=09lO=@301a40`08;0;hR
7P2eBd<0XdM30:91?P2W>CL0XbPZ0:4L7@2L51T0TA8I0<>GV@3AcL40_ZY;0;nU1P2kX0H0/Yd=0;>N
7`1ZGRP0Hfih08fIX02`/kT0XZ2V06^OHA400?l02?ooool2003o000307QH]02P8?00X23`0240X23`
203oP0000`3XJ3`0oh000?n000030?n000030=1@N03XJ3`0oh0000@0oh0000<0d51h0:0Pl02P8?00
2P2P8?0A003o00_ooooo000:ooooo`1C0;jQP`2NViP0VI>D05XZ:`2BLWH0bL[@0=3Ff`2i^l007Q@E
02`:3P0j10/0F0XB05`=103BVaD0dX/=0:hL00322@H0b0P;0<T62P3>2P/0d0X;0=092P3C2``0eP`=
0=P=3P3I3a00fA4>0=XE4@2c51<0WUiJ0?;Th03[jNT0j^SX0>OVi@3Xd<l0lZf]0=UEE`3N9B80WATG
0:60O03^jnT0lNg/0?gPg`2eC4d0O3@c0>kQgP3Zi^H0k^WX0<NCT`1;3``0b;bg0>SWi`3Wi^P0i>;S
0=kEd`3>][00`hj7098M6P2E0P@0T`0209D11@2D0@H0T`0709<11`2@0@@0U085090110280@D0O@43
07P10P1f0@80M00107H10`1f0PD0K`4206410P1J0@<0E@4404d1101@0@H0EP4405h70P26<A401@00
o`09ooooo`<0X23`00<0d51h0:0Pl02P8?00102P8?030?n000030=1@N03oP000oh0000d0oh0000<0
d51h0?n0002P8?000P2P8?000`3@D7P0oh000?n000020?n000030:0Pl03@D7P0oh000080oh0000@0
d51h0:0Pl02P8?00d51h0P3oP0060:0Pl0030=1@N03oP000oh0001P0oh001@00o`08ooooo`18003o
000XgaH0]JFH0;2][@2/Z:T0WiRN02hfFP0355H011AA08=fO02XRgP0[Xmj0;:DN`2fUgl0^Yb10;RO
Q`2<OW00Z9J50:BCQ@1bK6H0V8f10=:hX`3D^j@0ekjW0=RmY`3H_ZL0fKnZ0=k6/03K`k00hLZh0>;:
]P3Sb[H0hLZe0>7;]P3RbkP0iM2k0>3<^`3?^:h0fk:T0=FYW`3M[9l0k;BX0?Bm^03QYZ<0f:NR0;>N
XP2ZT:D0XCMB0;h94`311@/0]ATN09Y?H01gJXD0SIV[09^EYP37YJh0e[6b0=6[[038X:00`:j`0<_?
d035^H<0_JD<0:>>401iL0`0[Yh>0:NF8`24PVP0UYbL09nTY`2MWZ<0SGn14@00o`08ooooo`03003o
001@T7P0X23`02<0X23`0`3@D7P20?n000040>QX?03@D7P0X23`0:0Pl0@0oh0000<0j6Pl0:0Pl02P
8?004P2P8?0A003o00_ooooo000:ooooo`100;nSP`2NWY`0UY6E06<m?@22GF80bl[A0<oGg038bm00
81/M02T93@0d0`X0@`4805d>1@3EWQD0dHL@0:dH0@332PL0a`H90<X62@3>2PX0c`P;0=8;303A2PT0
e@/<0=T>3`3J3Ph0gQ0?0=lE4P2/4a40QeaJ0>cWi`3[j>T0j^SW0>WWi03ValH0cVeZ0=Pd;03X8a/0
bRHT08]ED@3/j>D0k^_Y0?SVi030IV@0PRTT0=6l]`3/jNL0jnWZ0>Fj^P2=;2X0Qe1A0>7JfP3UhN<0
h=_N0=c>b`2mTHD0TblT09@5102I0P<0UP8309<1102B0@L0TP4909012@80T0450140R`4408H00`2F
2`h0Zb`^08PE5@1c0@<0LP4107d5201a0@@0H`4205`00`1G0@@0C04304d0101H0PL0G0D208dg6`05
003o00Wooooo0`2P8?020=1@N0D0X23`0`3oP0000`3@D7P0oh000?n0000=0?n000030=1@N02h>;@0
X23`0080X23`00<0d51h0?n0003oP0000P3oP0000`3@D7P0X23`0;Ph]0030?n000<0X23`0P3oP000
0`3@D7P0X23`0:0Pl0030:0Pl1/0oh001@00o`08ooooo`19003o002<ZfL0[:Z[0;>e^@2XYZ/0V8nG
05mPNP054d`0119?07U^MP2RQW@0ZHag0:n@M`2eUWd0_9^00:NBO`24Ng80XiB709B:PP1`KF`0THMm
0=2fX03E^jD0e;^T0=JjY03H_:H0fKnY0=g4[`3Ka:h0hlZg0=o9^03PbkP0h/Zf0>?:]P3Qb[D0i<nj
0>7:^@3Ja[X0R8VJ0:UUNP3;>D80d2H[0<hM903:6A`0]adN0<1fP`1S?f`0/a8S0<H63@2n2@/0[PTB
0:X75P2U=dH0G4m^07/eE02I3ah0VQLT09/R<02L=T@0`9bR0<[>d033]g`0_JD:09j95`0J6@D0GUdB
08b24`2OTQd0V8hj0:VSM02VYIL0ViBD01?M300@003o00Sooooo00<00?l00:0Pl02P8?00902P8?00
0`3XJ3`0oh000?n000030?n000030>QX?02h>;@0oh0000D0oh0000<0X23`0=1@N03oP0000`3oP000
0`2h>;@0X23`0:0Pl00:0:0Pl003052@N000o`000?l000h00?l02oooool000[ooooo05<0_J>20::V
Y@2BU9H0JTm?068k?P3CcmD0cmGK0<oFf@0Y:2/09@P?03H43@0k0@P0G1450=JQ5`3>PA40[aD10<89
2@361PT0b0H70</82P3?2@/0dP`;0=4<203G3P/0fPl=0=d@303N40`0hA<@0=PE502J5QT0/HZA0>OQ
i03YinP0jNOW0>cXiP3fi=l0kjnU0=Xo=@3A8Ah0NbDT0>SNf`3]jnT0l>WW0>K5_P3GZJ00e/Bk0>cW
i@3[j^/0lmcL0;9AC@2U6Q/0S4E;0<Jc]@3LeMD0g=OG0>;Cc`3@WI80UQhG09@20`2A0@<0S`430901
1@2A0@P0TP8909821P2<0PD0Q08608l21P2a1@X0ZPD70:PC5`1g0@80M08408H=3`1b0@@0JP8406<2
0`1J0PD0C@4304X00`1C0@H0G`D208db6@05003o00Wooooo102P8?000`3@D7P0X23`0:0Pl0030:0P
l0<0oh0000<0d51h0?n0003oP0003P3oP0001@2h>;@0X23`0:0Pl02P8?00^3Rd00@0oh0000@0j6Pl
0:0Pl02P8?00d51h0P3XJ3`30:0Pl0040>QX?03oP000oh000>QX?0@0X23`00<0^3Rd0?n0003oP000
603oP005003o00Sooooo04T0<=DK0:RTX02_][T0/[Bh0:VVZ@2HSY80L6n600XGD0034dl0LVQb0:>6
J`2[S6P0/Hm/0;FDN02kVH00YX]m06m[J@1jMgH0KVi/06MVHP2`X8l0ckBN0=:hXP3D^j<0e;RR0=Jk
YP3H_ZT0f/B_0=[5[03QbK@0h<Nc0>;9]`3SbKL0hlVf0>;:^03Rc[P0h<fi0=W8`P1DGH@0]DaN0=LG
5`3L4a80f1LC0=Y8>03?E440bgIZ06YKO@2P:dL0a0T?0<Ld<P2>AeX0S`/W0:d84P2;@5D0JcA<09h:
502Y0P/0Y`8;0:08302LA4T0dlk>0<:gQP2lYAT0[iLB040a2P1DCQh0:2D206YW5P2MSQ80[9/A0;>U
@P2PTfh07=HB01000?l02?ooool00`1@T7P0X23`0:0Pl00T0:0Pl0030>QX?03oP000oh0000@0oh00
00D0X23`0?n0003oP000oh000>QX?0020?n00080d51h103oP0000`3XJ3`0X23`0:0Pl00:0:0Pl003
052@N000o`000?l000h00?l02oooool000[ooooo05<0`:B30;Jj^P2BUiP0KEUI05<[:`3HdMD0cmCI
0=GKg`0i>cl08`L?03D22`0m0@D0Fa430=2N6039N@l0/1<00<0720341@T0a@L:0</82P3@2`/0d0`;
0<l:203C2``0f@h=0=d@2`3L4@/0gQ0>0>4A4@3L5QL0VaLM0:^1S03Qfmd0jNOX0>[Yj@3/k>/0lNWW
0>FDSP2o8Ah0QaHE0=?3_`3/jnP0k^cZ0>WVi03[i^D0kNSV0>k/j`3Xi^P0kn;Q0=bCT02e6AT0XQ0G
05dB5`2dXIh0f]OD0=[FeP3Qdll0_Wab08l8202B0PD0T04408d1102?0@H0T@4709421`270P@0M@42
08L21@2`0PL0[P020:X210280P<0MP4408dI6`1`0@@0JP4305l10@1H0@80C`8504L10P1=0@@0G@@2
08H/4@05003o00Wooooo102P8?000`3@D7P0X23`0:0Pl0030:0Pl0<0oh0000<0d51h0?n0003oP000
3`3oP0000`3@D7P0X23`0:0Pl0020:0Pl0040=1@N03oP000oh000?n00080X23`00L0oh000:0Pl02P
8?00X23`0=1@N02P8?00d51h00@0oh00102P8?000`3@D7P0oh000?n0000G0?n000D00?l02?ooool0
B@1@/cP0UifS0:nd_02YZ:d0[JZ[09R@T@1oNhX02aI800<@B@1]Hf@0]YHl0<BM8P2oVD40]Y=X0;ZG
P@2gV8@0O6eW07I]JP2APgH0]9j;0<V^V03?/id0ckBN0=2eW@3A]Z40b[JT0;fZVP36]Z@0g<Fb0>78
]P3OakD0hl^h0>;;^P3Sb[X0hlbi0>G@^P3Rc[X0glVi0:RS/P1lJ8T0^T9=0=<I6@3B5aD0iWI]0>NW
U`3I/j40ZZ>^06lkIP2k3AT0]a0D0;aoR01P53d0/0HF0:HZ<`1lI7@0MS1209`84@2S10T0/DQ20;6;
QP37a/P0c<k>0<JnQ`2lYR00]9X@09An6012=PT0De<O05iF2P2CSA`0WI4B0:VE8@0Tg@d04000o`08
ooooo`0307QH]02P8?00X23`02@0X23`00<0^3Rd0>QX?03oP0000`3oP0000`2h>;@0X23`0=1@N002
0?n000060=1@N03XJ3`0oh000?n0002P8?00j6Pl0`3oP0000`2h>;@0X23`0:0Pl00:0:0Pl003052@
N000o`000?l000h00?l02oooool000[ooooo05<0^jn30:^^[P2IWJ00M6=S04dO8P3Ld=D0e]cT0=?H
h017BDh09PPA03d53P1?1`d0HA<40=>P5`36LPl0/Q830;l720341`T0a0D:0<T82P3=2P/0cP/;0=0;
303D30d0e`d=0=T=303M40h0hA8@0>8B3`3U5180gAXI0:PL8P2?Bdd0b[Ne0>cZi@3[k>L0kN_Z0?G=
b`2e<2d0]AlL0<^>R`3eh=l0l^3Q0?CPh03egml0m^3R0?GNh@3bg^00lmgN0?_6aP2f9bP0_PhB0:0=
4P1`8B80^jf[0=_Ee03Me]L0gL?109<Z9`2A0PD0S`8408`10`2;0@80SP8408`11`250PD0L@840781
102U1@T0Z@420:T20`2>0P@0MP4507T21P1b0@@0JP4306410P1H0@<0CP4504L10P180080HP@308<U
3005003o00Wooooo102P8?000`3@D7P0X23`0:0Pl0030:0Pl0<0oh0000<0d51h0?n0003oP000403o
P0001@3@D7P0X23`0:0Pl02P8?00^3Rd00@0oh0000<0j6Pl0=1@N03XJ3`00P3oP0030>QX?0@0oh00
00<0j6Pl0:0Pl02P8?000P2P8?0I0?n000D00?l02?ooool0B@1fVV00SiVU0::U[@2YYj`0ZjN/0:2F
V`2DSIX05Ai:008@B@1`IDd0aJ<F0<RW2P2iTc/0/8m_0;:CO02hUh40_9b70;VLR033YHl0c:jH0<f_
VP3;/9X0ck>N0=2eW`3>]Z40_JVF0=BkZ@2kZ9T0fLFe0=k7]@3MbKL0g/^i0>7<^@3Rc;P0h/^f0>??
^P3SdKd0i<jm0=k9^P34^;P0QgZB0:5KL035:2l0cADI0<LP8@3@Ee<0ek2]05aAM@2V8SP0_`P@0;Xl
B02><500[0LH0:L84@2aQ8`0TXbM074aAP2@3ad0U`lH0;f0RP3>bll0alkD0<_>cP2o]7@0_:@A0;RQ
102LQ`l0MVHF06iS3`1`JAl0J64<0:FH601K_@l04000o`08ooooobT0X23`00<0d51h0?n0003oP000
0P3oP0000`2h>;@0X23`0?n000020?n000060>QX?03oP000oh000=1@N02P8?00j6Pl0P3oP0000`3X
J3`0X23`0:0Pl00:0:0Pl00307QH]000o`000?l000h00?l02oooool000[ooooo05@0VLQg0<33aP2N
YJP0Ng1`048B5P3D`/L0dmWO0=;Kh@1KGfH08PXB03H32`140P`0GaL50=NR5P33JP`0/Ph20;h71`31
1PT0_P@90<@52@3;20X0b`L:0<h92`3A2PX0ePd=0=X>303K3Pd0hQ0@0>HD403W5Pl0jAPB0>HI503G
8Ah0P24R0=O;a`3ZjNL0k^WZ0>no`P2h;S00/1dJ0=R3O@37J6T0aU9E0<=:C02j@D<0_dQ80;a8B`2`
BD`0/U9D0<ACD02l9B00^0`<0:l5202H2Ph0F2HT0<Rj]P3Ne]P0gmCB09mBC02>0`H0T08408d20P2;
0@80RP4108L10P240@80NP8405d10@1a0@80Q@8408d31@1b0@@0J04307/21`1j0@H0K@4206D10`1J
0@80C`4404T10`1:0@40K@<408<N200Sc084003o00Wooooo102P8?000`3XJ3`0X23`0:0Pl0030:0P
l0<0oh0000<0d51h0?n0003oP0004@3oP000103XJ3`0X23`0:0Pl02h>;@A0?n000050=1@N02P8?00
X23`0:0Pl03@D7P0603oP0000`1@T7P00?l0003o0002003o00Sooooo04T0X9NA08FDY@2KXjX0YJJ/
0:>SZ02WXJH0S8B?02H]E`0<5ST0SWXZ0<BV1`37Z0<0`IX[0:b<K`2[T7/0]IIo0;bKQ030WhT0`ZFB
0<fgY`3>]jH0b:bI0<nbW03A]9l0d;JT0;^WV@3?^j/0_JZL0=W4/`3Mb;L0g/Fc0=k9]`3ObkX0hLbj
0>;<]P3SckT0i=710>?>_03PbkL0gLRf0=?5``21P9l0/g2;0<XL7@3B40d0b`l?0<9;A02KQiT0OCEJ
0;`:502l1`d0[PXD0:d54P2`0`d0UcDn0<75d01UI800MciC09/G8`2G2aP0_HZC0<[<dP36c=D0a<Fg
0<NkL02kYAP0]j040;6I1`2HP@X0R7HK061E3`2AQad0==d;01000?l02?oooolZ0:0Pl0030=1@N03o
P000oh000080oh0000<0X23`0=1@N03oP000103oP0000`3XJ3`0X23`0:0Pl0030?n000030;Ph]02P
8?00X23`00T0X23`00<0N5Rd003o0000o`003P00o`0;ooooo`002_ooool0E02Lbg/0]KVk09^TY`2=
QXH0@Q0C0;bX[03@em/0d][P071dN@0P2Q40=@<;03l11`1S6`L0fj@F0<AR3@2e3@80_`L80<872P33
1@/0a@D:0<X72`3;1`/0cPX<0=8;303G3@`0fa0<0=dA3@3S4@h0iQ@@0>HE3`3Y5a40iAH>0=PJ5P2@
9R40im?>0>kQhP3df=X0fWMl0<@L7`2]61T0`I:?0?kLe@3i_KH0hi^C0=26O03AS8<0hZ>K0>^g/03c
`;T0m[R/0=^5N02]<2L0YA8>08d51P1e>Rh0dKV]0>?EdP3Ob/H0USdg09820`2C0@<0S@4208h10@2;
0@40Q`4008H10@240P<0L@X806@F5@1N2`/0G@4405D00P1S0@<0O`8608821P1d0@80J`4306420`1A
0P<0A`4204T10@1_0`<0O1H202?;0P@00?l02Oooool40:0Pl0030?n0002P8?00X23`00<0X23`603o
P0000`3@D7P0X23`0?n0000A0?n000040=1@N02P8?00X23`0:0Pl1T0oh0000<0D91h003o0000o`00
0P00o`08ooooo`190:^VY01aPI80WZB/0:^Z/P2SXJP0XYjU08^4SP0/<d/0MVPV0;^L4P2^T`T0ajL5
0<2J9@2^Reh0Zhae0;FFO`2jVhD0_Z2<0=O8_P3Eb/H0el[40<nk[P3=[iT0dKFP0=FlZ03:/j80a:fN
0=K0[@3Ia;40flJc0=g7]P3PbKX0hlfm0>3>^`3Rc[d0i=6m0>CC`@3Tckd0h/bi0=S7_`1hO9P0/F1h
0</X<`3A4Q80b`h80<TX603>LU`0bk:_05e7KP2[5b`0^0T?0=AiO@1V5ch0Y`DH0:0@7@16:e<0KSUG
09LG9@2R1Ph0YP@:090X:P3@b<`0aLgG0<?<d`35b;L0_[9S0;fY<@2dWPX0/ih40;BM1P2WT0d0UhHE
04O@400@003o00Sooooo:@2P8?000`3XJ3`0oh000?n000030?n00080X23`0`3oP0001@3XJ3`0oh00
0?n0002h>;@0d51h00@0oh002`2P8?000`1@T7P00?l0003o000>003o00_ooooo000:ooooo`0m09g>
OP33b<T0X:Z[08=oOP1:6Qd0Z8^B0=GGh03CfN80PXF;0209400b0`P0?`<706/S2P3JXa@0`5H<0;X>
1@3220X0aPL<0<P62`381PP0b@L:0<T72`3=2@/0dPX;0=L=303I3PX0g10:0>0B303T5@l0iaH@0>TF
403Z6A@0daLD0=IOG`3]UYP0gh280=5EG03<8b@0e1HF0<hH5`2S<cT0hL320?GXi`3bj>D0lNSS0?;Y
iP3ajNL0k^SW0>kYi`3]j><0l>7L0>Jm]`39O7D0VB`W0:e=A02iK6H0^G9a0:aGE@2A4@l0U@4209<1
0P0209020@0E08d10P280@00Q`4108H10@295Q<0WEA@0;=gMP1N4A80H`4407L21@240`L0RP<907`2
101^0@80I04205@20`170@80BP420783101n5@@08lX200@00?l02Oooool40:0Pl0030=1@N02P8?00
X23`00<0X23`7P3oP0020>QX?0030?n0003@D7P0d51h00<0d51h00@0X23`0=1@N03@D7P0d51h0`3o
P0020=1@N0030>QX?03oP000oh0001L0oh0000<0D91h003o0000o`000P00o`08ooooo`1:0:^RVP1W
N8L0U9fW09jQYP2PWZ<0WIRL0:fWZ`16@b/0^9dG099h2`1mI@/0b:D=0;ZE7`30VcT0[8aZ0;FDP@2l
W8L0_jJE0=_?b@2lZ9h0aJnS0=>n/P3>/Yd0dkNS0=BkZ@3F_:d0fl2`0=S2[P3JaK<0fLBa0=k;]`3N
bkX0hLjm0>3?_`3Rd<00i]700>C@`@3QcK`0hLbk0=S9``1HHXT0/E5W0=4F6P3A3`h0`Q4:0=aMCP3N
[i`0a[2T07Y`QP28;Dl0^0TB0;mDG01UAVh0T0T[0:X4401d9D00FBm>08dA7`2S10`0Wa4@0;R6O@39
c<h0`l_D0<7:e037cmP0bM3=0<_;^`2aZfd0Y9lb0:nU902gYa80/YdE06:U4`0Dk`@?003o00Sooooo
:@2P8?000`3XJ3`0oh000?n000020?n000040;Ph]02P8?00X23`0>QX?080oh0000D0X23`0?n0003o
P000j6Pl0;Ph]0030?n000030=1@N02P8?00X23`00T0X23`00<0N5Rd02S8?000o`003P00o`0;oooo
o`002_ooool0502k/HH0`LO:09nZ[P2<Shh0CR@T08MQJ@3GeMl0dMWR092AVP0T2Q@0<`8:03d21P1^
:``0fj@E0;]62`2j30P0`0H:0<H630381@/0bPL90P3;2@X0?P3>2@X0d`/=0=L<3@3N3`h0h14=0>DD
3`3U5A00i1<?0>LF403Z6180j1PD0><L6P3N6ad0d10D0=DD5`3E4Q80eQ@D0=DC503F6Q`0_2P^0<5G
G`3FRY<0iZje0?2na03Y]K`0kKFo0>R]]@3QY:X0fj>Y0<ZUZ03H_;`0gjn[09XP7P2R1@/0X@@:09h3
1P2J0@<0U`4209H10P2D0@<0T@4308`10P2:0P80Q`4308L110260PH0R1DG094W9`2B7Al0QP<808T2
1`2@10/0T@@:08D11P1g0@@0JP4205P10P1<0@80E`4107T310204`H09ld61000o`09ooooo`@0X23`
00<0d51h0:0Pl02P8?000`2P8?030?n000030>QX?03oP000oh000280oh0000@0j6Pl0;Ph]02P8?00
j6Pl7@3oP0000`1@T7P00?l0003o0002003o00Sooooo04X0]ZJG05IUM@2GXjd0WjFY0:JVZ`2WWj80
QWQb09J2@P2lWa80LeT;0:F74033X100^ITJ0<2L;P2]S6X0/Hmm0;ZKQ`2lXi<0gm?=0;j^YP3D`KH0
bk:U0<jcWP3A]J40dkRU0=BjZ03F_JT0el2[0=[5]03HaK@0flVe0=[8]03Pc;X0glbk0>CA`@3Ud/40
iM;00>7>_@3Nbk`0flVk0:VU]01jJHT0]S]60</B5P3@3a80aQ<D0<YFCP3S_K40YINK060`E`2c3AT0
]bL]0<N>YP282b`0[`@>09@U=P1MDG00MD9K08hD802F2@l0`Hj@0<W;d@32b]<0`L[E0<39e032c=D0
`lcF0;S0a02Y]:@0]K^B0;RbFP2lZ1h0/ihG04;F2`l00?l02?oooolZ0:0Pl0D0oh0000<0d51h0:0P
l03@D7P00P3oP000103@D7P0oh000?n0003oP0020:0Pl080oh0000<0d51h0:0Pl02P8?002P2P8?00
0`1@T7P00?l0003o000=003o00_ooooo000:ooooo`1D09_8NP3:c=40Y[6d08F9R`1O=c/0Jci60=GA
fP3<e=`0SiFK020:4`0f0`d0@0@907@h3`3KY1@0]CL90;/81`2o1PT0``H:0<D52P3920X0cPX:0=0:
2P3C30/0ePd<0=/>403O3a00h14>0>8B403P4Ph0iA<A0>LF4@3V5A00jQPB0>LH5@3E3`h0d0h=0=DB
4@3C4Q80eA<A0=TE4`3M5aD0gaXH0=`K6`3G7Ad0e1hQ0<lN90396B40cATS0</H7`3:5a/0`A@H0:@>
5P2?4Q/0U3m30;=<A`2Q10L0Y04409l1102N0@D0V`4709P11@2H0@L0U00309410`2>0@D0R04208H1
0P270@D0QP4608P0102>0PP0T0<:08l22@2D0``0U@@<08L11`1k0@@0K@4205/20@1E0@40J@<307h2
0`1j30809/d51000o`09ooooo`@0X23`00<0d51h0:0Pl02P8?000`2P8?020?n000030=1@N03XJ3`0
oh0002H0oh0000<0j6Pl0?n0003oP0006`3oP0000`1@T7P00?l0003o0002003o00Sooooo04X0XlF;
06EdQ@2?W:L0XJBY0:VUYP2]WH00Y8Y20;VJ902ENP`0PF/C0;ZJ3`2aSRD0ZH]90:f>F`2ZRWH0[i1n
0;NIQ`2oWhl0bKBX0=;0]03<]jP0c;:M0<fbW03?]9l0d[NS0=>lZ@36]J<0eL6`0=_3/P3I`k40g<Nc
0=[9/`3PcK`0h<fm0>CB``3VdlD0i]C50>?B``3PcKh0g<Vj0=K6^@2YWjT0RFf30:e6D02h7b40aa<E
0<8C4`39FeD0bZRO0619J`2W7300]`T@0;8N;P2[21H0/0<;0:8K9`2^V:`0R8>J0751E`2@5200TahZ
0<BS[@33bM00`<[D0<OAfP36c]L0`lcF0:jha@1CH6H0Mgma096FO`2dZDT0_J`M06S75`l00?l02?oo
oolZ0:0Pl0030;Ph]03XJ3`0oh0000<0oh0000<0^3Rd0:0Pl03oP0001@3oP0000`2h>;@0X23`0;Ph
]0020?n000030;Ph]02P8?00X23`00T0X23`00<0N5Rd003o0000o`003@00o`0;ooooo`002_ooool0
@`2JaWL0al[?09nY[@2;TI@0H3e005PX;P3@cM80a];H09ZQYP0Q31<0=@<;03T21@1f?@d0gJ<E0;4Y
102n2PL0_@@80<@630351@`0aPD:0<`82@3A2P/0d``:0=L?2@3H3PT0fPd;0=h@3P3N3`l0i1@B0>@D
403W5Q80iaLC0>TH4`3P4a40d``>0=@?3`3C3`l0d@l?0=HD503L61D0gALE0=dG5`3O6aX0gaXF0=hH
5P3D4Q40eA<C0=LD503B4140d@h?0<X<402d1P`0[08809l62P2M3A00X`870:<11@2O0@@0X04709d1
2@2K0PP0VP4609H0102B0@@0T04508/10`280@800P260@803`270@<0SP4709022P2;0@P0TP@<09D4
30280@L0OP4307<20`1N0@40G@0107<10P1o0PD0NPT003J`1@04003o00Wooooo102P8?000`3@D7P0
X23`0:0Pl0030:0Pl080oh0000<0d51h0?n0003oP000A03oP0000`1@T7P00?l0003o0002003o00So
oooo02<0T=1c07N3U021T9`0Wj>X0:nWS`2gWRd0^id90:f@3P1`F@T0[Hh>0<2L3`2aRcT0Y8AT0::3
M`2XRW`0[Hj10;FGQ@2nWX/0a:JB0<R[U`3:[YT0bJjH0<N^U03</Y/0dKFQ0;n[V`2gZY`0a[>Q0=W2
[`3Ja[<0f/Vd0=c;^03Nc;`0glfm0>??`0020>GA``0U0>OBa@3Sc/40gLVj0=S6]@3Ea;H0cKfi09F5
T`1lHgP0Ve9Q0<0G6`2o4a00d8Yn09Z=VP2VHVh0^3Xe0;0f;P2[;b/0YbPZ09/Q:@2ONhL0b]7J0:n`
_`1_BV00RQ@U08hP;`36]kh0`lcD0<S@fP35cMT0_l_F0;K4dP1`QI`0OI2N096NY02PXh/0/k9m07Yl
BP0?003o00Sooooo;@2P8?001P3XJ3`0oh000?n0003@D7P0X23`0>QX?0D0oh0000@0^3Rd0:0Pl02P
8?00^3Rd0P3oP00<0:0Pl0l00?l02oooool000[ooooo01`0VLIc0<K8c@2[/kT0Q8V;06A8BP1761`0
`Kg00<7<c`2NY:P08@hC03@42P0m1@T0PdX@0=fP5`2_80<0_PP90<872`351`T0b0H90<`92`3@2``0
e0/>0=H=3@3G3@/0f@d=0=L;3@3J3@l0g`lA0P3T4Q80=P3U5140j1DB0>DD503I3`h0ePh@0=PA4P3F
4A80ca0@0=8A4P3F51@0fQDE0=`H5P3M5aH0g1LE0=dH5P3G4a80f1DE0=HB4`3A3Q00d@dA0<H9402a
0PT0[0470:X2202V0PX0Y@490:<1202R0PP0WP8609/11@2K0PL0V@4609L11@2B0@D0T@8609021029
0@40Q@4208@10P2600<0SP4809822`2C10h0U@D<09@42`290PP0O`4607H11@1X0@<0K`8307L10P1m
0P<0MPL004RH2@@00?l02Oooool50:0Pl0030=1@N02P8?00X23`0080X23`0P3oP0000`3@D7P0oh00
0?n000140?n0000308300000o`000?l000800?l02?ooool0B`1[gE<0PHVH07f9V02RXj40/9i?0;NJ
2P2/SPd0JUD9095h3`33X0T0[8TZ09QiI02KNgD0Y85l0:R7O@2/SH00/iF60;jNS035Yi80b:VD0<BW
T@35ZI<0bK2H0<fbV`3B^:40cKJR0;n/V@3C`:/0el>_0=[5/`3JbKD0f/Vh0=c;^@3OcK`0h/no0>?A
``3Td/<0hm320>;@`@3Lb[T0fLNg0=K5]P3FaKD0dL6i0;Jb`01KFGP0/d=60<0k:`3DXI<0Si2J09^E
Y031TXh0bZRW0<:^]02^UjD0LEeb07EdQP2iaLh0b];F0:BZ_01M<4/0R0XF0:QkP034cM@0aLoK0<K?
f@31cMH0_<OE069eSP1eRI/0T9jW0:6YZ@2TZZX0JFI`00cX1`0>003o00Sooooo00<0D91h0:0Pl02P
8?00:`2P8?020?n000050=1@N02P8?00X23`0:0Pl02h>;@01`2P8?000`3@D7P0oh000=1@N00;0:0P
l00302S8?000o`000?l000`00?l02oooool000[ooooo03L0Ul9a0<S;dP2R[;00O8:406UBE00l3Q80
[jJZ0<;;cP2QZJd08@`F03@32`0h0PD0S5PC0=JE4`2`5`L0_`L;0<<730341PH0bPP:0</82P3@30`0
d`X=0=@;3P3D2`d0f0`?0=/>3`3J3Ph0gA0@0>8A3`3S4Q00j1HB0>TI4`3L40l0ePl?0=LB4P3C3Q00
c`hA0<lA4@3B51D0cQ8A0=0E5P3<71P0aB@N0<4d;@3DCdP0fU9<0=Q7@`3>9280eQDE0=DA4`3;3140
]0<:0:`2202Y0PP0Y`880080X`4601/0X0860:021@2M0@@0W04509P1102E0PD0T@8609011P2@0@@0
R`4108L10P270@<0R04508`1202B0P/0T`8;09@4302B10/0R0480841201k0@L0O04508`21`210@<0
N08206l60019V`d01000o`09ooooo`D0X23`00<0oh000:0Pl02P8?000P2P8?020?n00080d51hA@3o
P0000`20`0000?l0003o0002003o00Sooooo04/0C=lf09nT[P1kQi80YIaZ0:nF402WS0T0Led807EN
302bT`/0/Y4K09=fF02DMg@0VgYi09mmNP2XQ7h0Zh^10;2AQ@2kVhX0`Z6>0<>ST@36ZiD0bK2J0<^f
Y03>]Z@0d[VS0=:lZ03C_Zd0e[n]0=W3/`3JaK@0f/Fc0=[8^03Ob[T0glfm0=o>_`3Pd;l0hm;10>C?
`@3Qc[l0g<bj0=W7^03Ga[L0e/Bf0<fm]02OUiL0/JJW0=2^W@3A/9/0ajnR0<Ng/P25N8T0SE=S0:0e
@`2T:SX0YB<c0:4M;02K9SH0XDAF0;R1T@2ZX[80NFQg08M9B02_ViT0a<gD0<K?f@37cm/0a<gH0<?<
f@1<GW`0G7B;07>1S`2AVJ40U9bT06IZNP0W_Q`03P00o`08ooooo`03052@N02P8?00X23`02/0X23`
0P2h>;@30:0Pl0030=1@N03oP000oh0000<0oh000P3@D7P20:0Pl0030=1@N02h>;@0X23`00X0X23`
00<0D91h003o0000o`003000o`0;ooooo`002_ooool0E02B_fd0a<O>0:Ze^024S8`0GDY<03462`2/
Y:P0bM;D0:2Z[00J3140;@<903L71P2@HAD0ch/G0:d@1@3020T0``L90<P92P371PT0c@X<0=0;303A
2P`0d@X;0=H=303H3@l0f0/;0=/?3@3L3``0gQ8<0>@E403Z6180gA8=0=8<2P3A3P`0dQ0@0<`<3`3:
3Q40b@h@0<hD50335A@0]28N0:I8@03JWYD0n=;=0?[Qg@3lhMd0o]cI0?:YY033<2/0d1DD0<h?4P2k
1`d0[0<:0:P22@2V0@D0XP440:41102O0@@0WP4409`11@2K0@@0U`4308L0101m0@<0S@<608h10`2;
0@40Q`4208P10`2:0@D0S@8809<32`2B0`/0U0H=09443@250@H0OP0607X10`2>0PL0W04808h10P1i
0@80K`@004RI30@00?l02Oooool50:0Pl0030?n0002P8?00X23`0080X23`00<0d51h0?n0002P8?00
AP3oP0000`20`0000?l0003o0002003o00Sooooo04/0;^@M0:bX[P1nQG/0Yi@T0;6I1@2GOPX0TGXE
0;:D2`2cUa40U7U508mcK@2CM7D0V7Qf09enM`2UPg`0ZXMn0;2@Q02gW8/0`JBB0<NZV03:[i`0^ZZL
0<_7a`3Le=40c[NW0=:jZ03B^ZT0f<6b0=W1/`3H`k80elFd0=[8^@3JbKT0glfm0=k=_P3Ockh0h]72
0>?A`P3RdKl0gljm0=O7]P3Fa[L0dlBe0=71/`3@_k40d;ja0<fl[@37]ZH0ak>V0<BcY`2n/:L0]:^`
0:21Q`2HEeP0[eE?0:iED02^G5`0Vd]C08`oC02FIW@0blW=0<G8c036c]80a<kF0<G@fP33d=X0a<cG
0<7;e`27Vk00NY6T08jMZ@2EWjP0WZRc06ehRP0g/C803P00o`08ooooo`03052@N02P8?00X23`0340
X23`00<0^3Rd0=1@N03@D7P0103@D7P00`2h>;@0X23`0:0Pl00<0:0Pl003052@N000o`000?l000`0
0?l02oooool000[ooooo05@0U<5/0<O<d@2T/KH0Phf<06ACE00k3A00^:ba0<gFfP2PZZ`05``A02/4
2@0/0`80UfLG0<Un5P2c40P0_`P90<<72P3720/0bPP;0<h92P3?20X0dP/<0=@=3@3G30`0g0h?0=h?
303Q4`h0h18>0>8D3`3V6180iQHA0=P?3P3D3`h0ea<A0=<A4P3=3a00cA8C0<HF5@2j71T0ZBdW0;Ma
J@3/d<X0l>KR0>oYj03[j^T0k>_Z0>cXj03eiN<0hiJA0;hW8`3<4QD0_`P?0:d32@2W0@P0Y0460:01
102N0@@0W04509d21@2J00@0V@0209T1102>0PD0O04308P21`2?0@@0S@8208T10`2:0@@0RP0408h1
1`2C0`X0T@<90945302@1@d0Q@4707l11P1n0@<0VP<80:<3202G0`H0NP8306X30015UPX4003o00Wo
oooo1@2P8?000`3@D7P0X23`0:0Pl0020:0Pl0030;Ph]03@D7P0X23`01/0oh0000@0d51h0>QX?03@
D7P0d51h0`2P8?000`3XJ3`0oh000?n0000Q0?n0000308300000o`000?l000800?l02?ooool0B`00
o`00`[BS08f6C02bV`/0Vh870:J;4P2BM`D0/9DB05A<6@24L6`0Sg=b09AeL`2KMgH0WGah0:B3O02Y
RGh0/9>40;NKR`2nXXh0_j>?0;jXT`2ZXIH0^KZk0<_1^`3=]jD0dKRX0=:l[03F`;00el6`0=W5/P3E
`kD0dL>g0<Jl[`38_[<0f<nn0=[?_`3PdL40hM310=o>_`3Nc/00f<Nk0=G6]`3DaKH0dL:a0<o1/`3=
_[40b[V/0<VhZ@36]:H0`K:T0<Nk/02k/Z/0^k>/0<[7a@36a<H0YJ^c08VEY@0Y?ET0ZKK409:AW`2F
XJ/0a/oF0<G>eP32cML0a<oJ0<C@g033cMP0`lkI06f1V01LM8T0RYfY0:>^]`2SZ[<0M7n?04b6A`0>
003o00Sooooo00<00?l00:0Pl02P8?00B02P8?0>003o00_ooooo000:ooooo`0o092lI`38c=00Z;Bj
07Z7R01REUL0?`hA0;ZZ/03<dm/0VZ2V01d<4P0`10`0<0<20:ak7032JPl0]Pd90;l82`321`X0_`D7
0<D72P3>2P/0dP/=0=H<3P3H3Pd0fPh>0=`?3P3P40h0i1<@0>DC403U5100iADA0=lD403C3Pl0eA4B
0=DB4P3>5Q80`a`H0;DY8`2fH5P0bIVA0>SAc03/i^D0jn_/0>SXjP3Yj^`0inSZ0>WZk03/k>l0kNg^
0?3Uh`3`]kD0_Rd_0<@=4@2b1P/0Z0<:0:H32@2P0@D0W04309P11@2I0@D0V04409T21@2J0@@0V@86
0080T08501<0S`4308X10@2;0@@0R@4408P1102=0@L0TP8909H42`2D1@X0T@D<08H1201o0@H0SP89
0:832`2P0PT0T`8407X10`1T0@00@98800@00?l02Oooool50:0Pl0030?n0002P8?00X23`0080X23`
00<0j6Pl0?n0002P8?00603oP000103XJ3`0oh000;Ph]02h>;@60:0Pl0030;Ph]03@D7P0oh000240
oh0000<0P<00003o0000o`000P00o`08ooooo`1;003o003;[740YY@L0:JA202FO@d0YX`=0;NH1`1f
J1L09b`l089^L`2ALWD0U7Eh09YiNP2OP7d0Y8Eo0:Z9PP2aTXL0^Yf?0;fNS`31Xi40_jFA09>6N`2J
SXH0^:NH0=2gY@3A^ZT0dKVY0=>n[03G`K40f/Ff0;V]X`2RVY@0]JbQ0::IT`2SXIP0fM2o0>3@``3Q
d<@0g/g00=c=_`3Ic;d0dlNg0=;5]P3@`kL0cL2d0<c1/`3=_k<0bKRZ0<JdZ036]:/0a;BZ0<:f[P37
`Kd0/[6^0;Bf^P2[/[X0WZ^j0:2daP2=Z;d0a=CM0;_:d@36dMT0a/oH0<C?f033cMT0`/gI0<;>e`31
c=P0P9:V05UcRP1^PY40TYjW09:JX`1]NXX0I5aN00h00?l02?ooool00`00o`00X23`0:0Pl0180:0P
l0h00?l02oooool000[ooooo0480T;YT0<75b@2/^;h0MH>3075XJ00n3a@0/9nV0<cCfP2JWJ807``C
02X3200c1`@0]hPL0;EG3P2d20P0_@H:0<0720311PP0a0H80<`92P3C30h0ePd?0=@=2`3J40d0f`l=
0=lB3`3S4Ph0i1D@0><D3`3R5Q40dPh;0<l@403<4a40b1dG0:`a9`2bI5/0hkV`0>kQg03Zi^D0i^GV
0>OWi`3Yj>P0j^WY0>SXjP3Xj>T0k>c]0>WYj`3[k>h0k>g^0?GTi@3?Kfh0`a4A0;D62@2/1@X0YP@9
0:411P2L0@@0VP4409P11P2G00@0U04409L11P2F0@H0U04409@21@2@0PL208`1100@08P10`270@80
R04408l2202D0PX0UP@;09<42`280@P0R04609X2202E0`X0R`4508h21@1k0P80I`40051e1P@00?l0
2Oooool50:0Pl0030?n0002P8?00X23`00<0X23`00<0oh000:0Pl03oP0005P3oP0000`3@D7P0X23`
0:0Pl0090:0Pl0030=1@N03oP000oh000200oh0000<0d51h003o0000o`000P00o`08ooooo`1;003o
001maQh0ZI@=06IH0P2@O140VX<=0;FM;P1:B3P0<SIE08=_M02?LGH0UWIj09]iO02POGd0XhAo0:Z<
QP2^SHH0]iZ=0;fQT@2oXXh0`:>B0:F@P@2YV8P0`ZfM0;fZW03@^ZT0d[RY0=>l[03D_jl0f<Bj08f4
P`2aZjH0`KVa0:nVY@23Pgh0f=2o0=oA`P3Qd/D0g/o20=c;`@3Ib/00dlRl0=;5^P3?a;P0c<6h0<c1
]P37_k80`kZ^0<2bY030/ZL0_K6W0;^d[`2/Y:`0[Yj[0<^b^@2fY:T0GFUo09>T^01cSJ<0`m?M0;W5
b`37dMX0aM7I0;o<eP2nbmH0`LgG0;o<e@31c=L0UJNk07><XP29WJX0UjB/09NSZ`1lRIP0HfE[00h0
0?l02?ooool00`00o`00N5Rd0:0Pl0180:0Pl0h00?l02oooool000[ooooo05@0SkQQ0<G:cP2`_<@0
QY2B06YSI@0h3AD0ZYZP0<oGg02=U9L06`/A02/32P0o3080aY<N0:e32`2h2@/0`0L<0<<730351PX0
b@P;0<`92`3A2P`0dPd>0<h@3`3I6AT0fa0@0=lB3`3L4`l0eS4Y0=Hk<P3A<RT0bC4Y0<]9@@3>I5/0
eh^30>g<a`3bin<0k>SV0>WXj03ZiNL0k>3U0>[@eP3W/kd0eY2K09aTL02k/KH0k>c^0>c/k`3]kO00
k>g_0>cXiP3PY:@0^aHG0;/8302a1P/0YP<:0:81202P0PP0V`4309T11@2C0@D0TP450981102B00H0
TP4609011P2<0@D0R`4708/11@280@<0Q00108P21@2?0PT0T`<;09H5302D1@`0SP4909/12`2Q0`/0
P04508XF6P2310P0N@4206T1001OF@H4003o00Wooooo2P2P8?000`2h>;@0oh000;Ph]00F0?n00005
0=1@N02h>;@0X23`0:0Pl02h>;@0103@D7P30:0Pl080^3Rd00<0d51h0?n0003oP0007`3oP0000`3@
D7P00?l0003o0002003o00Sooooo04`00?l003gR1P2BPPT0NVX50:bE2@2cWbX0SX=C04I;G@0l@5h0
QW9d099cNP2FMW`0VWYl09amO02TQX<0Z8R50:j=P`2iVXd0^I^;0;nQS@30Xhh0`ZFD0<>XU`30ZYT0
YIF;0<JaW`3C^ZP0d;jZ0=G3/P3E`KH0S86108J4R02<Rhh0Ogn109NCRP3Mckl0glo20=oA``3Ld<40
f<^n0=?8_P3Aa[`0dlFn0<k3^`3=`k/0cL:h0<Vn]@31]jh0_KB/0;>/[P2HRYX0TVAn09/eCP2Z6bh0
[18O0:PW<035RYP0LFYk07j?XP2ncm/0b=;J0<GBf`34c]P0_lcE0;c:d`2oc=L0_l[E0<7;f01/OiL0
J8:M07bBY02Y]<00[;O206EdRP1KI7806=8?3@00o`08ooooo`03003o001@T7P0X23`0300X23`00<0
d51h0>QX?03oP0000P3oP0000`3@D7P0X23`0:0Pl00@0:0Pl003052@N000o`000?l000/00?l02ooo
ool000[ooooo05@0SKEN0<G9c@2a_<80Phf@07QdN00f3aL0[IbU0=;Jh@1oQXd07@/C02h31`176040
didR0:L[1P2k20`0``T=0<<72P3020`0/`D:0;<62@392`d0bPd>0;hL70397Qh0g@l@0>0A3@3H4Q00
Vb<S0<B=S@3cd]00nN7N0?OWi@3dj>L0ln_Z0>oYjP3^hn80kM;E0>:X[P3ANH40d5aW0<@^>@367BD0
cA/O0;@N8@1Z?440jNW[0>_[k@3/k^l0j^_]0>c]kP3eemX0_2/^0<X>4`2l20`0Z`<:0:<01`2P0PH0
VP4309T1102C0PD0T08809<11`2C0@D0T@4508l11P2:0@<0RP4408X21@280@H0PP4208<10`2<0PL0
T@<809L53P2G1@d0XP@=0:X32`2P0PT0N@4507/3201g0PL0MPP;06L10@1KEPL4003o00Wooooo2P2P
8?000`3@D7P0X23`0=1@N00@0?n000030=1@N03oP000oh000080oh00103@D7P60?n00080d51h102P
8?0Q0?n000030=1@N000o`000?l000800?l02?ooool0C000o`006?8408Qb1@2TS`/0[iL40:VF@02R
WYL0=CeK04];J028LWT0SG1f099eN02INgh0WWen0::1P02WQH40ZX^30;2CR02lWXh0_jB?0;nUS`34
Yi80b:^F0<V_VP36/Id0d/2[0=G0[@3?_JX0dL2_0=;0/@36]:T0WHn:09nES`2dZ9d0e<Bf0=g<_`3L
cL00flg20=S<`@3Gbl80dl_10=;9_`3@akh0cLBm0<c4_@39`[`0a;jl0;2X[`2KQ9L0UE=^0:`^A@2c
41h0^@/@0;H93`2h1Pl0]`@;0:/;602K>4H0[9VT0<SDf`39e=d0a];K0<??f@30c=@0_l[B0<7=e`32
cML0`<gH096R]@1HLHP0NI2P09>NZP2GX:`0GFV104iIJP0^]R4=003o00Sooooo00<00?l002S8?02P
8?00;P2P8?000`3@D7P0oh000?n000060?n000030;Ph]02P8?00X23`00h0X23`00<0D91h003o0000
o`002`00o`0;ooooo`002_ooool0:02:]5/0^Kfn0;C0a`2?WJ80M75f03HA602YVJ40e]cV071fO`0L
2a<0<0D906@e403BVRL0X1L50;P7302m1`l0^@L<0:@31`32;CD0`CDj0:L72@3=3Pl0fB<V0=PM7`3O
4A00hQ8@0>8C3`3B4aD0[a4H0:dd@034IW80bWJ10=j<UP3MPhl0eFMc0<i?F039<SX0d1lV0=4I7@3A
5AL20=HF6@0E0=@F5P3:6A/0MAHI0:jWZ03Xj^/0jnc^0>c]k`3]kO00l^OZ0<MIG0384QD0``/=0;@6
2`2X0@P0X`4809/1102F0@80UP4409D11`2?0PP0T0880080T@4701<0S`8508d10P2=0@@0R`4608L0
1@240@@0S08808h12@2C10`0X0D>0:d5302X0PT0W@<:06d1101a1P`0N0<907@;3P1/0P@0F4l300@0
0?l02Oooool:0:0Pl0030=1@N02P8?00d51h0140oh0000<0j6Pl0=1@N03oP000303oP0040:0Pl003
0=1@N03XJ3`0oh0001l0oh0000<0d51h003o0000o`000P00o`08ooooo`800?l004X0ThX60:jJ1@2_
VA@0ZiiV08F4RP0nAVL0EEI]08I`MP2>L7L0UGAk09YiO`2OOGh0XX610:F3O`2/R800]YF<0;bNS`2n
XHh0_j>?0<BYUP36[9H0bk:L0<ffY03C_Zd0d;fZ0=:nZ`3C_Jd0d/6_0=K5]P3D`[@0fLRi0=c;_03J
b;X0flZm0=W;_@3Eb<00eL[40=K<a`2m_l40`lG90=K0_P3E]KL0aZBZ0;^CX@2ZJWl0ZdEM0;<S<@2h
5QX0]AdK0;Lj<@2iG500W5AF09P_?@2b1a00]P@90:/8402D?DL0`lS@0<kJh@36dm`0aLoI0<;<eP31
bM@0`<cD0<C?f032c]T0Sj>g05aeR`2;X:l0UJ:^09NR[`1PKhL0@51P03bV;`d00?l02?ooool2003o
02T0X23`00D0^3Rd0:0Pl03@D7P0d51h0>QX?0040?n000030>QX?03@D7P0j6Pl00<0oh0000<0j6Pl
0:0Pl02P8?003P2P8?000`1hF;@00?l0003o000;003o00_ooooo000:ooooo`0I08V`E`3>dM<0^LC=
08>BUP25Q8T0=18H0:VIX@3DgNH0GF9[024;4P0a1PT0RELJ0<^=802L3`H0]`L=0;P84@2X1@`0Z@@:
0<0:4`2g2Q40W0<50<d=3P3C3Pl0fPlC0=l@40020>0C3`0i0=8>3@3;2`X0cA0B0=4E603B61d0caLO
0=4I803D6Ad0dALH0=@F5P3G6AP0f1dJ0=<K5`3C6aT0ea`L0=@E603?5AT0WAPL0655A`3Si^H0j>_/
0>_/kP3Zjnd0k^[[0<moP`315aT0a0`=0;X8302`1@`0YP4909/0102H0P@0U00209<110220@80P`43
09021`2>0@D0S04408X00@2=0P@0RP4508P010270@<0R`8609012P2P2100Y`@;0:`4302S0@P0W089
06`72`1<00@0L0<:07P73@1`0P<0Fe0400@00?l02Oooool:0:0Pl0030=1@N02P8?00d51h0200oh00
1@2P8?000`3@D7P0oh000?n0000N0?n000030=1@N000o`000?l000800?l02?ooool2003o001:07Zg
1@2[V140/:EL0:ZUT023Q8`0>dEU061NLP27LGL0TG=j09=aN02GLgL0WGUj0:>0PP2WQH<0ZhR20;BG
SP2lWI<0`Z6C0<2ST@2oYI@0bJbK0<V_VP3;]:40dkfZ0=:oZ`3@^ZT0d[n/0=;0[P3Fa;H0d/6c0=O7
^`3Jb[d0elRj0=W;_P3Hc;l0f<c30=S;aP3Fc<L0[[Bo06aoX@2RM8T0[D9B0;4c@P2g:SP0^R4Y0;XT
8P2o?300`F=E0<JCQ02lXI@0[j6C0:JMWP1JAF@0WQ4O0;H33@2b0``0XahV0;Z^^03>fN80amCN0<7>
e`35c]P0`/_E0<C>f034d=X0`loK07b?Y01UQ9h0MY2P09VZ]`2O[kh0Gg2;049CI@1<Pcd=003o00So
oooo0P00o`0X0:0Pl0030;Ph]03oP000oh0000D0oh0000<0d51h0:0Pl02P8?000P2P8?040?n00140
X23`3@00o`0;ooooo`002_ooool0E01S`D80bL[;0;K1b@2EXjL0M7Ek03@D6`2]WJH0emoW04eBFP0R
2Q40<@L50:al802oNQX0W@/50;85302]20h0T0860;H83`341Pd0]PL;09`51P3>3@h0c`T:0=P>403K
3Pl0gA0?0=`C4@3<30d0b0`<0<h?4@3B5180calL0<l^:03B>C80dBlZ0<`Q703971X0^STd0=mfK@3L
NVl0hHQn0>R7PP30;bl0dAPL0;dL7`1>3@l0d<c<0>SZj@3Zjnd0jnc/0>[Zj`3MZZ`0]B4T0<@=402h
1@/0]0D?0:`32`2N0@L0U`4509<10`2D00<0SP8408T10`2>0P<0S@4209011`2?0@H0SP4508`11`2<
0@D0R`4408`21P2I1@`0[PTB0;88402[1@/0Y@4909l22@2A8RT0NCTn06h42P230`T0MP4305]<10@0
0?l02Oooool00`1hF;@0X23`0:0Pl0070:0Pl0030=1@N02P8?00j6Pl0240oh001@2P8?0P0?n00003
0=1@N000o`000?l000800?l02?ooool2003o001:07bj202ZX4h0Wj6K09nQYP2GVZD0<SmL06]YN@24
KWD0SG5g09IdNP2KMW/0WWUk0:9mO`2WQX80ZHR20;FER`2kWY<0_j6E0;jOT`32Xi40b:^J0<^aX03;
]:00dkj[0=:n[@3A_Jd0dknb0=?0/P3E`kD0d/6c0=S5^@3Jb[h0elNj0=S:_P3GcL<0f<c50=O;a`3E
blP0dl[:0<2nb02PWk00/9bX0;NCV`31TiD0dZBJ0=>^XP3;/jL0`[BZ0;V_YP2bZj40/:VO0;Ja[P1N
Hh00R3A:0:l43P2b0@`0Y`PB0:MkQ`3=f^80c=WR0<GBf`34d=X0aLoJ0<;>fP33d=d0`LoK09f_a@1F
Li@0E7BK03M@QP0^@gh062aV04AGJ`1DKT<=003o00Sooooo0P00o`0Z0:0Pl0@0d51h1`2P8?001@3X
J3`0oh000?n0003oP000d51h0100X23`3@00o`0;ooooo`002_ooool0E016]B@0c/_70;g9c`2@X:H0
NGf2034F6`2[WJL0e]kW03Dh@00T2A40?@l30<RH;02YG1@0XPT80;053`2I1`h0O`840;X83P3620h0
[0H90:P72P3C3@l0eP`>0=L?3P3J40h0f10@0=4<3`3:2Pd0c@h?0<DA4`2R;2L0g:FL0?SJe03hhM`0
n=WD0?;3_@3EUXl0NUeJ0>CKf@3Zi>@0k>OW0?GUiP3<Oh80b24T0=0K70295QP0Wh^=0>c/k@3/kNl0
inSY0>SYj@3Zd]<0YCTl0;P@502f1Pd0/`H=0:h42`2W0PP0WP8609P00`2F0@<0S`8208T00@290@40
S04108h10`2A0@D0TP4708h21P290@@0RP4209H1102X10X0]0P?0;<63P2^10/0Z@890:02202E20l0
RaTP08H63P260@H0N04207@S10@00?l02Oooool00`1@T7P0X23`0:0Pl0070:0Pl0030=1@N02P8?00
oh0001L0oh0000H0j6Pl0;Ph]02P8?00X23`0;Ph]03XJ3`40?n000D0X23`00<0d51h0?n0003oP000
7@3oP0000`3XJ3`00?l0003o0002003o00Sooooo0P00o`00B`1m^A00XIaY0:F//02PXZX0OX6>03U4
G`1bKGT0QFig08i`N@2FLgP0VgAl09ehN`2ROWl0YX:10:Z6P`2dU8`0^9Z?0;bOT02nX980`Z>B0<V[
V`3;/J40c;BR0=:lZ`3D`K40d[j^0=6n/03C`;80e<:e0=;0/`3E`kH0f<Vl0=K8_@3Eb[h0e<_20=C9
``3Ab<@0e<W50=;9aP3Bb/P0c<O30<c:aP39b<@0al?10<W2_037_KL0`KVd0;Ba/`2g/;00_:bV0;NV
X@2d[:L0WZBb05a6J`2P3Q/0/`8<0:l43P2`De/0e]SN0<_Gh`36e=h0aM;L0<KAg@36d]d0`loM0:>h
e@0cCHH011aS004DH0014Uh00A5K004BF`0C94h0G5aF00Kc0`0<003o00Sooooo0P00o`0e0:0Pl005
0;Ph]03oP000oh000?n0003XJ3`0402P8?000`0Xb3`00?l0003o000:003o00_ooooo000:ooooo`0P
04Rf8`36`/00/l3709>SZP1iOH40<aDJ0:jPZ03Cf^@0:b`e02H94@1@80X0cYd]08`o402N20/0[0L?
08T42@1g0@D0/@P=0;`;402K0`L0/PT;0=8=3P3B30/0dPX;0=P@3@3?2`/0b`T<0<d=3@3:30/0YQ0A
0:=mN03ak>X20>c/k@0b0>_[kP3[j^`0k>SW0=oKe`3Ccll0inKY0>SYj@3^j>P0m/S:0;l/<03B5Q/0
]R0W07iEF03/k^l0jng]0>GUj03YjN/0k^7S0:aRIP2/5AP0]@P?0;863`2/0`/0Z`<90:<11@2I00<0
U@8508h10@2;0P80R@4208/10@2?0@<0T@4609812@2<00@0S04409<10`2U0PP0[0890;D5402d1@h0
[P<:0:T3202U0PP0W@8909832`2<0@X0Q08507<0001n50D4003o00Wooooo00<0D91h0:0Pl02P8?00
1`2P8?000`3@D7P0X23`0=1@N00A0?n000030=1@N03oP000X23`00P0X23`00<0d51h0?n0003oP000
0P3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030=1@N03oP000oh0001h0oh001000o`08ooooo`800?l0
04/0Gm@]08nCOP2PYZh0XjJ`08b<W00h?UP0N6mj08EaN@2=KgP0UW9i09eeN`2QNWX0Xh200:F2P@2Z
QX<0/I290;ZJTP2jV8d0]iF80<2QT@35ZYT0bJnN0<^dYP3=^JT0dl6c0<jk[`3@_[00d/6b0=;0/`3D
`KD0eLBf0=G8^`3Eb;d0e<Rn0=;:`@3Cb/<0d/[50=;;a03CblH0d/c70<g9``2a^lD0P92Y0:>>Y`37
Mh80b7=h0<R9SP2?OID0R6=n0;<oBP2g>T<0`h^<0:n^/01BG800TS580;874`2b0`d0WQHP0=O5c03:
e=l0a]?L0<C@f`33dMh0`M3O07ZB^@0>9fd00AAV000BHP014V000Q9H008BEP0145L00Q1604I>D`0H
dPl03000o`08ooooo`800?l000<0D91h0:0Pl02P8?00:02P8?00102h>;@0d51h0=1@N03@D7P20;Ph
]080oh0000@0d51h0:0Pl02P8?00j6Pl0`3oP00@0:0Pl003052@N000o`000?l000X00?l02oooool0
00[ooooo05@0B;LU0<G2`02ia/d0T9fS07b1Q00c5Q/0/ZB/0<S?f00N6R@09`H>068c4P3EXS40R2d=
0:<62`2/1Pl0Q@@906/1102?0`T0U0<908D1102d2Pd0d``>0=8<2`3D3@h0d0/=0<D42@3920h0cP`=
0<h?402?3Q00^ZVV0>k^kP3]kO00k>_^0>WLh02nTid0_iNS0>CLg`3ViNL0i^GX0>OYj@3XinP0n>7S
0<I@E03D6ah0bAdP07<]<P3Yjn`0inSY0>SYj`3Wi^T0j>7T0=RXZ`2W7b<0/PL>0;053P2]10h0[P<;
0:/32P2N0@L0U`4509<10P2@0P40S08308X20@2=0P<0S`450981202B0@D0V0450:821P2Y0PP0Y`88
0;853P2f2100/@D=0:X32P2S0@L0V08809032P2;0PL0Q08607<10@1j4@@4003o00Wooooo00<0D91h
0:0Pl02P8?001`2P8?000`3@D7P0X23`0?n0000A0?n000030:0Pl03@D7P0d51h0080X23`00<0d51h
0;Ph]02P8?00102P8?040?n000030=1@N02P8?00X23`00<0X23`00<0d51h0?n0003oP0007@3oP004
003o00Sooooo0P00o`00B`1ZgD`0SINK0:J^^@2IW:H0TYBQ03e2E`1jKWP0Qg5g08i_MP2FLGL0VgEi
09eeMP2QO7`0YX>10:Z5Q02cSHX0^IZA0;fMT@2nWi00`::A0<>XV03;/J40cKFV0<nk[03A`;<0c;Z/
0<jl[03A`;40d/2d0=C1]`3D`kH0eLVm0=?7_P3Aakh0dLW00=C:`P3BbLH0dLW50=;9``3BblL0c<W5
06EoW`1fPK40[De[0<PH8`3851`0^Q/T0;0nD02oI7T0]a4K0<L?5P30EeL0]k2_08NDZ`1a@600YPdK
0;@43P2W1a<0_i2I0<_Cg@37dm`0a=3I0<3@g@2G[/h01b1X004CHP014F0001=M00<GE`0K;5L09cQY
01HYFP0?7DL0<cm?02_7900<003o00Sooooo0P00o`000`1@T7P0X23`0:0Pl00X0:0Pl0030=1@N03o
P000oh0000H0oh000P2P8?001@3@D7P0oh000?n0003oP000d51h00l0X23`00<0D91h003o0000o`00
2P00o`0;ooooo`002_ooool0E014/b<0][>b0;g8d02AX:@0P8:703<G702eZ;40];_601TA700Z1Pl0
OdhI0<^D;@254PH0[0H;0;453@2G1Pl0I04507P@5`2061l0P`<90;h93@3A30`0dP/<0=D>403720/0
a0H=0<T93`3>2Pl0c`h?09H@4`2bXj@0k>c]0>WYk03Yj>X0eJb`0:hX;`2l7RH0T3<o0:RGX03Sh^D0
iNKW0>KXj@3]iND0ehN<0=0P903A61/0QQ<I0<2l_P3TinP0j^[/0>W[k@3Wi^P0im;C0:<m@02`2A40
/0<=0;053P2^0`/0[P8;0:L22@2O0PL0U04409010@2>0@80R`4108X20P2?0@<0U`460:822@2U0PL0
Y@46098110290P@0Y`H=0;H83`2a1@X0Z`<80:<11`2C0PP0P@4408L21`250@H0N04207D<0`@00?l0
2Oooool00`1@T7P0X23`0:0Pl0060:0Pl0030;Ph]03@D7P0oh000180oh00102P8?00103@D7P0oh00
0?n0003XJ3`50:0Pl0@0oh001P2P8?0O0?n000@00?l02?ooool2003o001;06[LCP2GXJ/0WZFc09fO
Z020Qi@0>dEH07a^N@26KgP0SVme09A`M`2LM7T0XGQj0:9nP02UP800ZX>20;:<R02gUXh0^Yb@0;nQ
U032XiD0aZZM0<Z`X03<]JH0d[^]0=:n/03?^j/0cKVZ0=2n/03A`[@0dl:i0=71^@3=`[/0d<Jn0=;8
`@3Ab/80e<_40=G>a`3DblH0eL_50=?;a`3=bl/0E72H0:VUdP2b>4d0d18H0<TC5@3>FUT0X4MJ0:D_
A0314ah0b@`C0;DV:`33Y:@0Y:^f0518J`286Bh0Z`DA0:X43P2[EV40c]7I0<K@f`35dM/0[l;L02<n
P0015fL00AAO00@JG@0iE8D0JX2M08nP]@0X?FD0F6f305]TMP0T<T@0>J@`00`00?l02?ooool2003o
0003052@N02P8?00X23`02P0X23`103oP0000`3XJ3`0oh000?n000020?n000030;Ph]02P8?00X23`
00<0oh0000<0j6Pl0:0Pl02P8?003@2P8?000`1hF;@00?l0003o000:003o00_ooooo000:ooooo`1D
04Fb902k^KX0_LWB08nNY@1eN7l0;a<H0;JX/P2W[[L04@`E02@52P2@H200ZfXO08T;1P2`1``0]0D;
0:h:4P1c0`H0i:6X0>>QZ02B4A@0aPX<0=4=3`3B3@l0c0P>0<052@321@/0b`/@0=0:3`3C41<0ZA8F
09Z4R03Yin/0iNGW0>KTi`3N_[h0YRX/0<@D602`6200?@P?0<W5a@3Vi^L0inSX0>k[j`3P/;40^b@W
0<hG6`2R5Q/0Th>60>;Vi`3UjNX0i^[[0>CViP3Vg=d0[V=V0:/;4`2[0`/0[08<0:d4302Y0P/0Y@49
0:421`2F0@T0TP440941102A0P@0S@4109800@2Q0@H0Y`490:H01`2S0@D0V`@908@1102I1P/0]`TC
0;84302^10X0Y@4809P1202700D0Q`4608H21@1k0@<0M@X21000o`09ooooo`03052@N02P8?00X23`
00P0X23`4`3oP0050:0Pl0@0oh00102P8?040?n000H0X23`00<0d51h0?n0003oP000703oP004003o
00Sooooo0P00o`00B`1RdCl0XZRb09RP[@2LX:d0@DmX02lhDP1lJgD0Pfae08a`M`2FLGT0W7Mm09ih
O02SNh00YWn10:V1P`2WPWl0]IJ?0;bLU@2oWi@0`ZBD0<BXV039[Yl0b[>T0=6kZ`34ZID0e;f[0<fj
ZP3?`;40d;nc0<jo^02cZ:00_;:/0;:/Z03Aal40dlW30=?;a@3BcLL0dlc50=G=b`3Dc<X0dL_<07B:
[P1:G940[E=^0<lC6P355QP0fIZG0;Ra]P1lJXD0VSE@0<8>5`2k3A<0bWn10:JVZ01?FgP0N4a]09H<
7@2W0`d0Ta<P0<nob036d]`0_/gO03E?S0026Vl011aU04UUT01MMiD0Kh^R07^BY@16HHH07cML06io
Q@1^NWl0;3U504n<A`0<003o00Sooooo0P00o`000`1@T7P0X23`0:0Pl00X0:0Pl0040>QX?03oP000
oh000=1@N080X23`00@0j6Pl0?n0003oP000d51h0P2P8?00103@D7P0oh000?n0003oP00@0:0Pl0`0
0?l02oooool000[ooooo05@0BkPX0;Fa/032c=D0UjJ/07n2Q`0b4aT0_k:i09RPZP0A31@08@D80:Ad
;02:?@d0TPT70:d42@2e1P/0]PL>09`83@2VAdd0YTU;0;TV9P3930d0``@80</=40351P`0``P<0<D8
3P382@/0c``=0<h<3P2i4aL0NUEG0>KRi@3Vi>L0i>CW0>KFe02XDdl0^QTL0<4H701[3180UXV:0>KV
iP3Wi^P0inKW0>oEe`2]>3`0`Q<H0;@G7@1eCe<0hnCU0>GUi`3Zj^`0iNGW0>?Mg`2oRH`0Y@lE0:`7
3P2]10d0[0<;0:T22P2U0PP0X@<809/1202L0@L0UP4409410`2F0@80X@860:T1202X0@P0Y@470:<1
1@2Q0PH0V@<809/32@2e2@l0]0D>0;04302T0@X0V`4809811P290@<0Q08407d2101g2P84003o00Wo
oooo00<0D91h0:0Pl02P8?001`2P8?000`2h>;@0oh000?n0000A0?n000030=1@N02P8?00X23`0080
X23`103oP0040:0Pl0@0oh0000<0d51h0:0Pl02P8?000`2P8?000`3@D7P0oh000?n0000L0?n000@0
0?l02?ooool2003o000V037V7`2QWj@0Vj>_09BHYP0N9TL0?41J07UZM024KGL0Rfmh09A`NP2HMG`0
XG^30:9iOP2VOh40ZX>50:J1OP2dTX`0^IZA0;nNT`30Wi40aJRG0<R^WP38[Ih0cKJW0=2iZ@3@^jX0
cKZZ0<no/03@`;@0c[ni0;R]Y`3<a;/0]:nW0=39`03Cbl80dl_40=?=b03BblP20=?=b`0S0=79b@2`
^<X0;4ak089WS`316BD0cA8I0<iOH@36];00Zjbg05aEQ02Z7C80`0T>0:h]<@2n[J`0TI^Z02`_E`25
:D@0Y@@A09h54P2eNhD0bM7N06f4[P027Vl03bm`07VF]@2a`m<0KHBJ07J?Y01TOJ0042UK07:6U@1d
Oh<0Lgao0351B`1MGE@03000o`08ooooo`800?l000<0D91h0:0Pl02P8?00:02P8?00102h>;@0oh00
0?n0003oP0030:0Pl0<0oh0000@0^3Rd0:0Pl02P8?00j6Pl0P3oP0000`3@D7P0X23`0:0Pl00=0:0P
l0`00?l02oooool000[ooooo05D0A:lL0;bd/P33c=D0VJN/07AjO@0_61/0b<3708N@V00D2a<08`L6
0;9o;01`5@40V@H70;453@2h1@h0^0@=0;842P2i51T0]@lC0<893@3:2@`0`PD:0<06302n1@T0``L;
0<H62P3:2`d0c@h<0<h>3`344AH0HalS0=gGf@3Vi>H0iNGV0>SShP3EZjL0Z2HU0<LF6@2W6Ah0ID12
0>7Qh03Wi^H0inGV0>kTi03;Oh40_1dO0;`C6@1S6b00dm3B0>?Qi03UiNL0hN7T0>3Mh03I_Kh0W1XO
0:d73`2_10d0[P<<0:T32P2W0PX0Z0@<0:L32`2T00/0XP480:011@2U0@D0Z0470:/22@2X0@L0Y@47
0:811@2R0@H0Y`890:P22@2a1Pd0]@L?0:d1302R0PX0V04808l11P260@@0P04507h21@1h1`808LL1
00<00?l02Oooool00`1@T7P0X23`0:0Pl0070:0Pl0030;Ph]03oP000oh000140oh0000<0d51h0:0P
l02P8?000`2P8?030?n000050=1@N02P8?00X23`0:0Pl02h>;@00`3oP0000`3@D7P0X23`0:0Pl004
0:0Pl1h0oh0000@0D91h003o0000o`000?l02?ooool2003o001<01K`2`30^[T0WJJd0:>X^00W;Th0
ATMN071RJ`21KWL0RFmf099_N02HLgX0WGUo0::0P`2INGd0Xgj20:R1P02aRhP0]iB;0;bLSP2mX940
_J>A0<J^W@3;/J<0c[JW0<fiZP3=^j`0c;RZ0<nm[`3=_Jl0d<2d0;jbZP2j/J/0bL6h0<o8`03@b/<0
e<o80=G>a`3Cc<P0c<S70=3<b`3?b<H0bLS:0:>dc@1GJIP0]3eA0<dA6@327b@0e9nL0;Rd/P1]NYd0
Rd5V0;d=602`3A@0^7n00:6QY`1UKHX0GcYL09`8602U0`l0V30l0<S7f@0G=G@073ek09VfcP2ibmD0
]/GB05abS`0dD7X02BAG06IjT`1nR8h0M7j006UgO@0[?Td0FemF00Kc0`/00?l02?ooool2003o0003
02S8?02P8?00X23`02T0X23`00@0j6Pl0?n0003oP000d51h0P2P8?00103@D7P0oh000?n0003@D7P2
0:0Pl0040;Ph]03oP000oh000?n000l0X23`00<0:<Pl003o0000o`002@00o`0;ooooo`002_ooool0
E@13[AT0^;2_0<_Dg@2AWjH0PhR=038J8`37`l`0LW^5014:400[3P@0[WL]06/80@2L1`/0/`L=0;P5
2P2i1@T0^@<80<H93@3520T0aPP90<X930311PX0^0860;`52P3120`0`0@90<H72`3:3@d0b@`=0<49
3P1_3140b<720>GUi@3UiNH0i^GV0>GCd@2/ADD0aQDJ0;hH7P1L5ad0dM3?0>?Rh03WinL0jnKX0=f[
[P2Z8R@0`1@F07D?4`2d[Zl0h^;R0>;Rh`3Pgn40g]kP0=k?d02O<3L0[PTC0;463P2/0PX0Z@8:0:L3
2`2V0PX0Y`4<0:T02`2a0P/0[`<80:T11P2Y0@P0ZP470:P11`2U0@D0X@440:811`2U0@T0YP450;46
3@2b10h0[08=0:412P2E0@L0S@4608D11P1l00@0NP4507@50P0Qa`800`00o`09ooooo`03052@N02P
8?00X23`00L0X23`00<0d51h0?n0003oP0004P3oP0050:0Pl0<0oh0000<0d51h0:0Pl02P8?000P2P
8?040?n000H0X23`7P3oP000101@T7P00?l0003o0000o`08ooooo`<00?l004/0aKVa09^W]`2GVj/0
@DMS04e<G`1eJ6h0OVYa08E/L@2@LGT0V79j0:5gO@2JLWX0UG9h09EgNP2YQHD0/H^70;F@R02mW980
_Z6B0;nPT035ZYX0a:^I0<ZdX`3:]ZP0c[V[0<^gZ`3?^jh0c[b_0<^n/@3>`[P0c<6k0=36`03>al80
cl_40=CBcP3Dcl/0dL_:0<g:b03>cLP0c<[60<g7aP39b<d0MX^[095UR0345R00bQ0G0<IGF@2m[ZX0
Z[2m05A:N`2V52P0^@TB0:Xn@`2^XZ@0U9RU04Y:K`2:73<0XP8@08l64`2POiH02bUV09>ac`2kcMP0
^L_G09:ZbP0R?g@03bUH05=ZQP1oSiH0KWUn06EcN00kCFL06BiB05MSI00LaQ402`00o`08ooooo`<0
0?l0:`2P8?00103@D7P0oh000?n0003oP0030:0Pl0<0oh000`2P8?030?n000030;Ph]02P8?00X23`
00`0X23`00<0D91h003o0000o`002@00o`0;ooooo`002_ooool0E@14[AX0]jbX0<K?e`2FYJ/0Kg9e
038K8`3;b=80H6Ua01L:3`117`d0Y6LW07P9102C0`P0Y`@:0;X83@2o2@`0_`D:0<T;3@362P`0aPP;
0<<62`2f0`X0/`@:0;@42`2k1@`0^`@;0;l630332@`0`PT;0<<:3`2@3aD0Uh^;0>CSi03ThnD0iN?V
0>_QhP2oMG@0aA/L0<HF6P1h41L0Z:6T0>7Og`3Rhn80hnGU0>S?c`2S>3`0_AHI09@C6029O7h0h>;Q
0=oQhP3Ph>40g]kN0>7If`2RCU<0ZP`C0;873`2]10d0[0D<0:D22`2W0`h0[@<=0;H33P2j10`0^0@<
0:h12P2[0PT0Z`880:P1202U0PP0XP470:021P2S0@P0Y0480:h4302b1Pl0Z08:09l11`2F0@H0S@46
08@1201l0@H0NP8407D50P0Qa`800`00o`09ooooo`03052@N02P8?00X23`00L0X23`00<0d51h0?n0
003oP0004P3oP0050:0Pl0040=1@N03oP000oh000?n000@0X23`00@0^3Rd0?n0003oP000oh001P2P
8?000`3XJ3`0oh000?n0000K0?n00004052@N000o`000?l0003o00Sooooo0`00o`00B`2Tb940TYb[
09nU/P0M9d40DEIZ06mVK@1nJg40QVaf08e[M`2LMH00XWR009A/M@2RPhD0bKZl0<jk`@2]S8d0]92:
0;RHR`2lWXl0^if?0:VCQP2UThL0_jbM0<JbX`3;]:L0bkFX0<bg[03A_kP0c[jg0<g1^039`KX0clNo
0<o7`03?b/80d/o:0=??b`3Ac/X0cL_60<c:a`3<c<P0c<S40<c8aP2j_ld0FfVF0;0c@`3<41L0_Q`O
0<nLV`2k]kT0K7VL0910H02j3AL0YPhG0<>JW`2QXJ`0I6b806deE@2K1AD0W0<>084W?P0Z@7<0[<[X
09Vbd01@KYh03bmV04m_T`2=X[<0UZJ`08nPZ01[OHd0:SeP008@A0013D@0=4=J02bX8`0;003o00So
oooo0`00o`0/0:0Pl0<0oh0000@0d51h0:0Pl02P8?00j6Pl0P3oP000102h>;@0X23`0:0Pl03@D7P2
0?n000030>QX?02P8?00X23`00`0X23`00<0D91h003o0000o`002@00o`0;ooooo`002_ooool0E@17
/A`0^:^U0<[Df`2@XJP0LgAi03TS:P3BdMT0BdeJ01T7301L>aT0O3dI07l82`2I0`/0Z`@;0;P53@2n
1`d0_`H:0<T:303:2@`0a`P;0;/62P2`0`/0XP4709L21@2/1@d0]`@=0;/53@2m1``0_PP=0<4;402^
41L0J4Q80=WJfP3Rh^80hn;S0>CSh@3I];@0]R<U0<DD5`2R5a/0LUYO0>3Nh@3Ph>80h>7R0>WNg`2m
Oh80ZaTP0;4F7@1Y@DD0f][L0>3Oh@3Ng]l0h=oP0>3Mg@2iPH<0XQ@I0;893`2`1@d0[@@=09d21`2P
10T0]`L?0;X4302j0`/0^@@:0;@42`2Z00D0Y@450:H2202T0@L0XP470:011P2H0PH0T@460:d73P2[
0`X0YP4709d11`2E0PH0RP4507h11@1f0P@0M04107D60P0Qa`800`00o`09ooooo`03052@N02P8?00
X23`00L0X23`00<0d51h0?n0003oP0004P3oP0000`3@D7P0X23`0:0Pl0020:0Pl0050;Ph]03oP000
oh000?n0002h>;@0102P8?00103@D7P0oh000?n0003@D7P50:0Pl0030=1@N03oP000oh0001/0oh00
00@0D91h003o0000o`000?l02?ooool3003o001;09O9N`2EWZ/0V9b]02TdEP0>6dT0@45M07aYLP25
JG@0T6mj09YcP02OMGl0UW1g0;>QY@2`X:T0`Jjf0:^>T02^RX@0^9N;0;BFR@2YT8<0SWmi08UmNP2T
UX`0`:ZK0<F_X037/J<0b[N/0<jo^03@`k`0cL:j0<_3^P3>a[h0d<[40=3:`P3AcLP0e<o>0=3<b`3=
blP0c/[60<k9aP3=al<0b<C10<S7bP1[PJD0TF>30<4D7@3:41L0b5MK0<VTZ@2gXK<0WFR60;@C8P2d
1a00Yda@0<Bk_`2GWjh0ASaR08P;702L0Pd0Q`/H06=HO00P?7D06SM]04aXT01aR:@0HWjB08NMZP1i
RY@0FFb200XLC`022dH00@U1004=@00N<4l0?hhk00/00?l02?ooool3003o02`0X23`00L0d51h0?n0
003oP000oh000;Ph]02P8?00d51h0080oh0000@0j6Pl0:0Pl02P8?00X23`0`3oP00?0:0Pl0/00?l0
2oooool000[ooooo03@0@JL?0:^IT03:d]/0W:^e071`MP1==d00e]OP03Db?@0R20X0NE8T06LK302<
1Ph0Y`D=0;@53@2h1P/0^PH:0;d62P3:2Ph0b`T=0<062P2/0@P0[08;0:T32P2Y1@/0[`H90;H52@2e
1@`0^0L>0;T73@2m2A40]`dF05`G6P2o_Kl0h>;S0>;ShP3Shn80h=GE0;M/I`38HeT0_VUP09b0O03L
e]D0hn;Q0>7QhP3UhN@0gKfn0:8Y<02i4AT0G1DI0;fm_`3Og^00h=oQ0P3Ng]l07`3D][P0TR4W0;<<
502f20d0^0H;0;d93`2g1P`0_0H<0;d53@2l10X0^0@90;44202W0PH0W`440:411`2R0@L0Y0880:41
1P2O0@H0W0<:0:X63P2^1@h0YP8;09/11P2A0PH0Q`4507/1101b0P@0K@43078<200Sb`L00`00o`09
ooooo`03052@N02P8?00X23`00L0X23`5@3oP0000`3@D7P0X23`0:0Pl0030:0Pl0030>QX?03oP000
j6Pl00H0X23`0P3oP0000`3@D7P0X23`0:0Pl0040:0Pl1d0oh0000@0D91h003o0000o`000?l02?oo
ool3003o001;06cQF@2KXk80RXjR00P@>0022D009bYD07MVL`22JW@0Sfii09E_N`2IKWT0WG9k0;bT
ZP2WSYD0_ZJ[0:N8R02YQGh0[hf40:n?PP2URgh0LFET071YJ02GRGl0_ZRI0<:^W035/:00bKNY0<Rl
/@3?`k`0cL:j0<c4^@3?al00c/S50<c8``3BclX0eM?>0=;?bP3@cLX0cLS60<k:a`3<b<D0bLG40<S7
aP2f_LX0HFZD0:DkC@2o61`0^adO0:dY;`2X9S00ZRH]0:lJ7`2X5aT0V3/k0;:TY`2IXJ`0AU=e07PW
@@2J0`h0T@D@0;20R`2nbML0^l_I0;[9e@2a`<h0L8ZU03UGO@1IN9D0Efn8004AB`013D8031]003A5
F00O<dP0D71?00/00?l02?ooool3003o0003052@N02P8?00X23`02X0X23`00<0j6Pl0?n0003oP000
1@3oP0001@3XJ3`0X23`0:0Pl02P8?00j6Pl0080oh0000<0d51h0:0Pl02P8?00302P8?0;003o00_o
oooo000:ooooo`1E04:W3`3;^:d0b=7I08bKX`1_KgD0GDYC0=?Gg`0S8RX08@L509=X<`1R2`@0T08:
0:`53@2f1P/0_0L:0;d82@301`/0b@P@0<P93P2j1@X0[@8:0:/12@2_10/0/0@90;@62@2f1PT0/`@<
0;<3302h1`d0^@T?0;L94P1h3A<0N6=Z0=WGf@3QhN80gn7P0>;Ph03Xg]T0k]kI0>[Of@3Wgmd0hn3N
0>3PgP3Nh=l0h=kP0>G7b`2W<3L0_@lE06X:3P28PX@0fm[L0>7Oi03Pgn@0g]gQ0=c:cP2NA4`0/@hF
0<8;3`332@l0`0T>0;X53@2h1@d0^@<=0;`43@2f0`/0/P@<0:/12@2Q0@D0X`470:D11`2X0@L0YP47
0:@01`2U0@X0[0@;0:h4302V0@`0W04808d1201o0PH0N0440701101X00<0J0T702NY1P03003o00Wo
oooo00<0D91h0:0Pl02P8?001`2P8?0F0?n000h0X23`0`3oP0060:0Pl1d0oh0000@0D91h003o0000
o`000?l02?ooool3003o001<05WL@02KWJX0EUaf0086;P011CT082A@07UXMP25JWD0SVih09A]M@2J
L7D0WGAj0:>3Q`2lXjP0Y8B80:N4OP2VPWX0ZHAk0:n=P02`Th80ZI:50::=P@2bVXd0_ZJF0<6[V`36
/J80akJV0<Vm/@3<`KT0c/Fm0<_4^`3=al00blO10<o:aP3Fdlh0emGB0=SEd`3Ed<l0c/c;0<c:bP3;
bLP0b<G40<O5`P36`lD0];G20:^NZ036VYH0aYR@0;nIT@2oVY@0`9nJ0;jNV`2gVIH0^:VX0:FY[@2R
[k`0Ig^E05DfF02B1QP0V@8?09De@@3?cMD0`<gI0;S:eP26Vjd0A5f600<IHP087e/0IGnE00PMB@0^
@5T0EF=V05IRH@0Y>DH0HfYY00Cb0PX00?l02?ooool3003o0003052@N02P8?00X23`02/0X23`1@3@
D7P00`2h>;@0X23`0:0Pl0030:0Pl0040;Ph]03oP000oh000>QX?0h0X23`00<0:<Pl003o0000o`00
2000o`0;ooooo`002_ooool0E@17ZA80/ifE0<KAf02M[KD0GEaR079QJP3:c]P05a@M0207102CI2l0
M@X709T53P2/1@d0^0H<0;l830302@/0`@T<0<4630312A00/`<90:h32`2^0PX0[0870:h3202b10X0
/PD;0;843@2e1@h0]`H<0;L73`2g2A40YA0G06DB702[Qi00h=?H0>3Ef03Pd]P0gLcA0=O4b@3F_lH0
f[c30=Bc^`3>[K<0cjZb0<bLY`2oJWD0ZaLP0;d;4@293180BSHh0=OHfP3Rh^H0gmoS0=oOh@3Rf=/0
`hF:0:lF6`393Q40a@T?0;l93`2X0`T0ZP<;0;43302b0P`0/@8;0:d22`2X0@P0X`860:D21`2V0@L0
ZP880;852`2W0@H0Y`870:`42`2Z0`/0YP4909d11`2:0PL0MP4607H1201^0@D0IP4206@61P0_R0L0
0`00o`09ooooo`0306RX?02P8?00X23`00H0X23`00<0^3Rd0?n0003oP0005@3oP0000`2h>;@0X23`
0:0Pl0050:0Pl0040;Ph]03@D7P0d51h0=1@N0@0oh001P2P8?000`3@D7P0oh000?n0000J0?n00004
08300000o`000?l0003o00Sooooo0`00o`00C00aj240X9nW02ldDP021Rh03a8m02DYCP1kIWH0QfUg
08aXM@2CK7L0WG=l09icO@2QMG`0YWYl0:=hN@2TNGP0X7Ma0:N2M02bThD0/iR80;RNS`2iXHl0_JBD
0;nVU`32ZYP0aJnP0<ReZ037_;00b/2g0<g5_@3=akl0blK00<[6`@3Bcl/0eM7>0=GCd03GeM@0dm3A
0<_:b`3:b/P0blW50<S7`P36a/80`/;10<C1`@2n_K`0_;Vh0;Vf]02d/:l0/Jb[0:nYZ02/YJ@0/Zj^
0:>PY@2^[k@0YjVb0:Zhb`12@f`0QQD]09/240292AD0a:Vc0<3=eP2ibM@0Oi>V06n3W`076U@00aM@
061fQ`1PLGP0GFi/05aZI01HIFL083A006ikN`0Dd0l:003o00Sooooo0`00o`000`1@T7P0X23`0:0P
l00g0:0Pl0<0oh0000<0^3Rd0:0Pl02P8?002`2P8?000`1@T7P00?l0003o0008003o00_ooooo000:
ooooo`1204BU3@2PPWP0bm7H08jPY01HFed0SH690;Bh``0B2Q40>ad:08IC:@1c1@L0WP@>0:`52`2f
10`0_@L=0<483@301`X0^PH:0;<52P2Z0@P0ZP890:X32@2Y0`P0Z`@:0:l32P2c1@d0]0@=0;@53P2f
1`l0]PL>0;L:3`2j3Q@0]PlG0:XG8@2d>dL0/3]80:ld@@2]:cP0Z24^0:hS<@2]7RX0/Q/X0;8H902`
6280/QDQ0;LB602n4A@0aQ4E0;0E600i10L0_ko30>;SiP3RhnL0hN;U0>3Og`3M_[l0[c8d0<4=4030
2@d0^@@;0;022`2Y0PP0Z0460:T1202W0@L0Y@470P2S0@L04@2W0PT0YP480:T22@2d1Pd0[P880:h4
2P2]10/0Z0<90:L2202N0@H0SP4808<11`1m0PH0K`4406P10`1Q10<0<HL600<00?l02Oooool00`20
`000X23`0:0Pl0060:0Pl0030=1@N03oP000oh0002H0oh001P2P8?0L0?n0000408300000o`000?l0
003o00Sooooo0`00o`00C00ZgQ<0Zj>T01HL?00G6C@0DdUM03PdC@1kJGL0PFEd08=MKP2>IG80VVmj
09e`N`2OKgT0Y7=j09iaL`2QM7@0Y7Uf0:^6N`2_Sh00/iJ60;FHR02iWhd0_::C0<2UUP31ZiX0`jfQ
0<JdZ037_[80bKne0<_2^`3=aKl0bL6m0<g9a`3Cdm40clo>0=?Ad@3Ad=40dm;C0<g:bP3:b<T0b<O6
0<;2_`2i_l<0Y;2k0<JW/037Ti`0`X>=0<9dP@2jJ7<0]UeY0;1DH@2`CU`0Zd]D0:Q9EP2gGFh0[UQ/
08`mF01o=e40UAd_09X2402?0Q00XUQX0<Bjc032a=80Wj^f09JW]01jS9d0D6=g07:0Q`1_Ng`0IFi_
05YXJP0[?5004RHn05EXJ`0[Yb@:003o00Sooooo0`00o`000`1@T7P0X23`0:0Pl00Y0:0Pl0030;Ph
]03@D7P0d51h00@0d51h0P3oP0000`3XJ3`0d51h0=1@N0020=1@N0<0oh0000<0j6Pl0:0Pl02P8?00
2`2P8?000`1@T7P00?l0003o0008003o00_ooooo000:ooooo`0S04JT2`28HUH0blgD09n`]@1ACU40
YiZQ09jS[@0G20`0J4DU07@h702210d0X08=0:d42`2e1@d0_PL>0<09302n1PP0^PP:0:h11`2[0PT0
YP450:L2202P0@H0X`460;032`2e10d0/`@=0;833@2d10h0^0LA0;D83`2f2Q40_@dF0;/>502e3QD0
0P2g4QL0<02k51L0^a8H0;`C6@2j4QP0_A@H0;`E5`2i5aX0]aHH0;PE5@2k5AD0aQLI0;`J6P1N30h0
UhnB0>;TiP3Uj>X0i>CW0>7OhP3WfM/0]5=F0;h?402l2@d0]0@;0:l22`2[0PT0YP430:P11P2V00H0
Y0860:001P2R0@H0Y`880:@01`2X0PT0/@D=0;042`2_0`/0[P<;0:P1202W0PT0WP4809411P270@H0
N`4306h20P1V0@80H@8102j20@<00?l02Oooool00`20`000X23`0:0Pl0060:0Pl0030=1@N03oP000
oh0002H0oh001P2P8?0L0?n0000408300000o`000?l0003o00Sooooo0`00o`00C00Zf``0ZiZE00TA
;@1<BEL0FTmI04Q0D`1hHfl0O5i/07mIJ@2BIg<0Ufej08eZO@2HLGh0WFed09a/KP2OMG40YWaf0:R1
M`2XQgL0/9:10;>GR02eWY00^J6C0;jWV02oZYd0`ZnR0<:cY033^Zl0aknd0<[1^03>aKh0a/:l0<c9
a`3=cLT0d=3>0=3@d@3Ad=40c/k=0<[;bP39b<H0a/G40<?4``2f_/P0CFJC0:9;H02h7RH0]Q`P0;DM
8`2b7bH0[R8S0:XW9`2W:2P0XbPV0:@Y9`2U:2/0XBHY09/O9`2E6B<0TQ@M094<5@2@21<0R`XK088D
:P2293X0R69]07f9T`24UIP0N8J907=lOP1bOWd0IG1e02LgE@012SP00@Tc0353D`0^WR`:003o00So
oooo0`00o`000`1@T7P0X23`0:0Pl00Y0:0Pl0030>QX?03oP000oh000140oh0000<0^3Rd0:0Pl02P
8?00202P8?000`1hF;@00?l0003o0008003o00_ooooo000:ooooo`1E04VV302HL6H0blkF08bKXP1H
DET0_[>l08N;UP0O2P`0WGE106HO3P2A1Ph0Y`@=0:`42`2g1`l0_0H>0;l7302j1@/0[`890:H11P2Z
0PT0Z@880:X32@2Y0@P0ZP890;042`2a10T0/`D<0;@53P2e1@l0]`P@0;4<3`2/4Q00[QPC0:dK5P2_
91h0[2/Q0:/a:@2e@c`0]dY30;aCC02mGED0`FIM0<A^I@2mKF@0`71Y0<EeL03:NG<0cWMb0=5lM`2W
MG00[JBP0>3Qh03Si>@0h>7S0>7Pi03SgN00]GUi0:XM6@2/4Q40Z0X=0:L52`2W0PP0YP460:P1202V
0@L0Y0480:@12@2U0@P0Y@470:D12P2X0PT0/PH;0;<42`2a0`/0Z`8:0:/22`2Y0Pd0X@4;08d11`1n
0P@0O@4507410`1R0040GP8203^A3`03003o00Wooooo00<0P<000:0Pl02P8?001P2P8?000`3XJ3`0
oh000?n0000O0?n000<0d51h0`3oP0000`3@D7P0X23`0:0Pl0040:0Pl0030=1@N03oP000oh0001T0
oh0000@0P<00003o0000o`000?l02?ooool4003o001;0:F9O00<42`0HeUV05M:E@1;B5T0Kem/07UI
IP25GV`0T6Ed075HM@0G6U40DDM/09MZLP2KJf`0XgEd0:IgM@2UO7@0[8Uj0;:APP2[THH0V8Yo0;:P
T`2jY9P0^jNL0<6]X@31[jD0`[R_0<Jl/`38_kL0c<Bm0<g8``3=blH0c/g90<g<b`3=bld0c/k=0<W;
b@3;c</0alK50<G4a@32`<80_l34086?ZP2/VZL0aY>A0<RMU`38Y:40`:FR0;fWXP2gYj40]JBQ0;JV
X`2UVYD0/ZNV0:fSY02m]KX0Z:B]0;R]/P2iXZL0[hnD0:AlP@2CHVH0P4A>07=>E@2NYjd0NHN>07J2
Q@1YMWH0IgEf04IEJ00234000PPj0049=00C93l0=fXk00X00?l02?ooool4003o02/0X23`00@0^3Rd
0=1@N03@D7P0d51h302P8?001@2h>;@0d51h0=1@N03@D7P0^3Rd00/0X23`2P00o`0;ooooo`002_oo
ool0@@1;YP`0QUQ=0<O9d@2?WJ@0CTM?0=7:d`1WKWH0;aL=0:EgAP1E2080S0@;09h53@2G0PP0WP<8
0;H73@2k2100[08:0:X32`2V0@L0Z`890:T22@2]0PP0[`870:l3302R0PP0W`460;063P2e1Ph0/`D>
0:L;4028=c80cIR;0=R]X`3L^jh0i<No0>O@b@3Ve/l0j=cG0>SLfP3WfmX0jN3M0>GQg@3RhMh0hn3P
0>?Qh03RhN40i>7S0>?QhP3Th^80hN?Q0>OWi`3ShnD0hnCT0>7Qh`3Ph>@0hN7T0=cCdP3H^kP0cJFQ
0<2@RP2[FeT0VPD:0:H1202X0@P0YP470080Y@490180YP4:0:H2202T0PX0Y08:0:h42`2d1@d0/@@;
0:l4302]10d0Z08<0:822P2<0PP0MP4207X21@1c0@@0IP4205d20@0nUQ@3003o00Wooooo00<0P<00
0:0Pl02P8?001P2P8?0E0?n000030>QX?03@D7P0d51h00<0d51h5@2P8?00102h>;@0d51h0=1@N03X
J3`G0?n0000408300000o`000?l0003o00Sooooo1000o`007`2EVVP07R4f06=GH@1:@4l04aa003/i
E01eFfL0QF9`08AQM`0c:E80BD=`030[EP2BIg40Vf]]0:5aL@2XNGH0Z7mi0:Z6N@2cTH80X8Ml08eo
M@2EQg`0]:6F0;RUV02n[Ih0_[:V0<2g[`35^kD0akji0<O2_`3<b<@00P3=bLL0:P3>b/L0cLg;0<c<
c@39b/X0bl_:0<K5a@36a<H0`<300<71`@2o_kl0_;jn0;bl^`2i^[H0][Jh0;:b]@2][Zl0ZZV/0:NV
Z@2RXj@0Zk2a0;No``2`^/@0OI>]07bE[@35eN40a]?O0<OBgP35dMX0a/oH08>?X01nSIT0Uj>[09RS
ZP1jQH/0IWEc065cL`0L:dl00P]300DC>`0R<TT04B4h04=:C@X00?l02?ooool4003o04/0X23`2P00
o`0;ooooo`002_ooool0>01=Z0h0N4Lm0<6ob02GYZ`0EUAI0=OCg01>E5`0Ab/K07M69`1F1P<0S`D>
09P22`2@0@T0U@470;45302e1Pd0Y0080:H1202Z0PP0[0890:P1202^0`T0/04;0:l32P2]10/0Z`8:
0;@53`2d1Pd0]@H=0:/=501N=3D0g=GE0>;Oh03Pgmd0h=gN0>3Nh03Qgn40h]oS0>CMh`3Qf^00h][P
0=_Gg03Ie=X0gMGL0=kHg03Le]X0fm?I0=cEf`3Mem`0gMWN0=kIg`3Pg>00h]kR0>GOiP3Sh>@0hN3U
0P3Ng^806`3KfMh0fMCH0<BUY`2=2Q00YP490:L22@2U0@H0Y0480:812P2T0@X0Y00909l12`2K0@X0
Z@8;0;053P2]0PX0/@D?0:d53P2W0PT0X04708`11`220@H0O04507410`1S0@40F`4204mC3@03003o
00Wooooo00<0P<000:0Pl02P8?001P2P8?0E0?n000030=1@N02P8?00X23`01`0X23`5`3oP000103@
D7P00?l0003o0000o`08ooooo`@00?l00340NJi<03Ha?@1YGf80>S530088=`0]:dl0Mei/081PL01R
CVX0DTEV05A5JP0i;eX0TfA]09aXJ`2OL6d0Y7Ud0:AlMP2ZQW`0/9600:2:N@2UTX@0YYB70:jLT02i
Yi/0^ZfN0;ZbY`2o]jh0a;Ze0<Fn^038`l00c<S50<g8a`3;b<H0blS80<c;c03;bL`0bl[<0<W8bP37
aLH0`l720<71`02m`;d0`lK50;bo`02j_;`0]kNi0;2c]@2`/[@0[[6b0080ZZb_01T0X:BU0:2VZ02H
X:<0Z[Fm0:Bea02E/LX0`mGO0<CCg`36e>00a=;N0;o>fP2AY[H0P9>P08>AV`1hQX/0LGb006MdL`1P
LWD021E300XKA@13FF00DV9P02LfA@0iBE001^@400T00?l02?ooool4003o04/0X23`00<0D91h003o
0000o`001`00o`0;ooooo`002_ooool0501:Y@`0G2XQ0;2]]02FXjX0DTiD0=OGh00^<S`0FS`V04PG
1`1F0`<0SP<<09X12@2I0@T0Z@D>0;@84@2`1P/0Z@<90:/22P2[0@P0[P8:0P2[0PT0?`2/0PL0[P@:
0;442`2d1@`0/`D<0;@63`2e1Pd0]P/D06LE6P3LaLX0hlkD0=Bh`03<YJd0`IFN0;V7T02cMX40/Vih
0;1XM02bHG40[eUY0;5GI`2lFfX0aUi]0<9FI038FfT0b5][0<AJJ`34Gfl0`F5`0<5ZM`38N8D0b7f;
0<b8UP3>UJ80bYbY0<bZ]@3:/K/0bkJo0<6TZP2@61h0YP8:0:P22`2V0@P0Y@480:@22P2S0@/0X`4=
0:<2302L0PX0X`490:/42`2a1@h0/PL=0:/42`2W0`X0W`8908d11`220@H0N`460741101T0@80FP41
04mD3003003o00Wooooo00<0P<000:0Pl02P8?001@2P8?000`3@D7P0oh000?n0000C0?n000040>QX
?02P8?00X23`0:0Pl0T0d51h1`3oP0000`3XJ3`0d51h0=1@N0050=1@N0<0X23`5`3oP000103@D7P0
0?l0003o0000o`08ooooo`@00?l004`0FlDd069JHP1XGfD0;2Lk0087=`0W9Th0MUa/089SM011=ED0
N6B1034ZF@1:>V00U6=/09]YJ`2OKfl0XWIb0:EjM@2ZQ7T0/96309b7N02YV8d0XY250;:NT02iZ9/0
^ZbO0;^cZ@32^[<0`kRf0<:j]P38`k`0cLW40<c8aP3:a/L0blO60<S7b@38b</0cLS=0<W5bP34a<H0
_;no0;o1`P2j_[d0^;bo0;^n`@2h^K/0];Bi0:ja]02^/[@0[KJg0:R^/02RYZT0Wj>U0;6i^038dMH0
VJFd086H[018IhD0a=KR0<CBgP33dN00aM;M0:jlb`0mEFd0UZRd09b[/P1eQhX0NXV:06EcKP1OLGH0
118o0313G01IJfP0EVES02PhBP0S>D`01/H92@00o`08ooooo`@00?l000<0D91h0:0Pl02P8?00B02P
8?000`1@T7P00?l0003o0007003o00_ooooo000:ooooo`1004^V3P1=6A40WIRM07j8S01PG680b<_B
01<B5`1N?RP0?0@107442P2I0``0X`8=0:X33@2U10h0SP8709d52`2W0PT0[@8:0;822P2c0`T0/P89
0;@32P2b0PP0/0880;852P2b10`0/`8=0;@53`2e1Pd0]PLA0:d<5@2h;SP0]2Hc0;8J:02c5240/@lL
0;0>6@2b3QH0/`hH0;@B6P2e4AP0^@lI0;h>5`3;4QX0da8J0=LC5`3H4aP0e14I0=@A603B41P0ca0H
0<P=5P3431L0aPhK0<TA6`303a/0^PhL0;DC8P2W5RD0XQl]0:<Y=P2Q41/0Y`8:0:H12080Y04701<0
XP470:<22P2S0@X0Y0490:@12P2Q0@L0Y0460:d3302c1Pl0ZP<;0:@22P2K0@P0SP460801101i0@<0
L08306810@1I0@00D5@<00<00?l02Oooool00`20`000oh000:0Pl0050:0Pl4`0oh0000@0d51h003o
0000o`000?l02?ooool4003o001<02WL5@1^HFP0IUmZ024N=`042cT0;2a>075JIP21I7D0=bm?07i[
R@0A4dX0Je9^095OIP2KJf`0WVa`0:9`L02TMg40ZX=h0:j>P@2^U8D0VhMl0:NCQ`2hXi<0^JJI0;^[
X@2i[jD0`[Zb0<>h/`34^[D0b<6m0<W4a039aL<0b/S70<O5``37a/T0bLO<0<K5b035a<L0`/;40;c0
_@2j_k/0^[fl0;Zk_`2h^K`0]KJj0;>f^P2a];P0ZJ^_08fBT`2TZj`0XJR[0:B]]02DWJ@0YZff09jT
/P2b_ld0[[c80<OFgP36dn00`];N0<?Cg@2__/`0X[K409NW/P20SYL0NXV=06mlO01XMg<0I7Eh00TH
?P1=Hf`0FFa[04mPJ00@7Cl01ADi00FW40T00?l02?ooool4003o0003052@N02P8?00X23`04P0X23`
00<0D91h003o0000o`001`00o`0;ooooo`002_ooool05@1<Y`d0C1@<09>9SP1OJFX0G5UO0:6RZ`0C
1`T0ICXV04l51`1l0`X0V`8<0:@1302Y0`h0U0<908001P2@0`/0WP4:0:T21`2b0PT0]@8:0;L32P02
0;L32@0X0;@32@2b10`0/`<:0;D4302i1@l0^PH?0;/7402k20l0^PPA0;X64@2l2A80_@/B0;`;502o
2a@0_`dF0<0=5P2k31@0^@`A0<PA503>4A<0e18H0=H@503M5QL0gADG0=L?5@3F3Q80dP`A0<`94@3<
2Q@0b@PB0</84@381Pl0b0PA0<@8403120h0]`D=0;04302Y0PX0Z08:0:P12@80Y@4801@0Y0480:41
202R0PT0X0490:<12`2S0@T0X0470:801`2X0PX0/PL?0:T22`2R0@T0VP4608`11`200@H0MP420702
0`1U0P<0G08105=D3P<00?l02Oooool00`20`000oh000:0Pl0040:0Pl0030;Ph]03oP000oh0004X0
oh0000@0d51h003o0000o`000?l02?ooool4003o001<027V3P1gHf40If9_014B;00`=U<0@cmF079M
J01fHW<0=c5C04U3J`0H6Dh0QEmd099PIP2JJ6/0VfIZ09iXJ@2QLFd0ZhAl0;:@Q@2eUHP0]I^=0;JO
T@2fX900^jJH0;ZYWP2i[JD0`;F_0<2f/033^k@0a[nl0<W5a@38a/@0alG20<K3`P35a<H0bLO90<C3
a@32`/D0`;o40;g0`P2l_l00^Kbm0;Rj^@2c]kd0UJ>d09:?Y02`PY@0ZVEe0:E]M`2hUj00Zj>X06Uh
T01SHX@0UeQa0:MCJP2UDVL0WF1d0<k=f034e>00`m?O0<?CgP1hTJP0NI6S08fNZ@2EXjX0T9jS06ml
OP1XMWH0JWMj01d^B01?J780?eAV00lK@`0123L00P/e011b7`T00?l02?ooool4003o0003052@N02P
8?00X23`02/0X23`0`3@D7P0102h>;@0X23`0:0Pl02P8?040=1@N180X23`00<0N5Rd003o0000o`00
1`00o`0;ooooo`002_ooool0E@0d^@L0AQ0508IkOP1VKW00FeIL06=SJ@0G2@P0Fb`O04d0101j0PT0
V@<;0:D33P2W0Pd0R@4608412@2:0@T0Z1<L0:<12@2^0@X0/`<<0;H22@2f10T0[P<:0:421`2c10/0
]P<90;@22P2l1Ph0_@D=0<893`342Q00_PH>0<4:4P2n3180^@/B0;843@2l2aD0_P/C0;l;5P2n2QD0
``dB0</@503B41L0da0F0=TB5@3I4Q@0f14D0=P@5P3H4A@0e0d?0=<=4P3=2A80c0TB0=8<4`3920l0
`@H>0;`53@2l1Pd0/`<<0:`32`2Y0PX0Z0490:L1202U00L0Y@470:<12@2P0@T0W`890:02202U0@X0
Y0480:41202P00T0X`4:0:h4402X0P/0X00809T0202;0@P0P04807<10`1_0P<0I`4205d10@1=C0L0
0`00o`09ooooo`03052@N03oP000X23`00@0X23`00<0d51h0?n0003oP000BP3oP000103@D7P00?l0
003o0000o`08ooooo`D00?l004/0PVIG06APK`0>3RL0C4AG05U>G`1^F6<0I5=Y03ThH00A5e00A3UT
07UFIP1lF680V6I/09eVJP2LJ6T0Y7=b0:^3O@2aSh@0]9J70;BIRP2gWhl0]j6C0;VVV02fYi`0^jnV
0;jd[@32^K@0`k^g0<Jo^`38a<00b/K60<G4``33`L00`/;20<G5a031`L80`l;50;fo`@2l_[d0_/2o
0;Zj_P2c]k`0L8^Z079SS02S9d80]0dM0;X:5`2g2QT0[Q<T0;4kC02RJ880CSeY08@_B02M1QL0YP@A
09P86032VJD0am?P0<GChP34d^40WJo1096U]02=WjT0Q96I07^7S01aO800JWUi06MhMP13DF<04R==
008<@@011cd00@Le00TG>@0ZKcD02@00o`08ooooo`D00?l0:`2P8?000`2h>;@0oh000?n000040?n0
00030=1@N02P8?00oh0000<0oh0000<0^3Rd0:0Pl02P8?00402P8?09003o00_ooooo000:ooooo`0`
02S1101>50`0PW=d05MKF`1PG5h0=CDi02@G4P166140E08907h43@2?0PT0X0<=0:H43@290@H0O`89
07L11@2>1`l0V@880:/32`2]0PX0[P8:0;@42P2_10/0X0860;D52`2i10T0^@D;0;P42`332a00b``B
0<d=50362Q00a0dB0;h:402j2A00^PXA0;`950302Q<0``/F0<H>5`3:41@0c10D0<`>503B41L0ea<E
0=XD5@3I51H0f14D0P3I41<08`3F3Q80c`XB0<d:4P3<2A80b0P@0;`4302j0``0^0<;0;43302Z0PT0
Z08;0:L1202W0@H0YP470:@1202Q0@L0XP470:412@2K0PL0X0880:41202M0@T0W04809h12@2Y0``0
Z@<=0:822`2H0@X0R`4908411P1`0P<0K04206/10P1Q0P40BDL300<00?l02Oooool00`1@T7P0oh00
0:0Pl0040:0Pl0030=1@N03oP000oh0004X0oh0000@0d51h003o0000o`000?l02?ooool5003o001;
07>RG01OGg807AXb04PnCP1BCfD0L5a/05Y9I@0E8EL0211<06QDL01`E5l0GTQC08UTJ@2LJ6/0WFUZ
0:EdM@2[PX00[Xf10;>EQ02bV8@0]Ib=0;NQTP2iYiP0^JRM0;f`ZP2o];40`kRf0<>j]P34_KT0a/:o
0<6o`034`l<0`/720<31`@32a<@0`L;20<72``2o_l40_Kjo0;Zk_@2k_;l0Z[K203UIS@2Q?5X0_PTF
0<474@2o1Q00^`PA0:lG7`2O82d0Ta@V094P>P2_@eL0W0XH0:H13@2R0`h0XDEB0=3Ag036dn40//;E
05ihTP2P]<80V:^f08RFW`1gPhT0Kgj106YjN@1WN7L0@e=V0049@@0124800@`l00hO?014FV<0>d=1
00T00?l02?ooool5003o02/0X23`00<0j6Pl0?n0003oP0002P3oP0000`3XJ3`0X23`0:0Pl00@0:0P
l0T00?l02oooool000[ooooo05D07L/104D:0`1dHF80Fe]L06aYJP0=3@l0<B8I02h3101O0PX0Q`8>
09@22`2M0PX0W08:08h120270PP0L@@9080I7@2G10X0[08;0:P31P2W0PH0/@D:0;D32@2g10/0_@D<
0<073@2o1`h0`@P>0<d=4P3C41<0eA0E0<X=4`2o2A00`0hC0;h>4@2j4140^A4B0<@B5@374AD0b14E
0<XB5@304aP0^R0M0;dW9@2o:BP0a2dY0</a;@37:RL0cbHV0=DE6P3G3Q<0e0/C0<h94P3:1a40a`LA
0;d3302m10`0]P8<0;03302]0`/0Z0490:H22@2T0@P0Y@480:81202Q0@L0X@4909l12P2E0PH0U`45
09h2202O0@T0W@4709d1202Q0P/0YP@>09/22@270@L0QP8907l21P1g0@<0L04306h10P1V0P80H0T2
00<00?l02Oooool00`1@T7P0oh000:0Pl0040:0Pl0030=1@N03oP000oh0004/0oh000`00o`08oooo
o`D00?l004`0NZ=I04A3FP0/:Sh0=c=:00PAA017@V40BCiN0089AP0_;5/0L5Y^07AJI`1JB5@0NUYO
09MSJ02PKFl0Y7Ae0:R0O02]RX40/9B60;>HQP2eW8/0]Z6B0;RUV@2iZIl0`;6]0;fd/P30^;H0`;Vf
0<:k^036`Kl0`/6o0<2o_`30`;l0_l300;k3`@2n`/<0_l?50;k2``2g_;l0]K^n0;Rm_`2S/L40@5ZB
0:D]AP311aD0_`H@0;`4402^5ad0]XV;08F0R`1^HWX0LciG08PV>`2F2aT0W`<>09`2302@31X0cK?0
0<KCh02N/<@0Rj>b07fBW@28Uil0RiRN07R3R01ZNW/0K7]m06MfN01DHg400@/o00@A@@0[?eL0C61T
055VI@10CD/02>H52000o`08ooooo`D00?l0:`2P8?050?n000040;Ph]02P8?00X23`0=1@N0D0oh00
00<0^3Rd0:0Pl02P8?003`2P8?000`0Xb3`00?l0003o0006003o00_ooooo000:ooooo`1E01g:001:
2`@0O6MX04]9A`1UH6<00P42030Q6P0W0@80G@8808L33P2F0P/0W04<09D12`2B0@/0T`8<09D?6P2]
;3H0X`<:0:`22P2b10T0/@<80;832@2g10T0^P<;0;d6302n1@d0`@H=0<`:4@3B3Q<0cP`@0<l=4@39
4A<0^10E0;8N702[=2d0ZT4h0:m5?@2_=2l0/B<P0<0M6`385AL0P0L:0:agM03S^K@0kLG10>o7`P3c
bL@0llK20?J_/02i:Rd0bPdB0=H=503@2A00d0/@0<d;4@2o10/0_0D;0;<2302]0`X0Z08;0:L12`2U
0@X0Y0090:D0202R0@H0XP890:402`2N0@/0W04909P01`2K0@T0WP4:09d12P2L0@`0V@4:09L33@2E
0`h0O`8707P11P1_00<0M@850701101_0@D0I@8305h80P03003o00Wooooo00<0D91h0?n0002P8?00
102P8?000`3@D7P0oh000?n0000P0?n00080X23`:@3oP003003o00Sooooo1@00o`00C01V`TP0>SE8
044hBP0P7Cd00`Y503XhG00g<UL01@e6069CLP1[F6L0DT]I04`nB`21EUh0Uf9W0:5^K`2TMGH0Z7im
0:f9P@2aThL0/YN70;FLR`2cWi00]J:G0;j`Y@2n/:X0_kBb0<2g/`2n^;@0_kVg0<>o_P33`Kl0`;nm
0;g0_`2l_/80^[o00;g1a02m`L<0_/;30;^n`02f^kh0];Rl0:jjaP0bE8`0WDMV0;h85P301@l0^`@?
0:dK902fW9`0Z;2`09nW[`1eQIT0GfN706M3I02>31d0W@<=09T3402YHg40cMCO07B:Y@25Wk40V:Zd
09:NZ01nR8l0Lgn307=oP@1[NGX0IgUg06=cN00L;TP0B5aX05ibLP1GJf/0>e=M02i2C00K^AH8003o
00Sooooo1@00o`000`1hF;@0X23`0:0Pl00X0:0Pl0030=1@N03oP000oh000080oh001@2P8?001@2h
>;@0oh000?n0003oP000d51h0140X23`00<0D91h003o0000o`001P00o`0;ooooo`002_ooool03P0N
b`00B`X1075KG01?CD/0FeQJ00@10P0]6aL0;P4205h11@200@T0U08;09L23@2@0@X0T08;0P2A0@/0
>02L10d0Y@870:X2202^10X0[0870;D42`2d0PP0^0<;0;d42`311Pd0`PL=0<T93`3A3Pl0e0h@0</D
5P2L7A/0XEAA0<NITP3WcLT0j]SB0>OBcP3Ub/L0gKB`0<n?R@31Cd/0N1XK04Y0A@3Ce=D0jNKV0>KT
i@3Uhn@0inCU0>oKg@2nGf<0b1DK0=D=4@3@2Q00cP/A0<D63@2l10X0^@D<0;83302[0`X0Z@8;0:P2
2@2W0PT0XP490:41202P0@P0X@8809l12`2Q0@`0W04809T11`2J00L0W0470P2M0@P02`2M0PX0UP<>
08D22@1l0PD0PP<:07@21P1b0@D0K`4406`1101V0P<0I@d600<00?l02Oooool00`1@T7P0oh000:0P
l0040:0Pl0030=1@N03oP000oh0001H0oh000`3@D7P20:0Pl0<0d51h0P3oP0060:0Pl0030=1@N03o
P000oh000280oh000`00o`08ooooo`D00?l004`0HLdm03``>P1@AUL0410b008:@@0g>V003Q0n024S
C`1oHWD0Oei/05a5E01dCe/0Re=L09aUJ`2QKG80Y7Ag0:ImOP2]R800/I:30;2EQ@2cVHX0]InA0;j/
X`2o/:P0_k:/0;je/P2l/Zl0_kNa0;ji]`30_[`0_kjm0;fm_02l_;`0]kZk0;Vn_P2l`L<0^[o10;^o
`@2e^;d0^;Zm0;Ni_02c^[h0G7ZU07IQR`2`3ah0`0D?0;/23`2[2A@0]H:409VPX02c^l40Y:jj0<3A
iP0jC7/0OCAB09833P2M0`h0SQTZ0=;4dP22U:L0NXfL09>OZ@2<Uj00OXZ?07R2Q@1bOh00KGeo06Mi
N01UMW<0Ffm]05a_L01GKWD0;D=O00<B?@0J;D<0:iXX2000o`08ooooo`D00?l000<0D91h0:0Pl02P
8?00:02P8?000`2h>;@0oh000?n000020?n000030=1@N02P8?00X23`00<0X23`00@0d51h0?n0003o
P000oh004@2P8?000`1hF;@00?l0003o0006003o00_ooooo000:ooooo`1E01o<001<2P40MEiO03dj
>P1GE5D02`@302TF4P0l0P@0I08607L1102>0PT0S`8:08`1202?0@/0TP4=09D2302I0P/0X0470:T3
2P2X0PT0Y`880;D52`2f0`/0^0<<0;l53@341`h0`@L=0<D;3@3<30h0ba0C07lA4`32ZZP0jnSU0>GV
i03Ti>D0i^CW0>GTi@3Thn@0hN7Q0>CRh@3Yg]`0_ZZX0452A02l`<<0i^OY0>CSi@3[j^`0jNW[0>cW
j@3M[;00`RP_0=/A5`3A2a40b0D>0;h42`2k0``0^`D>0;@32`2_0P/0[08;0:P22P2W0@T0X`480:81
202Q0@T0X04:0:822P2Q0@/0V@4709P11P2I0@H0W04809`12@2L0@P0V04709<230220@H0R0<90841
1P200`P0LP4506P11@1Z0PD0H`4306@>2003003o00Wooooo00<0D91h0?n0002P8?00102P8?000`3X
J3`0oh000?n0000E0?n00180X23`00<0d51h0?n0003oP0008@3oP003003o00Sooooo1@00o`00C00d
j240Ie5?05A8F@0622X05Ai702D^F`021cd0C49P085NK028Ff`0OT]L0819E`2>Ef00VfEZ09iZK02S
LW80YG]j0:V6OP2_SX40/IB70:nER@2dWI40_:VP0<6aZP2l/:d0_;:^0;jc/@2l];40^KJe0;^i]P2k
^[/0^;Rk0;Vh^P2h^KX0^Kfn0;Vm`02k_/<0^[g10;Bj^P2f^k`0/[Fh0;>h^`2N[[l0?5B;0:4fC02l
1`l0_@@@0;D3402]BDh0/Zn`09jX/02MZ;@0GgR?08JP_`1@@F`0RPTI09H22`2C1Q80Y6ak07Z@YP2I
ZkL0QI>J07Z8S`1hQHP0L7io06inOP1bOh00JGQg06QgMP1PLg@0AEY]014RD0013D`00@]301@TA00_
LC88003o00Sooooo1@00o`000`1@T7P0X23`0:0Pl00Y0:0Pl0050>QX?03oP000oh000?n0003XJ3`0
1@2P8?001@2h>;@0oh000?n0003oP000d51h0140X23`2000o`0;ooooo`002_ooool02P0Oc000C@X0
06eFE@12?Cl0BdQ;01T@3`0O2PT0@@4406T21P1h0@D208@01`1908L12P2:00P0T04:09802P2E0@T0
WP880:L32P2U0PL0YP860;832P2c0`/0^0<;0<082`3520h0a0P>0<<93P3620l0^a<I06hn?P3Vh^40
j>SZ0>?Ri@3Sh^@0h>7P0>;Si03Sh^D0i>;T0>CSiP3Uin/0i^SY0>KXi`3Hfm/0inSY0>CTi@3Yjn/0
i^SX0>OXjP3`f=d0^d9;0=PA6P3G3Q@0bPP=0<863@2o1Pl0^`@=0;L32`2c0P/0[@8:0:L1202W0@/0
Y@490:@1202S0@T0X@0:0:812P2R0@`0U`8909@11P2I0@L0X04:09d0202L0@T0V@8909`43@2C10/0
R`4808X220260@H0N`8606D10`1T0@80H08305X80P03003o00Wooooo00<0D91h0?n0002P8?00102P
8?0G0?n000030=1@N02P8?00X23`0100X23`903oP003003o00Sooooo1@00o`00C00ciAT0SfiN04i2
C`0>3BP0@SmH00hHB`021cd0ETUQ07mMK025GF/0PE=N085=F@2>F680UF5U09]YJP2SLG80YGMh0:J1
NP2^SH40[i630;6HR@2eX940^jZN0;f]YP2h[ZX0^Jn]0;N^ZP2l];00^K>b0;Zd/`2i]kP0^[^k0;Ri
^@2f^[X0^Kbm0;Zn_`30`L@0_Ko30;Rk_`2i^kh0]KVm0;:i^`2`^;d0CVZH07UIPP2_31T0^P<?0;P2
3P2X5Ad0_j2T0:J_]P2kb=40RIb]06Z<[P0dBG`0OBM209H33P2H0P/0RQXS08=oRP2:WjX0V:N_08RF
WP1ePhD0LX6106mlO@1^O7/0JGUi05acN`0/@F80115<004:C@0134d01A=803A8G@0d=cL8003o00So
oooo1@00o`000`1@T7P0X23`0:0Pl00Y0:0Pl0030;Ph]03oP000oh000080oh0000<0^3Rd0:0Pl02P
8?000`2P8?00103XJ3`0oh000?n0003oP00A0:0Pl0P00?l02oooool000[ooooo02h08<`104/:001_
F5D0BD=403li?00[6QX070<304T2101/0PH0M08507X2201j00T0P@4;08P22`280@T0S04909T22`2M
0@P0YP<90:@2202P00D0/@@<0;412`2g1@`0_`H=0<@93`301`d0a0P>0<D:4@2J3140PG1_0>KViP3X
jN/0j>SY0>KVi`3Qh^40hn?U0=k9d02kP8l0/Fj10;JAX`3?bmD0hNGX0>CWj03Ui^H0hnGU0P3Uj>T0
9P3VinT0k>7U0<=ZL`3@51`0ePlG0<d;4P321Pl0_`D>0;`3302i0``0]P<<0;422`2Z0@X0Y@490:D2
3@2V0@/0Y@4;0:<12`2R0P/0X08:0982202C0`T0V@4909l12P2P0@/0X04<09`22`2A0`L0Y0L>0:45
3P2<0`T0SP<:07/21P1S0P<0F00105T20`1G2`D01_410P00o`09ooooo`03052@N03oP000X23`00@0
X23`5`3oP0080:0Pl080d51h00<0^3Rd0:0Pl02P8?001`2P8?000`3XJ3`0oh000?n0000P0?n00003
02S8?000o`000?l000Sooooo1P00o`00:02bRF/0CCm902HQ<`0k=4X00`]001XQCP1=A5h0Of1_08IJ
J@24EEl0Q59K08eIHP2FI6L0VFU[09m/L@2TMGH0Z81k0:j;P@2`T8@0/IR:0;BLT02lZ9`0^:^S0;N_
Z`2f[:X0]jj[0;Zb[P2g/k00^KFf0;Rg^@2h^;X0^;Rk0;Zl_@2j_;l0^[bn0;k0``2m_l<0_;k10;^n
`02g_;l20;>i^`0R09BW_011Dh/0WBTn0;H5402h0`d0/0D?0:aLH`2a/KT0QIR[0<CFi`1]S:L0M8fc
05HiH`2A1QL0W08=0984402EIFh0U:>[08ZIWP22SI<0NhZ=0762P@1^OGh0J7Ym055XN`0C:5X00@e@
004:C@0134`04RME04aQL`1KK700=Se000SU10L00?l02?ooool6003o02`0X23`103oP0000`3XJ3`0
X23`0:0Pl0030:0Pl0050;Ph]03oP000oh000?n0003@D7P0402P8?000`0Xb3`00?l0003o0005003o
00_ooooo000:ooooo`1901o=0@182P00KeYH05]FEP0V8240;A/K01T00@1A0`@0JP4206l20`1c0@L0
MP4907P22@220P/0PP4708X2202L0``0X08:0:L22P2/0`X0Z0880:h32P2a0`X0/0@:0;L52`2k10T0
^PD;0<884@392aL0S@X@08f3Q@3XinX0j>W/0>SYjP3Wi^T0inKW0>WTi`2cIW00a1/V0<lE7P397RL0
SAl]08=DI@2_Z;@0f]kQ0>;Ti@3TiNL0i^SZ0>GWj03Ui>H0dZ6W0;`E7@3:31<0a`T?0<D63@361``0
_0<90;P32`2e0P/0/@8:0;03302X0PX0YP8:0:H02P2T0@T0Y04:0:812`2N0@X0OP8506l10`2?0`X0
W04709h12`020:@23@0;09P32@2T1Pl0W`D=07T110260`T0O@<706L2101O0080F@8205T9100Ia@40
0P00o`09ooooo`03052@N03oP000X23`00@0X23`5`3oP0070:0Pl0060=1@N03oP000oh000?n0003X
J3`0d51h1`2P8?000`3@D7P0oh000?n0000P0?n00003052@N000o`000?l000Sooooo1P00o`00C01d
Sc40CC]003/b@@0/9T002a1004M4I`10?5T0Nei]08MOK@25F6<0Q55J08mJHP2FHVP0W6Y^09iZL@2T
LgH0YGej0:b9P@2/T840/9J70;>LS@2gXiT0^JZR0;NZZ02cZZT0/JbX0;B`[P2d];40]kJd0;fm_@2m
_l00^;Vj0;Vj_P2k_/40^ko10;k2a030`LD0^ko30;Zn`02e^kh0/kVm0;>g^`2^^<40@EnC08=DN@2^
21L0]`<=0;<33`2P7BL0_j^d09:R/`1NOi`0Ni^`0;W<hP0c?6h0O1Xc09H24@2F0Ph0RR/e0:RZ[`2;
VIl0P8^>07B2Q@1]OX40JWj503aDLP065eL00@YD004:D0022d/05BQB061gP@1TN7T0Ffma03I4B@0C
d0h7003o00Sooooo1P00o`0/0:0Pl0030=1@N03oP000oh000080oh001P2P8?00103XJ3`0oh000?n0
003XJ3`@0:0Pl003052@N000o`000?l000D00?l02oooool000[ooooo05H08<d104D;001hHV80FEEH
01`B4P0F10D0:P8205T30`1[0P<0K@4507821`1d0PP0L@4508012@250@L0RP4809T2302N0@P0X`47
0:H11P2V0@P0ZP490;422`2d10/0/`D:0:`2202g1`h0^`H=0<053`2P3Q@0MF=W0>CTj03Xj>X0inOY
0>SXjP3XjN/0jnOY0<1[L`395A`0fA@H0=`E5`3B4aH0_aDN06`B7`1jMGd0g>3Q0>?UiP3UiNL0iNKY
0>?SiP3Obll0/BXa0<P?503:3180`@D>0<053P2o1Pd0^`D:0;H32P2c0@X0/@8<0:h12`2Y0@T0Z089
0:H2202P0@T0X@4<09h12P2A0PH0PP4409421`2L0@L0W`4:0:<22`2Q0PX0U@8:09h53@2N1P`0T0@;
08/220200`P0L`8606h31@1L0P80E0L201S40@800?l02Oooool00`1@T7P0oh000:0Pl0030:0Pl003
0=1@N03oP000oh0001D0oh001`2P8?000`3@D7P0oh000?n000030?n000030>QX?02P8?00X23`00D0
X23`8P3oP0000`1@T7P00?l0003o0008ooooo`H00?l004`0E;XO04`i<`1=@D`06QPg02/[C@1HCfX0
<BiC07UOK`22GFX0QEMT08UHH`2>FV@0Tf1X09ITJ02LJ6d0Xg9f0:MmOP2^R840/9630:nDP`2bVXX0
]Z:I0;NYXP2aYJ80/:JR0:fWY02SX9l0Wj6O0<G9b@3=d=D0emcQ0<34b@2e^K`0^Kjo0;Rl_P2m`l<0
^ko30;o3a@2k_l00_;g20;Jj_P2d^;/0[kFi082C/`1<Ehh0VQX^0;L33`2d0Ph0Z`HC09=GIP2lbmX0
CFn@09^ld03:f^D0HGBJ05hgG02<11D0U@8:08/94`2CLWH0U:2S08ZIVP1ZO7h0Ih2503=>L@025E/0
0@iJ00<BC@0E9eT00Pi504INL01XO7h0HGMl059ZM00hBe408IhM1`00o`08ooooo`H00?l0;@2P8?04
0?n000030=1@N02P8?00X23`00<0X23`00D0d51h0?n0003oP000oh000;Ph]00?0:0Pl003052@N000
o`000?l000D00?l02oooool000[ooooo04L08<d104P;001^EEH0He]O01061P0A0@40;@4106020`1[
0@<0J`4507H2201d00P0M@4707l12@280P/0R`4809@12`2P0PX0YP880:D11`2R0@P0Z0490;422`2e
0`d0[0<:0:X42P2c10/0^P<;0<45302e3aH0Gci20>7Qi03Xj>X0i^OY0>SZk@3Vj>X0i^?S0<f6S037
6B80eQ<I0=<@5@3D41H0d10G0:4B6@1;<CL0d=?F0>KVj03Vi^L0hn?W0>CSi`3Sf]d0[dE=0<<?5036
2@l0_@@=0;`33@2l10d0_`H>0;`53@2g0@`0]@8=0;02302X0@X0YP8:0:<1202R0@P0X04709h12P2G
0@H0T00309L11`0209`12@0=0:012P2P0P/0T`8909P3302E10/0T0@<08P22@1/0@@0J`4306`10`1T
0P80FPL301W50P02003o00Wooooo00<0D91h0?n0002P8?000`2P8?000`3@D7P0oh000?n0000E0?n0
00030=1@N02P8?00X23`00@0X23`1`3oP0000`3@D7P0X23`0:0Pl0040:0Pl280oh0000<0D91h003o
0000o`002?ooool7003o000W0653=P1CB5D02``_04e6GP1QE7007Ae<07MOLP21FfT0QeYW08]IH`2>
FVH0Tf1W09UWK@2KJ6d0XFmc0:MjOP2]R880/I640;6BQ02cW8h0]ZBI0;BVWP2eZZH0[:BP0:fWY02O
W9X0/K:_0;Nk_P2d][`0a/kA0<O;d@2i_/80^;c00;Vm`02m`/D0_<;50;_1a@2l`LD0_Kk20080][Zn
0280/;Bi0:Vc_`0dDXH0Rd]X0;865@2g10h0/`8>09hY>024RJ40TJk608JT]P3:fN<0[[kF03LhJP1j
3bD0U@4=09<23P2A?DP0SHnC07Z7R`1KL7h07cUV008EH0014eh03bEK04=LMP0Q=ed02am?05]dOP1V
OH<0=4U/00@IB`0]AUd07VlN1`00o`08ooooo`L00?l0;02P8?000`3@D7P0oh000?n000020?n000H0
X23`0`3oP0000`3XJ3`0X23`0:0Pl00>0:0Pl0L00?l02oooool000[ooooo05H08Lh204T90020IfH0
CD=600d51@0D0@40?P<306D2101V0P<0I`4407<21P1e0@P0M`4907P11`280PX0T08;09<02P2M0@X0
W`480:41202S0PT0Z0490:d22P2`0P/0[P<<0:h32@2j1@`0c@`A0=L?4`3D5a`0E1HJ0=CCf03TiNL0
j>WY0>OXj`3Yj^`0jNSY0=2NX@2m8RT0d1<I0=0@603C3a@0da4D0;`D6`163180^;Vn0>?SiP3Wj>T0
iNGY0>?Ti`3ThN@0_79g0;hG70362Q00``L?0;l73P2i0`d0^0@=0;D32`2d0``0Y@<;09P;4P2c:380
W@dF0:<33@2T0PL0X@8909h12P2I0@L0T`0509H2202L0PT0W04709h1202O0PX0V`8<08d11`2@1P/0
U`D<0903301d0PL0K@8506d1101Q0@40G@P401[60`800?l02Oooool00`1@T7P0oh000:0Pl0030:0P
l0030>QX?03oP000oh0001D0oh0000<0d51h0:0Pl02P8?00102P8?000`3@D7P0oh000?n000040?n0
00030=1@N02P8?00X23`00@0X23`00<0d51h0?n0003oP0007`3oP0000`1@T7P00?l0003o0008oooo
o`L00?l004/0LU4g04PoC00=3Rh0HEEU04Y8I00:3cl0KU]d07mKI`28FfX0RUQT08]HH@2AGF<0VfQ_
09eZL02QKg80Z7]m0:^8P@2aT8@0/Y>80;:JS@2aWY@0[j6H0:fTW`2`Z:@0[jNU09FAT`2OWj80`LC7
0;o3b03=eMX0^kg40;Zk`P2l_L80^Kg10;_1a02m`/D0_L350;g1a@2m_l@0][Zm0;:i^`2a][X0[;:g
0727YP1HEHH0WQ4T0;D3402c0Pd0XPLG07mILP2Q^Lh0b=cV0<[Hh`36en@0BUb506X_CP2?0Pl0T`4<
08L?702HQ8H0O8^C02DnK0025VD00aMS02LnJP1NMH40BF5f014XE00Q=f40?UMi02DnJ`024eP00@e>
01T^E00R=BP01`00o`08ooooo`L00?l0;@2P8?040?n000030;Ph]02P8?00X23`00<0X23`00@0d51h
0?n0003oP000oh00402P8?07003o00_ooooo000:ooooo`1F02;>0P1:2000NeiP03lf>@0<0P806P00
04H20P1Q0`<0G00106410`1^0PL0LP4807<11`1j0@L0Q`4908/1202B0@T0V@4709X11P2K0@L0W`49
0:P12`2^0``0Z`8:0:L11`2b1@h0_0H=0=@?4`3N4aH0f18G074;3P2VYZX0j^_]0>_[k03XjNX0j>WY
0>KUi`3Tb/`0Z3Po0<DE6`3=41H0dPlF0=8?4`3=4aP0N``D05M:C`3Ffmh0i>GX0>;Ri@3Oh>40h^;U
0=:[/02T72@0`@/C0<06402m1@h0^`D=0;L3302d0`h0ZP<=07d31P2<1Pl0WPTF09<>602A0`X0X`8:
0:02302N0P`0U`4708l11P2<0@D0W04909d1202M0@X0W@4909h22`2J0P`0V@D=09/63@2C0`/0O`87
07421@1`0PD0H`8205`40@0Ja082003o00Wooooo00<0D91h0?n0002P8?000`2P8?0I0?n000L0X23`
1`3oP0060:0Pl0030;Ph]03oP000oh0001l0oh0000<0D91h003o0000o`002?ooool7003o000T05=h
900l<dD08R4l0516FP0^<eP03aA704]2H`1lFfT0PUQV08MEI02:F6<0SeiT09IUJP2KJFh0Wfib0:Mi
N`2YQ800/9240;2CQ`2dVi00/9^C0:RJT@2VW9T0Zj6P0:nVY02b[JX0/k2^0:ZYZ`2Z[:l0ZZbb0:Z]
/P2e]k`0_;k30;^n`P2j_l40^[o30P2k`LH09P2l`LD0][^n0;:j_02_][P0ZkBf0:6^_00^BH40TCmL
0;84502c0Pl0[08@09DdAP28SZ00c=cV0<_Ih`39en40VJ_304@hHP212Qd0U08<08l33@2?DeP0GVf5
00<JI0036f40=e1d06UmP`1PM7l04BQC04ILMP0dAfL00A5J004?H00245d00a5=00`L@`0_=d001n@4
1P00o`08ooooo`L00?l0;@2P8?001@3XJ3`0oh000?n0003oP000j6Pl00H0X23`0`3oP0000`3@D7P0
X23`0:0Pl00=0:0Pl003052@N000o`000?l000@00?l02oooool000[ooooo04P08/h2054;001lGV40
<b//01010@0X0P80CP8205d10P1I0@00G04206/11`1]0@D0L@4507h11`260@P0R00808l12P2C0@H0
UP4709T0202O0PX0Y@4;0:/22P2/0``0Z04<0:l22`2i0`X0d@lC0=LA4P3D3a<0U10C07=^L03VjNd0
inOZ0>;Ri03Ph^40h^?T0>GKf`2hKG<0_1PP0<h>5P3A3aL0d@lF0<d?5P2P4QL0:0H:0<?6c03TiNT0
hnCV0=oPh`3QhnD0gL[=09Ha>@2h31D0_PL@0;`63@2i1P/0]0<;0;L43P2Z1a00I`4409@73P2U0Ph0
VPD?07d21P2P0`d0X@4;09d12@2J0@P0UP4609L2202L0@L209`1200<09`12P2G0PX0TP4909P33027
0PP0R0<<07@10`1R0@80I0<506820`1O1@<0<hX40P00o`09ooooo`03052@N03oP000X23`00<0X23`
6@3oP0070:0Pl0L0oh001`2P8?0Q0?n0000308300000o`000?l000Sooooo1`00o`00C01ZRC<0<BTn
03D`B`0k<e408RMB01/PCP0Z:E40N5i^07iEH`28E6<0SU]Y08eNIP2DIF`0Vfac09m_L`2UNWT0ZHB0
0;6?Q@2`UHX0/IZ@0:nKT`2ZVI<0Z9jL0:bSX02aZJD0]k6`0;Fd/P2b/Jl0YJ:T0:j]/@2PXjH0Z:^_
0;Fi_@2e^kh0]ko10;_1a@2k`/L0^/770;[0``2g_;l0/kRl0;:g^`2/]KP0Yk>i04]WUP1`Dg`0Z@XJ
0;D23`2`0Pl0VaPX0>k6e@3Jd^80e]7S0=?<g`3@b>00DCiS08@L<02A0@d0T@8<08H[=`11BWD011eV
03eLP01TNh<0KH:603E:K00C:e@0JWj505IYO@024eD00@iL008DE`0Z@6<07Rm603I3B00LU146003o
00Sooooo1`00o`0]0:0Pl0030=1@N03oP000oh0000<0oh001@2P8?040?n00100X23`1P00o`0;oooo
o`002_ooool0EP0Sc`80D@`0075FEP0Z92D0304103420`1C0`<0F@8105D1001I0@80J@4606d11P1a
0@H0OP4908L22P280@P0S@4:09802@2D0@P0V04809h22`2R0@P0YP870:P22@2Y0P/0/`<<0<072`3@
3A40cP`?0<d<4`2U3Q@0CSXm0<W>dP3Qhn@0h^;R0>3Ph03Qh^80iN?R0=JZ[@2h9R`0d10H0=8@5`3?
3AH0c`hG0;/C6`1;0PP0ShbB0>CWj@3Si>H0hN;T0=oRhP3Of]X0XF=W0:TA6@2j1Q40^PH>0;L42`2e
1@h0/`<=0:T94@1J0@<0JP@:08/530241@/0I08409/43`2P0P`0WP8909/21`2E0@L0U@4809/1202M
0@L0WP4909d12`2H0@`0U04909X33@290PT0Q@8:07h22@1^0PL0G`4306010P1Q1@@0=8`60P00o`09
ooooo`03052@N03oP000X23`0080X23`6P3oP0000`2h>;@0X23`0:0Pl0050:0Pl0L0oh001P2P8?00
0`3@D7P0oh000?n0000N0?n0000308300000o`000?l000Sooooo1`00o`00C015/B<0:bDi04LnE00T
8T@08bM=02XZD00=4D80J5U^07aFH@23D5h0RUER095PJ02HIfl0WVee0:5cM`2WNgd0ZXF10:n?Q`2^
U8/0/YbA0:bHT02[VY@0[J6N0:nWX`2c[:P0[J^Y0:Z[[02c/K40[:V/0:nb]02[[Jh0Yjb_0;:h^`2d
^[h0^;g00;_1a@2f_/40]Kfo0;_1a02j_l80];Zm0;6j_02[];L0Zk>h07f@[P19DXL0VAda0;D54P2b
0Q00Z`HI0:hZ@`2Q;d`0UbY6098UA02>8d<0R1Xd08d96P2B0@`0T04<088?7`0g<680;4Qi06^2S`1Y
Oh@0BFIo00TRD`18H7@0KX2006amP`0[?f8021eC02]6J01EKGH0:Ca803a=D00TX1/6003o00Sooooo
1`00o`000`1@T7P0X23`0:0Pl00[0:0Pl0h0oh00402P8?06003o00_ooooo000:ooooo`1F02??0`1<
2@00M5QH020I6`0F0P40?`<205<20P1B0@40D@4105H10@1W0@D0J`4507011@1m0@X0Q@4;08H02@2<
0@X0T@0:09812@2H0@T0WP8:0:@12P2Z0P/0ZP490;H3303520l0c``A0</:40321`h0``TB0;P=5015
41@0ZJ^_0=gNh03ShnD0hN?S0>?Th`3ThnD0k=SJ0;Q9D@3=4QT0d@hE0=0?503A3aL0cA4J08l?601M
Add0gn?U0>;TiP3Phn@0gn?T0=kQh035[:h0VR@]0;@7402e1@h0]@@=0;@23`2a0`l0[@D>07/42@18
2@`0F1@F03l2101D0@L0VP@@09d12`2L0PT0V@4909411P2A00D0V`4809d1202N0@T0W@8;09/2302C
0PX0S`8:08h22P1l0PP0LP870742101`0PD0I04206030P0aR0@2003o00Wooooo00<0D91h0?n0002P
8?000P2P8?0J0?n000030=1@N02P8?00X23`00D0X23`1`3oP0000`2h>;@0X23`0:0Pl0040:0Pl200
oh0000<0P<00003o0000o`002?ooool7003o001<037E6`0M62P0ETiR00X?<P12?UX0?cID0086?@0X
:540MeMW08=CGP29EF40TF9Z09MZL02DK7<0Rf]b0:1kO`2WPH40ZhZ60:bCR02]VHd0ZYZB0:VMUP2V
W9T0[ZNR0:BQW`2RYJ@0WJ6U0:b]/@2QY:H0[[2c0:j`/P2VZjh0[[6f0;Fi_@2i_/80_<350;_0a02j
_l<0^<340;S0``2d_;l0/;Zl0;2i_02kaLT0Z[G104MRT01dEW`0W1//0:@;5`2V3AD0X@hE09`@5`2C
3aL0Sa0H08T=5P252aH0Q@XD08H94@272140N``E04LiH00bD7h0EG6;03=<M@099U`0AF5i06IkO@1^
P7d0KGin06QjO01SMg`0IGQi05M]K`0R>4P0AeYO048m=PH00?l02?ooool7003o0003052@N02P8?00
X23`02/0X23`00<0^3Rd0?n0003oP0002`3oP00@0:0Pl0H00?l02oooool000[ooooo05H09=030509
001T@d405@d>01L10P120P80D@4105810@1A0@00FP4206H11@1[00@0L@4207`220230P`0Q04:08T0
2`2@0@T0U@8909X2202N0@T0Y04:0:T12`2]0P/0]`@=0<D:40392Q00``L=0<07302o1`d0_0/A05X7
2`1[JVh0d=?F0>7Qh`3Ri><0hN;R0>;Rh`3[hN@0`G9g0<TD603A3aH0dA0E0=8?5P3B41H0]aPN04/L
8P3Be]X0h>?U0=oSiP3PhnL0gN7R0=oDe@2J@4X0[`TC0;42302d10d0/0<@0:X1302/0`/0X0P=08Le
=`3=T9<0GahP06l32@2N0P`0V`0709X02@2I0@X0T`4709D11`2I0@P0V`4809d12P2L0@P0T`8;07h0
1@260PX0R@<:06P00P1G00<0L@8507<31@1P0P80G@<103>:1@800?l02Oooool00`1@T7P0oh000:0P
l0020:0Pl1/0oh001`2P8?000`3@D7P0oh000?n000040?n000030=1@N02P8?00X23`00@0X23`00<0
d51h0?n0003oP0007@3oP0000`20`0000?l0003o0008ooooo`L00?l004d0;N4G02dO9P1ABel02`ld
06EFI`1IAed010Dk00H8?@1XCVD0OE1L08MHH02HJW<0Uf]c095ZL`23J780SG9f0:R2Q02[RHL0Zi28
0:^GS@2YVY00WYF<09nGT@2KUI00/k>_0;k3aP2j_/D0[Jfa09nRY02JW9l0W9nU09RLX@2Y[[@0/kRl
0;Vna02m`/H0^/340;Nm`P2k`LD0_<;50;Nm`02d_L00^lC70:nh_P2b_/H0//GC06InX`25Qj00LF=l
0;JOX`2nYJ@0_jRX0;bWZP2jZ:`0W9>O08IoSP1eKWP0Qg=b095fM`2=NWT0LGZ502HnJ`0G<f<0:TE/
05acQ01`PXD0KWmo0720O`1]Oh40JWYm06QhMP1TMG@0EVUd01P_BP1>IFT0@DU100cI1`05003o00So
oooo1`00o`000`1@T7P0X23`0:0Pl0190:0Pl003052@N000o`000?l000<00?l02oooool000[ooooo
05H09=44050<001WAD802PD501@10@110P<0E@<305<20P1C0P00F`4406P11P1]0@H0K`4507D52`24
61l0L08808@22`2=0PX0U04909T11`2M0@P0X`490:H0202/0PX0/`<:0;l730342Pl0`0L<0;l63@2o
20h0_@`A07/<4P0^8bH0^Kc00>;Qh`3QhN40hn;T0>GTi@3UhN80c9ZL0<0I7P3?41D0dPlG0=8>5@3@
3Q@0aA<J05`;4@2c]K/0h^CV0>;SiP3Ph^@0gn3R0>?LgP2WIfh0ZP`F0;<6402`0`d0[@<>0:T2302W
0@X0YP@=0:HX<P2H>4<0Sb8/09X53`2S0P/0W04809/12P2G0PT0TP0609P1202J0@T0W@8909h22@2K
0@P0SP8807`01@240`d0OP8907T42P1Q0PD0K`<706`2101L0@40F`<103F=20800?l02Oooool00`1@
T7P0oh000:0Pl0020:0Pl1/0oh001`2P8?000`3@D7P0oh000?n000040?n000030>QX?02P8?00X23`
00@0X23`00<0d51h0?n0003oP0007@3oP0000`20`0000?l0003o0008ooooo`L00?l004d03?P504/b
:010?5<08bE306mMH`1^F6L030Tg00`=?@1aE6T0PUEP08aNJP2GJGD0VV]g09=[M@2:JW80W7Qj0:N0
P02VQH<0Y8Z50:RES@2RU8/0XYN>09ZBR@2GTH/0Xj:Q0<S:c@2i^l00YjR[0:FZZP2Z[:d0Wj6U08nE
VP2V[Jl0][_10;g0aP2l`LH0_L?60;^na02m`LL0^/;50;Ro`P2e_<00_lO;0;[0a`2h`l/0Wjnm0:2h
c`1OQjl0QJFo0<gQj@3@gN@0dMgT0<oJi03;f>@0NHfX08^S^02CY;40VZVc09NV[@1lRhd0NXR<07J4
RP1bQ8X0LXB707:5Q@1bQHH0L85o06f0OP1]PH40=diN05YbMP1BJG807C1F004=@P0/A5/0B5MG01^X
4`05003o00Sooooo1`00o`000`0Xb3`0X23`0:0Pl0190:0Pl003052@N000o`000?l000<00?l02ooo
ool000[ooooo05H09=4404l=0@1C<Bd0204102020@140P80CP4205010P1D0@40F04206@11P1Y0@H0
HP4307H73@242aD0H@4507L32P2>0@X0U04909L12@2L0@T0XP490:@12@2/0PX0_@L=0<D:40301``0
_0L>0;/74@2m2140`@/@0:4@5P0Z0@@0S8b@0>;Qh03Sh>40hn7T0>GTiP3Th^@0h<[;0;@Y;03@4QL0
d@lE0=8>5@3B41@0cA0F08`>5@1gLWP0h^?V0>7Ri@3Rh^D0h=oR0>3Mh@32XjP0X1DM0;@94P2a1Ph0
[0@<0:P3302T0@T0Y@4<0:D2402R0a00Y08?0:P23@2U0P`0X08;09d1202G0PT0U@4809P22@2K0@P0
W@4:0:022P2Q0@/0W08;09D22`2E0`l0R0<;07X11`1_0PH0HP8405h10P1R0P<0G@8103Qj1@800?l0
2Oooool01@1@T7P0oh000:0Pl02P8?00^3Rd01/0oh0000<0d51h0:0Pl02P8?001@2P8?070?n000H0
X23`00<0^3Rd0?n0003oP0007@3oP0000`2XR3`00?l0003o0008ooooo`P00?l004`0H50Z038/A`13
?E<0LEeN071LIP0U7T<03`lm07=GJP22F6@0SfA_09IXL`2JKGL0Vg9j09ieO02SNWd0YGem0:F1P02N
PGd0Wh^20:>ES02HSH@0WYB;09nFS`2ET8/0VYND09ZJU`2IVYT0Z:f]0:N[[`2QY:P0T9>G0:J][`2e
_;h0^<730;c4a`2l`/L0][c30;2h_P2i`<D0^/340<?9c@2d_L80^LG:0;K5c@21VKD0WKG>076B/@2i
d]h0dMoX0=3Li@3>g^D0c=_T0<_Ii@2]`ML0EGFD07b@XP2AWj/0QiFL08JEV020SY80MhB607F3Q@1e
Ph@0LH620722Q@1`PH80KGj006YmO`0_A5X0>5=_00dMC0012TD00@]200hO@`1:H6<08Z8M1@00o`08
ooooo`P00?l0B`2P8?000`1@T7P00?l0003o0003003o00_ooooo000:ooooo`1F02KC1P1@3P80CC8/
00L10@0Z0@80C0<404`10P1A0@40F04105P1001O0@<0I@8705410`1f0`/0Q`<;06L21P1[0PL0SP89
09<12@2G0@T0V@4909h22P2S0PT0[`@:0;d6302n1P`0_0H=0;d73`302100`0T@0<4;402d3AL0G@H<
05iEF`3Ng^00hN7R0>7Ti03TiNL0iNCV0>KNh02jE5/0c1@K0=8@6@3C3aP0d0hF0<l@5P2e4a/0Cblf
0=?Ef@3RhnH0h>3S0>3Oi03Ng^40f/oA09P^=`2^2Q@0/0L@0:X43P2X0Pd0Y04;0:822`2P0Pd0X04;
0:81302V0P/0X`4=0:41302N0PT0W04909T12@2I0@X0VP4909`1202Q0@/0YP8=0:H6402D0`/0R@89
08h22P260@P0P@8907P21`1`0PD0HP8205`20P1@E0d2003o00Wooooo00D0D91h0?n0002P8?00X23`
0=1@N00L0?n000L0X23`1`3oP0000`3@D7P0X23`0:0Pl0040:0Pl1l0oh0000<0d51h003o0000o`00
2?ooool8003o000;05Mk9P0S7SL0FTmO0517E`1;A5/0@cUG00h??01fFfl0R65]08iVKP2GKGL00P2M
M7`0?`2MLW/0WWEi0:5iO@2PO7h0X8F20:6@Q`2NSHD0VY2609nHS`2OV980UY2;09jKU02NWIT0VI^H
0:V^[@2PZ:X0[:ba096DV02MYJL0/KRk0;_3aP2l`lL0^L350:^c^02d_<80^/C70;W1a@2ka<P0^lS>
0;[9d@2S]L40]/WJ05]oY`1iWKX0amcZ0=7Ni`3@gNH0c]cV0<gKi`3;fNL0RInf08nU]`2aa=40T9jZ
082@UP25TYL0PI2D07f=SP1bQH<0LH:107B3P`1_PX@0M8B606ioP@1RN84083AL004<B@0124L00@Y3
00LH@P065cT0@UYQ03B8;`05003o00Sooooo2000o`1<0:0Pl0D00?l02oooool000[ooooo0380:=@7
05HC0`0m8Ah01P0003010@1:0P40BP4205<20P1I0P40G08106@11@1R0PP0@P4206D42@1[0`T0D@46
06P2202?0@T0T@0909L12P2L0PX0X0490:D2202e1@d0^@H<0;P43@2m2100_0H>0;h73`2o1a00`@XB
0;X=5`273AL0BS8j0=CDf03Si>@0hN;T0>CTi@3UhnH0i^?V0<AmPP385a`0da<I0=<@5`3A3aL0d0hG
0<HD7@1:3A@0`/K;0>7Si080h>3R0280gMgN0>3Kg`2JCE@0ZP`F0:d63P2Z10d0Y@8=0:812`2O0@T0
W@4:09`02P2O0@/0Y08;0:412`2Q0@`0W`4:09d1302J00T0VP4809X11`2K0@L0X04:0:P33P2Z1A00
XP@@09<22P2=0PX0QP070801201f0@H0L`4406L2101N0@40Ce@=0P00o`09ooooo`05052@N03oP000
X23`0:0Pl03@D7P0703oP0000`3@D7P0X23`0:0Pl0040:0Pl0030=1@N03oP000oh0000@0oh0000<0
d51h0:0Pl02P8?00102P8?000`3@D7P0oh000?n0000L0?n000030=1@N000o`000?l000Sooooo2000
o`00801DVB@07aPY06IJI`0F6C`082E9065EJ@0>3SL0L5ad08aVM@2@Ig<0UF]d09A[L`2HKWH0Wg=l
09icN02RN7X0WW]j09j4P02NSHD0XiB<09jAR`2PV9<0VYJ@09RES02KVI40WIbK09JFUP2RXJ<0TYJH
0;2a/P2JWZ40W:>W0P2k`L@0:P2i_l@0]Ko30:Rc]`2f_/@0_<G90<O@e02g`LP0_<W@0;G6cP2G/lT0
Pj;006Z<[`2[`mH0dn3W0=7Oi`3AgnP0dMkW0<[Kk02^_M/0DE>407eTR@1mHW/0WI>Q07j8T02BXJP0
N8J>07V7R`1dQH@0M8B20720P@1aPh@0M8N905M/OP0E:f000@m@0048B0013D4072i=04]RK00aA5@0
=e1M04QMA@D00?l02?ooool8003o000307QH]02P8?00X23`03<0X23`0P2h>;@D0:0Pl0D00?l02ooo
ool000[ooooo04D09m@7058C1010:BP02`410443101?0P80C04205810P1H0@40G04206H21@1T0`T0
>@8303P20`120@D0A0020702202=0@P0TP0:09H12P2J0@X0XP8;0:X63@2[1P`0]`P@0;L33P2l1a00
_@P?0;d93`2m2A00_@TB0;`:5@2V4Qd0@Q<L0<O8c@3Qh^@0hn?W0>GTiP3UhnD0iNCV0<nUZ@2n72<0
ca@I0=0C603A51P0ca8G0<XE6P1[3QD0WYbQ0>3Qi03Ph>80gmoP0=gMg@3Og]h0ZGAk0:0B7@2]1a00
Z@<=0:H33@2S0@d0X08;09l2302M0@`0WP4<0:42302O0Pd0W04;09h22P2L0@X00P2I0@P03`2K0@P0
W0480:822@2X10d0Y@D@0:H74P2O10h0PP8708D32@210PT0M@8606T20`1L0P80H08204a>1`02003o
00Wooooo00@0D91h0?n0002P8?00X23`203oP0000`3@D7P0j6Pl0?n0000B0?n000030=1@N02P8?00
X23`00@0X23`00<0d51h0?n0003oP0001@3oP0060:0Pl0030=1@N03oP000oh0001`0oh0000<0d51h
003o0000o`002?ooool8003o001=04F_6`0Z82/0FTmM00D:=00J74@0KUMV03X^C@1GC6P0S6Yi09=X
M@2BIW80TFM`09Y`N@2OMWh0WGEj0:1fN@2LMWH0X8>00:6:Q@2MRhD0Vi2:09jDS`2OUi40V96;09JC
S`2GV9L0UIND0:2RY02QXZD0]KJg0:^`/`2NYJT0^;g00;S1``2h`<<0^L750;[4a@2ob/l0^<C;0;S1
aP3;e]d0`LkG0:2c``2_am@0Mibn07^O_`2ecMd0d^3X0<oNj`3:fo40Y;7D07UZV@1d:eL0R0h^0905
6`2<1A/0Pa@Z09AUL02BV9l0TIjU07Z6R`1kRHX0NXV907N6R01`PH80LX>802m4JP014Eh00PiH00HC
B@0eC5d0Efi/05Q[J@0iBED0>55K05=KF@04lP801000o`08ooooo`P00?l000<0D91h0:0Pl02P8?00
<02P8?000`2h>;@0d51h0?n000030?n000030;Ph]02P8?00X23`0100X23`00<0:<Pl003o0000o`00
0P00o`0;ooooo`002_ooool0EP0Xe@P0EAL803<K600B0@40A@8304h10@1?0@80E`4205X10P1O0@80
I04306<10`1?0`@0ERP]06dg?01Z1`d0Q@<:08l12P2B0@T0TP4709L12@2S0`/0Z@D<09d41`2a1Q00
^0@?0;/74P2k1A40^`LA0;/8402k2A80_@XD0;L?601N2Pl0UiNM0>;Si`3PhnL0hn?W0>;QiP3RhnH0
g]?E0;IWIP38Hf00b6MR0<IVHP36J6@0aV]V0:=YI`2NVY`0gMgQ0=oPh`3Lh>40gmoR0=oNh@38[K80
RQ`W0:`9502]10d0Z`H?0:L33P2S0Ph0X08<09h32`2M0@`0W@4;09d1302I00T0VP4:09T12@2I0PT0
V04809`12`2Q0P`0X`8;0:L43`2R1Q00U@<<09X53P250PP0O0<807L11P1b0PH0JP8406430`1S0P<0
Bd/70P00o`09ooooo`04052@N03oP000X23`0:0Pl0T0oh0000<0^3Rd0=1@N03oP0004@3oP0000`3X
J3`0X23`0:0Pl0050:0Pl0030>QX?03oP000oh0000<0oh0000<0d51h0:0Pl02P8?001@2P8?0N0?n0
00030=1@N000o`000?l000Sooooo2000o`00C@0[cA00=2HX04@lC`042SP081i4075EHP1ZDF00@SE@
08ETL`2?I780UFQd09Q/M`2JKWP0WGEm09]bN02LLgL0Ug5d09YnN`2JPg`0VhZ309^>Q`2LThl0WiVD
09J@S02HU980UYNE09NHV02NXJ80XJFW0;>h^@2V[Jl0X:JZ0;Bj_@2f_L00_<?70;S0``2malT0^<?7
0<?=dP30b]00^/W@0;S8dP2cb=T0MIRg05UnZ@2A]=40bMc/0;G3gP27P:l0KTIk084WE@2F3BX0W@DE
09X64P2?1100T08<09813@294240X7f907n:S`1mS900NXZ<07Z8S01hQhX0N8J:07F4RP11EWD00aMG
02@kJP0R=eP0FG5a05]aJP1JKV/08cI804INJ`1EIF@04Lh;00@00?l02?ooool8003o0003052@N02P
8?00X23`02h0X23`00<0d51h0>QX?03oP0001P3oP0000`2h>;@0X23`0:0Pl00?0:0Pl003052@N000
o`000?l000800?l02oooool000[ooooo0400:=H805TM3@0d7Q`07@4104d30`1;0000C`4205P10`1H
0@80GP4305l10P1R0@80I0D807Tg@`25=T@0OP<>08/1302?0@X0T@0808h11P2G0P/0Y08;0:h3302a
1@h0]`H?0;P23P2l1Q80^`LB0;T64@2h2140^PPB0;h;5P2j2aD0P@dC06iWKP3Oh^H0h^CX0>3SiP3S
h^L0i>?V0>CSi@3Ugmh0imoM0>WPgP3YhN40i=kM0>OQh03Uh^40hn;S0>;Qh`3PhN@0gMoQ0=cNh03M
gMl0elW<08hi@02Y2QL0[@@<0:X53P2X0Ph0Y08>0:894`2K0P`0WP8=0P2L0@`0502M0Pd0V`4;09/1
2P2I0@X0VP4909d22P2O0P/0XP4:0:H3302X2100TP@;08X530290PP0NP0507d22P1X0@@0G`0106@1
0`1V0P80DDl;0P00o`09ooooo`04052@N03oP000X23`0=1@N1h0oh005@2P8?0N0?n000030=1@N000
o`000?l000Sooooo2000o`00C@0Xf`l0@BdY038]A00X:T`0;bQ007AGH01eEf00KE=R089OK@2@IW<0
UFQe09QZMP2HK7H0WG=m09YaMP2GKG00UVe^09EiM02LQGl0WX^409Z<Q`2JThl0WIND09F<RP2HTHh0
SHb809:DTP2FVi`0X:>V0:b`/`2_/KH0Yjja0:ff^02la<L0_/C80<?9c@2ma<P0b<oE0;O0aP35d]P0
_LgH07BJ_@2V]ll0/[;709^H]@1kMIl0Q5Z508D`F`2=5CD0T`lU08lC7P258BD0QCm307UDH@1L?U/0
NAP^09<2402C0Ph0RB@c08b6R@22SY80OHbA07b:SP1iQhX0MhB90762Q@1NLgh0DFMj06UnQ`0X?eH0
Fg9h05ibK`1LL6l07C=1059[KP1HJfL07jhH00@00?l02?ooool8003o0003052@N02P8?00X23`02/0
X23`00<0d51h0>QX?03oP0000`3oP0030=1@N0040>QX?03oP000oh000?n00140X23`00<0D91h003o
0000o`000P00o`0;ooooo`002_ooool0<@0XePP0GB8D02/G5@0M0@40B`<204`10P1=0@80E@D70582
0P1J0P<0H0<606<11@1T0@@0K@XD07T64`280Pl0S@8<09422P2B0@X0S`4509L12@2X0``0/@D<0;05
3@2c1`l0^`P@0;`74P2i1a40]@H?0;D74@2f2100]`LB0;`;4P2S3aT0DCDn0<G8c`3Qi>H0h>?T0>7R
i@3ThnD0i>CU0>?Si@3Thn@0hn;T0>;Ri03QhN<0h^;T0>CSi@3Qh^D00P3Nh>@08`3Kg^00g=kP0=kN
h03McM80TT180:P<5P2]0`d0ZP8=0:P33P2T0Pd0W`@?09h33`2M0@`0WP8;09`1302K0@`0VP4;09/2
2`2L0@X0V`4:09d22P2O0P`0X`8=0:T43@2Y1Ph0X@L@08d42`2A0`/0R08907H21`1O0PL0H08506P2
101Y0`80E3h900800?l02Oooool0101@T7P0oh000:0Pl02P8?0N0?n000030;Ph]02P8?00X23`0180
X23`7P3oP0000`3@D7P00?l0003o0008ooooo`P00?l004d02oL404hb;00R83/0BTAH044e@`1aEUd0
LeEN07YJI@22Gf`0SfMe099VLP2FJ7@0V6af09a_N02GKWD0TfU^09E/K@2HMG80Vh9m09^5P02NSXT0
V8n:09^ET@2GTXh0VYBA092<R@2HUi@0TYNG0:2UZ02VZZl0Zk:e0:fe^02[/kH0_/C90;o4b@32a/X0
_/C80<77c@3?eM/0_LW?0;_<e@1aU;/0B6>L08=LP02:=E80SB4f08dP<026:S40S4Q:091SI@2RSX`0
]kNg09n[^@1MM8h0JX>S04HZE@261AT0T`4=08T64P2BK6h0Phb>07j<S@1lRh`0NhZ<07F6Q`1`PX80
LH:30722Q01^Oh80>U1P05YbM`1OLW40Fg1/051VI@1<Hf40FViY036B:`04003o00Sooooo2000o`00
0`0Xb3`0X23`0:0Pl00X0:0Pl0030;Ph]03oP000oh000080oh000P3@D7P50:0Pl0050;Ph]03oP000
oh000?n0002h>;@0402P8?000`1hF;@00?l0003o0002003o00_ooooo000:ooooo`0J02[G2P1Q8aD0
9a8A02<10P190P80C08204l20P1L3a<0CP4404P2101H4QH0DPD:05d21@1b0@H0Q`8>08h13@2?0Ph0
T04908h22@2A0@P0VP880:d4302c0`d0[`<<0:l53@2f1a020;L64@0j0;433@2c1Pl0/0D=0;L;4P2l
31<0^`hF07h=6@1/>T/0]IZZ0=O;e@3JdMT0gM;J0>3?f`3ObmD0g<C=0=o5dP3K`<l0g/;?0=^obP3N
`Ld0d[[80<jha03:]/80d[o:0=C0b`3G_<P0_7Z909/G902`2140[`@?0:`22`2W0PX0X`<=0:02302M
0@`0WP8=09h22P2L0@/0W08;09/12P2J0@/0VP4709X1202O0`/0XP4;0:@23@2V0`d0Y0@=0:D53`2P
1@d0QP8708011P1f0PH0H04505d10`1O0P@0IP<306DA2@800?l02Oooool0101@T7P0oh000:0Pl03@
D7PO0?n000030=1@N02h>;@0X23`00T0X23`00<0^3Rd0:0Pl02P8?00102P8?000`3@D7P0oh000?n0
000M0?n000800?l02?ooool9003o001<064n;`0I5c@0G4mN04TjB01ZDUP0KDiF07=AG01iEf40R5m[
091SL02FJ7@0UVae09Y`M`2GK7@0UVab09adMP2JNGP0WH9n09J2O@2KT8T0U8^509JAS02PWYT0X9fI
09FDT02JWi`0T9BG09VPY02;TiX0TI^N0;No`P2g_<40]kk20<C8cP39cmH0d=[P0;g7c033c]<0`/oF
0:2fa`2S^/h0Q:?806^=]`21T:L0[:B]0;J_]02j_Kl0b]?F0<_Ig@39f]l0b=SQ08^S^P2Q_M40HGbE
038jJ@1f5S80T@4?09023029>Cl0QhV;07f9RP1mRh`0O8V=07>4QP1dPhL0M8:507F2Q01aP8@0L7n4
06EkO01OM7<0GW9^05a_KP0_ADT0D6IW04=e?P@00?l02?ooool9003o03L0X23`00@0j6Pl0?n0003o
P000j6Pl4@2P8?04003o00_ooooo000:ooooo`0H02[H2@1W;AT07P/802T10@1=0P<0B`0205020`1A
0`D0BP4206DI7P2PC5T0W4QE05<10`1i0PX0RP8>08h23@2;0@`0RP4808`02@2?0PT0V`870;<53`2e
1A00]@DA0P2g1Q00?02h1a40/`@=0:d22@2b1Pd0/0@=0;L94@2h2A00_@/A0;h@6P2^52<0V1L_0:Q5
GP2jH7H0_EY`0;i>I02g@ED0]SQ>0;DdC02a;TL0/Bi40;0/?`2^:Sd0Z2Ln0:HW?`2X;480Yc150:Pb
B02X:d80Za4R0;H84@2f1@l0[`<<0:d32`2V0@T0YP8<0:<13@2N0Pd0W04=09/12`2L0@/0W@8;09/1
2P2I0@T0VP4709`12@2N0`/0X@8=0:<23@2S0@d0Z0H@0:P43`2T0``0SP8908T32P1h0@@0M0<806l1
1P1S0PD0H08306XG40800?l02Oooool0101@T7P0oh000:0Pl03@D7QB0?n000800?l02?ooool9003o
001<03aV6`0L73D0ET]I01LH>00b:d@0JDeF075<F@1iDel0Q5QT08aPJP2@HVd0U6Qc09UaN@2HKg@0
U6Q^09]bM02MNgd0W8Ao09^7P02IRh@0THN1096;Q02GTHd0W9RD09FFT`2JWih0PhV;08B:S027SY<0
U9bP0;bo``2h_/80]kk20<C;c`2j`/P0_LS=0=;KhP2ob]80]<C?0;c>fP2E]M<0LIJo03aYVP38gn`0
cMcX0=3LiP3?f^<0bm_T0;O;gP2/a]d0aLgP07EjW01MJhX0Zkg905ebT`1C:Dl0S0@D09812`243QL0
TGj007n;S01lS8`0NXV<07Z7R`1fQ8P0Lh6507:0P`1bPH@0L82306YoPP1SMgT0GG9b05U^L00jDUT0
=e5J05MLEP@00?l02?ooool9003o03L0X23`00@0d51h0?n0003oP000oh004@2P8?04003o00_ooooo
000:ooooo`1F02_I2P1W;QH06`L503D30`1=0@40C04304`10P180@80E04306h3201l10l0OP<@06h3
2@1g0P/0R@8=08/23@2;0P/0S04:08/12@2?0@L0X0880;<6302d10l0]`D?0;T5402i1@l0]PL>0;<6
302`1``0/0H>0;453`2h2A40_PlG0<4<4`333AH0`@hF0<4@6@304Ql0a1LS0<TF8@3>5B40cADO0<hE
7`3A5Ql0d1@O0<hC7@3=4Q/0bQ8J0<D@6@3331T0a0dJ0<4<602n2aH0_PXG0;h7502k1100]P@>0:d3
3@2X0Pd0YP<=0:@2302S0@`0W`4<09d23P2K0Ph0VP8<09`12@2K0@P0V08809`32P2K0@T0W@8;0:42
302R0P`0X`8<0:T63`2W10l0X`<=09T22P2A0PP0P`8707D11@1b0PD0JP8506<20`1Z4P`2003o00Wo
oooo00@0D91h0?n0002P8?00d51hDP3oP002003o00Sooooo2@00o`00C@17K1X0;2Po04a2E@0212`0
81/j06M<E01_CU@0ME5J081DH02:FfL0S61/099WLP2DJgH0UVaf09EWL02JLgH0WWan09j6PP2NSHL0
VHZ609F;Q`2@RH@0ShV508f;QP2ATHd0SYBC08R>T023QhT0UIZM0:F][`2k`<<0_<360;g5b031bL`0
c=GJ0<39dP2mbM40a]7H0:g3e`2L]m80FX6^09>if@2`c^D0OIW107QVT@2KEgP0XVB20;BD[P2YWl00
=CQZ06TXCP1h4bd0LbXm0:2S[@1iSJ@0=SIR07/@9P2D0Pd0U0@@091DF023RhP0O8b<07Z9S01iRX/0
MhR;07F4Q@1bPX<0Kh6206j1P@1/PH00Igel05eeL`1IKVh0DfQ[02Q3B`1MIfD04L`:00<00?l02?oo
ool9003o02`0X23`00@0^3Rd0=1@N03@D7P0^3Rd0P2P8?000`3XJ3`0oh000>QX?0030:0Pl0<0oh00
00<0d51h0:0Pl02P8?003P2P8?00101@T7P00?l0003o0000o`0;ooooo`002_ooool0EP0Zf@X0MD0S
01D40`0l0`<0C`8204X10P1<0P80AP4306D3101g0PD0P04808D12`1f0`T0K@8908D23P280@`0RP8:
08h12P2?0@P0U0480:H42`2b0``0]@D>0;H53`2h1A00]P@@0;D43`2e1A00[`<=0:h23P2a10`0^0PC
0;h>60333QL0``hD0<0>4`2n3QH0``lH0<XA60383aD0cA<I0=0C5`3?4A@0e1<H0=DB603B3aH0dQ0F
0=0>5P3?3QH0bPXB0<P94P342A00`PT@0<484@2k1@l0^@D@0;@43P2]0`h0Y`8?0:813`2T0a00YP8=
0:413@2K0@`0VP8=09X2302K0PX0V@4909H22P2D0PT0U@4:09/2302N0PX0XP8=0:<2302S2@l0Y1hM
0:0M802G1@d0U`4808d1201l0PL0K04406H1101Y0P@0I`T40P00o`09ooooo`04052@N02P8?00X23`
0>QX?580oh000P00o`08ooooo`T00?l004d0<j0B04HiAP0n<dX00@<Z01hH=@1XCE80KDiD07ACG01m
EEl0Q5QS08YOJ@2=HV`0UFUc09MZL`2EIg00WgIk09ikOP2LPh40V8J309jET@3>cL`0VYNF08^5PP29
Q840T8b:09RHUP27QXP0RHR;09FIW02RZjd0^L;30;o4a`3;dM@0`<O>0<cEfP3Bfn40am7I0:o0cP2[
_]00Y<CS07VJ`P0KBhD0WKkN03m>P`2663@0W@TL09D=801o7380Ka/i07DR@`2<8CT0S@DC08864`2R
OhT0Tj6]0393J@1S:4H0T0<@09D23P2:82`0V8:607n9S01kRhh0MhV;07N8R@1dPh@0LX:40723Q@1^
PX<0L8B306j1P01VO7T0GW9a05Q[J`0eDEL0DVQY02>O6003003o00Sooooo2@00o`000`1@T7P0X23`
0:0Pl00Y0:0Pl0T0oh0000@0^3Rd0:0Pl02P8?00d51h0`3oP00@0:0Pl004052@N000o`000?l0003o
00_ooooo000:ooooo`1F02_J2P1[>1T070<104/4101B0P80B`4204@20P0k0@80I@@507P11P200PP0
N`8:06021P1W0PT0Q08?08L13`2=0Ph0T04909<12@2D0@L0Y0890;<53P2e1@d0]0D=0;L63`2e10l0
]@<?0;843P2]0P`0[P8=0;843`2f1a40^@TC0;l>5@333AH0`@hG0;`<5P3241L0a@hD0<T@5@3?4QL0
dQ4G0=0@503B41D0da4F0=@@5@3C41H0dPlG0<l=5@3<3180b0XA0<L;4P342@l0`@P@0;`63`2j10l0
^@H>0;042`2U0`d0X@8=0:02302Q0P`0WP4:09`12P2K0@/0W04<09/13@2G0@X0T`490981202E0@X0
V`8;09/12P2L0PX0XPH>0:Hi>P3S];<0_7f609hh@02=4aP0Q@T?0801201h0@H0KP4406D10P1`50l2
003o00Wooooo00<0D91h0:0Pl02P8?00B@3oP0000`3@D7P0j6Pl0?n000070?n000800?l02?ooool9
003o001=04N^601H@T@0<2Q000<59`0Q6c<0IdeA06]?E01cEU`0N5AL081EH@27FVL0RUiX091UKP2G
JG<0TfE/09]aMP2POGh0WXF209b9Q02VWY`0e=GL09REV028Ogd0QGik08b:Q`2ATI00U9:B08V9S02;
T9D0VjBV0;Vn`P31al`0a<_>0=KLh039d]L0^/WB0<7;e038en<0_mO[02YISP1PR:h0T;3>0:Bme`0m
Ag/0RaH^0:8>7P2=4Qd0[HJ=06M@IP1G9TH0MP`W08l65@2A1180QCI40;o3bP1NKHP0@b]B08H55P2C
0@`0QPHD09YVKP24R8/0NhZ=07V8RP1gR8/0MHF807F3Q@1cPX<0Lh>40723PP1^PX80KH20069eM`1H
KFl093e604iWJ00_SbH00`00o`08ooooo`T00?l000<0D91h0:0Pl02P8?00:@2P8?030?n00080X23`
00D0d51h0?n0003oP000oh000=1@N0030:0Pl0<0oh004@2P8?03003o00_ooooo000:ooooo`1H02_J
2P1Z=A@07P8004T20`1@0@80B04203d20P0X0@40D0<306/31P1^10X0F`4704800P1X0`X0P@4<08L1
3P2=0@l0SP4:09801`2G00L0Y`<;0;<43P2b0P`0/`D=0;@53`2d10h0]0H=0:l33@2]0``0[P8>0;84
3`2d1Q00]0H?0;`<4`323QL0_PhH0;d?6@2o3Q<0aPhC0<`B5@3@4QD0e14G0=@A5@3E4QP0dQ4G0=<D
603>4AP0ba@I0<dD603;41D0aP/C0<D:4P3320h0``TA0;d63@2k10l0^PD?0;04302W0Ph0X04=09`0
202K00X0V`0809`22P2K0@T0W@8=09X12P2D0@L0TP4809<1202G0@X0W08;09/2202K0@X0W`H>0:mK
H@3M^lH0QBHh0:E6D03DVIX0ZV5U07P62`1j0@D0M`4406`20`1^3`/0;8H0003o00Wooooo00<0D91h
0:0Pl02P8?00103oP0000`3@D7P0oh000?n000120?n000030:0Pl03oP000oh0000L0oh0000<0X23`
003o0?ooool01oooool9003o001=02CH3P1hG5L07QP]02`W?00[8C80JDiA06a>E@1`D5P0NE=M085D
H@29FFD0ReiY095VKP2EJ740U6Qa09]cN02ONW/0WhN209f;R02FRHP0XIRL08MmN`28OgT0Q7ei08V8
Q02BTHl0SY2A08B7S028T9@0Y:^^0;Zo``2oalX0b=7D0=7Kg@32c=00^<G;0=;PjP2L//X0KYNj08:T
aP25[]40/lcM0<;Di`0cAGd0QBM30:<>80294B00dlC:0<cFh@2?UJh0AbM>07h=8@2A0a80PaDR0;6X
[P1jRY/0<C1I07`E:@2D0P`0S@<@080Z<P2;PH@0NhZ=07N7R@1cQHP0LHB407N5QP1dPhD0M8F707:5
Q01_PX@0Kh>306=hN`1JKFh0BV1Q04eRH@0gR2l00`00o`08ooooo`T00?l000<0D91h0:0Pl02P8?00
:@2P8?000`3XJ3`0oh000?n000030:0Pl0040;Ph]03oP000oh000?n000<0X23`103oP00@0:0Pl0<0
0?l02oooool000[ooooo04L0;=X:05/S0`0Q0@40BP8304`10P130@40?@8301h10@0^0@40@P<404@2
2@0g0@D0@@4407D33@220@d0Q`4>08`23P2>0@/0T`4909/12@2[0``0/@8;0;D53P2b10h0/0<;0;<4
302d1@`0/@@>0:l23@2]0Pd0/0@>0;443P2b1Q00^0dE0;X;502h2a@0^0dE0;d=50343QD0bA0E0=4A
5`3C4aP0cQ@G0<DF6`2a6Qh0YBPZ0;1:BP3=Lfl0bFMQ0<59B02f8B@0``hD0<@940311`l0_PD>0;/4
3`2g0`h0/@@=0:H2302R0@`0X04:09X12P2K0@X0W08909/22@2L0PX0V@4909D12@2E0@P0U`4809P2
2@0209T12@0?09h12P2P1@d0/5YP0=bd_@286RL0VBlg0=fa^@25CeL0Ue9D06dA501e10L0L@4306X9
1@0_Q`400?l000Wooooo00<0D91h0?n0002P8?00103oP0000`2P8?00d51h0?n0000T0?n000030>QX
?03oP000oh0001/0oh0000@0X23`0?n0003oP000X23`0P3@D7P40?n000030:0Pl000o`3ooooo00Oo
oooo2@00o`00C@0Pi@`0MeU:010;701?@TP0>bXd06a?E01]D5D0KDiF07E@F`1oEF00PeEQ08QIIP2?
Hfd0TfM]09I[LP2JLGH0WWQi09j2O`2NRXT0UHF208j0N`29OGD0Qgef08MmNP27P800T8n=08R9S027
R8l0S9:F09^RY@32b/d0`<K:0<C=dP39d]P0cmgQ0;[:d@2H[l40_M3N08nde01aV/P08dn90;;=h03A
gnX0DFZJ06e2J02J3Al0T@XM0:f0S@3?f^00c=[T05YZT01V:e00T@@F08l55P2?HFT0^lO?03i:K@1P
;Dd0R`<@09<130251Q00SemT07^7RP1gQh/0M8J:07:5R@1`PXH0KX:406n2Q01^PH<0LhB70726Q@1[
OX40HWAe05]`K`1KKV`0CUi600<00?l02?ooool9003o0003052@N02P8?00X23`02T0X23`00@0d51h
0?n0003oP000d51h0`2P8?00103@D7P0oh000?n0003@D7P20:0Pl0050=1@N03oP000oh000?n0003@
D7P03`2P8?03003o00_ooooo000:ooooo`1702gL2`1J9`L09@4104l30P1>0@80B04204P20`0Z0P80
BS8d0;VVZ@0`41L0>@4606<32`1l0P`0P04<08@02`2;0P/0S04909812P2I00T0[P<<0;@32`2f1Q00
]PLA0;843@2e1@h0]PD>0;<33P2a0Pd0[`<>0:d33P2b1a40]@XB0;H;502g2Q<0^@`D0;`<5P323aX0
bA4L0<TC6@315Q`0Y1dP09Hh>@2^MGH0d;Jf0>?If03Sh>80i>?T0>GRh@3TfmX0f[Vh0;=7BP2g4AT0
_`TB0;h7402l1A40]`8>0;423@2X0Pd0XP4;09h12P2H0@X0V04;09X12`2J0@X0WP8<09d12P2K0@X0
V04809D11`2E0@P00P2F0@P03`2I0P/0X0<?0:<g@P3Z^<40SB8^090F803RYk00MSm90;ZMX@1mGEl0
X6Y]06h@501^3@X0;XL1003o0009ooooo`03052@N03@D7P0d51h00@0oh0000@0d51h0:0Pl02P8?00
^3Rd7`3oP0020=1@N0H0X23`00<0^3Rd0>QX?03oP0006`3oP000103XJ3`0X23`0:0Pl03@D7P20?n0
00030:0Pl000o`3ooooo00Oooooo2P00o`00C@1fET405`lK05A3A@19<cX0K4eB06e=E01aCUH0MU9K
07eGH@21F6<0PeQS08aRJP2AIg00TFQ]09Q_LP2ON7/0UWQf09b7P`2IQh<0TXEo08Z0N@29OWT0RH1l
08EoO@2>S8`0R8V<08Z?T`2@UiX0X:^]0:fg_032b/h0bm;H0<G?eP2jc=<0bmgS0;W;g01cUkh0LYBj
07fYe@2X`mL0d^3X0=?Oj02R]m80A4ao08/K<@2M2AX0Pb0`0=71bP3?f>00[;_B03/aIP2432H0U08C
08@R<@2LW:<0NXZO03XbF@1l2a`0T`4;09433028;cH0R8R907b8S@1gR8/0M8N:07:5R@1_PhH0LXB5
06n1Q@1aPhP0KXB40764Q@1WNW`0I7Mf06AhM`1JHEd01?8200800?l02?ooool:003o02`0X23`0P3o
P0000`3XJ3`0X23`0:0Pl0020:0Pl080oh0000@0j6Pl0:0Pl02P8?00X23`0`3oP0000`3XJ3`0X23`
0:0Pl00=0:0Pl00302S8?000o`000?l000_ooooo000:ooooo`1H02cL301A80<0:04105420P1:0@40
B00104`10P1=3100:@PA03lU=`1<5R40H`D<07D22P1n0@/0O`4:08@02`2:0@`0S@4:09812`2I00X0
/0@?0;<33P2f2140/PD=0;843@2e1Pd0/P@<0;833@2^0P/0[@<;0:/22P2`1Pl0]PXB0;P<4`2h31D0
_Q0J0<<@6@3441X0`10I0;8J7P23:BP0_inK0>7Ie@3Thn80i>CU0>;SiP3Ri>H0hN?V0>?SiP3PhN<0
gmkO0=>d/`2H:bl0^0dE0;l64@2j0P`0]P8=0;823`2Y0Pd0X`8:09d22`2G0@/0U00909X0302L0@`0
V`4:09P1202I0@X0UP4709@1202F0@X0U04909D12@2G0@`0X@<>09LA703TWjP0Vca808l:5P2fHfl0
RU=L0;NPYP2iYZ`0XXR?09AFG@1[3PX0;XH0003o00Wooooo00<0D91h0:0Pl03@D7P01@3oP0020:0P
l0030=1@N03oP000oh0001`0oh002`2P8?0L0?n000080=1@N02P8?00X23`0:0Pl03@D7P0oh000:0P
l000o`08ooooo`X00?l004d0CVLX02HL8`1<=cL0Fcm206a;CP1]CE80LE1G07ADG01iEE`0OUQQ07=?
FP25FfH0SfA^08iSJP2DK6h0VGEg09MhNP2LQX@0V8N509R<QP2@Qh80SXF008J1N`25PX80QhJ408N:
S`28TIL0TIRK0:Fb]02a^kl0^/?90;_2b@3DgN<0Z[g;07FBZP2eb]`0QZG808N]e00RDhh0Qj_90=;P
j@3CgnP0d=o[041LRP21AV@0V@dM09@=7@2@@580eLcG0<[HiP1=GX/0KbU=09H3502;1Q@0Ug9l09FT
/@0a@6L0LBU409@3402G0@d0Q`XC091gNP1lRH/0MXR:0723Q01bPhH0LH>606j1PP1_PX<0L8B706n4
Q01`QH<0Igml06=hMP1XP7h0IWEa00o<2@02003o00Sooooo2P00o`0/0:0Pl0040=1@N03oP000oh00
0?n000<0X23`00@0d51h0?n0003oP000^3Rd0P2P8?001@3@D7P0oh000?n0003oP000^3Rd00h0X23`
00<0D91h003o0000o`002oooool000[ooooo05P0;Md=05/[300_0@80E@8304/10@190@80CP4205h9
401_:3D0L2/l07@B801c0@X0M`4807d12`1o0@T0QP4<08`23P2@0@X0T`4;09/12`2a1@l0]0@>0;@6
3`2d1a00/`@>0;@63`2f2100/PH=0:`22P2/0`/0Z`<;0;874@2d2A80]0XA0;X>5@2j4aT0]1PJ09lT
9@2LAD40[7ef0=K7`P3Thn80hn?S0>?TiP3ThnP0iNGY0>;SiP3Ri>H0hnCV0>3Qi03Ph>80hMcL0<6B
U02W72D0_PLA0;`43@2h0`h0/@8<0:X3302V0P`0X08=09`12`2K0@d0W04=09d13@2I0@X0U`4709/2
2@2F0PL0T@4609@22@2C0@X0T`4909D12P2P0Pd0WPLB09XY=@2iHF/0Z4M=07HG8P2QDV00XWR40:R9
T`2GLGT0KbTb06H6100aQ`800?l02Oooool00`1@T7P0X23`0=1@N0060?n000030=1@N03oP000oh00
01X0oh000P3@D7P<0:0Pl0030=1@N03oP000oh0001T0oh0000P0j6Pl0;Ph]02P8?00X23`0>QX?03o
P000X23`003o00Sooooo2P00o`00C@1<MBD0=BLX04<`;P1QBd`0IdY=06]<D@1_CeH0Me1N07UAG@1j
Del0L4iJ089HH`2?HFX0SemW09=XJ`2LMgL0UGUh09N3P02EQH00Uhj809J=R02>Ph00SHN408j7R022
PH<0Gfmo07f:U@2^]kX0UInV0:fg_@2la/P0a]3F0;?3bP34e=`0/<KH09:bd01YS;D0EX:f09Zid`3:
h>P0e>3X0=?Pj03AgnH0SZ?004i;N@233R@0V0PH08X;7@2`PXh0bmKP09jac011=6<0P`TN09423P23
<Cd0[;Bk07:4WP1:<UP0Q`LJ09<1402=0`h0RdaC07f7RP1gRX/0M8N807F7R01cQ8L0LHF50764Q@1^
PHD0Kh>406n4P`1YOgh0HgYh06R0OP1`PX007j`G00800?l02?ooool:003o02d0X23`0`3oP000103@
D7P0X23`0:0Pl02h>;@20?n000040>QX?02P8?00X23`0;Ph]0<0oh0000<0d51h0:0Pl02P8?00302P
8?000`1@T7P00?l0003o000;ooooo`002_ooool0F00^gPl0DQl703T20@1D0P<0B@4104/10P1A0@80
GP8306811@1Z0@P0N@8907H01`1f0@T0NP8807d12@260@d0SP8<09@12`2J0@`0WP490;053P2d10h0
/@<<0;03302a0``0]@D@0;D7402^10/0X@<;09HB5@2L8R40XQ/L0:4K6`2N8b80XCdi0:]PF02kU8X0
f/o:0>;RgP3Ri><0h^CV0>7Qi@3Qfn40hMCL0>33d03=YK<0SgZ90=3FfP3Pi>H0h>?V0>3Qi@3Oh><0
gm?F0:Q>E@2j2A<0_0D>0;T33P2_0P`0Y`4<0:H13`2Q0@`0W@8909`12`2L0@T0WP8;09d12`2L0@X0
V`8:09T22P2F0@L0U@4909<12@2B0PP0U04909d1302R0`d0X@PB09T@7P2U=DD0Q`/H08P44P2A>dH0
TVM`09a]M`1i>Cl0J``:03mZ1000o`09ooooo`03052@N03oP000oh0001l0oh0000<0j6Pl0=1@N02h
>;@01`2P8?020=1@N0030;Ph]02P8?00X23`00@0X23`00<0j6Pl0?n0003oP0006P3oP0020:0Pl004
0=1@N03oP000X23`003o00Sooooo2P00o`00C@0fTA80Ac8[05Ln>016<ST0CSHo06Y=DP1^CeD0LU1J
07QDGP2BKWL0PEUT08=GH@2>HV/0Sf=]099[L@2KN7/0VW]l095hMP2DQ7`0ViB<09N@S@29P7h0RhJ3
08Z5Q01cNhL0E6V1096JX02NYZT0XZV]0<;<dP2X/[T0`m7E0;G8d`2N]lT0//[M06B9[`2Vc>d0Ag2Y
05ElZ`3@hNX0d]oW0=?Oi`3Bg^H0bmcY03=:NP1e<4h0T0@D09P7502@:CT0e<gG0:Fba@1;D7X0NRHo
09423`202QH0RgIm0:Fc`00e?VH0MaXb08l13`2?0P`0OQ/U08N3Q@1hRXh0MhZ<07J8R@1eQhX0LXB7
0722Q01`Q8D0LX:306aoP01XOGd0JWam06MkO@1fQXT0;idY00800?l02?ooool:003o000307QH]02P
8?00X23`02X0X23`00@0d51h0?n0003oP000oh000`2P8?000`3XJ3`0oh000?n000030:0Pl0040>QX
?03oP000oh000?n000h0X23`00<0N5Rd003o0000o`002oooool000[ooooo00@0;n0@04dL1`0f0@40
D`410P1>0@404@1@0040FP4105l00@1Z0@H0N04:07@01`1i0@X0NP4807X02@250@`0S`4<09T12`2M
0@T0WP8:0:X22P2b10`0[`4:0080/@<=02X0/P8<0;<43P2Z0PX0V0D:05D<3@2`UYH0ekB]0=NbZP3Q
aKd0j=cF0>GPgP3Thn40h>CU0>7Tj03Ph>H0f<oH0>2nc@3GTZD0`eaa0;H^A02e7Rl0La8O09fLX@3Q
iNH0h>3T0=oOhP3NhN80gn7P0;EnP`2a3AL0^0<<0;L43P2`0Ph0Z`8A0:H13@2R0@/0W04809/1202J
0@P0W04909h2302K00X209P12@0C09L1202F0@X0U04809L21`2J00P0WP4<0:44402L10d0U`@>0903
3`2B0@`0T04:09Pf?`2XJgP0N2ln09=IH01V3@/0HA87003o0009ooooo`03052@N03oP000d51h01X0
oh0000<0d51h0:0Pl02P8?002P2P8?050?n000H0X23`00<0d51h0?n0003oP000703oP000103@D7P0
oh000?n00000o`08ooooo`X00?l004d0=j0=05Pk;P1[CT40BS@g04hk@@1[CU<0KDiD071>EP2<NX40
bL36091aP@26EfT0RV1[08iTKP2AJg<0VgEl08m/L02>LW00UH=o09R<R02ES8X0RhF108Z5P@2;R8T0
?De[06ioT02SZjl0Y:fb0;2i`02S[[H0bMCL09RW/`2ea]00Wk_?0;3?i@20X<406dZ707NLa02>[//0
d^7X0=7OiP3CgnL0d]kU0<kMi@20U[<0@cYU07/<8@2E1aD0S`HG09PlD`2;?5d0RC1@08dH;02A1Q40
Q`PD09A]MP2DXJ`0DF>205lcE0251AH0T@4=08D43`2<I6L0O8^=07Z<SP1gR8d0N8N=07J4Q`1cQ8H0
Kh:306j2P`1]PX40Jgim06UmO@1YOH00MhZ<03n2?@02003o00Sooooo2P00o`000`1@T7P0X23`0:0P
l00[0:0Pl0<0oh0000<0j6Pl0=1@N03XJ3`00`3oP000103@D7P0X23`0:0Pl03@D7P30?n000030;Ph
]02P8?00X23`00`0X23`0P00o`0;ooooo`002_ooool0AP0Tj0`0Ca/603`20@1G0P80D@4104`10`1A
0@80G@8106H2101^0PH0MP4707D1201g00X0O@8;07l1202:0P/0U@<=09/12`2P0@/0WP4:0:L32P2_
0``0[`4;0;023@2`0`/0[0860:l32P2]0`/0YP<;0805301R;3X0YI:Q0<Vob@3Cc=<0f=GI0=gFg@3I
cmL0flC@0=J/_03=RYh0ae]`0<4^@`366Rd0cA<S0<d=603?3aD0Y14G071NHP3PhnH0h>7U0>3Qi03M
hN80g>7Q0<FVZP2W4Qd0^0H>0;D4302a0Pd0Z`8<0:D12P2S0Ph0W@4;09/1202L0@T0W@4<09h22P2L
0@X0VP8:09P22@2H0@X209D12@0@09L1202I0@P0W@4<09h23@2E0P/0R`<;07h12@260PX0R089080<
5P2F9cH0N`DB08H/=@1V20L0Ha87003o00Wooooo00<0D91h0?n0003oP0006`3oP0000`3@D7P0X23`
0:0Pl0040:0Pl0030;Ph]03@D7P0d51h00L0oh0000<0^3Rd0:0Pl02P8?000`2P8?000`2h>;@0oh00
0?n0000O0?n00003003o0?oooooooooo00Kooooo2P00o`00C@0Hb`<0HD0a06a<?`19<C<0;R@_06Q=
D01ZBDh0KTaD07]PK02PR9P0PE]^08MHIP29GVl0R65/08eXK`2HLGH0TF]]09=hMP2FQ8D0VXj=09F;
Q`2?Qh00RhR307^3T`0]B6h0W:J^09VQZ@2V[[L0_<K>09ZX/`2U];d0Z;S10:c2d@1TPZ@09e:509^o
h@1[T[l0AWJ^0:71eP3ChNP0eN3X0=;Pj03Bg^H0dMkV0<gJi@1hRZD0JE=W08E7C`28@DL0S4Y@095G
H@1mCUd0TFAX08URIP2@KW80XJ:Y09^X/P2P/<@0?SUP074B;02>0a80SP8<08<b>P21R8T0O8^>07R9
S@1iRY00N8V<07>6RP1`Q8D0KhB50762Q@1`P840K82006YoOP1`Q8D0EEQC00800?l02?ooool:003o
0003052@N02P8?00X23`02/0X23`00<0^3Rd0=1@N03@D7P01P3@D7P40:0Pl0<0oh0000<0j6Pl0:0P
l02P8?00302P8?02003o00_ooooo000:ooooo`1H00ch101>6@D0A@8205d20`1F0@40C`4205@20P1Q
0P<0I@4306/1101i0@H0N@4707/22@1o0P/0Q@4:08d2302E0@/0W@8;09h22P2I0@T0XP8:0:l2302_
10`0[`<;0:`22`2[0PT0[0<70:`22P2Z0PT0[@<<0:D84P2D2a`0UQ/^09`W?@2iAU`0`DIL0<8nD`2m
8S@0`QHV0</C8P3A4a`0da4I0=<A5`3B3QH0c``A0=4>40344QL0FB0V0=CGf`3PhnH0h>7U0=kPh`3L
g^40f<g@09dY<`2c1100]P<>0;42302Z0@T0Y@490:02302M0@/0V`8909`12P2M0@/0W`8<09h23@2H
0PT0UP4909P22`2C0@T0T`8909D1202G0@P0V@4809l13@2J0Pd0R`<:07d220200`/0L@8606<21@1m
0PT0Q0<:07D2101Y0P40H@/3003o00Wooooo00<0:<Pl0?n0003oP000;03oP0000`3@D7P0X23`0:0P
l0040:0Pl240oh0000<00?l0ooooooooool01_ooool:003o001502KG2`1O?BH0K4`m06M8A@0f9c40
ITa>06M7C01ZAU40L4MC07]@G@1oDel0P5IT06a@G`1PCUX0PfE/09Q_M@2DKFl0TgIf08mmO02IS8T0
Uhn:09F=R`2BSi<0>e5k05YcT`2NYZT0WJBY0;>oa`2;Uj40`/oF0:6b_02__//0O9N^0;SAj01nVkl0
>fFQ06:>_`13Lj/0an7`0=;Pj03Ah>L0dMoV0=;Oi`3@g^D0dMcU0<[KhP38f]l0cMOK0<gEe`3:emX0
aM?K05UdT`22Vk@0G7><0;C8e@27VZT0V:Ve09:R[P1@GX40IC]P08H87@2C0@d0P@dF08elO`1mSY40
Nhj?07R:RP1iS8h0LhJ90080MHN900P0LXF606j2PP1/PX40L8J707B7RP1RIfD02>D4003o00Sooooo
2P00o`000`1@T7P0X23`0:0Pl00h0:0Pl0040=1@N03oP000oh000?n000h0X23`00<0:<Pl003o0?oo
ool02_ooool000[ooooo01`00?l004lI101A10@0H`8205P10@1E0@80D@4105l1101U0@<0J@4407T2
201h0@L0N`4908@130270@`0T08@09H13P2J0PX0VP4:09<02@2K0P/0ZP8:0:l52`2_1@`0Z`<90:L1
1`2X0@P0Z@490P2X0PT0>P2/10/0]P/B0;T?5P2l4QT0`AHM0<4H70325aX0baDI0<`B6@2o4aH0_bTX
0<8_<@34<cD0acLf0<`a<@3:51T0c0dD070;3`2ZZJd0hN7U0>3Oi03Og^<0g=gR0=gKgP2PE5`0[0/F
0;@43P2a0Pd0Z`4<0:L22`2Q0@d0W@8;09`22@2K0@P0VP4:09<330210PT0S1PN08@52`2B0PX0U047
09<12@2B0@P0U04709T1202M0P`0W@8;09/3302?10`0QP<908021`1/0PD0J08606X2101[0@80IP81
06<=1@00o`09ooooo`03003o003oP000oh0002d0oh001P2P8?000`3@D7P0oh000?n0000N0?n00003
003o0?oooooooooo00Kooooo2`00o`009P1V?ad0Kdln0691>`0n9R/0J4U;06]7C01[@dd0LDUD07U>
F`1mDel0JTeI07ILJ01[FfH0J5IS08mXLP2:IVl0Q6ac09F5Q02FS8L0UHj909NBSP25S9`03biX09JX
^02]];L0Xjfd0:>_]`2f`/X0Wjji0:Fc_@2c`m40Qijn03i[VP2af?@0IHji06bLcP1CP:X0bn7/0P3C
hNP09P3CgnL0d]oW0<oOiP38g>/0c][U0=;Gh`3Ad=h0cL[K0<S2e@34]ld0LfF?06UJPP2JP9/0TG>;
09UlU02bT:T0V7B=089PO`1^?5h0Ra<Z09L23`2?0a00TU1I08b9SP25Ri40P8j?07f?T@1eR8/0Mh^;
07J:R`1bQhT0KHB406Z2PP1]P8<0MXR;06EcLP0E`Ph00?l02?ooool;003o03@0X23`00<0^3Rd0=1@
N03@D7P0103@D7P30?n000030=1@N02P8?00X23`00/0X23`00<0D91h003o0?ooool02_ooool000[o
oooo05P00?l0058F101O10@0HP4105X1001H0@00EP0206421@1V0P@0J`0407l12@260@X0Q04:08D2
2P280@T0T04=09T23P2K0P/0U04909412@2E0@/0YP8:0:h72P2_10/0ZP490:H01P2V0@D0YP470:L1
2@2Z0`X0[@@<0;H=5@2_5AX0Va`L0;=ED02nKfP0]f1L0:db<P2a7R40M0`<0=J`ZP3P`K`0hl?10>K7
`P3X[J`0[R0Y0<`?6@2E3aD0OW=h0=kNh`3Ogn<0g]oS0=cPh`3Kg^00[7f30:0B6`2b0`h0/P4=0:h1
2`2Y0@X0XP4=09d12P2M0@T0V`4909H22P1m0PH0MP4809HM:02>6b40SP<;09D2202D0@P0T@0609<1
202G0@T0W@8<09`12P2J1@d0U`D>09P32`210PH0NP<707811@1U0@<0G04206D20P1U40L00?l02Ooo
ool00`00o`00oh000?n0000U0?n000@0X23`103oP0060:0Pl0030=1@N03oP000oh0001h0oh0000<0
0?l0ooooooooool01_ooool;003o001>06EM6P1_CS`0K4/m06U5?@1ZBD@0J4M906]5C@1aBe@0NU5L
07]DGP1MB5<0LUiY06=KI@1ODeh0RVI_08UYL026KW@0UH2309N:R02GShX0Ti6A04IIP@0_Ch@0YK2g
0:V_/`34cM<0VZJ_0;G1b02X]/40[kk:06R3VP30end0LIS305J6^P1WTl<075:K0:oDk`3BhNT0eN7Y
0=GPj03CgnD0d]oU0<_Lj00oHI80P6R?098fE`2>9DD0S1dj08LE<P284Rl0QPdY08L;8P2;2R40RPTP
08X98P2;2B40S0TO08/9702=2AX0T`HG0944402@10l0RPTG08PJ;024:3X0QEmV07j=S`1hS8l0N8^=
07J:S@1eRX`0KhB50764Q01aQ8H0LXN906n0P@0UXQh00?l02?ooool;003o02`0X23`00<0^3Rd0?n0
003oP0004@3oP0000`3XJ3`0^3Rd0:0Pl0090:0Pl003052@N000o`3ooooo00[ooooo000:ooooo`1H
003o001D50<0HP@206<20P1K0P80D`4005T10P1R0P@0IP4307011@220PT0R@4=08D130210@T0R`8=
08l12P2I0``0VP4:09@1202A0@L0TP480:D3202Z1@H0[@H;0:`32P2Y0@P0Y`480:X22@2/0@X0[0@<
0;87402E31D0FaPI0:V9Q03LdL`0gm[E0=oEdP3MaL40cZJO07iSH02UZ:T0h>;Q0>7Rh@3Sh^40imCF
0;1>E`3551d0/Q8J0654B@3Gfml0gn3S0=kOhP3Nh>@0fmkP0;jSZ@2>62@0/@LB0;423@2/0PX0Y`49
0:813@2M0@/0V`0809/12@2?0`/0L`<708h3302D0Pd0QP@:08H3202C0PT0U@8809D1202F0@X0UP48
09`12P2L0@T0S`8808@2202F1@h0K`8407831@220`L0L@8505L1001Q0`40H`l600_Q00Wooooo00<0
0?l00?n0003oP0007@3oP0000`3@D7P0^3Rd0:0Pl0020:0Pl0030;Ph]03@D7P0^3Rd00D0X23`0`3o
P0000`2h>;@0X23`0:0Pl0040:0Pl200oh0000<0:<Plooooooooool01_ooool;003o001>05mi5P1d
Ccl0KD`l06]7?01WAT80ITQ806Q8C01^Be<0M4mG07MAG@1D@e40E51M051?FP1cFfL0Rf=[089RJ026
KW40UGj309R9R@2ITY00PHNG00lYJ@1LLYX0[k6f0;k4c02JY:h0aM3H0:>a^`2Y^<80YKO20:c1c`1/
S:`0NYg802QHVP1eY=D0HXg306ZD`@3Bh^/0dn7Y0=?Qi`3Bh>L0d]oV0<oOj@1_S;80FEUo08LjAP2B
@4H0TDQ=099EG02GI6X0V6ab09ahOP21Hg@0VWZ108EWK@27IVX0Sfia091/L02MMgT0TVU]08MMH@29
Ee/0QDY;08@l?P24<3H0MT15086<S@1lSi40MXZ<07>6R@1fRH`0KX:606n3Q01cR8T0LhV<07J<S`0i
RCD00?l02?ooool;003o02d0X23`503@D7P00`2h>;@0X23`0:0Pl0090:0Pl003003o0?oooooooooo
00Wooooo000:ooooo`0L003o001D4`40I@@306810@1G0@40E04205T10P1O0@40J`8307@110220PL0
R@4:08H22`250@/0S`4=09D23@2K0`d0V08809@01P2?0@P0SP4609d31`2S0@H0Z0890:/22@2/0@X0
Z`890:`22P80[0<:03X0/0/C0587302?RXd0gMkM0>3Qh`3Qh^@0hN7S0=WGg@3Kemh0h>;T0=;Ge`3N
hn<0g^CS0=oSi03Rgn00dj6W0;4O9P324QL0D18I0;6e_03Kgn<0g]oR0=gNhP3KgN00d<G708doB02T
2aP0/0<@0:X12P2W0PT0Y04<0:413@2N0@/0V`4:08T4301O0`D0R0@=09<22`220PL0M0440902202E
0@P0T08808D21`2?0`P0V`4;09d1302L0P`0R`<908X32@1m10X0I`4408L5301k0`D0JP<305l10@1W
5Pl05L812Oooool00`00o`00oh000?n0000L0?n000030>QX?02P8?00X23`00/0X23`00@0d51h0?n0
003oP000d51h1P2P8?0P0?n00003052@N?oooooooooo00Kooooo2`00o`00CP0mY0`0LTll06i<?`1]
Bcl0IdHo06A6AP1TAdX0K4UB07=;EP1hCed0KDmL05M9E01bHF/0SVii08mYLP2@KFl0U7Ig09F0O`2E
RHH0UIBK02hnK@068fh0Q9B[0;2f^P2h_/<0/[c30:>_^@2V];h0`m7K08JL[02[`]<0L96b09Jjf`1k
X/d044FA06^Kb`2R_]D0d^;Y0=CRj03DgnD0e>3Y0=;QiP3BhNL0`mKS0:c2c`33c=00aLkA0<WDf@3:
fMd0c=[P0:Zld@1QQK40@VB@09Rba@2EZ[80/lG;0::c_@2S];d0WZjf0:2]]02O[K80SijS08fJWP2<
V9X0R96E08:<SP1iS8h0NHf@07N<S`1eR8d0LhV<0724R01YOGl0LHF707B9S@1eRhl0Cf5>003o00So
oooo2`00o`000`1@T7P0X23`0:0Pl01:0:0Pl003003o0?oooooooooo00Wooooo000:ooooo`1H003o
001J5`40J0<206<20@1G0P80D@4105@10@1W0P<0K@4407@11@220@P0R0480802301o0P`0S`4<09D1
3@2H0@/0V@4909@21`2<0@H0RP4309P11`2Q00H0Y`890:X22@2^0`/0[`8<0;44302]0PP0[P<;0:d8
4`162Ph0YjJZ0=kPh@3MhN<0fmoR0=cIh02ZM8T0N2m=0:N<X@3Kg^D0gn?V0=gQi03Pi>H0hNCU0>3:
cP2/=Sd0`a0D06L;4@1_KG@0emcO0=_Lh03Ngn@0g=gP0=SEe`2TLWX0V10N0:/3402X0P/0YP4;0:<2
3P2N0@d0W04<09T02`2:0`/0A`0206832P1n10/0K0D806<1102;0`X0U@8909422@1g0PD0N`8509T2
2`2K0@d0VP8>08L22@1n0@H0Q`<:07L31`1m10P0J`0106@10@1S0P40IaH?01K30@Wooooo00<00?l0
0?n0003oP000703oP0000`3@D7P0X23`0:0Pl0030:0Pl0030=1@N03oP000X23`00H0X23`0`3oP007
0:0Pl1l0oh0000<0D91hooooooooool01_ooool;003o001>04B[3@1cDSH0Ke1106i<@P1[Bd<0J4Q7
06Q8CP1ZAe80LdUG07]@H@21EVH0RFM_091`M`2ELWh0UW9k09MdNP2INGh0VXF409bAS`1iO9801AeW
01<dO02DWjd0a<_?0:JY/P2g_lL0Z[Nm0;70b`2Q/Kd0`=7N082K/`1oW[h0<V6I0;KPo@1hX=40>Ff_
0;gJkP3Dh^T0eN?Z0=CQj03Eh^T0e>;Y0=CRj03Ah>L0cmoV0<kOiP3@gnL0cmkW0=7Pi`3@gnL0`mKX
06fF``2Tan<0JiFi0:2mc`2X^LP0ZKC00;W6c`2a_LT0_L[F09na^P2J[;<0UZN_092QZ@27VJ00RI^P
07R;T01jSY80OI2E07:5R`1^Q8H0KH6506UlP01OLgP0JX2407>7S01OIf@01?822?ooool;003o0003
052@N02P8?00X23`04X0X23`00<0:<Plooooooooool02Oooool000[ooooo03X00?l006LL101a1@<0
H`4105P10@1A0@40E@4206T21P1/0PD0L@4508<22`280``0J`8606D21`2@0Pd0U`8<09`22`2I0@X0
S`4708T11`2:0PD0U@450:D32P2Z0PX0[0<;0:h22P2d0`h0]`H@0;<42`2c1`l0Z`LB04/83P2?T9D0
g=oQ0=cPhP3Nh^<0h=KK0:PgAP2k5bX0TaX^08UaP`3Jh>@0g^?U0>3TiP3PhnH0hmgP0;=KHP354AL0
S@hC03XX;036c]80f]kO0=[Mg`3LgN00gMcN0;^QZ02@7BX0Y`@>0P2W0@`0702S0P`0W@8<09/12`2L
0P`0UP@>04X210112@d0A@<803/10`1N0@H0S@8<09811`2F0PP0T0<908L21`2H0PX0W0<=09X23@25
0PP0PP<808X31`200`D0RPP=07@20`1U0@40IP82068;1P0G``49ooooo`03003o003oP000oh0001`0
oh0000<0d51h0:0Pl02P8?000`2P8?030?n000030;Ph]02P8?00X23`00<0X23`00<0j6Pl0?n0003o
P0001`2P8?0<0?n000030>QX?03oP000oh000100oh0000<0D91hooooooooool01_ooool;003o000]
027D1P1aCbl0Ke<o06mA@`1`DdX0Ke=B06Y>DP1/Be80KdYD07Q@G@23FFL0SVMc095/N02FLWd0VWIn
09imPP2OP8@0XHb?09fCU`14DH400Aei02m9QP2g_/H0YJ^_0;k4b`2/]l00ZKNo0;?5c@2P/[l0XK?3
06^6Y@2^b^D0KIG603I`]01bY=L0AGVg0;[Ll`3Fi>`0fNG/0=[Vk03Jind0f>K]0=OUk@3Fh^X0eN;[
0080e>7Z01l0eN7Y0=GQjP3AgNT0cMk_03U]/P1gZmX0S[KG0;KBh`2cam@0`];L0;_:e@32cMT0_/[F
0:6a_02Z^lD0X:nk09VX/P2CXZX0SYfU07f?UP1dR8d0LhV=06MmP@1ZOh80J7f206UnPP1>IF`0HGQk
06^2Q@1VLW804Ld;00Sooooo2`00o`000`1@T7P0X23`0:0Pl01:0:0Pl003052@N?oooooooooo00Wo
oooo000:ooooo`1H003o001X7P@0M@H206H10@1H0@40E04005L10@1T0@<0J04207@10`240@T0S08=
08@3301l0PX0U08>09/23@2L0P`0V08:08`120290@H0S@4509<11`2L0@L0Z@<;0;04302d10h0]`@?
0;H43`2c0`h0/PD@0;094@1W2A00DTaD0=3Ef03MhN80gN7S0=kLg`2cE5h0aA8L0<LC7@1Y3A/0/K6j
0>3TiP3OhnD0h^CW0>CSi@39U9T0_QDL0;8@5`100@H0VibO0=WMh03Gfmh0fMgO0=SKg@3Fd=<0TdA>
0:@54P2U0P/0Y0890:41302M0@/0V`4909P1202I0P/0PAPN09MQI`1T>d40A`8407`32P2A0@T0T@46
09D11P2E0@D0U`4609T12@2K0@d0V`8=08d22@1o0P@0P@8507/11@1f0@@0M@<406d20P1W0P40IPh9
01K200Wooooo00<00?l00?n0003oP0007@3oP0050:0Pl0040>QX?03oP000oh000>QX?0D0X23`00@0
d51h0?n0003oP000oh001P2P8?000`3@D7P0oh000?n000070?n000030=1@N02h>;@0j6Pl0180oh00
00<0D91hooooooooool01_ooool;003o001>02OH201dC2/0KeA106iC@P1`DTT0Ke9D06Y@D@1]C5<0
KDUB07YCG@24FfP0SFMc095/N@2FLG/0VWR00:60Q@2SQ8T0XHb@09^CWP0P<gT01RJ804mZW@2QZZd0
[kFi0;W2c02BXJX0cmoT08>DW`2[_LL0X;C10;33g021Xm40KYS<03Mc^@2FaNH0[=S[0:_Aj@3Oj>l0
i^c_0>[_l`3Tk?<0gn_a0=_WkP3KiNd0e^?[0=OSjP3Eh^X0e>;Z0=CQj@3AgnP0cmk[096ih`2Mc?<0
S;3B09k3g@2N]LP0[;g=0;?3d038en@0]<?C0;c@gP2a`ld0Y[>o0:6b_02N[;P0TZ:[08:CV`1dQh`0
L8B806b0Q01/PH80JGj206EkO`1GL7@0Fg=g06=kNP1XN7P08YdH2?ooool;003o0003052@N02P8?00
X23`04X0X23`00<0D91hooooooooool02Oooool000[ooooo05P00?l006PL0`1f1@80I`0105X10@1D
0@00EP4006<10P1Y0@80L`8408811`2<0P`0RP4908P12`2C0@d0W08>09l13P2H0PX0SP4908/11@2;
0@L0T`4909P01`2Z10h0/0<>0;@43P2i1@/0]08:0;412`2b10h0/@H?080:4`0T51/0_lC80=gQh`3J
h>00g^7T0<:2R02n6b@0cQ8L09@@6@21NH80gnGW0>7Tj03QhnH0h>?S0=Fi^`2c7B@0`A0I06l94P1b
J6h0f]oR0=SKg`3Hg=l0eM[L0=WIf`2PJG80W`LD0:@22`2R0@X0WP8:09l2302L00T0VP4909X1302C
2aH0Xd1<09HhA@241@h0T@4909811`2B00L0T`0609H1202I0@T0V04;09/1302J0@`0R@4607<00P1g
0@<0P@8807h1201[0@<0I@4106@1001V3PT05l812Oooool00`00o`00oh000?n0000M0?n000D0X23`
00@0d51h0?n0003oP000oh001P2P8?030?n000H0X23`00<0d51h0?n0003oP000703oP0000`1@T7So
ooooooooo`06ooooo``00?l004d0MddU06mC@@1`DD80Le=:06iAD@1^DU@0JdmF06e?F@1eDUd0P5MU
08eTLP2DKWX0UW=n09enQP2SQ8X0XhF<09n:T02ASJ802R=i008SP`1LMIl0[kJj0;Bj`02_]kl0^LK?
0:Nh`@2T/[/0c=[Q0;G6eP2O]m00EgNQ0=;Wn@3Fm?h0S/g/09KCk`3<j?P0lOKk0?WkoP3]loP0hncd
0=oYl03Jinh0enC[0=OTk03Gi>/0en;/0=CPjP3Bh^T0d=oX0<oPj`2Ta^P0>GNj09Fmg02S`]T0^LgM
0;_=g@2/_/l0[/3A0:6c``2Z_l/0/<G>0:Nf`@2V]Kh0WJfg08VKY025V9d0MX^?0725R01cR8/0MHV:
07J7R`1ZOX80H7Mi05eeMP1SNGT0IGMh02VI8`08ooooo``00?l07`2P8?000`2h>;@0X23`0:0Pl002
0:0Pl0030>QX?03oP000d51h02D0X23`00<0N5Rdooooooooool02Oooool000[ooooo00`00?l0074Q
1@1m1`40JP4105`10@1J0@80GP4106P20P1X0@<0K`450841202<0P`208/12`0D09D13@2O0a00X08@
09T22`2@0@P0S@4708h1202C0PX0U@490:<4302b1@h0]P@?0;P4302d10`0/P<<0;<53`2a10l0T`TD
02X22@2IWJ@20=gQhP0d0=gQh`3G];L0[2L_0<dE702c5A/0HdI>0=SMh03Lh^<0hN?W0=kPh`3QdmH0
[c4k0<LB602F4Q/0E3U00=OMh03JgN00f=_N0=OKgP3Hfml0[i2G09P=6@2U1@l0X@@=09l2302N0P/0
W@4:09/12`2H0@/0V08=09433`2A1A40U08;09<12P2D0@T0U08909<11`2@0PL0V04909X22@2H0@X0
V@4;09022P1n0@@0OP<607X21P1l0`P0J`8406420P1W0P80HPT4026T0@Wooooo00<00?l00?n0003o
P0007@3oP0000`3@D7P0X23`0:0Pl0020:0Pl0050;Ph]03oP000oh000?n0002h>;@01@2P8?030?n0
00030;Ph]02P8?00X23`00<0X23`00<0^3Rd0?n0003oP000703oP0000`1XZ3coooooooooo`06oooo
o``00?l004d0LeXN071@?P1eDTL0M59<06a>C`1]CU80JdeD06U;EP1]D5`0P5UW08eSL02DLGX0UgZ3
09]nQ`2OPX/0XX>:0:::S`1/L9@0126200HXP`21UkX0XZV]0<_Be@2f^l<0/K[20;o7cP3Fg><0en;X
0<_Jj@3Hio00iOKm08K1i02Vg_P0/>7e0<oan`3Nk_H0i^kd0>_`m03/loH0i^ke0>;/l`3Iinl0eNG/
0=CSj`3Fhn/0e^;[0=CRj`3Bh>T0d=oY0=?Rj`2ldNL0PJcL09k7jP1ZTKP0ZL3G0:Fib02daM<0`mCQ
0;33d02]_/X0UjRc09JU[@2HYJd0UZ:/08FFWP1fRI00MX^A06j5R@1fSHl0N8b@07N;S`1cQh/0FW1d
05mdM@1UN7X0HGAd03]l=@08ooooo``00?l07@2P8?000`3@D7P0j6Pl0:0Pl0020:0Pl0060;Ph]02P
8?00X23`0;Ph]03@D7P0^3Rd9@2P8?0;ooooo`002_ooool0F000o`00M1h308060P1[0@40G`4105`1
0@1N0P80J08306@10@1^0@@0P@8808P12P2=0@`0T@8=09L12`2O0P/0W08<09<12P2?0@X0SP8:08l1
202C0@T0UP8;09T22`2]10d0]@@>0;D3302d10d0/P@=0;46302]0`d0XPLB05L63@1OFf80fn3S0=_O
h@3Nh^D0hmWL0;QYK`356b80baHL05hE7P2l`<L0gNCU0=oSi03Phn@0i>;U0;YWK`3751/0]a4J058D
6`37c=40fmoQ0=[Mh03Hfml0fMgO0<Jj_`2>72T0X`DA0:<43`2R0@l0W`4;09`12@2I0PX0VP4:09T2
2P2D00L0U@4:09@12`2D0@P0U@4709<11P2A0PL0Q@4509<22@2G0@L0U`4809P12`2C0PP0PP4507P1
1P1U0`H0F04106P41@1S0P<0J04206D:1@0^QP89ooooo`03003o003oP000oh0001h0oh001@2P8?03
0?n000030>QX?02P8?00X23`00<0X23`00@0j6Pl0?n0003oP000d51h1P2P8?0N0?n0000308300?oo
oooooooo00Kooooo3000o`00C@1LNQD0L4df07ICA01eE4d0Jdi=06U<CP1XBe80H4A?06I;F021GF/0
RVA_095_MP2GMh<0UWZ608M`O02GO8D0XX^E04QDQP048XT022j408VJ]P3Bd]H0_[c40<_<dP3HfMh0
g=kU0=kTkP3Sjo<0jo7i0<;Ij`2deO00/]g`0=3fo`3;l?d0QlWV0<3Um`3WlOP0k?7h0>G]m03Mj>l0
fNK^0=OVk@3Ehn/0dN7Z0=3Qj@3@h>P0d=oY0=3Nj03?g^L0d^7Y0<;ChP1RQ[L0F8Bh0:S3g@2`bMl0
/LCD0:bnc02IZ[L0Zkc80:^maP2T]l40XK6j09FTZ@2<W:<0PiNN07f@U`1WOX40IWn107Z?TP1cRhh0
KXN806j6Q`1_QXP0JGam06=eM@1PMG<0CV5600Sooooo3000o`0K0:0Pl0<0^3Rd00@0X23`0;Ph]02P
8?00^3Rd0P2P8?000`2h>;@0d51h0;Ph]00V0:0Pl0_ooooo000:ooooo`1H003o001i80<0Q0L206l1
0@1U0P<0G04205h10P1Y0P@0I`4106`00P220@T0RP0<08l23@2@0P/0UP4;0:043@2J0P`0T@490941
2P2@00T0T@4709L12@2L0`d0V@8=0:422@2b1@h0/P<:0;422`2_10`0[@@;0:/32`2T10`0Pa0H04Da
>P3>dmT0fn7Q0=oRi03Ogml0gK:f0;/V;P3C5Q/0PQ0G079WL@3Oi>D0h>CV0>7UiP3Qi>D0biFL0<HK
9P384Q`0JPXB0:V_]03Kh><0fMgP0=OKgP3Ig^00d/kB094d@02U1A80Y@<?0:<33P2M0@X0V`0:09T1
2P2E0@X0U@0809D01`2D0@X0T`0709@01P2A00H0T@4509411P2@0@L0TP4809<01`2C0@H0U`4809D1
1`2<0PH0M@4307@31`1O0040H04206/10`1[0P80I`d803291@Wooooo00<00?l00?n0003oP0007P3o
P0060:0Pl0<0oh001@2P8?00103@D7P0oh000?n0003oP0060:0Pl1h0oh0000<0P<00ooooooooool0
1_ooool<003o000_06B05`1^C3D0LUA3079FC01ZCdh0IdY=06M;D@1XCEH0Ke9K089QK027Hg40Sfih
09AcOP2DMh<0MV5]08E_N@2STIl0;T67008WU00=>8/0/;_C0=75b@3IeMT0g=cR0=CHgP3LgnT0g^?[
0>C[l`3Li^l0f>Kc0>Kio`2_eo@0?Hg;06F`g`37k_T0]mO/0=OTk@3Fhn`0e^?[0=CRj03BhnP0eNC[
0=?Rj@3AhNP0cn7X0<kPj03>h>L00P3?gnP0703?gnT0d^3/0;G>i01/V<h0TKOO06bB]@2/`M@0]l[G
0;o@g@2jcM/0Y;G10:2a_P2P/KX0TZF/08JEWP1lSYD0MHV@06InPP1QN7`0L8B907>:SP1/PhL0L8N:
07B7S@1_PhD0IGYh065hM`1CFTl8ooooo``00?l0702P8?000`2h>;@0X23`0=1@N00^0:0Pl0_ooooo
000:ooooo`0B003o001i8`@0QPT207D10@1V0@40G`4106@10`1/0@D0K@8407811P240P/0RP4=08`2
3@2>0@`0U08<09X33@2E0@/0TP0:0P2C0@/0A02D0P/0V08<09d23@2M0`h0X08;0:`43P2b10d0/0<<
0:h63P2W0`X0YP880:P42`2G31@0>a8J0;_2bP3Nh^@0gn;S0=oRhP3XeMP0a4eF0=dK7@2c6R40AAlX
0=OHf`3RiNH0i>GW0>;Ui`3M_l@0_b@^0=@D6P2D4AT0SXR?0=cSi@3LhN<0fMkP0=SMh03Jf]h0WEQR
0:P95P2X0`l0Y@<>09l12P2L0@/0V`4909L12P2J0@`0V04:09D02`2B0@T0TP4709811P2B0@L0T045
0941202=0`P0S`8909H22P2F0@T0T`8808P2101l0PD0P@<707D10P1Y0P<0J`8406d20P1U1P@0<XP5
2Oooool00`00o`00oh000?n0000N0?n000030=1@N02P8?00X23`00<0X23`0`3oP0000`3@D7P0X23`
0:0Pl0020:0Pl0040;Ph]03oP000oh000?n000H0X23`00<0d51h0?n0003oP0006`3oP0000`20`03o
ooooooooo`06ooooo``00?l002D0?jH;079>=@1dET@0MEM;06a@BP1XCTl0Lf1R0:JFVP1jGVL0Q6=]
08UUL@2AKgP0UGEo09IgPP2BLGX0YX:<0:^KZ00T?Hd00c2T00DaS@2U]M80dlkF0=OHgP3FfMl0h>CX
0>?WkP3Pj>l0f^C^0=gVl03Mj_P0M9g=08k1jP2AaNh0MZgP07Z`h02G_]/0eN?[00<0e>;Z0P3Ch^X0
8`3?h>/0c>;]0<WSkP37h^h0a^;a0<GQl`2og_@0^=_f0;;Hm`22]^L06V32076]j@29^^P0U/?_07^V
eP1nY]L0P:OD08b_e02Q_n00SJc808FP]P29X;80QIfX07RAV@1XOh@0KHF606R2PP1cRXd0KhB:0766
S01dRHd0MX^=06^0O`1RMgL0EUeD00Sooooo3000o`000`1@T7P0X23`0:0Pl00J0:0Pl0030;Ph]02P
8?00X23`02d0X23`2oooool000[ooooo05P00?l007lV1`2:20@0O08306/10P1T0@<0H@4206P2101^
0PD0L04507/120210@`0P`4908`1302C0P`0TP4<08l22`2A0@T0TP0:09822@2A0PT0UP8<09X2302K
0P`0X@8=0:H1302_0`d0/0@=0:`53@2X0PT0Z0480;043P2^2AD0H0LB09:DW`3Oi>L0h>GU0>;ViP3X
i>@0hZ:U0>0m?`3OAdd0R3M10<_2aP3VjNT0i^W[0>OYj`3^i>L0fV1W0>hW:`3<82<0PEiU0=oUj03N
i>L0g>3S0=_OhP3Jg^40_9>J0:/@702f1A40/0@A0:T23P2S0@d0W`4;09`12P2K00X0VP4:09T22`2F
0PX0U@0909<1202B0@L0T@470941202:0PL0S04909/2302I0@X0T04608@21P1f0@@0PP8607@10`1Z
0`@0JP4206d10@1V1080<hP52Oooool00`00o`00oh000?n0000N0?n000030>QX?02P8?00X23`00<0
X23`103oP0001@2h>;@0X23`0:0Pl02P8?00d51h00<0oh0000<0d51h0:0Pl02P8?000`2P8?000`3@
D7P0oh000?n0000K0?n0000308300?oooooooooo00Kooooo3000o`00C@0c_PT0ME4d07AEA`1dE4T0
LE9;06U@C`1hJVh0/jZd07UOK022H6d0RVMc09=`N`2GN8@0XH6<0:N0S02aS9P0[::b01TfRP02<:X0
1SVO09VaeP3Dd]X0d]GJ0=WMi@3EfN@0e=cV0<_Hi038e=l0c]gZ08fW``2/anD0EXBk07R]g@1DSLP0
L:cQ0<SSm03Ei>d0f^K]0=gXk`3Gjo80`NOh09kIn020c_P0IKkg04bXl@17W^l0>XcY031hhP0[J]P0
9E[;02ADb00VC<<0:4:n02/o/@0^?Jh0;cb/02/eY00Y<j009C:O028`V`0P<IL06S6A01`gT`0Q@9L0
:T^J035CTP0jFHP0Bfb;06F5U`1dSYP0LHR@07>:SP1[PXH0L8N:07J;SP1]PhD0GF9N00Sooooo3000
o`000`1@T7P0X23`0:0Pl01:0:0Pl0_ooooo000:ooooo`0C003o0024:0H0S@P207d20P1/0@80H`82
05h10@1U0P@0J04206`11@1j0PX0O@4;07d020270@X0S`8<08h13@2<0@/0S@8;09012P0209022P13
09@12P2I0P/0W@8<0:@23P2R00/0Y`@<0;873P2h20h0_0T?0<<:4P383AD0ba<I0;8M9P2=KWT0jng`
0>KZk03Xj^`0kNg_0?C^kP3li^H0oo7b0?ofm`3oo?d0moSi0?Gfm`3cm?H0lo;d0?J/[`3jCTT0mD8k
08i1B`3]k_<0hnOX0>;Ui`3PhnH0gn;V0=o6c@2g82h0b`/H0<D7502l1Q00/`<=0:/23@2T0@/0WP4:
09/1202M0P`0V`4;09X12P2I0@P0UP4;09812@2A0@L0U04909X2302M0Pl0V`4;09H11`2@0PT0Q046
08021@1`0@<0I`8307420P1/0@40H0<103]o2P09ooooo`03003o003oP000oh0001l0oh0000H0^3Rd
0=1@N02P8?00X23`0=1@N03XJ3`;0?n00080d51h1@2P8?0M0?n000030:R8??oooooooooo00Kooooo
3000o`00C@0Te@L0ME0^07=GA@1fETP0LU=:06Y@CP1VCU40M5QQ07YJI`26HFh0SFQf09YgQ02RPH`0
[8^F0;2?V@2eXZT0_;S90210U003<J`01cZY07VEa@39bmD0al[D0<K;e@3;dM`0a/gI0;:ob03=fN<0
Z[W60:FldP2N_ML0N9g508fhf02fi?`0BK3W06K9m`2=fOX0[NKk09;Fm@1I^o409ZKa00bGlP05T?H0
1HKg03Y[h027CK<0X4>K0:hhQ@2j;Fl0_R=P0;/IEP2l5d`0^AU50;@H@P2b5T00[Qi80:PB>P2Q5C`0
W@`g0:09=02G3ST0SAA708DEC`1g5e<0I1EN058GH`0k56@09aQ[01<OKP0O>g`0<E2504UZSP1SOXh0
IGb106ImO`1jSiD0I7AU00Sooooo3000o`000`1@T7P0X23`0:0Pl00Z0:0Pl080d51h00<0j6Pl0?n0
003oP0003P3oP0030=1@N0030;Ph]02P8?00X23`00L0X23`2oooool000[ooooo05P00?l008@V1`2=
20<0N@4206X10@1T0@40H@4206010@1T0@40K`4207P1201i00T0O@4:08D12P2<0@`0S@8>08T12P29
0@T0R@0808h22P2?0@T0VP4;09l1302U0Pd0Z`8<0:d33@2/0P/0_0P@0<h@5P3N5aX0iAXN0>/Q903c
:Rh0l3Hl0;MHJ`3nmoh0knob0>o`l`3al_H0loCf0?Ggm`3ko?`0nogl0?cmo@3jn_/0m_Og0?CdmP3e
m?D0mZF[0?YAB`3h@CT0XC]50?C`mP3SinP0i>KY0>;Ti`3Qi>L0k=_S0<0e@P3A3aX0d@`I0<T74`35
1a80^P@>0;02302V0@X0W`070:812P2R0`d0X08=09d12`2I0@X0T`080941202G0@X0V`4;09`13@2J
0@/0V04809<120220PH0LP8506l20P1W0@<0K04206`10@1O0P40C54<2Oooool00`00o`00oh000?n0
000R0?n000030=1@N03oP000oh0000d0oh00102P8?000`3@D7P0oh000?n0000K0?n000030=1@N?oo
oooooooo00Kooooo3000o`00C@0:mP80N4hX07MF@`1hEdT0M5I?06aBC`1ZD5<0L59H07]II02:HVl0
VG=o09imR@2UQY<0ZHnK0;:KZ037/;`0_JZm02/oS`0299X01BZJ06f;_`2f^<<0`/C;0;g2b030aLl0
_/G<0<G=e`2caM@0YLON0:SEm@2Ab^d0L;_a04b_m@0VTnd059Cb00b?kP0AX^h0<:cY05Nlk01VaO80
B<?h02:bn@0<W?X048_i08E@]P3Y8dd0kAT_0>LD9@3J3ad0eP`L0</66P361QP0bdQC0>NX/02VAeX0
ei^Z0;UYN`3/_<H0Y2i60:X4502jDE/0dZVe0<^N[031RYX0YTML09L5702A2Ql0Q18^074<=@1J44L0
@a5D02LEGP0D8fD0<4ib05YgO`1YOH80CHY800Sooooo3000o`000`0Xb3`0X23`0:0Pl00Y0:0Pl003
0=1@N03oP000oh0000P0oh0000<0j6Pl0?n0003@D7P00`3oP0030=1@N0030>QX?03oP000oh000080
oh0000<0j6Pl0=1@N02h>;@01@2P8?0;ooooo`002_ooool0F000o`00S2T;08`80P1d0P40I`4106<1
0@1U0@<0IP4306/10`1c0@D0N`8:07P12@1h0@X0Q`4=08`23P280@X0R`8908d12@2@0@/0U@8;09T2
2@2V0PP0[`@90;X73@342@l0b0/A0<P:4P3@3QL0fa8J0>`N8`3f8bD0oBX]0?d/<P3m=S`0iCY<0=a_
R`3gd^00n?;h0?Wbn@3glOH0no;g0?cfn@3knOX0o?_m0?cgn@3llo<0oNk_0?[@e03cKFl0nTTo0?]0
=`2Q:S80cLO@0>7WjP3PhnL0gn;T0=kRi03Rf=l0^Sm>0<hA7P3=3QL0bPdE0<D:4P2o2180^@LB0;03
3`2Z0Pd0Y`4=0:P23@2Y0`h0YP8>09l2302J0@/0UP4:09L12`2N0Pd0X08=09l23@2L0P/0UP4808@2
1`1T0@<0KP@506P20`1`0@80K04205/10016BP@9ooooo`03003o003oP000oh000340oh001P2P8?0M
0?n000030=1@N?oooooooooo00Kooooo3@00o`00C01kDRH0MUI207UJBP1jFeD0LeID07AHF`1lGV@0
OemW08]XM@2EMWl0VX>=0:29UP2WSY`0/96Q0<:HZ@37WK80:Rij008HP@037X<0CVBG0<34bP2m_lL0
^/?=0<?Di@2/a^L0MjOQ04fCiP0ILN802V_Y00UVi`04P?L00XWk00FBo00<X_`0:K_k02ninP1=]O<0
Gjc]03n:h`0WLn40<F3H04ACbP1H@kH0W2Mj0=@@<`3G31`0c@PE0<H55@371QD0aPHD0<@550306bh0
hjZg0:IfR`3I]lP0^H^P0=BcaP2H6S/0Z08D0:Y;F`2]TjL0SEQg08iTO`2gTJ@0R`PP0:55C`2URi40
ZXJ>09eIJP202R@0P`HR068;=P0I4U4052mQ04mYMP0cXbl8ooooo`d00?l0:@2P8?000`2h>;@0d51h
0>QX?0080?n000050>QX?02h>;@0d51h0>QX?02P8?000`3oP0001`2P8?00^3Rd0;Ph]02h>;@0oh00
0>QX?02P8?000P3@D7P20?n000050>QX?02h>;@0X23`0:0Pl01hF;@02oooool000[ooooo05P00?l0
080T1P271`40LP4106P10@1Y0@80IP4206D10P1/0P@0M04707h12`1f0@D0M`4708X1302>0@`0R`08
09812@2L0Ph0X04>0:T33@2b10d0_@H>0<H93@3@3A00fA8@0=D=3`3;1Ph0b`LA0<l:4`3G3AH0l1/P
0?/V:03m;2d0oS8_0?df>03j>T00le9Q0?AcQ`3fMhX0m7N50?J1RP3iV:D0nKK80?o3f03iZ[P0mhV@
0?YnOP3lJVH0oUA<0?m7@@3n?S/0^2Tc0:jFXP3UjNh0gnCW0=kRi@3Jgn80hMkS0;MDH`364b40b0lI
0<H>5`3021D0^PDC0;H44@2b10h0Z`4:0:T1302/0@l0[P<>0:X13@2T0@X0X04<0901202E0PP0X@4=
0:H23`2Y1A40YPL@09X22P2:0@H0M`8506d2101_0PD0N08306h10P1R0@00BTX42Oooool00`00o`00
oh000?n0000a0?n000H0X23`7@3oP0000`3@D7Soooooooooo`06ooooo`d00?l004`0JWTR07=F?@1k
G4`0OEiD07aMF`1nHF@0P6EX089WK@29KgX0Tgj909R6T02KQi<0YHbJ0:V=V`2_SY`0]9>V024TK@01
5G`00Q^0055VW`2T[l@0Sj[E066CfP0VJ<h025?=00=Ef`03G>P00fSf00Icn`08OO/01ggh00Mim@0;
Mo405W?Y01U?a@0kBkl0JTJe08LlXP2G=Y<0WS6:09/`QP2<<XL0NCbD07diS`2l8Ed0haHZ0>@D6`3N
3aX0g@dG0=d>6@3I2aL0e0hN0=ATM@3:ZkP0gl7@0<2EZP3=WK@0Y1<a0;<44`2/<D40ajNf0<2]_@33
^<H0_9jb094:9@2F<3d0^k_00:bf_`2WUZ@0LAL]08L34P250a80>@do00<CE`0E;5409j/Z2?ooool=
003o02<0X23`00@0^3Rd0=1@N03@D7P0j6Pl0P3oP0000`3XJ3`0d51h0=1@N0090?n000040=1@N02P
8?00^3Rd0:0Pl0<0oh00102P8?020?n000<0X23`0`3oP000103@D7P0X23`0:0Pl01@T7P;ooooo`00
2_ooool0F000o`00Ob8408L80P1d0@80J@4106L10P1S0@80I@4206h11@1h0@H0Q08908<120250@T0
S`8;09L53`2D0@T0W@<<0:@2302Z0`h0/P@>0;@3302k0`X0`0@:0<P52@3D3Pd0e0d>0</73P391Pl0
cPTC0=8=5P3]6RD0o2P/0?/Z:`3n<2d0oS4`0?da;`3n=c/0nca50?e1BP3i?TD0n4A90?A6D`3^Bf40
kTeX0?58FP3d@DT0n4930?Ll>`3g<c@0m2X/0?<Y;@2_7RX0GT5C0=GIhP3Mh^@0g>7T0=[Nh@3Mg>40
Y59Q0;LA802m31P0`PhK0;T65@2d11@0/P@?0;433P2]0Pd0ZP8=0:X13P2/0@`0ZP4<0:D02P2Q0P`0
QP4408l12@2O0@/0Y@4?0:d85P2b51d0X0H=090220200PL0I`0106X10P1g0@80K@4206810@19BP@9
ooooo`03003o003oP000oh000340oh001P2P8?000`3@D7P0oh000?n0000J0?n000030=1@N?oooooo
oooo00Kooooo3@00o`00301ZQb@0PEi8089QCP26IEL0QVEP08IYJ@21J6T0Qg1d08YcO@2BNXP0Ug^<
09UlS@80Wh6@03h0/HnL0;RDZP0Q:WP00bBC00@ZW00D@JT05dfh00M9b003B<h015CN00EGhP04En@0
1eKU00Y?g@0JC=80=42k058fYP1U<IP0Mc6@08h_QP1]7W00IS650759VP1nJ:h0QXk206:Me`0]U>T0
5Hka0128m@0KM_00Od^d0=lQA`3Y5Qh0h10I0=X:603D2QH0dPPE0<l95`2o;440h<SC0=G0c`3BZKl0
/6F50:X<9`2c0Q00^3e;0=Nha@36]/@0a;[70;N0V02M1b40V2Tg0<k4c02[ZkL0[YRW07TJ=P2:0aH0
O@8<04D:<@094U@00aA401VL8@Sooooo3@00o`0N0:0Pl0<0d51h00<0oh000>QX?03@D7P00P3@D7P6
0:0Pl0030=1@N03oP000oh0000H0oh0000<0d51h0:0Pl03@D7P0103oP0030:0Pl0030=1@N03oP000
oh0000<0X23`0`3oP000103XJ3`0X23`0:0Pl01@T7P;ooooo`002_ooool0F000o`00QBL508@70@1e
0@40I@4106010@1S0@40JP4307D21@200@L0R04908P12P2=0PX0X@hH0;4I902U1a80Z@D>0:X32`2Z
0PX0/08:0;422@2h10T0_P@:0<H83@332P/0^PH80;T52`2h1@d0]`@>0;`74P3521D0gaLR0>DK8@3[
8BH0kRLY0>hY:@3[;Bd0iS0b0>He=P3V>CP0iCln0>I6A03SC4T0i59B0>AADP3WEeL0heID0=E:A`3M
D4l0eT]<0<M1A02K>D00CCQ40;_2a`3Kg^80fMkQ0=SKg`3Ifn00TEYU09dF8`2T3AL0Z0XE0:P64`2U
0Q40X`4>0:<23@2S0Ph0X`4<0:P2302Z0@d0Y`8>0:412`2P0P`0U08909H12P2R0PX0Y04;0:L24@2Z
2AL0X@PA08l4301l0`L0NP@707810`1i0P<0K04205l1001<C@L9ooooo`03003o003oP000oh000340
oh001P2P8?000`3@D7P0oh000?n0000J0?n000030=1@N?oooooooooo00Kooooo3@00o`00C01@Y1T0
Pf5908MUD`2>KEl0SW1Y08I^J`21J6/0OV=_08U_O@2:KWh0S6am08m/O02KO8T0Y8VG0:ZBY`24Ojd0
5CFE00<^Z002<:h00C>e00@m``05A<h01TWB00U4c00E>Kd0<C2[058WT`1`8gd0PB5_07XUL01K;gl0
CSjA03i@Z`0/K/l06hGX01RBk`0l[oH0I;[d05BWk`0IQ?0017Kd005^lP00INh01EWT03<m]P2e6U@0
f@XJ0=@8503F2AD0dPPC0=064`3;41`0_41<0>;:e02oX[D0biR_0:aELP2]4b/0/0@A0<AWL`30Z[P0
a[[80;fZ^`2dHWh0YPLM0:iBF`36_/L0_;c90<bncP249TL0TP@I08H2201S11H0=0li00/C?00BTQL8
ooooo`d00?l000<0N5Rd0:0Pl02P8?005P2P8?001@2h>;@0d51h0>QX?03oP000j6Pl0080d51h00<0
^3Rd0:0Pl02P8?002P2P8?080?n000030;Ph]02P8?00^3Rd00@0oh000`2P8?000`3XJ3`0oh000>QX
?0030:0Pl0@0oh0000<0^3Rd0:0Pl01@T7P02oooool000[ooooo05P00?l008<T1@201P80L`8106D1
0P1M0@40HP810701101l0@@0Q@4808P11`2900L0T`<=0:/;602X1a<0YP<>0:T33P2b1100/P<>0;@3
3@2h1@h0/@<:0;<53P2]0`X0X08709T0102H0@H0UP4609@11`2H0@/0WP8=0:<54P292A<0/5II0=bA
SP3ZYZ80kkJd0?7:b@3cd<l0m]OD0?CKf@3cgMX0lN7L0?7Rg`3bi><0l^GU0?7Sh`3/h=`0k>3O0>_O
h03Vfm/0gMKE0=GGe`3Fg=h0fmoS0=[Nh@3Hg>00f]gP0;Za/@2_Shl0[7mn0:MZK@2TDeT0TA8L09/2
302H0@X0U@4:09L1302M0P`0X08>09h13@2K0@/0VP4:09/12P2N0@X0Y@4;0:H13P2W0Q40W04>08X2
2@1h0PL0L`@807H4201b0`D0OP<507820P1R0040C3L22Oooool00`00o`00oh000?n0000N0?n00080
j6Pl0P3oP0000`3@D7P0oh000>QX?0070=1@N0030;Ph]03@D7P0d51h00T0X23`103@D7PH0?n00003
0=1@N?oooooooooo00Kooooo3@00o`00C019/1<0Qf56091ZE@2GMV80UWmb08iiMP20JVd0O6=/07QN
J@1oHVl0QVId08m^O02<NY40HfVI02I3U`07;id013Bb00@g^`05>/000bnc00Xb[`0L;:<0B2ZD06`J
M02266<0MQUR05LSM00g=Y<07U:l015Vg@0=M_4037of00Z3n@07O_L00W;f009ZlP01J?400VSa00=]
l@03K_4017;a00AjlP03OoD017of021ai@2Z?8X0lAdY0?<L803b6Ah0jQ<K0>TC7`3L<C`0mkk<0>70
e@3R_]H0hKgC0?2hdP2i;d`0_0HH0<=9H03L`m@0b;g>0=35eP2aG7X0X`TN0;]kPP2n_<H0^[S60<6I
]02J63d0Y@HH09D22P1D1R4060Ta024G;P08ePL8ooooo`d00?l000<0D91h0:0Pl02P8?004`2P8?00
1P3@D7P0j6Pl0?n0003XJ3`0d51h0;Ph]140X23`00<0j6Pl0?n0003oP000103oP000103XJ3`0d51h
0=1@N03@D7P40?n000060;Ph]02P8?00X23`0>QX?03oP000d51h0P2P8?001@2h>;@0oh000?n0003o
P000j6Pl0080X23`00<0:<Plooooooooool02Oooool000[ooooo05P00?l0084V1P1k1@40L`420681
0P1C0000G@4207<1101o00@0Q`4708X11@2=00P0V@<>0:P5402T0`h0XP8>0:/44@2_1100/0<=0;45
3P2[1@`0WP890:44302K0@P0TP480980202>0@D0R@4308T01P2B0@`0V`8>09d85P1O1A@0RGj90>SZ
jP3Yj^X0jng^0>WZk03Zjnd0k^oa0?CdmP3`l?80kNo_0>k^l03`k_40l_7b0?7bl`3/k>d0j^[]0>_[
k`3WjN`0i>SY0>7UiP3Oi>L0fn7T0=_OhP3LhN@0gMoR0=[MgP3HgMd0e]_K0=CGe`3?a/P0Rc8m09l2
3@2I0@/0T`4709D02@2I0P/0VP0909L02P2I0@X0UP0909H12@2L0@X0Y`8>0:l55@2]1aD0V`4:08d1
201f0@@0N@<606d3201@0000M`8607D10P1U0@00GPX32Oooool00`00o`00oh000?n0000N0?n000H0
X23`00<0d51h0?n0003oP000103oP0000`3@D7P0X23`0:0Pl00>0:0Pl0030=1@N03oP000oh0001H0
oh002?ooool=003o001<02CG202:Hd00UGAJ09f3K`2WUHX0SGUg081WJ@1eG640M5UT07iUK`1nJgd0
EE9o01T^O004:9@00RVR008YY005:j/03BVS01hPSP0i5GD0Ha9N07XBE01_6V40D2n902@fWP0@A;X0
2ECB00QNh`04GN@00ekW005Ij000F^H00F;[005Ul@02LOD017ce016;l`0lYo00J<3d07cAn01ZeOT0
@L[g01nio00?Z?h04I7j07UM_@3Y9440k1PU0><B8`3K42D0eA4V0<T@;@327TT0^1Y>0;8GB`2]64T0
ZaA40:/<<02/1R40Z0XX0:<WD@2X?VX0[d9/0:8;;02P11H0`6j20;jM]03>_Ll0/6F30:L=:02]1a80
VP@?04H=>`054e806APe003o00Sooooo3@00o`000`1@T7P0X23`0:0Pl00@0:0Pl0050=1@N03XJ3`0
oh000>QX?03@D7P05@2P8?000`3@D7P0oh000?n0000A0?n000040>QX?02h>;@0X23`0>QX?0<0oh00
00@0d51h0:0Pl02P8?000?l02oooool000[ooooo02/00?l007dU1P1i1040L`4106L20`1G0040H`42
07T110220@H0R@4708h11`2E0PP0V@<;0:H84@2_4QP0/1TP0:L;5P2T0a00XP<=09`22P2F0PX0R`07
09@11`2E0@H0U`4909H02@2F0@T0UP4609T12@2T10h0[PDA0;L<5`2M5RD0R6Ee0>k_l`3]ko80mOGh
0?ShnP3in?X0n_Wk0?kmo`3ooOl0o_co0080o__o0P3mnOd0:@3kmO/0n_Ck0?WbnP3ilo/0mNkg0??Z
l`3_iO40iMk[0>?Ok@3Kf^H0em[T0=OKhP3Gf^80emcQ0=CJg`3Dd]P0VdYI0:X44P2T0Pd0W00:09h1
302O0Pd0W@4<09/13@2H0@/0U@0809H12P2K0@`0Y`HC0;PF8P2i6280X0D?09032`1h0@D0M@<706d3
1@1U0`D0O0<707X10P1Y0@40HP/300Wooooo00<00?l00?n0003oP0007P3oP0020;Ph]0030=1@N03X
J3`0oh0000d0oh000`3@D7P90:0Pl0030=1@N03oP000oh0001H0oh002?ooool=003o001<00_f0`2=
I3H0VgmT0::>O`2]XYd0UHB307eTI01lHfD0NF=_05UDL`0L:6T00aUf008QS0028YL01B2E01TKR01:
5W<0MQ5F07T:@@1U3dX0>aMW01`XS00<<j/024C:00A<f002Am800DSC009:f001Dn000V3[005Zl@03
MoP01HGj00JHo@0<Z?h09[_j05O@n`1^boH0Gkcd03jZlP0CT_<01XWg00>2o002MOT00fcf01YMhP1X
?Il0NC:106XbQ01K<8`0D3BG04DdV`0o=Il0>3:R038_W@0^;YP0;BVB02hVR`0_8840<Qag03LGK013
5VT0DAIQ05dAD@1[3Cl0N@`i08@?>@2N<5H0YB0o0:/87@2[1A00T0HH030CD00466P03aY4003o00So
oooo3@00o`000`0Xb3`0X23`0:0Pl00=0:0Pl0050=1@N03oP000oh000>QX?03@D7P06@2P8?070=1@
N0030;Ph]02P8?00X23`0080X23`1P3@D7P00`3XJ3`0oh000?n000050?n000040=1@N02P8?00X23`
003o00_ooooo000:ooooo`09003o001k8@D0N0<107T20P1i0P<0L04107D110200@D0Q@450080S088
00P0S`4908l22@2I1140W`XG0:@D8@2J21H0U@8<09@22`80SP4903@0U@480:02202Z0`T0]`T=0<0?
402l20d0^`H@0;`53`2o2180``XE0<T>6P365B40YBe70=fI^`3OV[d0jYo10?2U`P3aYKl0lZJk0?6Y
]@3^[[T0k;C20>Z``P3XXK00ji:O0>b4T03^N8L0kVf20>mYO`3]IWX0k5]d0>iMM`3XEG40ge=c0=A@
M@3=EgT0bF:10<E[RP2mKHX0_GNB0;n6X`36TZh0/dML0;@54P2_0`d0Z@4:0:T22`2W0Pd0Y08=0:42
3@2M0@/0V`4:0P2J0@/03@2R1140Z`/I0:/?6`2H0`h0OP0707L42P1i0PP0M`8507D210270PD0P042
07410@1W2@802Oooool00`00o`00oh000?n0000g0?n000D0d51h6@3oP008ooooo`h00?l004/0TVPc
09IlH@2MS8<0_;Jg08ajN`25KV`0Ofia05EDL`064eX00QEc008JP0026hL02AN502dAK`1b3U40S0e1
05`9B@0U35d041Yo00D/X004;:/01CFh00E4cP02A=40047<009@f`01GNX0173f00=mo007S?l01iCo
00RJo`04V?d00Y;k00B?n@04ROT018Gi00=ln`01Mo/00GGk009_nP01J_H00FCb005Jj002FND02ECH
00U=cP07BL`01DG900=1a@05A/T01D?600A1aP03?l400SZk008e]@02<:d00bfT008YW@039YP01BJJ
00HTU@098i003Qf201LIM@0/4f80D`i;088><`2L2b<0X@HF08<87P0O55L00amb00/MCP00o`002?oo
ool>003o00h0X23`0`3oP00a0:0Pl0D0oh000`2P8?000`00o`3oooooooooo`09ooooo`002_ooool0
F000o`00Mb4307L40@210@40S04308L10@200@80Q08608L11@280PL0Q`4708<2201m0@H0OP4;08<3
402P4Ql0XPhK09T4402G0@X0VP490:P33@2a0`h0^0H?0;/63P2l1`T0aa0>0;h52@2g0PT0]`8=0;H2
302m1100aP/F0<T;5P3D5B@0g1lc0>4T>@3Y;dH0mdQJ0?]EG@3kHF40oGQ_0?Z<R@3gWJL0mZ6c0?NE
X@3gNWT0nfEN0?a@BP3lA4<0o40m0?Xk>@3g<340mb`]0?<S9`3/7RD0iAPQ0=lF8P3G5RH0d18T0<X?
8@323Qh0^@dS0;<<902d1aX0]`@@0:h1302[0@/0ZP4:0:X12`2X0P/0Z08=0:H12P2R0@X0WP4:09d1
302P0Q00Y`PE0:/?7@2L1A40PP490642101T0PD0KP8607X21@290P@0P`4207L10@1]2`<9ooooo`03
003o003oP000oh0005D0oh002?ooool>003o000O06JF8P2CLeT0UH9j0:fTXP2?P7`0S86205UMO@0;
7FH00AE^008FM`0457D04`eP04<:C01a34<0FPe>02lFKP0?6X<01b:C00<RVP029J0012n`008l``04
DM/00U7L00=Ji@05K_L017;l00EkoP04O_d00gSl005en`02009gn`0Z009io001M_X00G?j009_nP02
I_H00VCc009Ul@02Hn`00V;Y00AMh005FMX01U[D00UFbP0<Dl<04U2k01I@/`0LDZl08UF[02QFY@0]
FZD0;E^T02]HWP0ZE9T0:52B02M<SP0UB8/084>701PnQ`0B>8P03C2600HVPP048h@01R2200`MO@0O
7740>AEN05dCB@1R3SP04Q=K00<SM`0@8U@00?l02?ooool>003o00`0X23`00@0j6Pl0?n0003XJ3`0
^3Rd=02P8?000`3@D7P0j6Pl0?n000030:0Pl003003o0?oooooooooo00Wooooo000:ooooo`1H003o
001h:0L0N@@008X20`2D0P80V043090110250PD0PP85084220210PL0O04607/01P1k0PT0NP<=0:<M
:P2S3a/0W0<@09l33`2R0P/0[@8;0:h02@2_0@T0/`4;0;`72P3>61@0bA<E0;d84P2l21@0^@HA0;H4
402j1a80_PLA0<L;5P352QH0a0dK0;h:6@395B40g28^0>TZ=@3e=ch0n3i20?Q0AP3h?TT0mCLn0?Xj
>`3j=c@0nbd^0?d/:`3i:2X0kb0S0>TN7`3S6Qd0gAHM0=8@6@3?3aP0a`dG0;d:5`2l21@0^PLC0;@3
402a0Q40[@4<0:h2302`10l0Z08<0:H1302W0P/0Z@<?0:P1302V0@/0Y@4:0:422P2O0PT0WP490:01
3@2R0A40X@<C09X2402?00/0P0@:06D20`1S0@<0L`8408H20`220@80N04106l>0PWooooo00<00?l0
0?n0003oP000E@3oP008ooooo`h00?l004/0:=X=08i[A`2?MFT0Y9VD09:DX@0e@g802ai]00@MP004
5gT03PaM03P:@`1@1bd0>PPg01TAI@098i800bJO004RV`0189T00R>O004YY`02>;T014kF00ENj@04
HNh016Kc009Xm`02Ho<00V;c009Um@02H_800Eo`005OkP02HNd00V?^009Sk@04I^/01FCW00UPg@0B
HM<07FO<02i_``0mMKT0C7Za05R0Z`1UQ:L0LX^T07N>XP1kSId0P9BN08>FX@20U9`0QYBI08RFW@24
U9/0QYNM08:CU`1gR8d0MhV?07^;T@1aPXL0Jh:706b4R01]PX/0HGN8051WO`12FG`0:TIi01DdN00:
;7/02RZ300hWPP049X@00b^401XXD`00o`002?ooool>003o0003052@N02P8?00X23`00L0X23`00@0
d51h0?n0003@D7P0^3Rd?02P8?000`00o`3oooooooooo`09ooooo`002_ooool0F000o`00NRX;07l5
0@2@0@80U`8209d41P2I10L0P@8307H00`1j0P@0O@4507h11`260PX0SP@>09074P2=2180T0@>09<1
2P2J0@X0YP8:0;432@2c10/0^PTA0;443@2/10/0Z0@80:<32@2M0@T0V`8:09X12@2L0@`0W`4>0:@1
3P2[1140/@LE0;<85P2d21H0^`dI0<XE903P82`0m2le0?]3?P3iB440n4I00?Q5?@3h@cX0nCde0?Xb
;@3k<2`0mRXY0?HX:@3Y7B00i1XQ0=lI8`3@4Q`0bQ4K0<8=5`2g21<0/`HA0:l5402Y0Pd0Y`8=0:<1
2`2T0@/0X@4=09/12P2J00T0V`4909l23@2S0@h0X@8>09`22P2>0@D0U`8809h12@2O0@X0W`4>09h3
402G0@/0TP4808/2201e0P<0LP4307L1101m0P<0O04207H20@1_4P49ooooo`03003o003oP000oh00
05D0oh002?ooool?003o000`09Z4B@2:K5X0T8ZA03<jM0196EX0JAA@02LBJ00]3E/0D@Pa03`6<@0@
1TD01AMb008TTP02:J800RZV008^[`04=KL00SNn00E2a`02@<@00T;90098d`02CMP00UGR00=FiP02
F>@00USS009Ih`03F=l00eKJ00IJf`0;G]<06FG903=ea@1=PK`0Ihji07bF]@2=X;00Tj:]09NTZ`2O
[Zh0Y;6c0::^[`2P[J/0XJZZ0:F][P2[/k40[[Nf0P2e_Kl0602i_[l0^;bn0;Zm_`2g^[/0^;bi0;Ni
^`2c]kT0/KBg0:nb]@2Y[[00X:RX09nYZP2NZJT0Uj>S08jKW027UiP0KX>805icOP1:I7d084Ak00Pc
R@06;X005f/b003o00Sooooo3`00o`040:0Pl080d51h0P2h>;@00`3oP000j6Pl0:0Pl00n0:0Pl003
003o0?oooooooooo00Wooooo000:ooooo`0:003o0026=QD0Q@L209X3102G10D0Q`P808TG6@1g0P@0
LP0207T11080O`4704`0PP4608T1202:0@X0Q`4708P21`2A0@L0W08;0:P23@2`1@l0W`8<09H1202A
0@T0SP4908l02@2<0@T0RP4808/0202?0@T0V0490:D33@2^1100]PPC0<0;5P3@5Ql0gB0V0>P[<P3X
;cT0ldA70?]^I`3lUhP0nJnU0?Zj^03j]kD0nZFJ0?j=N`3nIET0oe9;0?i8A03n@T40oCXl0?/`=@3h
:c00l2L/0>HP9P3O72<0eA@N0<P=602l21@0]`DA0;D53`2]0Pd0Z04>0:413@2M0@T0V`0809P11`2F
0@T0V04;09T1302F0@T0T@4809D12`2H0@X0V@4:09D12P2C0@X0SP4408/10P2<0PD0Q04507h11@1k
0@@0M@4207<20P1^0`40KQP32Oooool00`00o`00oh000?n0001E0?n000Sooooo3`00o`00BP1Cc2@0
S6eI04<oH`1W6T/0X`/R0:`75P251b`0F`Te02<9@`074VL00QIf008QS001:9d00bnW00<c/@02=kX0
0CJi00<i_`02>kl00cZk008e]@01>[/00TC700=@e@03D]H01UC@00eIa`0RI<40@WFj05J0^01ZRkL0
QYbd09:R[P2W/kL0/kfl0;c3`P2h_/40bLo;0=GHf03Gfm/0f]gO0=7Be`38bLl0`[o70;Ra^02^YJX0
X9RK09J=SP2;PHD0Q7Uo081aM@1mLFl0O6a[07e]JP1fJV@0MfYW07IZI@1dJfD0MVeX07I]J@1eKfT0
NWA^07mjM`29QH40U9B@08nBT027ShX0PH^707B3P01RMGH0A5e[01ljE@0?[Q<00?l02?ooool?003o
000407QH]02P8?00X23`0>QX?0@0oh0000<0^3Rd0:0Pl02P8?00?@2P8?000`1@T7P00?l0ooooo`0:
ooooo`002_ooool0F000o`00U4LL088;0@2R1`P0S@<309@Q8`2<6b80M@8407X10`1h0080OP4507T0
0P1m0@@0Q@4808H12@280`T0T@hC09H;502H0Pl0X0<A09/13P2>0@T0R@0608`22P2>00L0U@0709P0
1`2L0@P0X@4:0:@22P2^0``0`@XD0<`?6@3I6B40jbD/0?0Y;`3g<ST0mcI20?HiB03iAU40nf5V0?Ym
O@3dQHl0m8BH0?5gR`3`IW@0m5QJ0?I2@@3i>3P0o3Ti0?/d=P3i;C80nbdb0?HW;03a8bX0j1dW0>@K
9P3L5B40eQ@P0<`>6P3931X0aPTF0;l74`2f0a00/04>0:X1302U00T0W`0709d2202O0Pd0V`4<09L0
1`2E0@T0S08;09<43`2L0aD0U04@09012P2:0@@0Q`0208`1102<0@D0P`4407d10P1j0@<0L@4007D<
0`1^6`<9ooooo`03003o003oP000oh0005D0oh002?ooool?003o000g00gi1P1jKTl0CQi80:PA8P2b
31<0/@TA09<67@0Q3d`00aM[008OO@0178000RJE00</Y@02;:T00B^[008a/`02;kH00cJk008f^@03
>[P00cZg00<o^@08AKP085Zf04Ul_@1dUk`0W[320;>maP2i`L@0^;o10;_1a032alL0d=GD0>3Qi03M
gN<0e=3I0<>lb@2c[;T0WiNU08J1S`1fM7d0Kfmc06][K`1UIf/0JfaV07M`I`1gLF@0N79T07UaHP1i
Kf80N6iQ07]cHP1hL5h0Ng1P07M_G00207I^F`0A07I_G01fKUh0LfiL06aZF@1]JUX0K6MH06QRE@1S
Fe40IEa>06IQE01ZIUP0K6]O06]_I01LIed0AeY>01nQ6000o`002?ooool?003o000302S8?02P8?00
d51h00@0oh0000<0^3Rd0:0Pl02P8?005P2P8?001@2h>;@0d51h0:0Pl02h>;@0d51h02<0X23`00<0
N5Rd003o0?ooool02_ooool000[ooooo05P00?l004VV1P259@d0U`H508@20P1l0`D0QP@807P10`2=
0`D0Q@4308H21@2<0PP0QP<707l11P260`d0V14N0:@Q;`2K5R<0U0HD09813@2B0@X0TP8909@11`2M
0PX0ZPD=0;D93`2m4180^0X?0;863`2_1Ph0[0<;0;87402k2A@0^`LB0<495P3431L0a``H0<d@7P3@
41h0ga/V0?4W<@3f=S`0nD960?Q1BP3f>D80n3Pl0?Ld<P3k<R`0nRXS0?/[9`3i:2L0mR8U0?DP8`3]
6Qd0iQDK0=dB6@3C3aP0b``H0<<8502o1Q<0_0@A0;X43`2g0Pd0]P<>0;D23P2b0P`0[P<;0:T12@2W
0@T0YP8=0:@23@2O0P/0V04908D220290a00W`LK09`6602E0Ph0S@4708L01@290PD0S08508H10P21
0P80O`8207D40@1h5PX0CE@12Oooool00`00o`00X23`0?n0001D0?n000030=1@N?oooooooooo00Ko
oooo4000o`00B@22NDl0OQTd0:hJ7@3QQ8L0]d9<0:P:6`1C5e8022B7008XTP02:YL00RRJ008VX002
9Z400RZV008][P02<;<00C6`00<d[P09>JL0:EBW0621]P2J[LD0`lc@0<oDd@3Eem<0g=kL0>3RhP3M
gN40d/oI0<K3cP2]Zk@0T8jI085nR021OhP0Q8B;08^?T`27SY00OHB606AaL@1PKfl0GVm_05e/K`1O
K6d0GVQO06EYG@1cLf@0N79O07MaG@1fKEd0MVmJ07M`F`1jKel0N71O07I_G01eKe`0LF]E07=^F@1g
LF00MVmP07A]H01aJU/0KVMF06m[F@1[IUD0JF=>06MUD`1GFTX0BDe204M:@01JGTd0FUm?04UH=`05
l`802?ooool@003o00030:0Pl03oP000oh0000<0oh0000<0j6Pl0:0Pl02P8?00?`2P8?000`0Xb3co
ooooooooo`09ooooo`002_ooool0F000o`005nl607@/2P231P80NP4207@10P2410H0N@840:062P2Z
1PX0X@<809/42@2:0PL0O`8708H33`2D21P0X1TV09XA7@2@0Ph0S`8:09X22`2N0PL0XP870:L32@2T
0PX0XP<909X21P2A0@@0T00608h1102B0@D0W08:0:@1302_1100^`D?0<L:4P3B41L0hQ/P0>PQ903d
<c00ndM00?MGD03dIf00mWei0?J5P`3gOGT0nVeR0?aJC@3mD3l0oT]00?i6>`3m?S<0oSX`0?/b:`3i
9bH0mB8P0>XI6P3J41P0d0hI0<L:50342Q<0_0H?0;P33@2e0`d0/@4;0:`1202Z0@P0ZP4:0:P12`2X
0@`0Z`8=0:P12`2R0@T0V`4909L2302M0a<0VP8B09P23`2?0@X0Q08706l10`1o0@D0QP4508P10P26
0P<0N@L306TB0P0^W@09ooooo`03003o001@T7P0oh0005@0oh0000<0J:Plooooooooool01_ooool@
003o001906nP9@2D7QX0^EeM0=FV[`3?S9T0Ya4N09/::00g76l012JE008VV@029i/00RJP008YXP02
:9h012^P00X`W@0P@9T0CVFK08NBZ`2Y[[H0`L750<g:c03@cm40b/W?0;Nb^P2QUIl0QW^4079/LP1Y
Ifd0J6]_06Q`K`1aNWL0JW=^06Y^J01ZJf40JFYM06aZGP1`K5h0KFaN06YWF`1JGEL0@dm<04AAD01@
GE/0GFQM06a/H01cKEh0LfmL07M_G`1eKUX0MFmI07I_FP1gKed0MFiJ07A]E`1gKET0MFeK07A^G`1j
MVL0MVeP071WE`1^JEP0L6UF06eWE`1ZIE00J6QI05=DCP0c>cH0;S/a04E>?P1FEdD0FeY301KC3008
oooooa000?l000D0Z8Pl0?n0003oP000d51h0>QX?0020?n000030;Ph]02P8?00X23`03h0X23`00<0
D91hooooooooool02Oooool000[ooooo0P00o`00EP1KIPL0O0T108020P1_0000M`@507820P2U20/0
[P<80:h63@2J0@L0QP4607d2202610l0T@XG09<>602<0`/0S@4909022`2D0@L0V`0709l0102R00D0
X00509T0102E0@80V@8309d21@2L00D0X@880;L530372aD0e10H0>DI703^7R00n2TX0?hg=@3oB4<0
oeYA0?miL@3oWih0ol[?0?oOjP3og>T0omCN0?nXYP3oMfh0oVEI0?eGB`3nEDH0oTdn0?i3>03n>C00
oBdY0?h[9P3k9240k1/O0>4F8@3E3aT0da0J0<`<5P331Q40`0PD0;P43P2b0PT0[@0;0:d12`2[0@X0
ZP490:d12@2/00T0Y@070:801@2O0@P0V`4;09L12P2C0@/0S08708H11`1c0PD0O04408@0102;0@@0
S08307d70P1]5@003nD12Oooool2003o00030=1@N03oP000oh000580oh0000<0D91hooooooooool0
1_oooolA003o001807U]4`36R8P0h/?<0=ne``2[:S`0/PHD084@@00C7HD00RJI008WW0029IT012BC
01XdR017D8D0KFV808QkS@2CQhl0W9BG0::OY02TWZ80ShR:07U_LP1_Hf@0MVQP089gJP1dLVT0HF]X
05QYJ@1BHF80GV9J06IWFP1fM6L0Sheo0:^[W`36`l<0`[jo0;:XY02MSHD0UX9d08YhJ@1nLV40KfQH
05=HB`1>FU80IFQP07MfJ`1eLV@0MfmN07A]F01bK5D0MF]G07IYE`1eJUH0MFaE07E[F01gKUX0LVYG
07A/G@1hKF00NVeN07I_G`1bK5d0LV]O06MTE@1GFE00@T@j03m6>P14DD80C5Q?061WFP1IF4405mD>
2?oooolA003o00040=1@N03XJ3`0X23`0=1@N0<0oh00@02P8?000`1@T7Soooooooooo`09ooooo`00
2_ooool2003o001F03Rn2@1i3`40S0D407L30`1_4Q80L`H50:P<3@2W0PH0Z0890:<430230PD0I@44
07d22`231`l0Q0D=08D11P2400D0QP4608d11P2W0P/0]@@=0;`530362a00^PD<0;/;3@313Q00_@P=
0;`84@2o3aP0b@`C0=HA603N4aT0iaXO0>/L8@3h9bP0oC8_0?ln=`3lA3l0o4]?0?UBG@3eG6/0mVAh
0?=JK@3dEfH0neUM0?]>C03nCTX0o4I20?i5?P3l>c@0oSL`0?da:`3j9280mAlL0?4J6P3U5A/0ePlJ
0=0=6`392aP0_0XF0;H7502k1Q<0^PDA0;L33@2f0Pd0^@<>0;d5402o1@h0a@XA0;/53P2Z0@P0Y047
0:021P2J0@H0U`0709<11P2=0@@0RP4408811@230@@0Q04408L1102:0`D0O`X406lI0000o`09oooo
o`800?l000<0J:Pl0?n0003oP000DP3oP0000`00o`3oooooooooo`06oooooa400?l004P05N/70<VB
SP3L/l00`FMk0;D?7@2j2@l0W@hZ02<LN00299<012F>01H^O`16BWH0LFAd07m^M@22LWD0R7Ml08Ik
OP1hLG40KF9M071RE01iKEL0OW1I081aF022LU/0LV]M05MMF@0kC4T0?e1805eTF021OW40UI2509^G
TP2DSh`0R8>308N1PP23P7d0OgYf075aJ01NG500GeM6079PA01kHdD0LVQA04aDB@1;EU00HfQK07Qh
J`21OF`0Mg9M07I]EP1hKEH0MF]F07AYE01eK5P0N71N07A]F@1fKU/0LfaI07M/G@1iLF80Mg9R07Ec
I`1YJ5l0GUU?059?@P1EED@0Ee];05IPDP1FHEL0IFaT06=OB`0Ge0/8oooooa400?l000<0:<Pl0=1@
N03@D7P0103oP0100:0Pl003052@N?oooooooooo00Wooooo000:ooooo`800?l005H03?L4080P1@2G
3@@0U0P:09Pl@0213@l0X@@70:D21`2W0PL0/@H=0:852P1m0PD0NP4507`10`220PH0Q`4708X21`2;
0@H0UP480:l43@2m1Ph0c0XB0</94P2i0`/0[P<:0:L22@2S00P0X08:09l32`2]1Q40]P<?0;h7403;
2Q@0bP@?0>`L7`3j9R@0nBPS0?/Y8`3i9b<0nRPX0?X[:@3l;R/0o2l[0?/^;03e9BP0mbh_0?dg=03l
<c00nc0`0?`_;@3h:BH0lR4Q0>lL7`3`7R00kAXM0>8D6@3821<0_@HD0:@4402`7bd0/2He09h33P2/
0Pd0[`8<0;P33P301Q00b@XB0=4>503C3Q80b0XB0;422`2V0PP0W@8509T1102G0@@0U@8508l21@2C
0PD0T04408/10P260@<0P@4408031@1l4@D0AW80003o00Wooooo0P00o`000`0Xb3`0oh000?n0001A
0?n000030:0Pl000o`3ooooo00Oooooo4P00o`00A`2jUGD0h9b/0;DZ=P3;4a<0/A0M05hLE`0>9HH0
3bYl03DnJ@1KDf40K5iR07=VI@1fKFP0L6MO06YQEP1_HU40NFYB08EdF02:N5X0R7EI081aF@21LED0
P75B07=YD@1BDT<0H6=F071`HP1hMFL0N7AX07QiK@24Qgd0MGeg06UeKP1TL6T0H6YQ06IYG`1RIeX0
H65E05mLD01iKED0PFM707QO?P1aKEP0Adm804YDB`1SIeL0MG=T07mmK01jLUd0N6eH07E]F@1hK5L0
MVaD07A]F@1eKEH0N6iI07M^F`1jL600N7EV07IdJ@1]KFD0G5eG05aHC01YHU<0JFEG06MYGP1LIE`0
GfMP06=WG`1WG4807=H900Sooooo4P00o`000`3XJ3`0oh000?n000020?n000030>QX?02P8?00X23`
03h0X23`00<0D91hooooooooool02Oooool000[ooooo0`00o`00E@29>@h0VQL809@40`2A61D0T@T6
09T20P2P0@<0Z`880;T62`2j1P/0]`P=0:<4202B0@D0U08809P12@2K0`/0UP8809T22@2T0`X0[@<:
0<073`372Q40`0T@0;072`2P0@L0U`0709<11`2A0@H0X`<90;L83@3A5QH0hQlJ0>HS7@3[:B80ib`V
0>Hd:`3P=B/0fS`a0=11=`3CB3h0d4]20=1?A@3<CDD0aTU10<1:?`37D4H0bDm60;i4?02j@3`0]S/f
0;4b<02d<C00/RTW0;LU902k8200]aPJ0;4C602B3a<0YS8j08`9502O2@l0/PP>0;`940312A40`@T?
0<@7403?31D0d@hC0<L;4P2_0``0X04909L11P2E0@L0U`4709D21`1n0@<0TP8909<11P2<0@80R@41
08@10`1j10@0MQX701c90000o`002Oooool3003o05<0oh0000<0D91h003o0?ooool01ooooolB003o
001706jO:`2fGEd0^R//0<<J8@1Y:V<04b^002DfJ01>BeD0GEEC06=KEP1WGeP0JV5?06mQA@1gIDH0
PFm>08McD`28LU<0RGAE08MdDP27Le40PW=J07i`EP23M5L0NVY=07U[C`1kKUH0LVQB05UHC010DDd0
BVAU055WK011EUP0D5]C06EUEP1iN6D0TI5o09jLS@2BRH40OG5Q07m]E01oJT`0OfQ607MS@P1cL5h0
DEQ?06i_H`1cKUh0M6eH071YE@1cJUH0OG=P07U[EP1fI4T0LfUA07I/F01nLV@0O7AX07QdJ@1^KV@0
Gf5J05]MF@1PI5P0LFmR07MfJ@1aLVD0J6mT06M`J@1VKF<0If9B075W;@0:m`@02?oooolB003o0005
0:R8?03oP000oh000?n0003XJ3`0@@2P8?000`0Xb3coooooooooo`09ooooo`002_ooool3003o001C
05eU0P2>5@@0R`8108H10@2D10<0V`420:D11@2a0`L0a0d?0<07303:3A00a`d>0:P1102N0@L0UP07
09<01`2A0@P0U@490:l7402h1a00`@/B0<<;4@2o1`d0`PdA0;`?4@2^3A40XPd?0:@G502g:240_BlU
0<<m<038Cd00aUa<0<IZFP34NFd0`hQk0<>@P`33X940_JFF0<:ZW@34[Z<0a[BX0<>cYP2n[j40^:fP
0:nVV`2`YIT0ZJ2D09nER`2KT8D0W8f509J4N`2IP7H0UgU_095/G`2DHU80TUI708A@A02HMG40GbPT
080S702G5a<0Z1DD0:d@402l4a@0aPlB0<h?5P3>3Q@0b0dD0;L73`2Q0@/0V04;09@12@2G0@L0U@46
08d11P2E0PT0T04608d10`290@80P`4107L60P1^7`D00P00o`09ooooo`<00?l000<0d51h0?n0003o
P0008@3oP00D0:0Pl0030?n0003@D7P0X23`01P0oh000P00o`08oooooa800?l003l02O@109=/;@2c
>C@0T3=N02<fQ00m@EP0Ed]006=JB`1YH580KF9<075O@P1iHS`0PVY608Q_CP27LU@0QgMK08EeEP29
M5D0RWEF08MaD025Kdl0PW1@07m]C@21K4l0Pfa:07m^CP1_ITl0FUU805iUF01]NW40OhZ7096GT@2P
WiT0WYbH08n@S024R840S8V707]hL020MFD0QgMU0960J@2=Nf00NV8i07=Q>`1^JUL0Jf=C07IXB`1e
Hd<0MF=:075SB`1hL5X0O7=P085aFP1jKUP0MVaI06eUDP1WHE<0F5eA05ENEP1LIUh0K7=V07IkKP1l
OW<00P1eMfd01P1bMV/0KG1V06mZFP1]JS@06^<8003o00Sooooo4P00o`00100Xb3`0d51h0?n0003X
J3a10:0Pl00302S8?000o`3ooooo00[ooooo000:ooooo`<00?l005<0CIT807`J0`230P80S`D309`6
0`2T0P80[0@60;8310394A40`0L:0<X=3P3>3Ph0a0X=0;<72P2N10/0V@TB09d;4P2T1a00/0P@0;09
3`2/3@l0Z1@C0:0L6P2P:bD0Xd0d0:5<@P2OFD`0WfYM0:=fJP2RPGH0X8Yn0:6BQ`2PUhd0XibD0:NS
WP2/[:H0];Na0<76_P3=d<P0f=WB0=OGd03If]@0f=WB0=?EcP3<dLX0`/W30;W0^02e_KL0YJj[09nZ
Y`2HX9l0T9RE08bAS028SXP0Q8V307j0M`1mOG40NWe`07EiKP1hM6P0Og5R07mUE`23FTd0PDXm08m2
=`2M<BX0Y2<Q0:hK6`2f51H0[PX@0;<;5P2U1A80V04=09P12@2G0PP0U04709811@2A0@D0TP<408`1
0P260P<0N@X404QT0@02003o00Wooooo0`00o`000`2XR3`0oh000?n0000E0?n000030>QX?03@D7P0
d51h00<0d51h802P8?030=1@N140oh0000<0d51h003o0000o`002?oooolD003o001307YK5P1LA7X0
?SaE06IB=@1^FC/0LfE8075SA`1hJ4L0OF]:08=aD@26M5H0QgII08]hF`2;NU/0R7II08I`D@2:Le00
QVe:08E^A@24KT@0Of]8085aE026LTl0P6Y607aZC01kJD`0PFiD09:1MP2JSI40O7Ag07MbK@1oMVL0
Mg1O09VER02/Y9`0U8Ym089eH`27NFH0R7m^09ZDT02:NfT0PVa9071O?P1fJDh0Nf@n07]S?@1bGd40
MVM<07ebH@1nLV80OFeG075SBP1XGdH0H61>05YSF01JJF<0I7A_07=oN01iP7L0NX1h07YnN01gO7@0
MWQ^075`H`1bJUL0N74k01_T2@02003o00Sooooo5000o`000`3XJ3`0^3Rd0:0Pl00o0:0Pl00302S8
?000o`000?l000_ooooo000:ooooo`<00?l005<05Nd607L^3@2530@0V`P40:P50`2a20H0/PH50;d:
2P2m2P`0^`D90<P<3P3?4100d10B0=0B5P3061T0ZQlQ0:@W:02H9bL0Tc/f095=A`2=HED0TGM[09:1
M@2@QWX0SHYn08^;OP2?SX@0SXn809>ETP2FV9P0VZ6P0:J_[02a^kL0_<G40<gCeP3Ig^00i>W/0>o`
l`3dloP0m_Ch0?GbmP3dl?H0l>kc0>gZl03Zin`0i>7V0>;Mh@3PfM`0dlo@0<k=c034a/40_knl0<2m
^@2k]k<0/[:^0:RXY@2LWYX0V9^E092?RP29RX80PXIl07f2NP1gOWD0Mgib07UlL01gMFT0NG1X07eZ
H020ETl0Od0k09Lf<`2W82@0Z@lG0:H8402I0PL0T08608P10`2<0@<0T@8308d10`270P80O0l401KF
0002003o00Wooooo0`00o`000`0Xb3`0oh000?n0000?0?n000030>QX?03@D7P0d51h00h0X23`0`3@
D7P20?n000030>QX?03@D7P0d51h00@0d51h5@2P8?020=1@N0030>QX?03oP000oh0000T0oh0000<0
D91h003o0000o`002?oooolD003o001202SI3`1K?S@0HDL]07aR>P1nId<0KV96075YC`1mJTT0P6]8
089^D024M5/0PWAJ08UiGP2;NE`0QW=E08QaCP24K4<0QV]608E/@`24JCh0Q6Tl07US>025LDl0SWAF
08Y_CP25JD<0QF]3089Z@P1lJDd0B4m507Z4PP2KU8P0RGUU08elI02@P6X0T7mY08emJ028NfL0Qge^
08Z1M@2<OFd0O6Q907]X@P1kJT`0P7=H08IhG`1oMEl0PGMR07mhIP20MfH0NW=Q079bH`1]MF/0LWah
07N3P@1fPWl0M8>207Z7Q@1nQX@0PXF007eoN@1mNg40NgAU07i[DP1XSbd05>h70`00o`08oooooa@0
0?l000<0D91h0:0Pl02P8?00?P2P8?00100Xb3`00?l0003o0000o`0;ooooo`002_ooool4003o001A
09176P2F7P/0Y`d40;@:1`2k2`X0_0`90;/91`2`0P<0^`D90<`>4@3=4180ba<D0<@I6`2/;2L0U4Do
095SG@2AO7<0RXEi08^9P@27Rgl0Rhf308b<PP2?ShH0TYB>09NKT`2JWYP0XjNR0;2f]@33b<X0`/W=
0<G9c`30aLd0^[c40:ZY/@2PWJT0W9VW09RDW`2DRYP0UXRF09V;V02ER9H0VhnK09B6S`2CQHX0T8:4
09F3PP2?O7/0Sgml0926P@2?R880ThR308j0N`2BPW`0TXIn09b>QP2OTH`0[9fF0;:QV`2bXYT0Zj2E
0:>OTP2IUHX0Ti2608V9OP21QW/0OXAn07IoN01dNG80MWE^07I]I@1oEe<0R3@`094Q7P2J4a@0SPH9
08X110280@40R04208X10@240P40Na4200<00?l02Oooool4003o00l0oh00>02P8?0:0?n000<00?l0
2?oooolE003o000o06E24P1jGS80NfDm05U>=P1OGe00JVYE07ETA01jHSd0OVM307e/D023MEX0PWEJ
08IeF@24KDd0OfY1089]A025Kd/0QFi608I]@025K3d0QVTj07mT>P20Jdd0QG5D08]eD`22Ich0Nf0`
07QT?01jNFD0ZZZU09B7P02WSG80Zhm_0::=L`2]U7/0T89a08^3M`24Og80OWIV08=dG@28N5/0SGmQ
08^0IP2=QWD0RXAc08^4L@2KTGl0W9N;09nNU@2KW9L0TYJG08nGV@2<UYL0SYRJ08fDU@26TY00PHb;
0826Q01mOWX0NgM]07i_E01hOCP0=lPE00D00?l02?oooolE003o03h0X23`00<0D91h003o0000o`00
0`00o`0;ooooo`002_ooool4003o001A05]g202;7`@0[1@60<<D2`3:6A40aQ<=0<0>30304A40`@d=
0;h?402a7a`0YSD`09aCB`2@Lf/0RX9i08N8O`26RWl0RXj508b@Q`2>THP0TiB=09BFS`2JViL0VYbI
09JJU`2IWI/0WJ2K09JET@2ASX/0Shb908n:Q02BSHL0UHn709>;PP2CR840U8Z009:6N@2DQWL0U8Ef
09B6N@2ISH40WI6709Z<O@2HRWT0VXaj09Z;M`2IS7L0VXel0:2FQP2QVHT0VXik09F4LP2<NfH0RWYR
08YiH@2=NVH0RgQS08egHP2<M5h0SWMQ099mJ@2JQG<0W8Qi09^<OP2MTXP0VY:<09>@QP28RGh0PHAl
07YmNP1dLVl0LFMP06mID01_?CL0Ma/J094A4`2@1PL0PP4208@10@201040Ic0400<00?l02Oooool4
003o00030=1@N03oP000oh0000T0oh0000<0d51h0;Ph]02P8?00>P2P8?000`3@D7P0oh000?n00004
0?n000040>QX?000o`000?l0003o00Sooooo5000o`00?P0@jP80Me@Q08MX>P1UFcX0ATHi045;?P1N
JE`0L6mO07I[E01jKU<0NfmF07i`F@21M5/0PfmD085]BP24KTH0QFm=08EcD028LTh0Qfa108I[?@27
Jcd0QFPk07eW?`1oKDP0PW9@08igE020ICP0NV8e07AVB020Nfd0T8=_0<RVR035YH/0/if80:fCOP26
M6@0PGAT07iaF`26NEh0QWaS08MmIP2GT7T0T8ah08R2MP2UY9H0_[ja0;nj/@2j]k<0^[Zh0;:d]02Y
[K00Y:N[0:2VZ@2HXZD0TibM08F>S@1nQHD0NWii07ahK@20JdL0CKXK1`00o`08oooooa@00?l000<0
D91h0:0Pl02P8?00>`2P8?07003o00_ooooo000:ooooo`@00?l001d0AZD807TX0P2O7PT0a20E0<DO
5P355Q00^14=0:dQ7@2N9ah0Sd`o08I`IP28PGT0QXR108>=Q@2:U8/0SIR?08fCR`2:SHH0Q8Ej08F4
O028R7l0RHIm08f7O@2CSWl0UI:409VERP2HUHP0VIB309B=NP0209^CP00b09R@OP2FT7/0W9B209^E
P`2OUXH0WIB209ZAO@2JT7/0Uhih09fBOP2JSWd0V8Yg09fBO`2MUH80WYR40:2IQP2QVHP0Xif=09fE
P`2EQVl0SgaT08ekHP2>OF40S7]O08YjH027N5l0QWMN08AcF@24LET0Qg5I08ehG02EP6L0WHej09F8
MP2APFl0SWiZ0921K@2=PW00SXMi08N3NP1mO7D0LG5]06QZI@1RETl0ISlf07@S6`202@T0O@8107h:
0`1=C@<3003o00Wooooo1000o`000`20`000oh000?n000060?n000030=1@N02P8?00X23`03l0X23`
00<0d51h0>QX?03oP0000P3oP000103@D7P00?l0003o0000o`08oooooa@00?l003d08=8308MQ:P1n
Id00HfAB05=LDP1:EDX0BUI;069ZH`1nP7@0NGUW07I`G`1hLeh0OG=N07e`F01oKe80Q71A08UeE`29
MeT0QWEF08McD027Ld`0R7A=08QdD029MU<0RGQI08MgF@2:NUh0TX9T08inF`23Ldh0P79F07]_E@2C
OfH0UXA`0965LP2OTGd0WI5l09^AO@2FSg/0U8mn0:2PSP2^[Yd0]k^/0<77^`38c<T0alc:0<?8aP35
a/H0a<G60;g0`@2h_[h0];bl0:bb]P2RZ:`0TIRL08J<SP1kP7d0NGYd07i_F@1XTSL09]d?00P00?l0
2?oooolD003o0003052@N02P8?00X23`03T0X23`00<0D91h003o0000o`001P00o`0;ooooo`002_oo
ool4003o001A01G/1020>`L0U2lI0:hR7P3XKF`0/aXD09XQ5`2HFdh0P6MG075cIP1oPW`0QXR208V=
QP2=TX/0RXn708:7O01nOW<0QhAg08b8M02BRgT0UXio09RBP02FT7h0V99n09:=N@2DSWh0ShYj09JB
O`2IU800W9B209^CP@2GT7l0UY1k09jEP`2MUH<0X9V809fDP`2RV8H0WYN40:>MS02TWHd0Y9f:0::J
Q`2PVHH0WIV609nJR02QVXX0WYZ=09nLSP2MVHT0THMd08YlI`26NV<0PgiV08B2K024P6l0PX5a08F6
N@2>SX00Ti6309:>O02HTW`0UXih09R=NP2HRgL0Vheh09R;L`2EQV`0RWUQ08IdGP28NFH0THQh08^7
N@1iNW00IVQR05iMF01LBd00Ib0I084?2P1n4`P0:hD100<00?l02Oooool4003o0003052@N03oP000
oh0000D0oh00A@2P8?030?n0000408300000o`000?l0003o00Sooooo5000o`004`0TeP@0SVT`07a`
EP1/LfX0IgEY06EbJ01OK6<0GfYU061^J`1hQ800NX9j08>8O@25QWX0PhAd08N4L`28Pfl0RhE`0929
M@2@S7H00P2ET7P09P2?RW40ShU`09FAN02ITg`0V8ii09N=N02CRgD0Thec09:>L`2GT7L0W9R20:FQ
S@2g]:<0aLFg0=ODcP3NfMD0h=kJ0>_[i`3fmo<0oOkk0?7clP3UjNX0g>7R0=WKg`3Dfmd0dmWK0=7I
f`3>d]P0`/O<0;c4aP2[]KP0WZNZ09FJW027QXH0OGA^07]gC`1EXbX04nd82P00o`08oooooa@00?l0
00<0D91h0:0Pl02P8?00802P8?040=1@N0030>QX?03oP000d51h00l0X23`00<0N5Rd02S8?000o`00
2@00o`0;ooooo`002_ooool5003o001@08JJ;`2SHdh0YC4^0<=5A02M<RH0Q5U807=ZG@1_LVD0Mgi`
08N8OP27Qgd0PX5f08R2MP28PW@0SHYf09JAOP2JU840VYB009ZCO`2JTh00VI9n09NBO@2JU840V91m
09ZCP@2GT7d0ViJ409ZCP02LU880WIN409REP@2KV8D0W9R509VEQ02KV8H0WiZ90:6JR`2NVHX0WYb=
09fKS@2MW8h0Wij?0:RTU`2UY9H0YZBH0:JUV@2TYI`0X:FI0:2UV`2NXYP0UYb@09ROTP2LYYT0W:BI
08jES@24ShP0NHF207V5P`1mQh@0P8R208N9O@2AS7`0V8ml09nBO02PT7/0WI5i09fANP2JS7L0V8Ua
09:2J`2?P6/0SX5^08ImK@1oO700M79Y061NE@1F@3D0Gb4C06<F1`0NY043003o00Wooooo1@00o`00
0`3@D7P0j6Pl0?n000020?n000030;Ph]02P8?00X23`04D0X23`00<0d51h0?n0001XZ3`00`00o`08
oooooa@00?l002<02oH2095V:P1lMf00M85h06mmN01fPGh0NhB407n<S01oSHd0Q92?08BASP27UI<0
RYNG09jYYP2Z/jd0^Kjf0;_1]`2o`[T0^[nc0<;8^`30a[`0`LJj0;_0/`31a[/0b/o30<_?``3=cl80
dmO;0=cPd`3TiMT0k>cT0?Gek`3lo?P0o_om0?kno@020?knoP0D0?ooo`3no_h0o_on0?kno`3moOd0
oOkn0?knoP3mo_d0l_?f0>CWj`3FfMh0aL_@0;_0a02a];T0YJR[09BBSP26MfD0FiTc03S:600;m`@<
003o00Sooooo5000o`000`0Xb3`0X23`0:0Pl00I0:0Pl0<0d51h00<0j6Pl0?n0003oP0002`3oP000
0`3XJ3`0X23`0:0Pl0070:0Pl003052@N00Xb3`00?l000/00?l02oooool000[ooooo1P00o`005P2K
MdP0SS<U0917=P1hGTh0KFiO07AgIP1kOfd0Ogm^08IoK02;Pfh0UH]h09F9M02ISW/0UHmi09B?N@2J
Th40ViF409jGQP2PVXT0WiZ90:2KS02NVhd20:2MSP0X09jKSP2QWi@0Y:6G0:VVV`2^ZIl0XZ6F09fO
U02NWi<0VI^A09bOU`2KXIX0Xj^T0;:i/@2f_KD0/kZe0:jf/02/]J/0[[B_0:fd[P2]]Jl0WjNS096H
UP29TY40OHR406mmN01aOWH0P8Z009fPUP2][:00WYf?08b7N01jMF@0MFaN06YSE`1GGE<0JW9[07n0
M@2@QgL0WI9m0:6CO080WY5k00d0V8]d09V<M02OTG/0V8]e09F<N`1iM6D0HV9C06YWE`1nMfD0JF1@
05E5<`1@9A@04/<100<00?l02Oooool6003o00030=1@N03oP000d51h04X0X23`00<0d51h052@N000
o`000P00o`08oooooaD00?l00140C;@D07m/C01dOG80N8R0086?S02:UID0TYjO09>RXP2JZ:L0XZj]
0:Jb]02JZ:/0ZkRi0<3;b`3Bg=`0gnKU0>?[jP020>S_kP090>O^k@3Zlo40j?3_0>kcl`3cn?L0loKf
0?Gin03io?`0o?gm0080oOkn01L0oOgm0?clo03lo?d0o?cm0?_ko03hnOT0n_Wi0?SinP3inOT0o?ck
0?knoP3moOd0n__k0??dm@3[k^l0i>SZ0=[Jg030_l00[:BO0:6>O01QXSl0@/8P01K`2P0?003o00So
oooo5@00o`000`1hF;@0X23`0:0Pl00A0:0Pl0030=1@N02P8?00d51h01@0oh0000<0j6Pl0=1@N02P
8?001@2P8?000`1@T7P0:<Pl003o000>003o00_ooooo000:ooooo`H00?l004<0KL4f07AE>P1/GDP0
MV]J07iiIP1kN6@0KfaK08EoK02ERW<0V8ef09N=N@2KTh00Ui1m09fDPP2MV8H0ViJ809jJT02MVHl0
XIfD0:BPU@2WXYL0Z:BG0:NSUP2YYYX0ZZNP0;:]Z02f/Zl0cLS80<k7c02f]KH0WJ:R08VBUP1oS8d0
OXb?07Z:R`1jS8X0R9F@09RQW@2SZJL0ZK2/0:fc[P2c]k<0`<G10<S=b@36blT0bLk>0<C:b02i_;/0
[jn/09^MU`2RXIh0`K_00<>k`02fZjL0WHel09V0IP2INEX0TG1?07mWB01VFdL0IEm<08QmJ02NTGX0
Wi9i09j@N@2LT7T0W95l0080VXmi00T0UH]h08^8O@1TJ680?DXo041:?01FE440P7AL07UZD`1L@2T0
1000o`09ooooo`H00?l000<0N5Rd0:0Pl02P8?00<02P8?000`3@D7P0^3Rd0:0Pl00H0:0Pl0@00?l0
2?oooolF003o000U05VO701mKe80OH=i08JBS@2;VYT0VJNW09n][P2_^kd0^/G70<?<cP32bl`0a<g>
0<_Ee`3Gh><0f^7V0=SRi@3Ii>P0fn?X0=cTj03Li^P0g>KZ0=cVj03Hh^@0g>CW0=kVj03RiNT0hNKY
0>CWk03Ni>L0h^KZ0>CWj@3Xk>l0kO;c0?;emP3gmoT0moOh0?GemP020?Kgn00:0?Kfm`3hmoX0m_Ge
0>gWj@3Fb/X0_jbQ08jWI@1L]SD0:n0F00ch1Q800?l02?oooolF003o000307QH]02P8?00X23`01d0
X23`00<0d51h0?n0003oP0001`3oP0020=1@N080X23`00<0N5Rd052@N00Xb3`04P00o`0;ooooo`00
2_ooool6003o001>03o>6P1]FSH0N6Y=089eG@1`Ie80JVAA06QVEP20OFd0TXQe09bDOP2@RW@0UY1l
09VEPP2DRg/0UXil09R=OP2LTH@0WYJ90:2MS`2MUHP0WYJ809fGQP2KUH@0VIB209ZBP@2JT840V8j3
09R>Q@2>R8D0Ngj105iXKP1?GfH0B5UK04mNF`1`NG@0Vj>L0;g6_P3Fg=P0h^OW0>_]lP3Xj?00gM[R
0<2k`P2[YJX0V9:G08=lO`1kKfd0OF]S085ZG024L5/0SG]T09N4L`2QSh00XHmi0:6?L@2MR6H0UWiM
08meD`2GMTh0Sg1:08M^B023KD/0Y9Em09jBN`2OTgl0VXij09nGPP2KSgX0V8aj09:>PP1ZKF/0AU9>
04EDAP1:EDD0D5A607EbF`24MEX0MUdn1000o`09ooooo`H00?l000<0D91h0:0Pl02P8?00B`2P8?04
003o00Sooooo5`00o`00500/cPh0MGdj08R1L021Qh00TI^H0:6[ZP2W/kD0/Kc10;W3aP2nal/0_<K:
0<7=c`33cm80aLoC0<SAe037dMD0am;C0<C?d03:emL0d=[L0P3>f=X05P3Dfmh0fN3S0=_Ph`3Jh><0
gN;U0=_Ti@3OiND0hNGW0>GYj`3Yjnh0k>g`0>o`l@3bl_@0m??e0?;_l03Vg]d0f/S30<baX`2K[fd0
F<@j04KC9@0<n0HF003o00Sooooo5`00o`000`1@T7P0X23`0:0Pl00N0:0Pl0040?n0003@D7P0j6Pl
0>QX?080d51h0P2P8?02052@N00302S8?000o`000?l001@00?l02oooool000[ooooo1P00o`00CP1>
YA@0OVM108IhEP1ZHDD0CD/f05=C@P1NHE@0OWia08n7M@2JTGd0ShYe09>>N`2:PVl0TXIb09B5K`2@
PFT0U8A^09F:M`2BSGX0UXem09F>O02GSW/0V8mj09N?N`2KTGd0Vi>009bCP02FSW`0Ngeb05MMFP11
C4P0BeI=07IlL01oOG00Uhn40:BMU`2/Y:@0ZJ6T09^BT`2>PH00QWIc08]gJ`2ANFD0UWiU09j6K`2Q
R6d0XHMU09amE@2DMe00RWQM09:6K@2HRg80XYR30:NNRP2KU880TXin08B3M@1fLf<0S75=0:1iB@2L
N4L0Rfa50::?MP2MS7D0VhUc09>1JP28Med0Q7AI07meIP1YKf`0BUMF04YGD01?G4l0Dei@05]UEP23
RW/0RH9[08Q]B`@00?l02Oooool6003o000307QH]02P8?00X23`04/0X23`1000o`08oooooaT00?l0
02D0=lPD062O<@2>NUT0UX]j0:FQVP2^/jh0/KRe0;Jn_@2f`L40]l310;o7bP33bld0`l[<0;k;c@30
bl`0_lO:0;k8b@34c/h0alo@0<O?d@39d=40c]CF0=;Gf03FfM/0fmcK0=WLf@3LgMX0f]GF0=C;bP3F
b/H0d/>j0<fdXP2_]H<0T[UY06O2@`1AcB`09>XB01/00?l02?oooolI003o0003052@N02P8?00X23`
01/0X23`00D0d51h0:0Pl02P8?00X23`07QH]002052@N1/00?l02oooool000[ooooo1P00o`00CP1Z
SB80S7AA075YC@1@CcL0C4lj04m@?`1?DD<0IFIL08J2M@2CRgX0VI:009RAOP2NTgh0UHUb09N7KP2I
RW00R7IM09J3J@2MSW<0UhU_09F7J`2FQ6H0V8=V09R4IP2IQFX0W8eg09j?NP2LSWX0PW]V06eWDP1e
K5D0OW9F09:0I02COEd0W85P0:B:JP2FPVH0UHMb0;NZV@30]:L0X9B009B4I`2IR6L0T8Y`07UhJP29
Pg40TH5S0:64F@2DNU80Ge]807EhKP24PWH0W9R>0;6[X@2ETHH0OGU]06e^GP1`JU80V7]>0:ImB02R
NdL0VG]A095lH02=N5`0SW]N08eoHP24NV<0NgMW05aUG@1@GeD0DEiC05UTE`1MIU/0HFeQ06ehK@21
RX40[jfN08a`C0@00?l02Oooool6003o04h0X23`1000o`08oooooa`00?l001`07nD;03S96@17^R/0
Lim607BRCP2AWFT0ZIF00:bKRP2bXYP0]ZRN0;BZW`2g[Z<0]ZfT0;V/XP2iZj40^ZbR0;j^X`2o[Il0
^jZH0;nYU@2`ZH00R[QY07fhF01EacX0F<De053<:@0`i1T09N/A8@00o`08oooooa`00?l00`1@T7PD
0:0Pl0D0D91h8@00o`0;ooooo`002_ooool6003o001>09id=`2;MUH0O7]Y04mDA01?E4<0CeA505=F
B01CEdX0HfEN07ioM02;RGX0UHik09fEP@2RUX@0TXI^09Z<LP2LS780U89Y09nBM`2RUWd0VXec09Z>
K`2LSG00WHa`09^9K02KRW80Vh]b09n@M`2APFD0SWQE08]`A02YS600]YI^0;6DK@2]Sf/0[8m^0:ZB
L`2RT7X0WY>309ZCPP2JTgl0Ui9k09:AO02UZ9P0WZ>G08J1L`24L5@0[XmT09elCP1hJ4`0J69D081a
G@2BQg40/Z^I09NCQ01mMfX0OW]X08YkG02LOTd0W7];0:R>IP2[W7l0ZIf90:nVUP2XXi<0Rh]n06ea
J01NIV40GFUQ05m[F`1NJEX0HFiO06IbJ01ZMfd0M7mf08B;Q@2JTh@0UgI91000o`09ooooo`H00?l0
CP2P8?04003o0<gooooo000:ooooo`H00?l004h0MYT]08YjG01oP7@0H6IJ05ELC@1AFDT0EEe>05IM
C`1HGU<0HFMO07anM`2ASh80V9B40:2JR`2OVHL0WiJ40:BLRP2UWHX0Xib90:RQT@2SVhX0X9Z709jH
Q@2PUXD0WYAo09ZAOP2JTW/0Vi=m09^>MP2IOe`0XhAF0:nEJ`2XSVP0/I1Z0:V:IP2KPfL0X8EY095n
J`27QW`0Z:^N0:b]X02l_;40/:jS096<OP21OV`0R7QL0:25GP2ZRET0Y7i;0:64G02DP6<0YXib0;NU
T`3JdLh0YYnJ07a^GP23M5P0VHAR0:NBK@2`XXL0/JRG0:bWV`2SXIX0RXb707f0N@1ZLFH0IVeT06Q^
J01WLFT0Jg=Y06agK@1WMF`0K7Yd071kN01lQH00SH^208aiH01fVS44003o00Wooooo1P00o`0e0:0P
l0030=1@N02P8?00X23`01H0X23`1000o`3=ooooo`002_ooool6003o001>06N/9P2FQVP0O7i_06ac
J01OIe`0Ff5H05IPE01JHUH0GFMI05mZF`1TIel0JVaV07QjL`2>SHH0WY^C09bJT02KVH`0WIV;09nK
S@2NVHX0Xif>0:>NS@2/YID0[ZFI0:bSU@2XXi<0[Z^K0:RRT`2YXI40WHih09=jF@2LQ5d0WXQR0:n?
K@2UR6/0SgaU09QmIP2QQg<0ZYnH0<O2`@2a[JT0YibH09N8N`2>OV<0TWaI09n3F02^U6`0[9E_0:V?
J02ZU6`0Z9E`0:JCM@2UUGd0Z9V60:RGO`2VUWh0]:JC0;N/W@2/Z9d0WIjH08f@R`25RH<0MGYc07Ij
L`1eNg80O8Ai0867O`1nQWh0Lh1j071oN01bPGX0KH1j07V6PP22R8<0RXV008UgGP2<Rcl05^l81000
o`09ooooo`H00?l000<0N5Rd0:0Pl02P8?00BP2P8?000`0Xb3`00?l0003o0002003o0<gooooo000:
ooooo`H00?l004`0:Md=09n9I01lN6D0LGIX06QcJ01SKVD0GVYO05eWGP1TKV40J71T06YaI`1WK6<0
J6mV06U/I01/KVL0PH5k09RESP2OWI<0ZJFM0:BQU`2OWhh0ViV709VDQ02MUXT0VIB709:?P@2FT8<0
VY6409ZAP@2HT7P0V8a]09V8H@2HQEl0V8=Q09N5J027Med0TGaQ09J0I@2KRW@0WXmm0:FDO`2YUh00
]9n30;RUPP2o[Xd0_[2A0<>iWP2eZiH0]ZfI0;R`W@2e[i/0]ZjO0;2XU`2m[il0^Z^J0;N[X02/YYh0
XYjI08n=R@26RX@0P8Eo08:5P`22R800P8El08F;PP2=UHd0QH^807b7P`1fPWh0NXJ207f9PP1lRXD0
QY2:08^=Q@24NFH0R8Ln1P00o`09ooooo`H00?l000<0D91h0:0Pl02P8?00B@2P8?06003o0<gooooo
000:ooooo`L00?l004/0P94h099oHP1jMfH0NWmf075jM01YM6d0Hg1X06McJ@1YMF/0KgQ_06meJ@1d
Nfh0LWU/079eJ@1`M6`0LgM`07MhL021OgX0QhR208nBRP2LWI@0Y:BH0:VWWP2]ZZ00/JnS0;2^X@2a
[9h0ZJ>B0:n[UP2_ZiD0]:bJ0;J]U`2m]9h0`[^S0<BmY03;`jT0dlVb0=WA_03NeL80hMW60=_D`03@
ak@0cLJd0<g8^038a[D0a/Fe0<;1]031`;H0_;be0;Zj/@2h]Jh0^[2V0<2_Y02cXi/0XiZD09^FT@2K
V9<0UiVD09FIU02CUY<0TiJD08fDS@2;Th`0RY:;08NCS`22Shh0P8n<082?R026T8/0Ri:<08jDS`2A
ShL0SGiW07Z??`0Rj0h01P00o`09ooooo`L00?l0BP2P8?000`0Xb3`00?l0003o0004003o0<gooooo
000:ooooo`L00?l001002oL406F/9P2?Qe@0UI:308J;Q01oR880Lgmh071kM01`NgD0M85i07AoLP1l
PWP0OH9h08>7OP27S8@0MW]b0P1eNg<0=`1dOWD0MGii07UnNP1kOg`0NX200827R02;U9@0UYnP09fV
Y02V[ZP0ZJnY0;Bi/`2h_KD0a/^o0<cBa`3Eflh0h^GJ0>_]i03cl^`0n_We0?cln@3mo?X0nOWe0?Ge
l03alnh0jncY0>?Wh@3GgmX0cmWE0<gFe@30alT0`lO70<?4`P38aKh0`kjh0<2m]`2l_KP0]KJb0;6c
[P2WZjT0XJVX09^RXP2LXZ40U9jL09BNW@2@ViT0SIVF08nKU`2@W9T0SiVE092DS`2GUH/0U8Eb07:K
?@11dA`02000o`09ooooo`L00?l000<0:<Pl0:0Pl02P8?007`2P8?000`2h>;@0d51h0=1@N0040?n0
00<0d51h702P8?000`1@T7P00?l0003o0006003o0<gooooo000:ooooo`T00?l002405>l807ZT@`2N
Rfh0ViF508jDR@27THT0N8=n07n=Q`21S8H0OhN40829QP27TX`0RiB>08^BS02:ShX0RI6;08F@RP2C
WYX0SYND08VBT01mQhL0QY:B08nLV`2>Vi/0TIjN09bWY`2X/K00][no0;o<b@3;eM<0eMkM0>C[j@3f
nOT00P3no_h0103moOh0o_kn0?kno@3mo_d20?knoP0L0?cmo@3am?@0i^c/0>C/k03Qj>T0eMgN0=OO
g`3Fg=`0eMOG0=3Bc`3@dm40`LK50;[1`@2f_Kd0Zk>c0:N`[`2V[jd0XZb[09jYZ@2MZ:P0W:JT09NM
W02DUYD0SXj808Z0K@1oS4d0BKXW02_P4`X00?l02Oooool9003o000302S8?02P8?00X23`01d0X23`
00<0j6Pl0?n0003oP0001`3oP0000`3XJ3`0X23`0;Ph]00F0:0Pl080D91h2P00o`3=ooooo`002_oo
ool;003o000S02gQ4`29RD80WHme09ZJS027Rh00SIF=092IUP2?VYP0RIBB08bFT`2?ViT0T9^J092I
V02IXYl0VZ>S09nYZ02BW9/0XJ^W08FCSP2CXYh0YK2]0;Bn_@2g`[l0_LK50;Fl_03:d=80e]kQ0=WQ
h03PiNL0j>g^0??fm`3oooh0o_kn0?gmoP3moOd00`3moOh06P3no_h0m_Kg0?;dm@3Zknl0jNk^0>O]
k@3Mh^@0h>KX0=gQh`3Gg=`0c=7A0<[?c`35bLX0`<G70;Fk_02h_Kd0/[Ng0:Z_/@2Z/;40Y:f^09jV
Y`2IVi`0SXEo08eiJ@2DMU@0E<0V3@00o`09ooooo`/00?l07P2P8?000`3@D7P0oh000?n000080?n0
01L0X23`3@00o`3=ooooo`002_ooool=003o000m03c>701P/3/0XHQW09b=N02NVHl0V9VB09NKV02H
WY`0VZBS08^HU`2=UiL0WJRW0::][P2S[J`0Oh^90::^Z`2W]:l0YK:_0;S1`P34c]00b=7B0=CLgP3A
f=T0fn3R0=WOh@3Qi^P0j>g^0>g`l@3hnOX0oOgm0?ooo`3moOd0o_kn0?gnoP3no_h0oOgm0?ooo`3k
no/0mOOg0>obl`3]lO<0jo3a0>7Wj03Qi^P0fn3R0=?If@3AfMH0c=7A0<K;c@35blX0_L;20;Vm`02d
^KT0[k2a0:BSX`2HT8X0V8Uh08B@FP1G]3409]`C01Oa2`0>003o00Wooooo3@00o`000`1@T7P0N5Rd
0:0Pl00H0:0Pl0030=1@N03oP000oh0000T0oh000P3@D7P00`2h>;@0X23`0:0Pl00>0:0Pl00307QH
]01@T7P0:<Pl00h00?l0cOooool000[ooooo4000o`00=P0]hA@0D;dY07ZQA@2KT6@0Wh]e0:FGRP2[
XIL0[JRQ0:j^Z`2_/[40/KFb0:ne[`2f_;T0]ko00;[1a02maLP0`<S;0<S>d@3?f=X0dM[K0=SOh03P
jNP0ing_0>cal@3fmoH0o_gm0?ooo`3no_h0o_gm0?gmo@3no_d0o_kn0?kno@3no_h0o_ko0?_mo03h
nOT0m?Gg0>_^l03UjN/0hnKY0=cOhP3Hg=d0d=CE0<[<b`2l_K/0[jbY0:^SW02VUHH0QZ=Q07jXCP1M
^CD0:n4G01[c3A800?l02Oooool@003o0080D91h5@2P8?000`3@D7P0oh000?n0000<0?n000030;Ph
]02P8?00X23`00X0X23`00<0N5Rd052@N01@T7P04P00o`3=ooooo`002_oooolD003o000N01Sa2`1C
_RH0ZH5A0::0GP2YT7X0/Yn>0;^YW@35]jl0b[fl0<Jo_`2o_;h0a<?50<G6a03=clh0dMOF0=[Qg`3M
hN80i^g/0>_^k`3em_H0n__k0?gmo@3nood0o_kn0?kmo@3moOd0o_kn0?kooP3no_d0oOkn0P3moOh0
3@3fm_T0mOKi0>c[k`3Xi^T0gMWM0<k8b@2m/Z/0/:6E0:RBO`2WR6@0PZE705c7<P0dj1X05`00o`09
oooooa@00?l000<0D91h0:0Pl02P8?00402P8?0?0?n000X0X23`00<0D91h003o0000o`005@00o`3=
ooooo`002_oooolH003o000V02gQ5@1MaRd0B/PV086dB`2>/5X0R[1O08jhJP2L^W`0aJnH0<B`W`39
^Jd0cL6g0=37`P3FcLT0e/g;0>?Jf03[hn00jn?R0>_Ti03/i><0kNCR0?3Vi03^i>80jMkL0>;Ed@3L
c/L0g<_10=K2]P3@^JP0bk6K09?0L`2?^FP0S[EO07nfCP1Lb3<0;N<I03?W700Km0dJ003o00Wooooo
6000o`03052@N0`0X23`303@D7P00`2h>;@0X23`0:0Pl0040:0Pl0<0D91h00<0:<Pl003o0000o`00
6000o`3=ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
\
\>"],
  ImageRangeCache->{{{0, 399}, {177.5, 0}} -> {-0.107233, -0.0446483, \
0.0105626, 0.0105626}, {{10.125, 98.1875}, {173.25, 4.1875}} -> {-17.1322, \
-6.21784, 1.692, 1.692}, {{107, 195.062}, {173.25, 4.1875}} -> {-181.044, \
-6.21784, 1.692, 1.692}, {{203.875, 291.938}, {173.25, 4.1875}} -> {-393.575, \
-30.3891, 1.93047, 1.93047}, {{300.75, 388.812}, {173.25, 4.1875}} -> \
{-580.589, -30.3891, 1.93047, 1.93047}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Coke\>", "\<Coke Light\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.00667408 [
[.27273 -0.0125 -14 -12 ]
[.27273 -0.0125 14 0 ]
[.72727 -0.0125 -32 -12 ]
[.72727 -0.0125 32 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1482 -12 -4.5 ]
[-0.0125 .1482 0 4.5 ]
[-0.0125 .28168 -12 -4.5 ]
[-0.0125 .28168 0 4.5 ]
[-0.0125 .41516 -12 -4.5 ]
[-0.0125 .41516 0 4.5 ]
[-0.0125 .54864 -12 -4.5 ]
[-0.0125 .54864 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -14 0 ]
[.27273 .63053 14 12 ]
[.72727 .63053 -32 0 ]
[.72727 .63053 32 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -93 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1482 m
.00625 .1482 L
s
[(20)] -0.0125 .1482 1 0 Mshowa
0 .28168 m
.00625 .28168 L
s
[(40)] -0.0125 .28168 1 0 Mshowa
0 .41516 m
.00625 .41516 L
s
[(60)] -0.0125 .41516 1 0 Mshowa
0 .54864 m
.00625 .54864 L
s
[(80)] -0.0125 .54864 1 0 Mshowa
.125 Mabswid
0 .04809 m
.00375 .04809 L
s
0 .08146 m
.00375 .08146 L
s
0 .11483 m
.00375 .11483 L
s
0 .18157 m
.00375 .18157 L
s
0 .21494 m
.00375 .21494 L
s
0 .24831 m
.00375 .24831 L
s
0 .31505 m
.00375 .31505 L
s
0 .34842 m
.00375 .34842 L
s
0 .38179 m
.00375 .38179 L
s
0 .44853 m
.00375 .44853 L
s
0 .4819 m
.00375 .4819 L
s
0 .51527 m
.00375 .51527 L
s
0 .58201 m
.00375 .58201 L
s
0 .61538 m
.00375 .61538 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1482 m
1 .1482 L
s
.99375 .28168 m
1 .28168 L
s
.99375 .41516 m
1 .41516 L
s
.99375 .54864 m
1 .54864 L
s
.125 Mabswid
.99625 .04809 m
1 .04809 L
s
.99625 .08146 m
1 .08146 L
s
.99625 .11483 m
1 .11483 L
s
.99625 .18157 m
1 .18157 L
s
.99625 .21494 m
1 .21494 L
s
.99625 .24831 m
1 .24831 L
s
.99625 .31505 m
1 .31505 L
s
.99625 .34842 m
1 .34842 L
s
.99625 .38179 m
1 .38179 L
s
.99625 .44853 m
1 .44853 L
s
.99625 .4819 m
1 .4819 L
s
.99625 .51527 m
1 .51527 L
s
.99625 .58201 m
1 .58201 L
s
.99625 .61538 m
1 .61538 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .49883 L
.27273 .49883 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .49883 L
.27273 .49883 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .09352 L
.72727 .09352 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .09352 L
.72727 .09352 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .19801 L
.45455 .19801 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .19801 L
.45455 .19801 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00ooooool/ooooo`?o0000H_ooool00?oooooo;oooool00ol0003ooooo
ooooo`1Oooooo`00Moooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0007Oooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0
0008ooooo`Go000000?oooooo`000?l000000ol00002ooooo`Co000000?oooooo`000?l000001?l0
0002ooooo`;o0000E_ooool007Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`1gooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
Doooool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00003ooooo`Go0000M?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000?ooooo1Ol00008ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000F?oo
ool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000007Cooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Hooooo`00MOoo
ool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o0000
MOooool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o
00002Oooool00ol0003oooooooooo`02ooooo`?o00001?ooool5o`000004ooooool0003o0000o`00
00;ooooo1?l0001Fooooo`00M_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
07cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`00Moooool3o`00
00Oooooo0_l0001oooooo`?o00001oooool2o`00013ooooo0ol00005ooooo`03o`000?oooooooooo
00Oooooo0_l00005ooooo`03o`000?oooooooooo05Kooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000Rooooool00000
G000000Cooooo`008_ooool00`00003oooooooooo`1Looooo`03o`000?oooooooooo09[ooooo00<0
0000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`006_ooool2o`0000Kooooo00<00000
ooooooooool0G?ooool00ol0003oooooooooo`2Jooooo`0300000?oooooooooo05_ooooo00<00000
ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`3o
oooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooo
oooooooo00001Ooooooo000005`000004oooool001Wooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Iooooo`04o`000?oooooooooo
o`0000Gooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`006_ooool2o`00
00Kooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`<000007Oooool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo0`00000Mooooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Looooo`03o`000000003ooooo
01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003o
X23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003o
X23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo@000000m
oj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooo
ooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo0003
00000?nP8?3oX23`03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0G?ooool0
0`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo0`00000Mooooo`0300000?ooO`3oogl003co
ogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_o
X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003ooooo
ooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003ooooo
ooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`1L
ooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0P
l?nP8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
00000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Looooo`03
00000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00
>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`004_ooool5o`0000?ooooo0_l00006ooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo
05cooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Cooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Gooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00?ooooo0`00000Mooooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000
ooooooooool06oooool3000001?ooooo000Booooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo05cooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo05cooooo
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Cooooo`?o00001?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo
000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool0G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0G?oo
ool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<00000ooooooooool0G?ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0G?ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo0`00000Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003o
ooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07?ooool00ol00000
0000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003ooooooooo
o`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`1Loooo
o`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP
8?00>onP8?000`00003oooooooooo`1Looooo`0300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl0?`00001Nooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool0
0`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003o
X23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`<000007Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<0
0000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000R
ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2J
ooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oooo
ooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo0003
00000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00
??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool0
0`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003o
X23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooooooo
o`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool3000001gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2J
ooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07?ooool00ol000000000ooooo`0B
ooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oooo
ooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo0003
00000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00
??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool0
0`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003o
X23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Dooooo`?o00000oooool2o`0000Kooooo00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Eooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`03ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??oo
O`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`004_ooool5o`0000;ooooo00Co0000oooooooooooo00001Ooo
ool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_oo
ool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool001;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00005ooooo`<00000
7Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00
>onP8?000`00003oooooooooo`0Kooooo`<000004oooool001?ooooo00?o0000ooooool000000ooo
ool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00
??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`005?ooool2o`0000?ooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool001Gooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool3000001gooooo00<00000oomo0?oo
O`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
00000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00
>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`<000007Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
00000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00
>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool0
0`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo0`00000Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
00000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00
>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004oooool3
o`0000Cooooo0_l00006ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`00
0`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool001;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Gooooo0`00000Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01_ooooo0`00000Cooooo`004_oo
ool4o`0000?ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool001;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00
??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`004oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Dooooo`;o00001?ooool2o`0000Kooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool3000001gooooo00<00000oomo0?oo
O`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
00000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo0`00000Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooood000000W?ooool00`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool0nOooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool0nOooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool0nOooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOoo
ool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo0`00003iooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07?ooool0
0ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`3iooooo`0300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`3iooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`3iooooo`0300000?nP8?3oX23`03_oX23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`3iooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`3iooooo`0300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`3ioooo
o`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`3iooooo`0300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`3iooooo`030000
0?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004ooo
ool3o`0000Cooooo0_l00006ooooo`0300000?oooooooooo0?Wooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo0?Wooooo
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`<0
0000nOooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01_ooooo0`00000Cooooo`00
4oooool3o`0000?ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`3iooooo`03
00000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
4_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00`00
003oooooooooo`3iooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001Oooool00`00003oooooooooo`3iooooo`0300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004oooool3o`0000Cooooo0_l00006oooo
o`0300000?oooooooooo0?Wooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo0?Wooooo00<00000oj0Pl?nP
8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo0?Wooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`0300000?oooooooooo0?Wooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo0?Wooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo0?Wooooo00<00000oj0Pl?nP8?00>onP8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo0?Wo
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo0?Wooooo00<00000oj0Pl?nP8?00>onP8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`<00000nOooool00`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000
ooooooooool0nOooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool0nOooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool0nOooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOoo
ool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool0nOooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOoooolo0000
01oooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0oooooomHooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo0?ooooooF?ooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`0300000?oooooooooo09[ooooo00<0
0000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`008_ooool3000005cooooo00<00000
ooooooooool0V_ooool00`00003oooooooooo`1Jooooo`03o`000000003ooooo01;ooooo000Roooo
ool00000G000000Cooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00ooooool/ooooo`?o0000H_ooool00?oooooo;oooool00ol0003ooooo
ooooo`1Oooooo`00Moooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0007Oooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0
0008ooooo`Go000000?oooooo`000?l000000ol00002ooooo`Co000000?oooooo`000?l000001?l0
0002ooooo`;o0000E_ooool007Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`1gooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
Doooool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00003ooooo`Go0000M?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000?ooooo1Ol00008ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000F?oo
ool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000007Cooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Hooooo`00MOoo
ool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o0000
MOooool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o
00002Oooool00ol0003oooooooooo`02ooooo`?o00001?ooool5o`000004ooooool0003o0000o`00
00;ooooo1?l0001Fooooo`00M_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
07cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`00Moooool3o`00
00Oooooo0_l0001oooooo`?o00001oooool2o`00013ooooo0ol00005ooooo`03o`000?oooooooooo
00Oooooo0_l00005ooooo`03o`000?oooooooooo05Kooooo003ooooooi7ooooo003ooooooi7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -9.28183, \
0.00636706, 0.433635}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2d Gaussian classification (RB plane)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(which = {1, 3};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Show[gobj1, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Show[gobj2, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[g1, g2, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{g1, g2}], \ imSize, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.15686 .04706 Mdot
.30196 .09412 Mdot
.63922 .29804 Mdot
.58824 .22745 Mdot
.6902 .36471 Mdot
.30588 .10588 Mdot
.75294 .27843 Mdot
.66667 .31765 Mdot
.29412 .10588 Mdot
.5451 .17255 Mdot
.44706 .03137 Mdot
.61569 .31373 Mdot
.63529 .32157 Mdot
.81176 .0549 Mdot
.63137 .24314 Mdot
.58039 .19216 Mdot
.41569 .01569 Mdot
.84706 .05882 Mdot
.49804 .07059 Mdot
.57255 .2 Mdot
.43922 .00392 Mdot
.79608 .07059 Mdot
.57255 .02745 Mdot
.61961 .32941 Mdot
.40392 0 Mdot
.62745 .04706 Mdot
.52549 .02353 Mdot
.8549 .8 Mdot
.59216 .28235 Mdot
.61176 .02353 Mdot
.87059 .13725 Mdot
.49804 .01569 Mdot
.58431 .25882 Mdot
.54118 .02353 Mdot
.64706 .04314 Mdot
.69412 .03529 Mdot
.81176 .79216 Mdot
.57255 .27059 Mdot
.59608 .02353 Mdot
.65882 .03922 Mdot
.61569 .03137 Mdot
.67451 .61961 Mdot
.39216 .02745 Mdot
.63922 .03529 Mdot
.68235 .0549 Mdot
.55686 .04314 Mdot
.76078 .72157 Mdot
.4 .02353 Mdot
.60784 .01961 Mdot
.67059 .05098 Mdot
.24314 .03529 Mdot
.84314 .80392 Mdot
.38824 .08627 Mdot
.61176 .02353 Mdot
.69412 .05098 Mdot
.55686 .46275 Mdot
.83529 .71373 Mdot
.12941 .04706 Mdot
.55294 .02353 Mdot
.68627 .03529 Mdot
.81569 .69412 Mdot
.58431 .01961 Mdot
.79608 .82353 Mdot
.43922 .02353 Mdot
.6549 .03529 Mdot
.48627 .09412 Mdot
.91373 .84706 Mdot
.87451 .82353 Mdot
.51765 .06275 Mdot
.54902 .01569 Mdot
.68627 .05098 Mdot
.92549 .89804 Mdot
.47843 .06275 Mdot
.83137 .84706 Mdot
.3098 0 Mdot
.59216 .02353 Mdot
.63529 .05098 Mdot
.90196 .90588 Mdot
.49412 .07843 Mdot
.80784 .82745 Mdot
.43922 .01176 Mdot
.63529 .02353 Mdot
.83137 .70196 Mdot
.90196 .90588 Mdot
.89412 .83529 Mdot
.65882 .59216 Mdot
.4549 .01176 Mdot
.62745 .03137 Mdot
.9098 .87843 Mdot
.88235 .88235 Mdot
.72157 .65098 Mdot
.66275 .51765 Mdot
.56078 .01961 Mdot
.62745 .03529 Mdot
.88627 .87843 Mdot
.8902 .88627 Mdot
.76078 .62353 Mdot
.57647 .48627 Mdot
.73725 .05098 Mdot
.61176 .02745 Mdot
.89804 .89412 Mdot
.88235 .88235 Mdot
.41569 .10196 Mdot
.75294 .72549 Mdot
.7451 .03529 Mdot
.62745 .02745 Mdot
.88627 .87843 Mdot
.87451 .88627 Mdot
.52549 .03137 Mdot
.81569 .83137 Mdot
.70196 .03922 Mdot
.63137 .02745 Mdot
.87059 .86667 Mdot
.89804 .88235 Mdot
.48627 .04314 Mdot
.8 .82745 Mdot
.60392 .00784 Mdot
.53333 .01176 Mdot
.82353 .67059 Mdot
.8902 .81961 Mdot
.87451 .84706 Mdot
.8 .77255 Mdot
.5098 .01176 Mdot
.79216 .04706 Mdot
.56078 .06667 Mdot
.88627 .86275 Mdot
.87059 .86667 Mdot
.78824 .71373 Mdot
.3451 .08235 Mdot
.72549 .03137 Mdot
.63529 .03922 Mdot
.88235 .87843 Mdot
.61569 .06667 Mdot
.56863 .06667 Mdot
.81569 .84314 Mdot
.67843 .03529 Mdot
.80392 .04314 Mdot
.85882 .83137 Mdot
.62353 .07843 Mdot
.84706 .8549 Mdot
.81961 .79608 Mdot
.53333 0 Mdot
.76078 .03529 Mdot
.59608 .03137 Mdot
.88627 .78431 Mdot
.61569 .04314 Mdot
.49412 .03137 Mdot
.75294 .78431 Mdot
.65098 .02353 Mdot
.81176 .03922 Mdot
.84706 .83529 Mdot
.65098 .05882 Mdot
.84706 .84706 Mdot
.71765 .67059 Mdot
.55294 .00784 Mdot
.73333 .04314 Mdot
.58039 .02353 Mdot
.61961 .18824 Mdot
.61569 .03137 Mdot
.51373 .03922 Mdot
.8 .83137 Mdot
.64706 .03137 Mdot
.8 .03922 Mdot
.87059 .84706 Mdot
.65882 .05882 Mdot
.87059 .80392 Mdot
.76078 .69412 Mdot
.35686 .18824 Mdot
.72157 .03922 Mdot
.83922 .05882 Mdot
.64706 .0902 Mdot
.6549 .04314 Mdot
.64706 .1451 Mdot
.8 .82745 Mdot
.58039 .01569 Mdot
.77647 .04314 Mdot
.84314 .83922 Mdot
.6549 .06667 Mdot
.55294 .00784 Mdot
.66667 .32549 Mdot
.54118 .47059 Mdot
.63529 .02353 Mdot
.81961 .04314 Mdot
.64706 .41961 Mdot
.16078 .02353 Mdot
.8549 .84314 Mdot
.64706 .60784 Mdot
.43922 .13333 Mdot
.7451 .04314 Mdot
.83529 .7098 Mdot
.66275 .05882 Mdot
.61569 .03137 Mdot
.65098 .13333 Mdot
.73333 .76471 Mdot
.56863 .01176 Mdot
.78824 .03922 Mdot
.86275 .8549 Mdot
.72157 .60784 Mdot
.53333 .00392 Mdot
.43529 .18431 Mdot
.36863 .27451 Mdot
.63137 .02745 Mdot
.82745 .05098 Mdot
.66275 .05882 Mdot
.89412 .8 Mdot
.76078 .58431 Mdot
.66275 .64314 Mdot
.62745 .63529 Mdot
.73333 .03529 Mdot
.8902 .88627 Mdot
.23529 .03922 Mdot
.61176 .04314 Mdot
.68235 .0549 Mdot
.73725 .78039 Mdot
.55686 .02353 Mdot
.78039 .03529 Mdot
.83922 .62353 Mdot
.8902 .87451 Mdot
.54902 .01569 Mdot
.5451 .21176 Mdot
.47059 .44314 Mdot
.60392 .02745 Mdot
.81176 .0549 Mdot
.62745 .0549 Mdot
.87843 .88235 Mdot
.83529 .75686 Mdot
.69412 .64314 Mdot
.45882 .50196 Mdot
.71373 .04314 Mdot
.88627 .89412 Mdot
.88235 .81569 Mdot
.51765 .19608 Mdot
.75294 .04706 Mdot
.77255 .81961 Mdot
.20392 .00392 Mdot
.78039 .03922 Mdot
.74902 .09412 Mdot
.87059 .86667 Mdot
.60392 .02745 Mdot
.51373 .02745 Mdot
.56078 .61569 Mdot
.56078 .02745 Mdot
.78431 .05882 Mdot
.62353 .09412 Mdot
.87059 .87059 Mdot
.86275 .83137 Mdot
.80392 .67451 Mdot
.76471 .72549 Mdot
.63922 .06275 Mdot
.87843 .8902 Mdot
.87843 .86275 Mdot
.68627 .48627 Mdot
.72549 .04706 Mdot
.80392 .84314 Mdot
.16863 .01961 Mdot
.76078 .04706 Mdot
.81961 .05882 Mdot
.89412 .87843 Mdot
.63922 .02353 Mdot
.67451 .05098 Mdot
.52549 .58039 Mdot
.47843 .01176 Mdot
.73725 .06275 Mdot
.44706 .20784 Mdot
.8549 .77647 Mdot
.83529 .80392 Mdot
.58039 .21961 Mdot
.50588 .27059 Mdot
.64314 .0549 Mdot
.85882 .86667 Mdot
.86667 .86275 Mdot
.51765 .21961 Mdot
.54118 .00392 Mdot
.79608 .83529 Mdot
.1451 .01569 Mdot
.63137 .07059 Mdot
.77255 .04706 Mdot
.56078 .18431 Mdot
.62745 .02353 Mdot
.70588 .02745 Mdot
.79608 .86667 Mdot
.03529 0 Mdot
.76471 .03529 Mdot
.43529 .1451 Mdot
.34902 .03922 Mdot
.75686 .47451 Mdot
.50588 .05098 Mdot
.21569 .22353 Mdot
.44314 .01176 Mdot
.86275 .8902 Mdot
.85098 .85098 Mdot
.80392 .68627 Mdot
.53725 .03529 Mdot
.81176 .61176 Mdot
.32157 .35686 Mdot
.63922 .04706 Mdot
.74902 .04314 Mdot
.59216 .08627 Mdot
.63922 .05098 Mdot
.52549 .01176 Mdot
.8 .83529 Mdot
.05098 .00784 Mdot
.74902 .04706 Mdot
.75294 .06667 Mdot
.29804 .03922 Mdot
.58431 .02353 Mdot
.6902 .02745 Mdot
.69412 .76863 Mdot
.16078 .00392 Mdot
.6902 .49412 Mdot
.84314 .83922 Mdot
.88235 .82353 Mdot
.83529 .79216 Mdot
.52157 .01569 Mdot
.43922 .24706 Mdot
.41176 .02353 Mdot
.61569 .2 Mdot
.87843 .83922 Mdot
.65098 .0549 Mdot
.53725 .01961 Mdot
.73333 .61569 Mdot
.24314 .31373 Mdot
.68235 .04314 Mdot
.46275 .04314 Mdot
.28235 .11373 Mdot
.63529 .03529 Mdot
.52549 .01176 Mdot
.73725 .80392 Mdot
.00392 0 Mdot
.76471 .04706 Mdot
.85882 .82745 Mdot
.86667 .85098 Mdot
.76863 .44314 Mdot
.68235 .03529 Mdot
.49804 .6 Mdot
.21176 0 Mdot
.87059 .8902 Mdot
.76471 .11373 Mdot
.18824 .03137 Mdot
.51373 .03137 Mdot
.47843 .04314 Mdot
.30196 .14118 Mdot
.43137 .01961 Mdot
.68235 .55686 Mdot
.88627 .84706 Mdot
.55294 .07843 Mdot
.51765 .01176 Mdot
.64706 .60392 Mdot
.03922 .00392 Mdot
.6902 .03922 Mdot
.66667 .31373 Mdot
.7098 .72157 Mdot
.63137 .02745 Mdot
.51373 .01176 Mdot
.78824 .8549 Mdot
.08235 .00392 Mdot
.88235 .65098 Mdot
.32941 .24706 Mdot
.86275 .77647 Mdot
.83529 .81176 Mdot
.67059 .02353 Mdot
.48627 .5451 Mdot
.23137 .00392 Mdot
.36471 .08235 Mdot
.80392 .71765 Mdot
.87059 .85098 Mdot
.56078 .02353 Mdot
.53725 .03922 Mdot
.31765 .37647 Mdot
.43137 .03137 Mdot
.86275 .83922 Mdot
.84706 .79216 Mdot
.51765 .06275 Mdot
.53725 .03137 Mdot
.6549 .65882 Mdot
.00392 .00392 Mdot
.75294 .04314 Mdot
.89412 .78431 Mdot
.86667 .86275 Mdot
.7451 .36863 Mdot
.50196 .01961 Mdot
.72941 .82745 Mdot
.15294 .00392 Mdot
.79216 .80784 Mdot
.88627 .85098 Mdot
.86667 .85882 Mdot
.44314 .06275 Mdot
.67451 .02353 Mdot
.63529 .56078 Mdot
.24706 0 Mdot
.83137 .81569 Mdot
.81569 .72157 Mdot
.85098 .8549 Mdot
.56078 .01961 Mdot
.59216 .07451 Mdot
.08235 .11765 Mdot
.50588 .03137 Mdot
.75294 .04314 Mdot
.90196 .9098 Mdot
.60392 .0549 Mdot
.51373 .00784 Mdot
.6549 .70588 Mdot
0 0 Mdot
.76078 .03922 Mdot
.76863 .07451 Mdot
.86275 .85882 Mdot
.83137 .82745 Mdot
.51373 .01961 Mdot
.72157 .82353 Mdot
.17647 .00392 Mdot
.65882 .18039 Mdot
.32549 .05098 Mdot
.86275 .78824 Mdot
.58039 .02745 Mdot
.67451 .03922 Mdot
.26275 .05882 Mdot
.41176 .02745 Mdot
.76471 .04706 Mdot
.8902 .8902 Mdot
.85098 .83137 Mdot
.53333 .01961 Mdot
.50196 .04706 Mdot
.00392 0 Mdot
.54118 .01961 Mdot
.75686 .0549 Mdot
.94902 .79216 Mdot
.58039 .1451 Mdot
.52549 .01569 Mdot
.72941 .81569 Mdot
.09804 .00392 Mdot
.78431 .03529 Mdot
.56863 .06667 Mdot
.75294 .08235 Mdot
.84706 .81176 Mdot
.52549 .01569 Mdot
.43529 .52549 Mdot
.34118 .01569 Mdot
.72157 .03137 Mdot
.84706 .8549 Mdot
.84706 .81961 Mdot
.56471 .01961 Mdot
.69412 .04706 Mdot
.34902 .36471 Mdot
.59216 .03922 Mdot
.74902 .04706 Mdot
.80392 .4 Mdot
.59216 .05882 Mdot
.52157 .01176 Mdot
.6549 .51765 Mdot
.02745 .00392 Mdot
.57255 .01961 Mdot
.73725 .04314 Mdot
.82353 .07059 Mdot
.84706 .80392 Mdot
.51765 .02353 Mdot
.76863 .85882 Mdot
.28235 .01961 Mdot
.75686 .03529 Mdot
.8549 .8549 Mdot
.39216 .22353 Mdot
.4549 .35686 Mdot
.56078 .02353 Mdot
.42745 .39608 Mdot
.19608 .01176 Mdot
.76471 .04314 Mdot
.71765 .23529 Mdot
.43529 .18824 Mdot
.53333 .01176 Mdot
.70196 .05098 Mdot
.05882 .08627 Mdot
.45098 .04706 Mdot
.74118 .04706 Mdot
.81961 .0549 Mdot
.59608 .0549 Mdot
.49804 .00784 Mdot
.56863 .40392 Mdot
.16863 .00392 Mdot
.61569 .01569 Mdot
.85882 .80392 Mdot
.24706 .04706 Mdot
.80784 .82353 Mdot
.50588 .01569 Mdot
.68627 .78039 Mdot
.31373 .01961 Mdot
.76471 .04706 Mdot
.32941 .35686 Mdot
.77255 .75686 Mdot
.23529 .19608 Mdot
.63137 .04706 Mdot
.23922 .07451 Mdot
.59216 .36863 Mdot
.73725 .05098 Mdot
.72157 .12941 Mdot
.50196 .38824 Mdot
.51765 .01176 Mdot
.6902 .06275 Mdot
.2 .00392 Mdot
.55686 .01961 Mdot
.70588 .21176 Mdot
.23529 .02353 Mdot
.7451 .47059 Mdot
.49804 .01569 Mdot
.62353 .63529 Mdot
.27451 .02745 Mdot
.62353 .02353 Mdot
.82353 .77255 Mdot
.86275 .87843 Mdot
.80392 .82745 Mdot
.44706 .02353 Mdot
.58431 .67843 Mdot
.27843 .00784 Mdot
.72549 .03922 Mdot
.84314 .85098 Mdot
.83529 .85098 Mdot
.66275 .62353 Mdot
.67451 .05098 Mdot
.63529 .74902 Mdot
.50196 .04314 Mdot
.69412 .01961 Mdot
.20392 .06275 Mdot
.64314 .47059 Mdot
.51373 .01176 Mdot
.65098 .15686 Mdot
.22745 .01569 Mdot
.57647 .02745 Mdot
.85882 .81176 Mdot
.84314 .86275 Mdot
.84314 .83529 Mdot
.4902 .01569 Mdot
.61569 .68235 Mdot
.19216 .00784 Mdot
.63529 .02745 Mdot
.83529 .80392 Mdot
.83922 .8549 Mdot
.8 .83137 Mdot
.40784 .00784 Mdot
.33333 .3451 Mdot
.38431 .01176 Mdot
.65098 .01961 Mdot
.10196 .11765 Mdot
.82353 .85098 Mdot
.47451 .08627 Mdot
.67843 .07451 Mdot
.66275 .74902 Mdot
.51373 .01961 Mdot
.71373 .04314 Mdot
.85882 .86667 Mdot
.58039 .07059 Mdot
.49804 .00392 Mdot
.63529 .0549 Mdot
.14118 .00392 Mdot
.55686 .01961 Mdot
.65882 .13333 Mdot
.85098 .8549 Mdot
.82745 .74902 Mdot
.47843 .00784 Mdot
.63922 .7098 Mdot
.18824 .00784 Mdot
.57255 .01569 Mdot
.64706 .17255 Mdot
.47059 .24314 Mdot
.81569 .83529 Mdot
.36078 .00392 Mdot
.45098 .53725 Mdot
.30588 .01176 Mdot
.66275 .02353 Mdot
.80392 .76078 Mdot
.83922 .86275 Mdot
.50196 .03529 Mdot
.50588 .04706 Mdot
.44314 .43137 Mdot
.48627 .02353 Mdot
.70196 .03922 Mdot
.83529 .85098 Mdot
.21176 .03137 Mdot
.52157 .00392 Mdot
.6902 .05882 Mdot
.17255 .00784 Mdot
.55686 .02745 Mdot
.70588 .03922 Mdot
.67059 .23137 Mdot
.6 .05882 Mdot
.51765 .01569 Mdot
.42353 .0902 Mdot
.14902 .00392 Mdot
.56078 .03137 Mdot
.56863 .0902 Mdot
.66275 .61569 Mdot
.80784 .82353 Mdot
.47451 .00784 Mdot
.71765 .82353 Mdot
.2 .00392 Mdot
.56078 .02745 Mdot
.83137 .84706 Mdot
.84314 .84706 Mdot
.62353 .5098 Mdot
.85098 .70196 Mdot
.18039 .0549 Mdot
.40784 .01569 Mdot
.67843 .05882 Mdot
.83922 .75686 Mdot
.81961 .84706 Mdot
.53725 .01176 Mdot
.57647 .0549 Mdot
.16471 .1098 Mdot
.50196 .03922 Mdot
.70196 .04314 Mdot
.14902 .06667 Mdot
.58431 .07843 Mdot
.50588 .00392 Mdot
.63137 .06275 Mdot
.13333 .00392 Mdot
.54118 .01961 Mdot
.3451 .04706 Mdot
.85882 .87451 Mdot
.55294 .05882 Mdot
.46667 .00392 Mdot
.74118 .80392 Mdot
.15686 0 Mdot
.55686 .02745 Mdot
.84314 .85098 Mdot
.83529 .86275 Mdot
.79608 .81569 Mdot
.45098 .00784 Mdot
.4902 .53333 Mdot
.3451 .02353 Mdot
.61961 .02745 Mdot
.37255 .12941 Mdot
.82353 .84314 Mdot
.5098 .02745 Mdot
.4549 .01176 Mdot
.42745 .4 Mdot
.47451 .03529 Mdot
.68235 .03137 Mdot
.85098 .83529 Mdot
.54118 .09804 Mdot
.51765 .01569 Mdot
.58824 .04314 Mdot
.13333 0 Mdot
.50588 .03529 Mdot
.73333 .46667 Mdot
.84706 .87059 Mdot
.60784 .06275 Mdot
.4902 .01176 Mdot
.47451 .09412 Mdot
.18431 .00392 Mdot
.52941 .01569 Mdot
.81569 .8549 Mdot
.36471 .39608 Mdot
.52941 .06667 Mdot
.45882 .00784 Mdot
.75686 .87059 Mdot
.32549 .01176 Mdot
.57255 .03137 Mdot
.67059 .64706 Mdot
.83529 .85882 Mdot
.80392 .81176 Mdot
.45098 .01176 Mdot
.34118 .05098 Mdot
.38431 .02353 Mdot
.6902 .04314 Mdot
.84314 .86275 Mdot
.60784 .07059 Mdot
.50588 .01176 Mdot
.59608 .05098 Mdot
.12157 .00392 Mdot
.44314 .00784 Mdot
.58431 .04314 Mdot
.81569 .69804 Mdot
.62353 .05098 Mdot
.50588 .01176 Mdot
.57255 .05098 Mdot
.13725 .00392 Mdot
.53725 .02745 Mdot
.81176 .83922 Mdot
.61569 .58824 Mdot
.59608 .05882 Mdot
.4902 .01961 Mdot
.77647 .82353 Mdot
.26275 .00784 Mdot
.56471 .02745 Mdot
.83137 .84314 Mdot
.74902 .51373 Mdot
.56078 .05098 Mdot
.4549 .01961 Mdot
.47451 .42353 Mdot
.32157 .01176 Mdot
.62353 .03529 Mdot
.85098 .85098 Mdot
.71373 .07451 Mdot
.63922 .55686 Mdot
.5098 .02353 Mdot
.21176 .00784 Mdot
.42353 .02353 Mdot
.68627 .03529 Mdot
.70196 .12941 Mdot
.58824 .06667 Mdot
.49412 .01569 Mdot
.55294 .03922 Mdot
.12549 .00784 Mdot
.4902 .00784 Mdot
.75294 .67843 Mdot
.8549 .8549 Mdot
.48235 .08235 Mdot
.47451 .00784 Mdot
.42745 .0549 Mdot
.24314 .01569 Mdot
.55686 .02353 Mdot
.83922 .86275 Mdot
.75294 .10196 Mdot
.53333 .0549 Mdot
.45098 .00392 Mdot
.47451 .56863 Mdot
.27843 .00784 Mdot
.59608 .02745 Mdot
.67451 .15686 Mdot
.15294 .02353 Mdot
.57255 .04314 Mdot
.46275 .02353 Mdot
.21176 0 Mdot
.36078 .01569 Mdot
.69412 .04706 Mdot
.78039 .0902 Mdot
.56863 .57255 Mdot
.52549 .03529 Mdot
.61176 .03922 Mdot
.10588 .00784 Mdot
.4902 .01569 Mdot
.59608 .13725 Mdot
.67451 .28627 Mdot
.78824 .77647 Mdot
.4902 .01569 Mdot
.51765 .02353 Mdot
.21961 .01176 Mdot
.54118 .01961 Mdot
.71373 .59608 Mdot
.08235 .04706 Mdot
.76078 .75294 Mdot
.44706 .00392 Mdot
.56078 .59216 Mdot
.26275 .00392 Mdot
.60392 .04314 Mdot
.65882 .21569 Mdot
.84314 .85882 Mdot
.09412 .05098 Mdot
.45098 .01176 Mdot
.33725 .26667 Mdot
.35686 .01569 Mdot
.66667 .05882 Mdot
.77255 .08627 Mdot
.82353 .8549 Mdot
.52157 .02745 Mdot
.53725 .03137 Mdot
.11765 0 Mdot
.43922 .01961 Mdot
.71373 .06667 Mdot
.16863 .01176 Mdot
.81961 .84706 Mdot
.47059 .00784 Mdot
.53725 .03529 Mdot
.13725 .00392 Mdot
.37255 .00784 Mdot
.18431 .04314 Mdot
.87059 .86667 Mdot
.81176 .83922 Mdot
.46667 .01176 Mdot
.36863 .05098 Mdot
.23922 .00784 Mdot
.57647 .02745 Mdot
.84706 .8549 Mdot
.83922 .87059 Mdot
.8 .82745 Mdot
.37647 .00392 Mdot
.47059 .49804 Mdot
.30196 .00392 Mdot
.59608 .03922 Mdot
.65098 .11765 Mdot
.83529 .86667 Mdot
.46275 .32941 Mdot
.4549 .01176 Mdot
.23922 .00784 Mdot
.4 .00784 Mdot
.67843 .05098 Mdot
.80784 .81961 Mdot
.80392 .84314 Mdot
.49412 .01569 Mdot
.56863 .02745 Mdot
.11765 .00784 Mdot
.4902 .01569 Mdot
.74902 .54118 Mdot
.87451 .8902 Mdot
.82745 .84314 Mdot
.44314 .01176 Mdot
.51373 .02745 Mdot
.2 .00392 Mdot
.55294 .02353 Mdot
.85098 .86275 Mdot
.85882 .87843 Mdot
.81569 .84314 Mdot
.45882 .01569 Mdot
.51765 .54902 Mdot
.13725 0 Mdot
.6 .03137 Mdot
.3098 .31765 Mdot
.81961 .76471 Mdot
.79216 .82745 Mdot
.48627 .03137 Mdot
.12157 .03137 Mdot
.36471 .01569 Mdot
.64314 .04706 Mdot
.8549 .88235 Mdot
.47451 .13725 Mdot
.40784 .11373 Mdot
.56863 .05098 Mdot
.28627 .00784 Mdot
.42745 .01961 Mdot
.70588 .06667 Mdot
.88627 .90588 Mdot
.04706 .05098 Mdot
.5098 .01961 Mdot
.57647 .02745 Mdot
.17647 0 Mdot
.44706 .00392 Mdot
.68235 .07059 Mdot
.85098 .87843 Mdot
.51373 .33725 Mdot
.52157 .03922 Mdot
.53333 .02745 Mdot
.12549 .00392 Mdot
.4902 .00784 Mdot
.80784 .52157 Mdot
.86275 .70588 Mdot
.52549 .1098 Mdot
.4902 .02745 Mdot
.45882 .01569 Mdot
.20392 .00784 Mdot
.52549 .00784 Mdot
.41961 .36078 Mdot
.72157 .13333 Mdot
.55294 .04706 Mdot
.4902 .04314 Mdot
.61961 .56863 Mdot
.12941 .00392 Mdot
.56863 .02745 Mdot
.88627 .90588 Mdot
.41961 .41961 Mdot
.63922 .63137 Mdot
.50196 .03137 Mdot
.14902 .11765 Mdot
.14902 .01569 Mdot
.58824 .03529 Mdot
.87059 .89804 Mdot
.84706 .87059 Mdot
.79608 .83137 Mdot
.52941 .03922 Mdot
.12941 .02353 Mdot
.2549 .01569 Mdot
.59608 .0549 Mdot
.86667 .89412 Mdot
.82353 .85882 Mdot
.44706 .09804 Mdot
.35686 .00392 Mdot
.24314 .00392 Mdot
.32941 0 Mdot
.67059 .0549 Mdot
.73333 .31765 Mdot
.75686 .7098 Mdot
.49804 .04314 Mdot
.32157 .01176 Mdot
.22353 .00784 Mdot
.40392 .00392 Mdot
.58039 .10588 Mdot
.8 .09412 Mdot
.60392 .0549 Mdot
.48627 .03529 Mdot
.58431 .03529 Mdot
.12549 .00392 Mdot
.47451 .01569 Mdot
.83529 .85098 Mdot
.32549 .14118 Mdot
.52549 .05098 Mdot
.51373 .04314 Mdot
.51373 .02745 Mdot
.18431 .00392 Mdot
.50196 .00784 Mdot
.83922 .87059 Mdot
.8549 .87843 Mdot
.34902 .34902 Mdot
.49804 .03137 Mdot
.4902 .25098 Mdot
.24706 .00784 Mdot
.52157 .00392 Mdot
.85882 .88235 Mdot
.83529 .86275 Mdot
.81569 .84314 Mdot
.49804 .02745 Mdot
.41569 .40784 Mdot
.27451 .01176 Mdot
.53725 .00784 Mdot
.64314 .31373 Mdot
.78824 .6902 Mdot
.47843 .10196 Mdot
.5098 .04314 Mdot
.15294 .01961 Mdot
.32549 .01176 Mdot
.58039 .03922 Mdot
.80784 .08235 Mdot
.60784 .09412 Mdot
.53333 .03922 Mdot
.58039 .04314 Mdot
.30588 0 Mdot
.27843 .01176 Mdot
.27843 .02353 Mdot
.83529 .08627 Mdot
.50588 .09412 Mdot
.51373 .01961 Mdot
.67843 .06275 Mdot
.21176 .00392 Mdot
.47059 .02353 Mdot
.83137 .83922 Mdot
.84706 .5098 Mdot
.34118 .38039 Mdot
.49804 .01961 Mdot
.64706 .05098 Mdot
.17647 .00392 Mdot
.4902 .04706 Mdot
.83529 .8549 Mdot
.86275 .87059 Mdot
.82745 .86275 Mdot
.47451 .01961 Mdot
.54902 .03137 Mdot
.17255 .00784 Mdot
.38431 .03137 Mdot
.78039 .67059 Mdot
.71765 .72549 Mdot
.26275 .27451 Mdot
.5098 .03137 Mdot
.44706 .03922 Mdot
.24314 .01176 Mdot
.51765 .01176 Mdot
.71373 .08235 Mdot
.0902 .03137 Mdot
.03137 .03529 Mdot
.48627 .02745 Mdot
.38824 .35294 Mdot
.22745 0 Mdot
.54118 .01569 Mdot
.72157 .08235 Mdot
.39608 .42353 Mdot
.18039 .20784 Mdot
.51373 .03137 Mdot
.03922 .00392 Mdot
.16863 .00392 Mdot
.32941 .03137 Mdot
.72941 .10196 Mdot
.80392 .84314 Mdot
.03529 .01176 Mdot
.5451 .03137 Mdot
.22745 .01176 Mdot
.41569 .03922 Mdot
.81176 .81961 Mdot
.75294 .07451 Mdot
.78431 .8549 Mdot
.47059 .05882 Mdot
.64314 .04706 Mdot
.18431 .00392 Mdot
.36471 .03922 Mdot
.81176 .83922 Mdot
.73725 .07451 Mdot
.33333 .41961 Mdot
.52157 .03529 Mdot
.6549 .06667 Mdot
.16471 .00784 Mdot
.23529 .00784 Mdot
.57647 .21569 Mdot
.68627 .27059 Mdot
.83137 .85882 Mdot
.52157 .02353 Mdot
.59608 .03529 Mdot
.15686 .00392 Mdot
.53725 .03529 Mdot
.23137 .02353 Mdot
.72157 .41176 Mdot
.81569 .85098 Mdot
.51765 .02745 Mdot
.47451 .01961 Mdot
.24314 .00784 Mdot
.55294 .02745 Mdot
.72549 .73333 Mdot
.67059 .17647 Mdot
.80784 .84314 Mdot
.48627 .02745 Mdot
.45882 .38824 Mdot
.2902 .00392 Mdot
.54902 .06667 Mdot
.86667 .88235 Mdot
.35294 .05098 Mdot
.80392 .84706 Mdot
.48235 .03137 Mdot
.01569 0 Mdot
.35294 .02353 Mdot
.78824 .79608 Mdot
.84314 .87059 Mdot
.68627 .71765 Mdot
.80784 .8549 Mdot
.56078 .03922 Mdot
.27059 .01569 Mdot
.47843 .3098 Mdot
.8 .82745 Mdot
.8 .66667 Mdot
.81961 .8549 Mdot
.71373 .6902 Mdot
.60784 .04314 Mdot
.15294 .00392 Mdot
.37647 .06275 Mdot
.36863 .11765 Mdot
.76078 .07451 Mdot
.81961 .85882 Mdot
.52941 .05098 Mdot
.61569 .03529 Mdot
.26275 .11373 Mdot
.47059 .02745 Mdot
.73725 .75686 Mdot
.78039 .08627 Mdot
.80392 .83922 Mdot
.48627 .02745 Mdot
.57255 .03529 Mdot
.08627 .00392 Mdot
.51373 .04314 Mdot
.69412 .55294 Mdot
.73333 .07843 Mdot
.46667 .15686 Mdot
.49804 .03529 Mdot
.50196 .02353 Mdot
.16863 .00784 Mdot
.54118 .03529 Mdot
.71373 .07843 Mdot
.61569 .61961 Mdot
.43529 .09804 Mdot
.43922 .01569 Mdot
.56078 .46275 Mdot
.23922 .00392 Mdot
.42745 .30196 Mdot
.39216 .36078 Mdot
.8549 .87843 Mdot
.71765 .76078 Mdot
.43137 .01569 Mdot
.00392 .00392 Mdot
.28627 .00784 Mdot
.8 .83922 Mdot
.87451 .87843 Mdot
.83529 .87059 Mdot
.78824 .81569 Mdot
.51373 .01569 Mdot
.18431 .00784 Mdot
.36078 .01961 Mdot
.06667 .07059 Mdot
.75686 .10588 Mdot
.36471 .45882 Mdot
.51373 .0549 Mdot
.52157 .01569 Mdot
.29804 .03137 Mdot
.41176 .02353 Mdot
.81961 .83529 Mdot
.78431 .08627 Mdot
.49804 .12157 Mdot
.49412 .02745 Mdot
.57255 .03137 Mdot
.08627 .00392 Mdot
.35294 .04314 Mdot
.59608 .09412 Mdot
.76471 .0902 Mdot
.39608 .07451 Mdot
.50196 .03529 Mdot
.57255 .03137 Mdot
.08627 0 Mdot
.43137 .02353 Mdot
.22353 .01961 Mdot
.40784 .3098 Mdot
.15294 .18824 Mdot
.48627 .02745 Mdot
.57255 .03529 Mdot
.0902 .00392 Mdot
.52941 .03529 Mdot
.56471 .61176 Mdot
.83922 .86667 Mdot
.79608 .82745 Mdot
.49412 .04314 Mdot
.46667 .03922 Mdot
.07451 0 Mdot
.52941 .03922 Mdot
.84314 .86275 Mdot
.86275 .87451 Mdot
.7451 .75294 Mdot
.45882 .02353 Mdot
.20784 .11373 Mdot
.2 .00784 Mdot
.62745 .42353 Mdot
.58824 .24314 Mdot
.55686 .2 Mdot
.4902 .10588 Mdot
.44314 .00784 Mdot
.00392 0 Mdot
.27059 .01176 Mdot
.78824 .81961 Mdot
.71765 .06275 Mdot
.36078 .07451 Mdot
.4 .07843 Mdot
.49412 .01569 Mdot
.04706 .00392 Mdot
.31373 .00784 Mdot
.72941 .76863 Mdot
.71373 .06667 Mdot
.08627 .12549 Mdot
.12941 .00784 Mdot
.48627 .01176 Mdot
.2549 .01569 Mdot
.36078 .01569 Mdot
.8 .83529 Mdot
.70588 .05882 Mdot
.67843 .73333 Mdot
.06275 .00784 Mdot
.4902 .01176 Mdot
.25098 .00392 Mdot
.38431 .01961 Mdot
.76471 .79216 Mdot
.68235 .0549 Mdot
.81961 .87059 Mdot
.13333 .01569 Mdot
.50588 .02353 Mdot
.37255 .03137 Mdot
.41176 .01961 Mdot
.81569 .83529 Mdot
.71373 .07843 Mdot
.79216 .84706 Mdot
.39608 .05098 Mdot
.52941 .03137 Mdot
.11373 0 Mdot
.45098 .03137 Mdot
.55294 .20392 Mdot
.72549 .07451 Mdot
.68235 .7451 Mdot
.47843 .03529 Mdot
.53333 .02353 Mdot
.05882 0 Mdot
.48235 .03922 Mdot
.65098 .06667 Mdot
.71373 .09804 Mdot
.78039 .82353 Mdot
.44706 .01569 Mdot
.53725 .03137 Mdot
.05098 0 Mdot
.50588 .04314 Mdot
.65882 .05882 Mdot
.66667 .11765 Mdot
.82353 .8549 Mdot
.44314 .01569 Mdot
.44706 .09412 Mdot
.0549 .00392 Mdot
.50588 .02745 Mdot
.69804 .07451 Mdot
.65098 .10196 Mdot
.82353 .86275 Mdot
.4902 .02745 Mdot
.13333 .08235 Mdot
.06275 .00392 Mdot
.5098 .03137 Mdot
.6902 .06275 Mdot
.43137 .08235 Mdot
.82745 .86667 Mdot
.5451 .02745 Mdot
.00392 .00392 Mdot
.19216 .01176 Mdot
.54902 .3098 Mdot
.70196 .05882 Mdot
.20392 .2549 Mdot
.82745 .86667 Mdot
.52941 .02353 Mdot
.05882 .00392 Mdot
.26275 .00392 Mdot
.8 .83137 Mdot
.71373 .06667 Mdot
.83137 .87059 Mdot
.81569 .86275 Mdot
.5451 .03137 Mdot
.27843 .01961 Mdot
.3098 .01176 Mdot
.78431 .82745 Mdot
.71373 .07059 Mdot
.83922 .87451 Mdot
.81961 .86275 Mdot
.54118 .03529 Mdot
.30196 .00784 Mdot
.35686 .01569 Mdot
.76078 .80392 Mdot
.73725 .07059 Mdot
.83922 .87843 Mdot
.81569 .86275 Mdot
.55294 .03137 Mdot
.21176 0 Mdot
.38039 .01961 Mdot
.14118 .14118 Mdot
.74118 .06667 Mdot
.83922 .87843 Mdot
.66667 .66275 Mdot
.58431 .04314 Mdot
.32157 .00784 Mdot
.43137 .02745 Mdot
.30196 .0549 Mdot
.51373 .10196 Mdot
.80392 .79608 Mdot
.47451 .06667 Mdot
.61569 .0549 Mdot
.36078 .22353 Mdot
.4549 .03922 Mdot
.59216 .07843 Mdot
.36078 .39608 Mdot
.54902 .16471 Mdot
.47843 .02745 Mdot
.63137 .07843 Mdot
.09804 .01176 Mdot
.45882 .03922 Mdot
.62745 .07451 Mdot
.82353 .86275 Mdot
.62353 .07451 Mdot
.50588 .02745 Mdot
.58431 .22745 Mdot
.1098 .05098 Mdot
.47451 .04314 Mdot
.64314 .0549 Mdot
.8549 .8902 Mdot
.56078 .08235 Mdot
.52549 .02745 Mdot
.64706 .49804 Mdot
.04314 .00392 Mdot
.47843 .04706 Mdot
.67843 .06275 Mdot
.83922 .87843 Mdot
.13725 .01176 Mdot
.53725 .02745 Mdot
.47059 .35686 Mdot
.03137 0 Mdot
.46275 .03529 Mdot
.67843 .0549 Mdot
.84314 .88235 Mdot
.30588 .36078 Mdot
.52941 .01961 Mdot
.4 .32157 Mdot
.03137 .00392 Mdot
.47451 .03922 Mdot
.67843 .05882 Mdot
.84314 .88235 Mdot
.72549 .76863 Mdot
.53725 .03529 Mdot
.07451 .03529 Mdot
.02353 0 Mdot
.47843 .03922 Mdot
.68627 .05882 Mdot
.67451 .72549 Mdot
.81176 .85098 Mdot
.5451 .03529 Mdot
.09412 .04706 Mdot
.02353 0 Mdot
.49804 .04314 Mdot
.66667 .05882 Mdot
.06275 .13725 Mdot
.8 .84314 Mdot
.54118 .03137 Mdot
.11765 .02353 Mdot
.02745 .00392 Mdot
.50588 .02745 Mdot
.51765 .09412 Mdot
.66275 .71373 Mdot
.80392 .84706 Mdot
.5451 .03137 Mdot
.22353 .01569 Mdot
.08627 0 Mdot
.54118 .02745 Mdot
.1098 .06667 Mdot
.84314 .87451 Mdot
.80392 .84706 Mdot
.56863 .03922 Mdot
.33725 .02745 Mdot
.20392 .01569 Mdot
.59216 .05098 Mdot
.67451 .71373 Mdot
.81569 .76078 Mdot
.80392 .84706 Mdot
.58039 .04706 Mdot
.41569 .00784 Mdot
.27451 .01176 Mdot
.61569 .05098 Mdot
.83529 .87059 Mdot
.53333 .21961 Mdot
.8 .86275 Mdot
.57647 .04314 Mdot
.49804 .01569 Mdot
.29804 .01176 Mdot
.61569 .05882 Mdot
.83922 .87451 Mdot
.15294 .03529 Mdot
.67059 .74902 Mdot
.55686 .03529 Mdot
.47451 .01176 Mdot
.30196 .00784 Mdot
.60392 .07843 Mdot
.83137 .87059 Mdot
.6 .65882 Mdot
.69804 .76078 Mdot
.55294 .02353 Mdot
.4 .00784 Mdot
.32549 .01176 Mdot
.57647 .0902 Mdot
.85098 .87059 Mdot
.83529 .87843 Mdot
.8 .83922 Mdot
.54902 .02745 Mdot
.32941 .00392 Mdot
.36078 .01961 Mdot
.53333 .12157 Mdot
.59608 .37255 Mdot
.83529 .87451 Mdot
.79608 .84706 Mdot
.52941 .03137 Mdot
.2902 .00784 Mdot
.35294 .00784 Mdot
.54118 .20784 Mdot
.63529 .1098 Mdot
.83137 .87451 Mdot
.4902 .59216 Mdot
.4902 .16471 Mdot
.27451 .00392 Mdot
.36078 .01961 Mdot
.60392 .36078 Mdot
.51765 .10588 Mdot
.81569 .8549 Mdot
.60784 .68235 Mdot
.83137 .76863 Mdot
.27843 .00392 Mdot
.33333 .01176 Mdot
.64314 .49412 Mdot
.15294 .11373 Mdot
.83529 .85098 Mdot
.78039 .83137 Mdot
.55686 .52941 Mdot
.07059 .00392 Mdot
.34902 .01961 Mdot
.55294 .27843 Mdot
.52941 .56863 Mdot
.6549 .5451 Mdot
.78039 .83137 Mdot
.33333 .2902 Mdot
.13725 .00392 Mdot
.35686 .02353 Mdot
.49804 .12941 Mdot
.6902 .73725 Mdot
.51765 .21569 Mdot
.78039 .83137 Mdot
.20392 .14118 Mdot
.14118 .00392 Mdot
.38824 .05098 Mdot
.43922 .09804 Mdot
.81961 .86667 Mdot
.4902 .14902 Mdot
.78039 .83137 Mdot
.24314 .1451 Mdot
.14902 .01569 Mdot
.38039 .02353 Mdot
.24706 .03922 Mdot
.83529 .87451 Mdot
.19216 .03137 Mdot
.78039 .83137 Mdot
.43137 .33725 Mdot
.1451 .01176 Mdot
.39216 .01961 Mdot
.1098 .04314 Mdot
.83922 .83137 Mdot
.07451 .09412 Mdot
.77255 .82745 Mdot
.62745 .56471 Mdot
.15294 .01176 Mdot
.38431 .02745 Mdot
.2902 .3098 Mdot
.64706 .49412 Mdot
.54118 .61176 Mdot
.77647 .82745 Mdot
.72549 .68627 Mdot
.14118 .00392 Mdot
.33333 .02353 Mdot
.56863 .61961 Mdot
.58039 .20392 Mdot
.72157 .77647 Mdot
.78039 .83137 Mdot
.78431 .76078 Mdot
.1451 .00784 Mdot
.30588 .01961 Mdot
.7451 .79608 Mdot
.69412 .12941 Mdot
.81961 .86667 Mdot
.76078 .79608 Mdot
.76078 .75294 Mdot
.14118 .00784 Mdot
.34902 .03137 Mdot
.77255 .81569 Mdot
.78824 .10196 Mdot
.84314 .88235 Mdot
.61176 .57647 Mdot
.72157 .7451 Mdot
.1451 .00392 Mdot
.39216 .03137 Mdot
.77647 .82353 Mdot
.87059 .11373 Mdot
.87059 .89804 Mdot
.47059 .30196 Mdot
.69412 .74118 Mdot
.14118 .00392 Mdot
.38431 .01961 Mdot
.77647 .82353 Mdot
.95686 .15686 Mdot
.89804 .92157 Mdot
.5098 .16078 Mdot
.70588 .76471 Mdot
.14902 .00784 Mdot
.37255 .02353 Mdot
.78824 .83529 Mdot
.99216 .21569 Mdot
.92157 .93725 Mdot
.60392 .10196 Mdot
.68235 .75294 Mdot
.15294 .00784 Mdot
.36863 .02353 Mdot
.80392 .83529 Mdot
1 .25098 Mdot
.94118 .95686 Mdot
.66667 .06667 Mdot
.63529 .71765 Mdot
.15294 .00784 Mdot
.37647 .02745 Mdot
.85098 .82353 Mdot
.97647 .23137 Mdot
.93333 .95294 Mdot
.72549 .06667 Mdot
.67059 .7451 Mdot
.15686 .00784 Mdot
.38431 .02745 Mdot
.8549 .74118 Mdot
.99216 .27451 Mdot
.9451 .95686 Mdot
.76078 .08235 Mdot
.69412 .76471 Mdot
.15686 .00392 Mdot
.39608 .01961 Mdot
.71373 .56471 Mdot
.99608 .25882 Mdot
1 .95294 Mdot
.74902 .07843 Mdot
.60784 .6902 Mdot
.15686 .00392 Mdot
.41176 .02353 Mdot
.40392 .3098 Mdot
.98431 .19608 Mdot
.87059 .5098 Mdot
.74118 .07451 Mdot
.51765 .6 Mdot
.1451 0 Mdot
.43137 .03137 Mdot
.17647 .17647 Mdot
.9098 .12941 Mdot
.83137 .21961 Mdot
.6902 .03922 Mdot
.70588 .77647 Mdot
.13725 0 Mdot
.47059 .04706 Mdot
.24314 .29412 Mdot
.80784 .0902 Mdot
.8 .11373 Mdot
.63529 .00392 Mdot
.73333 .81569 Mdot
.13725 0 Mdot
.47843 .04706 Mdot
.62353 .6902 Mdot
.75686 .07843 Mdot
.79216 .09804 Mdot
.76078 .1098 Mdot
.61569 .70196 Mdot
.27843 .00392 Mdot
.59216 .15686 Mdot
.73725 .79216 Mdot
.79608 .08235 Mdot
.83137 .09804 Mdot
.83922 .18431 Mdot
.66667 .7451 Mdot
.28235 .00392 Mdot
.6 .13333 Mdot
.78431 .82745 Mdot
.90196 .13333 Mdot
.91373 .11373 Mdot
.65882 .04706 Mdot
.61176 .6902 Mdot
.27843 .00784 Mdot
.57255 .07059 Mdot
.78431 .80392 Mdot
.96863 .18039 Mdot
.97647 .16471 Mdot
.5451 .00392 Mdot
.57255 .65882 Mdot
.26275 .00392 Mdot
.50196 .0549 Mdot
.65882 .50196 Mdot
1 .23922 Mdot
.96078 .26275 Mdot
.58431 .01176 Mdot
.51765 .61569 Mdot
.27059 0 Mdot
.70196 .39608 Mdot
.63529 .18824 Mdot
1 .25098 Mdot
.97647 .58039 Mdot
.6549 .03529 Mdot
.5098 .6 Mdot
.28627 .00784 Mdot
.48235 .27451 Mdot
.74118 .10588 Mdot
.97255 .18824 Mdot
.9098 .64706 Mdot
.71373 .05882 Mdot
.52941 .61961 Mdot
.27059 .00392 Mdot
.56863 .33725 Mdot
.8 .1098 Mdot
.99216 .20784 Mdot
.90588 .67059 Mdot
.73333 .07843 Mdot
.51765 .60784 Mdot
.27059 .00392 Mdot
.40392 .07843 Mdot
.81176 .13725 Mdot
.99608 .21569 Mdot
.9451 .77647 Mdot
.72941 .07451 Mdot
.48235 .57647 Mdot
.26275 .00392 Mdot
.41569 .02745 Mdot
.73725 .12941 Mdot
.95294 .14902 Mdot
.91373 .75294 Mdot
.73725 .07451 Mdot
.49412 .58431 Mdot
.26275 .00392 Mdot
.44314 .03137 Mdot
.61961 .12549 Mdot
.9098 .11373 Mdot
.73725 .55294 Mdot
.70588 .07843 Mdot
.58431 .67451 Mdot
.28235 .00784 Mdot
.46275 .03529 Mdot
.38431 .0549 Mdot
.88235 .1098 Mdot
.84314 .63529 Mdot
.61569 .06667 Mdot
.60392 .69412 Mdot
.2902 .00392 Mdot
.46667 .03922 Mdot
.16078 .00784 Mdot
.8902 .1098 Mdot
.91373 .52941 Mdot
.52941 .07059 Mdot
.54118 .63529 Mdot
.29412 .00392 Mdot
.43529 .01176 Mdot
.15294 .11765 Mdot
.92941 .13725 Mdot
.8902 .25882 Mdot
.4549 .0902 Mdot
.60392 .68235 Mdot
.31373 0 Mdot
.43529 .01176 Mdot
.3098 .3451 Mdot
.98039 .19216 Mdot
.99608 .31373 Mdot
.55294 .27451 Mdot
.74902 .82353 Mdot
.32941 .00784 Mdot
.42353 .02353 Mdot
.53725 .59608 Mdot
1 .2549 Mdot
1 .32549 Mdot
.78824 .58824 Mdot
.6902 .78824 Mdot
.3098 0 Mdot
.41176 .03922 Mdot
.71765 .77255 Mdot
.98431 .21569 Mdot
.9451 .21176 Mdot
.90196 .77255 Mdot
.58824 .68627 Mdot
.33333 .00392 Mdot
.51373 .13333 Mdot
.78431 .81961 Mdot
.97647 .15294 Mdot
.8902 .12941 Mdot
.8549 .8 Mdot
.60784 .67451 Mdot
.34118 .00392 Mdot
.48235 .05098 Mdot
.84706 .83529 Mdot
.96863 .16078 Mdot
.94118 .18039 Mdot
.82353 .82353 Mdot
.65098 .71373 Mdot
.34902 .00392 Mdot
.4549 .02353 Mdot
.7098 .41176 Mdot
.99608 .22745 Mdot
.98431 .23529 Mdot
.79216 .82745 Mdot
.55686 .58431 Mdot
.39608 .06667 Mdot
.43922 .02353 Mdot
.77647 .12549 Mdot
1 .32941 Mdot
.99608 .26275 Mdot
.78431 .82353 Mdot
.10588 .09804 Mdot
.33333 .00392 Mdot
.47451 .02745 Mdot
.83529 .0902 Mdot
.97647 .30196 Mdot
.99608 .23529 Mdot
.81961 .82745 Mdot
.1098 .06275 Mdot
.19216 .00392 Mdot
.62745 .04314 Mdot
.87843 .11373 Mdot
.98431 .28627 Mdot
.86667 .04314 Mdot
.52941 .13725 Mdot
.18824 .14118 Mdot
.21176 0 Mdot
.65098 .02745 Mdot
.83137 .09804 Mdot
.99216 .23529 Mdot
.84706 .05098 Mdot
.77647 .61569 Mdot
.31765 .03137 Mdot
.39608 .03529 Mdot
.68235 .03529 Mdot
.91765 .10588 Mdot
.99216 .2 Mdot
.64706 .01176 Mdot
.76471 .86667 Mdot
.4902 .03922 Mdot
.12549 0 Mdot
.72941 .0549 Mdot
.98039 .12549 Mdot
.98431 .17647 Mdot
.68627 .0549 Mdot
.81569 .90588 Mdot
.34902 .01961 Mdot
.04706 .00392 Mdot
.70588 .09412 Mdot
.96078 .16863 Mdot
.88627 .2 Mdot
.83529 .67843 Mdot
.85098 .93725 Mdot
.49804 .03529 Mdot
.29804 .01569 Mdot
.73725 .05098 Mdot
.85098 .6902 Mdot
.68627 .27843 Mdot
.75294 .81961 Mdot
.77647 .85882 Mdot
.2902 .00392 Mdot
.42745 .02745 Mdot
.8 .12549 Mdot
.60784 .49412 Mdot
.51765 .37255 Mdot
.40784 .10588 Mdot
.5098 .10588 Mdot
.22745 .00784 Mdot
.66275 .0549 Mdot
.72157 .45882 Mdot
.53333 .55294 Mdot
.45882 .4549 Mdot
.71765 .81569 Mdot
.63137 .07059 Mdot
.18431 .00784 Mdot
.75294 .1098 Mdot
.69412 .69804 Mdot
.60392 .64706 Mdot
.43922 .47451 Mdot
.69412 .82745 Mdot
.6 .03922 Mdot
.19216 .00392 Mdot
.57255 .2902 Mdot
.78039 .79608 Mdot
.81176 .85882 Mdot
.40784 .47451 Mdot
.74902 .87451 Mdot
.40784 0 Mdot
.40784 .12549 Mdot
.47059 .52941 Mdot
.87451 .92549 Mdot
.83137 .85098 Mdot
.39608 .47843 Mdot
.6549 .80392 Mdot
.44706 .07059 Mdot
.5451 .15294 Mdot
.58039 .65882 Mdot
.4549 .46275 Mdot
.54118 .53333 Mdot
.37647 .46275 Mdot
.46667 .10196 Mdot
.3451 .01176 Mdot
.45882 .50588 Mdot
.43137 .41569 Mdot
.43922 .38824 Mdot
.56863 .55686 Mdot
.36078 .43922 Mdot
.53725 .00784 Mdot
.21961 .02353 Mdot
.4902 .49804 Mdot
.4549 .37647 Mdot
.4549 .41569 Mdot
.52157 .43137 Mdot
.35686 .44706 Mdot
.27059 .06275 Mdot
.41176 .47843 Mdot
.4902 .39216 Mdot
.46275 .38824 Mdot
.58039 .60392 Mdot
.52549 .42745 Mdot
.41961 .07843 Mdot
.35294 .01961 Mdot
.37255 .33725 Mdot
.4549 .36471 Mdot
.46667 .42353 Mdot
.45098 .38039 Mdot
.56471 .5451 Mdot
.61176 .05098 Mdot
.35294 .40392 Mdot
.47451 .36471 Mdot
.46667 .36863 Mdot
.44706 .39216 Mdot
.40392 .28627 Mdot
.36078 .45882 Mdot
.43137 .04314 Mdot
.4549 .37255 Mdot
.47451 .37255 Mdot
.44314 .4 Mdot
.50196 .36471 Mdot
.47059 .34902 Mdot
.5451 .07843 Mdot
.35686 .39216 Mdot
.5098 .38431 Mdot
.45882 .36863 Mdot
.43529 .38431 Mdot
.46275 .32549 Mdot
.50588 .38039 Mdot
.41569 .04314 Mdot
.46667 .34902 Mdot
.49412 .38824 Mdot
.43922 .4 Mdot
.45098 .30588 Mdot
.48235 .38824 Mdot
.34118 .36078 Mdot
.37255 .3451 Mdot
.50588 .38039 Mdot
.44706 .39608 Mdot
.43137 .40392 Mdot
.48235 .3451 Mdot
.43137 .2902 Mdot
.42745 .21569 Mdot
.4902 .36471 Mdot
.47843 .36471 Mdot
.53333 .55294 Mdot
.4549 .3098 Mdot
.48235 .34902 Mdot
.32941 .38824 Mdot
.45098 .33725 Mdot
.48627 .35686 Mdot
.42745 .43529 Mdot
.40784 .43137 Mdot
.46667 .37647 Mdot
.43529 .30588 Mdot
.38824 .29804 Mdot
.47059 .35294 Mdot
.47451 .41569 Mdot
.11765 .21961 Mdot
.42353 .33333 Mdot
.47059 .37255 Mdot
.29412 .21961 Mdot
.48627 .37255 Mdot
.4902 .37255 Mdot
.24314 .32941 Mdot
.38824 .38039 Mdot
.4549 .36471 Mdot
.25098 .24706 Mdot
.36471 .27843 Mdot
.4902 .35294 Mdot
.19608 .25882 Mdot
.51373 .5451 Mdot
.47843 .35294 Mdot
.47451 .3451 Mdot
.39608 .02745 Mdot
.48627 .36078 Mdot
.39608 .36863 Mdot
.54118 .56863 Mdot
.4902 .34902 Mdot
.4902 .3451 Mdot
.19608 .21569 Mdot
.38039 .36078 Mdot
.48235 .35686 Mdot
.40784 .32941 Mdot
.57647 .54118 Mdot
.43922 .34902 Mdot
.4 .37255 Mdot
.36863 .32941 Mdot
.4902 .34902 Mdot
.19216 .2549 Mdot
.67451 .62353 Mdot
.47843 .38039 Mdot
.47843 .38824 Mdot
.41961 .25098 Mdot
.40392 .35294 Mdot
.23137 .2902 Mdot
.46667 .25882 Mdot
.46667 .2549 Mdot
.50196 .37255 Mdot
.2 .25098 Mdot
.3451 .35294 Mdot
.51373 .4 Mdot
.51373 .23922 Mdot
.51373 .38431 Mdot
.50196 .37255 Mdot
.39216 .3451 Mdot
.27843 .04706 Mdot
.37255 .27451 Mdot
.36863 .29412 Mdot
.37255 .32941 Mdot
.50588 .30196 Mdot
.47059 .33725 Mdot
.3098 .36863 Mdot
.43137 .44706 Mdot
.50588 .41569 Mdot
.55686 .30196 Mdot
.30588 .27451 Mdot
.52157 .38824 Mdot
.32549 .32157 Mdot
.47451 .47843 Mdot
.43922 .33725 Mdot
.51373 .3098 Mdot
.23529 .28627 Mdot
.52941 .38431 Mdot
.29804 .30588 Mdot
.55686 .17255 Mdot
.46275 .48627 Mdot
.46667 .27451 Mdot
.6902 .63529 Mdot
.53333 .39608 Mdot
.38039 .28627 Mdot
.38039 .42745 Mdot
.5098 .57255 Mdot
.51765 .23922 Mdot
.53333 .34902 Mdot
.58039 .38431 Mdot
.40784 .3098 Mdot
.39608 .45882 Mdot
.52941 .6 Mdot
.47843 .44706 Mdot
.56863 .55294 Mdot
.63529 .40784 Mdot
.45098 .33725 Mdot
.40784 .46275 Mdot
.53725 .59216 Mdot
.50196 .52157 Mdot
.43922 .41961 Mdot
.73725 .47843 Mdot
.47843 .38039 Mdot
.44706 .50196 Mdot
.57255 .57647 Mdot
.53725 .57647 Mdot
.52941 .38431 Mdot
.82745 .65098 Mdot
.53725 .50588 Mdot
.45882 .52941 Mdot
.51765 .50196 Mdot
.56863 .60784 Mdot
.56863 .35294 Mdot
.85098 .77647 Mdot
.58431 .56078 Mdot
.45098 .52549 Mdot
.58039 .64314 Mdot
.55294 .60784 Mdot
.56863 .50196 Mdot
.87451 .83922 Mdot
.7098 .58824 Mdot
.43137 .47843 Mdot
.60784 .68235 Mdot
.61569 .67843 Mdot
.98824 .95294 Mdot
.78039 .83137 Mdot
.54118 .59216 Mdot
.31373 .12157 Mdot
.61569 .6902 Mdot
.75294 .80392 Mdot
.99216 .99216 Mdot
.67059 .6902 Mdot
.46667 .53333 Mdot
.64314 .71373 Mdot
.64706 .71765 Mdot
.99608 .99608 Mdot
.75294 .81176 Mdot
.5451 .61176 Mdot
.66667 .6902 Mdot
.66275 .73725 Mdot
.9451 .96078 Mdot
.88627 .92157 Mdot
.59608 .65098 Mdot
.65882 .64706 Mdot
.69412 .76078 Mdot
.92549 .93725 Mdot
.88235 .92549 Mdot
.54118 .6 Mdot
.69412 .76471 Mdot
.78431 .83922 Mdot
.99216 .99216 Mdot
.8 .8549 Mdot
.17647 .08235 Mdot
.72941 .8 Mdot
.93333 .95686 Mdot
.92157 .95294 Mdot
.4549 .26275 Mdot
.75294 .81569 Mdot
.91373 .94118 Mdot
.91373 .95294 Mdot
.32549 .15294 Mdot
.76471 .82745 Mdot
.98824 .98824 Mdot
.70196 .72157 Mdot
.67059 .52157 Mdot
.96471 .98824 Mdot
.61176 .57255 Mdot
.64706 .44706 Mdot
.75686 .70196 Mdot
.40784 .21176 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.34902 .20392 Mdot
.47451 .38824 Mdot
.8 .68235 Mdot
.74118 .73333 Mdot
.71373 .54118 Mdot
.43137 .44314 Mdot
.77255 .68235 Mdot
.76078 .63529 Mdot
.73725 .75686 Mdot
.79216 .78431 Mdot
.81176 .62745 Mdot
.83922 .80784 Mdot
.79216 .83137 Mdot
.72941 .43922 Mdot
.76863 .61176 Mdot
.61569 .63922 Mdot
.78039 .82745 Mdot
.7451 .51373 Mdot
.72549 .60392 Mdot
.71765 .75294 Mdot
.76078 .80784 Mdot
.71765 .48235 Mdot
.84314 .66667 Mdot
.83922 .81569 Mdot
.78431 .83137 Mdot
.11765 .05098 Mdot
.65098 .5451 Mdot
.76863 .72941 Mdot
.16863 .43137 Mdot
.75686 .81176 Mdot
.71765 .51373 Mdot
.87451 .72549 Mdot
.73725 .68627 Mdot
.79216 .83922 Mdot
.74118 .77255 Mdot
.80392 .63137 Mdot
.87059 .72941 Mdot
.73333 .70588 Mdot
.77647 .82353 Mdot
.33333 .21569 Mdot
.82745 .64706 Mdot
.84706 .70588 Mdot
.72157 .72549 Mdot
.78824 .8549 Mdot
.10196 .05098 Mdot
.82353 .66275 Mdot
.86667 .7098 Mdot
.83922 .81176 Mdot
.79608 .84706 Mdot
.44314 .54118 Mdot
.8 .61961 Mdot
.80784 .81961 Mdot
.83529 .76863 Mdot
.78824 .85098 Mdot
.75294 .81569 Mdot
.7451 .57647 Mdot
.84706 .64706 Mdot
.81176 .71765 Mdot
.66275 .77255 Mdot
.75294 .80392 Mdot
.6902 .45882 Mdot
.79608 .61569 Mdot
.87059 .70196 Mdot
.7451 .67843 Mdot
.80392 .86667 Mdot
.72157 .81569 Mdot
.76863 .6 Mdot
.83922 .63137 Mdot
.83137 .68627 Mdot
.38824 .52157 Mdot
.76471 .82353 Mdot
.6549 .41176 Mdot
.76078 .58431 Mdot
.84706 .67451 Mdot
.86667 .81176 Mdot
.08627 .36863 Mdot
.77255 .83922 Mdot
.69804 .49804 Mdot
.79216 .60392 Mdot
.85882 .69412 Mdot
.80784 .74902 Mdot
.80392 .8549 Mdot
.70588 .76078 Mdot
.84314 .5098 Mdot
.44314 .39608 Mdot
.85098 .66667 Mdot
.79608 .75686 Mdot
.79216 .85882 Mdot
.50588 .62353 Mdot
.70196 .09412 Mdot
.60392 .53333 Mdot
.83922 .6549 Mdot
.8 .74118 Mdot
.78824 .8549 Mdot
.2549 .4 Mdot
.69412 .08235 Mdot
.65098 .54118 Mdot
.83922 .66667 Mdot
.71765 .67059 Mdot
.8 .86667 Mdot
.18431 .3451 Mdot
.61176 .17647 Mdot
.61961 .53725 Mdot
.85098 .68235 Mdot
.82745 .8 Mdot
.80392 .84706 Mdot
.7451 .84314 Mdot
.68235 .51373 Mdot
.77255 .53333 Mdot
.85098 .65882 Mdot
.76471 .64314 Mdot
.72941 .48627 Mdot
.74902 .75294 Mdot
.61569 .47843 Mdot
.75686 .5098 Mdot
.82353 .63922 Mdot
.78431 .61569 Mdot
.67059 .37255 Mdot
.77255 .83529 Mdot
.50588 .32941 Mdot
.72157 .50196 Mdot
.36471 .4 Mdot
.83529 .65882 Mdot
.7098 .61569 Mdot
.78431 .66667 Mdot
.39608 .5098 Mdot
.67843 .50196 Mdot
.7451 .43922 Mdot
.8549 .67059 Mdot
.82353 .6902 Mdot
.71765 .03922 Mdot
.73725 .58431 Mdot
.5451 .44314 Mdot
.70588 .46667 Mdot
.81176 .61961 Mdot
.80392 .63529 Mdot
.71373 .04314 Mdot
.80392 .82745 Mdot
.51765 .55686 Mdot
.68627 .51765 Mdot
.72941 .43922 Mdot
.85098 .68235 Mdot
.76078 .57255 Mdot
.6902 .02353 Mdot
.78039 .71765 Mdot
.56863 .48627 Mdot
.70196 .44314 Mdot
.8 .57647 Mdot
.81176 .63137 Mdot
.7098 .03137 Mdot
.57647 .25882 Mdot
.61176 .68235 Mdot
.64314 .47451 Mdot
.7451 .41569 Mdot
.83529 .68627 Mdot
.83137 .57255 Mdot
.70196 .02745 Mdot
.66275 .03922 Mdot
.66275 .75686 Mdot
.68235 .4549 Mdot
.78039 .50196 Mdot
.46275 .43137 Mdot
.72941 .03922 Mdot
.67059 .03137 Mdot
.20784 .31765 Mdot
.60392 .53333 Mdot
.7098 .37647 Mdot
.8 .60392 Mdot
.80392 .63137 Mdot
.67843 .03922 Mdot
.74902 .59216 Mdot
.10588 .05098 Mdot
.63922 .48235 Mdot
.75686 .43922 Mdot
.53725 .45882 Mdot
.78039 .0549 Mdot
.4 .40392 Mdot
.65098 .19608 Mdot
.73725 .80784 Mdot
.68627 .47843 Mdot
.77255 .49412 Mdot
.51373 .51373 Mdot
.76078 .05098 Mdot
.21961 .42353 Mdot
.68627 .01176 Mdot
.8 .83529 Mdot
.67451 .43137 Mdot
.79608 .54902 Mdot
.81961 .68235 Mdot
.65098 .11765 Mdot
.58431 .33725 Mdot
.41176 .38824 Mdot
.57647 .51765 Mdot
.69412 .37647 Mdot
.80784 .61961 Mdot
.88627 .57647 Mdot
.15294 .38431 Mdot
.63137 .03922 Mdot
.53333 .52941 Mdot
.62745 .53725 Mdot
.71765 .40392 Mdot
.82745 .66275 Mdot
.81176 .06667 Mdot
.80784 .82353 Mdot
.66667 .71373 Mdot
.69804 .76471 Mdot
.62353 .48627 Mdot
.75294 .47451 Mdot
.86667 .70196 Mdot
.8 .05098 Mdot
.70196 .68627 Mdot
.66667 .08235 Mdot
.70588 .81569 Mdot
.64706 .50588 Mdot
.76863 .55686 Mdot
.85098 .72157 Mdot
.7098 .39216 Mdot
.72157 .79216 Mdot
.57255 .02353 Mdot
.47451 .60784 Mdot
.64706 .47451 Mdot
.78431 .57647 Mdot
.83529 .69804 Mdot
.12941 .41961 Mdot
.21176 .38431 Mdot
.51373 .03922 Mdot
.57255 .67843 Mdot
.67059 .46275 Mdot
.78039 .59216 Mdot
.84706 .68235 Mdot
.67843 .58039 Mdot
.69412 .85882 Mdot
.43137 .01569 Mdot
.77255 .84706 Mdot
.67059 .42353 Mdot
.8 .61176 Mdot
.72157 .23137 Mdot
.7451 .41961 Mdot
.77255 .8549 Mdot
.4902 .04706 Mdot
.65882 .70196 Mdot
.67843 .38824 Mdot
.78824 .61176 Mdot
.82353 .06667 Mdot
.7098 .05098 Mdot
.78431 .85882 Mdot
.38039 .02745 Mdot
.52157 .54118 Mdot
.67843 .39608 Mdot
.80784 .62745 Mdot
.83922 .05882 Mdot
.71765 .04314 Mdot
.79216 .8549 Mdot
.29412 .00392 Mdot
.54902 .54118 Mdot
.69804 .41569 Mdot
.80392 .62745 Mdot
.81569 .05882 Mdot
.71373 .03529 Mdot
.77647 .77255 Mdot
.39216 .01569 Mdot
.56471 .54902 Mdot
.67843 .41176 Mdot
.81569 .64314 Mdot
.75686 .29804 Mdot
.70588 .03529 Mdot
.59216 .42353 Mdot
.54902 .05882 Mdot
.58431 .56078 Mdot
.70588 .4549 Mdot
.82353 .65882 Mdot
.19608 .46275 Mdot
.63137 .12549 Mdot
.52549 .12157 Mdot
.56078 .06275 Mdot
.58431 .56078 Mdot
.69804 .46275 Mdot
.80784 .6549 Mdot
.12941 .49804 Mdot
.51373 .43922 Mdot
.51765 .11373 Mdot
.52549 .02353 Mdot
.58824 .56078 Mdot
.71765 .49804 Mdot
.81176 .64706 Mdot
.46667 .69804 Mdot
.08235 .36471 Mdot
.52157 .1098 Mdot
.5451 .02353 Mdot
.58431 .55686 Mdot
.71373 .50588 Mdot
.80392 .64706 Mdot
.71373 .76471 Mdot
.32549 .53333 Mdot
.52549 .10196 Mdot
.49804 .00784 Mdot
.59216 .56863 Mdot
.70588 .5098 Mdot
.8 .63529 Mdot
.78039 .7098 Mdot
.77647 .78039 Mdot
.52549 .08627 Mdot
.52157 .03137 Mdot
.5451 .53333 Mdot
.71373 .52549 Mdot
.79608 .63137 Mdot
.80784 .67451 Mdot
.7098 .58431 Mdot
.53725 .09804 Mdot
.59216 .08235 Mdot
.52549 .51373 Mdot
.71765 .52549 Mdot
.80392 .63529 Mdot
.85882 .62353 Mdot
.72941 .45882 Mdot
.5451 .09804 Mdot
.58431 .15686 Mdot
.52549 .50196 Mdot
.73725 .54118 Mdot
.80392 .64314 Mdot
.71373 .24314 Mdot
.63529 .15294 Mdot
.54902 .08235 Mdot
.58824 .2902 Mdot
.50196 .47843 Mdot
.73725 .55294 Mdot
.8 .63529 Mdot
.75686 .10196 Mdot
.68235 .06275 Mdot
.56471 .08235 Mdot
.65098 .50588 Mdot
.50196 .48235 Mdot
.72549 .54902 Mdot
.80392 .63137 Mdot
.78039 .08235 Mdot
.66275 .05098 Mdot
.57647 .08235 Mdot
.60392 .58039 Mdot
.4902 .47451 Mdot
.72157 .5451 Mdot
.81569 .65098 Mdot
.73725 .0902 Mdot
.60784 .21176 Mdot
.56863 .06667 Mdot
.5098 .53333 Mdot
.48235 .46667 Mdot
.72157 .54118 Mdot
.80392 .64314 Mdot
.70588 .23529 Mdot
.32941 .25882 Mdot
.56078 .06275 Mdot
.68235 .73725 Mdot
.44314 .46275 Mdot
.69804 .52941 Mdot
.78431 .62745 Mdot
.73725 .3098 Mdot
.66275 .34118 Mdot
.49804 .0902 Mdot
.47843 .60784 Mdot
.65882 .70196 Mdot
.68235 .54118 Mdot
.78431 .61569 Mdot
.73725 .50196 Mdot
.63922 .04314 Mdot
.52941 .34118 Mdot
.3098 .50196 Mdot
.72941 .78039 Mdot
.69804 .56078 Mdot
.79216 .63137 Mdot
.50588 .56863 Mdot
.69412 .05882 Mdot
.35294 .42745 Mdot
.62745 .81176 Mdot
.70588 .78431 Mdot
.71765 .58039 Mdot
.76863 .60784 Mdot
.20784 .45882 Mdot
.63137 .07843 Mdot
.37647 .52549 Mdot
.35686 .58039 Mdot
.54902 .66667 Mdot
.7098 .58431 Mdot
.78039 .61961 Mdot
.6549 .70588 Mdot
.61569 .16471 Mdot
.56471 .6902 Mdot
.7098 .87451 Mdot
.40392 .52549 Mdot
.70196 .59216 Mdot
.77255 .61569 Mdot
.81569 .72549 Mdot
.6549 .25882 Mdot
.58039 .49412 Mdot
.72549 .84706 Mdot
.38431 .51765 Mdot
.67451 .6 Mdot
.76078 .59608 Mdot
.81176 .7098 Mdot
.67451 .30588 Mdot
.54902 .07843 Mdot
.70588 .83137 Mdot
.33333 .47059 Mdot
.68235 .60784 Mdot
.7451 .58824 Mdot
.81569 .71373 Mdot
.66275 .30196 Mdot
.63922 .02745 Mdot
.73333 .84314 Mdot
.31765 .45098 Mdot
.68627 .61569 Mdot
.74118 .58824 Mdot
.81961 .72157 Mdot
.6549 .30588 Mdot
.65882 .03529 Mdot
.72157 .83922 Mdot
.34902 .50588 Mdot
.66667 .60784 Mdot
.74118 .57647 Mdot
.82353 .72157 Mdot
.77255 .6 Mdot
.63922 .42353 Mdot
.72157 .85098 Mdot
.56078 .7098 Mdot
.63137 .59216 Mdot
.73333 .56078 Mdot
.8 .69412 Mdot
.73333 .64706 Mdot
.62353 .66275 Mdot
.72549 .82353 Mdot
.53725 .55294 Mdot
.60784 .56471 Mdot
.73725 .55294 Mdot
.80392 .6902 Mdot
.73725 .67451 Mdot
.61961 .60392 Mdot
.72941 .83137 Mdot
.68627 .40784 Mdot
.55686 .52549 Mdot
.72941 .54902 Mdot
.79608 .67059 Mdot
.72941 .67059 Mdot
.61176 .54902 Mdot
.71765 .8549 Mdot
.31373 .21961 Mdot
.55686 .53725 Mdot
.71765 .54118 Mdot
.8 .66667 Mdot
.73725 .69412 Mdot
.61961 .56078 Mdot
.63922 .80784 Mdot
.1098 .21176 Mdot
.56078 .55294 Mdot
.69412 .52157 Mdot
.80392 .67843 Mdot
.7451 .69804 Mdot
.62745 .56863 Mdot
.43922 .32549 Mdot
.52549 .63137 Mdot
.5451 .56078 Mdot
.70196 .52941 Mdot
.8 .67843 Mdot
.75294 .69412 Mdot
.64706 .59608 Mdot
.5451 .05882 Mdot
.56471 .65882 Mdot
.65882 .71373 Mdot
.70196 .54902 Mdot
.79608 .66275 Mdot
.75686 .69804 Mdot
.61569 .57647 Mdot
.59216 .02745 Mdot
.40784 .51373 Mdot
.33333 .44706 Mdot
.68627 .56078 Mdot
.79608 .6549 Mdot
.77647 .73333 Mdot
.56471 .1451 Mdot
.50588 .29804 Mdot
.4 .60784 Mdot
.55294 .67451 Mdot
.66275 .55686 Mdot
.77647 .63922 Mdot
.78824 .72941 Mdot
.67451 .06275 Mdot
.65098 .59608 Mdot
.67451 .83529 Mdot
.16863 .33333 Mdot
.67059 .58824 Mdot
.77255 .63922 Mdot
.78039 .71373 Mdot
.70196 .05882 Mdot
.61176 .05098 Mdot
.7098 .84706 Mdot
.3451 .49804 Mdot
.67059 .61176 Mdot
.74902 .60392 Mdot
.78039 .71373 Mdot
.69804 .09412 Mdot
.66275 .03137 Mdot
.69804 .83529 Mdot
.44706 .59216 Mdot
.63922 .6 Mdot
.73333 .59216 Mdot
.76471 .70588 Mdot
.62353 .27451 Mdot
.6549 .02353 Mdot
.72157 .84314 Mdot
.49804 .63137 Mdot
.61961 .59608 Mdot
.74118 .57647 Mdot
.76471 .69804 Mdot
.73333 .66667 Mdot
.66275 .03922 Mdot
.7098 .7098 Mdot
.69804 .60392 Mdot
.59608 .58039 Mdot
.71373 .56078 Mdot
.75686 .68627 Mdot
.75294 .69804 Mdot
.65098 .03529 Mdot
.52157 .06275 Mdot
.27451 .12941 Mdot
.58039 .58431 Mdot
.7098 .53725 Mdot
.77255 .6902 Mdot
.72941 .69804 Mdot
.66667 .04706 Mdot
.57647 .04314 Mdot
.01569 .18431 Mdot
.52549 .56471 Mdot
.69804 .53333 Mdot
.75294 .66275 Mdot
.7451 .72549 Mdot
.68627 .0549 Mdot
.59216 .04706 Mdot
.02353 .2 Mdot
.76471 .8549 Mdot
.68235 .54118 Mdot
.74118 .61176 Mdot
.75294 .72941 Mdot
.70196 .05098 Mdot
.53725 .49412 Mdot
.57647 .70196 Mdot
.25098 .38824 Mdot
.64314 .54118 Mdot
.69412 .55686 Mdot
.76078 .73333 Mdot
.7098 .04706 Mdot
.41569 .53333 Mdot
.16471 .40392 Mdot
.58431 .72549 Mdot
.61569 .52549 Mdot
.68627 .51765 Mdot
.76471 .75294 Mdot
.72157 .0549 Mdot
.58039 .07843 Mdot
.68627 .85098 Mdot
.23137 .37255 Mdot
.62353 .55294 Mdot
.66275 .49412 Mdot
.56863 .58824 Mdot
.7098 .07451 Mdot
.6549 .03529 Mdot
.67059 .84314 Mdot
.37255 .52157 Mdot
.60392 .5451 Mdot
.68627 .50588 Mdot
.66275 .64706 Mdot
.60784 .14118 Mdot
.63922 .03137 Mdot
.65098 .86275 Mdot
.66667 .78824 Mdot
.60784 .56863 Mdot
.6902 .50196 Mdot
.72549 .67059 Mdot
.78039 .63529 Mdot
.64706 .03529 Mdot
.29412 .62353 Mdot
.63922 .53725 Mdot
.57647 .55294 Mdot
.67059 .48235 Mdot
.66667 .58431 Mdot
.70588 .68235 Mdot
.64706 .03529 Mdot
.03529 .32549 Mdot
.33725 .30588 Mdot
.56471 .55294 Mdot
.66275 .48235 Mdot
.66275 .56471 Mdot
.7098 .69804 Mdot
.67843 .05098 Mdot
.15294 .25882 Mdot
.22353 .29804 Mdot
.52549 .55294 Mdot
.66667 .4902 Mdot
.66667 .57255 Mdot
.73333 .71373 Mdot
.67843 .03529 Mdot
.57255 .5451 Mdot
.32941 .37647 Mdot
.47059 .50196 Mdot
.64314 .48627 Mdot
.64706 .51765 Mdot
.7451 .73725 Mdot
.69412 .04314 Mdot
.60392 .79216 Mdot
.41176 .4902 Mdot
.43137 .43922 Mdot
.63137 .50196 Mdot
.64706 .48627 Mdot
.76078 .74118 Mdot
.68627 .04706 Mdot
.36863 .7451 Mdot
.64706 .76863 Mdot
.42745 .38824 Mdot
.61569 .49412 Mdot
.65882 .44314 Mdot
.77255 .75294 Mdot
.69804 .04706 Mdot
.04706 .37647 Mdot
.27451 .49412 Mdot
.44314 .51765 Mdot
.6 .50588 Mdot
.64314 .43529 Mdot
.76863 .73725 Mdot
.71765 .05882 Mdot
.38431 .45098 Mdot
.28627 .47843 Mdot
.65882 .78824 Mdot
.59608 .53725 Mdot
.63137 .44706 Mdot
.73725 .71765 Mdot
.71373 .04314 Mdot
.56471 .37647 Mdot
.69412 .83529 Mdot
.68627 .82353 Mdot
.56078 .5098 Mdot
.63137 .43529 Mdot
.63529 .58431 Mdot
.60784 .13333 Mdot
.51765 .18039 Mdot
.36078 .4549 Mdot
.67451 .58431 Mdot
.56863 .54902 Mdot
.62353 .42745 Mdot
.62353 .55294 Mdot
.70588 .70588 Mdot
.57647 .06667 Mdot
.56471 .47451 Mdot
.17647 .27451 Mdot
.52941 .53333 Mdot
.61961 .41961 Mdot
.62353 .53333 Mdot
.7098 .72549 Mdot
.46667 .14118 Mdot
.74118 .86275 Mdot
.25882 .36471 Mdot
.4549 .4902 Mdot
.63137 .45098 Mdot
.61569 .51765 Mdot
.7098 .73725 Mdot
.56863 .6549 Mdot
.4902 .73333 Mdot
.1451 .34118 Mdot
.37647 .14902 Mdot
.61961 .49804 Mdot
.66275 .57255 Mdot
.72549 .74118 Mdot
.57255 .62745 Mdot
.20392 .40392 Mdot
.31373 .49804 Mdot
.4549 .36471 Mdot
.63529 .52941 Mdot
.61961 .50588 Mdot
.74118 .7451 Mdot
.51765 .16863 Mdot
.58824 .58431 Mdot
.01569 .29804 Mdot
.43922 .18431 Mdot
.62353 .52157 Mdot
.63137 .50196 Mdot
.7451 .74902 Mdot
.57647 .18039 Mdot
.58039 .40392 Mdot
.5451 .68235 Mdot
.31373 .12157 Mdot
.56863 .48627 Mdot
.63922 .50196 Mdot
.53725 .57647 Mdot
.58824 .21176 Mdot
.51373 .17255 Mdot
.3098 .52157 Mdot
.32157 .21569 Mdot
.54118 .4902 Mdot
.61569 .45882 Mdot
.53725 .53725 Mdot
.7451 .66667 Mdot
.50196 .12941 Mdot
.70588 .83137 Mdot
.30196 .08235 Mdot
.54902 .50196 Mdot
.61569 .46667 Mdot
.66275 .62353 Mdot
.6902 .70196 Mdot
.53725 .18431 Mdot
.44706 .18039 Mdot
.00392 .18824 Mdot
.4902 .48627 Mdot
.61176 .45098 Mdot
.66275 .62745 Mdot
.71373 .73333 Mdot
.53725 .16863 Mdot
.58039 .04706 Mdot
.00392 .19608 Mdot
.47451 .4902 Mdot
.61961 .4549 Mdot
.69412 .65882 Mdot
.69412 .72157 Mdot
.56863 .18431 Mdot
.56863 .03137 Mdot
.00784 .20784 Mdot
.46667 .43922 Mdot
.60392 .48235 Mdot
.66667 .63529 Mdot
.7098 .74902 Mdot
.55294 .2549 Mdot
.59608 .02745 Mdot
.32549 .42745 Mdot
.38824 .23529 Mdot
.58431 .47059 Mdot
.66275 .61176 Mdot
.70588 .71765 Mdot
.43137 .47451 Mdot
.61569 .04706 Mdot
.36863 .45882 Mdot
.32941 .09804 Mdot
.53333 .41569 Mdot
.66275 .6 Mdot
.69412 .7098 Mdot
.21176 .39216 Mdot
.59608 .04314 Mdot
.37647 .48235 Mdot
.47451 .22745 Mdot
.50196 .41569 Mdot
.64706 .56471 Mdot
.69804 .71373 Mdot
.27059 .43137 Mdot
.55686 .04314 Mdot
.35686 .48627 Mdot
.38039 .18039 Mdot
.47451 .41961 Mdot
.65098 .56078 Mdot
.6902 .72941 Mdot
.70196 .68627 Mdot
.52941 .06667 Mdot
.33333 .22745 Mdot
.46667 .26275 Mdot
.50196 .46275 Mdot
.61961 .52549 Mdot
.68235 .71765 Mdot
.68627 .70588 Mdot
.51765 .10196 Mdot
.49804 .03529 Mdot
.26667 .33725 Mdot
.43922 .43529 Mdot
.6 .48627 Mdot
.68627 .7098 Mdot
.65098 .67843 Mdot
.50588 .10588 Mdot
.44706 .20392 Mdot
.24706 .37255 Mdot
.40784 .4 Mdot
.61569 .49412 Mdot
.65098 .65098 Mdot
.68235 .72157 Mdot
.57647 .05882 Mdot
.53333 .53725 Mdot
.32941 .4 Mdot
.3451 .35686 Mdot
.60392 .48627 Mdot
.68235 .6549 Mdot
.66667 .7098 Mdot
.63529 .03922 Mdot
.55294 .07451 Mdot
.00784 .18431 Mdot
.30196 .32157 Mdot
.58431 .50196 Mdot
.6902 .66667 Mdot
.65098 .69412 Mdot
.67059 .05098 Mdot
.60784 .04314 Mdot
.36471 .43922 Mdot
.33725 .31765 Mdot
.55294 .43922 Mdot
.67843 .63529 Mdot
.7098 .73333 Mdot
.65882 .03529 Mdot
.61176 .02745 Mdot
.39608 .47451 Mdot
.39608 .11373 Mdot
.51373 .43137 Mdot
.67059 .59608 Mdot
.69412 .72157 Mdot
.70588 .05882 Mdot
.59608 .03529 Mdot
.48235 .6902 Mdot
.47451 .31765 Mdot
.4902 .44706 Mdot
.6549 .55294 Mdot
.66667 .6902 Mdot
.69412 .06667 Mdot
.50588 .08627 Mdot
.41569 .09412 Mdot
.19216 .32157 Mdot
.38431 .38824 Mdot
.65098 .53725 Mdot
.58431 .56078 Mdot
.65098 .38431 Mdot
.51765 .57647 Mdot
.55686 .49804 Mdot
.00392 .23529 Mdot
.31373 .33333 Mdot
.61569 .50196 Mdot
.53333 .49412 Mdot
.66275 .69804 Mdot
.49804 .62353 Mdot
.63137 .90588 Mdot
.01569 .20392 Mdot
.27843 .29412 Mdot
.59608 .49412 Mdot
.61176 .58824 Mdot
.63137 .67451 Mdot
.34118 .62353 Mdot
.10196 .4 Mdot
.35294 .43529 Mdot
.29804 .27451 Mdot
.58039 .47451 Mdot
.66667 .62745 Mdot
.67059 .72157 Mdot
.03529 .46275 Mdot
.02353 .39216 Mdot
.39608 .46667 Mdot
.39608 .38824 Mdot
.5098 .43529 Mdot
.62353 .57647 Mdot
.68235 .70588 Mdot
.42745 .48627 Mdot
.02353 .36471 Mdot
.40784 .4902 Mdot
.43137 .37647 Mdot
.48235 .43922 Mdot
.60392 .50196 Mdot
.63922 .69804 Mdot
.60392 .0902 Mdot
.52941 .22745 Mdot
.62353 .80784 Mdot
.20784 .3098 Mdot
.40392 .38039 Mdot
.56863 .43529 Mdot
.61176 .60392 Mdot
.66667 .04706 Mdot
.5098 .34902 Mdot
.1451 .3451 Mdot
.28627 .42353 Mdot
.30588 .3098 Mdot
.52157 .4 Mdot
.63529 .64314 Mdot
.65882 .09412 Mdot
.54118 .58039 Mdot
.47843 .13725 Mdot
.32157 .39608 Mdot
.29412 .14118 Mdot
.55294 .43137 Mdot
.65098 .63137 Mdot
.66667 .66275 Mdot
.54902 .19608 Mdot
.52941 .0549 Mdot
.34902 .43137 Mdot
.35686 .29412 Mdot
.53333 .44314 Mdot
.54902 .49804 Mdot
.60784 .6549 Mdot
.55294 .12941 Mdot
.51765 .07059 Mdot
.38431 .46275 Mdot
.41569 .38824 Mdot
.54902 .4902 Mdot
.58431 .5098 Mdot
.64706 .69412 Mdot
.57255 .51765 Mdot
.40784 .32157 Mdot
.46275 .48627 Mdot
.19608 .27451 Mdot
.45882 .42353 Mdot
.5451 .37647 Mdot
.63137 .66275 Mdot
.12157 .48235 Mdot
.61961 .69412 Mdot
.47843 .07843 Mdot
0 .23529 Mdot
.37647 .37255 Mdot
.54902 .39608 Mdot
.67843 .71765 Mdot
.58431 .33333 Mdot
.3451 .58431 Mdot
.55686 .03922 Mdot
.00392 .23529 Mdot
.36078 .33725 Mdot
.52941 .38039 Mdot
.66275 .65882 Mdot
.72157 .07843 Mdot
.56078 .08627 Mdot
.55294 .05882 Mdot
.00392 .2902 Mdot
.26667 .23137 Mdot
.4902 .38824 Mdot
.54118 .50196 Mdot
.68235 .5451 Mdot
.50196 .63922 Mdot
.50196 .09412 Mdot
.00784 .28627 Mdot
.45882 .30196 Mdot
.54902 .47843 Mdot
.58431 .53333 Mdot
.65882 .70588 Mdot
.13333 .54118 Mdot
.4902 .48627 Mdot
.41961 .36078 Mdot
.56863 .31373 Mdot
.51373 .48627 Mdot
.60784 .50588 Mdot
.67843 .72157 Mdot
.40784 .50588 Mdot
.69804 .84314 Mdot
.52549 .03529 Mdot
.3098 .39216 Mdot
.41569 .38824 Mdot
.6 .47059 Mdot
.65882 .70588 Mdot
.67843 .08627 Mdot
.53725 .66667 Mdot
.44314 .13725 Mdot
.29412 .41569 Mdot
.35294 .32549 Mdot
.53333 .38824 Mdot
.55686 .57647 Mdot
.72549 .22745 Mdot
.06275 .39216 Mdot
.46667 .13725 Mdot
.01569 .23137 Mdot
.32157 .27059 Mdot
.47843 .33333 Mdot
.78824 .82353 Mdot
.71765 .0902 Mdot
.52941 .35686 Mdot
.48235 .04706 Mdot
.33333 .47059 Mdot
.32549 .21569 Mdot
.53333 .44706 Mdot
.48235 .4902 Mdot
.60392 .66275 Mdot
.59608 .07451 Mdot
.54902 .03137 Mdot
.06275 .3451 Mdot
.38824 .28235 Mdot
.52549 .47059 Mdot
.60392 .54118 Mdot
.65882 .71373 Mdot
.62353 .12157 Mdot
.55686 .0549 Mdot
.04314 .31373 Mdot
.1098 .27451 Mdot
.49804 .46667 Mdot
.58039 .47059 Mdot
.65098 .6902 Mdot
.54902 .19216 Mdot
.57647 .71765 Mdot
.43137 .10588 Mdot
.00784 .25882 Mdot
.39608 .37647 Mdot
.57255 .45098 Mdot
.63922 .66667 Mdot
.6902 .06667 Mdot
.42745 .54902 Mdot
.67059 .73725 Mdot
.05098 .23922 Mdot
.33333 .27843 Mdot
.51373 .4 Mdot
.5098 .52941 Mdot
.57255 .12941 Mdot
.63137 .73725 Mdot
.45098 .07843 Mdot
.06275 .30196 Mdot
.32941 .08235 Mdot
.52157 .40784 Mdot
.52941 .52941 Mdot
.65098 .71373 Mdot
.53725 .72549 Mdot
.07059 .31373 Mdot
.31765 .4902 Mdot
.47059 .27843 Mdot
.44706 .4 Mdot
.58824 .5451 Mdot
.66275 .71373 Mdot
.19216 .53333 Mdot
.52157 .05882 Mdot
.07451 .37647 Mdot
.17255 .30588 Mdot
.43137 .06667 Mdot
.56863 .45882 Mdot
.59216 .63529 Mdot
.25098 .62745 Mdot
.46275 .59608 Mdot
.31373 .31373 Mdot
.1098 .28235 Mdot
.34118 .17255 Mdot
.53333 .42353 Mdot
.50196 .52549 Mdot
.67059 .1098 Mdot
.48627 .62745 Mdot
.47451 .07451 Mdot
.3451 .43529 Mdot
.32941 .25882 Mdot
.51373 .41176 Mdot
.48627 .48235 Mdot
.58431 .32941 Mdot
.52549 .62353 Mdot
.48627 .0549 Mdot
.38039 .47843 Mdot
.33725 .26275 Mdot
.48627 .40392 Mdot
.53725 .53725 Mdot
.63529 .69804 Mdot
.64314 .73333 Mdot
.40784 .07843 Mdot
.32941 .46275 Mdot
.36863 .01569 Mdot
.38824 .32941 Mdot
.59608 .55294 Mdot
.65098 .70588 Mdot
.6 .67451 Mdot
.65098 .67059 Mdot
.41569 .30588 Mdot
.01569 .17647 Mdot
.39608 .35686 Mdot
.57255 .47451 Mdot
.46667 .5098 Mdot
.24706 .39608 Mdot
.5098 .7451 Mdot
.42745 .07451 Mdot
.25098 .37255 Mdot
.37647 .28627 Mdot
.51765 .42353 Mdot
.46275 .47843 Mdot
.72157 .07059 Mdot
.53725 .68235 Mdot
.52549 .03529 Mdot
.36471 .46275 Mdot
.38039 .06667 Mdot
.51765 .42353 Mdot
.43137 .4549 Mdot
.62745 .68627 Mdot
.57255 .67843 Mdot
.4 .17647 Mdot
.35686 .43137 Mdot
.30196 .01569 Mdot
.36471 .3098 Mdot
.49804 .4549 Mdot
.58824 .66275 Mdot
.57647 .67059 Mdot
.58039 .59216 Mdot
.43137 .02745 Mdot
.00392 .17255 Mdot
.37255 .31765 Mdot
.58431 .51765 Mdot
.44706 .50588 Mdot
.55686 .46667 Mdot
.74118 .8549 Mdot
.4549 .03137 Mdot
.00392 .2 Mdot
.36078 .32157 Mdot
.57647 .47843 Mdot
.43529 .48235 Mdot
.71373 .05098 Mdot
.46667 .77255 Mdot
.5098 .02745 Mdot
.02745 .24706 Mdot
.32549 .2902 Mdot
.54118 .43922 Mdot
.36471 .43922 Mdot
.60392 .35686 Mdot
.60784 .81961 Mdot
.50588 .03137 Mdot
.31765 .41176 Mdot
.43529 .19216 Mdot
.41961 .34902 Mdot
.28627 .33333 Mdot
.57647 .64706 Mdot
.60392 .70196 Mdot
.51765 .03137 Mdot
.3451 .0549 Mdot
.1451 .12157 Mdot
.32941 .28235 Mdot
.4902 .44314 Mdot
.51373 .57255 Mdot
.56863 .13333 Mdot
.55686 .03529 Mdot
.32941 .34118 Mdot
.21176 .34118 Mdot
.34118 .3098 Mdot
.56078 .49412 Mdot
.42745 .48235 Mdot
.70196 .07059 Mdot
.56078 .08235 Mdot
.08235 .40784 Mdot
0 .21961 Mdot
.34118 .13333 Mdot
.5451 .45098 Mdot
.40784 .45098 Mdot
.67843 .67451 Mdot
.67451 .68627 Mdot
.42745 .16863 Mdot
.32941 .45098 Mdot
.48235 .38824 Mdot
.48235 .41569 Mdot
.4902 .4902 Mdot
.50588 .59608 Mdot
.61176 .68235 Mdot
.56471 .44706 Mdot
.05098 .25882 Mdot
.05882 .03529 Mdot
.35686 .30588 Mdot
.44706 .41961 Mdot
.49412 .56471 Mdot
.69412 .06275 Mdot
.44314 .12157 Mdot
.44706 .02353 Mdot
.2549 .35294 Mdot
.35686 .30588 Mdot
.57255 .50588 Mdot
.76863 .87451 Mdot
.68235 .07451 Mdot
.58039 .04706 Mdot
.41961 .12941 Mdot
.11373 .26275 Mdot
.3098 .20784 Mdot
.51373 .40392 Mdot
.44706 .47451 Mdot
.55686 .63529 Mdot
.61176 .03922 Mdot
.28235 .52941 Mdot
.30196 .39216 Mdot
.45098 .13725 Mdot
.47451 .41961 Mdot
.47059 .48627 Mdot
.48235 .58039 Mdot
.59216 .11373 Mdot
.45882 .23922 Mdot
.31373 .07059 Mdot
.2549 .03137 Mdot
.37647 .31765 Mdot
.45098 .43137 Mdot
.53333 .60392 Mdot
.66275 .07451 Mdot
.44706 .31373 Mdot
.44706 .03137 Mdot
.28627 .35686 Mdot
.32549 .28235 Mdot
.49412 .43529 Mdot
.46667 .53333 Mdot
.53333 .29412 Mdot
.04314 .43529 Mdot
.4902 .04706 Mdot
.28627 .38039 Mdot
.31373 .17255 Mdot
.56078 .32157 Mdot
.47843 .52941 Mdot
.67451 .76863 Mdot
.47451 .36078 Mdot
.51765 .03137 Mdot
.28627 .39216 Mdot
.51373 .30588 Mdot
.48235 .4 Mdot
.4549 .46275 Mdot
.45882 .55294 Mdot
.69804 .06667 Mdot
.41961 .48627 Mdot
.32157 .09804 Mdot
.13333 .1098 Mdot
.33725 .0902 Mdot
.43529 .42745 Mdot
.50196 .58824 Mdot
.68627 .14118 Mdot
.49412 .18824 Mdot
.41569 .37647 Mdot
.25098 .3451 Mdot
.33725 .2902 Mdot
.53725 .47451 Mdot
.44314 .50588 Mdot
.70588 .79216 Mdot
.5098 .22353 Mdot
.28627 .36078 Mdot
.28235 .38039 Mdot
.30588 .2549 Mdot
.51373 .41961 Mdot
.44706 .48235 Mdot
.54118 .65098 Mdot
.32941 .61176 Mdot
.42353 .05098 Mdot
.29412 .39216 Mdot
.46275 .23922 Mdot
.4 .34118 Mdot
.46667 .46667 Mdot
.6902 .78431 Mdot
.62353 .16471 Mdot
.54902 .04314 Mdot
.31373 .20392 Mdot
.24314 .00784 Mdot
.37647 .27843 Mdot
.46667 .45098 Mdot
.52549 .62353 Mdot
.72157 .08627 Mdot
.50588 .65882 Mdot
.44706 .02745 Mdot
.27059 .36078 Mdot
.33725 .06275 Mdot
.54902 .50196 Mdot
.38824 .46275 Mdot
.63922 .47451 Mdot
.51765 .40392 Mdot
.41961 .18824 Mdot
.29804 .4 Mdot
.32549 .26275 Mdot
.51373 .43529 Mdot
.41569 .45098 Mdot
.55686 .66667 Mdot
.73725 .34118 Mdot
.02353 .3098 Mdot
.25098 .37255 Mdot
.37255 .12157 Mdot
.35686 .31765 Mdot
.42353 .45882 Mdot
.70196 .78824 Mdot
.67059 .07059 Mdot
.56863 .04314 Mdot
.41176 .01176 Mdot
.20392 .28627 Mdot
.37647 .32157 Mdot
.55294 .53333 Mdot
.27059 .43922 Mdot
.62353 .11765 Mdot
.74118 .87843 Mdot
.44314 .01569 Mdot
.28235 .36471 Mdot
.34118 .2549 Mdot
.51765 .46275 Mdot
.40392 .48235 Mdot
.54902 .3451 Mdot
.11373 .52157 Mdot
.51373 .03529 Mdot
.27843 .37647 Mdot
.32941 .19608 Mdot
.47451 .42745 Mdot
.42353 .47451 Mdot
.74118 .84314 Mdot
.53333 .21961 Mdot
.52549 .0549 Mdot
.2 .37647 Mdot
.32941 0 Mdot
.44314 .38824 Mdot
.47059 .45882 Mdot
.50588 .60392 Mdot
.63137 .10196 Mdot
.48627 .21569 Mdot
.40784 .02745 Mdot
.27059 .36078 Mdot
.37255 .32157 Mdot
.52941 .50196 Mdot
.37255 .55686 Mdot
.2 .38431 Mdot
.74902 .87059 Mdot
.26667 .31373 Mdot
.28235 .38039 Mdot
.30588 .2549 Mdot
.40392 .31373 Mdot
.42745 .4902 Mdot
.73333 .72549 Mdot
.71373 .91765 Mdot
.47843 .05098 Mdot
.2902 .39608 Mdot
.34902 .05098 Mdot
.42745 .38824 Mdot
.78039 .83137 Mdot
.70196 .80392 Mdot
.59608 .07059 Mdot
.51765 .04314 Mdot
.00784 .23529 Mdot
.23922 .26667 Mdot
.44314 .14902 Mdot
.54118 .5098 Mdot
.44706 .54118 Mdot
.73333 .52157 Mdot
.74118 .85098 Mdot
.42745 .04706 Mdot
.2549 .35686 Mdot
.36863 .16471 Mdot
.47451 .42353 Mdot
.04314 .35294 Mdot
.56863 .33725 Mdot
.7451 .87059 Mdot
.48627 .72941 Mdot
.28627 .39608 Mdot
.36863 .2549 Mdot
.44706 .41961 Mdot
.41176 .45882 Mdot
.77647 .88627 Mdot
.05882 .44314 Mdot
.15686 .35686 Mdot
.29412 .38824 Mdot
.48235 .0549 Mdot
.46275 .43137 Mdot
.44706 .50588 Mdot
.49412 .58824 Mdot
.6 .09412 Mdot
.32941 .24706 Mdot
.23137 .4549 Mdot
.24706 .3451 Mdot
.40784 .30196 Mdot
.49804 .47451 Mdot
.64706 .74902 Mdot
.10588 .55294 Mdot
.7451 .86275 Mdot
.4902 .59216 Mdot
.27843 .38039 Mdot
.39216 .10196 Mdot
.50196 .18431 Mdot
.01176 .32941 Mdot
.59216 .79608 Mdot
.76078 .86667 Mdot
.44314 .65882 Mdot
.2902 .38824 Mdot
.36863 .19608 Mdot
.47843 .38824 Mdot
.45098 .48235 Mdot
.73333 .84706 Mdot
.03137 .4 Mdot
.49804 .72941 Mdot
.3098 .42353 Mdot
.26667 .32941 Mdot
.42353 .41569 Mdot
.55294 .5451 Mdot
.60784 .71373 Mdot
.64706 .0902 Mdot
.73333 .85882 Mdot
.48235 .60392 Mdot
.26667 .36471 Mdot
.38039 .36471 Mdot
.48235 .38431 Mdot
.4 .4902 Mdot
.03922 .47843 Mdot
.75686 .87451 Mdot
.63137 .79608 Mdot
.2902 .39608 Mdot
.34902 .01176 Mdot
.48627 .24314 Mdot
.41961 .47451 Mdot
.77255 .88235 Mdot
.76863 .87843 Mdot
.53333 .76078 Mdot
.31765 .42353 Mdot
.29412 .30588 Mdot
.43529 .18431 Mdot
.54902 .55294 Mdot
.52157 .64706 Mdot
.03922 .47059 Mdot
.71373 .86667 Mdot
.39608 .51765 Mdot
.27843 .37255 Mdot
.38824 .35686 Mdot
.47843 .44314 Mdot
.48627 .58431 Mdot
.59216 .2 Mdot
.7451 .86275 Mdot
.51765 .66275 Mdot
.2902 .40784 Mdot
.43529 .18039 Mdot
.52157 .49804 Mdot
.05882 .44314 Mdot
.76863 .8902 Mdot
.77255 .88627 Mdot
.23137 .48235 Mdot
.30196 .41569 Mdot
.36078 .02745 Mdot
.47059 .43137 Mdot
.57647 .61176 Mdot
.59608 .69412 Mdot
.78431 .88627 Mdot
.72549 .85882 Mdot
.43137 .55294 Mdot
.27843 .36078 Mdot
.36078 .21176 Mdot
.52941 .52549 Mdot
.76471 .86275 Mdot
.49804 .91373 Mdot
.74902 .87059 Mdot
.68235 .82353 Mdot
.2902 .38824 Mdot
.40392 .26667 Mdot
.50196 .45098 Mdot
.49804 .61176 Mdot
.7451 .87843 Mdot
.77647 .88235 Mdot
.41961 .63137 Mdot
.3098 .41176 Mdot
.38039 .07451 Mdot
.47059 .43922 Mdot
.46275 .63922 Mdot
.62353 .73333 Mdot
.78431 .88627 Mdot
.7451 .87451 Mdot
.44706 .57647 Mdot
.25098 .3451 Mdot
.40784 .40392 Mdot
.50588 .49412 Mdot
.5098 .63529 Mdot
.50196 .8549 Mdot
.76471 .88235 Mdot
.56078 .69412 Mdot
.2902 .39216 Mdot
.38824 .12157 Mdot
.47843 .3451 Mdot
.52941 .64706 Mdot
.56863 .9098 Mdot
.78039 .88627 Mdot
.38824 .64706 Mdot
.32549 .43529 Mdot
.36471 .0902 Mdot
.55294 .25098 Mdot
.00784 .46667 Mdot
.91373 1 Mdot
.80392 .90196 Mdot
.74902 .90196 Mdot
.48235 .61176 Mdot
.27843 .35686 Mdot
.4549 .4 Mdot
.55294 .57255 Mdot
.76471 .86667 Mdot
.87451 .9451 Mdot
.76471 .89804 Mdot
.69804 .81961 Mdot
.2902 .39216 Mdot
.37647 .35294 Mdot
.50588 .45098 Mdot
.67843 .81569 Mdot
.82353 .9451 Mdot
.79216 .89804 Mdot
.52157 .72157 Mdot
.36078 .46667 Mdot
.3451 .06275 Mdot
.55686 .30588 Mdot
0 .52157 Mdot
.98039 1 Mdot
.81569 .91373 Mdot
.67843 .86275 Mdot
.60784 .69804 Mdot
.29412 .36471 Mdot
.50196 .32941 Mdot
.52157 .56078 Mdot
.92549 .96471 Mdot
.85882 .95294 Mdot
.76078 .88235 Mdot
.65098 .8 Mdot
.33333 .42745 Mdot
.4 .34118 Mdot
.54118 .50588 Mdot
.83529 .89804 Mdot
.75294 .98824 Mdot
.74118 .88627 Mdot
.17255 .4902 Mdot
.38039 .49412 Mdot
.3451 .11765 Mdot
.53725 .22353 Mdot
.00784 .63922 Mdot
.92941 .95686 Mdot
.76078 .8902 Mdot
.71373 .87059 Mdot
.52549 .64706 Mdot
.32941 .38824 Mdot
.42745 .34118 Mdot
.63137 .6549 Mdot
.98039 1 Mdot
.79216 .9098 Mdot
.7451 .87451 Mdot
.37647 .52941 Mdot
.36471 .46275 Mdot
.38824 .12157 Mdot
.59216 .59216 Mdot
.84314 .91373 Mdot
.74118 .98824 Mdot
.74902 .87843 Mdot
.28627 .54902 Mdot
.35294 .46667 Mdot
.34118 .12549 Mdot
.50196 .23922 Mdot
.00784 .69804 Mdot
.39216 .6549 Mdot
.77255 .8902 Mdot
.71765 .8902 Mdot
.41961 .5451 Mdot
.34902 .42745 Mdot
.44706 .1098 Mdot
.76078 .77647 Mdot
.68235 .82745 Mdot
.79216 .90196 Mdot
.64706 .97647 Mdot
.42745 .6549 Mdot
.32157 .43137 Mdot
.42745 .18039 Mdot
.76078 .65098 Mdot
.75294 .85098 Mdot
.61176 .92549 Mdot
.32157 .92941 Mdot
.12157 .63529 Mdot
.40392 .52157 Mdot
.33725 .12941 Mdot
.49804 .22353 Mdot
.02353 .61176 Mdot
.74118 .89412 Mdot
.19608 .9098 Mdot
.07843 .60392 Mdot
.2 .5451 Mdot
.51765 .61961 Mdot
.43137 .25098 Mdot
.70196 .72157 Mdot
.78039 .88627 Mdot
.32941 .9451 Mdot
.43137 .5098 Mdot
.13725 .41176 Mdot
.30588 .40784 Mdot
.39608 .13333 Mdot
.71373 .6549 Mdot
.76863 .87843 Mdot
.28627 .94118 Mdot
.14902 .91373 Mdot
.55686 .18039 Mdot
.03137 .38824 Mdot
.32549 .02745 Mdot
.62745 .25882 Mdot
.02353 .41176 Mdot
.31373 .93725 Mdot
.06667 1 Mdot
.63922 .08627 Mdot
.38824 .18039 Mdot
.50588 .62353 Mdot
.55686 .41569 Mdot
.60392 .65098 Mdot
.23137 .87843 Mdot
.35686 1 Mdot
.68627 .09412 Mdot
.5098 .08235 Mdot
.19608 .47059 Mdot
.41569 .26275 Mdot
.62353 .62745 Mdot
.36078 .86275 Mdot
.4 .99216 Mdot
.65882 .20392 Mdot
.56471 .38039 Mdot
.39608 .16078 Mdot
.36471 .03137 Mdot
.56078 .57255 Mdot
.33725 .78824 Mdot
.04706 .99608 Mdot
.41569 .48235 Mdot
.72941 .55686 Mdot
.44314 .02353 Mdot
.34118 .32549 Mdot
.51765 .5098 Mdot
.50588 .74118 Mdot
.02353 .98039 Mdot
.62353 .44706 Mdot
.6 .52157 Mdot
.70588 .59608 Mdot
.06667 .45882 Mdot
.47451 .28235 Mdot
.6 .67843 Mdot
.01569 .97255 Mdot
.68627 .47843 Mdot
.76863 .10588 Mdot
.60784 .62745 Mdot
.48235 .05882 Mdot
.33333 .17647 Mdot
.61569 .60392 Mdot
.01176 .84314 Mdot
.69804 .52549 Mdot
.4549 .67843 Mdot
.63137 .64706 Mdot
.43529 .17647 Mdot
.44314 .17647 Mdot
.50588 .50196 Mdot
.01176 .73333 Mdot
.56863 .54118 Mdot
.03137 .99608 Mdot
.75686 .67059 Mdot
.43922 .01176 Mdot
.32549 .07451 Mdot
.4549 .43922 Mdot
.02745 .69412 Mdot
.43529 .4902 Mdot
.02745 .94902 Mdot
.59216 .4549 Mdot
.4 .36863 Mdot
.52941 .18039 Mdot
.40392 .40392 Mdot
.00784 .65882 Mdot
.47059 .45098 Mdot
.03529 .93333 Mdot
.75686 .09804 Mdot
.51373 .2902 Mdot
.70196 .63137 Mdot
.46667 .43529 Mdot
.00392 .61176 Mdot
.00784 .52157 Mdot
.00784 .93333 Mdot
.76471 .26667 Mdot
.65098 .20392 Mdot
.5451 .45882 Mdot
.57255 .33333 Mdot
.00784 .58039 Mdot
.32157 .45882 Mdot
0 .92157 Mdot
.00392 .95294 Mdot
.74902 .09804 Mdot
.67843 .4902 Mdot
.52549 .21176 Mdot
.00392 .47451 Mdot
.21961 .30588 Mdot
0 .8902 Mdot
.03529 .99608 Mdot
.77647 .1098 Mdot
.52549 .04706 Mdot
.04706 .0902 Mdot
.09804 .38824 Mdot
.32941 .33725 Mdot
0 .83529 Mdot
.33725 1 Mdot
.78039 .12549 Mdot
.53333 .03137 Mdot
.59216 .23922 Mdot
.39216 .47843 Mdot
.42745 .29804 Mdot
0 .79216 Mdot
.5451 .98039 Mdot
.7451 .14902 Mdot
.6 .06275 Mdot
.58824 .50196 Mdot
.43529 .40392 Mdot
.44314 .25882 Mdot
0 .7098 Mdot
.24706 .89412 Mdot
.47059 .38824 Mdot
.50588 .18824 Mdot
.56078 .10588 Mdot
.43529 .39608 Mdot
.28235 .34902 Mdot
.01961 .76863 Mdot
.03137 .96078 Mdot
.0902 .68627 Mdot
.2 .41176 Mdot
.58039 .06275 Mdot
.43137 .36863 Mdot
.11373 .43529 Mdot
.00392 .79216 Mdot
.00784 .97255 Mdot
.00392 .76078 Mdot
.02353 .58431 Mdot
.55294 .05882 Mdot
.43922 .3098 Mdot
.07451 .41961 Mdot
.0549 .95294 Mdot
0 .93333 Mdot
.01176 .76863 Mdot
.00784 .62353 Mdot
.35294 .14118 Mdot
.41176 .25882 Mdot
.0549 .41961 Mdot
.01961 .81961 Mdot
.00392 .88627 Mdot
.01961 .72549 Mdot
.05882 .53333 Mdot
.05882 .40392 Mdot
.41176 .24706 Mdot
.01176 .45098 Mdot
.01176 .78039 Mdot
.00392 .86667 Mdot
.16863 .61176 Mdot
.35294 .57647 Mdot
.00392 .47451 Mdot
.41961 .23137 Mdot
.00392 .4902 Mdot
0 .74902 Mdot
.00392 .83137 Mdot
.40784 .57647 Mdot
.61961 .7098 Mdot
.03529 .39608 Mdot
.47843 .17255 Mdot
.01176 .51765 Mdot
.01176 .78431 Mdot
.02745 .76863 Mdot
.51373 .60392 Mdot
.70588 .77255 Mdot
.21961 .4 Mdot
.49804 .12157 Mdot
.00784 .5451 Mdot
.00784 .73333 Mdot
.18039 .62745 Mdot
.60784 .67451 Mdot
.72157 .80784 Mdot
.25882 .37255 Mdot
.35294 .07451 Mdot
.00392 .55686 Mdot
.01569 .71373 Mdot
.43922 .57255 Mdot
.85098 .88235 Mdot
.46275 .52549 Mdot
.23529 .34902 Mdot
.03137 .12941 Mdot
.00392 .58039 Mdot
.00392 .61569 Mdot
.51765 .59216 Mdot
.58824 .58824 Mdot
.47059 .37647 Mdot
.23922 .31765 Mdot
.00784 .21569 Mdot
.00392 .58824 Mdot
.07843 .51765 Mdot
.74118 .78824 Mdot
.52157 .40392 Mdot
.46275 .2902 Mdot
.2549 .29804 Mdot
.24706 .0902 Mdot
.00392 .59216 Mdot
.43137 .53333 Mdot
.56078 .58039 Mdot
.4549 .30588 Mdot
.40392 .28627 Mdot
.2549 .28627 Mdot
.00784 .36863 Mdot
0 .62353 Mdot
.53725 .6 Mdot
.48235 .37255 Mdot
.37647 .24314 Mdot
.38431 .3098 Mdot
.20392 .25098 Mdot
.00392 .52157 Mdot
.10588 .52549 Mdot
.56863 .63137 Mdot
.40392 .2902 Mdot
.37647 .25882 Mdot
.36471 .28627 Mdot
.1451 .20392 Mdot
.00392 .47843 Mdot
.4902 .57647 Mdot
.41176 .27843 Mdot
.40392 .26275 Mdot
.36471 .2549 Mdot
.35294 .25882 Mdot
.22745 .03529 Mdot
.00392 .53333 Mdot
.69412 .74902 Mdot
.42353 .28627 Mdot
.37647 .25098 Mdot
.39608 .29412 Mdot
.33725 .25098 Mdot
.01961 .15686 Mdot
.03922 .43137 Mdot
.41569 .38039 Mdot
.43137 .31765 Mdot
.38824 .25098 Mdot
.37255 .2902 Mdot
.28235 .27843 Mdot
.00392 .45098 Mdot
.4902 .56471 Mdot
.48235 .38431 Mdot
.43137 .33333 Mdot
.38039 .25098 Mdot
.36078 .27451 Mdot
.19608 .2 Mdot
0 .49412 Mdot
.63922 .69412 Mdot
.50588 .46275 Mdot
.40784 .32941 Mdot
.3451 .23529 Mdot
.39216 .33333 Mdot
.30196 .24314 Mdot
.02353 .42353 Mdot
.52549 .4549 Mdot
.55686 .49412 Mdot
.35686 .31373 Mdot
.34902 .27451 Mdot
.3451 .28627 Mdot
.23529 .02745 Mdot
.60784 .64314 Mdot
.58039 .59608 Mdot
.43529 .39608 Mdot
.34902 .34902 Mdot
.35686 .38039 Mdot
.28235 .30588 Mdot
0 .52549 Mdot
.3451 .31373 Mdot
.44314 .39216 Mdot
.45098 .48235 Mdot
.24314 .32157 Mdot
.34902 .32157 Mdot
.34902 .36471 Mdot
.12941 .43137 Mdot
.42745 .28627 Mdot
.43137 .31765 Mdot
.1098 .21569 Mdot
.19216 .24314 Mdot
.40784 .38431 Mdot
.35686 .29804 Mdot
.5098 .54902 Mdot
.43529 .2549 Mdot
.42353 .41961 Mdot
.23137 .30588 Mdot
.12549 .18039 Mdot
.26667 .30588 Mdot
.03529 .61961 Mdot
.43922 .3098 Mdot
.46667 .2902 Mdot
.32549 .4 Mdot
.3451 .33333 Mdot
.36471 .36078 Mdot
.38431 .40784 Mdot
.44706 .42745 Mdot
.43922 .27451 Mdot
.36863 .33333 Mdot
.56078 .47059 Mdot
.4902 .33333 Mdot
.34118 .32157 Mdot
.18824 .04706 Mdot
.44706 .28627 Mdot
.4549 .25882 Mdot
.61961 .69412 Mdot
.52941 .26667 Mdot
.38824 .30588 Mdot
.43529 .46667 Mdot
.37647 .31765 Mdot
.43137 .2902 Mdot
.40784 .31373 Mdot
.54118 .43922 Mdot
.42353 .26275 Mdot
.36078 .4 Mdot
.43922 .17647 Mdot
.4549 .28235 Mdot
.42353 .27451 Mdot
.45882 .39216 Mdot
.38039 .25098 Mdot
.43922 .32549 Mdot
.46275 .52549 Mdot
.30196 .16863 Mdot
.44314 .27059 Mdot
.73333 .76471 Mdot
.27843 .33333 Mdot
.37255 .38039 Mdot
.52549 .59216 Mdot
.35294 .18824 Mdot
.43529 .29804 Mdot
.45098 .21961 Mdot
.42353 .40392 Mdot
.42353 .43922 Mdot
.54902 .61569 Mdot
.40784 .27843 Mdot
.4 .1451 Mdot
.42353 .19608 Mdot
.47059 .38824 Mdot
.44314 .37255 Mdot
.50196 .46667 Mdot
.52941 .59608 Mdot
.31765 .27843 Mdot
.46275 .33725 Mdot
.42353 .23529 Mdot
.59608 .64314 Mdot
.45882 .41176 Mdot
.67059 .71765 Mdot
.18431 .16471 Mdot
.43137 .28627 Mdot
.48235 .36078 Mdot
.57255 .57255 Mdot
.49412 .52157 Mdot
.75294 .79608 Mdot
.43922 .19216 Mdot
.41569 .29412 Mdot
.45882 .32157 Mdot
.59608 .42353 Mdot
.67843 .63922 Mdot
.87059 .89412 Mdot
.46667 .07843 Mdot
.4 .32941 Mdot
.46667 .3451 Mdot
.54118 .29804 Mdot
.65098 .48627 Mdot
.90196 .93725 Mdot
.4902 .0902 Mdot
.38039 .33333 Mdot
.47059 .36863 Mdot
.57647 .42745 Mdot
.91765 .81569 Mdot
.81961 .8902 Mdot
.36471 .19608 Mdot
.35686 .32157 Mdot
.45098 .37647 Mdot
.60784 .55294 Mdot
.99608 .98824 Mdot
.78039 .84706 Mdot
.24706 .30196 Mdot
.43922 .43922 Mdot
.4902 .45098 Mdot
.87059 .84706 Mdot
.98431 .99608 Mdot
.69804 .74118 Mdot
.37255 .38824 Mdot
.42745 .42745 Mdot
.57647 .56078 Mdot
.99216 .99216 Mdot
.83529 .89412 Mdot
.42353 .16471 Mdot
.36471 .36078 Mdot
.50588 .55294 Mdot
.99608 .99216 Mdot
.87843 .9098 Mdot
.75294 .78039 Mdot
.40392 .43137 Mdot
.52157 .58431 Mdot
.99216 .99216 Mdot
.95294 .98039 Mdot
.77255 .82745 Mdot
.36863 .41569 Mdot
.51765 .55294 Mdot
.86667 .92157 Mdot
.97255 .98039 Mdot
.79608 .84314 Mdot
.35294 .38824 Mdot
.52941 .59216 Mdot
.85882 .90588 Mdot
.90588 .92941 Mdot
.8 .84706 Mdot
.4 .43137 Mdot
.6 .66275 Mdot
.98039 .99216 Mdot
.89412 .92941 Mdot
.60784 .44314 Mdot
.47843 .51373 Mdot
.84314 .90588 Mdot
.93333 .96078 Mdot
.81569 .8549 Mdot
.42353 .43922 Mdot
.68627 .7451 Mdot
.94118 .96471 Mdot
.8549 .8902 Mdot
.41961 .2549 Mdot
.65882 .72549 Mdot
.91373 .93725 Mdot
.89804 .9098 Mdot
.46667 .41569 Mdot
.77647 .83922 Mdot
.89804 .92941 Mdot
.34118 .18824 Mdot
.61176 .68627 Mdot
.9098 .94118 Mdot
.36078 .20784 Mdot
.67059 .67451 Mdot
.74118 .59608 Mdot
.60392 .32157 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool01?ooO`3oooooooooooooool9oomo0003ooooooooO`3o
ogl000;oogl00oooool8oomo0004ooooooooO`3oogl0ooooo`Googl00oooool3oomo0003oooooooo
O`3ooooo00Coogl000Cooooooomo0?ooooooogl01?ooool01_ooO`3ooooooomo0?ooO`3ooooooomo
00;ooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`03ooooo`06oomo0?ooooooogl0
oomo0?ooooooogl01Oooool2oomo00;ooooo00Coogl0ooooooooO`3ooooo0_ooO`0?ooooo`03oomo
0?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`03oj0P
l?oooooooooo07cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool00ooo
ool00oooO`3ooooooomo0002ooooo`03oomo0?oooooooooo00?ooooo0_ooO`02ooooo`[oogl00_oo
ool5oomo0004ooooooooO`3oogl0ooooo`?oogl00_ooool=oomo0004ooooooooO`3ooooooomo00;o
oooo00Ooogl0ooooooooooooogl0ooooooooO`3ooooo00;oogl00oooool2oomo0003ooooooooO`3o
ogl000?oogl000?ooooooomo0?ooO`002?ooO`02ooooo`04oomo0?oooooooooooomo00;ooooo00Co
ogl0ooooooooooooogl01oooool00oooO`3oooooooooo`0mooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo00Sooooo
00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo01oooooo
00?oX23`ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0Dooooo`04oomo0?ooooooogl0oomo00Wooooo00Googl0oooooooooooooooooomo0002ooooo`03
oomo0?ooooooogl000;ooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`05ooooo`03
oomo0?oooooooooo00;oogl01oooool2oomo00;ooooo1?ooO`001Oooooooogl0ooooooooooooogl0
00;ooooo0oooO`000oooooooogl0oomo0002oomo0003ooooooooO`3oogl000?ooooo00?oogl0oooo
ooooO`001Oooool00oooO`3oooooooooo`13ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<oooool00onP8?3oooooooooo`09ooooo`05oj0Pl?oooooooooooooooonP8?001_ooool0
1?nP8?3ooooooooooonP8?1Sooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo01;ooooo00?oogl0ooooooooO`000oooool2oomo0003ooooooooO`3ooooo00Oooooo1?ooO`06
ooooo`;oogl00oooool00oooO`3ooooooomo0002ooooo`03oomo0?ooooooogl000?oogl000?ooooo
oomo0?ooool01?ooO`001?ooooooogl0ooooooooool3oomo0003ooooooooO`3oogl000Coogl000?o
oooooomo0?ooO`002OooO`000oooooooogl0oomo0002oomo0003ooooooooO`3oogl000;oogl000Oo
oooooomo0?ooO`3ooooooomo0?ooooooogl000;ooooo00?oogl0ooooooooO`000_ooO`02ooooo`03
oomo0?oooooooooo03Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03
oj0Pl?oooooooooo00_ooooo00GoX23`oooooooooooooooooj0Pl004ooooo`03oj0Pl?oooooooooo
00cooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`0eooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo02kooooo00?oogl0ooooooooool02?ooool00oooO`3o
ooooooooo`04ooooo`03oomo0?ooooooogl000;oogl000Cooooooomo0?ooO`3ooooo0_ooO`06oooo
o`;oogl000?ooooooomo0?ooO`004?ooO`02ooooo`;oogl000?ooooooomo0?ooO`000oooO`02oooo
o`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooO`00=Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Oooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`04oooo
o`04oj0Pl?oooooooooooj0Pl0Cooooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oo
oooooooo00Wooooo00?oX23`ooooooooool02oooool2oj0Pl0;ooooo00?oX23`ooooooooool00_oo
ool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo03?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool00_ooool00oooO`3oooooooooo`05ooooo`04oomo0?oooooo
oooooomo00Cooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`03ooooo`;oogl00_oo
ool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00Oooooo00Ooogl0oooooooooooooooo
oomo0?ooooooogl000;ooooo00Googl0oooooooooooooooooomo0002ooooo`?oogl01Oooool00ooo
O`3ooooooomo0002oomo0003ooooooooO`3ooooo013oogl000Oooooooomo0?oooooooooooomo0?oo
ooooogl000;ooooo00Koogl0ooooooooO`3ooooooomo0?ooool2oomo00Cooooo0oooO`04ooooo`?o
ogl00_ooool01?ooO`3ooooooomo0?ooO`02ooooo`;oogl09_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?oX23`ooooooooool07?ooool00onP8?3oooooooooo`02oooo
o`03oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool03?ooool00onP8?3ooooooj0Pl006oooo
o`03oj0Pl?ooooooX23`00?oX23`00Cooooooj0Pl?oooooooooo0_nP8?000oooooooX23`ooooo`03
ooooo`03oj0Pl?oooooooooo00Gooooo1OnP8?000oooooooX23`oj0Pl004ooooo`;oX23`<oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Wooooo`03oomo0?ooooooogl0
00Sooooo00?oogl0ooooooooool01_ooool01?ooO`3oooooooooooooO`07ooooo`;oogl01Oooool4
oomo0008ooooooooO`3oogl0ooooooooO`3ooooooomo0?ooool2oomo0003ooooooooO`3oogl000;o
oooo0_ooO`001Oooooooogl0ooooooooO`3ooooo00;oogl00_ooool01OooO`3ooooooooooooooooo
ogl000?ooooo00Coogl0ooooooooooooogl00_ooool00oooO`3ooooooomo0002ooooo`;oogl01Ooo
ool01?ooO`3oooooooooooooool2oomo0005ooooooooO`3oooooooooooooO`008Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05Wooooo00?oX23`ooooooooool01Oooool00onP8?3o
ooooooooo`07ooooo`05oj0Pl?oooooooooooooooonP8?001?ooool01?nP8?3ooooooooooonP8?06
ooooo`03oj0Pl?ooooooX23`033ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool04?ooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo01_ooooo00?oogl0oooo
ooooool02?ooool01?ooO`3oooooooooooooO`05ooooo`04oomo0?ooooooogl0ooooo`Koogl01ooo
ool00oooO`3ooooooomo0003oomo00;ooooo0oooO`000oooooooogl0ooooo`02ooooo`;oogl01?oo
ool01oooO`3ooooooomo0?ooooooogl0ooooooooO`000_ooool2oomo0007ooooooooO`3oogl0oooo
ooooO`3ooooooomo0004ooooo`04oomo0?oooooooooooomo00Oooooo00?oogl0ooooooooool05_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05[ooooo00?oX23`ooooooooool00ooo
ool2oj0Pl004oooooonP8?3ooooooj0Pl0;ooooo00?oX23`oooooonP8?001Oooool00onP8?3ooooo
ooooo`07ooooo`03oj0Pl?oooooooooo00;oX23`<_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`05ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooO`000_oo
ool01OooO`3oooooooooooooooooogl000Cooooo00?oogl0ooooooooool03Oooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?oooooooooo00Kooooo00Koogl0ooooooooooooogl0ooooooooO`02oooo
o`06oomo0?oooooooooooomo0?ooooooogl02Oooool00oooO`3oooooooooo`03oomo0004oooooooo
O`3ooooooomo00?ooooo0_ooO`03ooooo`;oogl000Gooooooomo0?ooooooogl0ooooo`02oomo00;o
oooo00?oogl0ooooooooO`001?ooO`000oooooooogl0ooooo`05oomo0003ooooooooO`3ooooo00;o
oooo00?oogl0ooooooooO`001_ooO`03ooooo`03oomo0?oooooooooo00?ooooo00Googl0oooooooo
oooooooooomo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool2oj0P
l003oooooonP8?3ooooo00_ooooo00?oX23`ooooooooool06_ooool00onP8?3oooooooooo`0:oooo
o`;oX23`2?ooool3oj0Pl0Gooooo00?oX23`ooooooooool01oooool00onP8?3ooooooj0Pl003oooo
o`;oX23`1oooool5oj0Pl0;ooooo00?oX23`oooooonP8?002?ooool00onP8?3oooooooooo`04oooo
o`03oj0Pl?oooooooooo027ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool07Oooool00oooO`3oooooooooo`0Cooooo`03oomo0?oooooooooo00cooooo00?oogl0oooooooo
ool01?ooool00oooO`3oooooooooo`0;ooooo`03oomo0?ooooooogl000;ooooo00?oogl0oooooooo
ool01Oooool01?ooO`3oooooooooooooool2oomo0005ooooooooO`3ooooooomo0?ooool00_ooO`00
0oooooooogl0ooooo`02oomo0003ooooooooO`3oogl000Oooooo00?oogl0ooooooooool00_ooool0
0oooO`3oooooooooo`07ooooo`;oogl08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03_ooooo00?oX23`ooooooooool05_ooool00onP8?3oooooooooo`04ooooo`;oX23`1?ooool0
0onP8?3oooooooooo`0Dooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01oooool0
0onP8?3oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
013ooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`08ooooo`;oogl04_ooool00ooo
O`3oooooooooo`09ooooo`03oomo0?oooooooooo00;ooooo0_ooO`07ooooo`03oomo0?oooooooooo
00?ooooo00?oogl0ooooooooool01?ooool2oomo0003ooooooooO`3oogl000;ooooo0_ooO`02oooo
o`?oogl00_ooool3oomo0003ooooooooO`3ooooo00;oogl00_ooool00oooO`3oooooooooo`06oooo
o`03oomo0?oooooooooo00?ooooo00Koogl0ooooooooooooogl0ooooooooO`0Kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0>_ooool2oj0Pl1Sooooo00?oX23`ooooooooool01?oo
ool01?nP8?3oooooooooooooool2oj0Pl005oooooonP8?3ooooooooooonP8?000oooool00onP8?3o
ooooooooo`0:ooooo`04oj0Pl?ooooooX23`ooooo`?oX23`00?ooooooj0Pl?ooool04?ooool01OnP
8?3oooooooooooooooooX23`01cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool04?ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo02[ooooo00?oogl0oooo
ooooool02oooool00oooO`3oooooooooo`07ooooo`08oomo0?oooooooooooomo0?ooooooogl0oooo
ooooO`02ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01?ooool00oooO`3ooooo
oomo0006ooooo`05oomo0?ooooooogl0ooooooooO`000_ooool00oooO`3ooooooomo000/ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool00onP8?3oooooooooo`06ooooo`03
oj0Pl?oooooooooo00oooooo00?oX23`ooooooooool01?ooool00onP8?3ooooooj0Pl00Cooooo`?o
X23`4oooool00onP8?3ooooooj0Pl00Oooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo00Sooooo00?oogl0ooooooooool0@_ooool00oooO`3oooooooooo`06ooooo`03oomo
0?oooooooooo00?ooooo00?oogl0ooooooooool01?ooool00oooO`3ooooooomo0004ooooo`05oomo
0?ooooooooooooooooooO`002?ooool00oooO`3oooooooooo`03ooooo`05oomo0?oooooooooooooo
ooooO`002_ooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo01gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0eooooo`03oj0Pl?oooooooooo02;ooooo00?oX23`oooo
ooooool02oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?oooooooooo00;ooooo00GoX23`oooo
oooooooooooooj0Pl00aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
02Oooooo00?oogl0ooooooooool04oooool00oooO`3oooooooooo`04ooooo`;oogl00_ooool00ooo
O`3oooooooooo`0:ooooo`03oomo0?oooooooooo00Oooooo0_ooO`05ooooo`;oogl000?ooooooomo
0?ooool00_ooool2oomo00Sooooo00?oogl0ooooooooool00_ooO`000oooooooogl0ooooo`07oomo
0003ooooooooO`3ooooo02Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0goooo
o`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`02oooo
o`05oj0Pl?oooooooooooooooonP8?000oooool00onP8?3oooooooooo`03oj0Pl0cooooo00?oX23`
ooooooooool00_ooool01?nP8?3ooooooooooonP8?06ooooo`03oj0Pl?oooooooooo00;ooooo00Go
X23`oooooooooooooooooj0Pl004ooooo`03oj0Pl?ooooooX23`037ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool05?ooool00oooO`3oooooooooo`05ooooo`03oomo0?oo
oooooooo01_ooooo00Googl0oooooooooooooooooomo000;ooooo`03oomo0?oooooooooo00Kooooo
00?oogl0ooooooooool02oooool00oooO`3oooooooooo`0Iooooo`;oogl01Oooool2oomo00Kooooo
00?oogl0ooooooooO`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0Nooooo`03oj0Pl?oooooooooo00Cooooo
00SoX23`oooooonP8?3oX23`oooooonP8?3ooooooj0Pl0gooooo00?oX23`ooooooooool00_ooool0
0onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo02Gooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool01oooool00oooO`3oooooooooo`0hooooo`03oomo0?oooooooooo
00Cooooo00?oogl0ooooooooool00_ooool01OooO`3oooooooooooooooooogl0013ooooo0_ooO`02
ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool04_ooool2oomo0003ooooooooO`3o
ogl000?ooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`0Kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01Oooool00onP8?3oooooooooo`0Qooooo`03oj0Pl?oooooo
oooo00kooooo00GoX23`oooooooooooooooooj0Pl00Fooooo`;oX23`00Gooooooj0Pl?oooooooooo
oj0Pl006ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool00oooool2oj0Pl0Gooooo
00?oX23`ooooooooool01?ooool2oj0Pl0;ooooo00?oX23`ooooooooool0;?ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`0:ooooo`03oomo0?oooooooooo02Kooooo00?o
ogl0ooooooooool05oooool00oooO`3oooooooooo`02ooooo`03oomo0?ooooooogl000;ooooo00Co
ogl0ooooooooooooogl03Oooool00oooO`3ooooooomo0002ooooo`03oomo0?oooooooooo00_ooooo
00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo02;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03oj0Pl?oooooooooo00cooooo
00?oX23`ooooooooool03oooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00;ooooo
00CoX23`ooooooooooooX23`=Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`0?ooooo`03oomo0?oooooooooo03Gooooo00Ooogl0oooooooooooooooooomo0?ooooooogl0
00;ooooo00?oogl0ooooooooO`001_ooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo
00Sooooo00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`08ooooo`04oomo0?oooooooooo
oomo00?ooooo00?oogl0ooooooooool00oooool2oomo00Kooooo00?oogl0ooooooooool07?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Oooooo0_nP8?0:ooooo`03oj0Pl?oooooo
oooo01Cooooo0_nP8?02ooooo`;oX23`3oooool00onP8?3oooooooooo`0Booooo`;oX23`:oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0aooooo`03oomo0?ooooooogl0
01;ooooo00?oogl0ooooooooool03?ooool01_ooO`3oooooooooooooO`3ooooooomo00[ooooo00?o
ogl0ooooooooool06_ooool01?ooO`3oooooooooooooO`0Looooo`03oomo0?oooooooooo00cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1:ooooo`03oj0Pl?oooooooooo00_ooooo
00?oX23`ooooooooool01oooool00onP8?3oooooooooo`0Rooooo`03oj0Pl?oooooooooo02Oooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool06_ooool00oooO`3ooooooooo
o`0nooooo`03oomo0?oooooooooo017ooooo00?oogl0ooooooooool04_ooool2oomo00Kooooo00?o
ogl0ooooooooool03?ooool00oooO`3ooooooomo000Cooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05Oooool00onP8?3oooooooooo`0eooooo`03oj0Pl?oooooooooo00_ooooo00?o
X23`ooooooooool06?ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo02Gooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool02oooool01OooO`3ooooooooooooo
ooooogl000Oooooo0_ooO`09ooooo`03oomo0?oooooooooo00Oooooo00Coogl0ooooooooooooogl0
3oooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo02Wooooo00?oogl0ooooooooO`00
4Oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooO`00
1?ooool2oomo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0kooooo`03oj0P
l?oooooooooo00Kooooo00?oX23`ooooooooool04oooool00onP8?3oooooooooo`0:ooooo`03oj0P
l?oooooooooo00?ooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0looooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03Gooooo00?oogl0ooooooooool07_oo
ool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo05;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Gooooo`03oj0Pl?oooooooooo01_ooooo00?oX23`ooooooooool02?oo
ool01?nP8?3ooooooooooonP8?09ooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool0
0_ooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?oooooooooo047ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool03?ooool00oooO`3oooooooooo`0`ooooo`03oomo0?oo
oooooooo00Cooooo00?oogl0ooooooooool03Oooool00oooO`3oooooooooo`0Cooooo`03oomo0?oo
oooooooo00[ooooo00?oogl0ooooooooO`000_ooool01?ooO`3oooooooooooooO`06ooooo`05oomo
0?ooooooooooooooooooO`004?ooool01?ooO`3oooooooooooooO`0<ooooo`05oomo0?oooooooooo
ooooool000004Oooool00ol0003oooooooooo`02ooooo`03oj0Pl?oooooooooo02Wooooo00?oX23`
ooooooooool02Oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`
ooooooooool01_ooool01OnP8?3oooooooooooooooooX23`00[ooooo00?oX23`ooooooooool05ooo
ool00onP8?3oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo04_ooooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooo
oooo00Oooooo0_ooO`0:ooooo`03oomo0?oooooooooo01kooooo00?oogl0ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo00?oX23`ooooooooool01oooool0
0onP8?3oooooooooo`0Looooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool0A?ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`08ooooo`03oomo0?oooooooooo
04Oooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo
02Cooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo
00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`;oX23`0_ooool00onP
8?3ooooooj0Pl01Mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo01Ko
oooo00?oogl0ooooooooool01Oooool01?ooO`3oooooooooooooO`06ooooo`03oomo0?oooooooooo
00Sooooo00Googl0oooooooooooooooooomo000Cooooo`03oomo0?oooooooooo01Oooooo00?oogl0
ooooooooool02Oooool00oooO`3oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<_ooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`
ooooooooool02Oooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`
ooooooooool02oooool00onP8?3oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo05Gooooo00?oogl0ooooooooool0D?ooool00oooO`3oooooooooo`06oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool00onP8?3oooooooooo`09oooo
o`03oj0Pl?oooooooooo03?ooooo00?oX23`ooooooooool0:oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`0gooooo`03oomo0?oooooooooo01Kooooo00?oogl0oooooooo
ool03?ooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo00Sooooo00Googl0oooooooo
oooooooooomo000booooo`04oomo0?oooooooooooomo00Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooonP8?1Uooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool0?ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1Hooooo`03oomo0?oooooo
oooo053ooooo00?oogl0ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04Cooooo00?oX23`ooooooooool0J_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`1Eooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool0Aoooool01?oo
O`3oooooooooooooO`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool0
0onP8?3oooooooooo`0Booooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool01oooool2
oj0Pl0oooooo00GoX23`oooooooooooooooooj0Pl00=ooooo`;oX23`@oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`1Oooooo`03oomo0?ooooooogl000oooooo00?oogl0
ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo03Gooooo00?oX23`
ooooooooool00_ooool00onP8?3oooooooooo`0Fooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`
ooooooooool0EOooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Loooo
o`03oomo0?oooooooooo05Kooooo00?oogl0ooooooooool0=_ooool01?ooO`3oooooooooool0000A
ooooo`04o`000?oooooooooooj0Pl3Sooooo00?oX23`ooooooooool02Oooool00onP8?3ooooooooo
o`03ooooo`?oX23`7Oooool00onP8?3oooooooooo`13ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo04_ooooo00?oogl0ooooooooool04oooool00oooO`3oooooooooo`0?
ooooo`03oomo0?oooooooooo01gooooo00?oogl0ooooooooool04?ooool00oooO`3oooooooooo`02
ooooo`03oomo0?oooooooooo00?ooooo00?o0000ooooooooool03oooool01?l0003oX23`oooooonP
8?0Booooo`03oj0Pl?oooooooooo02_ooooo00?oX23`oooooonP8?001_ooool4oj0Pl0Wooooo00So
X23`ooooooooooooX23`oooooonP8?3ooooooj0Pl0;ooooo00GoX23`oooooonP8?3ooooooj0Pl01;
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo01Sooooo00?oogl0oooo
ooooool08_ooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo01kooooo00Coogl0oooo
ooooooooogl0>oooool00oooO`3oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?oX23`
ooooooooool0>_ooool00onP8?3ooooooj0Pl00;ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`
oooooonP8?00F?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Woooo
o`03oomo0?oooooooooo033ooooo00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`15oooo
o`;oogl00_ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo03Sooooo00?oX23`oooo
ooooool00oooool2oj0Pl0Wooooo00CoX23`oooooonP8?3oX23`4oooool00onP8?3oooooooooo`0?
ooooo`03oj0Pl?oooooooooo03cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0HOooool00oooO`3ooooooomo0007ooooo`03oomo0?oooooooooo02kooooo00?oogl0oooo
ooooool04?ooool00oooO`3oooooo`00000Aooooo`05oj0Pl?oooooooooooooooonP8?007_ooool0
0onP8?3oooooooooo`14ooooo`03oj0Pl?oooooooooo04Oooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0H?ooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo
04Wooooo00?o0000ooooooooool03oooool01?l0003ooooooooooonP8?0Fooooo`03oj0Pl?oooooo
oooo01_ooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooo
oooo02;ooooo0_nP8?0mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
01gooooo00?oogl0ooooooooool09_ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo
00kooooo0_ooO`0Kooooo`03oomo0?oooooooooo02Wooooo00?oogl0ooooooooool01Oooool00ooo
O`3oooooo`00000Aooooo`03o`000?nP8?3ooooo017ooooo00?oX23`ooooooooool08Oooool00onP
8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo01[ooooo00?oX23`ooooooooool02Oooool01?nP
8?3ooooooooooonP8?16ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
023ooooo00?oogl0ooooooooool09_ooool00oooO`3oooooooooo`0>ooooo`03oomo0?oooooooooo
00Oooooo00?oogl0ooooooooool03?ooool00oooO`3oooooooooo`0hooooo`?oogl000?o0000oooo
ooooool03oooool00ol0003oX23`ooooo`0Aooooo`03oj0Pl?oooooooooo02?ooooo00?oX23`oooo
oonP8?006_ooool00onP8?3oooooooooo`1Jooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo01;ooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`0;ooooo`03
oomo0?oooooooooo00Wooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0Dooooo`03
oomo0?ooooooogl000Sooooo00?oogl0ooooooooool0:_ooool00oooO`3oooooooooo`0Looooo`03
o`000?oooooooooo00oooooo00?oX23`ooooooooool0=Oooool00onP8?3oooooooooo`0Fooooo`03
oj0Pl?oooooooooo00Gooooo00CoX23`ooooooooooooX23`0oooool2oj0Pl5;ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0I_ooool00oooO`3oooooooooo`17ooooo`03
oomo0?l0003ooooo013ooooo00?o0000ooooooooool0>Oooool00onP8?3oooooooooo`0Fooooo`03
oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool08?ooool00onP8?3oooooooooo`0_ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo07Gooooo00?oogl0ooooooooool0
=?ooool00oooO`3oooooooooo`02ooooo`03o`000?oooooooooo00oooooo0_nP8?000oooooooX23`
ooooo`0[ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool01Oooool00onP8?3ooooo
ooooo`02ooooo`;oX23`<_ooool01?nP8?3ooooooooooonP8?0aooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`000?oooooooooo05Wooooo0_ooO`0Sooooo`03oomo0?oooooooooo02gooooo
0oooO`000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?oX23`ooooooooool0
A_ooool2oj0Pl0Kooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`17ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo057ooooo00?oogl0ooooooooool04_oo
ool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo043ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Oooooo`03oj0Pl?oooooooooo017ooooo00?oX23`ooooooooool02ooo
ool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo02Kooooo00?oX23`ooooooooool0<Ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Pooooo`03oomo0?oooooo
oooo00Oooooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`0=ooooo`04oomo0?oooooo
oooooomo00Wooooo00?oogl0ooooooooool0F?ooool00oooO`3o0000ooooo`0@ooooo`03o`000?oo
oooooooo00;ooooo00?oX23`ooooooooool07?ooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?oo
ooooX23`00Kooooo00?oX23`oooooonP8?000oooool01?nP8?3ooooooooooonP8?0Eooooo`03oj0P
l?oooooooooo04kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool07ooo
ool00oooO`3ooooooomo000^ooooo`03oomo0?oooooooooo05gooooo00?oogl0o`000?ooool04?oo
ool00ol0003oooooooooo`0dooooo`03oj0Pl?oooooooooo00?ooooo00CoX23`oooooooooooooooo
0_nP8?08ooooo`04oj0Pl?oooooooooooj0Pl1Cooooo00?oX23`ooooooooool0C_ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Pooooo`03oomo0?oooooooooo02_ooooo
00?oogl0ooooooooO`005Oooool00oooO`3oooooooooo`0dooooo`03oomo0?oooooooooo00Wooooo
00?oogl0ooooooooool01?ooool00oooO`3o0000ooooo`0@ooooo`03o`000?nP8?3ooooo00Kooooo
00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo01cooooo
0_nP8?001?ooooooX23`oooooonP8?04ooooo`03oj0Pl?oooooooooo00;ooooo1?nP8?03ooooo`05
oj0Pl?ooooooX23`oooooonP8?004oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo
00;ooooo00?oX23`ooooooooool0>oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`0iooooo`03oomo0?oooooooooo07Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Xooooo`03oj0Pl?oooooooooo01_ooooo00?oX23`ooooooooool04oooool00onP8?3o
ooooooooo`0Xooooo`03oj0Pl?oooooooooo02Oooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0Eoooool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo01;ooooo
00?oogl0ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Oooooo
00?oX23`ooooooooool04oooool00onP8?3oooooooooo`1Qooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo02cooooo00?oogl0ooooooooool01?ooool00oooO`3ooooooooo
o`08ooooo`;oogl04?ooool01?ooO`3oooooooooooooO`0<ooooo`03oomo0?oooooooooo01Gooooo
00?oogl0ooooooooool02Oooool00oooO`3oooooooooo`0Xooooo`03oomo0?oooooo0000017ooooo
00?o0000ooooooooool04Oooool00onP8?3oooooooooo`09ooooo`04oj0Pl?oooooooooooj0Pl0oo
oooo00?oX23`oooooonP8?000oooool01?nP8?3ooooooooooonP8?02ooooo`03oj0Pl?ooooooX23`
00;ooooo00?oX23`ooooooooool00_ooool2oj0Pl005oooooonP8?3ooooooooooonP8?001Oooool0
0onP8?3oooooooooo`0Hooooo`03oj0Pl?oooooooooo047ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0Ioooool00oooO`3oooooooooo`17ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04Oooool00onP8?3oooooooooo`0Sooooo`;oX23`2_ooool00onP
8?3oooooooooo`09ooooo`04oj0Pl?oooooooooooj0Pl5kooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool09_ooool2oomo013ooooo00?oogl0ooooooooool01_ooool01Ooo
O`3oooooooooooooooooogl000Cooooo00?oogl0ooooooooool05_ooool00oooO`3oooooooooo`0@
ooooo`03oomo0?oooooooooo03Gooooo00Coogl0oooooooooooo00004Oooool2oj0Pl2;ooooo00?o
X23`ooooooooool01oooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00;oX23`0_oo
ool01?nP8?3ooooooj0Pl?nP8?04ooooo`03oj0Pl?oooooooooo00;oX23`0_ooool00onP8?3ooooo
ooooo`02oj0Pl0Oooooo00?oX23`ooooooooool02oooool00onP8?3oooooooooo`17ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo02Sooooo00?oogl0ooooooooool05?oo
ool00oooO`3oooooooooo`1_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;ooo
ool00onP8?3oooooooooo`0;ooooo`03oj0Pl?oooooooooo00Cooooo00GoX23`oooooooooooooooo
oj0Pl00Dooooo`03oj0Pl?oooooooooo057ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0@_ooool00oooO`3oooooooooo`0Zooooo`03oomo0?oooooooooo03oooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooonP8?0Tooooo`03oj0Pl?oooooooooo00?ooooo
00?oX23`ooooooooool03oooool00onP8?3oooooooooo`0:ooooo`;oX23`3?ooool00onP8?3ooooo
ooooo`03ooooo`03oj0Pl?oooooooooo02Cooooo00?oX23`ooooooooool0:Oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`0booooo`03oomo0?oooooooooo01Cooooo00?o
ogl0ooooooooO`000_ooool01?ooO`3oooooooooooooO`05ooooo`03oomo0?oooooooooo00Oooooo
00?oogl0ooooooooool0B?ooool00oooO`3oooooooooo`02ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00onP8?3oooooooooo`0Aooooo`03oj0Pl?oooooooooo00Gooooo
00?oX23`oooooonP8?000_ooool01OnP8?3oooooooooooooooooX23`00;ooooo00?oX23`oooooonP
8?001oooool01?nP8?3ooooooooooonP8?05ooooo`06oj0Pl?oooooooooooj0Pl?ooooooX23`1_oo
ool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool03ooo
ool2oj0Pl003oooooonP8?3ooooo03Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
ooooooooool0<Oooool00oooO`3oooooooooo`0Aooooo`;oogl01oooool01OooO`3ooooooooooooo
ooooogl000Kooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`1?ooooo`03o`000?oo
oooooooo00oooooo00Go0000oooooooooooooooooj0Pl00Pooooo`03oj0Pl?oooooooooo00oooooo
00?oX23`ooooooooool00oooool01OnP8?3oooooooooooooooooX23`00?ooooo00?oX23`oooooooo
ool01oooool00onP8?3oooooooooo`0cooooo`03oj0Pl?oooooooooo02cooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool0:?ooool00oooO`3oooooooooo`09ooooo`03oomo
0?oooooooooo03Cooooo00?oogl0ooooooooool00_ooool01OooO`3oooooooooooooooooogl000_o
oooo00?oogl0ooooooooool0;Oooool00oooO`3o0000ooooo`0@ooooo`03o`000?oooooooooo00Go
oooo00GoX23`oooooooooooooooooj0Pl00Hooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`oooo
ooooool00_ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00;ooooo0_nP8?001?oo
ooooX23`ooooooooool2oj0Pl0Cooooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oo
oooooooo00;ooooo00?oX23`ooooooooool03_ooool00onP8?3oooooooooo`1;ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo03Oooooo00?oogl0ooooooooool02_ooool0
0oooO`3oooooooooo`0Xooooo`03oomo0?oooooooooo03oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Oooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool01oooool0
0onP8?3oooooooooo`04ooooo`03oj0Pl?ooooooX23`00;oX23`00?ooooooj0Pl?nP8?001?ooool0
0onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool01Oooool0
0onP8?3oooooooooo`14ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
02Sooooo00?oogl0ooooooooool05?ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo
00Oooooo00?oogl0ooooooooool06Oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo
03Wooooo00?oogl0o`000?ooool04?ooool00ol0003ooooooj0Pl003ooooo`03oj0Pl?oooooooooo
02Oooooo00?oX23`ooooooooool02_ooool00onP8?3ooooooj0Pl006ooooo`04oj0Pl?ooooooX23`
oj0Pl0Gooooo00?oX23`ooooooooool02?ooool2oj0Pl0gooooo00?oX23`ooooooooool0B?ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`19ooooo`03oomo0?oooooooooo
06Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03oj0Pl?oooooooooo
017ooooo0_nP8?04ooooo`03oj0Pl?oooooooooo00?ooooo00WoX23`oooooooooooooooooj0Pl?oo
ooooX23`oooooonP8?001_ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?ooooooX23`00kooooo
00?oX23`oooooonP8?00B_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0oooooo`03oomo0?oooooooooo00Sooooo0_ooO`02ooooo`04oomo0?oooooooooooomo00Oooooo
00?oogl0ooooooooool01oooool00oooO`3oooooooooo`1;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0;Oooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo00?ooooo
00?oX23`ooooooooool03oooool00onP8?3oooooooooo`0@ooooo`04oj0Pl?oooooooooooj0Pl4[o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0=?ooool01OooO`3ooooo
ooooooooooooogl000Kooooo00Googl0oooooooooooooooooomo000>ooooo`;oogl000?ooooooomo
0?ooool0F_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?oX23`oooo
ooooool03?ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooo
ooooool00oooool2oj0Pl0gooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`02oooo
o`03oj0Pl?oooooooooo00Cooooo00?oX23`oooooonP8?002?ooool01OnP8?3ooooooooooooooooo
X23`01?ooooo00?oX23`ooooooooool02oooool00onP8?3oooooooooo`0/ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo03_ooooo00?oogl0ooooooooool03Oooool00ooo
O`3oooooooooo`02ooooo`;oogl000Cooooooomo0?ooooooogl01_ooool00oooO`3oooooooooo`1B
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00onP8?3oooooooooo`06
ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool02Oooool00onP8?3oooooooooo`0>
ooooo`03oj0Pl?oooooooooo05Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0=_ooool01OooO`3ooooooomo0?ooooooogl000Oooooo00Coogl0ooooooooooooogl02?oo
ool00oooO`3oooooooooo`05oomo00gooooo00?oogl0ooooooooool0Boooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Gooooo00?oX23`ooooooooool04Oooool00onP8?3ooooooooo
o`0?ooooo`04oj0Pl?ooooooooooooooo`;oX23`2_ooool00onP8?3oooooooooo`03ooooo`04oj0P
l?ooooooX23`oj0Pl1Oooooo00?oX23`ooooooooool02oooool00onP8?3oooooooooo`14ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03?ooooo00?oogl0ooooooooool0
1?ooool00oooO`3oooooooooo`04ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool0
2Oooool00oooO`3oooooooooo`0Booooo`03oomo0?oooooooooo04Gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0^ooooo`?oX23`3Oooool00onP8?3oooooooooo`07ooooo`03oj0P
l?oooooooooo00Oooooo00?oX23`oooooonP8?00G?ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`0kooooo`03oomo0?oooooooooo013ooooo00Googl0oooooooooooooooo
oomo0002ooooo`03oomo0?ooooooogl0027ooooo00?oogl0ooooooooool0=Oooool00ol0003ooooo
ooooo`0?ooooo`05o`000?oooooooooooooooonP8?002_ooool00onP8?3oooooooooo`0Looooo`03
oj0Pl?ooooooX23`00;ooooo00?oX23`oooooonP8?002Oooool00onP8?3oooooooooo`02ooooo`03
oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool0Goooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`0dooooo`03oomo0?oooooooooo00gooooo00?oogl0ooooooooool0
1oooool5oomo0005ooooooooO`3oogl0ooooooooO`000_ooool00oooO`3oooooooooo`0:ooooo`;o
ogl06_ooool00oooO`3oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000oj0Pl?oo
ool03?ooool00onP8?3oooooooooo`0Gooooo`03oj0Pl?oooooooooo00?oX23`0oooool00onP8?3o
ooooooooo`0?ooooo`05oj0Pl?oooooooooooooooonP8?001?ooool01?nP8?3ooooooooooonP8?04
ooooo`03oj0Pl?ooooooX23`027ooooo00?oX23`ooooooooool0>?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`0fooooo`03oomo0?oooooooooo01Gooooo00?oogl0oooo
ooooO`00H?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?oX23`oooo
ooooool00_ooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`oooo
ooooool01_ooool00onP8?3oooooooooo`09ooooo`07oj0Pl?oooooooooooooooonP8?3ooooooj0P
l003ooooo`05oj0Pl?oooooooooooooooonP8?003?ooool01OnP8?3oooooooooooooooooX23`01Ko
oooo00CoX23`ooooooooooooX23`<oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`0jooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool01_ooool01?ooO`3o
ooooooooooooO`03ooooo`03oomo0?oooooooooo00;ooooo0oooO`02ooooo`03oomo0?oooooooooo
00Kooooo00?oogl0ooooooooool0BOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Sooooo00?oX23`ooooooooool01_ooool00onP8?3ooooooj0Pl00;ooooo`;oX23`3?ooool01?nP
8?3ooooooooooonP8?05ooooo`03oj0Pl?ooooooX23`00_ooooo00?oX23`ooooooooool01Oooool0
0onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool0??ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0hooooo`03oomo0?oooooooooo
013ooooo00Coogl0oooooooooooooooo0_ooO`001oooooooogl0oomo0?ooooooogl0ooooooooO`00
0_ooool00oooO`3oooooooooo`1Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0_ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo01Wooooo00?oX23`ooooooooool0
1?ooool2oj0Pl0Gooooo00GoX23`oooooooooooooooooj0Pl003ooooo`05oj0Pl?ooooooX23`oooo
oonP8?000_ooool2oj0Pl005oooooonP8?3ooooooooooonP8?001?ooool4oj0Pl0Oooooo00?oX23`
ooooooooool05oooool00onP8?3oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo03gooooo0_ooO`0:ooooo`05oomo0?ooooooooooooooooooO`001oooool0
0oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo01cooooo00?oogl0ooooooooool0<oooool0
0ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooonP8?3ooooooj0Pl004ooooo`03oj0P
l?oooooooooo01Sooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`04ooooo`CoX23`
00Cooooooj0Pl?ooooooX23`4oooool01OnP8?3ooooooj0Pl?ooooooX23`013ooooo00?oX23`oooo
ooooool05?ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo037ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0BOooool01?ooO`3ooooooomo0?ooO`0<oooo
o`03oomo0?oooooooooo037ooooo00?oogl0ooooooooool08Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`0Boooo
o`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`02oooo
o`;oX23`1Oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooo
oonP8?001?ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?ooooooX23`05Gooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0??ooool00oooO`3oooooooooo`0;ooooo`03
oomo0?oooooooooo01Kooooo00?oogl0ooooooooool0Boooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Oooooo00?oX23`ooooooooool04?ooool00onP8?3oooooooooo`04ooooo`03
oj0Pl?oooooooooo027ooooo0_nP8?02ooooo`03oj0Pl?ooooooX23`00Sooooo00?oX23`oooooooo
ool00_ooool3oj0Pl0Wooooo00?oX23`ooooooooool05_ooool00onP8?3oooooooooo`0`ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04Oooooo00?oogl0ooooooooool0
9Oooool00oooO`3oooooooooo`0:ooooo`03oomo0?ooooooogl003;ooooo00?o0000ooooooooool0
3oooool01Ol0003oooooooooooooooooX23`00[ooooo00?oX23`ooooooooool01_ooool00onP8?3o
ooooooooo`09ooooo`03oj0Pl?oooooooooo00gooooo00?oX23`ooooooooool00onP8?0;ooooo`03
oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool01oooool00onP8?3ooooooj0Pl00Gooooo`04
oj0Pl?ooooooooooooooo`;oX23`>?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`1:ooooo`05oomo0?ooooooooooooooooooO`000oooool00oooO`3oooooooooo`02oooo
o`03oomo0?oooooooooo05Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0boooo
o`;oX23`2oooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00Gooooo00CoX23`oooo
ooooooooX23`0_ooool00onP8?3oooooooooo`03ooooo`05oj0Pl?oooooooooooooooonP8?006Ooo
ool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo02_ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0>?ooool00oooO`3oooooooooo`09ooooo`05oomo0?oooooo
ooooooooooooO`000_ooool00oooO`3oooooooooo`02ooooo`03oomo0?ooooooogl001[ooooo00Go
ogl0oooooooooooooooooomo000oooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooo
oooooj0Pl005ooooo`04oj0Pl?oooooooooooj0Pl0Wooooo00?oX23`ooooooooool03Oooool00onP
8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00;ooooo0_nP8?0Booooo`07oj0Pl?oooooooooo
oooooonP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo00Cooooo0_nP8?02ooooo`03oj0Pl?oo
oooooooo00Oooooo0_nP8?03ooooo`05oj0Pl?oooooooooooooooonP8?001Oooool00onP8?3ooooo
ooooo`0:ooooo`03oj0Pl?oooooooooo02_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0@Oooool00oooO`3oooooooooo`0Gooooo`03oomo0?oooooooooo05?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0gooooo`03oj0Pl?ooooooX23`00;ooooo00?o
X23`ooooooooool02oooool2oj0Pl003oooooonP8?3ooooo00?ooooo00?oX23`ooooooooool04?oo
ool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo047ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0A_ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooo
oooo00_ooooo00?oogl0ooooooooool0E?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Cooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooo
oooo013ooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`02ooooo`;oX23`1oooool2
oj0Pl0Oooooo00GoX23`oooooonP8?3ooooooj0Pl006ooooo`03oj0Pl?oooooooooo00Cooooo00?o
X23`ooooooooool04oooool00onP8?3oooooooooo`0hooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo03gooooo00?oogl0ooooooooool02Oooool00oooO`3oooooooooo`1U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00onP8?3oooooooooo`09
ooooo`03oj0Pl?oooooooooo01[ooooo00?oX23`ooooooooool01_ooool01?nP8?3ooooooooooooo
ool2oj0Pl003oooooonP8?3ooooo00Wooooo0_nP8?001_ooooooX23`ooooooooooooX23`ooooo`;o
X23`00Cooooooj0Pl?ooooooX23`0_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?ooooooX23`
00;ooooo00?oX23`ooooooooool02Oooool00onP8?3ooooooj0Pl00>ooooo`06oj0Pl?oooooooooo
oj0Pl?ooooooX23`:oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1A
ooooo`03oomo0?oooooooooo03?ooooo00?oogl0ooooooooool09oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00?oX23`ooooooooool0@?ooool00onP8?3oooooooooo`06
ooooo`03oj0Pl?ooooooX23`00Oooooo00?oX23`oooooonP8?002_ooool00onP8?3oooooooooo`06
ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool0<oooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`0mooooo`03oomo0?oooooooooo00[ooooo00?oogl0oooo
ooooool01Oooool00oooO`3oooooooooo`0Looooo`03oomo0?oooooooooo03gooooo00?o0000oooo
ooooool03oooool00onP8?3ooooooj0Pl00fooooo`04oj0Pl?ooooooX23`oj0Pl0Sooooo00OoX23`
oooooooooooooooooj0Pl?ooooooX23`00Sooooo0_nP8?02ooooo`04oj0Pl?ooooooX23`oj0Pl0Co
oooo00?oX23`oooooonP8?000oooool2oj0Pl0Kooooo00GoX23`oooooonP8?3ooooooj0Pl011oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04oooooo00?oogl0oooooooo
ool0Goooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo00?oX23`oooooooo
ool05Oooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`oooooooo
ool00_ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooooooo
ool02Oooool01OnP8?3oooooooooooooooooX23`03Cooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0?Oooool2oomo0003ooooooooO`3ooooo00;ooooo00?oogl0oooooooo
O`001oooool00oooO`3oooooooooo`0@ooooo`03oomo0?oooooooooo01[ooooo00?oogl0oooooooo
ool0<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?oX23`oooooooo
ool00oooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?ooooooX23`01Cooooo0_nP8?05ooooo`;o
X23`0_ooool2oj0Pl0?ooooo00?oX23`oooooonP8?000oooool00onP8?3ooooooj0Pl002ooooo`03
oj0Pl?oooooooooo00;ooooo0_nP8?000oooooooX23`ooooo`02ooooo`;oX23`0oooool00onP8?3o
ooooooooo`06ooooo`03oj0Pl?oooooooooo00Oooooo00KoX23`ooooooooooooX23`oooooonP8?04
ooooo`03oj0Pl?oooooooooo02kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0P?ooool00oooO`3oooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00?o0000oj0P
l?ooool0??ooool00onP8?3ooooooj0Pl005ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooo
ooooool00oooool01OnP8?3ooooooooooonP8?3ooooo00;oX23`2Oooool00onP8?3oooooooooo`08
ooooo`03oj0Pl?oooooooooo00gooooo00?oX23`ooooooooool0<_ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`1Nooooo`03oomo0?oooooooooo00oooooo00?oogl0oooo
ooooool04?ooool00oooO`3oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01?ooool00onP8?3oooooooooo`0Iooooo`03oj0Pl?oooooooooo01Kooooo00?oX23`oooo
ooooool07oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00;oX23`0_ooool00onP
8?3oooooooooo`15ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04Co
oooo00?oogl0ooooooooO`000oooool2oomo00Kooooo00?oogl0ooooooooool0;?ooool01OooO`3o
ooooooooooooooooogl002_ooooo00?o0000ooooooooool03oooool00onP8?3oooooooooo`04oooo
o`03oj0Pl?oooooooooo02Wooooo00?oX23`ooooooooool03_ooool01?nP8?3ooooooj0Pl?nP8?03
ooooo`?oX23`0_ooool01?nP8?3ooooooooooonP8?04ooooo`?oX23`1_ooool00onP8?3ooooooj0P
l002ooooo`?oX23`1_ooool01?nP8?3oooooooooooooool2oj0Pl0Kooooo00?oX23`ooooooooool0
2Oooool00onP8?3oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03oj0Pl?oo
oooooooo013ooooo00?oX23`ooooooooool06?ooool00onP8?3oooooooooo`02ooooo`04oj0Pl?oo
ooooX23`ooooo`;oX23`00?ooooooj0Pl?nP8?001Oooool01?nP8?3ooooooooooonP8?0Booooo`03
oj0Pl?oooooooooo00?ooooo00OoX23`oooooooooooooooooj0Pl?ooooooX23`00Oooooo00?oX23`
ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1@oooo
o`03oomo0?oooooooooo017ooooo00?oogl0ooooooooool04Oooool00oooO`3oooooooooo`0foooo
o`03o`000?oooooooooo00oooooo00?oX23`ooooooooool07?ooool00onP8?3oooooooooo`0Goooo
o`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01Oooool4oj0Pl003oooooonP8?3oX23`
00?ooooo0_nP8?000oooooooX23`ooooo`02oj0Pl0?ooooo00?oX23`ooooooooool00_ooool00onP
8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo00?ooooo0_nP8?02ooooo`04oj0Pl?oooooooooo
ooooo`;oX23`0_ooool00onP8?3ooooooj0Pl008ooooo`03oj0Pl?oooooooooo02kooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0J_ooool00oooO`3oooooooooo`03oooo
o`;oogl01oooool00oooO`3oooooooooo`0eooooo`03o`000?oooooooooo00oooooo00?oX23`oooo
ooooool0;_ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`oooo
ooooool00_ooool2oj0Pl0;ooooo0_nP8?02ooooo`04oj0Pl?oooooooooooj0Pl0?ooooo00?oX23`
ooooooooool01Oooool00onP8?3oooooooooo`0Aooooo`03oj0Pl?oooooooooo02Kooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0DOooool01OooO`3ooooooooooooooooo
ogl001_ooooo00?oogl0ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Cooooo00?oX23`ooooooooool07_ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooo
oooo01gooooo00?oX23`ooooooooool00_ooool2oj0Pl0[ooooo00?oX23`ooooooooool03?ooool0
1?nP8?3ooooooooooonP8?0booooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo04gooooo00?oogl0ooooooooO`002_ooool01?ooO`3oooooooooooooO`05ooooo`03oomo0?oo
oooooooo00gooooo00?oogl0ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Gooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oo
oooooooo00Cooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oo
oooooooo00;oX23`00Cooooooj0Pl?ooooooX23`0oooool01OnP8?3ooooooj0Pl?nP8?3ooooo00;o
X23`00Cooooooj0Pl?oooooooooo1?nP8?04ooooo`?oX23`0oooool00onP8?3ooooooj0Pl002oooo
o`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool09Oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`1]ooooo`03oomo0?oooooooooo02Gooooo00Googl0oooooooo
oooooooooomo000Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0A?ooool00onP
8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01_ooool01OnP
8?3oooooooooooooooooX23`00?ooooo00GoX23`oooooooooooooooooj0Pl00Eooooo`03oj0Pl?oo
oooooooo00Kooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`0Iooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo07;ooooo00?oogl0ooooooooO`003_ooool0
0oooO`3oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000oooooonP8?002oooool0
0onP8?3oooooooooo`0dooooo`05oj0Pl?ooooooX23`oooooonP8?001_ooool00onP8?3ooooooooo
o`03ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooonP8?002?ooool3oj0Pl0Gooooo00?o
X23`ooooooooool00_ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`ooooooooool00_ooool00onP8?3oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo05Oooooo00?oogl0ooooooooool06oooool00oooO`3oooooooooo`0F
ooooo`03oomo0?oooooooooo023ooooo00?o0000ooooooooool03oooool2oj0Pl1;ooooo00?oX23`
ooooooooool08Oooool00onP8?3oooooooooo`08ooooo`04oj0Pl?oooooooooooj0Pl0;ooooo00?o
X23`ooooooooool03Oooool00onP8?3oooooooooo`0@ooooo`05oj0Pl?oooooooooooooooonP8?00
3?ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo02gooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0Boooool00oooO`3oooooooooo`02oomo0003oooooooo
O`3ooooo00kooooo00?oogl0ooooooooool0?Oooool00oooO`3oooooooooo`0=ooooo`03o`000?oo
oooooooo00oooooo00?oX23`ooooooooool04?ooool00onP8?3oooooooooo`0Mooooo`03oj0Pl?oo
oooooooo00kooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`07ooooo`04oj0Pl?oo
oooooooooj0Pl0?ooooo00?oX23`oooooonP8?000_ooool2oj0Pl0?ooooo00?oX23`ooooooooool0
2?ooool01?nP8?3ooooooooooonP8?0;ooooo`04oj0Pl?ooooooX23`oj0Pl3;ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0D?ooool00oooO`3oooooooooo`02ooooo`03
oomo0?oooooooooo00Kooooo00?oogl0ooooooooool0D?ooool00ol0003oooooooooo`0?ooooo`03
oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`0Eooooo`03
oj0Pl?oooooooooo00kooooo00?oX23`oooooonP8?001_ooool00onP8?3oooooooooo`05ooooo`04
oj0Pl?oooooooooooj0Pl0;ooooo0_nP8?05ooooo`05oj0Pl?oooooooooooooooonP8?000_ooool0
0onP8?3oooooooooo`0;ooooo`03oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool09_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1>ooooo`03oomo0?oooooooooo
063ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Mooooo`;oX23`0_ooool00onP
8?3oooooooooo`04ooooo`0;oj0Pl?oooooooooooooooonP8?3ooooooj0Pl?ooooooX23`oooooonP
8?002_ooool00onP8?3oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo05Cooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`06ooooo`03oomo
0?ooooooogl000gooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`0[ooooo`03o`00
0?oooooooooo00oooooo00?o0000oj0Pl?ooool05Oooool00onP8?3oooooooooo`09ooooo`03oj0P
l?oooooooooo02Cooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0;ooooo`03oj0P
l?oooooooooo00;ooooo00?oX23`ooooooooool00_nP8?02ooooo`04oj0Pl?oooooooooooj0Pl0Ko
oooo0_nP8?05ooooo`03oj0Pl?oooooooooo00;ooooo0onP8?02ooooo`03oj0Pl?oooooooooo02co
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0F_ooool00oooO`3ooooo
ooooo`1Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool00onP8?3ooooo
ooooo`0Gooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool01oooool00onP8?3ooooo
ooooo`05ooooo`03oj0Pl?oooooooooo00gooooo00CoX23`oooooooooooooooo0_nP8?0;ooooo`03
oj0Pl?oooooooooo02;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
G?ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooool0
1Oooool00oooO`3ooooooomo0007ooooo`03oomo0?oooooooooo02gooooo00?o0000ooooooooool0
3oooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo02gooooo00?oX23`ooooooooool0
1oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00Kooooo00CoX23`oooooonP8?3o
X23`0_ooool01?nP8?3ooooooj0Pl?ooool2oj0Pl007oooooonP8?3oX23`oooooonP8?3ooooooj0P
l002ooooo`03oj0Pl?oooooooooo00?ooooo0_nP8?05ooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`oooooonP8?001?ooool00onP8?3oooooooooo`0Wooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo06Kooooo00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`0o
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool01OnP8?3ooooooooooooo
ooooX23`00Gooooo0onP8?04ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool00ooo
ool01_nP8?3ooooooooooonP8?3ooooooj0Pl0?ooooo00?oX23`ooooooooool0;Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1]ooooo`03oomo0?oooooooooo00gooooo
00?oogl0ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Gooooo
0_nP8?04ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool01?ooool01?nP8?3ooooo
oooooonP8?0looooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo05;ooooo
00?oogl0ooooooooool00oooool01oooO`3oooooooooooooooooogl0ooooooooO`001?ooool00ooo
O`3oooooooooo`05ooooo`;oogl0A?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04cooooo00?oX23`ooooooooool02Oooool2oj0Pl0Kooooo00GoX23`oooooonP8?3ooooooj0Pl002
ooooo`04oj0Pl?oooooooooooj0Pl0?ooooo00?oX23`ooooooooool00oooool2oj0Pl13ooooo00?o
X23`ooooooooool02_ooool00onP8?3oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo05?ooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`03
ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool0@oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03cooooo00?oX23`ooooooooool01oooool00onP8?3oooooooooo`04
ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool00_ooool01OnP8?3ooooooooooooo
ooooX23`00;ooooo00?oX23`ooooooooool02?ooool2oj0Pl1Cooooo0_nP8?06ooooo`04oj0Pl?oo
oooooooooj0Pl0kooooo00?oX23`ooooooooool04_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`1Eooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool00ooo
ool00oooO`3oooooooooo`0Qooooo`03oomo0?oooooooooo02Cooooo00?oogl0ooooooooool00_oo
ool00ol0003oooooooooo`0?ooooo`;oX23`0_ooool00onP8?3oooooooooo`0gooooo`03oj0Pl?oo
ooooX23`01Kooooo00?oX23`ooooooooool01?ooool01?nP8?3ooooooooooonP8?03ooooo`05oj0P
l?oooooooooooj0Pl?ooool00_nP8?000oooooooX23`ooooo`03ooooo`03oj0Pl?oooooooooo00?o
oooo0onP8?05ooooo`;oX23`0oooool01OnP8?3oooooooooooooooooX23`02[ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0Joooool00oooO`3oooooooooo`0>ooooo`03
oomo0?oooooooooo00_ooooo00?oogl0ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03
oj0Pl?oooooooooo05Kooooo0_nP8?0;ooooo`05oj0Pl?oooooooooooooooonP8?000oooool00onP
8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo00Wooooo0_nP8?0]ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo05Gooooo00?oogl0ooooooooool01Oooool2oomo00;o
oooo00?oogl0ooooooooool03oooool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo037o
oooo00?o0000ooooooooool03oooool00onP8?3oooooooooo`1=ooooo`04oj0Pl?oooooooooooj0P
l0Cooooo00GoX23`ooooooooooooX23`ooooo`03oj0Pl0Sooooo00?oX23`oooooonP8?001?ooool0
1OnP8?3ooooooooooonP8?3ooooo00;oX23`0oooool00onP8?3oooooooooo`02ooooo`;oX23`1?oo
ool2oj0Pl004oooooonP8?3ooooooj0Pl0;ooooo00?oX23`ooooooooool09Oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`1Fooooo`09oomo0?ooooooogl0ooooooooO`3o
oooooomo0?ooooooogl005;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Noooo
o`03oj0Pl?oooooooooo00oooooo00OoX23`oooooooooooooooooj0Pl?ooooooX23`013ooooo0_nP
8?0Xooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Gooooo00?oogl0
ooooooooool02Oooool00oooO`3oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02oooool00onP8?3oooooooooo`16ooooo`04oj0Pl?ooooooooooooooo`;oX23`0ooo
ool00onP8?3oooooooooo`0;ooooo`;oX23`3_ooool01OnP8?3oooooooooooooooooX23`00Cooooo
00?oX23`ooooooooool01?ooool00onP8?3ooooooj0Pl00Sooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo05[ooooo00Coogl0oooooooooooooooo0oooO`000oooooooogl0
oomo000=ooooo`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooool03_ooool00oooO`3ooooo
ooooo`0Oooooo`03o`000?oooooooooo00oooooo00GoX23`oooooooooooooooooj0Pl00Iooooo`03
oj0Pl?oooooooooo01[ooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`0:ooooo`?o
X23`00?ooooooj0Pl?ooool03Oooool00onP8?3oooooooooo`0<ooooo`?oX23`00?ooooooj0Pl?oo
ool02?ooool00onP8?3oooooooooo`02ooooo`07oj0Pl?oooooooooooooooonP8?3ooooooj0Pl00S
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo05[ooooo00?oogl0oooo
ooooool01?ooool00oooO`3oooooooooo`0@ooooo`03oomo0?oooooooooo00Wooooo00?oogl0oooo
ooooool01Oooool00oooO`3oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?oX23`oooo
ooooool0H?ooool00onP8?3oooooooooo`0Eooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooo
ooooool02?ooool01OnP8?3ooooooj0Pl?ooooooX23`02Cooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0G?ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo
00Gooooo00?oogl0ooooooooool01_ooool00oooO`3ooooooomo000>ooooo`03oomo0?oooooooooo
00_ooooo00?oogl0ooooooooool06oooool00ol0003oooooooooo`0?ooooo`;oX23`1?ooool00onP
8?3oooooooooo`0/ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool06Oooool01?nP
8?3ooooooj0Pl?ooool2oj0Pl1Sooooo00?oX23`ooooooooool04_ooool01?nP8?3ooooooooooooo
ool3oj0Pl0Oooooo00?oX23`ooooooooool05oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool0
0onP8?3oooooooooo`0:ooooo`03oj0Pl?oooooooooo02Oooooo00?oX23`ooooooooool03Oooool0
0onP8?3oooooooooo`03ooooo`04oj0Pl?oooooooooooj0Pl0Kooooo0_nP8?0Dooooo`04oj0Pl?oo
ooooooooooooo`;oX23`8Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`1_ooooo`03oomo0?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`18ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooooo
o`05ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool01_ooool00onP8?3ooooooooo
o`0=ooooo`;oX23`00?ooooooj0Pl?nP8?001?ooool00onP8?3oooooooooo`0Jooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo05kooooo00?oogl0ooooooooool03?ooool0
0oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo01Sooooo00?oogl0ooooooooool06_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?nP8?3ooooo01?ooooo00?oX23`ooooooooool0>_ooool0
0onP8?3oooooooooo`04ooooo`03oj0Pl?ooooooX23`00Oooooo00?oX23`ooooooooool00oooool0
0onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`oooooonP8?003_ooool0
1?nP8?3ooooooj0Pl?nP8?03ooooo`;oX23`0_ooool00onP8?3oooooooooo`0Mooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Gooooo00?oogl0ooooooooool03?ooool0
0oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo03Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Xooooo`03oj0Pl?ooooooX23`00Cooooo00?oX23`ooooooooool05Oooool0
0onP8?3oooooooooo`04ooooo`03oj0Pl?ooooooX23`023ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0J?ooool2oomo00Wooooo00?oogl0ooooooooO`002?ooool00ooo
O`3oooooooooo`0@ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool00_ooool00ooo
O`3oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool00onP
8?3oooooooooo`0Eooooo`;oX23`00?ooooooj0Pl?ooool01Oooool00onP8?3oooooooooo`02oooo
o`03oj0Pl?oooooooooo00;ooooo00KoX23`ooooooooooooX23`oooooonP8?0<ooooo`03oj0Pl?oo
oooooooo00;ooooo00?oX23`ooooooooool01Oooool3oj0Pl005oooooonP8?3ooooooooooonP8?00
6oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0@oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oo
oooooooo01Kooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oo
oooooooo00Kooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oo
ooooX23`00Gooooo00?oX23`ooooooooool06_ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`1Sooooo`03oomo0?ooooooogl000;ooooo00?oogl0ooooooooool01oooool0
0oooO`3oooooooooo`0looooo`03o`000?oooooooooo00oooooo00?o0000oj0Pl?ooool0COooool0
0onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`ooooooooool03_ooool0
0onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`oooooonP8?000_ooool0
0onP8?3oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
07Cooooo00?oogl0ooooooooool05Oooool00oooO`3oooooooooo`0Rooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0F_ooool01_nP8?3oooooooooooooooooX23`ooooo`;oX23`1Ooo
ool01?nP8?3ooooooj0Pl?nP8?02ooooo`04oj0Pl?ooooooX23`oj0Pl0Cooooo00GoX23`oooooooo
oooooooooj0Pl007ooooo`04oj0Pl?ooooooX23`oj0Pl0Gooooo00CoX23`oooooonP8?3oX23`0ooo
ool2oj0Pl004oooooonP8?3oX23`oj0Pl1[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0O_ooool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00Gooooo00?o
ogl0ooooooooool02oooool00oooO`3oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0IOooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?oooooooooo00Wooooo0onP
8?04ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool02?ooool00onP8?3ooooooooo
o`0Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Kooooo00Coogl0
oooooooooooooooo0_ooO`0Hooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool00ooo
ool00oooO`3oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Cooo
ool00onP8?3oooooooooo`0>ooooo`05oj0Pl?oooooooooooooooonP8?001?ooool2oj0Pl0Cooooo
00CoX23`ooooooooooooX23`0oooool2oj0Pl0[ooooo0_nP8?09ooooo`;oX23`1_ooool00onP8?3o
ooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Wooooo
0oooO`15ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0G_ooool2oj0Pl0_ooooo
00?oX23`ooooooooool03_ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00;ooooo
00CoX23`ooooooooooooX23`1?ooool2oj0Pl1[ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0I_ooool01?ooO`3oooooooooooooool2oomo0003ooooooooO`3ooooo00Go
oooo0_ooO`07ooooo`03oomo0?ooooooogl000[ooooo00Coogl0ooooooooooooogl02?ooool00ooo
O`3oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00onP
8?3oooooooooo`14ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool01Oooool01?nP
8?3ooooooooooonP8?03ooooo`03oj0Pl?oooooooooo00;oX23`1?ooool00onP8?3oooooooooo`04
ooooo`04oj0Pl?oooooooooooj0Pl0;ooooo00?oX23`ooooooooool00oooool01_nP8?3ooooooooo
oonP8?3ooooooj0Pl1gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
JOooool00oooO`3oooooooooo`0Iooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool0
7oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?oX23`ooooooooool0
GOooool00onP8?3oooooooooo`03ooooo`05oj0Pl?oooooooooooooooonP8?000oooool3oj0Pl0oo
oooo00?oX23`oooooonP8?002?ooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo01Oo
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0NOooool00oooO`3ooooo
ooooo`0Cooooo`03oomo0?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oX23`
ooooo`1Aooooo`03oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool00_ooool2oj0Pl0?ooooo
00?oX23`ooooooooool01_ooool01?nP8?3ooooooooooonP8?02ooooo`?oX23`00?ooooooj0Pl?oo
ool02_ooool00onP8?3oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo06_ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0@ooooo`03oomo
0?oooooooooo00[ooooo00Ooogl0oooooooooooooooooomo0?ooooooogl001Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Uooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooo
ooooool01Oooool2oj0Pl0Cooooo0_nP8?02ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooo
ooooool00oooool00onP8?3oooooooooo`0;ooooo`04oj0Pl?ooooooooooooooo`;oX23`5_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1_ooooo`03oomo0?oooooooooo
01?ooooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`0Kooooo`03o`000?oooooooooo
00oooooo00?oX23`ooooooooool0H_ooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo
00Kooooo00KoX23`ooooooooooooX23`oooooonP8?02ooooo`03oj0Pl?oooooooooo00Wooooo00?o
X23`ooooooooool00oooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo01Gooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Koooool4oomo0006ooooooooO`3o
oooooomo0?ooooooogl04Oooool01?ooO`3oooooooooooooO`05ooooo`03oomo0?oooooooooo01_o
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooonP8?1Tooooo`03oj0Pl?oooooooooo
00;ooooo00?oX23`ooooooooool01Oooool7oj0Pl0;ooooo0_nP8?04ooooo`;oX23`1_ooool00onP
8?3oooooooooo`03ooooo`;oX23`8?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`1kooooo`;oogl02?ooool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo01oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Kooooo`03oj0Pl?oooooooooo01So
oooo0onP8?000oooooooX23`oj0Pl00Dooooo`;oX23`1?ooool00onP8?3oooooooooo`0Hooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo07Kooooo00?oogl0ooooooooool0
1Oooool00oooO`3oooooooooo`03ooooo`03oomo0?ooooooogl002[ooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooonP8?1Mooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`oooooooo
ool02_ooool00onP8?3oooooooooo`07ooooo`07oj0Pl?ooooooX23`oooooonP8?3ooooooj0Pl00<
ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool05?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`1gooooo`03oomo0?oooooooooo00Gooooo00?oogl0oooo
ooooool0;oooool00ol0003oooooooooo`0?ooooo`03o`000?nP8?3oX23`05Cooooo0onP8?0Foooo
o`05oj0Pl?oooooooooooooooonP8?001oooool01OnP8?3oooooooooooooooooX23`00Cooooo00Co
X23`oooooonP8?3ooooo0_nP8?001?ooooooX23`oooooonP8?0>ooooo`03oj0Pl?oooooooooo01Co
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0M?ooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?oooooooooo03Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1_ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooooonP8?001?ooool00onP8?3ooooo
ooooo`03ooooo`05oj0Pl?oooooooooooooooonP8?00:Oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`1dooooo`;oogl000Cooooooomo0?ooooooogl01?ooool00oooO`3o
ooooooooo`0Eooooo`03oomo0?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0oooooo`03oj0Pl?oooooooooo01Kooooo0_nP8?0Nooooo`04oj0Pl?oooooooooooj0P
l0?ooooo00CoX23`ooooooooooooX23`0oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Koooool00ooo
O`3oooooooooo`02ooooo`;oogl06oooool00oooO`3oooooooooo`0Mooooo`03o`000?oooooooooo
00oooooo00?oX23`ooooooooool0LOooool00onP8?3oooooooooo`06ooooo`04oj0Pl?oooooooooo
oj0Pl0Gooooo00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`0Pooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo07Oooooo00?oogl0ooooooooool01oooool01ooo
O`3ooooooomo0?ooooooogl0ooooooooO`002oooool00oooO`3oooooooooo`0;ooooo`03oomo0?oo
oooooooo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1dooooo`03oj0Pl?oo
oooooooo00Oooooo00OoX23`oooooooooooooooooj0Pl?ooooooX23`00;ooooo0_nP8?03ooooo`03
oj0Pl?oooooooooo02;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
NOooool2oomo00?ooooo00?oogl0ooooooooool02Oooool01_ooO`3oooooooooooooO`3ooooooomo
027ooooo00?o0000ooooooooool03oooool00onP8?3oooooooooo`1Mooooo`03oj0Pl?oooooooooo
01cooooo00?oX23`ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`1iooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool03Oooool00oooO`3o
ooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Noooool00onP8?3o
oooooj0Pl003ooooo`03oj0Pl?oooooooooo02gooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0NOooool00oooO`3oooooooooo`02ooooo`?oogl02oooool00oooO`3ooooo
ooooo`02ooooo`;oogl03?ooool00oooO`3oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00Ko0000oooooonP8?3oX23`oooooonP8?1>ooooo`03oj0Pl?oooooooooo01gooooo00KoX23`oooo
ooooooooX23`oooooonP8?05ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool01?oo
ool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo01_ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0Noooool01?ooO`3oooooooooooooO`0;ooooo`03oomo0?oo
oooooooo00Wooooo00?oogl0ooooooooO`003_ooool00oooO`3oooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Q_ooool00onP8?3oooooooooo`0Xooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo07Sooooo00?oogl0ooooooooool01_ooool0
1?ooO`3oooooooooooooO`0Gooooo`;oogl04oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
ooooX23`07Wooooo00CoX23`ooooooooooooX23`0oooool01OnP8?3oooooooooooooooooX23`00Co
oooo00?oX23`oooooonP8?009Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`1iooooo`03oomo0?oooooooooo01cooooo00?oogl0ooooooooool05_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03[ooooo00?oX23`ooooooooool0=_ooool00onP8?3ooooo
oj0Pl005ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool0;?ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`21ooooo`03oomo0?oooooooooo00;ooooo00?o
ogl0ooooooooool01_ooool01oooO`3oooooooooooooooooogl0ooooooooO`004Oooool00oooO`3o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?oX23`ooooooooool0J_ooool00onP8?3o
ooooooooo`0?ooooo`04oj0Pl?oooooooooooj0Pl37ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0P?ooool01_ooO`3oooooooooooooO`3ooooooomo00?ooooo0_ooO`02
ooooo`04oomo0?oooooooooooomo00Gooooo00?oogl0ooooooooool01?ooool00oooO`3ooooooooo
o`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Ioooool00onP8?3ooooooooo
o`05ooooo`04oj0Pl?oooooooooooj0Pl17ooooo00?oX23`ooooooooool02oooool00onP8?3ooooo
ooooo`0Looooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo07;ooooo00?o
ogl0ooooooooool03?ooool2oomo0003ooooooooO`3oogl000Cooooo00?oogl0ooooooooool01_oo
ool3oomo0004ooooooooO`3ooooooomo01Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1kooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool0:_ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`24ooooo`03oomo0?oooooooooo00Cooooo00?o
ogl0ooooooooO`001Oooool01OooO`3ooooooomo0?ooooooogl001Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1]ooooo`;oX23`00?ooooooj0Pl?ooool03Oooool01?nP8?3ooooo
oooooonP8?02ooooo`;oX23`3Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01Go
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0O_ooool00oooO`3ooooo
oomo0003ooooo`04oomo0?oooooooooooomo00;ooooo00?oogl0ooooooooO`001Oooool00oooO`3o
ooooooooo`06ooooo`03oomo0?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1gooooo`03oj0Pl?oooooooooo00;ooooo00CoX23`ooooooooooooX23`1?ooool00onP
8?3oooooooooo`0=ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool03?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1nooooo`03oomo0?oooooooooo00;o
oooo0_ooO`02ooooo`Coogl000?ooooooomo0?ooool00_ooO`000oooooooogl0ooooo`02ooooo`;o
ogl00oooool2oomo0003ooooooooO`3ooooo01;ooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooonP8?1Yooooo`03oj0Pl?oooooooooo00_ooooo00CoX23`ooooooooooooX23`0oooool0
0onP8?3oooooooooo`05ooooo`05oj0Pl?ooooooX23`oooooonP8?000_ooool00onP8?3ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo07Wooooo00?oogl0
ooooooooool01?ooool00oooO`3oooooooooo`03ooooo`?oogl000?ooooooomo0?ooO`000oooO`00
1?ooooooogl0ooooooooO`04ooooo`03oomo0?oooooooooo01Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1hooooo`03oj0Pl?oooooooooo00gooooo0_nP8?04ooooo`03oj0Pl?oo
oooooooo023ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0ROooool0
1?ooO`3oooooooooooooO`02ooooo`05oomo0?ooooooooooooooooooO`000_ooool3oomo01Sooooo
00?o0000ooooooooool03oooool00onP8?3oooooooooo`1looooo`05oj0Pl?oooooooooooooooonP
8?002?ooool3oj0Pl2Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
R_ooool01OooO`3ooooooomo0?ooO`3ooooo00;oogl000?ooooooomo0?ooool00oooO`000ooooooo
ogl0ooooo`02oomo0003ooooooooO`3ooooo01;ooooo00?o0000ooooooooool03oooool00onP8?3o
ooooooooo`1fooooo`04oj0Pl?ooooooooooooooo`;oX23`0oooool00onP8?3oooooooooo`06oooo
o`;oX23`00Cooooooj0Pl?ooooooX23`8oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`2<ooooo`Coogl000?ooooooomo0?ooO`000oooool00oooO`3oooooooooo`0Hoooo
o`03o`000?oooooooooo00oooooo00?o0000oooooonP8?00M_ooool00onP8?3oooooooooo`02oooo
o`06oj0Pl?oooooooooooooooonP8?3ooooo0onP8?08ooooo`03oj0Pl?oooooooooo02;ooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Roooool3oomo0003ooooooooO`3o
ogl000Koogl000Kooooooomo0?ooO`3oogl0ooooooooO`04ooooo`03oomo0?oooooooooo00gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1hooooo`03oj0Pl?oooooooooo00;ooooo
00CoX23`oooooonP8?3ooooo0_nP8?000oooooooX23`ooooo`02ooooo`;oX23`00?ooooooj0Pl?nP
8?000_nP8?0;ooooo`03oj0Pl?oooooooooo01Cooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0R_ooool01?ooO`3ooooooomo0?ooool4oomo0003ooooooooO`3ooooo00;o
ogl000?ooooooomo0?ooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oo
oooo00?oX23`ooooooooool09?ooool01OnP8?3oooooooooooooooooX23`00Cooooo0_nP8?02oooo
o`06oj0Pl?oooooooooooj0Pl?ooooooX23`8?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`27ooooo`;oogl01_ooool6oomo00?ooooo00?oogl0ooooooooool05_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07[ooooo00?oX23`ooooooooool00_ooool0
0onP8?3ooooooj0Pl008ooooo`;oX23`9Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`26ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool00oooO`001?oo
ooooogl0oomo0?ooool4oomo0003ooooooooO`3oogl001Cooooo00?o0000ooooooooool03oooool0
0onP8?3oooooooooo`0nooooo`03oj0Pl?oooooooooo037ooooo00?oX23`ooooooooool00_ooool0
0onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00;ooooo0_nP8?02ooooo`;oX23`1Oooool2
oj0Pl2;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0QOooool00ooo
O`3oooooooooo`08ooooo`03oomo0?ooooooogl000Coogl000?ooooooomo0?ooO`005oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo07gooooo00?oX23`ooooooooool00oooool2oj0P
l2cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Poooool00oooO`3o
ooooooooo`0<ooooo`?oogl000Gooooooomo0?ooO`3oogl0ooooo`04oomo00;ooooo00?oogl0oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo00?oX23`oooo
ooooool0E?ooool00onP8?3oooooooooo`02ooooo`CoX23`00?ooooooj0Pl?ooool0:?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Dooooo`03oomo0?ooooooogl000;o
ogl00_ooool01?ooO`3oooooooooooooO`0Booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Q_ooool4oj0Pl0cooooo00?oX23`ooooooooool06?ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`2Fooooo`03oomo0?ooooooogl000?oogl000?ooooooomo0?oo
ool04_ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo07kooooo00GoX23`oooooooo
oooooooooj0Pl003ooooo`GoX23`1Oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo
01Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0V?ooool01oooO`3o
ooooooooooooooooogl0ooooooooO`004_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Wooooo00?oX23`ooooooooool0E_ooool00onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooo
oooo00Cooooo00?oX23`ooooooooool05?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`2Iooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool02oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo08Oooooo00GoX23`oooooooooooooooooj0Pl007
ooooo`03oj0Pl?oooooooooo01_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0Soooool00oooO`3oooooooooo`0:ooooo`04oomo0?oooooooooooomo017ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1_ooooo`03oj0Pl?oooooooooo01;ooooo00?oX23`
ooooooooool01?ooool01?nP8?3ooooooooooonP8?06ooooo`03oj0Pl?ooooooX23`01Wooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Woooool00oooO`3oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00onP8?3oooooooooo`10
ooooo`03oj0Pl?oooooooooo02Gooooo00?oX23`ooooooooool03Oooool01OnP8?3ooooooooooooo
ooooX23`017ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0/Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?oX23`ooooooooool0>oooool0
0onP8?3oooooooooo`0Tooooo`03oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool00_ooool0
0onP8?3oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
09cooooo00?oogl0ooooooooO`004_ooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo
09Wooooo00?oX23`ooooooooool05Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2Jooooo`;oogl05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06_o
oooo00?oX23`ooooooooool0@oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`2aooooo`03o`000?oooooooooo00oooooo0_nP8?04ooooo`03oj0Pl?oooooooooo037ooooo
00?oX23`ooooooooool0I?ooool3oj0Pl13ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0U_ooool00oooO`3oooooooooo`09ooooo`;oogl03Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Gooooo00?oX23`ooooooooool0Ioooool00onP8?3ooooooj0P
l00?ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0:7ooooo00?oogl0
ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo00?oX23`
ooooooooool01Oooool00onP8?3oooooooooo`1Fooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`03oj0Pl?oooooooooo0:cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool0XOooool2oomo0003ooooooooO`3ooooo00;oogl01_ooool01?ooO`3ooooooomo0?l0000Aoooo
o`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool0SOooool00onP8?3oooooooooo`0Goooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0:Oooooo00?oogl0oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?oX23`oooooooo
ool0Woooool2oj0Pl0_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:Cooooo00?oX23`oooooonP8?00
2_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oo
oooooooo00oooooo00Co0000oj0Pl?ooooooX23`/?ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOoo
ool00onP8?3oooooooooo`0mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooooooX23`05gooooo00?o
X23`ooooooooool0A_ooool01OnP8?3oooooooooooooooooX23`00Cooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0Z_ooool01OooO`3oooooooooooooooooogl000;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`22ooooo`03oj0Pl?ooooooX23`02_ooooo
00?oX23`o`000?ooool02_ooool000[ooooo00?o0000ooooooooool0[oooool00oooO`3oooooo`00
000Aooooo`03o`000?oooooooooo04Gooooo00?oX23`ooooooooool0IOooool01OnP8?3ooooooooo
oonP8?3o000000_ooooo000:oooook?o000000?oogl0o`000?ooool04?ooool5o`0000;oX23`00?o
0000oj0Pl?l000000_l000000onP8?3o0000o`00000^o`000004oj0Pl?l0003o0000oj0Pl6?o0000
00?oX23`o`000?l000002Ol00002oj0Pl0?o00002oooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-14.4237, \
-6.63736, 1.4157, 1.4157}, {{208.5, 388.938}, {184.875, 4.5}} -> {-295.249, \
-6.59083, 1.41521, 1.41521}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian models", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[{
    \(\(d2d1 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data1)\);\)\), "\[IndentingNewLine]", 
    \(\(d2d2 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[d2d1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[d2d2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.70578 .98077 m
.68491 .96872 L
.66494 .95611 L
.66026 .95301 L
.6356 .93588 L
.62954 .93146 L
.61095 .91731 L
.59772 .9068 L
.58629 .89736 L
.56854 .88215 L
.56164 .87602 L
.54142 .8575 L
.53698 .85329 L
.51598 .83284 L
.51233 .82917 L
.49196 .80819 L
.48767 .80364 L
.46917 .78353 L
.46302 .77667 L
.44746 .75888 L
.43836 .74821 L
.42672 .73422 L
.41371 .71824 L
.40683 .70957 L
.38905 .68668 L
.38772 .68491 L
.36939 .66026 L
.3644 .65341 L
.35177 .6356 L
.33974 .61834 L
.33475 .61095 L
.31834 .58629 L
.31509 .58133 L
.30258 .56164 L
.29043 .54218 L
.2873 .53698 L
.27261 .51233 L
.26578 .50066 L
.25844 .48767 L
.24472 .46302 L
.24112 .45645 L
.23158 .43836 L
.21881 .41371 L
.21647 .4091 L
.20665 .38905 L
.19482 .3644 L
.19181 .35799 L
.18358 .33974 L
.17271 .31509 L
.16716 .30217 L
.16234 .29043 L
.15244 .26578 L
.1429 .24112 L
.1425 .24009 L
.13398 .21647 L
.12544 .19181 L
.11785 .16883 L
.11733 .16716 L
.10984 .1425 L
.10276 .11785 L
.09616 .0932 L
.0932 .08147 L
.09014 .06854 L
.08468 .04389 L
.07976 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.70578 .98077 m
.68491 .96872 L
.66494 .95611 L
.66026 .95301 L
.6356 .93588 L
.62954 .93146 L
.61095 .91731 L
.59772 .9068 L
.58629 .89736 L
.56854 .88215 L
.56164 .87602 L
.54142 .8575 L
.53698 .85329 L
.51598 .83284 L
.51233 .82917 L
.49196 .80819 L
.48767 .80364 L
.46917 .78353 L
.46302 .77667 L
.44746 .75888 L
.43836 .74821 L
.42672 .73422 L
.41371 .71824 L
.40683 .70957 L
.38905 .68668 L
.38772 .68491 L
.36939 .66026 L
.3644 .65341 L
.35177 .6356 L
.33974 .61834 L
.33475 .61095 L
.31834 .58629 L
.31509 .58133 L
.30258 .56164 L
.29043 .54218 L
.2873 .53698 L
.27261 .51233 L
.26578 .50066 L
.25844 .48767 L
.24472 .46302 L
.24112 .45645 L
.23158 .43836 L
.21881 .41371 L
.21647 .4091 L
.20665 .38905 L
.19482 .3644 L
.19181 .35799 L
.18358 .33974 L
.17271 .31509 L
.16716 .30217 L
Mistroke
.16234 .29043 L
.15244 .26578 L
.1429 .24112 L
.1425 .24009 L
.13398 .21647 L
.12544 .19181 L
.11785 .16883 L
.11733 .16716 L
.10984 .1425 L
.10276 .11785 L
.09616 .0932 L
.0932 .08147 L
.09014 .06854 L
.08468 .04389 L
.07976 .01923 L
Mfstroke
.2 g
.7293 .01923 m
.73422 .02602 L
.74675 .04389 L
.75888 .06164 L
.76345 .06854 L
.77943 .0932 L
.78353 .09969 L
.79469 .11785 L
.80819 .14049 L
.80935 .1425 L
.82332 .16716 L
.83284 .1845 L
.83673 .19181 L
.84953 .21647 L
.8575 .23234 L
.86176 .24112 L
.87341 .26578 L
.88215 .285 L
.88453 .29043 L
.89504 .31509 L
.90506 .33974 L
.9068 .34418 L
.91445 .3644 L
.92331 .38905 L
.93146 .41319 L
.93163 .41371 L
.93929 .43836 L
.94638 .46302 L
.95288 .48767 L
.95611 .50092 L
.95874 .51233 L
.96391 .53698 L
.96836 .56164 L
.97204 .58629 L
.97491 .61095 L
.97691 .6356 L
.97794 .66026 L
.97791 .68491 L
.97666 .70957 L
.97402 .73422 L
.96972 .75888 L
.9634 .78353 L
.95611 .80424 L
.95447 .80819 L
.94196 .83284 L
.93146 .84833 L
.92392 .8575 L
.9068 .87367 L
.89504 .88215 L
.88215 .88919 L
.8575 .8982 L
.83284 .90238 L
.80819 .90273 L
.78353 .89988 L
.75888 .89426 L
.73422 .8862 L
.72371 .88215 L
.70957 .87592 L
.68491 .86359 L
.67391 .8575 L
.66026 .84934 L
.6356 .83328 L
.63496 .83284 L
.61095 .81543 L
.60154 .80819 L
.58629 .79588 L
.57171 .78353 L
.56164 .77464 L
.54448 .75888 L
.53698 .75172 L
.51929 .73422 L
.51233 .72709 L
.49575 .70957 L
.48767 .70075 L
.4736 .68491 L
.46302 .67262 L
.45267 .66026 L
.43836 .64264 L
.4328 .6356 L
.41388 .61095 L
.41371 .61072 L
.39587 .58629 L
.38905 .57668 L
.37867 .56164 L
.3644 .54038 L
.36218 .53698 L
.34645 .51233 L
.33974 .50153 L
.33138 .48767 L
.31692 .46302 L
.31509 .45982 L
.30315 .43836 L
.29043 .41473 L
.2899 .41371 L
.27732 .38905 L
.26578 .36556 L
.26523 .3644 L
.25379 .33974 L
.24283 .31509 L
.24112 .31115 L
.2325 .29043 L
.22267 .26578 L
.21647 .24948 L
.21342 .24112 L
.20477 .21647 L
.19664 .19181 L
.19181 .17627 L
.18913 .16716 L
.18225 .1425 L
.17597 .11785 L
.17032 .0932 L
.16716 .07792 L
.16538 .06854 L
.16119 .04389 L
.15775 .01923 L
F
0 g
.7293 .01923 m
.73422 .02602 L
.74675 .04389 L
.75888 .06164 L
.76345 .06854 L
.77943 .0932 L
.78353 .09969 L
.79469 .11785 L
.80819 .14049 L
.80935 .1425 L
.82332 .16716 L
.83284 .1845 L
.83673 .19181 L
.84953 .21647 L
.8575 .23234 L
.86176 .24112 L
.87341 .26578 L
.88215 .285 L
.88453 .29043 L
.89504 .31509 L
.90506 .33974 L
.9068 .34418 L
.91445 .3644 L
.92331 .38905 L
.93146 .41319 L
.93163 .41371 L
.93929 .43836 L
.94638 .46302 L
.95288 .48767 L
.95611 .50092 L
.95874 .51233 L
.96391 .53698 L
.96836 .56164 L
.97204 .58629 L
.97491 .61095 L
.97691 .6356 L
.97794 .66026 L
.97791 .68491 L
.97666 .70957 L
.97402 .73422 L
.96972 .75888 L
.9634 .78353 L
.95611 .80424 L
.95447 .80819 L
.94196 .83284 L
.93146 .84833 L
.92392 .8575 L
.9068 .87367 L
.89504 .88215 L
.88215 .88919 L
Mistroke
.8575 .8982 L
.83284 .90238 L
.80819 .90273 L
.78353 .89988 L
.75888 .89426 L
.73422 .8862 L
.72371 .88215 L
.70957 .87592 L
.68491 .86359 L
.67391 .8575 L
.66026 .84934 L
.6356 .83328 L
.63496 .83284 L
.61095 .81543 L
.60154 .80819 L
.58629 .79588 L
.57171 .78353 L
.56164 .77464 L
.54448 .75888 L
.53698 .75172 L
.51929 .73422 L
.51233 .72709 L
.49575 .70957 L
.48767 .70075 L
.4736 .68491 L
.46302 .67262 L
.45267 .66026 L
.43836 .64264 L
.4328 .6356 L
.41388 .61095 L
.41371 .61072 L
.39587 .58629 L
.38905 .57668 L
.37867 .56164 L
.3644 .54038 L
.36218 .53698 L
.34645 .51233 L
.33974 .50153 L
.33138 .48767 L
.31692 .46302 L
.31509 .45982 L
.30315 .43836 L
.29043 .41473 L
.2899 .41371 L
.27732 .38905 L
.26578 .36556 L
.26523 .3644 L
.25379 .33974 L
.24283 .31509 L
.24112 .31115 L
Mistroke
.2325 .29043 L
.22267 .26578 L
.21647 .24948 L
.21342 .24112 L
.20477 .21647 L
.19664 .19181 L
.19181 .17627 L
.18913 .16716 L
.18225 .1425 L
.17597 .11785 L
.17032 .0932 L
.16716 .07792 L
.16538 .06854 L
.16119 .04389 L
.15775 .01923 L
Mfstroke
.3 g
.67757 .01923 m
.68491 .02859 L
.69653 .04389 L
.70957 .06164 L
.71448 .06854 L
.73151 .0932 L
.73422 .09723 L
.74767 .11785 L
.75888 .13568 L
.76304 .1425 L
.77765 .16716 L
.78353 .17743 L
.79152 .19181 L
.80472 .21647 L
.80819 .22314 L
.81722 .24112 L
.82909 .26578 L
.83284 .27386 L
.84027 .29043 L
.85083 .31509 L
.8575 .33144 L
.86075 .33974 L
.86999 .3644 L
.87861 .38905 L
.88215 .39976 L
.88653 .41371 L
.89377 .43836 L
.9003 .46302 L
.9061 .48767 L
.9068 .4909 L
.91108 .51233 L
.91523 .53698 L
.91849 .56164 L
.92076 .58629 L
.92194 .61095 L
.92189 .6356 L
.92042 .66026 L
.91727 .68491 L
.91205 .70957 L
.9068 .72698 L
.90413 .73422 L
.89244 .75888 L
.88215 .77443 L
.87467 .78353 L
.8575 .7991 L
.84355 .80819 L
.83284 .81302 L
.80819 .82008 L
.78353 .82213 L
.75888 .82022 L
.73422 .81501 L
.71248 .80819 L
.70957 .80695 L
.68491 .79633 L
.6605 .78353 L
.66026 .78339 L
.6356 .76826 L
.62176 .75888 L
.61095 .75106 L
.58916 .73422 L
.58629 .73188 L
.56164 .71073 L
.56034 .70957 L
.53698 .68763 L
.53421 .68491 L
.51233 .66256 L
.51015 .66026 L
.48777 .6356 L
.48767 .63549 L
.46682 .61095 L
.46302 .60631 L
.4471 .58629 L
.43836 .57491 L
.42847 .56164 L
.41371 .54113 L
.41081 .53698 L
.39407 .51233 L
.38905 .50471 L
.37816 .48767 L
.3644 .46532 L
.36302 .46302 L
.34866 .43836 L
.33974 .42245 L
.33499 .41371 L
.32202 .38905 L
.31509 .37537 L
.30972 .3644 L
.29807 .33974 L
.29043 .32283 L
.28707 .31509 L
.27673 .29043 L
.267 .26578 L
.26578 .26257 L
.25797 .24112 L
.24957 .21647 L
.24183 .19181 L
.24112 .18944 L
.23483 .16716 L
.22854 .1425 L
.22299 .11785 L
.21824 .0932 L
.21647 .08287 L
.21436 .06854 L
.21141 .04389 L
.20947 .01923 L
F
0 g
.67757 .01923 m
.68491 .02859 L
.69653 .04389 L
.70957 .06164 L
.71448 .06854 L
.73151 .0932 L
.73422 .09723 L
.74767 .11785 L
.75888 .13568 L
.76304 .1425 L
.77765 .16716 L
.78353 .17743 L
.79152 .19181 L
.80472 .21647 L
.80819 .22314 L
.81722 .24112 L
.82909 .26578 L
.83284 .27386 L
.84027 .29043 L
.85083 .31509 L
.8575 .33144 L
.86075 .33974 L
.86999 .3644 L
.87861 .38905 L
.88215 .39976 L
.88653 .41371 L
.89377 .43836 L
.9003 .46302 L
.9061 .48767 L
.9068 .4909 L
.91108 .51233 L
.91523 .53698 L
.91849 .56164 L
.92076 .58629 L
.92194 .61095 L
.92189 .6356 L
.92042 .66026 L
.91727 .68491 L
.91205 .70957 L
.9068 .72698 L
.90413 .73422 L
.89244 .75888 L
.88215 .77443 L
.87467 .78353 L
.8575 .7991 L
.84355 .80819 L
.83284 .81302 L
.80819 .82008 L
.78353 .82213 L
.75888 .82022 L
Mistroke
.73422 .81501 L
.71248 .80819 L
.70957 .80695 L
.68491 .79633 L
.6605 .78353 L
.66026 .78339 L
.6356 .76826 L
.62176 .75888 L
.61095 .75106 L
.58916 .73422 L
.58629 .73188 L
.56164 .71073 L
.56034 .70957 L
.53698 .68763 L
.53421 .68491 L
.51233 .66256 L
.51015 .66026 L
.48777 .6356 L
.48767 .63549 L
.46682 .61095 L
.46302 .60631 L
.4471 .58629 L
.43836 .57491 L
.42847 .56164 L
.41371 .54113 L
.41081 .53698 L
.39407 .51233 L
.38905 .50471 L
.37816 .48767 L
.3644 .46532 L
.36302 .46302 L
.34866 .43836 L
.33974 .42245 L
.33499 .41371 L
.32202 .38905 L
.31509 .37537 L
.30972 .3644 L
.29807 .33974 L
.29043 .32283 L
.28707 .31509 L
.27673 .29043 L
.267 .26578 L
.26578 .26257 L
.25797 .24112 L
.24957 .21647 L
.24183 .19181 L
.24112 .18944 L
.23483 .16716 L
.22854 .1425 L
.22299 .11785 L
Mistroke
.21824 .0932 L
.21647 .08287 L
.21436 .06854 L
.21141 .04389 L
.20947 .01923 L
Mfstroke
.4 g
.6342 .01923 m
.6356 .02083 L
.65501 .04389 L
.66026 .05038 L
.67444 .06854 L
.68491 .0825 L
.69268 .0932 L
.70957 .11744 L
.70984 .11785 L
.72601 .1425 L
.73422 .15558 L
.74127 .16716 L
.75569 .19181 L
.75888 .19746 L
.76927 .21647 L
.78209 .24112 L
.78353 .24398 L
.79413 .26578 L
.80545 .29043 L
.80819 .29664 L
.81601 .31509 L
.82584 .33974 L
.83284 .35851 L
.83493 .3644 L
.84326 .38905 L
.85082 .41371 L
.8575 .43799 L
.85759 .43836 L
.86349 .46302 L
.86852 .48767 L
.87258 .51233 L
.8756 .53698 L
.87747 .56164 L
.87802 .58629 L
.87704 .61095 L
.87423 .6356 L
.86911 .66026 L
.86088 .68491 L
.8575 .69257 L
.84806 .70957 L
.83284 .72837 L
.82672 .73422 L
.80819 .74658 L
.78353 .75558 L
.75888 .75844 L
.73422 .75667 L
.70957 .75115 L
.68491 .74243 L
.66657 .73422 L
.66026 .7309 L
.6356 .71678 L
.62434 .70957 L
.61095 .70026 L
.59059 .68491 L
.58629 .68145 L
.56164 .6604 L
.56148 .66026 L
.53698 .63712 L
.53545 .6356 L
.51233 .61159 L
.51173 .61095 L
.48985 .58629 L
.48767 .58374 L
.46949 .56164 L
.46302 .55344 L
.45045 .53698 L
.43836 .52049 L
.43256 .51233 L
.41572 .48767 L
.41371 .48464 L
.39984 .46302 L
.38905 .44543 L
.38485 .43836 L
.3707 .41371 L
.3644 .40226 L
.35736 .38905 L
.34478 .3644 L
.33974 .35409 L
.33297 .33974 L
.32189 .31509 L
.31509 .29909 L
.31155 .29043 L
.30196 .26578 L
.2931 .24112 L
.29043 .2333 L
.28501 .21647 L
.2777 .19181 L
.2712 .16716 L
.26578 .14361 L
.26555 .1425 L
.26083 .11785 L
.25708 .0932 L
.25441 .06854 L
.25294 .04389 L
.25284 .01923 L
F
0 g
.6342 .01923 m
.6356 .02083 L
.65501 .04389 L
.66026 .05038 L
.67444 .06854 L
.68491 .0825 L
.69268 .0932 L
.70957 .11744 L
.70984 .11785 L
.72601 .1425 L
.73422 .15558 L
.74127 .16716 L
.75569 .19181 L
.75888 .19746 L
.76927 .21647 L
.78209 .24112 L
.78353 .24398 L
.79413 .26578 L
.80545 .29043 L
.80819 .29664 L
.81601 .31509 L
.82584 .33974 L
.83284 .35851 L
.83493 .3644 L
.84326 .38905 L
.85082 .41371 L
.8575 .43799 L
.85759 .43836 L
.86349 .46302 L
.86852 .48767 L
.87258 .51233 L
.8756 .53698 L
.87747 .56164 L
.87802 .58629 L
.87704 .61095 L
.87423 .6356 L
.86911 .66026 L
.86088 .68491 L
.8575 .69257 L
.84806 .70957 L
.83284 .72837 L
.82672 .73422 L
.80819 .74658 L
.78353 .75558 L
.75888 .75844 L
.73422 .75667 L
.70957 .75115 L
.68491 .74243 L
.66657 .73422 L
.66026 .7309 L
Mistroke
.6356 .71678 L
.62434 .70957 L
.61095 .70026 L
.59059 .68491 L
.58629 .68145 L
.56164 .6604 L
.56148 .66026 L
.53698 .63712 L
.53545 .6356 L
.51233 .61159 L
.51173 .61095 L
.48985 .58629 L
.48767 .58374 L
.46949 .56164 L
.46302 .55344 L
.45045 .53698 L
.43836 .52049 L
.43256 .51233 L
.41572 .48767 L
.41371 .48464 L
.39984 .46302 L
.38905 .44543 L
.38485 .43836 L
.3707 .41371 L
.3644 .40226 L
.35736 .38905 L
.34478 .3644 L
.33974 .35409 L
.33297 .33974 L
.32189 .31509 L
.31509 .29909 L
.31155 .29043 L
.30196 .26578 L
.2931 .24112 L
.29043 .2333 L
.28501 .21647 L
.2777 .19181 L
.2712 .16716 L
.26578 .14361 L
.26555 .1425 L
.26083 .11785 L
.25708 .0932 L
.25441 .06854 L
.25294 .04389 L
.25284 .01923 L
Mfstroke
.5 g
.59296 .01923 m
.61095 .03793 L
.61642 .04389 L
.6356 .06584 L
.63786 .06854 L
.65766 .0932 L
.66026 .09657 L
.67605 .11785 L
.68491 .13037 L
.69321 .1425 L
.70926 .16716 L
.70957 .16765 L
.72427 .19181 L
.73422 .20908 L
.73833 .21647 L
.75148 .24112 L
.75888 .25574 L
.76376 .26578 L
.77519 .29043 L
.78353 .30968 L
.78577 .31509 L
.79551 .33974 L
.80441 .3644 L
.80819 .3756 L
.81244 .38905 L
.81957 .41371 L
.82577 .43836 L
.83096 .46302 L
.83284 .47302 L
.83507 .48767 L
.83798 .51233 L
.83955 .53698 L
.83956 .56164 L
.83769 .58629 L
.83343 .61095 L
.83284 .6135 L
.82597 .6356 L
.81346 .66026 L
.80819 .66761 L
.79108 .68491 L
.78353 .68988 L
.75888 .70016 L
.73422 .70317 L
.70957 .70094 L
.68491 .69457 L
.66062 .68491 L
.66026 .68471 L
.6356 .67177 L
.61707 .66026 L
.61095 .65603 L
.58629 .63765 L
.58374 .6356 L
.56164 .6167 L
.55533 .61095 L
.53698 .59322 L
.53017 .58629 L
.51233 .56716 L
.5074 .56164 L
.48767 .53842 L
.4865 .53698 L
.46716 .51233 L
.46302 .5068 L
.44917 .48767 L
.43836 .472 L
.43238 .46302 L
.41666 .43836 L
.41371 .43355 L
.40195 .41371 L
.38905 .39068 L
.38817 .38905 L
.3753 .3644 L
.3644 .3421 L
.36329 .33974 L
.35214 .31509 L
.34181 .29043 L
.33974 .28526 L
.33233 .26578 L
.3237 .24112 L
.31595 .21647 L
.31509 .21358 L
.30911 .19181 L
.30322 .16716 L
.29836 .1425 L
.29461 .11785 L
.29209 .0932 L
.29099 .06854 L
.29153 .04389 L
.29408 .01923 L
F
0 g
.59296 .01923 m
.61095 .03793 L
.61642 .04389 L
.6356 .06584 L
.63786 .06854 L
.65766 .0932 L
.66026 .09657 L
.67605 .11785 L
.68491 .13037 L
.69321 .1425 L
.70926 .16716 L
.70957 .16765 L
.72427 .19181 L
.73422 .20908 L
.73833 .21647 L
.75148 .24112 L
.75888 .25574 L
.76376 .26578 L
.77519 .29043 L
.78353 .30968 L
.78577 .31509 L
.79551 .33974 L
.80441 .3644 L
.80819 .3756 L
.81244 .38905 L
.81957 .41371 L
.82577 .43836 L
.83096 .46302 L
.83284 .47302 L
.83507 .48767 L
.83798 .51233 L
.83955 .53698 L
.83956 .56164 L
.83769 .58629 L
.83343 .61095 L
.83284 .6135 L
.82597 .6356 L
.81346 .66026 L
.80819 .66761 L
.79108 .68491 L
.78353 .68988 L
.75888 .70016 L
.73422 .70317 L
.70957 .70094 L
.68491 .69457 L
.66062 .68491 L
.66026 .68471 L
.6356 .67177 L
.61707 .66026 L
.61095 .65603 L
Mistroke
.58629 .63765 L
.58374 .6356 L
.56164 .6167 L
.55533 .61095 L
.53698 .59322 L
.53017 .58629 L
.51233 .56716 L
.5074 .56164 L
.48767 .53842 L
.4865 .53698 L
.46716 .51233 L
.46302 .5068 L
.44917 .48767 L
.43836 .472 L
.43238 .46302 L
.41666 .43836 L
.41371 .43355 L
.40195 .41371 L
.38905 .39068 L
.38817 .38905 L
.3753 .3644 L
.3644 .3421 L
.36329 .33974 L
.35214 .31509 L
.34181 .29043 L
.33974 .28526 L
.33233 .26578 L
.3237 .24112 L
.31595 .21647 L
.31509 .21358 L
.30911 .19181 L
.30322 .16716 L
.29836 .1425 L
.29461 .11785 L
.29209 .0932 L
.29099 .06854 L
.29153 .04389 L
.29408 .01923 L
Mfstroke
.6 g
.54846 .01923 m
.56164 .03031 L
.57671 .04389 L
.58629 .05315 L
.60137 .06854 L
.61095 .07894 L
.62348 .0932 L
.6356 .10781 L
.64359 .11785 L
.66026 .14002 L
.66205 .1425 L
.67911 .16716 L
.68491 .176 L
.6949 .19181 L
.70954 .21647 L
.70957 .21651 L
.72312 .24112 L
.73422 .26283 L
.73567 .26578 L
.74724 .29043 L
.75784 .31509 L
.75888 .31761 L
.76748 .33974 L
.77615 .3644 L
.78353 .38811 L
.7838 .38905 L
.7904 .41371 L
.79589 .43836 L
.80015 .46302 L
.80305 .48767 L
.80439 .51233 L
.80386 .53698 L
.80098 .56164 L
.79492 .58629 L
.78383 .61095 L
.78353 .61144 L
.76274 .6356 L
.75888 .6383 L
.73422 .64943 L
.70957 .65209 L
.68491 .64893 L
.66026 .64126 L
.64634 .6356 L
.6356 .62981 L
.61095 .61502 L
.60486 .61095 L
.58629 .59715 L
.57293 .58629 L
.56164 .57634 L
.54597 .56164 L
.53698 .55261 L
.52219 .53698 L
.51233 .52591 L
.50076 .51233 L
.48767 .49607 L
.48119 .48767 L
.46319 .46302 L
.46302 .46277 L
.44654 .43836 L
.43836 .42552 L
.43112 .41371 L
.41682 .38905 L
.41371 .38344 L
.40357 .3644 L
.39133 .33974 L
.38905 .33494 L
.38006 .31509 L
.36976 .29043 L
.3644 .27662 L
.36042 .26578 L
.35207 .24112 L
.34474 .21647 L
.33974 .19726 L
.33848 .19181 L
.33336 .16716 L
.32951 .1425 L
.32707 .11785 L
.32628 .0932 L
.32748 .06854 L
.33125 .04389 L
.33864 .01923 L
F
0 g
.54846 .01923 m
.56164 .03031 L
.57671 .04389 L
.58629 .05315 L
.60137 .06854 L
.61095 .07894 L
.62348 .0932 L
.6356 .10781 L
.64359 .11785 L
.66026 .14002 L
.66205 .1425 L
.67911 .16716 L
.68491 .176 L
.6949 .19181 L
.70954 .21647 L
.70957 .21651 L
.72312 .24112 L
.73422 .26283 L
.73567 .26578 L
.74724 .29043 L
.75784 .31509 L
.75888 .31761 L
.76748 .33974 L
.77615 .3644 L
.78353 .38811 L
.7838 .38905 L
.7904 .41371 L
.79589 .43836 L
.80015 .46302 L
.80305 .48767 L
.80439 .51233 L
.80386 .53698 L
.80098 .56164 L
.79492 .58629 L
.78383 .61095 L
.78353 .61144 L
.76274 .6356 L
.75888 .6383 L
.73422 .64943 L
.70957 .65209 L
.68491 .64893 L
.66026 .64126 L
.64634 .6356 L
.6356 .62981 L
.61095 .61502 L
.60486 .61095 L
.58629 .59715 L
.57293 .58629 L
.56164 .57634 L
.54597 .56164 L
Mistroke
.53698 .55261 L
.52219 .53698 L
.51233 .52591 L
.50076 .51233 L
.48767 .49607 L
.48119 .48767 L
.46319 .46302 L
.46302 .46277 L
.44654 .43836 L
.43836 .42552 L
.43112 .41371 L
.41682 .38905 L
.41371 .38344 L
.40357 .3644 L
.39133 .33974 L
.38905 .33494 L
.38006 .31509 L
.36976 .29043 L
.3644 .27662 L
.36042 .26578 L
.35207 .24112 L
.34474 .21647 L
.33974 .19726 L
.33848 .19181 L
.33336 .16716 L
.32951 .1425 L
.32707 .11785 L
.32628 .0932 L
.32748 .06854 L
.33125 .04389 L
.33864 .01923 L
Mfstroke
.7 g
.48211 .01923 m
.48767 .02145 L
.51233 .03377 L
.52877 .04389 L
.53698 .04986 L
.56058 .06854 L
.56164 .06948 L
.58629 .09249 L
.587 .0932 L
.60998 .11785 L
.61095 .11896 L
.63048 .1425 L
.6356 .14911 L
.649 .16716 L
.66026 .18338 L
.66587 .19181 L
.6813 .21647 L
.68491 .22257 L
.69543 .24112 L
.70835 .26578 L
.70957 .26823 L
.72011 .29043 L
.73074 .31509 L
.73422 .32377 L
.74024 .33974 L
.7486 .3644 L
.75576 .38905 L
.75888 .40116 L
.76164 .41371 L
.76615 .43836 L
.76908 .46302 L
.77017 .48767 L
.76897 .51233 L
.76467 .53698 L
.75888 .55477 L
.75573 .56164 L
.73702 .58629 L
.73422 .58845 L
.70957 .60037 L
.68491 .60237 L
.66026 .5979 L
.6356 .58851 L
.63069 .58629 L
.61095 .575 L
.59119 .56164 L
.58629 .55781 L
.56164 .53717 L
.56143 .53698 L
.53698 .51312 L
.53622 .51233 L
.51409 .48767 L
.51233 .48557 L
.49425 .46302 L
.48767 .45424 L
.47628 .43836 L
.46302 .41859 L
.45988 .41371 L
.44486 .38905 L
.43836 .37766 L
.43112 .3644 L
.41857 .33974 L
.41371 .32954 L
.40717 .31509 L
.39689 .29043 L
.38905 .26951 L
.38775 .26578 L
.37975 .24112 L
.37298 .21647 L
.36751 .19181 L
.3644 .17454 L
.36349 .16716 L
.3611 .1425 L
.36068 .11785 L
.36275 .0932 L
.3644 .08229 L
.36822 .06854 L
.37926 .04389 L
.38905 .03181 L
.40266 .01923 L
F
0 g
.48211 .01923 m
.48767 .02145 L
.51233 .03377 L
.52877 .04389 L
.53698 .04986 L
.56058 .06854 L
.56164 .06948 L
.58629 .09249 L
.587 .0932 L
.60998 .11785 L
.61095 .11896 L
.63048 .1425 L
.6356 .14911 L
.649 .16716 L
.66026 .18338 L
.66587 .19181 L
.6813 .21647 L
.68491 .22257 L
.69543 .24112 L
.70835 .26578 L
.70957 .26823 L
.72011 .29043 L
.73074 .31509 L
.73422 .32377 L
.74024 .33974 L
.7486 .3644 L
.75576 .38905 L
.75888 .40116 L
.76164 .41371 L
.76615 .43836 L
.76908 .46302 L
.77017 .48767 L
.76897 .51233 L
.76467 .53698 L
.75888 .55477 L
.75573 .56164 L
.73702 .58629 L
.73422 .58845 L
.70957 .60037 L
.68491 .60237 L
.66026 .5979 L
.6356 .58851 L
.63069 .58629 L
.61095 .575 L
.59119 .56164 L
.58629 .55781 L
.56164 .53717 L
.56143 .53698 L
.53698 .51312 L
.53622 .51233 L
Mistroke
.51409 .48767 L
.51233 .48557 L
.49425 .46302 L
.48767 .45424 L
.47628 .43836 L
.46302 .41859 L
.45988 .41371 L
.44486 .38905 L
.43836 .37766 L
.43112 .3644 L
.41857 .33974 L
.41371 .32954 L
.40717 .31509 L
.39689 .29043 L
.38905 .26951 L
.38775 .26578 L
.37975 .24112 L
.37298 .21647 L
.36751 .19181 L
.3644 .17454 L
.36349 .16716 L
.3611 .1425 L
.36068 .11785 L
.36275 .0932 L
.3644 .08229 L
.36822 .06854 L
.37926 .04389 L
.38905 .03181 L
.40266 .01923 L
Mfstroke
.8 g
.43836 .06548 m
.46302 .06128 L
.48767 .06542 L
.49681 .06854 L
.51233 .07545 L
.53698 .09031 L
.54121 .0932 L
.56164 .10946 L
.57118 .11785 L
.58629 .13272 L
.5956 .1425 L
.61095 .16019 L
.61666 .16716 L
.63528 .19181 L
.6356 .19228 L
.65197 .21647 L
.66026 .22983 L
.66692 .24112 L
.68038 .26578 L
.68491 .27475 L
.69241 .29043 L
.70308 .31509 L
.70957 .33188 L
.71236 .33974 L
.72029 .3644 L
.72672 .38905 L
.73151 .41371 L
.73422 .43602 L
.73441 .43836 L
.73506 .46302 L
.73422 .47622 L
.73272 .48767 L
.72604 .51233 L
.70957 .53664 L
.7092 .53698 L
.68491 .55018 L
.66026 .55144 L
.6356 .54535 L
.61427 .53698 L
.61095 .53377 L
.58629 .51758 L
.57926 .51233 L
.56164 .49719 L
.55145 .48767 L
.53698 .47268 L
.52822 .46302 L
.51233 .44387 L
.508 .43836 L
.49002 .41371 L
.48767 .41026 L
.47389 .38905 L
.46302 .37073 L
.45944 .3644 L
.44643 .33974 L
.43836 .3229 L
.43484 .31509 L
.42458 .29043 L
.41573 .26578 L
.41371 .2597 L
.40827 .24112 L
.40231 .21647 L
.39806 .19181 L
.39578 .16716 L
.39595 .1425 L
.39944 .11785 L
.40851 .0932 L
.41371 .08505 L
.42933 .06854 L
F
0 g
.43836 .06548 m
.46302 .06128 L
.48767 .06542 L
.49681 .06854 L
.51233 .07545 L
.53698 .09031 L
.54121 .0932 L
.56164 .10946 L
.57118 .11785 L
.58629 .13272 L
.5956 .1425 L
.61095 .16019 L
.61666 .16716 L
.63528 .19181 L
.6356 .19228 L
.65197 .21647 L
.66026 .22983 L
.66692 .24112 L
.68038 .26578 L
.68491 .27475 L
.69241 .29043 L
.70308 .31509 L
.70957 .33188 L
.71236 .33974 L
.72029 .3644 L
.72672 .38905 L
.73151 .41371 L
.73422 .43602 L
.73441 .43836 L
.73506 .46302 L
.73422 .47622 L
.73272 .48767 L
.72604 .51233 L
.70957 .53664 L
.7092 .53698 L
.68491 .55018 L
.66026 .55144 L
.6356 .54535 L
.61427 .53698 L
.61095 .53377 L
.58629 .51758 L
.57926 .51233 L
.56164 .49719 L
.55145 .48767 L
.53698 .47268 L
.52822 .46302 L
.51233 .44387 L
.508 .43836 L
.49002 .41371 L
.48767 .41026 L
Mistroke
.47389 .38905 L
.46302 .37073 L
.45944 .3644 L
.44643 .33974 L
.43836 .3229 L
.43484 .31509 L
.42458 .29043 L
.41573 .26578 L
.41371 .2597 L
.40827 .24112 L
.40231 .21647 L
.39806 .19181 L
.39578 .16716 L
.39595 .1425 L
.39944 .11785 L
.40851 .0932 L
.41371 .08505 L
.42933 .06854 L
.43836 .06548 L
Mfstroke
.9 g
.48767 .11657 m
.49764 .11785 L
.51233 .12213 L
.53698 .13475 L
.54925 .1425 L
.56164 .1531 L
.5773 .16716 L
.58629 .17678 L
.59977 .19181 L
.61095 .206 L
.61878 .21647 L
.63522 .24112 L
.6356 .24175 L
.64969 .26578 L
.66026 .28653 L
.66211 .29043 L
.67291 .31509 L
.68184 .33974 L
.68491 .34908 L
.68895 .3644 L
.6941 .38905 L
.69684 .41371 L
.69645 .43836 L
.6911 .46302 L
.68491 .47578 L
.67382 .48767 L
.66026 .49478 L
.6356 .4959 L
.61095 .48793 L
.61024 .48767 L
.58629 .47352 L
.5718 .46302 L
.56164 .45355 L
.54594 .43836 L
.53698 .42824 L
.52468 .41371 L
.51233 .3972 L
.50655 .38905 L
.49074 .3644 L
.48767 .35915 L
.47694 .33974 L
.46504 .31509 L
.46302 .31054 L
.45484 .29043 L
.4464 .26578 L
.43994 .24112 L
.43836 .2334 L
.43556 .21647 L
.43373 .19181 L
.43549 .16716 L
.43836 .15134 L
.44199 .1425 L
.46302 .12149 L
.47303 .11785 L
F
0 g
.48767 .11657 m
.49764 .11785 L
.51233 .12213 L
.53698 .13475 L
.54925 .1425 L
.56164 .1531 L
.5773 .16716 L
.58629 .17678 L
.59977 .19181 L
.61095 .206 L
.61878 .21647 L
.63522 .24112 L
.6356 .24175 L
.64969 .26578 L
.66026 .28653 L
.66211 .29043 L
.67291 .31509 L
.68184 .33974 L
.68491 .34908 L
.68895 .3644 L
.6941 .38905 L
.69684 .41371 L
.69645 .43836 L
.6911 .46302 L
.68491 .47578 L
.67382 .48767 L
.66026 .49478 L
.6356 .4959 L
.61095 .48793 L
.61024 .48767 L
.58629 .47352 L
.5718 .46302 L
.56164 .45355 L
.54594 .43836 L
.53698 .42824 L
.52468 .41371 L
.51233 .3972 L
.50655 .38905 L
.49074 .3644 L
.48767 .35915 L
.47694 .33974 L
.46504 .31509 L
.46302 .31054 L
.45484 .29043 L
.4464 .26578 L
.43994 .24112 L
.43836 .2334 L
.43556 .21647 L
.43373 .19181 L
.43549 .16716 L
Mistroke
.43836 .15134 L
.44199 .1425 L
.46302 .12149 L
.47303 .11785 L
.48767 .11657 L
Mfstroke
1 g
.51233 .1852 m
.53698 .19129 L
.53805 .19181 L
.56164 .20746 L
.57307 .21647 L
.58629 .23222 L
.59388 .24112 L
.61058 .26578 L
.61095 .26646 L
.62471 .29043 L
.63519 .31509 L
.6356 .31576 L
.64353 .33974 L
.6489 .3644 L
.65053 .38905 L
.64498 .41371 L
.6356 .42191 L
.61095 .42771 L
.58629 .41803 L
.57625 .41371 L
.56164 .39919 L
.55054 .38905 L
.53698 .3718 L
.53124 .3644 L
.51518 .33974 L
.51233 .33427 L
.50243 .31509 L
.4923 .29043 L
.48767 .27678 L
.48551 .26578 L
.48139 .24112 L
.48214 .21647 L
.48767 .20161 L
.49536 .19181 L
F
0 g
.51233 .1852 m
.53698 .19129 L
.53805 .19181 L
.56164 .20746 L
.57307 .21647 L
.58629 .23222 L
.59388 .24112 L
.61058 .26578 L
.61095 .26646 L
.62471 .29043 L
.63519 .31509 L
.6356 .31576 L
.64353 .33974 L
.6489 .3644 L
.65053 .38905 L
.64498 .41371 L
.6356 .42191 L
.61095 .42771 L
.58629 .41803 L
.57625 .41371 L
.56164 .39919 L
.55054 .38905 L
.53698 .3718 L
.53124 .3644 L
.51518 .33974 L
.51233 .33427 L
.50243 .31509 L
.4923 .29043 L
.48767 .27678 L
.48551 .26578 L
.48139 .24112 L
.48214 .21647 L
.48767 .20161 L
.49536 .19181 L
.51233 .1852 L
s
.98077 .3536 m
.97539 .33974 L
.96533 .31509 L
.95611 .29363 L
.95471 .29043 L
.94365 .26578 L
.93228 .24112 L
.93146 .23936 L
.9203 .21647 L
.90799 .19181 L
.9068 .18947 L
.89507 .16716 L
.88215 .14312 L
.88181 .1425 L
.86789 .11785 L
.8575 .09977 L
.85359 .0932 L
.83869 .06854 L
.83284 .059 L
.82327 .04389 L
.80819 .0205 L
.80734 .01923 L
.98077 .01923 L
F
.98077 .3536 m
.97539 .33974 L
.96533 .31509 L
.95611 .29363 L
.95471 .29043 L
.94365 .26578 L
.93228 .24112 L
.93146 .23936 L
.9203 .21647 L
.90799 .19181 L
.9068 .18947 L
.89507 .16716 L
.88215 .14312 L
.88181 .1425 L
.86789 .11785 L
.8575 .09977 L
.85359 .0932 L
.83869 .06854 L
.83284 .059 L
.82327 .04389 L
.80819 .0205 L
.80734 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.48957 .98077 m
.48767 .97999 L
.46302 .96916 L
.43836 .95694 L
.43679 .95611 L
.41371 .94339 L
.39371 .93146 L
.38905 .92853 L
.3644 .91221 L
.35665 .9068 L
.33974 .89441 L
.32386 .88215 L
.31509 .87506 L
.29435 .8575 L
.29043 .85403 L
.26751 .83284 L
.26578 .83117 L
.24292 .80819 L
.24112 .8063 L
.22027 .78353 L
.21647 .7792 L
.19933 .75888 L
.19181 .74956 L
.17994 .73422 L
.16716 .71694 L
.16194 .70957 L
.14523 .68491 L
.1425 .68072 L
.12979 .66026 L
.11785 .63991 L
.11544 .6356 L
.10224 .61095 L
.0932 .59291 L
.09005 .58629 L
.07893 .56164 L
.06872 .53698 L
.06854 .53652 L
.0596 .51233 L
.05137 .48767 L
.04407 .46302 L
.04389 .46235 L
.03773 .43836 L
.03237 .41371 L
.02801 .38905 L
.02466 .3644 L
.02233 .33974 L
.02104 .31509 L
.02085 .29043 L
.02179 .26578 L
.02394 .24112 L
.0274 .21647 L
.03228 .19181 L
.0387 .16716 L
.04389 .15082 L
.04684 .1425 L
.05689 .11785 L
.06854 .0943 L
.06914 .0932 L
.08407 .06854 L
.0932 .05553 L
.10225 .04389 L
.11785 .02615 L
.12465 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.48957 .98077 m
.48767 .97999 L
.46302 .96916 L
.43836 .95694 L
.43679 .95611 L
.41371 .94339 L
.39371 .93146 L
.38905 .92853 L
.3644 .91221 L
.35665 .9068 L
.33974 .89441 L
.32386 .88215 L
.31509 .87506 L
.29435 .8575 L
.29043 .85403 L
.26751 .83284 L
.26578 .83117 L
.24292 .80819 L
.24112 .8063 L
.22027 .78353 L
.21647 .7792 L
.19933 .75888 L
.19181 .74956 L
.17994 .73422 L
.16716 .71694 L
.16194 .70957 L
.14523 .68491 L
.1425 .68072 L
.12979 .66026 L
.11785 .63991 L
.11544 .6356 L
.10224 .61095 L
.0932 .59291 L
.09005 .58629 L
.07893 .56164 L
.06872 .53698 L
.06854 .53652 L
.0596 .51233 L
.05137 .48767 L
.04407 .46302 L
.04389 .46235 L
.03773 .43836 L
.03237 .41371 L
.02801 .38905 L
.02466 .3644 L
.02233 .33974 L
.02104 .31509 L
.02085 .29043 L
.02179 .26578 L
.02394 .24112 L
Mistroke
.0274 .21647 L
.03228 .19181 L
.0387 .16716 L
.04389 .15082 L
.04684 .1425 L
.05689 .11785 L
.06854 .0943 L
.06914 .0932 L
.08407 .06854 L
.0932 .05553 L
.10225 .04389 L
.11785 .02615 L
.12465 .01923 L
Mfstroke
.2 g
.29043 .04053 m
.31509 .03361 L
.33974 .02906 L
.3644 .02665 L
.38905 .02618 L
.41371 .02752 L
.43836 .03058 L
.46302 .0353 L
.48767 .04163 L
.49529 .04389 L
.51233 .04953 L
.53698 .05898 L
.55862 .06854 L
.56164 .06998 L
.58629 .0826 L
.60493 .0932 L
.61095 .09684 L
.6356 .11279 L
.64292 .11785 L
.66026 .13054 L
.67558 .1425 L
.68491 .15019 L
.70436 .16716 L
.70957 .17194 L
.73011 .19181 L
.73422 .196 L
.75336 .21647 L
.75888 .22268 L
.77447 .24112 L
.78353 .25244 L
.79371 .26578 L
.80819 .28591 L
.81128 .29043 L
.8273 .31509 L
.83284 .32414 L
.8419 .33974 L
.85517 .3644 L
.8575 .36897 L
.86714 .38905 L
.8779 .41371 L
.88215 .42425 L
.88745 .43836 L
.89583 .46302 L
.90307 .48767 L
.9068 .5022 L
.90913 .51233 L
.91399 .53698 L
.91768 .56164 L
.92013 .58629 L
.92131 .61095 L
.92115 .6356 L
.91955 .66026 L
.91641 .68491 L
.9116 .70957 L
.9068 .728 L
.9049 .73422 L
.89604 .75888 L
.88469 .78353 L
.88215 .78832 L
.87026 .80819 L
.8575 .82598 L
.85193 .83284 L
.83284 .85317 L
.82819 .8575 L
.80819 .87377 L
.79598 .88215 L
.78353 .88962 L
.75888 .90174 L
.74616 .9068 L
.73422 .9108 L
.70957 .91723 L
.68491 .92135 L
.66026 .92338 L
.6356 .92349 L
.61095 .92181 L
.58629 .91842 L
.56164 .9134 L
.53699 .9068 L
.53698 .9068 L
.51233 .8986 L
.48767 .88886 L
.47259 .88215 L
.46302 .87755 L
.43836 .86463 L
.4259 .8575 L
.41371 .85006 L
.38905 .83379 L
.38768 .83284 L
.3644 .81568 L
.35487 .80819 L
.33974 .79564 L
.32597 .78353 L
.31509 .77347 L
.30012 .75888 L
.29043 .74893 L
.27679 .73422 L
.26578 .7217 L
.25561 .70957 L
.24112 .6913 L
.2363 .68491 L
.21867 .66026 L
.21647 .65702 L
.20261 .6356 L
.19181 .6177 L
.18795 .61095 L
.17465 .58629 L
.16716 .57128 L
.16262 .56164 L
.15183 .53698 L
.1425 .51314 L
.14221 .51233 L
.13381 .48767 L
.12655 .46302 L
.12043 .43836 L
.11785 .42636 L
.11551 .41371 L
.11179 .38905 L
.1093 .3644 L
.10807 .33974 L
.10819 .31509 L
.10973 .29043 L
.11281 .26578 L
.11756 .24112 L
.11785 .23985 L
.1242 .21647 L
.13297 .19181 L
.1425 .17056 L
.14423 .16716 L
.15854 .1425 L
.16716 .13005 L
.17672 .11785 L
.19181 .10126 L
.20022 .0932 L
.21647 .07958 L
.23205 .06854 L
.24112 .06292 L
.26578 .05014 L
.28088 .04389 L
F
0 g
.29043 .04053 m
.31509 .03361 L
.33974 .02906 L
.3644 .02665 L
.38905 .02618 L
.41371 .02752 L
.43836 .03058 L
.46302 .0353 L
.48767 .04163 L
.49529 .04389 L
.51233 .04953 L
.53698 .05898 L
.55862 .06854 L
.56164 .06998 L
.58629 .0826 L
.60493 .0932 L
.61095 .09684 L
.6356 .11279 L
.64292 .11785 L
.66026 .13054 L
.67558 .1425 L
.68491 .15019 L
.70436 .16716 L
.70957 .17194 L
.73011 .19181 L
.73422 .196 L
.75336 .21647 L
.75888 .22268 L
.77447 .24112 L
.78353 .25244 L
.79371 .26578 L
.80819 .28591 L
.81128 .29043 L
.8273 .31509 L
.83284 .32414 L
.8419 .33974 L
.85517 .3644 L
.8575 .36897 L
.86714 .38905 L
.8779 .41371 L
.88215 .42425 L
.88745 .43836 L
.89583 .46302 L
.90307 .48767 L
.9068 .5022 L
.90913 .51233 L
.91399 .53698 L
.91768 .56164 L
.92013 .58629 L
.92131 .61095 L
Mistroke
.92115 .6356 L
.91955 .66026 L
.91641 .68491 L
.9116 .70957 L
.9068 .728 L
.9049 .73422 L
.89604 .75888 L
.88469 .78353 L
.88215 .78832 L
.87026 .80819 L
.8575 .82598 L
.85193 .83284 L
.83284 .85317 L
.82819 .8575 L
.80819 .87377 L
.79598 .88215 L
.78353 .88962 L
.75888 .90174 L
.74616 .9068 L
.73422 .9108 L
.70957 .91723 L
.68491 .92135 L
.66026 .92338 L
.6356 .92349 L
.61095 .92181 L
.58629 .91842 L
.56164 .9134 L
.53699 .9068 L
.53698 .9068 L
.51233 .8986 L
.48767 .88886 L
.47259 .88215 L
.46302 .87755 L
.43836 .86463 L
.4259 .8575 L
.41371 .85006 L
.38905 .83379 L
.38768 .83284 L
.3644 .81568 L
.35487 .80819 L
.33974 .79564 L
.32597 .78353 L
.31509 .77347 L
.30012 .75888 L
.29043 .74893 L
.27679 .73422 L
.26578 .7217 L
.25561 .70957 L
.24112 .6913 L
.2363 .68491 L
Mistroke
.21867 .66026 L
.21647 .65702 L
.20261 .6356 L
.19181 .6177 L
.18795 .61095 L
.17465 .58629 L
.16716 .57128 L
.16262 .56164 L
.15183 .53698 L
.1425 .51314 L
.14221 .51233 L
.13381 .48767 L
.12655 .46302 L
.12043 .43836 L
.11785 .42636 L
.11551 .41371 L
.11179 .38905 L
.1093 .3644 L
.10807 .33974 L
.10819 .31509 L
.10973 .29043 L
.11281 .26578 L
.11756 .24112 L
.11785 .23985 L
.1242 .21647 L
.13297 .19181 L
.1425 .17056 L
.14423 .16716 L
.15854 .1425 L
.16716 .13005 L
.17672 .11785 L
.19181 .10126 L
.20022 .0932 L
.21647 .07958 L
.23205 .06854 L
.24112 .06292 L
.26578 .05014 L
.28088 .04389 L
.29043 .04053 L
Mfstroke
.3 g
.3644 .08932 m
.38905 .08715 L
.41371 .0872 L
.43836 .08931 L
.46243 .0932 L
.46302 .09335 L
.48767 .09928 L
.51233 .10702 L
.53698 .11655 L
.54003 .11785 L
.56164 .12792 L
.58629 .14113 L
.58867 .1425 L
.61095 .15629 L
.62692 .16716 L
.6356 .17346 L
.65906 .19181 L
.66026 .19281 L
.68491 .21457 L
.68693 .21647 L
.70957 .23903 L
.71154 .24112 L
.7335 .26578 L
.73422 .26664 L
.75319 .29043 L
.75888 .29807 L
.7709 .31509 L
.78353 .3344 L
.78684 .33974 L
.80113 .3644 L
.80819 .37763 L
.81391 .38905 L
.82523 .41371 L
.83284 .43225 L
.83516 .43836 L
.84372 .46302 L
.85094 .48767 L
.85682 .51233 L
.8575 .51543 L
.86132 .53698 L
.86442 .56164 L
.86608 .58629 L
.8662 .61095 L
.86469 .6356 L
.8614 .66026 L
.8575 .67957 L
.85612 .68491 L
.84856 .70957 L
.83833 .73422 L
.83284 .74507 L
.8248 .75888 L
.80819 .78206 L
.80697 .78353 L
.78353 .80766 L
.78293 .80819 L
.75888 .82636 L
.74828 .83284 L
.73422 .84016 L
.70957 .85013 L
.68491 .85697 L
.68319 .8575 L
.66026 .8611 L
.6356 .86283 L
.61095 .86237 L
.58629 .85989 L
.57058 .8575 L
.56164 .85548 L
.53698 .84921 L
.51233 .84112 L
.49135 .83284 L
.48767 .83124 L
.46302 .81952 L
.44219 .80819 L
.43836 .80595 L
.41371 .79042 L
.40368 .78353 L
.38905 .77284 L
.37136 .75888 L
.3644 .75304 L
.34336 .73422 L
.33974 .7308 L
.31864 .70957 L
.31509 .70577 L
.29661 .68491 L
.29043 .6775 L
.27684 .66026 L
.26578 .64524 L
.25906 .6356 L
.24306 .61095 L
.24112 .60778 L
.22871 .58629 L
.21647 .56285 L
.21587 .56164 L
.20452 .53698 L
.19453 .51233 L
.19181 .505 L
.18593 .48767 L
.17866 .46302 L
.17274 .43836 L
.16818 .41371 L
.16716 .40795 L
.16502 .38905 L
.16332 .3644 L
.16313 .33974 L
.16459 .31509 L
.16716 .29354 L
.16781 .29043 L
.17303 .26578 L
.1805 .24112 L
.19063 .21647 L
.19181 .21398 L
.20402 .19181 L
.21647 .17373 L
.22168 .16716 L
.24112 .14644 L
.24544 .1425 L
.26578 .12661 L
.27958 .11785 L
.29043 .11198 L
.31509 .10133 L
.33974 .09394 L
.34232 .0932 L
F
0 g
.3644 .08932 m
.38905 .08715 L
.41371 .0872 L
.43836 .08931 L
.46243 .0932 L
.46302 .09335 L
.48767 .09928 L
.51233 .10702 L
.53698 .11655 L
.54003 .11785 L
.56164 .12792 L
.58629 .14113 L
.58867 .1425 L
.61095 .15629 L
.62692 .16716 L
.6356 .17346 L
.65906 .19181 L
.66026 .19281 L
.68491 .21457 L
.68693 .21647 L
.70957 .23903 L
.71154 .24112 L
.7335 .26578 L
.73422 .26664 L
.75319 .29043 L
.75888 .29807 L
.7709 .31509 L
.78353 .3344 L
.78684 .33974 L
.80113 .3644 L
.80819 .37763 L
.81391 .38905 L
.82523 .41371 L
.83284 .43225 L
.83516 .43836 L
.84372 .46302 L
.85094 .48767 L
.85682 .51233 L
.8575 .51543 L
.86132 .53698 L
.86442 .56164 L
.86608 .58629 L
.8662 .61095 L
.86469 .6356 L
.8614 .66026 L
.8575 .67957 L
.85612 .68491 L
.84856 .70957 L
.83833 .73422 L
.83284 .74507 L
Mistroke
.8248 .75888 L
.80819 .78206 L
.80697 .78353 L
.78353 .80766 L
.78293 .80819 L
.75888 .82636 L
.74828 .83284 L
.73422 .84016 L
.70957 .85013 L
.68491 .85697 L
.68319 .8575 L
.66026 .8611 L
.6356 .86283 L
.61095 .86237 L
.58629 .85989 L
.57058 .8575 L
.56164 .85548 L
.53698 .84921 L
.51233 .84112 L
.49135 .83284 L
.48767 .83124 L
.46302 .81952 L
.44219 .80819 L
.43836 .80595 L
.41371 .79042 L
.40368 .78353 L
.38905 .77284 L
.37136 .75888 L
.3644 .75304 L
.34336 .73422 L
.33974 .7308 L
.31864 .70957 L
.31509 .70577 L
.29661 .68491 L
.29043 .6775 L
.27684 .66026 L
.26578 .64524 L
.25906 .6356 L
.24306 .61095 L
.24112 .60778 L
.22871 .58629 L
.21647 .56285 L
.21587 .56164 L
.20452 .53698 L
.19453 .51233 L
.19181 .505 L
.18593 .48767 L
.17866 .46302 L
.17274 .43836 L
.16818 .41371 L
Mistroke
.16716 .40795 L
.16502 .38905 L
.16332 .3644 L
.16313 .33974 L
.16459 .31509 L
.16716 .29354 L
.16781 .29043 L
.17303 .26578 L
.1805 .24112 L
.19063 .21647 L
.19181 .21398 L
.20402 .19181 L
.21647 .17373 L
.22168 .16716 L
.24112 .14644 L
.24544 .1425 L
.26578 .12661 L
.27958 .11785 L
.29043 .11198 L
.31509 .10133 L
.33974 .09394 L
.34232 .0932 L
.3644 .08932 L
Mfstroke
.4 g
.3644 .14024 m
.38905 .13616 L
.41371 .1348 L
.43836 .13588 L
.46302 .13923 L
.47952 .1425 L
.48767 .14472 L
.51233 .15232 L
.53698 .16196 L
.54851 .16716 L
.56164 .17369 L
.58629 .18755 L
.59319 .19181 L
.61095 .20365 L
.62838 .21647 L
.6356 .22216 L
.65784 .24112 L
.66026 .24332 L
.68326 .26578 L
.68491 .26751 L
.70552 .29043 L
.70957 .29527 L
.72517 .31509 L
.73422 .32751 L
.7426 .33974 L
.75804 .3644 L
.75888 .36582 L
.77165 .38905 L
.78353 .41358 L
.78359 .41371 L
.79389 .43836 L
.80264 .46302 L
.80819 .48137 L
.80986 .48767 L
.81553 .51233 L
.81965 .53698 L
.82214 .56164 L
.82295 .58629 L
.82193 .61095 L
.81891 .6356 L
.81365 .66026 L
.80819 .67836 L
.80577 .68491 L
.79471 .70957 L
.78353 .72849 L
.77956 .73422 L
.75888 .75861 L
.7586 .75888 L
.73422 .77929 L
.72794 .78353 L
.70957 .7939 L
.68491 .80403 L
.67143 .80819 L
.66026 .81059 L
.6356 .81412 L
.61095 .815 L
.58629 .81348 L
.56164 .80971 L
.55391 .80819 L
.53698 .80381 L
.51233 .79582 L
.48767 .78578 L
.48272 .78353 L
.46302 .77365 L
.43836 .75938 L
.43756 .75888 L
.41371 .74282 L
.40212 .73422 L
.38905 .72383 L
.37249 .70957 L
.3644 .70212 L
.34695 .68491 L
.33974 .6773 L
.32459 .66026 L
.31509 .64877 L
.30485 .6356 L
.29043 .61553 L
.28734 .61095 L
.27184 .58629 L
.26578 .57577 L
.25816 .56164 L
.24618 .53698 L
.24112 .52547 L
.23581 .51233 L
.22701 .48767 L
.21973 .46302 L
.21647 .45003 L
.214 .43836 L
.20984 .41371 L
.20728 .38905 L
.20642 .3644 L
.20737 .33974 L
.21031 .31509 L
.21549 .29043 L
.21647 .2867 L
.22327 .26578 L
.2342 .24112 L
.24112 .22875 L
.24918 .21647 L
.26578 .19608 L
.26989 .19181 L
.29043 .17395 L
.30008 .16716 L
.31509 .15833 L
.33974 .14743 L
.35484 .1425 L
F
0 g
.3644 .14024 m
.38905 .13616 L
.41371 .1348 L
.43836 .13588 L
.46302 .13923 L
.47952 .1425 L
.48767 .14472 L
.51233 .15232 L
.53698 .16196 L
.54851 .16716 L
.56164 .17369 L
.58629 .18755 L
.59319 .19181 L
.61095 .20365 L
.62838 .21647 L
.6356 .22216 L
.65784 .24112 L
.66026 .24332 L
.68326 .26578 L
.68491 .26751 L
.70552 .29043 L
.70957 .29527 L
.72517 .31509 L
.73422 .32751 L
.7426 .33974 L
.75804 .3644 L
.75888 .36582 L
.77165 .38905 L
.78353 .41358 L
.78359 .41371 L
.79389 .43836 L
.80264 .46302 L
.80819 .48137 L
.80986 .48767 L
.81553 .51233 L
.81965 .53698 L
.82214 .56164 L
.82295 .58629 L
.82193 .61095 L
.81891 .6356 L
.81365 .66026 L
.80819 .67836 L
.80577 .68491 L
.79471 .70957 L
.78353 .72849 L
.77956 .73422 L
.75888 .75861 L
.7586 .75888 L
.73422 .77929 L
.72794 .78353 L
Mistroke
.70957 .7939 L
.68491 .80403 L
.67143 .80819 L
.66026 .81059 L
.6356 .81412 L
.61095 .815 L
.58629 .81348 L
.56164 .80971 L
.55391 .80819 L
.53698 .80381 L
.51233 .79582 L
.48767 .78578 L
.48272 .78353 L
.46302 .77365 L
.43836 .75938 L
.43756 .75888 L
.41371 .74282 L
.40212 .73422 L
.38905 .72383 L
.37249 .70957 L
.3644 .70212 L
.34695 .68491 L
.33974 .6773 L
.32459 .66026 L
.31509 .64877 L
.30485 .6356 L
.29043 .61553 L
.28734 .61095 L
.27184 .58629 L
.26578 .57577 L
.25816 .56164 L
.24618 .53698 L
.24112 .52547 L
.23581 .51233 L
.22701 .48767 L
.21973 .46302 L
.21647 .45003 L
.214 .43836 L
.20984 .41371 L
.20728 .38905 L
.20642 .3644 L
.20737 .33974 L
.21031 .31509 L
.21549 .29043 L
.21647 .2867 L
.22327 .26578 L
.2342 .24112 L
.24112 .22875 L
.24918 .21647 L
.26578 .19608 L
Mistroke
.26989 .19181 L
.29043 .17395 L
.30008 .16716 L
.31509 .15833 L
.33974 .14743 L
.35484 .1425 L
.3644 .14024 L
Mfstroke
.5 g
.3644 .18633 m
.38905 .17987 L
.41371 .1768 L
.43836 .17668 L
.46302 .17922 L
.48767 .18425 L
.51233 .19166 L
.51277 .19181 L
.53698 .20143 L
.56164 .21357 L
.56692 .21647 L
.58629 .22817 L
.60521 .24112 L
.61095 .24539 L
.6356 .26549 L
.63592 .26578 L
.66026 .2889 L
.66175 .29043 L
.68394 .31509 L
.68491 .31625 L
.70321 .33974 L
.70957 .34867 L
.72001 .3644 L
.73422 .38832 L
.73462 .38905 L
.74724 .41371 L
.758 .43836 L
.75888 .44056 L
.76695 .46302 L
.77417 .48767 L
.77962 .51233 L
.78329 .53698 L
.78353 .5392 L
.78509 .56164 L
.78488 .58629 L
.78353 .60284 L
.78249 .61095 L
.7776 .6356 L
.76978 .66026 L
.75888 .68386 L
.75829 .68491 L
.74185 .70957 L
.73422 .71849 L
.71769 .73422 L
.70957 .7405 L
.68491 .75529 L
.67732 .75888 L
.66026 .76501 L
.6356 .77079 L
.61095 .77326 L
.58629 .77286 L
.56164 .76983 L
.53698 .76434 L
.51886 .75888 L
.51233 .75647 L
.48767 .74626 L
.46401 .73422 L
.46302 .73366 L
.43836 .71857 L
.42535 .70957 L
.41371 .70082 L
.39443 .68491 L
.38905 .68012 L
.36846 .66026 L
.3644 .65603 L
.34615 .6356 L
.33974 .62782 L
.32679 .61095 L
.31509 .59423 L
.30991 .58629 L
.29522 .56164 L
.29043 .55278 L
.28254 .53698 L
.27172 .51233 L
.26578 .49672 L
.2627 .48767 L
.25543 .46302 L
.24991 .43836 L
.24618 .41371 L
.24431 .38905 L
.24444 .3644 L
.24676 .33974 L
.25155 .31509 L
.25925 .29043 L
.26578 .27511 L
.27059 .26578 L
.28684 .24112 L
.29043 .2367 L
.31065 .21647 L
.31509 .21288 L
.33974 .19692 L
.35007 .19181 L
F
0 g
.3644 .18633 m
.38905 .17987 L
.41371 .1768 L
.43836 .17668 L
.46302 .17922 L
.48767 .18425 L
.51233 .19166 L
.51277 .19181 L
.53698 .20143 L
.56164 .21357 L
.56692 .21647 L
.58629 .22817 L
.60521 .24112 L
.61095 .24539 L
.6356 .26549 L
.63592 .26578 L
.66026 .2889 L
.66175 .29043 L
.68394 .31509 L
.68491 .31625 L
.70321 .33974 L
.70957 .34867 L
.72001 .3644 L
.73422 .38832 L
.73462 .38905 L
.74724 .41371 L
.758 .43836 L
.75888 .44056 L
.76695 .46302 L
.77417 .48767 L
.77962 .51233 L
.78329 .53698 L
.78353 .5392 L
.78509 .56164 L
.78488 .58629 L
.78353 .60284 L
.78249 .61095 L
.7776 .6356 L
.76978 .66026 L
.75888 .68386 L
.75829 .68491 L
.74185 .70957 L
.73422 .71849 L
.71769 .73422 L
.70957 .7405 L
.68491 .75529 L
.67732 .75888 L
.66026 .76501 L
.6356 .77079 L
.61095 .77326 L
Mistroke
.58629 .77286 L
.56164 .76983 L
.53698 .76434 L
.51886 .75888 L
.51233 .75647 L
.48767 .74626 L
.46401 .73422 L
.46302 .73366 L
.43836 .71857 L
.42535 .70957 L
.41371 .70082 L
.39443 .68491 L
.38905 .68012 L
.36846 .66026 L
.3644 .65603 L
.34615 .6356 L
.33974 .62782 L
.32679 .61095 L
.31509 .59423 L
.30991 .58629 L
.29522 .56164 L
.29043 .55278 L
.28254 .53698 L
.27172 .51233 L
.26578 .49672 L
.2627 .48767 L
.25543 .46302 L
.24991 .43836 L
.24618 .41371 L
.24431 .38905 L
.24444 .3644 L
.24676 .33974 L
.25155 .31509 L
.25925 .29043 L
.26578 .27511 L
.27059 .26578 L
.28684 .24112 L
.29043 .2367 L
.31065 .21647 L
.31509 .21288 L
.33974 .19692 L
.35007 .19181 L
.3644 .18633 L
Mfstroke
.6 g
.41371 .21646 m
.43836 .21481 L
.46302 .21636 L
.46392 .21647 L
.48767 .22081 L
.51233 .22802 L
.53698 .23792 L
.54384 .24112 L
.56164 .25056 L
.58587 .26578 L
.58629 .26607 L
.61095 .28471 L
.61773 .29043 L
.6356 .30691 L
.6437 .31509 L
.66026 .33341 L
.66553 .33974 L
.68412 .3644 L
.68491 .36554 L
.69999 .38905 L
.70957 .4061 L
.71347 .41371 L
.72476 .43836 L
.73398 .46302 L
.73422 .46371 L
.74119 .48767 L
.74638 .51233 L
.74949 .53698 L
.75042 .56164 L
.74894 .58629 L
.74473 .61095 L
.73725 .6356 L
.73422 .64317 L
.7256 .66026 L
.70957 .68305 L
.70796 .68491 L
.68491 .70601 L
.67991 .70957 L
.66026 .72051 L
.6356 .72938 L
.61095 .73394 L
.60819 .73422 L
.58629 .73495 L
.57351 .73422 L
.56164 .73283 L
.53698 .72785 L
.51233 .72012 L
.48767 .7097 L
.48739 .70957 L
.46302 .69652 L
.44474 .68491 L
.43836 .68044 L
.41371 .66116 L
.41265 .66026 L
.38905 .63821 L
.3865 .6356 L
.36455 .61095 L
.3644 .61076 L
.34585 .58629 L
.33974 .57732 L
.32989 .56164 L
.31633 .53698 L
.31509 .53451 L
.30497 .51233 L
.29568 .48767 L
.29043 .47083 L
.2884 .46302 L
.28314 .43836 L
.27995 .41371 L
.27894 .38905 L
.28033 .3644 L
.28444 .33974 L
.29043 .31861 L
.29179 .31509 L
.30327 .29043 L
.31509 .27258 L
.32063 .26578 L
.33974 .24741 L
.34815 .24112 L
.3644 .23159 L
.38905 .22178 L
.4136 .21647 L
F
0 g
.41371 .21646 m
.43836 .21481 L
.46302 .21636 L
.46392 .21647 L
.48767 .22081 L
.51233 .22802 L
.53698 .23792 L
.54384 .24112 L
.56164 .25056 L
.58587 .26578 L
.58629 .26607 L
.61095 .28471 L
.61773 .29043 L
.6356 .30691 L
.6437 .31509 L
.66026 .33341 L
.66553 .33974 L
.68412 .3644 L
.68491 .36554 L
.69999 .38905 L
.70957 .4061 L
.71347 .41371 L
.72476 .43836 L
.73398 .46302 L
.73422 .46371 L
.74119 .48767 L
.74638 .51233 L
.74949 .53698 L
.75042 .56164 L
.74894 .58629 L
.74473 .61095 L
.73725 .6356 L
.73422 .64317 L
.7256 .66026 L
.70957 .68305 L
.70796 .68491 L
.68491 .70601 L
.67991 .70957 L
.66026 .72051 L
.6356 .72938 L
.61095 .73394 L
.60819 .73422 L
.58629 .73495 L
.57351 .73422 L
.56164 .73283 L
.53698 .72785 L
.51233 .72012 L
.48767 .7097 L
.48739 .70957 L
.46302 .69652 L
Mistroke
.44474 .68491 L
.43836 .68044 L
.41371 .66116 L
.41265 .66026 L
.38905 .63821 L
.3865 .6356 L
.36455 .61095 L
.3644 .61076 L
.34585 .58629 L
.33974 .57732 L
.32989 .56164 L
.31633 .53698 L
.31509 .53451 L
.30497 .51233 L
.29568 .48767 L
.29043 .47083 L
.2884 .46302 L
.28314 .43836 L
.27995 .41371 L
.27894 .38905 L
.28033 .3644 L
.28444 .33974 L
.29043 .31861 L
.29179 .31509 L
.30327 .29043 L
.31509 .27258 L
.32063 .26578 L
.33974 .24741 L
.34815 .24112 L
.3644 .23159 L
.38905 .22178 L
.4136 .21647 L
.41371 .21646 L
Mfstroke
.7 g
.38905 .26497 m
.41371 .25627 L
.43836 .25247 L
.46302 .25267 L
.48767 .25637 L
.51233 .2633 L
.51941 .26578 L
.53698 .27339 L
.56164 .2867 L
.56767 .29043 L
.58629 .30343 L
.60088 .31509 L
.61095 .32403 L
.62687 .33974 L
.6356 .34932 L
.64812 .3644 L
.66026 .38086 L
.66576 .38905 L
.6804 .41371 L
.68491 .42231 L
.69241 .43836 L
.70196 .46302 L
.70916 .48767 L
.70957 .4888 L
.714 .51233 L
.71639 .53698 L
.71613 .56164 L
.71285 .58629 L
.70957 .60081 L
.70594 .61095 L
.69424 .6356 L
.68491 .64923 L
.67522 .66026 L
.66026 .67306 L
.64037 .68491 L
.6356 .68696 L
.61095 .69462 L
.58629 .6976 L
.56164 .6967 L
.53698 .69237 L
.5125 .68491 L
.51233 .68483 L
.48767 .67414 L
.4631 .66026 L
.46302 .6602 L
.43836 .64277 L
.42952 .6356 L
.41371 .62135 L
.40332 .61095 L
.38905 .59503 L
.38193 .58629 L
.3644 .56197 L
.36418 .56164 L
.34943 .53698 L
.33974 .5177 L
.33734 .51233 L
.3277 .48767 L
.32042 .46302 L
.3155 .43836 L
.31509 .43555 L
.31302 .41371 L
.31318 .38905 L
.31509 .37156 L
.31634 .3644 L
.3231 .33974 L
.33462 .31509 L
.33974 .30702 L
.3533 .29043 L
.3644 .28037 L
.38732 .26578 L
F
0 g
.38905 .26497 m
.41371 .25627 L
.43836 .25247 L
.46302 .25267 L
.48767 .25637 L
.51233 .2633 L
.51941 .26578 L
.53698 .27339 L
.56164 .2867 L
.56767 .29043 L
.58629 .30343 L
.60088 .31509 L
.61095 .32403 L
.62687 .33974 L
.6356 .34932 L
.64812 .3644 L
.66026 .38086 L
.66576 .38905 L
.6804 .41371 L
.68491 .42231 L
.69241 .43836 L
.70196 .46302 L
.70916 .48767 L
.70957 .4888 L
.714 .51233 L
.71639 .53698 L
.71613 .56164 L
.71285 .58629 L
.70957 .60081 L
.70594 .61095 L
.69424 .6356 L
.68491 .64923 L
.67522 .66026 L
.66026 .67306 L
.64037 .68491 L
.6356 .68696 L
.61095 .69462 L
.58629 .6976 L
.56164 .6967 L
.53698 .69237 L
.5125 .68491 L
.51233 .68483 L
.48767 .67414 L
.4631 .66026 L
.46302 .6602 L
.43836 .64277 L
.42952 .6356 L
.41371 .62135 L
.40332 .61095 L
.38905 .59503 L
Mistroke
.38193 .58629 L
.3644 .56197 L
.36418 .56164 L
.34943 .53698 L
.33974 .5177 L
.33734 .51233 L
.3277 .48767 L
.32042 .46302 L
.3155 .43836 L
.31509 .43555 L
.31302 .41371 L
.31318 .38905 L
.31509 .37156 L
.31634 .3644 L
.3231 .33974 L
.33462 .31509 L
.33974 .30702 L
.3533 .29043 L
.3644 .28037 L
.38732 .26578 L
.38905 .26497 L
Mfstroke
.8 g
.46302 .29021 m
.46859 .29043 L
.48767 .29278 L
.51233 .29932 L
.53698 .30968 L
.54738 .31509 L
.56164 .32394 L
.58299 .33974 L
.58629 .34254 L
.60916 .3644 L
.61095 .36634 L
.62973 .38905 L
.6356 .39722 L
.64617 .41371 L
.65921 .43836 L
.66026 .44054 L
.66927 .46302 L
.67646 .48767 L
.68079 .51233 L
.6821 .53698 L
.68002 .56164 L
.6738 .58629 L
.6618 .61095 L
.66026 .61332 L
.6401 .6356 L
.6356 .63903 L
.61095 .65233 L
.58629 .65848 L
.56164 .65944 L
.53698 .65609 L
.51233 .64882 L
.48767 .63772 L
.48367 .6356 L
.46302 .62268 L
.4474 .61095 L
.43836 .60319 L
.421 .58629 L
.41371 .57824 L
.40028 .56164 L
.38905 .54556 L
.38372 .53698 L
.37055 .51233 L
.3644 .49845 L
.36041 .48767 L
.35311 .46302 L
.34867 .43836 L
.34724 .41371 L
.3492 .38905 L
.35527 .3644 L
.3644 .34392 L
.36699 .33974 L
.38831 .31509 L
.38905 .31448 L
.41371 .29939 L
.43836 .29208 L
.45244 .29043 L
F
0 g
.46302 .29021 m
.46859 .29043 L
.48767 .29278 L
.51233 .29932 L
.53698 .30968 L
.54738 .31509 L
.56164 .32394 L
.58299 .33974 L
.58629 .34254 L
.60916 .3644 L
.61095 .36634 L
.62973 .38905 L
.6356 .39722 L
.64617 .41371 L
.65921 .43836 L
.66026 .44054 L
.66927 .46302 L
.67646 .48767 L
.68079 .51233 L
.6821 .53698 L
.68002 .56164 L
.6738 .58629 L
.6618 .61095 L
.66026 .61332 L
.6401 .6356 L
.6356 .63903 L
.61095 .65233 L
.58629 .65848 L
.56164 .65944 L
.53698 .65609 L
.51233 .64882 L
.48767 .63772 L
.48367 .6356 L
.46302 .62268 L
.4474 .61095 L
.43836 .60319 L
.421 .58629 L
.41371 .57824 L
.40028 .56164 L
.38905 .54556 L
.38372 .53698 L
.37055 .51233 L
.3644 .49845 L
.36041 .48767 L
.35311 .46302 L
.34867 .43836 L
.34724 .41371 L
.3492 .38905 L
.35527 .3644 L
.3644 .34392 L
Mistroke
.36699 .33974 L
.38831 .31509 L
.38905 .31448 L
.41371 .29939 L
.43836 .29208 L
.45244 .29043 L
.46302 .29021 L
Mfstroke
.9 g
.43836 .3381 m
.46302 .33218 L
.48767 .33277 L
.51233 .33866 L
.5159 .33974 L
.53698 .34944 L
.56034 .3644 L
.56164 .36544 L
.58629 .38757 L
.5877 .38905 L
.60771 .41371 L
.61095 .4184 L
.62268 .43836 L
.63353 .46302 L
.6356 .4671 L
.64071 .48767 L
.64419 .51233 L
.64357 .53698 L
.63783 .56164 L
.6356 .5678 L
.62478 .58629 L
.61095 .60029 L
.59441 .61095 L
.58629 .61346 L
.56164 .61797 L
.53698 .61631 L
.51644 .61095 L
.51233 .60948 L
.48767 .59775 L
.47 .58629 L
.46302 .58071 L
.44242 .56164 L
.43836 .5572 L
.42224 .53698 L
.41371 .52404 L
.40716 .51233 L
.39613 .48767 L
.38905 .46402 L
.38887 .46302 L
.38525 .43836 L
.38573 .41371 L
.38905 .39618 L
.3912 .38905 L
.404 .3644 L
.41371 .35359 L
.43393 .33974 L
F
0 g
.43836 .3381 m
.46302 .33218 L
.48767 .33277 L
.51233 .33866 L
.5159 .33974 L
.53698 .34944 L
.56034 .3644 L
.56164 .36544 L
.58629 .38757 L
.5877 .38905 L
.60771 .41371 L
.61095 .4184 L
.62268 .43836 L
.63353 .46302 L
.6356 .4671 L
.64071 .48767 L
.64419 .51233 L
.64357 .53698 L
.63783 .56164 L
.6356 .5678 L
.62478 .58629 L
.61095 .60029 L
.59441 .61095 L
.58629 .61346 L
.56164 .61797 L
.53698 .61631 L
.51644 .61095 L
.51233 .60948 L
.48767 .59775 L
.47 .58629 L
.46302 .58071 L
.44242 .56164 L
.43836 .5572 L
.42224 .53698 L
.41371 .52404 L
.40716 .51233 L
.39613 .48767 L
.38905 .46402 L
.38887 .46302 L
.38525 .43836 L
.38573 .41371 L
.38905 .39618 L
.3912 .38905 L
.404 .3644 L
.41371 .35359 L
.43393 .33974 L
.43836 .3381 L
s
1 g
.46302 .38895 m
.48767 .38349 L
.51233 .38769 L
.51612 .38905 L
.53698 .39946 L
.55572 .41371 L
.56164 .42016 L
.57608 .43836 L
.58629 .45631 L
.58888 .46302 L
.59618 .48767 L
.59742 .51233 L
.59058 .53698 L
.58629 .54492 L
.56465 .56164 L
.56164 .56287 L
.53698 .56616 L
.51566 .56164 L
.51233 .56048 L
.48767 .54711 L
.47471 .53698 L
.46302 .52435 L
.45398 .51233 L
.44074 .48767 L
.43836 .48103 L
.43345 .46302 L
.43201 .43836 L
.43836 .41421 L
.43853 .41371 L
.46271 .38905 L
F
0 g
.46302 .38895 m
.48767 .38349 L
.51233 .38769 L
.51612 .38905 L
.53698 .39946 L
.55572 .41371 L
.56164 .42016 L
.57608 .43836 L
.58629 .45631 L
.58888 .46302 L
.59618 .48767 L
.59742 .51233 L
.59058 .53698 L
.58629 .54492 L
.56465 .56164 L
.56164 .56287 L
.53698 .56616 L
.51566 .56164 L
.51233 .56048 L
.48767 .54711 L
.47471 .53698 L
.46302 .52435 L
.45398 .51233 L
.44074 .48767 L
.43836 .48103 L
.43345 .46302 L
.43201 .43836 L
.43836 .41421 L
.43853 .41371 L
.46271 .38905 L
.46302 .38895 L
s
.98077 .47104 m
.97834 .46302 L
.97019 .43836 L
.96101 .41371 L
.95611 .40155 L
.95083 .38905 L
.9397 .3644 L
.93146 .34733 L
.92759 .33974 L
.91438 .31509 L
.9068 .3017 L
.90011 .29043 L
.8847 .26578 L
.88215 .26187 L
.86803 .24112 L
.8575 .22639 L
.85009 .21647 L
.83284 .19437 L
.83076 .19181 L
.80987 .16716 L
.80819 .16525 L
.78727 .1425 L
.78353 .13861 L
.76275 .11785 L
.75888 .11414 L
.736 .0932 L
.73422 .09163 L
.70957 .07092 L
.7066 .06854 L
.68491 .05188 L
.67394 .04389 L
.66026 .03432 L
.63705 .01923 L
.98077 .01923 L
F
.98077 .47104 m
.97834 .46302 L
.97019 .43836 L
.96101 .41371 L
.95611 .40155 L
.95083 .38905 L
.9397 .3644 L
.93146 .34733 L
.92759 .33974 L
.91438 .31509 L
.9068 .3017 L
.90011 .29043 L
.8847 .26578 L
.88215 .26187 L
.86803 .24112 L
.8575 .22639 L
.85009 .21647 L
.83284 .19437 L
.83076 .19181 L
.80987 .16716 L
.80819 .16525 L
.78727 .1425 L
.78353 .13861 L
.76275 .11785 L
.75888 .11414 L
.736 .0932 L
.73422 .09163 L
.70957 .07092 L
.7066 .06854 L
.68491 .05188 L
.67394 .04389 L
.66026 .03432 L
.63705 .01923 L
s
.98077 .81205 m
.97213 .83284 L
.95975 .8575 L
.95611 .86391 L
.94471 .88215 L
.93146 .9005 L
.92641 .9068 L
.9068 .92851 L
.90383 .93146 L
.88215 .95071 L
.87523 .95611 L
.8575 .96858 L
.83694 .98077 L
.98077 .98077 L
F
.98077 .81205 m
.97213 .83284 L
.95975 .8575 L
.95611 .86391 L
.94471 .88215 L
.93146 .9005 L
.92641 .9068 L
.9068 .92851 L
.90383 .93146 L
.88215 .95071 L
.87523 .95611 L
.8575 .96858 L
.83694 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58845 Mtetra
.42372 .58845 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.663 .741 .908 r
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57634 Mtetra
.46385 .57634 .47147 .58381 .48494 .57977 .47736 .57227 Mtetra
.47736 .57227 .48494 .57977 .49847 .57572 .49093 .56818 Mtetra
.49093 .56818 .49847 .57572 .51207 .57165 .50458 .56407 Mtetra
.50458 .56407 .51207 .57165 .52574 .56756 .51829 .55995 Mtetra
.663 .741 .909 r
.51829 .55995 .52574 .56756 .53948 .56346 .53207 .55583 Mtetra
.662 .742 .909 r
.53207 .55583 .53948 .56346 .55329 .55936 .54593 .5517 Mtetra
.661 .742 .91 r
.54593 .5517 .55329 .55936 .56716 .55525 .55985 .54758 Mtetra
.66 .742 .91 r
.55985 .54758 .56716 .55525 .58111 .55115 .57384 .54347 Mtetra
.659 .742 .912 r
.57384 .54347 .58111 .55115 .59513 .54707 .58791 .5394 Mtetra
.657 .743 .913 r
.58791 .5394 .59513 .54707 .60922 .54302 .60205 .53537 Mtetra
.654 .744 .916 r
.60205 .53537 .60922 .54302 .62339 .53901 .61627 .53141 Mtetra
.651 .745 .918 r
.61627 .53141 .62339 .53901 .63763 .53507 .63057 .52754 Mtetra
.647 .747 .922 r
.63057 .52754 .63763 .53507 .65196 .53122 .64495 .52379 Mtetra
.641 .749 .927 r
.64495 .52379 .65196 .53122 .66636 .52748 .65941 .52018 Mtetra
.635 .751 .932 r
.65941 .52018 .66636 .52748 .68085 .52387 .67396 .51674 Mtetra
.627 .755 .939 r
.67396 .51674 .68085 .52387 .69543 .5204 .68861 .51349 Mtetra
.618 .759 .946 r
.68861 .51349 .69543 .5204 .71011 .5171 .70336 .51043 Mtetra
.608 .764 .954 r
.70336 .51043 .71011 .5171 .72488 .51395 .7182 .50756 Mtetra
.597 .769 .962 r
.7182 .50756 .72488 .51395 .73975 .51096 .73315 .50487 Mtetra
.586 .776 .97 r
.73315 .50487 .73975 .51096 .75472 .50809 .7482 .50231 Mtetra
.576 .783 .977 r
.7482 .50231 .75472 .50809 .76978 .50531 .76336 .49983 Mtetra
.567 .791 .983 r
.76336 .49983 .76978 .50531 .78495 .50257 .77862 .49737 Mtetra
.562 .8 .988 r
.77862 .49737 .78495 .50257 .80021 .49979 .79397 .49483 Mtetra
.562 .809 .991 r
.79397 .49483 .80021 .49979 .81556 .4969 .80941 .49212 Mtetra
.568 .819 .992 r
.80941 .49212 .81556 .4969 .83099 .49381 .82492 .48915 Mtetra
.579 .829 .992 r
.82492 .48915 .83099 .49381 .84649 .49045 .84051 .48581 Mtetra
.595 .837 .99 r
.84051 .48581 .84649 .49045 .86205 .48674 .85614 .48205 Mtetra
.615 .844 .987 r
.85614 .48205 .86205 .48674 .87766 .48263 .87182 .47779 Mtetra
.636 .848 .981 r
.87182 .47779 .87766 .48263 .89332 .4781 .88753 .47302 Mtetra
.657 .849 .974 r
.88753 .47302 .89332 .4781 .90901 .47312 .90327 .46775 Mtetra
.675 .847 .965 r
.90327 .46775 .90901 .47312 .92473 .46773 .91904 .46199 Mtetra
.69 .841 .956 r
.91904 .46199 .92473 .46773 .94049 .46195 .93483 .45582 Mtetra
.701 .834 .946 r
.93483 .45582 .94049 .46195 .95628 .45585 .95066 .44931 Mtetra
.708 .825 .937 r
.95066 .44931 .95628 .45585 .97212 .44951 .96652 .44255 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58845 .41589 .58101 Mtetra
.41589 .58101 .42372 .58845 .43703 .58443 .42925 .57696 Mtetra
.663 .741 .908 r
.42925 .57696 .43703 .58443 .4504 .58039 .44266 .57289 Mtetra
.44266 .57289 .4504 .58039 .46385 .57634 .45615 .5688 Mtetra
.45615 .5688 .46385 .57634 .47736 .57227 .4697 .56469 Mtetra
.4697 .56469 .47736 .57227 .49093 .56818 .48332 .56057 Mtetra
.48332 .56057 .49093 .56818 .50458 .56407 .49701 .55643 Mtetra
.663 .741 .909 r
.49701 .55643 .50458 .56407 .51829 .55995 .51077 .55228 Mtetra
.662 .742 .909 r
.51077 .55228 .51829 .55995 .53207 .55583 .5246 .54813 Mtetra
.5246 .54813 .53207 .55583 .54593 .5517 .5385 .54399 Mtetra
.661 .742 .91 r
.5385 .54399 .54593 .5517 .55985 .54758 .55247 .53985 Mtetra
.659 .742 .911 r
.55247 .53985 .55985 .54758 .57384 .54347 .56651 .53575 Mtetra
.657 .743 .913 r
.56651 .53575 .57384 .54347 .58791 .5394 .58062 .5317 Mtetra
.655 .744 .915 r
.58062 .5317 .58791 .5394 .60205 .53537 .59481 .52771 Mtetra
.651 .745 .918 r
.59481 .52771 .60205 .53537 .61627 .53141 .60908 .52382 Mtetra
.647 .746 .922 r
.60908 .52382 .61627 .53141 .63057 .52754 .62344 .52006 Mtetra
.641 .748 .927 r
.62344 .52006 .63057 .52754 .64495 .52379 .63787 .51645 Mtetra
.634 .751 .932 r
.63787 .51645 .64495 .52379 .65941 .52018 .6524 .51302 Mtetra
.625 .754 .939 r
.6524 .51302 .65941 .52018 .67396 .51674 .66701 .5098 Mtetra
.615 .758 .947 r
.66701 .5098 .67396 .51674 .68861 .51349 .68173 .50681 Mtetra
.603 .763 .956 r
.68173 .50681 .68861 .51349 .70336 .51043 .69655 .50406 Mtetra
.589 .768 .965 r
.69655 .50406 .70336 .51043 .7182 .50756 .71148 .50152 Mtetra
.575 .774 .973 r
.71148 .50152 .7182 .50756 .73315 .50487 .72651 .49918 Mtetra
.56 .781 .982 r
.72651 .49918 .73315 .50487 .7482 .50231 .74165 .49698 Mtetra
.547 .789 .988 r
.74165 .49698 .7482 .50231 .76336 .49983 .7569 .49485 Mtetra
.537 .798 .993 r
.7569 .49485 .76336 .49983 .77862 .49737 .77225 .4927 Mtetra
.531 .807 .997 r
.77225 .4927 .77862 .49737 .79397 .49483 .7877 .49041 Mtetra
.533 .818 .998 r
.7877 .49041 .79397 .49483 .80941 .49212 .80323 .48788 Mtetra
.543 .829 .998 r
.80323 .48788 .80941 .49212 .82492 .48915 .81883 .48499 Mtetra
.56 .841 .997 r
.81883 .48499 .82492 .48915 .84051 .48581 .8345 .48165 Mtetra
.584 .851 .995 r
.8345 .48165 .84051 .48581 .85614 .48205 .85021 .47777 Mtetra
.611 .859 .99 r
.85021 .47777 .85614 .48205 .87182 .47779 .86595 .47331 Mtetra
.638 .863 .984 r
.86595 .47331 .87182 .47779 .88753 .47302 .88172 .46824 Mtetra
.663 .863 .975 r
.88172 .46824 .88753 .47302 .90327 .46775 .8975 .46258 Mtetra
.684 .859 .965 r
.8975 .46258 .90327 .46775 .91904 .46199 .91331 .4564 Mtetra
.7 .852 .955 r
.91331 .4564 .91904 .46199 .93483 .45582 .92913 .44976 Mtetra
.711 .842 .944 r
.92913 .44976 .93483 .45582 .95066 .44931 .94498 .44278 Mtetra
.718 .831 .935 r
.94498 .44278 .95066 .44931 .96652 .44255 .96087 .43556 Mtetra
.664 .741 .908 r
.38141 .58164 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.663 .741 .908 r
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56943 Mtetra
.42139 .56943 .42925 .57696 .44266 .57289 .43486 .56532 Mtetra
.43486 .56532 .44266 .57289 .45615 .5688 .44838 .56119 Mtetra
.44838 .56119 .45615 .5688 .4697 .56469 .46198 .55705 Mtetra
.46198 .55705 .4697 .56469 .48332 .56057 .47564 .55289 Mtetra
.47564 .55289 .48332 .56057 .49701 .55643 .48938 .54872 Mtetra
.662 .742 .909 r
.48938 .54872 .49701 .55643 .51077 .55228 .50318 .54455 Mtetra
.50318 .54455 .51077 .55228 .5246 .54813 .51705 .54038 Mtetra
.661 .742 .91 r
.51705 .54038 .5246 .54813 .5385 .54399 .531 .53622 Mtetra
.659 .742 .911 r
.531 .53622 .5385 .54399 .55247 .53985 .54501 .53209 Mtetra
.658 .743 .913 r
.54501 .53209 .55247 .53985 .56651 .53575 .5591 .52801 Mtetra
.655 .743 .915 r
.5591 .52801 .56651 .53575 .58062 .5317 .57327 .52399 Mtetra
.651 .744 .918 r
.57327 .52399 .58062 .5317 .59481 .52771 .58751 .52007 Mtetra
.647 .746 .921 r
.58751 .52007 .59481 .52771 .60908 .52382 .60183 .51628 Mtetra
.641 .748 .926 r
.60183 .51628 .60908 .52382 .62344 .52006 .61624 .51266 Mtetra
.633 .75 .932 r
.61624 .51266 .62344 .52006 .63787 .51645 .63073 .50923 Mtetra
.624 .753 .939 r
.63073 .50923 .63787 .51645 .6524 .51302 .64532 .50603 Mtetra
.612 .757 .948 r
.64532 .50603 .6524 .51302 .66701 .5098 .66001 .5031 Mtetra
.598 .761 .957 r
.66001 .5031 .66701 .5098 .68173 .50681 .6748 .50044 Mtetra
.582 .767 .967 r
.6748 .50044 .68173 .50681 .69655 .50406 .68969 .49805 Mtetra
.564 .772 .976 r
.68969 .49805 .69655 .50406 .71148 .50152 .7047 .49591 Mtetra
.544 .779 .985 r
.7047 .49591 .71148 .50152 .72651 .49918 .71982 .49398 Mtetra
.525 .785 .992 r
.71982 .49398 .72651 .49918 .74165 .49698 .73506 .49219 Mtetra
.508 .793 .997 r
.73506 .49219 .74165 .49698 .7569 .49485 .75041 .49044 Mtetra
.496 .801 .999 r
.75041 .49044 .7569 .49485 .77225 .4927 .76586 .48861 Mtetra
.491 .811 1 r
.76586 .48861 .77225 .4927 .7877 .49041 .7814 .48658 Mtetra
.497 .823 1 r
.7814 .48658 .7877 .49041 .80323 .48788 .79703 .48422 Mtetra
.513 .837 .999 r
.79703 .48422 .80323 .48788 .81883 .48499 .81272 .48138 Mtetra
.54 .852 .998 r
.81272 .48138 .81883 .48499 .8345 .48165 .82846 .47798 Mtetra
.573 .865 .996 r
.82846 .47798 .8345 .48165 .85021 .47777 .84424 .47392 Mtetra
.609 .874 .991 r
.84424 .47392 .85021 .47777 .86595 .47331 .86004 .46916 Mtetra
.643 .878 .984 r
.86004 .46916 .86595 .47331 .88172 .46824 .87586 .46371 Mtetra
.673 .877 .975 r
.87586 .46371 .88172 .46824 .8975 .46258 .89169 .4576 Mtetra
.696 .871 .964 r
.89169 .4576 .8975 .46258 .91331 .4564 .90752 .45091 Mtetra
.713 .861 .952 r
.90752 .45091 .91331 .4564 .92913 .44976 .92337 .44374 Mtetra
.723 .849 .941 r
.92337 .44374 .92913 .44976 .94498 .44278 .93925 .43623 Mtetra
.729 .836 .931 r
.93925 .43623 .94498 .44278 .96087 .43556 .95516 .4285 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58164 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56595 Mtetra
.663 .741 .908 r
.40003 .56595 .408 .57351 .42139 .56943 .41347 .56182 Mtetra
.41347 .56182 .42139 .56943 .43486 .56532 .42697 .55768 Mtetra
.42697 .55768 .43486 .56532 .44838 .56119 .44054 .55351 Mtetra
.44054 .55351 .44838 .56119 .46198 .55705 .45418 .54934 Mtetra
.45418 .54934 .46198 .55705 .47564 .55289 .46789 .54515 Mtetra
.663 .741 .909 r
.46789 .54515 .47564 .55289 .48938 .54872 .48167 .54095 Mtetra
.662 .742 .909 r
.48167 .54095 .48938 .54872 .50318 .54455 .49552 .53676 Mtetra
.661 .742 .91 r
.49552 .53676 .50318 .54455 .51705 .54038 .50944 .53257 Mtetra
.66 .742 .911 r
.50944 .53257 .51705 .54038 .531 .53622 .52343 .52841 Mtetra
.658 .742 .912 r
.52343 .52841 .531 .53622 .54501 .53209 .53749 .5243 Mtetra
.655 .743 .914 r
.53749 .5243 .54501 .53209 .5591 .52801 .55163 .52025 Mtetra
.652 .744 .917 r
.55163 .52025 .5591 .52801 .57327 .52399 .56584 .51629 Mtetra
.647 .745 .921 r
.56584 .51629 .57327 .52399 .58751 .52007 .58013 .51247 Mtetra
.641 .747 .926 r
.58013 .51247 .58751 .52007 .60183 .51628 .59451 .50882 Mtetra
.633 .749 .932 r
.59451 .50882 .60183 .51628 .61624 .51266 .60897 .50538 Mtetra
.623 .752 .939 r
.60897 .50538 .61624 .51266 .63073 .50923 .62353 .50219 Mtetra
.611 .756 .948 r
.62353 .50219 .63073 .50923 .64532 .50603 .63818 .49929 Mtetra
.595 .76 .957 r
.63818 .49929 .64532 .50603 .66001 .5031 .65294 .4967 Mtetra
.576 .765 .968 r
.65294 .4967 .66001 .5031 .6748 .50044 .6678 .49443 Mtetra
.554 .77 .978 r
.6678 .49443 .6748 .50044 .68969 .49805 .68278 .49248 Mtetra
.529 .775 .987 r
.68278 .49248 .68969 .49805 .7047 .49591 .69788 .49081 Mtetra
.503 .78 .994 r
.69788 .49081 .7047 .49591 .71982 .49398 .7131 .48935 Mtetra
.477 .785 .998 r
.7131 .48935 .71982 .49398 .73506 .49219 .72843 .48801 Mtetra
.455 .791 .999 r
.72843 .48801 .73506 .49219 .75041 .49044 .74388 .48667 Mtetra
.441 .798 .997 r
.74388 .48667 .75041 .49044 .76586 .48861 .75943 .48518 Mtetra
.44 .809 .994 r
.75943 .48518 .76586 .48861 .7814 .48658 .77508 .4834 Mtetra
.452 .824 .992 r
.77508 .4834 .7814 .48658 .79703 .48422 .7908 .48116 Mtetra
.479 .842 .992 r
.7908 .48116 .79703 .48422 .81272 .48138 .80658 .47833 Mtetra
.518 .861 .993 r
.80658 .47833 .81272 .48138 .82846 .47798 .8224 .47479 Mtetra
.563 .877 .993 r
.8224 .47479 .82846 .47798 .84424 .47392 .83824 .47047 Mtetra
.61 .889 .99 r
.83824 .47047 .84424 .47392 .86004 .46916 .8541 .46534 Mtetra
.651 .893 .983 r
.8541 .46534 .86004 .46916 .87586 .46371 .86996 .45941 Mtetra
.685 .89 .973 r
.86996 .45941 .87586 .46371 .89169 .4576 .88582 .45276 Mtetra
.71 .881 .96 r
.88582 .45276 .89169 .4576 .90752 .45091 .90168 .44548 Mtetra
.727 .869 .948 r
.90168 .44548 .90752 .45091 .92337 .44374 .91755 .43771 Mtetra
.736 .854 .936 r
.91755 .43771 .92337 .44374 .93925 .43623 .93344 .42961 Mtetra
.74 .84 .926 r
.93344 .42961 .93925 .43623 .95516 .4285 .94937 .42134 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.663 .741 .908 r
.37858 .56245 .38666 .57005 .40003 .56595 .39199 .55831 Mtetra
.39199 .55831 .40003 .56595 .41347 .56182 .40547 .55415 Mtetra
.40547 .55415 .41347 .56182 .42697 .55768 .41902 .54997 Mtetra
.41902 .54997 .42697 .55768 .44054 .55351 .43263 .54577 Mtetra
.43263 .54577 .44054 .55351 .45418 .54934 .44631 .54156 Mtetra
.663 .741 .909 r
.44631 .54156 .45418 .54934 .46789 .54515 .46007 .53734 Mtetra
.662 .742 .909 r
.46007 .53734 .46789 .54515 .48167 .54095 .47389 .53312 Mtetra
.661 .742 .91 r
.47389 .53312 .48167 .54095 .49552 .53676 .48778 .52891 Mtetra
.66 .742 .911 r
.48778 .52891 .49552 .53676 .50944 .53257 .50175 .52472 Mtetra
.658 .742 .912 r
.50175 .52472 .50944 .53257 .52343 .52841 .51578 .52057 Mtetra
.656 .743 .914 r
.51578 .52057 .52343 .52841 .53749 .5243 .52989 .51648 Mtetra
.653 .744 .916 r
.52989 .51648 .53749 .5243 .55163 .52025 .54408 .51249 Mtetra
.648 .745 .92 r
.54408 .51249 .55163 .52025 .56584 .51629 .55834 .50862 Mtetra
.642 .746 .925 r
.55834 .50862 .56584 .51629 .58013 .51247 .57269 .50494 Mtetra
.634 .748 .931 r
.57269 .50494 .58013 .51247 .59451 .50882 .58712 .50147 Mtetra
.623 .751 .938 r
.58712 .50147 .59451 .50882 .60897 .50538 .60164 .49826 Mtetra
.61 .754 .947 r
.60164 .49826 .60897 .50538 .62353 .50219 .61626 .49537 Mtetra
.593 .758 .957 r
.61626 .49537 .62353 .50219 .63818 .49929 .63098 .49283 Mtetra
.572 .762 .968 r
.63098 .49283 .63818 .49929 .65294 .4967 .64581 .49066 Mtetra
.546 .767 .979 r
.64581 .49066 .65294 .4967 .6678 .49443 .66076 .48887 Mtetra
.516 .77 .989 r
.66076 .48887 .6678 .49443 .68278 .49248 .67582 .48743 Mtetra
.481 .773 .996 r
.67582 .48743 .68278 .49248 .69788 .49081 .69101 .48629 Mtetra
.445 .775 .998 r
.69101 .48629 .69788 .49081 .7131 .48935 .70633 .48535 Mtetra
.411 .776 .995 r
.70633 .48535 .7131 .48935 .72843 .48801 .72177 .48451 Mtetra
.385 .779 .988 r
.72177 .48451 .72843 .48801 .74388 .48667 .73732 .4836 Mtetra
.372 .785 .98 r
.73732 .4836 .74388 .48667 .75943 .48518 .75297 .48245 Mtetra
.376 .797 .974 r
.75297 .48245 .75943 .48518 .77508 .4834 .76872 .48089 Mtetra
.4 .817 .973 r
.76872 .48089 .77508 .4834 .7908 .48116 .78453 .47873 Mtetra
.442 .842 .977 r
.78453 .47873 .7908 .48116 .80658 .47833 .8004 .47583 Mtetra
.497 .868 .982 r
.8004 .47583 .80658 .47833 .8224 .47479 .81629 .47208 Mtetra
.557 .89 .986 r
.81629 .47208 .8224 .47479 .83824 .47047 .8322 .4674 Mtetra
.615 .903 .985 r
.8322 .4674 .83824 .47047 .8541 .46534 .84811 .46179 Mtetra
.664 .907 .979 r
.84811 .46179 .8541 .46534 .86996 .45941 .86401 .45528 Mtetra
.701 .902 .968 r
.86401 .45528 .86996 .45941 .88582 .45276 .8799 .44799 Mtetra
.727 .89 .955 r
.8799 .44799 .88582 .45276 .90168 .44548 .89578 .44005 Mtetra
.742 .875 .941 r
.89578 .44005 .90168 .44548 .91755 .43771 .91166 .43162 Mtetra
.75 .858 .929 r
.91166 .43162 .91755 .43771 .93344 .42961 .92757 .42288 Mtetra
.752 .842 .919 r
.92757 .42288 .93344 .42961 .94937 .42134 .94351 .41402 Mtetra
.663 .741 .908 r
.35704 .55895 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55415 .3974 .5464 Mtetra
.3974 .5464 .40547 .55415 .41902 .54997 .41099 .54219 Mtetra
.41099 .54219 .41902 .54997 .43263 .54577 .42464 .53795 Mtetra
.42464 .53795 .43263 .54577 .44631 .54156 .43837 .53371 Mtetra
.662 .741 .909 r
.43837 .53371 .44631 .54156 .46007 .53734 .45217 .52947 Mtetra
.662 .742 .909 r
.45217 .52947 .46007 .53734 .47389 .53312 .46603 .52523 Mtetra
.66 .742 .91 r
.46603 .52523 .47389 .53312 .48778 .52891 .47997 .52101 Mtetra
.659 .742 .912 r
.47997 .52101 .48778 .52891 .50175 .52472 .49398 .51682 Mtetra
.657 .743 .913 r
.49398 .51682 .50175 .52472 .51578 .52057 .50807 .51269 Mtetra
.653 .743 .916 r
.50807 .51269 .51578 .52057 .52989 .51648 .52222 .50866 Mtetra
.649 .744 .919 r
.52222 .50866 .52989 .51648 .54408 .51249 .53646 .50475 Mtetra
.643 .746 .924 r
.53646 .50475 .54408 .51249 .55834 .50862 .55077 .50101 Mtetra
.635 .748 .93 r
.55077 .50101 .55834 .50862 .57269 .50494 .56517 .4975 Mtetra
.624 .75 .937 r
.56517 .4975 .57269 .50494 .58712 .50147 .57966 .49426 Mtetra
.61 .753 .946 r
.57966 .49426 .58712 .50147 .60164 .49826 .59424 .49136 Mtetra
.592 .756 .957 r
.59424 .49136 .60164 .49826 .61626 .49537 .60892 .48884 Mtetra
.569 .76 .968 r
.60892 .48884 .61626 .49537 .63098 .49283 .62371 .48673 Mtetra
.54 .763 .98 r
.62371 .48673 .63098 .49283 .64581 .49066 .63862 .48507 Mtetra
.504 .766 .99 r
.63862 .48507 .64581 .49066 .66076 .48887 .65365 .48383 Mtetra
.462 .766 .996 r
.65365 .48383 .66076 .48887 .67582 .48743 .66881 .48297 Mtetra
.415 .763 .995 r
.66881 .48297 .67582 .48743 .69101 .48629 .68409 .48243 Mtetra
.367 .758 .987 r
.68409 .48243 .69101 .48629 .70633 .48535 .69951 .48207 Mtetra
.325 .752 .973 r
.69951 .48207 .70633 .48535 .72177 .48451 .71506 .48175 Mtetra
.296 .75 .955 r
.71506 .48175 .72177 .48451 .73732 .4836 .73072 .48128 Mtetra
.287 .756 .942 r
.73072 .48128 .73732 .4836 .75297 .48245 .74648 .48045 Mtetra
.303 .773 .936 r
.74648 .48045 .75297 .48245 .76872 .48089 .76233 .47906 Mtetra
.343 .801 .94 r
.76233 .47906 .76872 .48089 .78453 .47873 .77823 .47692 Mtetra
.405 .837 .952 r
.77823 .47692 .78453 .47873 .8004 .47583 .79418 .47387 Mtetra
.481 .873 .966 r
.79418 .47387 .8004 .47583 .81629 .47208 .81015 .46979 Mtetra
.558 .902 .977 r
.81015 .46979 .81629 .47208 .8322 .4674 .82611 .46464 Mtetra
.627 .918 .979 r
.82611 .46464 .8322 .4674 .84811 .46179 .84206 .45844 Mtetra
.682 .92 .972 r
.84206 .45844 .84811 .46179 .86401 .45528 .85799 .45126 Mtetra
.72 .911 .961 r
.85799 .45126 .86401 .45528 .8799 .44799 .8739 .44323 Mtetra
.745 .897 .947 r
.8739 .44323 .8799 .44799 .89578 .44005 .8898 .43455 Mtetra
.759 .879 .933 r
.8898 .43455 .89578 .44005 .91166 .43162 .9057 .42539 Mtetra
.764 .86 .921 r
.9057 .42539 .91166 .43162 .92757 .42288 .92161 .41598 Mtetra
.763 .842 .911 r
.92161 .41598 .92757 .42288 .94351 .41402 .93757 .4065 Mtetra
.663 .741 .908 r
.34877 .55124 .35704 .55895 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54282 Mtetra
.37569 .54282 .38388 .5506 .3974 .5464 .38925 .53859 Mtetra
.38925 .53859 .3974 .5464 .41099 .54219 .40288 .53433 Mtetra
.40288 .53433 .41099 .54219 .42464 .53795 .41658 .53007 Mtetra
.662 .741 .909 r
.41658 .53007 .42464 .53795 .43837 .53371 .43035 .5258 Mtetra
.662 .742 .909 r
.43035 .5258 .43837 .53371 .45217 .52947 .44419 .52153 Mtetra
.661 .742 .91 r
.44419 .52153 .45217 .52947 .46603 .52523 .45811 .51728 Mtetra
.659 .742 .911 r
.45811 .51728 .46603 .52523 .47997 .52101 .47209 .51306 Mtetra
.657 .742 .913 r
.47209 .51306 .47997 .52101 .49398 .51682 .48614 .50889 Mtetra
.654 .743 .915 r
.48614 .50889 .49398 .51682 .50807 .51269 .50027 .50481 Mtetra
.65 .744 .918 r
.50027 .50481 .50807 .51269 .52222 .50866 .51448 .50085 Mtetra
.644 .745 .923 r
.51448 .50085 .52222 .50866 .53646 .50475 .52876 .49706 Mtetra
.636 .747 .928 r
.52876 .49706 .53646 .50475 .55077 .50101 .54313 .49349 Mtetra
.625 .749 .936 r
.54313 .49349 .55077 .50101 .56517 .4975 .55758 .4902 Mtetra
.611 .752 .945 r
.55758 .4902 .56517 .4975 .57966 .49426 .57212 .48726 Mtetra
.592 .755 .955 r
.57212 .48726 .57966 .49426 .59424 .49136 .58677 .48473 Mtetra
.568 .758 .967 r
.58677 .48473 .59424 .49136 .60892 .48884 .60152 .48265 Mtetra
.536 .76 .979 r
.60152 .48265 .60892 .48884 .62371 .48673 .61638 .48107 Mtetra
.496 .761 .99 r
.61638 .48107 .62371 .48673 .63862 .48507 .63136 .47999 Mtetra
.446 .758 .995 r
.63136 .47999 .63862 .48507 .65365 .48383 .64648 .47938 Mtetra
.387 .751 .992 r
.64648 .47938 .65365 .48383 .66881 .48297 .66173 .47919 Mtetra
.324 .738 .978 r
.66173 .47919 .66881 .48297 .68409 .48243 .67712 .4793 Mtetra
.264 .721 .953 r
.67712 .4793 .68409 .48243 .69951 .48207 .69265 .47957 Mtetra
.216 .706 .923 r
.69265 .47957 .69951 .48207 .71506 .48175 .7083 .47979 Mtetra
.189 .701 .896 r
.7083 .47979 .71506 .48175 .73072 .48128 .72407 .47975 Mtetra
.192 .71 .88 r
.72407 .47975 .73072 .48128 .74648 .48045 .73994 .4792 Mtetra
.225 .736 .88 r
.73994 .4792 .74648 .48045 .76233 .47906 .75589 .47792 Mtetra
.288 .779 .896 r
.75589 .47792 .76233 .47906 .77823 .47692 .77189 .47571 Mtetra
.374 .83 .922 r
.77189 .47571 .77823 .47692 .79418 .47387 .78792 .47239 Mtetra
.472 .879 .948 r
.78792 .47239 .79418 .47387 .81015 .46979 .80395 .46788 Mtetra
.567 .914 .966 r
.80395 .46788 .81015 .46979 .82611 .46464 .81996 .46214 Mtetra
.646 .931 .971 r
.81996 .46214 .82611 .46464 .84206 .45844 .83595 .45522 Mtetra
.704 .931 .964 r
.83595 .45522 .84206 .45844 .85799 .45126 .8519 .44725 Mtetra
.742 .918 .951 r
.8519 .44725 .85799 .45126 .8739 .44323 .86783 .43841 Mtetra
.764 .9 .937 r
.86783 .43841 .8739 .44323 .8898 .43455 .88374 .4289 Mtetra
.775 .88 .923 r
.88374 .4289 .8898 .43455 .9057 .42539 .89964 .41897 Mtetra
.777 .859 .911 r
.89964 .41897 .9057 .42539 .92161 .41598 .91557 .40884 Mtetra
.774 .84 .903 r
.91557 .40884 .92161 .41598 .93757 .4065 .93154 .39874 Mtetra
.663 .741 .908 r
.34042 .54347 .34877 .55124 .36219 .54704 .35388 .53923 Mtetra
.35388 .53923 .36219 .54704 .37569 .54282 .36742 .53497 Mtetra
.36742 .53497 .37569 .54282 .38925 .53859 .38103 .5307 Mtetra
.38103 .5307 .38925 .53859 .40288 .53433 .3947 .52641 Mtetra
.663 .741 .909 r
.3947 .52641 .40288 .53433 .41658 .53007 .40844 .52212 Mtetra
.662 .742 .909 r
.40844 .52212 .41658 .53007 .43035 .5258 .42226 .51782 Mtetra
.661 .742 .91 r
.42226 .51782 .43035 .5258 .44419 .52153 .43614 .51354 Mtetra
.66 .742 .911 r
.43614 .51354 .44419 .52153 .45811 .51728 .4501 .50928 Mtetra
.658 .742 .912 r
.4501 .50928 .45811 .51728 .47209 .51306 .46413 .50507 Mtetra
.655 .743 .914 r
.46413 .50507 .47209 .51306 .48614 .50889 .47823 .50094 Mtetra
.651 .744 .917 r
.47823 .50094 .48614 .50889 .50027 .50481 .49241 .49692 Mtetra
.645 .745 .921 r
.49241 .49692 .50027 .50481 .51448 .50085 .50666 .49307 Mtetra
.638 .746 .927 r
.50666 .49307 .51448 .50085 .52876 .49706 .52099 .48943 Mtetra
.627 .748 .934 r
.52099 .48943 .52876 .49706 .54313 .49349 .53541 .48608 Mtetra
.613 .75 .943 r
.53541 .48608 .54313 .49349 .55758 .4902 .54991 .48308 Mtetra
.594 .753 .954 r
.54991 .48308 .55758 .4902 .57212 .48726 .56451 .48051 Mtetra
.569 .756 .966 r
.56451 .48051 .57212 .48726 .58677 .48473 .57922 .47843 Mtetra
.535 .757 .978 r
.57922 .47843 .58677 .48473 .60152 .48265 .59403 .47688 Mtetra
.491 .757 .989 r
.59403 .47688 .60152 .48265 .61638 .48107 .60897 .47591 Mtetra
.434 .751 .994 r
.60897 .47591 .61638 .48107 .63136 .47999 .62404 .4755 Mtetra
.365 .739 .989 r
.62404 .4755 .63136 .47999 .64648 .47938 .63925 .47561 Mtetra
.286 .717 .968 r
.63925 .47561 .64648 .47938 .66173 .47919 .6546 .47615 Mtetra
.207 .688 .932 r
.6546 .47615 .66173 .47919 .67712 .4793 .6701 .47698 Mtetra
.138 .658 .885 r
.6701 .47698 .67712 .4793 .69265 .47957 .68573 .47789 Mtetra
.091 .636 .841 r
.68573 .47789 .69265 .47957 .7083 .47979 .7015 .47866 Mtetra
.076 .631 .809 r
.7015 .47866 .7083 .47979 .72407 .47975 .71738 .47901 Mtetra
.095 .65 .799 r
.71738 .47901 .72407 .47975 .73994 .4792 .73336 .47869 Mtetra
.151 .692 .812 r
.73336 .47869 .73994 .4792 .75589 .47792 .7494 .47744 Mtetra
.241 .755 .846 r
.7494 .47744 .75589 .47792 .77189 .47571 .76549 .47504 Mtetra
.355 .825 .891 r
.76549 .47504 .77189 .47571 .78792 .47239 .78159 .47133 Mtetra
.476 .888 .931 r
.78159 .47133 .78792 .47239 .80395 .46788 .79768 .46624 Mtetra
.587 .928 .956 r
.79768 .46624 .80395 .46788 .81996 .46214 .81374 .45978 Mtetra
.672 .944 .962 r
.81374 .45978 .81996 .46214 .83595 .45522 .82976 .45203 Mtetra
.73 .939 .954 r
.82976 .45203 .83595 .45522 .8519 .44725 .84573 .44317 Mtetra
.765 .922 .94 r
.84573 .44317 .8519 .44725 .86783 .43841 .86167 .43341 Mtetra
.783 .9 .925 r
.86167 .43341 .86783 .43841 .88374 .4289 .87758 .42303 Mtetra
.79 .878 .911 r
.87758 .42303 .88374 .4289 .89964 .41897 .89349 .41228 Mtetra
.789 .856 .901 r
.89349 .41228 .89964 .41897 .91557 .40884 .90943 .40142 Mtetra
.783 .837 .893 r
.90943 .40142 .91557 .40884 .93154 .39874 .92542 .39069 Mtetra
.663 .741 .908 r
.33199 .53562 .34042 .54347 .35388 .53923 .3455 .53135 Mtetra
.3455 .53135 .35388 .53923 .36742 .53497 .35907 .52705 Mtetra
.35907 .52705 .36742 .53497 .38103 .5307 .37272 .52274 Mtetra
.37272 .52274 .38103 .5307 .3947 .52641 .38644 .51842 Mtetra
.662 .741 .909 r
.38644 .51842 .3947 .52641 .40844 .52212 .40023 .5141 Mtetra
.661 .742 .909 r
.40023 .5141 .40844 .52212 .42226 .51782 .41409 .50979 Mtetra
.66 .742 .91 r
.41409 .50979 .42226 .51782 .43614 .51354 .42802 .50549 Mtetra
.658 .742 .912 r
.42802 .50549 .43614 .51354 .4501 .50928 .44202 .50124 Mtetra
.656 .743 .914 r
.44202 .50124 .4501 .50928 .46413 .50507 .45609 .49706 Mtetra
.652 .743 .916 r
.45609 .49706 .46413 .50507 .47823 .50094 .47024 .49298 Mtetra
.647 .744 .92 r
.47024 .49298 .47823 .50094 .49241 .49692 .48446 .48906 Mtetra
.64 .745 .925 r
.48446 .48906 .49241 .49692 .50666 .49307 .49876 .48535 Mtetra
.629 .747 .932 r
.49876 .48535 .50666 .49307 .52099 .48943 .51314 .48191 Mtetra
.616 .749 .941 r
.51314 .48191 .52099 .48943 .53541 .48608 .52761 .47884 Mtetra
.597 .751 .951 r
.52761 .47884 .53541 .48608 .54991 .48308 .54217 .4762 Mtetra
.571 .754 .964 r
.54217 .4762 .54991 .48308 .56451 .48051 .55682 .47407 Mtetra
.537 .755 .977 r
.55682 .47407 .56451 .48051 .57922 .47843 .57159 .47252 Mtetra
.49 .753 .988 r
.57159 .47252 .57922 .47843 .59403 .47688 .58648 .4716 Mtetra
.428 .746 .993 r
.58648 .4716 .59403 .47688 .60897 .47591 .60149 .47133 Mtetra
.349 .729 .986 r
.60149 .47133 .60897 .47591 .62404 .4755 .61665 .47168 Mtetra
.256 .699 .96 r
.61665 .47168 .62404 .4755 .63925 .47561 .63195 .47259 Mtetra
.157 .656 .911 r
.63195 .47259 .63925 .47561 .6546 .47615 .6474 .47393 Mtetra
.067 .609 .848 r
.6474 .47393 .6546 .47615 .6701 .47698 .66301 .4755 Mtetra
0 .568 .782 r
.66301 .4755 .6701 .47698 .68573 .47789 .67876 .47708 Mtetra
0 .546 .731 r
.67876 .47708 .68573 .47789 .7015 .47866 .69464 .47837 Mtetra
.032 0 0 r
.69464 .47837 .7015 .47866 .71738 .47901 .71063 .47907 Mtetra
.01 .585 .709 r
.71063 .47907 .71738 .47901 .73336 .47869 .72672 .47889 Mtetra
.091 .649 .743 r
.72672 .47889 .73336 .47869 .7494 .47744 .74286 .47755 Mtetra
.209 .735 .8 r
.74286 .47755 .7494 .47744 .76549 .47504 .75903 .47483 Mtetra
.352 .827 .865 r
.75903 .47483 .76549 .47504 .78159 .47133 .7752 .47059 Mtetra
.496 .901 .918 r
.7752 .47059 .78159 .47133 .79768 .46624 .79134 .46478 Mtetra
.617 .943 .947 r
.79134 .46478 .79768 .46624 .81374 .45978 .80743 .45746 Mtetra
.704 .954 .952 r
.80743 .45746 .81374 .45978 .82976 .45203 .82347 .44875 Mtetra
.758 .943 .942 r
.82347 .44875 .82976 .45203 .84573 .44317 .83946 .4389 Mtetra
.788 .921 .927 r
.83946 .4389 .84573 .44317 .86167 .43341 .8554 .42816 Mtetra
.801 .897 .911 r
.8554 .42816 .86167 .43341 .87758 .42303 .87132 .41684 Mtetra
.803 .873 .899 r
.87132 .41684 .87758 .42303 .89349 .41228 .88724 .40524 Mtetra
.799 .851 .889 r
.88724 .40524 .89349 .41228 .90943 .40142 .90319 .39365 Mtetra
.791 .832 .884 r
.90319 .39365 .90943 .40142 .92542 .39069 .9192 .3823 Mtetra
.663 .741 .908 r
.32348 .5277 .33199 .53562 .3455 .53135 .33703 .52339 Mtetra
.33703 .52339 .3455 .53135 .35907 .52705 .35065 .51906 Mtetra
.35065 .51906 .35907 .52705 .37272 .52274 .36434 .51472 Mtetra
.662 .741 .909 r
.36434 .51472 .37272 .52274 .38644 .51842 .3781 .51037 Mtetra
.662 .742 .909 r
.3781 .51037 .38644 .51842 .40023 .5141 .39193 .50602 Mtetra
.661 .742 .91 r
.39193 .50602 .40023 .5141 .41409 .50979 .40583 .50169 Mtetra
.659 .742 .911 r
.40583 .50169 .41409 .50979 .42802 .50549 .41981 .49739 Mtetra
.657 .742 .913 r
.41981 .49739 .42802 .50549 .44202 .50124 .43385 .49316 Mtetra
.653 .743 .915 r
.43385 .49316 .44202 .50124 .45609 .49706 .44797 .48902 Mtetra
.648 .744 .919 r
.44797 .48902 .45609 .49706 .47024 .49298 .46216 .48503 Mtetra
.642 .745 .924 r
.46216 .48503 .47024 .49298 .48446 .48906 .47643 .48123 Mtetra
.632 .746 .93 r
.47643 .48123 .48446 .48906 .49876 .48535 .49078 .47771 Mtetra
.619 .748 .938 r
.49078 .47771 .49876 .48535 .51314 .48191 .50521 .47454 Mtetra
.601 .75 .949 r
.50521 .47454 .51314 .48191 .52761 .47884 .51972 .4718 Mtetra
.575 .752 .961 r
.51972 .4718 .52761 .47884 .54217 .4762 .53434 .46959 Mtetra
.54 .753 .974 r
.53434 .46959 .54217 .4762 .55682 .47407 .54905 .46799 Mtetra
.493 .75 .986 r
.54905 .46799 .55682 .47407 .57159 .47252 .56388 .46707 Mtetra
.427 .741 .992 r
.56388 .46707 .57159 .47252 .58648 .4716 .57884 .46687 Mtetra
.341 .721 .985 r
.57884 .46687 .58648 .4716 .60149 .47133 .59394 .4674 Mtetra
.235 .684 .954 r
.59394 .4674 .60149 .47133 .61665 .47168 .60918 .4686 Mtetra
.118 .629 .895 r
.60918 .4686 .61665 .47168 .63195 .47259 .62458 .47039 Mtetra
.007 .564 .814 r
.62458 .47039 .63195 .47259 .6474 .47393 .64014 .47257 Mtetra
0 .504 .728 r
.64014 .47257 .6474 .47393 .66301 .4755 .65585 .47491 Mtetra
.133 0 0 r
.65585 .47491 .66301 .4755 .67876 .47708 .67171 .47714 Mtetra
.148 0 0 r
.67171 .47714 .67876 .47708 .69464 .47837 .68771 .47891 Mtetra
.123 0 0 r
.68771 .47891 .69464 .47837 .71063 .47907 .70382 .47988 Mtetra
.057 0 0 r
.70382 .47988 .71063 .47907 .72672 .47889 .72001 .47973 Mtetra
0 0 0 r
.72001 .47973 .72672 .47889 .74286 .47755 .73624 .47816 Mtetra
.199 .727 .765 r
.73624 .47816 .74286 .47755 .75903 .47483 .75249 .47497 Mtetra
.37 .838 .85 r
.75249 .47497 .75903 .47483 .7752 .47059 .76872 .47004 Mtetra
.532 .919 .912 r
.76872 .47004 .7752 .47059 .79134 .46478 .7849 .46336 Mtetra
.658 .957 .94 r
.7849 .46336 .79134 .46478 .80743 .45746 .80103 .45503 Mtetra
.74 .96 .941 r
.80103 .45503 .80743 .45746 .82347 .44875 .81709 .44526 Mtetra
.786 .942 .928 r
.81709 .44526 .82347 .44875 .83946 .4389 .83308 .43432 Mtetra
.809 .916 .911 r
.83308 .43432 .83946 .4389 .8554 .42816 .84903 .42254 Mtetra
.816 .89 .896 r
.84903 .42254 .8554 .42816 .87132 .41684 .86495 .41025 Mtetra
.815 .866 .885 r
.86495 .41025 .87132 .41684 .88724 .40524 .88088 .3978 Mtetra
.808 .844 .878 r
.88088 .3978 .88724 .40524 .90319 .39365 .89684 .38548 Mtetra
.797 .826 .874 r
.89684 .38548 .90319 .39365 .9192 .3823 .91287 .37353 Mtetra
.663 .741 .908 r
.31489 .51971 .32348 .5277 .33703 .52339 .32848 .51536 Mtetra
.32848 .51536 .33703 .52339 .35065 .51906 .34214 .51099 Mtetra
.663 .741 .909 r
.34214 .51099 .35065 .51906 .36434 .51472 .35588 .50662 Mtetra
.662 .741 .909 r
.35588 .50662 .36434 .51472 .3781 .51037 .36968 .50224 Mtetra
.661 .742 .91 r
.36968 .50224 .3781 .51037 .39193 .50602 .38356 .49787 Mtetra
.66 .742 .911 r
.38356 .49787 .39193 .50602 .40583 .50169 .3975 .49354 Mtetra
.658 .742 .912 r
.3975 .49354 .40583 .50169 .41981 .49739 .41152 .48925 Mtetra
.655 .743 .914 r
.41152 .48925 .41981 .49739 .43385 .49316 .42561 .48505 Mtetra
.65 .743 .918 r
.42561 .48505 .43385 .49316 .44797 .48902 .43977 .48099 Mtetra
.644 .744 .922 r
.43977 .48099 .44797 .48902 .46216 .48503 .45401 .4771 Mtetra
.635 .745 .928 r
.45401 .4771 .46216 .48503 .47643 .48123 .46832 .47348 Mtetra
.622 .747 .936 r
.46832 .47348 .47643 .48123 .49078 .47771 .48271 .47019 Mtetra
.605 .749 .946 r
.48271 .47019 .49078 .47771 .50521 .47454 .49719 .46733 Mtetra
.581 .75 .958 r
.49719 .46733 .50521 .47454 .51972 .4718 .51175 .46501 Mtetra
.546 .751 .971 r
.51175 .46501 .51972 .4718 .53434 .46959 .52642 .46331 Mtetra
.499 .748 .984 r
.52642 .46331 .53434 .46959 .54905 .46799 .54119 .46234 Mtetra
.432 .738 .991 r
.54119 .46234 .54905 .46799 .56388 .46707 .55609 .46214 Mtetra
.341 .716 .985 r
.55609 .46214 .56388 .46707 .57884 .46687 .57112 .46276 Mtetra
.226 .674 .952 r
.57112 .46276 .57884 .46687 .59394 .4674 .5863 .46418 Mtetra
.093 .609 .886 r
.5863 .46418 .59394 .4674 .60918 .4686 .60163 .46632 Mtetra
0 .528 .789 r
.60163 .46632 .60918 .4686 .62458 .47039 .61713 .46903 Mtetra
.144 0 0 r
.61713 .46903 .62458 .47039 .64014 .47257 .63279 .47209 Mtetra
.214 0 0 r
.63279 .47209 .64014 .47257 .65585 .47491 .64862 .47522 Mtetra
.245 0 0 r
.64862 .47522 .65585 .47491 .67171 .47714 .6646 .47806 Mtetra
.237 0 0 r
.6646 .47806 .67171 .47714 .68771 .47891 .68071 .48023 Mtetra
.191 0 0 r
.68071 .48023 .68771 .47891 .70382 .47988 .69693 .48137 Mtetra
.101 0 0 r
.69693 .48137 .70382 .47988 .72001 .47973 .71322 .48111 Mtetra
0 0 0 r
.71322 .48111 .72001 .47973 .73624 .47816 .72954 .47916 Mtetra
.213 .736 .748 r
.72954 .47916 .73624 .47816 .75249 .47497 .74586 .47533 Mtetra
.41 .861 .848 r
.74586 .47533 .75249 .47497 .76872 .47004 .76214 .46953 Mtetra
.583 .941 .912 r
.76214 .46953 .76872 .47004 .7849 .46336 .77836 .46183 Mtetra
.704 .968 .934 r
.77836 .46183 .7849 .46336 .80103 .45503 .79451 .45237 Mtetra
.776 .96 .928 r
.79451 .45237 .80103 .45503 .81709 .44526 .81058 .44142 Mtetra
.812 .936 .912 r
.81058 .44142 .81709 .44526 .83308 .43432 .82658 .42932 Mtetra
.826 .907 .895 r
.82658 .42932 .83308 .43432 .84903 .42254 .84253 .41645 Mtetra
.829 .88 .881 r
.84253 .41645 .84903 .42254 .86495 .41025 .85846 .40319 Mtetra
.824 .856 .872 r
.85846 .40319 .86495 .41025 .88088 .3978 .87439 .38989 Mtetra
.814 .836 .866 r
.87439 .38989 .88088 .3978 .89684 .38548 .89037 .37687 Mtetra
.802 .819 .864 r
.89037 .37687 .89684 .38548 .91287 .37353 .90643 .36437 Mtetra
.663 .741 .908 r
.30622 .51164 .31489 .51971 .32848 .51536 .31985 .50725 Mtetra
.31985 .50725 .32848 .51536 .34214 .51099 .33356 .50285 Mtetra
.662 .741 .909 r
.33356 .50285 .34214 .51099 .35588 .50662 .34733 .49845 Mtetra
.662 .742 .909 r
.34733 .49845 .35588 .50662 .36968 .50224 .36118 .49405 Mtetra
.66 .742 .91 r
.36118 .49405 .36968 .50224 .38356 .49787 .3751 .48967 Mtetra
.658 .742 .912 r
.3751 .48967 .38356 .49787 .3975 .49354 .38909 .48534 Mtetra
.656 .742 .914 r
.38909 .48534 .3975 .49354 .41152 .48925 .40315 .48108 Mtetra
.652 .743 .916 r
.40315 .48108 .41152 .48925 .42561 .48505 .41728 .47693 Mtetra
.646 .744 .92 r
.41728 .47693 .42561 .48505 .43977 .48099 .43149 .47296 Mtetra
.638 .745 .926 r
.43149 .47296 .43977 .48099 .45401 .4771 .44576 .46923 Mtetra
.626 .746 .933 r
.44576 .46923 .45401 .4771 .46832 .47348 .46012 .46582 Mtetra
.61 .748 .943 r
.46012 .46582 .46832 .47348 .48271 .47019 .47456 .46282 Mtetra
.587 .749 .954 r
.47456 .46282 .48271 .47019 .49719 .46733 .48908 .46035 Mtetra
.554 .749 .968 r
.48908 .46035 .49719 .46733 .51175 .46501 .50369 .45852 Mtetra
.508 .747 .981 r
.50369 .45852 .51175 .46501 .52642 .46331 .51841 .45743 Mtetra
.442 .737 .99 r
.51841 .45743 .52642 .46331 .54119 .46234 .53325 .45717 Mtetra
.349 .714 .986 r
.53325 .45717 .54119 .46234 .55609 .46214 .54821 .4578 Mtetra
.227 .67 .954 r
.54821 .4578 .55609 .46214 .57112 .46276 .56331 .45934 Mtetra
.081 .597 .883 r
.56331 .45934 .57112 .46276 .5863 .46418 .57857 .46174 Mtetra
0 .503 .775 r
.57857 .46174 .5863 .46418 .60163 .46632 .59399 .46488 Mtetra
.192 0 0 r
.59399 .46488 .60163 .46632 .61713 .46903 .60959 .46857 Mtetra
.277 0 0 r
.60959 .46857 .61713 .46903 .63279 .47209 .62536 .47252 Mtetra
.322 0 0 r
.62536 .47252 .63279 .47209 .64862 .47522 .6413 .47639 Mtetra
.329 0 0 r
.6413 .47639 .64862 .47522 .6646 .47806 .6574 .47978 Mtetra
.301 0 0 r
.6574 .47978 .6646 .47806 .68071 .48023 .67362 .48227 Mtetra
.234 0 0 r
.67362 .48227 .68071 .48023 .69693 .48137 .68995 .48342 Mtetra
.121 0 0 r
.68995 .48342 .69693 .48137 .71322 .48111 .70633 .48289 Mtetra
0 0 0 r
.70633 .48289 .71322 .48111 .72954 .47916 .72273 .48037 Mtetra
.256 .763 .751 r
.72273 .48037 .72954 .47916 .74586 .47533 .73912 .47572 Mtetra
.473 .895 .859 r
.73912 .47572 .74586 .47533 .76214 .46953 .75545 .4689 Mtetra
.645 .963 .915 r
.75545 .4689 .76214 .46953 .77836 .46183 .7717 .46001 Mtetra
.752 .973 .925 r
.7717 .46001 .77836 .46183 .79451 .45237 .78787 .44929 Mtetra
.808 .954 .912 r
.78787 .44929 .79451 .45237 .81058 .44142 .80395 .43708 Mtetra
.833 .924 .894 r
.80395 .43708 .81058 .44142 .82658 .42932 .81995 .42377 Mtetra
.841 .894 .877 r
.81995 .42377 .82658 .42932 .84253 .41645 .83591 .40979 Mtetra
.838 .868 .865 r
.83591 .40979 .84253 .41645 .85846 .40319 .85184 .39556 Mtetra
.83 .845 .858 r
.85184 .39556 .85846 .40319 .87439 .38989 .86779 .38146 Mtetra
.819 .826 .855 r
.86779 .38146 .87439 .38989 .89037 .37687 .88379 .36778 Mtetra
.805 .811 .856 r
.88379 .36778 .89037 .37687 .90643 .36437 .89989 .35478 Mtetra
.663 .741 .908 r
.29746 .5035 .30622 .51164 .31985 .50725 .31114 .49907 Mtetra
.663 .741 .909 r
.31114 .49907 .31985 .50725 .33356 .50285 .32489 .49464 Mtetra
.662 .741 .909 r
.32489 .49464 .33356 .50285 .34733 .49845 .33871 .49021 Mtetra
.661 .742 .91 r
.33871 .49021 .34733 .49845 .36118 .49405 .3526 .48579 Mtetra
.659 .742 .911 r
.3526 .48579 .36118 .49405 .3751 .48967 .36656 .48141 Mtetra
.657 .742 .913 r
.36656 .48141 .3751 .48967 .38909 .48534 .38059 .47709 Mtetra
.653 .743 .915 r
.38059 .47709 .38909 .48534 .40315 .48108 .39469 .47287 Mtetra
.648 .743 .919 r
.39469 .47287 .40315 .48108 .41728 .47693 .40887 .46881 Mtetra
.641 .744 .924 r
.40887 .46881 .41728 .47693 .43149 .47296 .42311 .46497 Mtetra
.63 .745 .931 r
.42311 .46497 .43149 .47296 .44576 .46923 .43743 .46142 Mtetra
.615 .747 .939 r
.43743 .46142 .44576 .46923 .46012 .46582 .45183 .45828 Mtetra
.594 .748 .951 r
.45183 .45828 .46012 .46582 .47456 .46282 .46631 .45564 Mtetra
.563 .748 .964 r
.46631 .45564 .47456 .46282 .48908 .46035 .48088 .45364 Mtetra
.519 .746 .978 r
.48088 .45364 .48908 .46035 .50369 .45852 .49554 .45239 Mtetra
.455 .737 .988 r
.49554 .45239 .50369 .45852 .51841 .45743 .51031 .452 Mtetra
.364 .715 .987 r
.51031 .452 .51841 .45743 .53325 .45717 .5252 .45256 Mtetra
.24 .67 .959 r
.5252 .45256 .53325 .45717 .54821 .4578 .54022 .45411 Mtetra
.085 .594 .889 r
.54022 .45411 .54821 .4578 .56331 .45934 .5554 .45666 Mtetra
0 .489 .774 r
.5554 .45666 .56331 .45934 .57857 .46174 .57074 .46011 Mtetra
.222 0 0 r
.57074 .46011 .57857 .46174 .59399 .46488 .58625 .4643 Mtetra
.323 0 0 r
.58625 .4643 .59399 .46488 .60959 .46857 .60195 .46899 Mtetra
.381 0 0 r
.60195 .46899 .60959 .46857 .62536 .47252 .61783 .47382 Mtetra
.401 0 0 r
.61783 .47382 .62536 .47252 .6413 .47639 .63389 .47839 Mtetra
.388 0 0 r
.63389 .47839 .6413 .47639 .6574 .47978 .6501 .48223 Mtetra
.342 0 0 r
.6501 .48223 .6574 .47978 .67362 .48227 .66644 .48488 Mtetra
.254 0 0 r
.66644 .48488 .67362 .48227 .68995 .48342 .68286 .4859 Mtetra
.115 0 0 r
.68286 .4859 .68995 .48342 .70633 .48289 .69934 .4849 Mtetra
0 0 0 r
.69934 .4849 .70633 .48289 .72273 .48037 .71581 .48163 Mtetra
.327 .809 .775 r
.71581 .48163 .72273 .48037 .73912 .47572 .73226 .47596 Mtetra
.553 .932 .878 r
.73226 .47596 .73912 .47572 .75545 .4689 .74863 .46793 Mtetra
.709 .977 .916 r
.74863 .46793 .75545 .4689 .7717 .46001 .76491 .45772 Mtetra
.795 .969 .912 r
.76491 .45772 .7717 .46001 .78787 .44929 .78109 .44564 Mtetra
.835 .941 .894 r
.78109 .44564 .78787 .44929 .80395 .43708 .79718 .4321 Mtetra
.85 .909 .875 r
.79718 .4321 .80395 .43708 .81995 .42377 .81318 .41755 Mtetra
.851 .879 .86 r
.81318 .41755 .81995 .42377 .83591 .40979 .82914 .40248 Mtetra
.845 .854 .85 r
.82914 .40248 .83591 .40979 .85184 .39556 .84509 .38732 Mtetra
.834 .833 .845 r
.84509 .38732 .85184 .39556 .86779 .38146 .86106 .37245 Mtetra
.821 .816 .845 r
.86106 .37245 .86779 .38146 .88379 .36778 .87709 .35819 Mtetra
.807 .802 .847 r
.87709 .35819 .88379 .36778 .89989 .35478 .89323 .34475 Mtetra
.663 .741 .908 r
.28862 .49528 .29746 .5035 .31114 .49907 .30234 .49082 Mtetra
.662 .741 .909 r
.30234 .49082 .31114 .49907 .32489 .49464 .31613 .48636 Mtetra
.661 .742 .909 r
.31613 .48636 .32489 .49464 .33871 .49021 .33 .48191 Mtetra
.66 .742 .91 r
.33 .48191 .33871 .49021 .3526 .48579 .34393 .47748 Mtetra
.658 .742 .912 r
.34393 .47748 .3526 .48579 .36656 .48141 .35793 .4731 Mtetra
.655 .742 .914 r
.35793 .4731 .36656 .48141 .38059 .47709 .37201 .46881 Mtetra
.65 .743 .917 r
.37201 .46881 .38059 .47709 .39469 .47287 .38615 .46466 Mtetra
.644 .744 .922 r
.38615 .46466 .39469 .47287 .40887 .46881 .40037 .4607 Mtetra
.634 .745 .928 r
.40037 .4607 .40887 .46881 .42311 .46497 .41465 .45702 Mtetra
.62 .746 .936 r
.41465 .45702 .42311 .46497 .43743 .46142 .42901 .45372 Mtetra
.601 .747 .947 r
.42901 .45372 .43743 .46142 .45183 .45828 .44345 .4509 Mtetra
.573 .747 .959 r
.44345 .4509 .45183 .45828 .46631 .45564 .45797 .44869 Mtetra
.532 .745 .973 r
.45797 .44869 .46631 .45564 .48088 .45364 .47258 .44724 Mtetra
.472 .737 .985 r
.47258 .44724 .48088 .45364 .49554 .45239 .48729 .44665 Mtetra
.385 .718 .988 r
.48729 .44665 .49554 .45239 .51031 .452 .5021 .44706 Mtetra
.262 .676 .967 r
.5021 .44706 .51031 .452 .5252 .45256 .51705 .44854 Mtetra
.102 .599 .901 r
.51705 .44854 .5252 .45256 .54022 .45411 .53213 .45111 Mtetra
0 .488 .784 r
.53213 .45111 .54022 .45411 .5554 .45666 .54738 .45474 Mtetra
.236 0 0 r
.54738 .45474 .5554 .45666 .57074 .46011 .5628 .45931 Mtetra
.353 0 0 r
.5628 .45931 .57074 .46011 .58625 .4643 .57841 .46459 Mtetra
.424 0 0 r
.57841 .46459 .58625 .4643 .60195 .46899 .59421 .47027 Mtetra
.456 0 0 r
.59421 .47027 .60195 .46899 .61783 .47382 .6102 .47593 Mtetra
.6102 .47593 .61783 .47382 .63389 .47839 .62637 .48111 Mtetra
.426 0 0 r
.62637 .48111 .63389 .47839 .6501 .48223 .64269 .48528 Mtetra
.362 0 0 r
.64269 .48528 .6501 .48223 .66644 .48488 .65914 .48793 Mtetra
.253 0 0 r
.65914 .48793 .66644 .48488 .68286 .4859 .67566 .48861 Mtetra
.082 0 0 r
.67566 .48861 .68286 .4859 .69934 .4849 .69222 .48694 Mtetra
0 0 0 r
.69222 .48694 .69934 .4849 .71581 .48163 .70877 .4827 Mtetra
.424 .868 .815 r
.70877 .4827 .71581 .48163 .73226 .47596 .72526 .47583 Mtetra
.64 .964 .897 r
.72526 .47583 .73226 .47596 .74863 .46793 .74167 .46644 Mtetra
.769 .98 .912 r
.74167 .46644 .74863 .46793 .76491 .45772 .75797 .45479 Mtetra
.83 .956 .896 r
.75797 .45479 .76491 .45772 .78109 .44564 .77416 .44126 Mtetra
.855 .922 .874 r
.77416 .44126 .78109 .44564 .79718 .4321 .79025 .42636 Mtetra
.861 .89 .856 r
.79025 .42636 .79718 .4321 .81318 .41755 .80627 .41058 Mtetra
.857 .862 .843 r
.80627 .41058 .81318 .41755 .82914 .40248 .82224 .39444 Mtetra
.849 .839 .836 r
.82224 .39444 .82914 .40248 .84509 .38732 .8382 .3784 Mtetra
.836 .821 .834 r
.8382 .3784 .84509 .38732 .86106 .37245 .8542 .36285 Mtetra
.822 .806 .835 r
.8542 .36285 .86106 .37245 .87709 .35819 .87028 .34807 Mtetra
.807 .794 .84 r
.87028 .34807 .87709 .35819 .89323 .34475 .88646 .33427 Mtetra
.662 .741 .909 r
.2797 .48699 .28862 .49528 .30234 .49082 .29346 .4825 Mtetra
.29346 .4825 .30234 .49082 .31613 .48636 .30729 .47801 Mtetra
.661 .742 .91 r
.30729 .47801 .31613 .48636 .33 .48191 .3212 .47354 Mtetra
.659 .742 .911 r
.3212 .47354 .33 .48191 .34393 .47748 .33517 .46911 Mtetra
.656 .742 .913 r
.33517 .46911 .34393 .47748 .35793 .4731 .34922 .46475 Mtetra
.652 .742 .916 r
.34922 .46475 .35793 .4731 .37201 .46881 .36333 .46051 Mtetra
.646 .743 .92 r
.36333 .46051 .37201 .46881 .38615 .46466 .37752 .45644 Mtetra
.638 .744 .925 r
.37752 .45644 .38615 .46466 .40037 .4607 .39177 .45262 Mtetra
.626 .745 .933 r
.39177 .45262 .40037 .4607 .41465 .45702 .4061 .44915 Mtetra
.608 .746 .942 r
.4061 .44915 .41465 .45702 .42901 .45372 .4205 .44614 Mtetra
.582 .746 .955 r
.4205 .44614 .42901 .45372 .44345 .4509 .43497 .44371 Mtetra
.545 .745 .969 r
.43497 .44371 .44345 .4509 .45797 .44869 .44953 .44201 Mtetra
.49 .738 .982 r
.44953 .44201 .45797 .44869 .47258 .44724 .46418 .44119 Mtetra
.409 .722 .988 r
.46418 .44119 .47258 .44724 .48729 .44665 .47892 .44137 Mtetra
.292 .684 .974 r
.47892 .44137 .48729 .44665 .5021 .44706 .49379 .44267 Mtetra
.132 .611 .918 r
.49379 .44267 .5021 .44706 .51705 .44854 .50879 .44516 Mtetra
0 .498 .805 r
.50879 .44516 .51705 .44854 .53213 .45111 .52393 .44883 Mtetra
.232 0 0 r
.52393 .44883 .53213 .45111 .54738 .45474 .53925 .45362 Mtetra
.367 0 0 r
.53925 .45362 .54738 .45474 .5628 .45931 .55475 .45934 Mtetra
.452 0 0 r
.55475 .45934 .5628 .45931 .57841 .46459 .57045 .46571 Mtetra
.496 0 0 r
.57045 .46571 .57841 .46459 .59421 .47027 .58636 .47234 Mtetra
.507 0 0 r
.58636 .47234 .59421 .47027 .6102 .47593 .60245 .47876 Mtetra
.491 0 0 r
.60245 .47876 .6102 .47593 .62637 .48111 .61873 .48442 Mtetra
.446 0 0 r
.61873 .48442 .62637 .48111 .64269 .48528 .63516 .48875 Mtetra
.364 0 0 r
.63516 .48875 .64269 .48528 .65914 .48793 .65171 .4912 Mtetra
.228 0 0 r
.65171 .4912 .65914 .48793 .67566 .48861 .66833 .49132 Mtetra
.017 0 0 r
.66833 .49132 .67566 .48861 .69222 .48694 .68496 .48877 Mtetra
.263 .764 .723 r
.68496 .48877 .69222 .48694 .70877 .4827 .70157 .48336 Mtetra
.538 .926 .859 r
.70157 .48336 .70877 .4827 .72526 .47583 .71811 .47511 Mtetra
.723 .982 .907 r
.71811 .47511 .72526 .47583 .74167 .46644 .73455 .46421 Mtetra
.817 .97 .899 r
.73455 .46421 .74167 .46644 .75797 .45479 .75087 .45101 Mtetra
.856 .936 .876 r
.75087 .45101 .75797 .45479 .77416 .44126 .76707 .436 Mtetra
.868 .9 .853 r
.76707 .436 .77416 .44126 .79025 .42636 .78317 .41972 Mtetra
.868 .869 .837 r
.78317 .41972 .79025 .42636 .80627 .41058 .7992 .40274 Mtetra
.861 .844 .827 r
.7992 .40274 .80627 .41058 .82224 .39444 .81518 .3856 Mtetra
.85 .824 .823 r
.81518 .3856 .82224 .39444 .8382 .3784 .83118 .36877 Mtetra
.837 .808 .823 r
.83118 .36877 .8382 .3784 .8542 .36285 .84721 .35262 Mtetra
.822 .796 .827 r
.84721 .35262 .8542 .36285 .87028 .34807 .86334 .33743 Mtetra
.806 .785 .834 r
.86334 .33743 .87028 .34807 .88646 .33427 .87959 .32336 Mtetra
.662 .741 .909 r
.27069 .47862 .2797 .48699 .29346 .4825 .28449 .4741 Mtetra
.661 .742 .91 r
.28449 .4741 .29346 .4825 .30729 .47801 .29837 .46959 Mtetra
.66 .742 .911 r
.29837 .46959 .30729 .47801 .3212 .47354 .31231 .46511 Mtetra
.657 .742 .912 r
.31231 .46511 .3212 .47354 .33517 .46911 .32633 .46068 Mtetra
.654 .742 .915 r
.32633 .46068 .33517 .46911 .34922 .46475 .34042 .45636 Mtetra
.649 .743 .918 r
.34042 .45636 .34922 .46475 .36333 .46051 .35457 .45219 Mtetra
.641 .743 .923 r
.35457 .45219 .36333 .46051 .37752 .45644 .36879 .44823 Mtetra
.631 .744 .93 r
.36879 .44823 .37752 .45644 .39177 .45262 .38309 .4446 Mtetra
.615 .745 .938 r
.38309 .4446 .39177 .45262 .4061 .44915 .39745 .44138 Mtetra
.592 .745 .95 r
.39745 .44138 .4061 .44915 .4205 .44614 .41188 .43871 Mtetra
.559 .744 .963 r
.41188 .43871 .4205 .44614 .43497 .44371 .42639 .43675 Mtetra
.51 .739 .977 r
.42639 .43675 .43497 .44371 .44953 .44201 .44098 .43563 Mtetra
.436 .726 .987 r
.44098 .43563 .44953 .44201 .46418 .44119 .45566 .43553 Mtetra
.327 .694 .981 r
.45566 .43553 .46418 .44119 .47892 .44137 .47045 .43657 Mtetra
.173 .628 .937 r
.47045 .43657 .47892 .44137 .49379 .44267 .48536 .43886 Mtetra
0 .519 .835 r
.48536 .43886 .49379 .44267 .50879 .44516 .50041 .44244 Mtetra
0 .377 .678 r
.50041 .44244 .50879 .44516 .52393 .44883 .51561 .44729 Mtetra
.366 0 0 r
.51561 .44729 .52393 .44883 .53925 .45362 .531 .45328 Mtetra
.467 0 0 r
.531 .45328 .53925 .45362 .55475 .45934 .54658 .46016 Mtetra
.523 0 0 r
.54658 .46016 .55475 .45934 .57045 .46571 .56237 .4676 Mtetra
.545 0 0 r
.56237 .4676 .57045 .46571 .58636 .47234 .57837 .47512 Mtetra
.541 0 0 r
.57837 .47512 .58636 .47234 .60245 .47876 .59458 .48217 Mtetra
.511 0 0 r
.59458 .48217 .60245 .47876 .61873 .48442 .61096 .48814 Mtetra
.451 0 0 r
.61096 .48814 .61873 .48442 .63516 .48875 .6275 .49243 Mtetra
.347 0 0 r
.6275 .49243 .63516 .48875 .65171 .4912 .64415 .49447 Mtetra
.175 0 0 r
.64415 .49447 .65171 .4912 .66833 .49132 .66085 .4938 Mtetra
0 0 0 r
.66085 .4938 .66833 .49132 .68496 .48877 .67756 .49013 Mtetra
.398 .852 .797 r
.67756 .49013 .68496 .48877 .70157 .48336 .69422 .48335 Mtetra
.651 .968 .894 r
.69422 .48335 .70157 .48336 .71811 .47511 .7108 .47355 Mtetra
.79 .98 .904 r
.7108 .47355 .71811 .47511 .73455 .46421 .72726 .46103 Mtetra
.85 .949 .881 r
.72726 .46103 .73455 .46421 .75087 .45101 .7436 .44623 Mtetra
.871 .91 .854 r
.7436 .44623 .75087 .45101 .76707 .436 .75982 .42971 Mtetra
.875 .876 .833 r
.75982 .42971 .76707 .436 .78317 .41972 .77593 .4121 Mtetra
.87 .849 .82 r
.77593 .4121 .78317 .41972 .7992 .40274 .79197 .39399 Mtetra
.861 .827 .813 r
.79197 .39399 .7992 .40274 .81518 .3856 .80799 .37594 Mtetra
.849 .81 .811 r
.80799 .37594 .81518 .3856 .83118 .36877 .82401 .35842 Mtetra
.835 .796 .814 r
.82401 .35842 .83118 .36877 .84721 .35262 .8401 .34179 Mtetra
.82 .786 .82 r
.8401 .34179 .84721 .35262 .86334 .33743 .85629 .32628 Mtetra
.804 .777 .829 r
.85629 .32628 .86334 .33743 .87959 .32336 .87261 .31204 Mtetra
.662 .741 .909 r
.26159 .47018 .27069 .47862 .28449 .4741 .27543 .46563 Mtetra
.66 .742 .91 r
.27543 .46563 .28449 .4741 .29837 .46959 .28935 .4611 Mtetra
.658 .742 .911 r
.28935 .4611 .29837 .46959 .31231 .46511 .30334 .45662 Mtetra
.655 .742 .913 r
.30334 .45662 .31231 .46511 .32633 .46068 .3174 .45221 Mtetra
.651 .742 .916 r
.3174 .45221 .32633 .46068 .34042 .45636 .33152 .44794 Mtetra
.645 .743 .921 r
.33152 .44794 .34042 .45636 .35457 .45219 .34571 .44386 Mtetra
.635 .744 .926 r
.34571 .44386 .35457 .45219 .36879 .44823 .35998 .44006 Mtetra
.622 .744 .934 r
.35998 .44006 .36879 .44823 .38309 .4446 .3743 .43664 Mtetra
.602 .745 .945 r
.3743 .43664 .38309 .4446 .39745 .44138 .3887 .43373 Mtetra
.572 .744 .958 r
.3887 .43373 .39745 .44138 .41188 .43871 .40316 .43147 Mtetra
.529 .74 .972 r
.40316 .43147 .41188 .43871 .42639 .43675 .4177 .43004 Mtetra
.463 .73 .984 r
.4177 .43004 .42639 .43675 .44098 .43563 .43232 .4296 Mtetra
.365 .704 .985 r
.43232 .4296 .44098 .43563 .45566 .43553 .44704 .4303 Mtetra
.221 .648 .955 r
.44704 .4303 .45566 .43553 .47045 .43657 .46186 .43229 Mtetra
.032 .547 .869 r
.46186 .43229 .47045 .43657 .48536 .43886 .47681 .43565 Mtetra
0 .405 .719 r
.47681 .43565 .48536 .43886 .50041 .44244 .4919 .4404 Mtetra
.349 0 0 r
.4919 .4404 .50041 .44244 .51561 .44729 .50716 .44647 Mtetra
.469 0 0 r
.50716 .44647 .51561 .44729 .531 .45328 .52262 .45367 Mtetra
.539 0 0 r
.52262 .45367 .531 .45328 .54658 .46016 .53828 .46171 Mtetra
.572 .01 0 r
.53828 .46171 .54658 .46016 .56237 .4676 .55416 .47015 Mtetra
.578 .028 0 r
.55416 .47015 .56237 .4676 .57837 .47512 .57025 .47844 Mtetra
.56 .015 0 r
.57025 .47844 .57837 .47512 .59458 .48217 .58656 .48597 Mtetra
.518 0 0 r
.58656 .48597 .59458 .48217 .61096 .48814 .60305 .49207 Mtetra
.441 0 0 r
.60305 .49207 .61096 .48814 .6275 .49243 .61969 .49609 Mtetra
.308 0 0 r
.61969 .49609 .6275 .49243 .64415 .49447 .63643 .49746 Mtetra
.088 0 0 r
.63643 .49746 .64415 .49447 .66085 .4938 .65321 .49576 Mtetra
.228 .74 .707 r
.65321 .49576 .66085 .4938 .67756 .49013 .66999 .49075 Mtetra
.546 .929 .866 r
.66999 .49075 .67756 .49013 .69422 .48335 .6867 .48241 Mtetra
.746 .983 .909 r
.6867 .48241 .69422 .48335 .7108 .47355 .70332 .47093 Mtetra
.837 .961 .89 r
.70332 .47093 .7108 .47355 .72726 .46103 .71981 .4567 Mtetra
.87 .92 .858 r
.71981 .4567 .72726 .46103 .7436 .44623 .73616 .44028 Mtetra
.879 .883 .832 r
.73616 .44028 .7436 .44623 .75982 .42971 .75239 .42229 Mtetra
.877 .852 .814 r
.75239 .42229 .75982 .42971 .77593 .4121 .76852 .40341 Mtetra
.87 .828 .804 r
.76852 .40341 .77593 .4121 .79197 .39399 .78459 .38427 Mtetra
.859 .81 .8 r
.78459 .38427 .79197 .39399 .80799 .37594 .80064 .36543 Mtetra
.847 .795 .801 r
.80064 .36543 .80799 .37594 .82401 .35842 .81672 .34735 Mtetra
.833 .785 .806 r
.81672 .34735 .82401 .35842 .8401 .34179 .83287 .33035 Mtetra
.817 .776 .814 r
.83287 .33035 .8401 .34179 .85629 .32628 .84913 .31464 Mtetra
.8 .77 .825 r
.84913 .31464 .85629 .32628 .87261 .31204 .86553 .30032 Mtetra
.661 .741 .91 r
.2524 .46166 .26159 .47018 .27543 .46563 .26628 .45709 Mtetra
.659 .742 .911 r
.26628 .45709 .27543 .46563 .28935 .4611 .28024 .45255 Mtetra
.657 .742 .912 r
.28024 .45255 .28935 .4611 .30334 .45662 .29427 .44807 Mtetra
.653 .742 .915 r
.29427 .44807 .30334 .45662 .3174 .45221 .30837 .44371 Mtetra
.648 .743 .919 r
.30837 .44371 .3174 .45221 .33152 .44794 .32253 .4395 Mtetra
.64 .743 .924 r
.32253 .4395 .33152 .44794 .34571 .44386 .33676 .43554 Mtetra
.628 .744 .931 r
.33676 .43554 .34571 .44386 .35998 .44006 .35106 .43192 Mtetra
.61 .744 .94 r
.35106 .43192 .35998 .44006 .3743 .43664 .36542 .42877 Mtetra
.585 .744 .952 r
.36542 .42877 .3743 .43664 .3887 .43373 .37984 .42622 Mtetra
.547 .741 .966 r
.37984 .42622 .3887 .43373 .40316 .43147 .39433 .42445 Mtetra
.49 .733 .98 r
.39433 .42445 .40316 .43147 .4177 .43004 .4089 .42363 Mtetra
.403 .713 .986 r
.4089 .42363 .4177 .43004 .43232 .4296 .42355 .42393 Mtetra
.274 .668 .97 r
.42355 .42393 .43232 .4296 .44704 .4303 .43829 .42553 Mtetra
.094 .58 .904 r
.43829 .42553 .44704 .4303 .46186 .43229 .45314 .42854 Mtetra
0 .443 .77 r
.45314 .42854 .46186 .43229 .47681 .43565 .46812 .43304 Mtetra
.314 0 0 r
.46812 .43304 .47681 .43565 .4919 .4404 .48326 .43901 Mtetra
.457 0 0 r
.48326 .43901 .4919 .4404 .50716 .44647 .49858 .44633 Mtetra
.543 0 0 r
.49858 .44633 .50716 .44647 .52262 .45367 .51409 .45474 Mtetra
.588 .027 0 r
.51409 .45474 .52262 .45367 .53828 .46171 .52983 .46388 Mtetra
.604 .058 0 r
.52983 .46388 .53828 .46171 .55416 .47015 .54579 .47321 Mtetra
.598 .059 0 r
.54579 .47321 .55416 .47015 .57025 .47844 .56199 .48213 Mtetra
.57 .03 0 r
.56199 .48213 .57025 .47844 .58656 .48597 .57839 .48994 Mtetra
.513 0 0 r
.57839 .48994 .58656 .48597 .60305 .49207 .59499 .49593 Mtetra
.413 0 0 r
.59499 .49593 .60305 .49207 .61969 .49609 .61172 .49943 Mtetra
.239 0 0 r
.61172 .49943 .61969 .49609 .63643 .49746 .62855 .49988 Mtetra
0 0 0 r
.62855 .49988 .63643 .49746 .65321 .49576 .64541 .49691 Mtetra
.402 .855 .815 r
.64541 .49691 .65321 .49576 .66999 .49075 .66224 .49036 Mtetra
.677 .973 .909 r
.66224 .49036 .66999 .49075 .6867 .48241 .67901 .48029 Mtetra
.812 .97 .902 r
.67901 .48029 .6867 .48241 .70332 .47093 .69565 .46703 Mtetra
.864 .93 .867 r
.69565 .46703 .70332 .47093 .71981 .4567 .71217 .45107 Mtetra
.88 .889 .835 r
.71217 .45107 .71981 .4567 .73616 .44028 .72854 .43304 Mtetra
.881 .855 .811 r
.72854 .43304 .73616 .44028 .75239 .42229 .7448 .41365 Mtetra
.876 .829 .797 r
.7448 .41365 .75239 .42229 .76852 .40341 .76096 .39361 Mtetra
.867 .809 .79 r
.76096 .39361 .76852 .40341 .78459 .38427 .77706 .37357 Mtetra
.856 .794 .789 r
.77706 .37357 .78459 .38427 .80064 .36543 .79316 .35408 Mtetra
.843 .782 .793 r
.79316 .35408 .80064 .36543 .81672 .34735 .8093 .33557 Mtetra
.829 .774 .8 r
.8093 .33557 .81672 .34735 .83287 .33035 .82552 .31834 Mtetra
.813 .767 .81 r
.82552 .31834 .83287 .33035 .84913 .31464 .84186 .30254 Mtetra
.797 .763 .822 r
.84186 .30254 .84913 .31464 .86553 .30032 .85835 .28823 Mtetra
.66 .742 .91 r
.24312 .45306 .2524 .46166 .26628 .45709 .25704 .44848 Mtetra
.658 .742 .912 r
.25704 .44848 .26628 .45709 .28024 .45255 .27104 .44393 Mtetra
.655 .742 .914 r
.27104 .44393 .28024 .45255 .29427 .44807 .28511 .43948 Mtetra
.65 .742 .917 r
.28511 .43948 .29427 .44807 .30837 .44371 .29925 .43516 Mtetra
.644 .743 .921 r
.29925 .43516 .30837 .44371 .32253 .4395 .31345 .43106 Mtetra
.633 .743 .927 r
.31345 .43106 .32253 .4395 .33676 .43554 .32771 .42725 Mtetra
.619 .744 .936 r
.32771 .42725 .33676 .43554 .35106 .43192 .34204 .42385 Mtetra
.597 .743 .946 r
.34204 .42385 .35106 .43192 .36542 .42877 .35643 .42101 Mtetra
.564 .742 .96 r
.35643 .42101 .36542 .42877 .37984 .42622 .37088 .41888 Mtetra
.515 .736 .974 r
.37088 .41888 .37984 .42622 .39433 .42445 .38539 .41766 Mtetra
.441 .721 .984 r
.38539 .41766 .39433 .42445 .4089 .42363 .39998 .41752 Mtetra
.327 .686 .979 r
.39998 .41752 .4089 .42363 .42355 .42393 .41464 .41866 Mtetra
.163 .613 .935 r
.41464 .41866 .42355 .42393 .43829 .42553 .42941 .42122 Mtetra
0 .489 .824 r
.42941 .42122 .43829 .42553 .45314 .42854 .44428 .42533 Mtetra
.261 0 0 r
.44428 .42533 .45314 .42854 .46812 .43304 .4593 .43103 Mtetra
.429 0 0 r
.4593 .43103 .46812 .43304 .48326 .43901 .47448 .43825 Mtetra
.536 0 0 r
.47448 .43825 .48326 .43901 .49858 .44633 .48984 .44681 Mtetra
.595 .032 0 r
.48984 .44681 .49858 .44633 .51409 .45474 .50542 .45638 Mtetra
.622 .076 0 r
.50542 .45638 .51409 .45474 .52983 .46388 .52123 .46652 Mtetra
.626 .09 0 r
.52123 .46652 .52983 .46388 .54579 .47321 .53728 .47661 Mtetra
.609 .076 0 r
.53728 .47661 .54579 .47321 .56199 .48213 .55357 .48596 Mtetra
.569 .03 0 r
.55357 .48596 .56199 .48213 .57839 .48994 .57007 .49382 Mtetra
.495 0 0 r
.57007 .49382 .57839 .48994 .59499 .49593 .58676 .49944 Mtetra
.363 0 0 r
.58676 .49944 .59499 .49593 .61172 .49943 .60359 .50215 Mtetra
.13 0 0 r
.60359 .50215 .61172 .49943 .62855 .49988 .6205 .50142 Mtetra
.226 .742 .736 r
.6205 .50142 .62855 .49988 .64541 .49691 .63743 .49695 Mtetra
.575 .94 .898 r
.63743 .49695 .64541 .49691 .66224 .49036 .65432 .48867 Mtetra
.772 .975 .917 r
.65432 .48867 .66224 .49036 .67901 .48029 .67113 .47677 Mtetra
.851 .94 .881 r
.67113 .47677 .67901 .48029 .69565 .46703 .68781 .46167 Mtetra
.877 .895 .841 r
.68781 .46167 .69565 .46703 .71217 .45107 .70435 .44398 Mtetra
.883 .857 .812 r
.70435 .44398 .71217 .45107 .72854 .43304 .72075 .42442 Mtetra
.879 .828 .793 r
.72075 .42442 .72854 .43304 .7448 .41365 .73704 .40373 Mtetra
.872 .807 .782 r
.73704 .40373 .7448 .41365 .76096 .39361 .75323 .38268 Mtetra
.863 .791 .779 r
.75323 .38268 .76096 .39361 .77706 .37357 .76938 .36189 Mtetra
.851 .779 .78 r
.76938 .36189 .77706 .37357 .79316 .35408 .78554 .34191 Mtetra
.838 .77 .786 r
.78554 .34191 .79316 .35408 .8093 .33557 .80175 .32313 Mtetra
.824 .764 .796 r
.80175 .32313 .8093 .33557 .82552 .31834 .81805 .3058 Mtetra
.809 .76 .807 r
.81805 .3058 .82552 .31834 .84186 .30254 .83448 .29003 Mtetra
.792 .756 .82 r
.83448 .29003 .84186 .30254 .85835 .28823 .85107 .27583 Mtetra
.659 .742 .911 r
.23374 .4444 .24312 .45306 .25704 .44848 .24771 .4398 Mtetra
.657 .742 .913 r
.24771 .4398 .25704 .44848 .27104 .44393 .26175 .43527 Mtetra
.653 .742 .915 r
.26175 .43527 .27104 .44393 .28511 .43948 .27586 .43084 Mtetra
.647 .742 .919 r
.27586 .43084 .28511 .43948 .29925 .43516 .29003 .4266 Mtetra
.638 .743 .924 r
.29003 .4266 .29925 .43516 .31345 .43106 .30426 .42261 Mtetra
.626 .743 .931 r
.30426 .42261 .31345 .43106 .32771 .42725 .31856 .41898 Mtetra
.607 .743 .941 r
.31856 .41898 .32771 .42725 .34204 .42385 .33292 .41585 Mtetra
.58 .742 .953 r
.33292 .41585 .34204 .42385 .35643 .42101 .34733 .41338 Mtetra
.538 .738 .967 r
.34733 .41338 .35643 .42101 .37088 .41888 .3618 .41174 Mtetra
.475 .727 .98 r
.3618 .41174 .37088 .41888 .38539 .41766 .37633 .41112 Mtetra
.378 .701 .984 r
.37633 .41112 .38539 .41766 .39998 .41752 .39093 .41174 Mtetra
.233 .644 .959 r
.39093 .41174 .39998 .41752 .41464 .41866 .40561 .41378 Mtetra
.035 .539 .875 r
.40561 .41378 .41464 .41866 .42941 .42122 .42039 .41738 Mtetra
0 .384 .719 r
.42039 .41738 .42941 .42122 .44428 .42533 .43529 .42264 Mtetra
.383 0 0 r
.43529 .42264 .44428 .42533 .4593 .43103 .45033 .42956 Mtetra
.515 0 0 r
.45033 .42956 .4593 .43103 .47448 .43825 .46554 .43803 Mtetra
.592 .024 0 r
.46554 .43803 .47448 .43825 .48984 .44681 .48096 .44779 Mtetra
.631 .082 0 r
.48096 .44779 .48984 .44681 .50542 .45638 .49659 .45844 Mtetra
.645 .109 0 r
.49659 .45844 .50542 .45638 .52123 .46652 .51247 .46944 Mtetra
.638 .109 0 r
.51247 .46944 .52123 .46652 .53728 .47661 .52861 .48011 Mtetra
.611 .079 0 r
.52861 .48011 .53728 .47661 .55357 .48596 .54498 .48967 Mtetra
.558 .014 0 r
.54498 .48967 .55357 .48596 .57007 .49382 .56158 .49732 Mtetra
.46 0 0 r
.56158 .49732 .57007 .49382 .58676 .49944 .57836 .50229 Mtetra
.279 0 0 r
.57836 .50229 .58676 .49944 .60359 .50215 .59528 .50393 Mtetra
0 0 0 r
.59528 .50393 .60359 .50215 .6205 .50142 .61227 .50178 Mtetra
.433 .874 .867 r
.61227 .50178 .6205 .50142 .63743 .49695 .62927 .4956 Mtetra
.709 .969 .933 r
.62927 .4956 .63743 .49695 .65432 .48867 .64621 .48545 Mtetra
.828 .947 .9 r
.64621 .48545 .65432 .48867 .67113 .47677 .66306 .47164 Mtetra
.869 .901 .853 r
.66306 .47164 .67113 .47677 .68781 .46167 .67978 .4547 Mtetra
.88 .86 .816 r
.67978 .4547 .68781 .46167 .70435 .44398 .69635 .43535 Mtetra
.88 .828 .792 r
.69635 .43535 .70435 .44398 .72075 .42442 .71279 .41435 Mtetra
.875 .804 .777 r
.71279 .41435 .72075 .42442 .73704 .40373 .72911 .39253 Mtetra
.867 .787 .77 r
.72911 .39253 .73704 .40373 .75323 .38268 .74536 .37063 Mtetra
.857 .774 .769 r
.74536 .37063 .75323 .38268 .76938 .36189 .76157 .34928 Mtetra
.846 .766 .773 r
.76157 .34928 .76938 .36189 .78554 .34191 .7778 .32898 Mtetra
.833 .759 .781 r
.7778 .32898 .78554 .34191 .80175 .32313 .79409 .31008 Mtetra
.819 .755 .792 r
.79409 .31008 .80175 .32313 .81805 .3058 .81048 .29278 Mtetra
.804 .752 .806 r
.81048 .29278 .81805 .3058 .83448 .29003 .82701 .27715 Mtetra
.787 .751 .82 r
.82701 .27715 .83448 .29003 .85107 .27583 .84371 .26314 Mtetra
.658 .742 .912 r
.22427 .43566 .23374 .4444 .24771 .4398 .23828 .43106 Mtetra
.655 .742 .914 r
.23828 .43106 .24771 .4398 .26175 .43527 .25236 .42654 Mtetra
.65 .742 .917 r
.25236 .42654 .26175 .43527 .27586 .43084 .2665 .42217 Mtetra
.643 .742 .921 r
.2665 .42217 .27586 .43084 .29003 .4266 .28071 .41802 Mtetra
.632 .743 .928 r
.28071 .41802 .29003 .4266 .30426 .42261 .29498 .41417 Mtetra
.617 .743 .936 r
.29498 .41417 .30426 .42261 .31856 .41898 .3093 .41077 Mtetra
.593 .742 .947 r
.3093 .41077 .31856 .41898 .33292 .41585 .32368 .40795 Mtetra
.559 .739 .961 r
.32368 .40795 .33292 .41585 .34733 .41338 .33811 .40589 Mtetra
.506 .732 .975 r
.33811 .40589 .34733 .41338 .3618 .41174 .3526 .40479 Mtetra
.425 .713 .984 r
.3526 .40479 .3618 .41174 .37633 .41112 .36714 .40486 Mtetra
.301 .671 .974 r
.36714 .40486 .37633 .41112 .39093 .41174 .38175 .4063 Mtetra
.122 .586 .919 r
.38175 .4063 .39093 .41174 .40561 .41378 .39645 .4093 Mtetra
0 .447 .792 r
.39645 .4093 .40561 .41378 .42039 .41738 .41123 .41399 Mtetra
.316 0 0 r
.41123 .41399 .42039 .41738 .43529 .42264 .42615 .42043 Mtetra
.478 0 0 r
.42615 .42043 .43529 .42264 .45033 .42956 .44121 .42858 Mtetra
.577 .002 0 r
.44121 .42858 .45033 .42956 .46554 .43803 .45646 .43826 Mtetra
.632 .077 0 r
.45646 .43826 .46554 .43803 .48096 .44779 .47191 .44914 Mtetra
.656 .118 0 r
.47191 .44914 .48096 .44779 .49659 .45844 .48761 .46075 Mtetra
.659 .13 0 r
.48761 .46075 .49659 .45844 .51247 .46944 .50356 .47244 Mtetra
.643 .115 0 r
.50356 .47244 .51247 .46944 .52861 .48011 .51977 .48345 Mtetra
.605 .069 0 r
.51977 .48345 .52861 .48011 .54498 .48967 .53623 .49295 Mtetra
.533 0 0 r
.53623 .49295 .54498 .48967 .56158 .49732 .55292 .50011 Mtetra
.398 0 0 r
.55292 .50011 .56158 .49732 .57836 .50229 .5698 .50415 Mtetra
.143 0 0 r
.5698 .50415 .57836 .50229 .59528 .50393 .5868 .50445 Mtetra
.256 .767 .805 r
.5868 .50445 .59528 .50393 .61227 .50178 .60386 .50064 Mtetra
.616 .945 .941 r
.60386 .50064 .61227 .50178 .62927 .4956 .62092 .49259 Mtetra
.791 .951 .923 r
.62092 .49259 .62927 .4956 .64621 .48545 .63792 .48048 Mtetra
.854 .906 .87 r
.63792 .48048 .64621 .48545 .66306 .47164 .65482 .46474 Mtetra
.874 .862 .825 r
.65482 .46474 .66306 .47164 .67978 .4547 .67157 .44601 Mtetra
.878 .827 .793 r
.67157 .44601 .67978 .4547 .69635 .43535 .68819 .4251 Mtetra
.875 .801 .774 r
.68819 .4251 .69635 .43535 .71279 .41435 .70466 .40284 Mtetra
.869 .783 .763 r
.70466 .40284 .71279 .41435 .72911 .39253 .72103 .38007 Mtetra
.861 .769 .76 r
.72103 .38007 .72911 .39253 .74536 .37063 .73734 .35751 Mtetra
.851 .76 .762 r
.73734 .35751 .74536 .37063 .76157 .34928 .75362 .33579 Mtetra
.84 .754 .768 r
.75362 .33579 .76157 .34928 .7778 .32898 .76993 .31535 Mtetra
.827 .75 .778 r
.76993 .31535 .7778 .32898 .79409 .31008 .78631 .29649 Mtetra
.813 .748 .791 r
.78631 .29649 .79409 .31008 .81048 .29278 .80281 .27934 Mtetra
.798 .746 .805 r
.80281 .27934 .81048 .29278 .82701 .27715 .81945 .26395 Mtetra
.781 .746 .821 r
.81945 .26395 .82701 .27715 .84371 .26314 .83626 .25022 Mtetra
.657 .742 .913 r
.21471 .42685 .22427 .43566 .23828 .43106 .22876 .42225 Mtetra
.653 .742 .915 r
.22876 .42225 .23828 .43106 .25236 .42654 .24287 .41777 Mtetra
.647 .742 .919 r
.24287 .41777 .25236 .42654 .2665 .42217 .25705 .41346 Mtetra
.638 .742 .924 r
.25705 .41346 .2665 .42217 .28071 .41802 .27129 .40942 Mtetra
.625 .742 .931 r
.27129 .40942 .28071 .41802 .29498 .41417 .28559 .40576 Mtetra
.606 .742 .941 r
.28559 .40576 .29498 .41417 .3093 .41077 .29993 .40261 Mtetra
.577 .74 .954 r
.29993 .40261 .3093 .41077 .32368 .40795 .31433 .40015 Mtetra
.533 .735 .968 r
.31433 .40015 .32368 .40795 .33811 .40589 .32878 .39856 Mtetra
.466 .722 .98 r
.32878 .39856 .33811 .40589 .3526 .40479 .34328 .39806 Mtetra
.364 .692 .982 r
.34328 .39806 .3526 .40479 .36714 .40486 .35783 .39887 Mtetra
.209 .628 .951 r
.35783 .39887 .36714 .40486 .38175 .4063 .37244 .40119 Mtetra
.001 .512 .859 r
.37244 .40119 .38175 .4063 .39645 .4093 .38714 .40519 Mtetra
0 .347 .693 r
.38714 .40519 .39645 .4093 .41123 .41399 .40193 .411 Mtetra
.42 0 0 r
.40193 .411 .41123 .41399 .42615 .42043 .41685 .41863 Mtetra
.548 0 0 r
.41685 .41863 .42615 .42043 .44121 .42858 .43193 .42797 Mtetra
.621 .059 0 r
.43193 .42797 .44121 .42858 .45646 .43826 .44721 .4388 Mtetra
.658 .116 0 r
.44721 .4388 .45646 .43826 .47191 .44914 .46271 .45069 Mtetra
.671 .141 0 r
.46271 .45069 .47191 .44914 .48761 .46075 .47846 .46308 Mtetra
.666 .14 0 r
.47846 .46308 .48761 .46075 .50356 .47244 .49447 .47524 Mtetra
.641 .11 0 r
.49447 .47524 .50356 .47244 .51977 .48345 .51076 .48634 Mtetra
.589 .043 0 r
.51076 .48634 .51977 .48345 .53623 .49295 .52732 .4955 Mtetra
.489 0 0 r
.52732 .4955 .53623 .49295 .55292 .50011 .5441 .50186 Mtetra
.294 0 0 r
.5441 .50186 .55292 .50011 .5698 .50415 .56106 .50468 Mtetra
.061 .626 .716 r
.56106 .50468 .5698 .50415 .5868 .50445 .57814 .5034 Mtetra
.483 .891 .933 r
.57814 .5034 .5868 .50445 .60386 .50064 .59528 .49774 Mtetra
.735 .947 .949 r
.59528 .49774 .60386 .50064 .62092 .49259 .6124 .4877 Mtetra
.831 .91 .892 r
.6124 .4877 .62092 .49259 .63792 .48048 .62946 .47358 Mtetra
.863 .863 .837 r
.62946 .47358 .63792 .48048 .65482 .46474 .6464 .45595 Mtetra
.872 .826 .799 r
.6464 .45595 .65482 .46474 .67157 .44601 .6632 .43555 Mtetra
.872 .798 .774 r
.6632 .43555 .67157 .44601 .68819 .4251 .67985 .41324 Mtetra
.868 .778 .759 r
.67985 .41324 .68819 .4251 .70466 .40284 .69638 .38991 Mtetra
.862 .764 .752 r
.69638 .38991 .70466 .40284 .72103 .38007 .71281 .3664 Mtetra
.854 .754 .752 r
.71281 .3664 .72103 .38007 .73734 .35751 .72918 .34341 Mtetra
.844 .747 .756 r
.72918 .34341 .73734 .35751 .75362 .33579 .74555 .32151 Mtetra
.834 .743 .765 r
.74555 .32151 .75362 .33579 .76993 .31535 .76195 .3011 Mtetra
.821 .741 .776 r
.76195 .3011 .76993 .31535 .78631 .29649 .77844 .28242 Mtetra
.807 .741 .79 r
.77844 .28242 .78631 .29649 .80281 .27934 .79505 .26556 Mtetra
.792 .741 .806 r
.79505 .26556 .80281 .27934 .81945 .26395 .81181 .25049 Mtetra
.775 .742 .822 r
.81181 .25049 .81945 .26395 .83626 .25022 .82873 .2371 Mtetra
.655 .742 .914 r
.20504 .41798 .21471 .42685 .22876 .42225 .21913 .41339 Mtetra
.65 .742 .917 r
.21913 .41339 .22876 .42225 .24287 .41777 .23328 .40895 Mtetra
.643 .742 .921 r
.23328 .40895 .24287 .41777 .25705 .41346 .24749 .40473 Mtetra
.632 .742 .927 r
.24749 .40473 .25705 .41346 .27129 .40942 .26176 .40083 Mtetra
.616 .742 .936 r
.26176 .40083 .27129 .40942 .28559 .40576 .27608 .39738 Mtetra
.592 .741 .947 r
.27608 .39738 .28559 .40576 .29993 .40261 .29045 .39453 Mtetra
.557 .737 .96 r
.29045 .39453 .29993 .40261 .31433 .40015 .30487 .39246 Mtetra
.502 .728 .974 r
.30487 .39246 .31433 .40015 .32878 .39856 .31932 .3914 Mtetra
.418 .707 .983 r
.31932 .3914 .32878 .39856 .34328 .39806 .33382 .39155 Mtetra
.29 .661 .971 r
.33382 .39155 .34328 .39806 .35783 .39887 .34837 .39314 Mtetra
.105 .571 .913 r
.34837 .39314 .35783 .39887 .37244 .40119 .36299 .39638 Mtetra
0 .425 .781 r
.36299 .39638 .37244 .40119 .38714 .40519 .37768 .40143 Mtetra
.34 0 0 r
.37768 .40143 .38714 .40519 .40193 .411 .39247 .40836 Mtetra
.5 0 0 r
.39247 .40836 .40193 .411 .41685 .41863 .4074 .41714 Mtetra
.598 .027 0 r
.4074 .41714 .41685 .41863 .43193 .42797 .4225 .42763 Mtetra
.652 .101 0 r
.4225 .42763 .43193 .42797 .44721 .4388 .4378 .43948 Mtetra
.676 .141 0 r
.4378 .43948 .44721 .4388 .46271 .45069 .45334 .45222 Mtetra
.68 .153 0 r
.45334 .45222 .46271 .45069 .47846 .46308 .46914 .46518 Mtetra
.666 .138 0 r
.46914 .46518 .47846 .46308 .49447 .47524 .48523 .47756 Mtetra
.63 .09 0 r
.48523 .47756 .49447 .47524 .51076 .48634 .5016 .48846 Mtetra
.557 0 0 r
.5016 .48846 .51076 .48634 .52732 .4955 .51823 .49697 Mtetra
.412 0 0 r
.51823 .49697 .52732 .4955 .5441 .50186 .5351 .50225 Mtetra
.124 0 0 r
.5351 .50225 .5441 .50186 .56106 .50468 .55215 .50358 Mtetra
.313 .797 .895 r
.55215 .50358 .56106 .50468 .57814 .5034 .56932 .5005 Mtetra
.651 .928 .973 r
.56932 .5005 .57814 .5034 .59528 .49774 .58652 .49285 Mtetra
.796 .91 .919 r
.58652 .49285 .59528 .49774 .6124 .4877 .60371 .48075 Mtetra
.846 .864 .855 r
.60371 .48075 .6124 .4877 .62946 .47358 .62082 .46465 Mtetra
.863 .824 .808 r
.62082 .46465 .62946 .47358 .6464 .45595 .63781 .44522 Mtetra
.867 .794 .777 r
.63781 .44522 .6464 .45595 .6632 .43555 .65466 .4233 Mtetra
.865 .773 .758 r
.65466 .4233 .6632 .43555 .67985 .41324 .67137 .3998 Mtetra
.861 .757 .747 r
.67137 .3998 .67985 .41324 .69638 .38991 .68795 .37563 Mtetra
.854 .747 .744 r
.68795 .37563 .69638 .38991 .71281 .3664 .70445 .35161 Mtetra
.847 .74 .746 r
.70445 .35161 .71281 .3664 .72918 .34341 .72091 .3284 Mtetra
.838 .736 .752 r
.72091 .3284 .72918 .34341 .74555 .32151 .73737 .30653 Mtetra
.827 .735 .763 r
.73737 .30653 .74555 .32151 .76195 .3011 .75388 .28632 Mtetra
.814 .734 .776 r
.75388 .28632 .76195 .3011 .77844 .28242 .77047 .26797 Mtetra
.801 .735 .791 r
.77047 .26797 .77844 .28242 .79505 .26556 .7872 .25149 Mtetra
.785 .737 .808 r
.7872 .25149 .79505 .26556 .81181 .25049 .80408 .23683 Mtetra
.769 .738 .825 r
.80408 .23683 .81181 .25049 .82873 .2371 .82113 .22382 Mtetra
.653 .742 .915 r
.19528 .40903 .20504 .41798 .21913 .41339 .2094 .40447 Mtetra
.647 .742 .919 r
.2094 .40447 .21913 .41339 .23328 .40895 .22359 .40009 Mtetra
.638 .742 .924 r
.22359 .40009 .23328 .40895 .24749 .40473 .23783 .39598 Mtetra
.625 .742 .931 r
.23783 .39598 .24749 .40473 .26176 .40083 .25213 .39224 Mtetra
.606 .741 .941 r
.25213 .39224 .26176 .40083 .27608 .39738 .26647 .38903 Mtetra
.577 .739 .953 r
.26647 .38903 .27608 .39738 .29045 .39453 .28086 .38652 Mtetra
.533 .733 .967 r
.28086 .38652 .29045 .39453 .30487 .39246 .29528 .3849 Mtetra
.465 .719 .979 r
.29528 .3849 .30487 .39246 .31932 .3914 .30974 .38439 Mtetra
.361 .687 .98 r
.30974 .38439 .31932 .3914 .33382 .39155 .32424 .38524 Mtetra
.206 .621 .95 r
.32424 .38524 .33382 .39155 .34837 .39314 .33878 .38766 Mtetra
0 .502 .858 r
.33878 .38766 .34837 .39314 .36299 .39638 .35339 .39185 Mtetra
0 .336 .693 r
.35339 .39185 .36299 .39638 .37768 .40143 .36807 .39794 Mtetra
.429 0 0 r
.36807 .39794 .37768 .40143 .39247 .40836 .38286 .40597 Mtetra
.559 0 0 r
.38286 .40597 .39247 .40836 .4074 .41714 .39779 .41586 Mtetra
.634 .073 0 r
.39779 .41586 .4074 .41714 .4225 .42763 .4129 .42738 Mtetra
.673 .13 0 r
.4129 .42738 .4225 .42763 .4378 .43948 .42823 .44012 Mtetra
.687 .156 0 r
.42823 .44012 .4378 .43948 .45334 .45222 .44381 .4535 Mtetra
.683 .154 0 r
.44381 .4535 .45334 .45222 .46914 .46518 .45967 .46679 Mtetra
.659 .124 0 r
.45967 .46679 .46914 .46518 .48523 .47756 .47582 .4791 Mtetra
.607 .053 0 r
.47582 .4791 .48523 .47756 .5016 .48846 .49227 .4895 Mtetra
.501 0 0 r
.49227 .4895 .5016 .48846 .51823 .49697 .509 .49706 Mtetra
.28 0 0 r
.509 .49706 .51823 .49697 .5351 .50225 .52595 .50095 Mtetra
.119 .665 .824 r
.52595 .50095 .5351 .50225 .55215 .50358 .54309 .50056 Mtetra
.533 .884 .983 r
.54309 .50056 .55215 .50358 .56932 .5005 .56033 .49552 Mtetra
.744 .903 .949 r
.56033 .49552 .56932 .5005 .58652 .49285 .57761 .48578 Mtetra
.821 .862 .877 r
.57761 .48578 .58652 .49285 .60371 .48075 .59486 .47163 Mtetra
.849 .821 .821 r
.59486 .47163 .60371 .48075 .62082 .46465 .61203 .45363 Mtetra
.858 .789 .783 r
.61203 .45363 .62082 .46465 .63781 .44522 .62907 .43256 Mtetra
.859 .767 .759 r
.62907 .43256 .63781 .44522 .65466 .4233 .64597 .40932 Mtetra
.857 .751 .745 r
.64597 .40932 .65466 .4233 .67137 .3998 .66274 .38487 Mtetra
.853 .74 .738 r
.66274 .38487 .67137 .3998 .68795 .37563 .6794 .36011 Mtetra
.847 .733 .738 r
.6794 .36011 .68795 .37563 .70445 .35161 .69598 .33582 Mtetra
.839 .729 .742 r
.69598 .33582 .70445 .35161 .72091 .3284 .71253 .31262 Mtetra
.83 .727 .751 r
.71253 .31262 .72091 .3284 .73737 .30653 .72909 .29096 Mtetra
.82 .727 .763 r
.72909 .29096 .73737 .30653 .75388 .28632 .74571 .27112 Mtetra
.808 .729 .777 r
.74571 .27112 .75388 .28632 .77047 .26797 .76242 .2532 Mtetra
.794 .731 .794 r
.76242 .2532 .77047 .26797 .7872 .25149 .77927 .23721 Mtetra
.778 .733 .811 r
.77927 .23721 .7872 .25149 .80408 .23683 .79628 .22301 Mtetra
.762 .736 .828 r
.79628 .22301 .80408 .23683 .82113 .22382 .81345 .21044 Mtetra
.65 .742 .916 r
.18541 .40003 .19528 .40903 .2094 .40447 .19957 .3955 Mtetra
.643 .742 .921 r
.19957 .3955 .2094 .40447 .22359 .40009 .21379 .3912 Mtetra
.633 .742 .927 r
.21379 .3912 .22359 .40009 .23783 .39598 .22806 .38721 Mtetra
.617 .741 .935 r
.22806 .38721 .23783 .39598 .25213 .39224 .24238 .38367 Mtetra
.593 .74 .946 r
.24238 .38367 .25213 .39224 .26647 .38903 .25674 .38073 Mtetra
.558 .736 .959 r
.25674 .38073 .26647 .38903 .28086 .38652 .27114 .37858 Mtetra
.504 .726 .972 r
.27114 .37858 .28086 .38652 .29528 .3849 .28557 .37745 Mtetra
.422 .705 .981 r
.28557 .37745 .29528 .3849 .30974 .38439 .30002 .37755 Mtetra
.295 .659 .971 r
.30002 .37755 .30974 .38439 .32424 .38524 .31451 .37913 Mtetra
.113 .57 .917 r
.31451 .37913 .32424 .38524 .33878 .38766 .32905 .3824 Mtetra
0 .426 .791 r
.32905 .3824 .33878 .38766 .35339 .39185 .34364 .38754 Mtetra
.333 0 0 r
.34364 .38754 .35339 .39185 .36807 .39794 .35831 .39466 Mtetra
.498 0 0 r
.35831 .39466 .36807 .39794 .38286 .40597 .37309 .40374 Mtetra
.601 .029 0 r
.37309 .40374 .38286 .40597 .39779 .41586 .38803 .41464 Mtetra
.658 .105 0 r
.38803 .41464 .39779 .41586 .4129 .42738 .40315 .42705 Mtetra
.685 .147 0 r
.40315 .42705 .4129 .42738 .42823 .44012 .4185 .44048 Mtetra
.691 .16 0 r
.4185 .44048 .42823 .44012 .44381 .4535 .43412 .45428 Mtetra
.679 .144 0 r
.43412 .45428 .44381 .4535 .45967 .46679 .45004 .46761 Mtetra
.642 .094 0 r
.45004 .46761 .45967 .46679 .47582 .4791 .46626 .47955 Mtetra
.564 0 0 r
.46626 .47955 .47582 .4791 .49227 .4895 .4828 .48913 Mtetra
.4 0 0 r
.4828 .48913 .49227 .4895 .509 .49706 .49961 .49544 Mtetra
0 .514 .73 r
.49961 .49544 .509 .49706 .52595 .50095 .51665 .49771 Mtetra
.378 .805 .969 r
.51665 .49771 .52595 .50095 .54309 .50056 .53387 .49539 Mtetra
.669 .883 .977 r
.53387 .49539 .54309 .50056 .56033 .49552 .55119 .48827 Mtetra
.785 .856 .903 r
.55119 .48827 .56033 .49552 .57761 .48578 .56855 .47643 Mtetra
.829 .816 .838 r
.56855 .47643 .57761 .48578 .59486 .47163 .58586 .46029 Mtetra
.845 .784 .792 r
.58586 .46029 .59486 .47163 .61203 .45363 .60309 .44053 Mtetra
.851 .761 .763 r
.60309 .44053 .61203 .45363 .62907 .43256 .62019 .41802 Mtetra
.851 .744 .744 r
.62019 .41802 .62907 .43256 .64597 .40932 .63715 .39372 Mtetra
.849 .733 .734 r
.63715 .39372 .64597 .40932 .66274 .38487 .65399 .36858 Mtetra
.845 .725 .731 r
.65399 .36858 .66274 .38487 .6794 .36011 .67073 .34349 Mtetra
.839 .721 .733 r
.67073 .34349 .6794 .36011 .69598 .33582 .6874 .31917 Mtetra
.832 .719 .74 r
.6874 .31917 .69598 .33582 .71253 .31262 .70404 .29619 Mtetra
.823 .719 .75 r
.70404 .29619 .71253 .31262 .72909 .29096 .72071 .27492 Mtetra
.813 .721 .764 r
.72071 .27492 .72909 .29096 .74571 .27112 .73745 .25558 Mtetra
.801 .724 .78 r
.73745 .25558 .74571 .27112 .76242 .2532 .75429 .23822 Mtetra
.787 .727 .797 r
.75429 .23822 .76242 .2532 .77927 .23721 .77127 .22277 Mtetra
.771 .73 .815 r
.77127 .22277 .77927 .23721 .79628 .22301 .7884 .2091 Mtetra
.755 .734 .832 r
.7884 .2091 .79628 .22301 .81345 .21044 .8057 .19697 Mtetra
.647 .742 .918 r
.17544 .39096 .18541 .40003 .19957 .3955 .18963 .38648 Mtetra
.639 .742 .923 r
.18963 .38648 .19957 .3955 .21379 .3912 .20388 .38227 Mtetra
.626 .741 .93 r
.20388 .38227 .21379 .3912 .22806 .38721 .21818 .37843 Mtetra
.607 .74 .939 r
.21818 .37843 .22806 .38721 .24238 .38367 .23252 .3751 Mtetra
.579 .738 .951 r
.23252 .3751 .24238 .38367 .25674 .38073 .24689 .37247 Mtetra
.537 .732 .964 r
.24689 .37247 .25674 .38073 .27114 .37858 .26129 .37073 Mtetra
.472 .717 .977 r
.26129 .37073 .27114 .37858 .28557 .37745 .27572 .37011 Mtetra
.372 .686 .98 r
.27572 .37011 .28557 .37745 .30002 .37755 .29017 .37084 Mtetra
.222 .624 .954 r
.29017 .37084 .30002 .37755 .31451 .37913 .30465 .37317 Mtetra
.018 .511 .872 r
.30465 .37317 .31451 .37913 .32905 .3824 .31917 .3773 Mtetra
0 .349 .719 r
.31917 .3773 .32905 .3824 .34364 .38754 .33374 .38338 Mtetra
.41 0 0 r
.33374 .38338 .34364 .38754 .35831 .39466 .3484 .39148 Mtetra
.548 0 0 r
.3484 .39148 .35831 .39466 .37309 .40374 .36317 .40152 Mtetra
.63 .066 0 r
.36317 .40152 .37309 .40374 .38803 .41464 .37811 .4133 Mtetra
.673 .126 0 r
.37811 .4133 .38803 .41464 .40315 .42705 .39324 .42643 Mtetra
.691 .154 0 r
.39324 .42643 .40315 .42705 .4185 .44048 .40862 .44033 Mtetra
.689 .153 0 r
.40862 .44033 .4185 .44048 .43412 .45428 .42429 .45427 Mtetra
.665 .12 0 r
.42429 .45427 .43412 .45428 .45004 .46761 .44027 .46735 Mtetra
.609 .044 0 r
.44027 .46735 .45004 .46761 .46626 .47955 .45657 .47861 Mtetra
.487 0 0 r
.45657 .47861 .46626 .47955 .4828 .48913 .47318 .48707 Mtetra
.23 0 0 r
.47318 .48707 .4828 .48913 .49961 .49544 .49008 .49185 Mtetra
.199 .691 .922 r
.49008 .49185 .49961 .49544 .51665 .49771 .50722 .49227 Mtetra
.565 .844 .997 r
.50722 .49227 .51665 .49771 .53387 .49539 .52453 .4879 Mtetra
.735 .844 .931 r
.52453 .4879 .53387 .49539 .55119 .48827 .54193 .47864 Mtetra
.801 .809 .858 r
.54193 .47864 .55119 .48827 .56855 .47643 .55935 .46474 Mtetra
.828 .778 .805 r
.55935 .46474 .56855 .47643 .58586 .46029 .57673 .44674 Mtetra
.839 .754 .769 r
.57673 .44674 .58586 .46029 .60309 .44053 .59402 .42542 Mtetra
.843 .737 .746 r
.59402 .42542 .60309 .44053 .62019 .41802 .61118 .40173 Mtetra
.843 .725 .733 r
.61118 .40173 .62019 .41802 .63715 .39372 .62822 .37663 Mtetra
.841 .717 .727 r
.62822 .37663 .63715 .39372 .65399 .36858 .64513 .35109 Mtetra
.837 .713 .726 r
.64513 .35109 .65399 .36858 .67073 .34349 .66195 .32593 Mtetra
.832 .711 .731 r
.66195 .32593 .67073 .34349 .6874 .31917 .67872 .30181 Mtetra
.825 .711 .739 r
.67872 .30181 .6874 .31917 .70404 .29619 .69547 .27925 Mtetra
.816 .713 .751 r
.69547 .27925 .70404 .29619 .72071 .27492 .71226 .25854 Mtetra
.806 .716 .766 r
.71226 .25854 .72071 .27492 .73745 .25558 .72912 .23981 Mtetra
.793 .72 .783 r
.72912 .23981 .73745 .25558 .75429 .23822 .74609 .22309 Mtetra
.779 .724 .801 r
.74609 .22309 .75429 .23822 .77127 .22277 .76319 .20825 Mtetra
.764 .728 .82 r
.76319 .20825 .77127 .22277 .7884 .2091 .78045 .19511 Mtetra
.748 .732 .837 r
.78045 .19511 .7884 .2091 .8057 .19697 .79787 .18346 Mtetra
.644 .741 .92 r
.16536 .38183 .17544 .39096 .18963 .38648 .17958 .37742 Mtetra
.634 .741 .926 r
.17958 .37742 .18963 .38648 .20388 .38227 .19386 .37331 Mtetra
.619 .741 .933 r
.19386 .37331 .20388 .38227 .21818 .37843 .20818 .36964 Mtetra
.596 .739 .944 r
.20818 .36964 .21818 .37843 .23252 .3751 .22254 .36656 Mtetra
.563 .735 .956 r
.22254 .36656 .23252 .3751 .24689 .37247 .23692 .36425 Mtetra
.512 .726 .97 r
.23692 .36425 .24689 .37247 .26129 .37073 .25132 .36294 Mtetra
.434 .705 .979 r
.25132 .36294 .26129 .37073 .27572 .37011 .26575 .36286 Mtetra
.316 .663 .973 r
.26575 .36286 .27572 .37011 .29017 .37084 .28019 .36425 Mtetra
.144 .581 .929 r
.28019 .36425 .29017 .37084 .30465 .37317 .29465 .36734 Mtetra
0 .448 .82 r
.29465 .36734 .30465 .37317 .31917 .3773 .30914 .37231 Mtetra
0 .278 .65 r
.30914 .37231 .31917 .3773 .33374 .38338 .3237 .37928 Mtetra
.469 0 0 r
.3237 .37928 .33374 .38338 .3484 .39148 .33834 .38828 Mtetra
.583 .008 0 r
.33834 .38828 .3484 .39148 .36317 .40152 .3531 .39916 Mtetra
.648 .089 0 r
.3531 .39916 .36317 .40152 .37811 .4133 .36804 .41166 Mtetra
.68 .134 0 r
.36804 .41166 .37811 .4133 .39324 .42643 .38319 .4253 Mtetra
.689 .149 0 r
.38319 .4253 .39324 .42643 .40862 .44033 .3986 .43942 Mtetra
.677 .133 0 r
.3986 .43942 .40862 .44033 .42429 .45427 .41432 .45321 Mtetra
.638 .078 0 r
.41432 .45321 .42429 .45427 .44027 .46735 .43036 .46573 Mtetra
.548 0 0 r
.43036 .46573 .44027 .46735 .45657 .47861 .44674 .476 Mtetra
.352 0 0 r
.44674 .476 .45657 .47861 .47318 .48707 .46345 .48305 Mtetra
.018 .556 .846 r
.46345 .48305 .47318 .48707 .49008 .49185 .48044 .48607 Mtetra
.432 .778 .997 r
.48044 .48607 .49008 .49185 .50722 .49227 .49767 .48448 Mtetra
.666 .821 .958 r
.49767 .48448 .50722 .49227 .52453 .4879 .51506 .47797 Mtetra
.764 .799 .881 r
.51506 .47797 .52453 .4879 .54193 .47864 .53254 .4666 Mtetra
.805 .77 .82 r
.53254 .4666 .54193 .47864 .55935 .46474 .55004 .45075 Mtetra
.824 .746 .778 r
.55004 .45075 .55935 .46474 .57673 .44674 .56748 .43108 Mtetra
.832 .729 .751 r
.56748 .43108 .57673 .44674 .59402 .42542 .58484 .40845 Mtetra
.835 .717 .734 r
.58484 .40845 .59402 .42542 .61118 .40173 .60207 .38385 Mtetra
.835 .709 .725 r
.60207 .38385 .61118 .40173 .62822 .37663 .61918 .35825 Mtetra
.833 .705 .722 r
.61918 .35825 .62822 .37663 .64513 .35109 .63617 .33258 Mtetra
.83 .703 .724 r
.63617 .33258 .64513 .35109 .66195 .32593 .65309 .3076 Mtetra
.824 .703 .73 r
.65309 .3076 .66195 .32593 .67872 .30181 .66996 .28391 Mtetra
.818 .705 .741 r
.66996 .28391 .67872 .30181 .69547 .27925 .68682 .26194 Mtetra
.809 .708 .754 r
.68682 .26194 .69547 .27925 .71226 .25854 .70373 .24191 Mtetra
.798 .713 .77 r
.70373 .24191 .71226 .25854 .72912 .23981 .72072 .22391 Mtetra
.786 .718 .788 r
.72072 .22391 .72912 .23981 .74609 .22309 .73781 .20788 Mtetra
.772 .723 .807 r
.73781 .20788 .74609 .22309 .76319 .20825 .75505 .19368 Mtetra
.757 .727 .825 r
.75505 .19368 .76319 .20825 .78045 .19511 .77243 .1811 Mtetra
.741 .731 .842 r
.77243 .1811 .78045 .19511 .79787 .18346 .78998 .16992 Mtetra
.64 .741 .922 r
.15517 .37263 .16536 .38183 .17958 .37742 .16942 .3683 Mtetra
.628 .741 .928 r
.16942 .3683 .17958 .37742 .19386 .37331 .18373 .36432 Mtetra
.61 .74 .937 r
.18373 .36432 .19386 .37331 .20818 .36964 .19807 .36084 Mtetra
.584 .737 .948 r
.19807 .36084 .20818 .36964 .22254 .36656 .21243 .35802 Mtetra
.544 .731 .961 r
.21243 .35802 .22254 .36656 .23692 .36425 .22682 .35607 Mtetra
.484 .718 .974 r
.22682 .35607 .23692 .36425 .25132 .36294 .24123 .35521 Mtetra
.393 .69 .979 r
.24123 .35521 .25132 .36294 .26575 .36286 .25564 .35569 Mtetra
.256 .634 .962 r
.25564 .35569 .26575 .36286 .28019 .36425 .27006 .35773 Mtetra
.066 .534 .897 r
.27006 .35773 .28019 .36425 .29465 .36734 .2845 .36156 Mtetra
0 .386 .766 r
.2845 .36156 .29465 .36734 .30914 .37231 .29897 .36734 Mtetra
.361 0 0 r
.29897 .36734 .30914 .37231 .3237 .37928 .3135 .37514 Mtetra
.511 0 0 r
.3135 .37514 .3237 .37928 .33834 .38828 .32813 .38493 Mtetra
.605 .035 0 r
.32813 .38493 .33834 .38828 .3531 .39916 .34289 .39651 Mtetra
.657 .101 0 r
.34289 .39651 .3531 .39916 .36804 .41166 .35783 .40953 Mtetra
.679 .132 0 r
.35783 .40953 .36804 .41166 .38319 .4253 .373 .42343 Mtetra
.373 .42343 .38319 .4253 .3986 .43942 .38846 .43749 Mtetra
.653 .097 0 r
.38846 .43749 .3986 .43942 .41432 .45321 .40423 .45083 Mtetra
.586 .011 0 r
.40423 .45083 .41432 .45321 .43036 .46573 .42035 .46249 Mtetra
.439 0 0 r
.42035 .46249 .43036 .46573 .44674 .476 .43681 .47146 Mtetra
0 .423 .759 r
.43681 .47146 .44674 .476 .46345 .48305 .45361 .47686 Mtetra
.278 .686 .971 r
.45361 .47686 .46345 .48305 .48044 .48607 .4707 .47794 Mtetra
.577 .784 .977 r
.4707 .47794 .48044 .48607 .49767 .48448 .48802 .47423 Mtetra
.716 .782 .905 r
.48802 .47423 .49767 .48448 .51506 .47797 .5055 .46558 Mtetra
.776 .759 .838 r
.5055 .46558 .51506 .47797 .53254 .4666 .52306 .45219 Mtetra
.804 .737 .79 r
.52306 .45219 .53254 .4666 .55004 .45075 .54062 .43456 Mtetra
.818 .721 .757 r
.54062 .43456 .55004 .45075 .56748 .43108 .55814 .41345 Mtetra
.825 .709 .737 r
.55814 .41345 .56748 .43108 .58484 .40845 .57556 .3898 Mtetra
.828 .701 .724 r
.57556 .3898 .58484 .40845 .60207 .38385 .59287 .36459 Mtetra
.828 .696 .719 r
.59287 .36459 .60207 .38385 .61918 .35825 .61005 .33878 Mtetra
.826 .694 .718 r
.61005 .33878 .61918 .35825 .63617 .33258 .62713 .31325 Mtetra
.822 .694 .723 r
.62713 .31325 .63617 .33258 .65309 .3076 .64414 .28869 Mtetra
.817 .696 .731 r
.64414 .28869 .65309 .3076 .66996 .28391 .66112 .26563 Mtetra
.81 .7 .743 r
.66112 .26563 .66996 .28391 .68682 .26194 .6781 .2444 Mtetra
.801 .705 .758 r
.6781 .2444 .68682 .26194 .70373 .24191 .69513 .22516 Mtetra
.791 .71 .775 r
.69513 .22516 .70373 .24191 .72072 .22391 .71225 .20795 Mtetra
.778 .716 .794 r
.71225 .20795 .72072 .22391 .73781 .20788 .72947 .19265 Mtetra
.764 .721 .813 r
.72947 .19265 .73781 .20788 .75505 .19368 .74684 .17911 Mtetra
.749 .726 .831 r
.74684 .17911 .75505 .19368 .77243 .1811 .76435 .16709 Mtetra
.734 .731 .848 r
.76435 .16709 .77243 .1811 .78998 .16992 .78202 .15637 Mtetra
.636 .741 .924 r
.14487 .36338 .15517 .37263 .16942 .3683 .15915 .35914 Mtetra
.622 .74 .931 r
.15915 .35914 .16942 .3683 .18373 .36432 .17347 .3553 Mtetra
.601 .738 .941 r
.17347 .3553 .18373 .36432 .19807 .36084 .18783 .35203 Mtetra
.57 .735 .953 r
.18783 .35203 .19807 .36084 .21243 .35802 .20221 .34949 Mtetra
.524 .726 .966 r
.20221 .34949 .21243 .35802 .22682 .35607 .2166 .34791 Mtetra
.454 .708 .977 r
.2166 .34791 .22682 .35607 .24123 .35521 .23099 .34752 Mtetra
.348 .671 .976 r
.23099 .34752 .24123 .35521 .25564 .35569 .24539 .34855 Mtetra
.194 .602 .945 r
.24539 .34855 .25564 .35569 .27006 .35773 .25979 .35124 Mtetra
0 .485 .861 r
.25979 .35124 .27006 .35773 .2845 .36156 .27421 .35578 Mtetra
0 .33 .716 r
.27421 .35578 .2845 .36156 .29897 .36734 .28866 .3623 Mtetra
.409 0 0 r
.28866 .3623 .29897 .36734 .3135 .37514 .30317 .37083 Mtetra
.538 0 0 r
.30317 .37083 .3135 .37514 .32813 .38493 .31778 .38127 Mtetra
.616 .049 0 r
.31778 .38127 .32813 .38493 .34289 .39651 .33254 .39337 Mtetra
.656 .1 0 r
.33254 .39337 .34289 .39651 .35783 .40953 .34749 .40669 Mtetra
.669 .117 0 r
.34749 .40669 .35783 .40953 .373 .42343 .36269 .42059 Mtetra
.656 .1 0 r
.36269 .42059 .373 .42343 .38846 .43749 .3782 .4343 Mtetra
.608 .039 0 r
.3782 .4343 .38846 .43749 .40423 .45083 .39404 .44689 Mtetra
.495 0 0 r
.39404 .44689 .40423 .45083 .42035 .46249 .41024 .45739 Mtetra
0 .31 .679 r
.41024 .45739 .42035 .46249 .43681 .47146 .42679 .46482 Mtetra
.12 .577 .919 r
.42679 .46482 .43681 .47146 .45361 .47686 .44369 .46835 Mtetra
.466 .729 .983 r
.44369 .46835 .45361 .47686 .4707 .47794 .46087 .46736 Mtetra
.653 .758 .926 r
.46087 .46736 .4707 .47794 .48802 .47423 .47829 .46151 Mtetra
.739 .745 .857 r
.47829 .46151 .48802 .47423 .5055 .46558 .49585 .45078 Mtetra
.78 .727 .803 r
.49585 .45078 .5055 .46558 .52306 .45219 .51349 .43552 Mtetra
.801 .712 .766 r
.51349 .43552 .52306 .45219 .54062 .43456 .53113 .41633 Mtetra
.812 .7 .741 r
.53113 .41633 .54062 .43456 .55814 .41345 .54872 .39407 Mtetra
.818 .693 .726 r
.54872 .39407 .55814 .41345 .57556 .3898 .56621 .36969 Mtetra
.821 .688 .718 r
.56621 .36969 .57556 .3898 .59287 .36459 .58358 .34418 Mtetra
.821 .686 .715 r
.58358 .34418 .59287 .36459 .61005 .33878 .60085 .31846 Mtetra
.819 .686 .717 r
.60085 .31846 .61005 .33878 .62713 .31325 .61802 .29332 Mtetra
.815 .688 .724 r
.61802 .29332 .62713 .31325 .64414 .28869 .63513 .26939 Mtetra
.81 .691 .734 r
.63513 .26939 .64414 .28869 .66112 .26563 .65222 .24711 Mtetra
.803 .696 .747 r
.65222 .24711 .66112 .26563 .6781 .2444 .66932 .22674 Mtetra
.794 .702 .763 r
.66932 .22674 .6781 .2444 .69513 .22516 .68647 .20838 Mtetra
.783 .709 .781 r
.68647 .20838 .69513 .22516 .71225 .20795 .70371 .192 Mtetra
.77 .715 .801 r
.70371 .192 .71225 .20795 .72947 .19265 .72107 .17746 Mtetra
.756 .721 .82 r
.72107 .17746 .72947 .19265 .74684 .17911 .73856 .16457 Mtetra
.742 .726 .838 r
.73856 .16457 .74684 .17911 .76435 .16709 .75619 .15311 Mtetra
.727 .731 .854 r
.75619 .15311 .76435 .16709 .78202 .15637 .77398 .14282 Mtetra
.631 .741 .927 r
.13445 .35407 .14487 .36338 .15915 .35914 .14876 .34993 Mtetra
.615 .739 .935 r
.14876 .34993 .15915 .35914 .17347 .3553 .16311 .34625 Mtetra
.591 .737 .945 r
.16311 .34625 .17347 .3553 .18783 .35203 .17747 .34319 Mtetra
.555 .731 .957 r
.17747 .34319 .18783 .35203 .20221 .34949 .19186 .34096 Mtetra
.502 .72 .97 r
.19186 .34096 .20221 .34949 .2166 .34791 .20624 .33976 Mtetra
.421 .696 .978 r
.20624 .33976 .2166 .34791 .23099 .34752 .22063 .33983 Mtetra
.302 .65 .969 r
.22063 .33983 .23099 .34752 .24539 .34855 .23501 .34141 Mtetra
.134 .567 .925 r
.23501 .34141 .24539 .34855 .25979 .35124 .24939 .34471 Mtetra
0 .439 .825 r
.24939 .34471 .25979 .35124 .27421 .35578 .26378 .34991 Mtetra
0 .283 .675 r
.26378 .34991 .27421 .35578 .28866 .3623 .27821 .35709 Mtetra
.442 0 0 r
.27821 .35709 .28866 .3623 .30317 .37083 .2927 .36622 Mtetra
.552 0 0 r
.2927 .36622 .30317 .37083 .31778 .38127 .3073 .37716 Mtetra
.616 .051 0 r
.3073 .37716 .31778 .38127 .33254 .39337 .32207 .38957 Mtetra
.645 .087 0 r
.32207 .38957 .33254 .39337 .34749 .40669 .33704 .40294 Mtetra
.646 .088 0 r
.33704 .40294 .34749 .40669 .36269 .42059 .35228 .41657 Mtetra
.613 .048 0 r
.35228 .41657 .36269 .42059 .3782 .4343 .36785 .42964 Mtetra
.528 0 0 r
.36785 .42964 .3782 .4343 .39404 .44689 .38376 .44119 Mtetra
.345 0 0 r
.38376 .44119 .39404 .44689 .41024 .45739 .40005 .45025 Mtetra
0 .467 .855 r
.40005 .45025 .41024 .45739 .42679 .46482 .41671 .45593 Mtetra
.34 .657 .971 r
.41671 .45593 .42679 .46482 .44369 .46835 .4337 .45745 Mtetra
.575 .723 .943 r
.4337 .45745 .44369 .46835 .46087 .46736 .45099 .45433 Mtetra
.692 .726 .876 r
.45099 .45433 .46087 .46736 .47829 .46151 .46849 .44637 Mtetra
.75 .714 .819 r
.46849 .44637 .47829 .46151 .49585 .45078 .48614 .43369 Mtetra
.78 .701 .777 r
.48614 .43369 .49585 .45078 .51349 .43552 .50386 .41677 Mtetra
.797 .691 .748 r
.50386 .41677 .51349 .43552 .53113 .41633 .52157 .3963 Mtetra
.806 .684 .73 r
.52157 .3963 .53113 .41633 .54872 .39407 .53922 .37319 Mtetra
.811 .68 .718 r
.53922 .37319 .54872 .39407 .56621 .36969 .55678 .34839 Mtetra
.814 .678 .713 r
.55678 .34839 .56621 .36969 .58358 .34418 .57423 .32288 Mtetra
.57423 .32288 .58358 .34418 .60085 .31846 .59158 .2975 Mtetra
.812 .679 .718 r
.59158 .2975 .60085 .31846 .61802 .29332 .60885 .27298 Mtetra
.808 .683 .726 r
.60885 .27298 .61802 .29332 .63513 .26939 .62606 .24986 Mtetra
.803 .688 .738 r
.62606 .24986 .63513 .26939 .65222 .24711 .64325 .2285 Mtetra
.796 .694 .753 r
.64325 .2285 .65222 .24711 .66932 .22674 .66047 .20908 Mtetra
.786 .701 .77 r
.66047 .20908 .66932 .22674 .68647 .20838 .67775 .19165 Mtetra
.775 .708 .789 r
.67775 .19165 .68647 .20838 .70371 .192 .69511 .17612 Mtetra
.762 .715 .808 r
.69511 .17612 .70371 .192 .72107 .17746 .7126 .16234 Mtetra
.748 .721 .827 r
.7126 .16234 .72107 .17746 .73856 .16457 .73021 .1501 Mtetra
.734 .727 .844 r
.73021 .1501 .73856 .16457 .75619 .15311 .74797 .13915 Mtetra
.72 .731 .859 r
.74797 .13915 .75619 .15311 .77398 .14282 .76587 .12927 Mtetra
.626 .74 .929 r
.12392 .3447 .13445 .35407 .14876 .34993 .13825 .34067 Mtetra
.607 .738 .938 r
.13825 .34067 .14876 .34993 .16311 .34625 .15262 .33716 Mtetra
.58 .735 .949 r
.15262 .33716 .16311 .34625 .17747 .34319 .16699 .33434 Mtetra
.539 .727 .961 r
.16699 .33434 .17747 .34319 .19186 .34096 .18138 .3324 Mtetra
.478 .712 .973 r
.18138 .3324 .19186 .34096 .20624 .33976 .19576 .33159 Mtetra
.388 .682 .977 r
.19576 .33159 .20624 .33976 .22063 .33983 .21013 .33212 Mtetra
.256 .627 .96 r
.21013 .33212 .22063 .33983 .23501 .34141 .2245 .33422 Mtetra
.08 .532 .903 r
.2245 .33422 .23501 .34141 .24939 .34471 .23885 .33809 Mtetra
0 .399 .793 r
.23885 .33809 .24939 .34471 .26378 .34991 .25322 .34386 Mtetra
0 .249 .646 r
.25322 .34386 .26378 .34991 .27821 .35709 .26763 .35159 Mtetra
.459 0 0 r
.26763 .35159 .27821 .35709 .2927 .36622 .28211 .36119 Mtetra
.552 0 0 r
.28211 .36119 .2927 .36622 .3073 .37716 .29671 .37243 Mtetra
.604 .039 0 r
.29671 .37243 .3073 .37716 .32207 .38957 .31149 .38492 Mtetra
.62 .059 0 r
.31149 .38492 .32207 .38957 .33704 .40294 .32649 .39809 Mtetra
.603 .04 0 r
.32649 .39809 .33704 .40294 .35228 .41657 .34179 .41117 Mtetra
.54 0 0 r
.34179 .41117 .35228 .41657 .36785 .42964 .35742 .42331 Mtetra
.397 0 0 r
.35742 .42331 .36785 .42964 .38376 .44119 .37342 .43356 Mtetra
0 .373 .792 r
.37342 .43356 .38376 .44119 .40005 .45025 .38981 .44097 Mtetra
.213 .576 .941 r
.38981 .44097 .40005 .45025 .41671 .45593 .40657 .44472 Mtetra
.484 .678 .951 r
.40657 .44472 .41671 .45593 .4337 .45745 .42367 .44416 Mtetra
.636 .702 .894 r
.42367 .44416 .4337 .45745 .45099 .45433 .44106 .43892 Mtetra
.713 .699 .835 r
.44106 .43892 .45099 .45433 .46849 .44637 .45866 .42895 Mtetra
.755 .69 .789 r
.45866 .42895 .46849 .44637 .48614 .43369 .47639 .41452 Mtetra
.778 .682 .757 r
.47639 .41452 .48614 .43369 .50386 .41677 .49418 .39618 Mtetra
.792 .675 .735 r
.49418 .39618 .50386 .41677 .52157 .3963 .51196 .37473 Mtetra
.801 .671 .721 r
.51196 .37473 .52157 .3963 .53922 .37319 .52968 .35107 Mtetra
.805 .669 .714 r
.52968 .35107 .53922 .37319 .55678 .34839 .54731 .32617 Mtetra
.807 .669 .711 r
.54731 .32617 .55678 .34839 .57423 .32288 .56483 .30093 Mtetra
.807 .671 .714 r
.56483 .30093 .57423 .32288 .59158 .2975 .58226 .27614 Mtetra
.805 .675 .72 r
.58226 .27614 .59158 .2975 .60885 .27298 .59961 .25243 Mtetra
.801 .68 .73 r
.59961 .25243 .60885 .27298 .62606 .24986 .61693 .23027 Mtetra
.796 .686 .743 r
.61693 .23027 .62606 .24986 .64325 .2285 .63423 .20992 Mtetra
.788 .693 .759 r
.63423 .20992 .64325 .2285 .66047 .20908 .65157 .19152 Mtetra
.779 .7 .777 r
.65157 .19152 .66047 .20908 .67775 .19165 .66896 .17503 Mtetra
.767 .708 .797 r
.66896 .17503 .67775 .19165 .69511 .17612 .68645 .16037 Mtetra
.754 .715 .816 r
.68645 .16037 .69511 .17612 .7126 .16234 .70406 .14733 Mtetra
.74 .722 .834 r
.70406 .14733 .7126 .16234 .73021 .1501 .72179 .13569 Mtetra
.726 .727 .851 r
.72179 .13569 .73021 .1501 .74797 .13915 .73967 .12524 Mtetra
.713 .731 .865 r
.73967 .12524 .74797 .13915 .76587 .12927 .75769 .11573 Mtetra
.62 .739 .932 r
.11328 .33527 .12392 .3447 .13825 .34067 .12763 .33136 Mtetra
.599 .737 .941 r
.12763 .33136 .13825 .34067 .15262 .33716 .142 .32802 Mtetra
.568 .732 .952 r
.142 .32802 .15262 .33716 .16699 .33434 .15639 .32544 Mtetra
.522 .722 .964 r
.15639 .32544 .16699 .33434 .18138 .3324 .17077 .32381 Mtetra
.454 .703 .974 r
.17077 .32381 .18138 .3324 .19576 .33159 .18515 .32337 Mtetra
.354 .667 .974 r
.18515 .32337 .19576 .33159 .21013 .33212 .19951 .32433 Mtetra
.214 .603 .949 r
.19951 .32433 .21013 .33212 .2245 .33422 .21385 .32692 Mtetra
.034 .501 .882 r
.21385 .32692 .2245 .33422 .23885 .33809 .22819 .33129 Mtetra
0 .367 .769 r
.22819 .33129 .23885 .33809 .25322 .34386 .24254 .33755 Mtetra
0 .227 .631 r
.24254 .33755 .25322 .34386 .26763 .35159 .25693 .34569 Mtetra
.461 0 0 r
.25693 .34569 .26763 .35159 .28211 .36119 .27141 .35558 Mtetra
.539 0 0 r
.27141 .35558 .28211 .36119 .29671 .37243 .28602 .36693 Mtetra
.577 .012 0 r
.28602 .36693 .29671 .37243 .31149 .38492 .30082 .37926 Mtetra
.577 .014 0 r
.30082 .37926 .31149 .38492 .32649 .39809 .31587 .39196 Mtetra
.533 0 0 r
.31587 .39196 .32649 .39809 .34179 .41117 .33123 .40423 Mtetra
.423 0 0 r
.33123 .40423 .34179 .41117 .35742 .42331 .34695 .41518 Mtetra
0 .301 .741 r
.34695 .41518 .35742 .42331 .37342 .43356 .36304 .42389 Mtetra
.097 .495 .901 r
.36304 .42389 .37342 .43356 .38981 .44097 .37954 .42948 Mtetra
.385 .623 .947 r
.37954 .42948 .38981 .44097 .40657 .44472 .39641 .4312 Mtetra
.569 .672 .908 r
.39641 .4312 .40657 .44472 .42367 .44416 .41361 .42854 Mtetra
.67 .681 .851 r
.41361 .42854 .42367 .44416 .44106 .43892 .4311 .42126 Mtetra
.725 .677 .803 r
.4311 .42126 .44106 .43892 .45866 .42895 .44879 .40945 Mtetra
.757 .671 .767 r
.44879 .40945 .45866 .42895 .47639 .41452 .4666 .39349 Mtetra
.776 .666 .742 r
.4666 .39349 .47639 .41452 .49418 .39618 .48446 .37404 Mtetra
.788 .663 .725 r
.48446 .37404 .49418 .39618 .51196 .37473 .5023 .35191 Mtetra
.795 .661 .715 r
.5023 .35191 .51196 .37473 .52968 .35107 .52009 .32802 Mtetra
.799 .661 .711 r
.52009 .32802 .52968 .35107 .54731 .32617 .53778 .3033 Mtetra
.801 .663 .711 r
.53778 .3033 .54731 .32617 .56483 .30093 .55537 .27859 Mtetra
.801 .667 .715 r
.55537 .27859 .56483 .30093 .58226 .27614 .57288 .25459 Mtetra
.799 .672 .724 r
.57288 .25459 .58226 .27614 .59961 .25243 .59033 .23185 Mtetra
.795 .678 .735 r
.59033 .23185 .59961 .25243 .61693 .23027 .60774 .21075 Mtetra
.789 .685 .75 r
.60774 .21075 .61693 .23027 .63423 .20992 .62515 .19149 Mtetra
.781 .693 .767 r
.62515 .19149 .63423 .20992 .65157 .19152 .6426 .17412 Mtetra
.771 .701 .786 r
.6426 .17412 .65157 .19152 .66896 .17503 .66012 .15859 Mtetra
.759 .709 .805 r
.66012 .15859 .66896 .17503 .68645 .16037 .67773 .14476 Mtetra
.746 .716 .824 r
.67773 .14476 .68645 .16037 .70406 .14733 .69545 .13243 Mtetra
.732 .723 .842 r
.69545 .13243 .70406 .14733 .72179 .13569 .7133 .12137 Mtetra
.719 .728 .857 r
.7133 .12137 .72179 .13569 .73967 .12524 .73129 .11136 Mtetra
.707 .732 .87 r
.73129 .11136 .73967 .12524 .75769 .11573 .74943 .10219 Mtetra
.614 .738 .934 r
.10251 .32577 .11328 .33527 .12763 .33136 .11688 .32198 Mtetra
.59 .735 .944 r
.11688 .32198 .12763 .33136 .142 .32802 .13126 .31883 Mtetra
.555 .729 .955 r
.13126 .31883 .142 .32802 .15639 .32544 .14566 .31648 Mtetra
.504 .717 .967 r
.14566 .31648 .15639 .32544 .17077 .32381 .16004 .31515 Mtetra
.43 .694 .975 r
.16004 .31515 .17077 .32381 .18515 .32337 .1744 .31507 Mtetra
.323 .652 .97 r
.1744 .31507 .18515 .32337 .19951 .32433 .18875 .31643 Mtetra
.177 .58 .938 r
.18875 .31643 .19951 .32433 .21385 .32692 .20308 .31944 Mtetra
0 .474 .865 r
.20308 .31944 .21385 .32692 .22819 .33129 .2174 .32423 Mtetra
0 .345 .755 r
.2174 .32423 .22819 .33129 .24254 .33755 .23173 .33086 Mtetra
0 .218 .631 r
.23173 .33086 .24254 .33755 .25693 .34569 .24612 .33927 Mtetra
.447 0 0 r
.24612 .33927 .25693 .34569 .27141 .35558 .2606 .34927 Mtetra
.51 0 0 r
.2606 .34927 .27141 .35558 .28602 .36693 .27523 .3605 Mtetra
.531 0 0 r
.27523 .3605 .28602 .36693 .30082 .37926 .29007 .37244 Mtetra
.507 0 0 r
.29007 .37244 .30082 .37926 .31587 .39196 .30519 .38442 Mtetra
.424 0 0 r
.30519 .38442 .31587 .39196 .33123 .40423 .32062 .39562 Mtetra
0 .254 .708 r
.32062 .39562 .33123 .40423 .34695 .41518 .33643 .40516 Mtetra
.005 .425 .86 r
.33643 .40516 .34695 .41518 .36304 .42389 .35264 .41215 Mtetra
.287 .565 .933 r
.35264 .41215 .36304 .42389 .37954 .42948 .36925 .4158 Mtetra
.495 .636 .916 r
.36925 .4158 .37954 .42948 .39641 .4312 .38623 .41546 Mtetra
.619 .659 .866 r
.38623 .41546 .39641 .4312 .41361 .42854 .40354 .41075 Mtetra
.69 .662 .817 r
.40354 .41075 .41361 .42854 .4311 .42126 .42113 .40157 Mtetra
.732 .66 .779 r
.42113 .40157 .4311 .42126 .44879 .40945 .4389 .38813 Mtetra
.757 .657 .751 r
.4389 .38813 .44879 .40945 .4666 .39349 .45678 .37092 Mtetra
.773 .654 .731 r
.45678 .37092 .4666 .39349 .48446 .37404 .47471 .35064 Mtetra
.783 .653 .719 r
.47471 .35064 .48446 .37404 .5023 .35191 .49261 .32815 Mtetra
.79 .654 .712 r
.49261 .32815 .5023 .35191 .52009 .32802 .51045 .30433 Mtetra
.794 .656 .71 r
.51045 .30433 .52009 .32802 .53778 .3033 .52821 .28005 Mtetra
.795 .659 .713 r
.52821 .28005 .53778 .3033 .55537 .27859 .54587 .25608 Mtetra
.794 .664 .719 r
.54587 .25608 .55537 .27859 .57288 .25459 .56346 .23305 Mtetra
.792 .67 .729 r
.56346 .23305 .57288 .25459 .59033 .23185 .58099 .2114 Mtetra
.788 .677 .742 r
.58099 .2114 .59033 .23185 .60774 .21075 .5985 .19143 Mtetra
.781 .685 .758 r
.5985 .19143 .60774 .21075 .62515 .19149 .61602 .17328 Mtetra
.773 .694 .776 r
.61602 .17328 .62515 .19149 .6426 .17412 .63358 .15695 Mtetra
.763 .702 .795 r
.63358 .15695 .6426 .17412 .66012 .15859 .65121 .14236 Mtetra
.751 .711 .814 r
.65121 .14236 .66012 .15859 .67773 .14476 .66894 .12932 Mtetra
.738 .718 .833 r
.66894 .12932 .67773 .14476 .69545 .13243 .68678 .11765 Mtetra
.725 .724 .849 r
.68678 .11765 .69545 .13243 .7133 .12137 .70474 .10712 Mtetra
.712 .729 .864 r
.70474 .10712 .7133 .12137 .73129 .11136 .72284 .09752 Mtetra
.701 .733 .875 r
.72284 .09752 .73129 .11136 .74943 .10219 .74108 .08864 Mtetra
.608 .737 .937 r
.09162 .31619 .10251 .32577 .11688 .32198 .106 .31254 Mtetra
.581 .733 .947 r
.106 .31254 .11688 .32198 .13126 .31883 .1204 .30956 Mtetra
.543 .725 .958 r
.1204 .30956 .13126 .31883 .14566 .31648 .1348 .30745 Mtetra
.487 .71 .969 r
.1348 .30745 .14566 .31648 .16004 .31515 .14918 .3064 Mtetra
.407 .683 .974 r
.14918 .3064 .16004 .31515 .1744 .31507 .16353 .30664 Mtetra
.295 .636 .965 r
.16353 .30664 .1744 .31507 .18875 .31643 .17787 .30836 Mtetra
.148 .561 .928 r
.17787 .30836 .18875 .31643 .20308 .31944 .19218 .31172 Mtetra
0 .455 .854 r
.19218 .31172 .20308 .31944 .2174 .32423 .20649 .31683 Mtetra
0 .335 .752 r
.20649 .31683 .2174 .32423 .23173 .33086 .22082 .3237 Mtetra
0 .223 .646 r
.22082 .3237 .23173 .33086 .24612 .33927 .23521 .33221 Mtetra
.417 0 0 r
.23521 .33221 .24612 .33927 .2606 .34927 .24971 .34212 Mtetra
.462 0 0 r
.24971 .34212 .2606 .34927 .27523 .3605 .26438 .35302 Mtetra
.46 0 0 r
.26438 .35302 .27523 .3605 .29007 .37244 .27927 .36434 Mtetra
0 .135 .585 r
.27927 .36434 .29007 .37244 .30519 .38442 .29446 .37536 Mtetra
0 .232 .696 r
.29446 .37536 .30519 .38442 .32062 .39562 .30999 .38527 Mtetra
0 .373 .827 r
.30999 .38527 .32062 .39562 .33643 .40516 .32591 .39321 Mtetra
.198 .509 .912 r
.32591 .39321 .33643 .40516 .35264 .41215 .34223 .39836 Mtetra
.418 .596 .918 r
.34223 .39836 .35264 .41215 .36925 .4158 .35895 .40001 Mtetra
.563 .633 .879 r
.35895 .40001 .36925 .4158 .38623 .41546 .37605 .39763 Mtetra
.65 .645 .832 r
.37605 .39763 .38623 .41546 .40354 .41075 .39347 .39099 Mtetra
.703 .647 .791 r
.39347 .39099 .40354 .41075 .42113 .40157 .41115 .3801 Mtetra
.735 .647 .761 r
.41115 .3801 .42113 .40157 .4389 .38813 .429 .36529 Mtetra
.756 .645 .739 r
.429 .36529 .4389 .38813 .45678 .37092 .44695 .34711 Mtetra
.77 .645 .724 r
.44695 .34711 .45678 .37092 .47471 .35064 .46493 .32632 Mtetra
.779 .646 .715 r
.46493 .32632 .47471 .35064 .49261 .32815 .48289 .30376 Mtetra
.785 .648 .711 r
.48289 .30376 .49261 .32815 .51045 .30433 .50079 .28027 Mtetra
.788 .652 .712 r
.50079 .28027 .51045 .30433 .52821 .28005 .5186 .25667 Mtetra
.789 .656 .716 r
.5186 .25667 .52821 .28005 .54587 .25608 .53633 .23362 Mtetra
.788 .662 .724 r
.53633 .23362 .54587 .25608 .56346 .23305 .55399 .21167 Mtetra
.785 .669 .736 r
.55399 .21167 .56346 .23305 .58099 .2114 .57161 .19119 Mtetra
.781 .678 .75 r
.57161 .19119 .58099 .2114 .5985 .19143 .58921 .1724 Mtetra
.774 .686 .767 r
.58921 .1724 .5985 .19143 .61602 .17328 .60683 .15536 Mtetra
.765 .696 .785 r
.60683 .15536 .61602 .17328 .63358 .15695 .6245 .14005 Mtetra
.754 .704 .805 r
.6245 .14005 .63358 .15695 .65121 .14236 .64224 .12635 Mtetra
.742 .713 .824 r
.64224 .12635 .65121 .14236 .66894 .12932 .66007 .11406 Mtetra
.73 .72 .841 r
.66007 .11406 .66894 .12932 .68678 .11765 .67803 .103 Mtetra
.717 .726 .857 r
.67803 .103 .68678 .11765 .70474 .10712 .6961 .09295 Mtetra
.706 .73 .87 r
.6961 .09295 .70474 .10712 .72284 .09752 .71431 .0837 Mtetra
.695 .734 .88 r
.71431 .0837 .72284 .09752 .74108 .08864 .73265 .07507 Mtetra
.601 .736 .939 r
.0806 .30654 .09162 .31619 .106 .31254 .09501 .30301 Mtetra
.572 .73 .949 r
.09501 .30301 .106 .31254 .1204 .30956 .10941 .30021 Mtetra
.531 .721 .961 r
.10941 .30021 .1204 .30956 .1348 .30745 .12381 .29832 Mtetra
.471 .704 .97 r
.12381 .29832 .1348 .30745 .14918 .3064 .13819 .29753 Mtetra
.387 .673 .973 r
.13819 .29753 .14918 .3064 .16353 .30664 .15254 .29805 Mtetra
.272 .622 .96 r
.15254 .29805 .16353 .30664 .17787 .30836 .16686 .30006 Mtetra
.128 .545 .92 r
.16686 .30006 .17787 .30836 .19218 .31172 .18117 .30369 Mtetra
0 .445 .85 r
.18117 .30369 .19218 .31172 .20649 .31683 .19547 .30901 Mtetra
0 .336 .76 r
.19547 .30901 .20649 .31683 .22082 .3237 .20981 .31597 Mtetra
0 .241 .674 r
.20981 .31597 .22082 .3237 .23521 .33221 .22421 .32442 Mtetra
0 .176 .615 r
.22421 .32442 .23521 .33221 .24971 .34212 .23875 .33405 Mtetra
0 .15 .596 r
.23875 .33405 .24971 .34212 .26438 .35302 .25347 .3444 Mtetra
0 .167 .625 r
.25347 .3444 .26438 .35302 .27927 .36434 .26843 .35486 Mtetra
0 .233 .702 r
.26843 .35486 .27927 .36434 .29446 .37536 .28371 .36471 Mtetra
0 .342 .806 r
.28371 .36471 .29446 .37536 .30999 .38527 .29935 .37315 Mtetra
.128 .463 .89 r
.29935 .37315 .30999 .38527 .32591 .39321 .31538 .37936 Mtetra
.343 .556 .914 r
.31538 .37936 .32591 .39321 .34223 .39836 .33183 .3826 Mtetra
.503 .606 .888 r
.33183 .3826 .34223 .39836 .35895 .40001 .34867 .38225 Mtetra
.606 .627 .845 r
.34867 .38225 .35895 .40001 .37605 .39763 .36588 .37794 Mtetra
.67 .634 .805 r
.36588 .37794 .37605 .39763 .39347 .39099 .3834 .36952 Mtetra
.711 .636 .772 r
.3834 .36952 .39347 .39099 .41115 .3801 .40116 .35715 Mtetra
.737 .637 .747 r
.40116 .35715 .41115 .3801 .429 .36529 .41909 .34124 Mtetra
.755 .637 .73 r
.41909 .34124 .429 .36529 .44695 .34711 .4371 .3224 Mtetra
.767 .639 .719 r
.4371 .3224 .44695 .34711 .46493 .32632 .45513 .3014 Mtetra
.775 .641 .713 r
.45513 .3014 .46493 .32632 .48289 .30376 .47314 .27903 Mtetra
.78 .644 .712 r
.47314 .27903 .48289 .30376 .50079 .28027 .49108 .25612 Mtetra
.783 .649 .715 r
.49108 .25612 .50079 .28027 .5186 .25667 .50895 .23337 Mtetra
.784 .655 .721 r
.50895 .23337 .5186 .25667 .53633 .23362 .52674 .21139 Mtetra
.782 .662 .731 r
.52674 .21139 .53633 .23362 .55399 .21167 .54447 .19061 Mtetra
.779 .67 .744 r
.54447 .19061 .55399 .21167 .57161 .19119 .56217 .17134 Mtetra
.774 .679 .759 r
.56217 .17134 .57161 .19119 .58921 .1724 .57986 .15372 Mtetra
.766 .689 .777 r
.57986 .15372 .58921 .1724 .60683 .15536 .59758 .13778 Mtetra
.757 .698 .796 r
.59758 .13778 .60683 .15536 .6245 .14005 .61535 .12344 Mtetra
.746 .707 .815 r
.61535 .12344 .6245 .14005 .64224 .12635 .63319 .11057 Mtetra
.734 .715 .833 r
.63319 .11057 .64224 .12635 .66007 .11406 .65114 .09898 Mtetra
.722 .722 .849 r
.65114 .09898 .66007 .11406 .67803 .103 .6692 .08847 Mtetra
.71 .727 .864 r
.6692 .08847 .67803 .103 .6961 .09295 .68738 .07884 Mtetra
.699 .731 .875 r
.68738 .07884 .6961 .09295 .71431 .0837 .70569 .06989 Mtetra
.69 .734 .885 r
.70569 .06989 .71431 .0837 .73265 .07507 .72413 .06147 Mtetra
.595 .734 .941 r
.06946 .29679 .0806 .30654 .09501 .30301 .08388 .29339 Mtetra
.563 .728 .952 r
.08388 .29339 .09501 .30301 .10941 .30021 .0983 .29076 Mtetra
.519 .717 .962 r
.0983 .29076 .10941 .30021 .12381 .29832 .1127 .28906 Mtetra
.456 .697 .971 r
.1127 .28906 .12381 .29832 .13819 .29753 .12708 .2885 Mtetra
.37 .664 .971 r
.12708 .2885 .13819 .29753 .15254 .29805 .14143 .28925 Mtetra
.257 .611 .956 r
.14143 .28925 .15254 .29805 .16686 .30006 .15574 .29148 Mtetra
.12 .535 .916 r
.15574 .29148 .16686 .30006 .18117 .30369 .17005 .29528 Mtetra
0 .442 .853 r
.17005 .29528 .18117 .30369 .19547 .30901 .18436 .30068 Mtetra
0 .348 .778 r
.18436 .30068 .19547 .30901 .20981 .31597 .19871 .30759 Mtetra
0 .271 .713 r
.19871 .30759 .20981 .31597 .22421 .32442 .21315 .3158 Mtetra
0 .225 .677 r
.21315 .3158 .22421 .32442 .23875 .33405 .22773 .32495 Mtetra
0 .218 .68 r
.22773 .32495 .23875 .33405 .25347 .3444 .24251 .33455 Mtetra
0 .254 .725 r
.24251 .33455 .25347 .3444 .26843 .35486 .25757 .34396 Mtetra
0 .331 .8 r
.25757 .34396 .26843 .35486 .28371 .36471 .27295 .35247 Mtetra
.08 .431 .873 r
.27295 .35247 .28371 .36471 .29935 .37315 .28871 .3593 Mtetra
.279 .52 .906 r
.28871 .3593 .29935 .37315 .31538 .37936 .30487 .3637 Mtetra
.444 .578 .893 r
.30487 .3637 .31538 .37936 .33183 .3826 .32144 .36501 Mtetra
.559 .607 .858 r
.32144 .36501 .33183 .3826 .34867 .38225 .33841 .36273 Mtetra
.635 .62 .818 r
.33841 .36273 .34867 .38225 .36588 .37794 .35573 .35662 Mtetra
.684 .625 .784 r
.35573 .35662 .36588 .37794 .3834 .36952 .37334 .34664 Mtetra
.716 .628 .758 r
.37334 .34664 .3834 .36952 .40116 .35715 .39118 .33305 Mtetra
.738 .63 .738 r
.39118 .33305 .40116 .35715 .41909 .34124 .40917 .31633 Mtetra
.754 .632 .725 r
.40917 .31633 .41909 .34124 .4371 .3224 .42723 .29712 Mtetra
.764 .634 .717 r
.42723 .29712 .4371 .3224 .45513 .3014 .4453 .27616 Mtetra
.771 .638 .714 r
.4453 .27616 .45513 .3014 .47314 .27903 .46335 .25425 Mtetra
.776 .643 .715 r
.46335 .25425 .47314 .27903 .49108 .25612 .48133 .2321 Mtetra
.778 .648 .719 r
.48133 .2321 .49108 .25612 .50895 .23337 .49925 .21035 Mtetra
.778 .655 .727 r
.49925 .21035 .50895 .23337 .52674 .21139 .51709 .18952 Mtetra
.776 .663 .739 r
.51709 .18952 .52674 .21139 .54447 .19061 .53489 .16997 Mtetra
.772 .672 .753 r
.53489 .16997 .54447 .19061 .56217 .17134 .55267 .15191 Mtetra
.766 .682 .77 r
.55267 .15191 .56217 .17134 .57986 .15372 .57045 .13545 Mtetra
.758 .692 .788 r
.57045 .13545 .57986 .15372 .59758 .13778 .58826 .12055 Mtetra
.749 .701 .806 r
.58826 .12055 .59758 .13778 .61535 .12344 .60613 .10713 Mtetra
.738 .71 .825 r
.60613 .10713 .61535 .12344 .63319 .11057 .62407 .09502 Mtetra
.726 .717 .842 r
.62407 .09502 .63319 .11057 .65114 .09898 .64212 .08406 Mtetra
.714 .724 .857 r
.64212 .08406 .65114 .09898 .6692 .08847 .66028 .07403 Mtetra
.704 .729 .87 r
.66028 .07403 .6692 .08847 .68738 .07884 .67857 .06477 Mtetra
.694 .733 .88 r
.67857 .06477 .68738 .07884 .70569 .06989 .69698 .05608 Mtetra
.686 .735 .888 r
.69698 .05608 .70569 .06989 .72413 .06147 .71552 .04783 Mtetra
.588 .732 .943 r
.0582 .28694 .06946 .29679 .08388 .29339 .07263 .28367 Mtetra
.555 .725 .953 r
.07263 .28367 .08388 .29339 .0983 .29076 .08706 .28117 Mtetra
.509 .712 .963 r
.08706 .28117 .0983 .29076 .1127 .28906 .10147 .27965 Mtetra
.444 .691 .97 r
.10147 .27965 .1127 .28906 .12708 .2885 .11585 .27927 Mtetra
.358 .656 .969 r
.11585 .27927 .12708 .2885 .14143 .28925 .13019 .2802 Mtetra
.249 .603 .953 r
.13019 .2802 .14143 .28925 .15574 .29148 .14452 .28256 Mtetra
.122 .531 .916 r
.14452 .28256 .15574 .29148 .17005 .29528 .15883 .28643 Mtetra
0 .449 .862 r
.15883 .28643 .17005 .29528 .18436 .30068 .17315 .29178 Mtetra
0 .37 .804 r
.17315 .29178 .18436 .30068 .19871 .30759 .18753 .29848 Mtetra
0 .31 .759 r
.18753 .29848 .19871 .30759 .21315 .3158 .20202 .30627 Mtetra
0 .283 .743 r
.20202 .30627 .21315 .3158 .22773 .32495 .21666 .31477 Mtetra
0 .293 .761 r
.21666 .31477 .22773 .32495 .24251 .33455 .23154 .32343 Mtetra
0 .341 .808 r
.23154 .32343 .24251 .33455 .25757 .34396 .24669 .33163 Mtetra
.057 .415 .864 r
.24669 .33163 .25757 .34396 .27295 .35247 .26219 .33866 Mtetra
.229 .493 .898 r
.26219 .33866 .27295 .35247 .28871 .3593 .27808 .34379 Mtetra
.389 .552 .896 r
.27808 .34379 .28871 .3593 .30487 .3637 .29437 .34635 Mtetra
.512 .588 .868 r
.29437 .34635 .30487 .3637 .32144 .36501 .31107 .34578 Mtetra
.597 .606 .831 r
.31107 .34578 .32144 .36501 .33841 .36273 .32816 .3417 Mtetra
.655 .615 .797 r
.32816 .3417 .33841 .36273 .35573 .35662 .34558 .33396 Mtetra
.693 .619 .769 r
.34558 .33396 .35573 .35662 .37334 .34664 .36328 .32266 Mtetra
.72 .622 .748 r
.36328 .32266 .37334 .34664 .39118 .33305 .38119 .30812 Mtetra
.739 .625 .732 r
.38119 .30812 .39118 .33305 .40917 .31633 .39923 .29087 Mtetra
.752 .628 .722 r
.39923 .29087 .40917 .31633 .42723 .29712 .41733 .27155 Mtetra
.761 .632 .717 r
.41733 .27155 .42723 .29712 .4453 .27616 .43544 .2509 Mtetra
.767 .636 .716 r
.43544 .2509 .4453 .27616 .46335 .25425 .45352 .22963 Mtetra
.771 .642 .719 r
.45352 .22963 .46335 .25425 .48133 .2321 .47154 .2084 Mtetra
.773 .649 .726 r
.47154 .2084 .48133 .2321 .49925 .21035 .4895 .18776 Mtetra
.772 .657 .735 r
.4895 .18776 .49925 .21035 .51709 .18952 .5074 .16814 Mtetra
.77 .666 .748 r
.5074 .16814 .51709 .18952 .53489 .16997 .52526 .14982 Mtetra
.765 .675 .763 r
.52526 .14982 .53489 .16997 .55267 .15191 .54311 .13296 Mtetra
.759 .685 .781 r
.54311 .13296 .55267 .15191 .57045 .13545 .56097 .11759 Mtetra
.75 .695 .799 r
.56097 .11759 .57045 .13545 .58826 .12055 .57887 .10368 Mtetra
.741 .704 .817 r
.57887 .10368 .58826 .12055 .60613 .10713 .59683 .0911 Mtetra
.73 .713 .835 r
.59683 .0911 .60613 .10713 .62407 .09502 .61488 .07969 Mtetra
.718 .72 .851 r
.61488 .07969 .62407 .09502 .64212 .08406 .63302 .06928 Mtetra
.707 .726 .865 r
.63302 .06928 .64212 .08406 .66028 .07403 .65129 .05968 Mtetra
.697 .73 .876 r
.65129 .05968 .66028 .07403 .67857 .06477 .66967 .05072 Mtetra
.689 .734 .885 r
.66967 .05072 .67857 .06477 .69698 .05608 .68818 .04224 Mtetra
.682 .736 .892 r
.68818 .04224 .69698 .05608 .71552 .04783 .70682 .03413 Mtetra
.582 .73 .945 r
.04681 .27699 .0582 .28694 .07263 .28367 .06126 .27381 Mtetra
.548 .722 .954 r
.06126 .27381 .07263 .28367 .08706 .28117 .0757 .27144 Mtetra
.5 .708 .964 r
.0757 .27144 .08706 .28117 .10147 .27965 .09011 .27005 Mtetra
.435 .685 .969 r
.09011 .27005 .10147 .27965 .11585 .27927 .1045 .26981 Mtetra
.351 .649 .967 r
.1045 .26981 .11585 .27927 .13019 .2802 .11885 .27084 Mtetra
.249 .598 .951 r
.11885 .27084 .13019 .2802 .14452 .28256 .13318 .27326 Mtetra
.136 .533 .919 r
.13318 .27326 .14452 .28256 .15883 .28643 .14751 .27708 Mtetra
.028 .462 .876 r
.14751 .27708 .15883 .28643 .17315 .29178 .16187 .28225 Mtetra
0 .399 .834 r
.16187 .28225 .17315 .29178 .18753 .29848 .1763 .28859 Mtetra
0 .357 .807 r
.1763 .28859 .18753 .29848 .20202 .30627 .19084 .2958 Mtetra
0 .345 .804 r
.19084 .2958 .20202 .30627 .21666 .31477 .20557 .30347 Mtetra
0 .367 .828 r
.20557 .30347 .21666 .31477 .23154 .32343 .22054 .31105 Mtetra
.057 .416 .864 r
.22054 .31105 .23154 .32343 .24669 .33163 .23581 .3179 Mtetra
.198 .477 .892 r
.23581 .3179 .24669 .33163 .26219 .33866 .25144 .32336 Mtetra
.343 .532 .896 r
.25144 .32336 .26219 .33866 .27808 .34379 .26746 .32676 Mtetra
.466 .57 .876 r
.26746 .32676 .27808 .34379 .29437 .34635 .28389 .3275 Mtetra
.558 .592 .844 r
.28389 .3275 .29437 .34635 .31107 .34578 .30072 .32514 Mtetra
.623 .604 .81 r
.30072 .32514 .31107 .34578 .32816 .3417 .31792 .31941 Mtetra
.669 .611 .781 r
.31792 .31941 .32816 .3417 .34558 .33396 .33544 .31027 Mtetra
.7 .615 .758 r
.33544 .31027 .34558 .33396 .36328 .32266 .35322 .2979 Mtetra
.722 .618 .741 r
.35322 .2979 .36328 .32266 .38119 .30812 .37119 .28268 Mtetra
.738 .622 .729 r
.37119 .28268 .38119 .30812 .39923 .29087 .38927 .26516 Mtetra
.75 .626 .722 r
.38927 .26516 .39923 .29087 .41733 .27155 .4074 .24599 Mtetra
.758 .631 .719 r
.4074 .24599 .41733 .27155 .43544 .2509 .42554 .22585 Mtetra
.763 .636 .721 r
.42554 .22585 .43544 .2509 .45352 .22963 .44364 .20539 Mtetra
.766 .643 .725 r
.44364 .20539 .45352 .22963 .47154 .2084 .46169 .18518 Mtetra
.767 .651 .733 r
.46169 .18518 .47154 .2084 .4895 .18776 .47969 .16571 Mtetra
.766 .66 .745 r
.47969 .16571 .4895 .18776 .5074 .16814 .49763 .14731 Mtetra
.763 .669 .758 r
.49763 .14731 .5074 .16814 .52526 .14982 .51556 .13021 Mtetra
.758 .679 .775 r
.51556 .13021 .52526 .14982 .54311 .13296 .53347 .11449 Mtetra
.751 .689 .792 r
.53347 .11449 .54311 .13296 .56097 .11759 .55141 .10017 Mtetra
.742 .699 .81 r
.55141 .10017 .56097 .11759 .57887 .10368 .5694 .08716 Mtetra
.732 .708 .828 r
.5694 .08716 .57887 .10368 .59683 .0911 .58745 .07535 Mtetra
.722 .716 .844 r
.58745 .07535 .59683 .0911 .61488 .07969 .60559 .06456 Mtetra
.711 .723 .859 r
.60559 .06456 .61488 .07969 .63302 .06928 .62384 .05462 Mtetra
.701 .728 .871 r
.62384 .05462 .63302 .06928 .65129 .05968 .64219 .04538 Mtetra
.692 .732 .881 r
.64219 .04538 .65129 .05968 .66967 .05072 .66067 .03668 Mtetra
.684 .735 .889 r
.66067 .03668 .66967 .05072 .68818 .04224 .67928 .02837 Mtetra
.678 .737 .895 r
.67928 .02837 .68818 .04224 .70682 .03413 .69802 .02034 Mtetra
.577 .728 .946 r
.0353 .26691 .04681 .27699 .06126 .27381 .04976 .26381 Mtetra
.541 .719 .955 r
.04976 .26381 .06126 .27381 .0757 .27144 .06421 .26154 Mtetra
.493 .704 .964 r
.06421 .26154 .0757 .27144 .09011 .27005 .07864 .26025 Mtetra
.43 .68 .968 r
.07864 .26025 .09011 .27005 .1045 .26981 .09303 .26008 Mtetra
.35 .645 .965 r
.09303 .26008 .1045 .26981 .11885 .27084 .1074 .26114 Mtetra
.257 .597 .951 r
.1074 .26114 .11885 .27084 .13318 .27326 .12176 .26351 Mtetra
.159 .54 .925 r
.12176 .26351 .13318 .27326 .14751 .27708 .13612 .26718 Mtetra
.072 .481 .892 r
.13612 .26718 .14751 .27708 .16187 .28225 .15052 .27203 Mtetra
.009 .433 .864 r
.15052 .27203 .16187 .28225 .1763 .28859 .165 .27787 Mtetra
0 .406 .849 r
.165 .27787 .1763 .28859 .19084 .2958 .17963 .28436 Mtetra
.008 .405 .854 r
.17963 .28436 .19084 .2958 .20557 .30347 .19445 .29106 Mtetra
.078 .431 .873 r
.19445 .29106 .20557 .30347 .22054 .31105 .20954 .29742 Mtetra
.186 .474 .892 r
.20954 .29742 .22054 .31105 .23581 .3179 .22494 .30284 Mtetra
.31 .519 .897 r
.22494 .30284 .23581 .3179 .25144 .32336 .24071 .30669 Mtetra
.427 .556 .882 r
.24071 .30669 .25144 .32336 .26746 .32676 .25687 .30836 Mtetra
.521 .58 .855 r
.25687 .30836 .26746 .32676 .28389 .3275 .27343 .30737 Mtetra
.592 .594 .824 r
.27343 .30737 .28389 .3275 .30072 .32514 .29038 .30336 Mtetra
.642 .603 .794 r
.29038 .30336 .30072 .32514 .31792 .31941 .30769 .29617 Mtetra
.679 .608 .77 r
.30769 .29617 .31792 .31941 .33544 .31027 .3253 .28586 Mtetra
.705 .613 .751 r
.3253 .28586 .33544 .31027 .35322 .2979 .34315 .27267 Mtetra
.724 .617 .737 r
.34315 .27267 .35322 .2979 .37119 .28268 .36116 .25703 Mtetra
.738 .621 .729 r
.36116 .25703 .37119 .28268 .38927 .26516 .37927 .2395 Mtetra
.748 .626 .724 r
.37927 .2395 .38927 .26516 .4074 .24599 .39743 .22068 Mtetra
.755 .631 .723 r
.39743 .22068 .4074 .24599 .42554 .22585 .41558 .20121 Mtetra
.759 .638 .726 r
.41558 .20121 .42554 .22585 .44364 .20539 .4337 .18168 Mtetra
.762 .645 .733 r
.4337 .18168 .44364 .20539 .46169 .18518 .45178 .16257 Mtetra
.762 .654 .743 r
.45178 .16257 .46169 .18518 .47969 .16571 .46981 .14429 Mtetra
.76 .663 .755 r
.46981 .14429 .47969 .16571 .49763 .14731 .4878 .1271 Mtetra
.756 .673 .77 r
.4878 .1271 .49763 .14731 .51556 .13021 .50578 .11116 Mtetra
.751 .684 .786 r
.50578 .11116 .51556 .13021 .53347 .11449 .52376 .09653 Mtetra
.743 .694 .804 r
.52376 .09653 .53347 .11449 .55141 .10017 .54178 .08316 Mtetra
.734 .703 .822 r
.54178 .08316 .55141 .10017 .5694 .08716 .55984 .07098 Mtetra
.724 .712 .838 r
.55984 .07098 .5694 .08716 .58745 .07535 .57798 .05983 Mtetra
.714 .719 .853 r
.57798 .05983 .58745 .07535 .60559 .06456 .59622 .04958 Mtetra
.704 .725 .867 r
.59622 .04958 .60559 .06456 .62384 .05462 .61456 .04006 Mtetra
.695 .73 .877 r
.61456 .04006 .62384 .05462 .64219 .04538 .63301 .03112 Mtetra
.687 .733 .886 r
.63301 .03112 .64219 .04538 .66067 .03668 .65158 .02261 Mtetra
.68 .736 .893 r
.65158 .02261 .66067 .03668 .67928 .02837 .67028 .01443 Mtetra
.675 .738 .897 r
.67028 .01443 .67928 .02837 .69802 .02034 .68911 .00647 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.661 .742 .91 r
.39729 .59647 .40512 .60371 .41826 .59983 .41047 .59257 Mtetra
.66 .742 .911 r
.41047 .59257 .41826 .59983 .43146 .59595 .42371 .58869 Mtetra
.659 .743 .912 r
.42371 .58869 .43146 .59595 .44473 .59208 .43702 .58482 Mtetra
.658 .744 .913 r
.43702 .58482 .44473 .59208 .45806 .58823 .45039 .58099 Mtetra
.656 .744 .915 r
.45039 .58099 .45806 .58823 .47146 .58441 .46383 .57721 Mtetra
.653 .746 .918 r
.46383 .57721 .47146 .58441 .48493 .58064 .47734 .57348 Mtetra
.65 .747 .921 r
.47734 .57348 .48493 .58064 .49846 .57691 .49092 .56983 Mtetra
.646 .749 .924 r
.49092 .56983 .49846 .57691 .51207 .57326 .50457 .56628 Mtetra
.642 .752 .929 r
.50457 .56628 .51207 .57326 .52574 .56968 .51829 .56283 Mtetra
.636 .755 .934 r
.51829 .56283 .52574 .56968 .53949 .5662 .53208 .55951 Mtetra
.63 .759 .94 r
.53208 .55951 .53949 .5662 .55332 .56282 .54595 .55633 Mtetra
.622 .763 .947 r
.54595 .55633 .55332 .56282 .56722 .55955 .55991 .55329 Mtetra
.614 .769 .954 r
.55991 .55329 .56722 .55955 .5812 .55639 .57394 .55039 Mtetra
.604 .775 .962 r
.57394 .55039 .5812 .55639 .59526 .55334 .58806 .54763 Mtetra
.594 .782 .97 r
.58806 .54763 .59526 .55334 .60941 .55039 .60227 .545 Mtetra
.583 .789 .978 r
.60227 .545 .60941 .55039 .62364 .54752 .61657 .54246 Mtetra
.571 .797 .985 r
.61657 .54246 .62364 .54752 .63796 .54471 .63096 .53998 Mtetra
.56 .806 .991 r
.63096 .53998 .63796 .54471 .65236 .54191 .64544 .53751 Mtetra
.551 .815 .995 r
.64544 .53751 .65236 .54191 .66685 .53909 .66001 .53501 Mtetra
.544 .824 .998 r
.66001 .53501 .66685 .53909 .68143 .5362 .67466 .53241 Mtetra
.54 .833 .999 r
.67466 .53241 .68143 .5362 .69609 .53319 .6894 .52964 Mtetra
.541 .843 .999 r
.6894 .52964 .69609 .53319 .71082 .53001 .70422 .52666 Mtetra
.547 .852 .998 r
.70422 .52666 .71082 .53001 .72564 .52662 .71912 .52339 Mtetra
.558 .862 .997 r
.71912 .52339 .72564 .52662 .74052 .52296 .73408 .51979 Mtetra
.573 .87 .995 r
.73408 .51979 .74052 .52296 .75547 .51902 .74911 .51582 Mtetra
.592 .877 .993 r
.74911 .51582 .75547 .51902 .77048 .51476 .76419 .51146 Mtetra
.612 .883 .99 r
.76419 .51146 .77048 .51476 .78555 .51018 .77933 .5067 Mtetra
.633 .885 .987 r
.77933 .5067 .78555 .51018 .80067 .50527 .79451 .50156 Mtetra
.652 .884 .982 r
.79451 .50156 .80067 .50527 .81584 .50007 .80975 .49605 Mtetra
.669 .881 .977 r
.80975 .49605 .81584 .50007 .83106 .49459 .82502 .49021 Mtetra
.683 .874 .971 r
.82502 .49021 .83106 .49459 .84634 .48887 .84034 .4841 Mtetra
.693 .866 .964 r
.84034 .4841 .84634 .48887 .86167 .48296 .85571 .47778 Mtetra
.7 .856 .957 r
.85571 .47778 .86167 .48296 .87705 .47692 .87114 .47131 Mtetra
.704 .845 .95 r
.87114 .47131 .87705 .47692 .8925 .47077 .88662 .46474 Mtetra
.706 .833 .943 r
.88662 .46474 .8925 .47077 .90801 .46459 .90217 .45814 Mtetra
.706 .822 .937 r
.90217 .45814 .90801 .46459 .9236 .4584 .91779 .45156 Mtetra
.704 .811 .931 r
.91779 .45156 .9236 .4584 .93926 .45225 .93349 .44505 Mtetra
.701 .8 .927 r
.93349 .44505 .93926 .45225 .95501 .44617 .94927 .43863 Mtetra
.698 .791 .922 r
.94927 .43863 .95501 .44617 .97084 .44017 .96514 .43234 Mtetra
.66 .742 .911 r
.38938 .58918 .39729 .59647 .41047 .59257 .4026 .58527 Mtetra
.659 .743 .912 r
.4026 .58527 .41047 .59257 .42371 .58869 .41588 .58139 Mtetra
.658 .743 .913 r
.41588 .58139 .42371 .58869 .43702 .58482 .42923 .57754 Mtetra
.655 .744 .915 r
.42923 .57754 .43702 .58482 .45039 .58099 .44264 .57375 Mtetra
.653 .745 .918 r
.44264 .57375 .45039 .58099 .46383 .57721 .45613 .57001 Mtetra
.649 .747 .921 r
.45613 .57001 .46383 .57721 .47734 .57348 .46968 .56637 Mtetra
.645 .749 .925 r
.46968 .56637 .47734 .57348 .49092 .56983 .4833 .56282 Mtetra
.64 .751 .929 r
.4833 .56282 .49092 .56983 .50457 .56628 .49699 .5594 Mtetra
.634 .754 .935 r
.49699 .5594 .50457 .56628 .51829 .56283 .51075 .55613 Mtetra
.626 .758 .941 r
.51075 .55613 .51829 .56283 .53208 .55951 .5246 .55302 Mtetra
.617 .763 .949 r
.5246 .55302 .53208 .55951 .54595 .55633 .53852 .55009 Mtetra
.607 .768 .957 r
.53852 .55009 .54595 .55633 .55991 .55329 .55253 .54734 Mtetra
.595 .774 .966 r
.55253 .54734 .55991 .55329 .57394 .55039 .56662 .54477 Mtetra
.581 .781 .975 r
.56662 .54477 .57394 .55039 .58806 .54763 .5808 .54237 Mtetra
.565 .788 .983 r
.5808 .54237 .58806 .54763 .60227 .545 .59507 .54012 Mtetra
.548 .796 .99 r
.59507 .54012 .60227 .545 .61657 .54246 .60944 .53798 Mtetra
.53 .804 .996 r
.60944 .53798 .61657 .54246 .63096 .53998 .6239 .53591 Mtetra
.513 .812 .999 r
.6239 .53591 .63096 .53998 .64544 .53751 .63846 .53384 Mtetra
.498 .82 1 r
.63846 .53384 .64544 .53751 .66001 .53501 .65311 .53171 Mtetra
.487 .828 .998 r
.65311 .53171 .66001 .53501 .67466 .53241 .66785 .52944 Mtetra
.482 .836 .995 r
.66785 .52944 .67466 .53241 .6894 .52964 .68268 .52695 Mtetra
.483 .846 .991 r
.68268 .52695 .6894 .52964 .70422 .52666 .69759 .52417 Mtetra
.492 .857 .988 r
.69759 .52417 .70422 .52666 .71912 .52339 .71257 .52103 Mtetra
.509 .869 .986 r
.71257 .52103 .71912 .52339 .73408 .51979 .72762 .51747 Mtetra
.533 .881 .986 r
.72762 .51747 .73408 .51979 .74911 .51582 .74273 .51345 Mtetra
.561 .892 .986 r
.74273 .51345 .74911 .51582 .76419 .51146 .75789 .50895 Mtetra
.591 .9 .985 r
.75789 .50895 .76419 .51146 .77933 .5067 .77309 .50396 Mtetra
.621 .905 .984 r
.77309 .50396 .77933 .5067 .79451 .50156 .78834 .4985 Mtetra
.648 .906 .982 r
.78834 .4985 .79451 .50156 .80975 .49605 .80363 .49262 Mtetra
.67 .902 .978 r
.80363 .49262 .80975 .49605 .82502 .49021 .81895 .48635 Mtetra
.688 .895 .972 r
.81895 .48635 .82502 .49021 .84034 .4841 .83432 .47978 Mtetra
.702 .885 .965 r
.83432 .47978 .84034 .4841 .85571 .47778 .84973 .47296 Mtetra
.71 .872 .958 r
.84973 .47296 .85571 .47778 .87114 .47131 .86519 .46599 Mtetra
.715 .859 .95 r
.86519 .46599 .87114 .47131 .88662 .46474 .88071 .45893 Mtetra
.716 .845 .943 r
.88071 .45893 .88662 .46474 .90217 .45814 .89629 .45186 Mtetra
.715 .832 .937 r
.89629 .45186 .90217 .45814 .91779 .45156 .91194 .44484 Mtetra
.713 .819 .931 r
.91194 .44484 .91779 .45156 .93349 .44505 .92767 .43792 Mtetra
.709 .807 .926 r
.92767 .43792 .93349 .44505 .94927 .43863 .94348 .43113 Mtetra
.704 .797 .922 r
.94348 .43113 .94927 .43863 .96514 .43234 .95939 .4245 Mtetra
.659 .743 .912 r
.3814 .58184 .38938 .58918 .4026 .58527 .39466 .57794 Mtetra
.658 .743 .913 r
.39466 .57794 .4026 .58527 .41588 .58139 .40798 .57407 Mtetra
.656 .744 .915 r
.40798 .57407 .41588 .58139 .42923 .57754 .42137 .57025 Mtetra
.653 .745 .917 r
.42137 .57025 .42923 .57754 .44264 .57375 .43482 .5665 Mtetra
.649 .746 .92 r
.43482 .5665 .44264 .57375 .45613 .57001 .44835 .56285 Mtetra
.645 .748 .924 r
.44835 .56285 .45613 .57001 .46968 .56637 .46194 .55931 Mtetra
.639 .751 .929 r
.46194 .55931 .46968 .56637 .4833 .56282 .4756 .5559 Mtetra
.632 .754 .935 r
.4756 .5559 .4833 .56282 .49699 .5594 .48934 .55267 Mtetra
.624 .757 .942 r
.48934 .55267 .49699 .5594 .51075 .55613 .50315 .54962 Mtetra
.613 .762 .95 r
.50315 .54962 .51075 .55613 .5246 .55302 .51704 .54677 Mtetra
.601 .767 .959 r
.51704 .54677 .5246 .55302 .53852 .55009 .53101 .54416 Mtetra
.586 .773 .969 r
.53101 .54416 .53852 .55009 .55253 .54734 .54507 .54177 Mtetra
.568 .779 .978 r
.54507 .54177 .55253 .54734 .56662 .54477 .55922 .5396 Mtetra
.547 .786 .987 r
.55922 .5396 .56662 .54477 .5808 .54237 .57346 .53764 Mtetra
.523 .792 .994 r
.57346 .53764 .5808 .54237 .59507 .54012 .5878 .53585 Mtetra
.497 .798 .999 r
.5878 .53585 .59507 .54012 .60944 .53798 .60224 .53419 Mtetra
.47 .803 .999 r
.60224 .53419 .60944 .53798 .6239 .53591 .61678 .5326 Mtetra
.443 .807 .995 r
.61678 .5326 .6239 .53591 .63846 .53384 .63142 .53099 Mtetra
.42 .81 .987 r
.63142 .53099 .63846 .53384 .65311 .53171 .64616 .52929 Mtetra
.403 .814 .977 r
.64616 .52929 .65311 .53171 .66785 .52944 .66099 .52739 Mtetra
.396 .82 .966 r
.66099 .52739 .66785 .52944 .68268 .52695 .67591 .52521 Mtetra
.399 .83 .957 r
.67591 .52521 .68268 .52695 .69759 .52417 .69091 .52264 Mtetra
.415 .843 .953 r
.69091 .52264 .69759 .52417 .71257 .52103 .70599 .51962 Mtetra
.441 .859 .952 r
.70599 .51962 .71257 .52103 .72762 .51747 .72112 .51608 Mtetra
.477 .878 .956 r
.72112 .51608 .72762 .51747 .74273 .51345 .73632 .51197 Mtetra
.519 .896 .962 r
.73632 .51197 .74273 .51345 .75789 .50895 .75155 .50727 Mtetra
.563 .911 .968 r
.75155 .50727 .75789 .50895 .77309 .50396 .76683 .50198 Mtetra
.605 .921 .973 r
.76683 .50198 .77309 .50396 .78834 .4985 .78214 .49614 Mtetra
.642 .925 .975 r
.78214 .49614 .78834 .4985 .80363 .49262 .79749 .48979 Mtetra
.673 .922 .973 r
.79749 .48979 .80363 .49262 .81895 .48635 .81286 .48301 Mtetra
.696 .915 .969 r
.81286 .48301 .81895 .48635 .83432 .47978 .82827 .47588 Mtetra
.712 .903 .964 r
.82827 .47588 .83432 .47978 .84973 .47296 .84372 .4685 Mtetra
.722 .889 .957 r
.84372 .4685 .84973 .47296 .86519 .46599 .85921 .46095 Mtetra
.727 .873 .949 r
.85921 .46095 .86519 .46599 .88071 .45893 .87475 .45333 Mtetra
.728 .857 .942 r
.87475 .45333 .88071 .45893 .89629 .45186 .89036 .44573 Mtetra
.726 .842 .936 r
.89036 .44573 .89629 .45186 .91194 .44484 .90604 .43821 Mtetra
.723 .827 .93 r
.90604 .43821 .91194 .44484 .92767 .43792 .9218 .43083 Mtetra
.717 .814 .925 r
.9218 .43083 .92767 .43792 .94348 .43113 .93764 .42364 Mtetra
.712 .802 .921 r
.93764 .42364 .94348 .43113 .95939 .4245 .95359 .41665 Mtetra
.658 .743 .913 r
.37335 .57446 .3814 .58184 .39466 .57794 .38664 .57057 Mtetra
.656 .744 .915 r
.38664 .57057 .39466 .57794 .40798 .57407 .4 .56673 Mtetra
.653 .745 .917 r
.4 .56673 .40798 .57407 .42137 .57025 .41343 .56296 Mtetra
.649 .746 .92 r
.41343 .56296 .42137 .57025 .43482 .5665 .42693 .55928 Mtetra
.645 .748 .924 r
.42693 .55928 .43482 .5665 .44835 .56285 .44049 .55573 Mtetra
.639 .75 .929 r
.44049 .55573 .44835 .56285 .46194 .55931 .45412 .55233 Mtetra
.631 .753 .935 r
.45412 .55233 .46194 .55931 .4756 .5559 .46782 .54911 Mtetra
.622 .756 .942 r
.46782 .54911 .4756 .5559 .48934 .55267 .4816 .5461 Mtetra
.61 .76 .951 r
.4816 .5461 .48934 .55267 .50315 .54962 .49546 .54333 Mtetra
.596 .765 .96 r
.49546 .54333 .50315 .54962 .51704 .54677 .5094 .54082 Mtetra
.578 .77 .97 r
.5094 .54082 .51704 .54677 .53101 .54416 .52342 .53859 Mtetra
.556 .776 .981 r
.52342 .53859 .53101 .54416 .54507 .54177 .53754 .53663 Mtetra
.529 .782 .99 r
.53754 .53663 .54507 .54177 .55922 .5396 .55174 .53495 Mtetra
.498 .786 .997 r
.55174 .53495 .55922 .5396 .57346 .53764 .56605 .53351 Mtetra
.461 .789 .999 r
.56605 .53351 .57346 .53764 .5878 .53585 .58046 .53228 Mtetra
.421 .788 .995 r
.58046 .53228 .5878 .53585 .60224 .53419 .59498 .53118 Mtetra
.379 .785 .983 r
.59498 .53118 .60224 .53419 .61678 .5326 .6096 .53014 Mtetra
.34 .779 .964 r
.6096 .53014 .61678 .5326 .63142 .53099 .62433 .52906 Mtetra
.307 .773 .941 r
.62433 .52906 .63142 .53099 .64616 .52929 .63916 .52783 Mtetra
.286 .77 .917 r
.63916 .52783 .64616 .52929 .66099 .52739 .65408 .52635 Mtetra
.278 .772 .897 r
.65408 .52635 .66099 .52739 .67591 .52521 .6691 .52449 Mtetra
.288 .782 .884 r
.6691 .52449 .67591 .52521 .69091 .52264 .6842 .52215 Mtetra
.314 .8 .881 r
.6842 .52215 .69091 .52264 .70599 .51962 .69937 .51923 Mtetra
.355 .826 .887 r
.69937 .51923 .70599 .51962 .72112 .51608 .71459 .51566 Mtetra
.407 .856 .9 r
.71459 .51566 .72112 .51608 .73632 .51197 .72987 .51141 Mtetra
.468 .886 .918 r
.72987 .51141 .73632 .51197 .75155 .50727 .74519 .50644 Mtetra
.529 .913 .936 r
.74519 .50644 .75155 .50727 .76683 .50198 .76054 .50077 Mtetra
.587 .931 .951 r
.76054 .50077 .76683 .50198 .78214 .49614 .77591 .49445 Mtetra
.637 .94 .96 r
.77591 .49445 .78214 .49614 .79749 .48979 .79131 .48756 Mtetra
.677 .94 .964 r
.79131 .48756 .79749 .48979 .81286 .48301 .80673 .48017 Mtetra
.706 .933 .963 r
.80673 .48017 .81286 .48301 .82827 .47588 .82218 .47239 Mtetra
.725 .92 .959 r
.82218 .47239 .82827 .47588 .84372 .4685 .83766 .46435 Mtetra
.736 .904 .953 r
.83766 .46435 .84372 .4685 .85921 .46095 .85318 .45615 Mtetra
.741 .886 .946 r
.85318 .45615 .85921 .46095 .87475 .45333 .86875 .44791 Mtetra
.741 .868 .939 r
.86875 .44791 .87475 .45333 .89036 .44573 .88438 .43971 Mtetra
.738 .851 .933 r
.88438 .43971 .89036 .44573 .90604 .43821 .90009 .43164 Mtetra
.733 .835 .927 r
.90009 .43164 .90604 .43821 .9218 .43083 .91587 .42377 Mtetra
.727 .82 .923 r
.91587 .42377 .9218 .43083 .93764 .42364 .93175 .41613 Mtetra
.719 .806 .919 r
.93175 .41613 .93764 .42364 .95359 .41665 .94773 .40876 Mtetra
.656 .743 .914 r
.36522 .56704 .37335 .57446 .38664 .57057 .37855 .56318 Mtetra
.653 .744 .916 r
.37855 .56318 .38664 .57057 .4 .56673 .39195 .55938 Mtetra
.65 .745 .919 r
.39195 .55938 .4 .56673 .41343 .56296 .40542 .55568 Mtetra
.645 .747 .923 r
.40542 .55568 .41343 .56296 .42693 .55928 .41895 .5521 Mtetra
.639 .749 .928 r
.41895 .5521 .42693 .55928 .44049 .55573 .43255 .54868 Mtetra
.631 .751 .934 r
.43255 .54868 .44049 .55573 .45412 .55233 .44622 .54546 Mtetra
.621 .755 .942 r
.44622 .54546 .45412 .55233 .46782 .54911 .45997 .54247 Mtetra
.608 .758 .951 r
.45997 .54247 .46782 .54911 .4816 .5461 .47379 .53975 Mtetra
.592 .763 .96 r
.47379 .53975 .4816 .5461 .49546 .54333 .48769 .53732 Mtetra
.572 .768 .971 r
.48769 .53732 .49546 .54333 .5094 .54082 .50167 .53521 Mtetra
.546 .772 .982 r
.50167 .53521 .5094 .54082 .52342 .53859 .51575 .53344 Mtetra
.514 .776 .991 r
.51575 .53344 .52342 .53859 .53754 .53663 .52992 .53201 Mtetra
.474 .778 .997 r
.52992 .53201 .53754 .53663 .55174 .53495 .54419 .5309 Mtetra
.427 .776 .997 r
.54419 .5309 .55174 .53495 .56605 .53351 .55856 .53008 Mtetra
.372 .769 .986 r
.55856 .53008 .56605 .53351 .58046 .53228 .57304 .52948 Mtetra
.312 .755 .964 r
.57304 .52948 .58046 .53228 .59498 .53118 .58764 .52902 Mtetra
.253 .736 .93 r
.58764 .52902 .59498 .53118 .6096 .53014 .60234 .52861 Mtetra
.201 .714 .888 r
.60234 .52861 .6096 .53014 .62433 .52906 .61716 .52812 Mtetra
.162 .695 .845 r
.61716 .52812 .62433 .52906 .63916 .52783 .63209 .52742 Mtetra
.14 .684 .807 r
.63209 .52742 .63916 .52783 .65408 .52635 .64711 .52638 Mtetra
.139 .685 .781 r
.64711 .52638 .65408 .52635 .6691 .52449 .66223 .52485 Mtetra
.159 .7 .769 r
.66223 .52485 .6691 .52449 .6842 .52215 .67743 .52272 Mtetra
.199 .728 .774 r
.67743 .52272 .6842 .52215 .69937 .51923 .6927 .51987 Mtetra
.258 .768 .792 r
.6927 .51987 .69937 .51923 .71459 .51566 .70802 .51624 Mtetra
.331 .815 .822 r
.70802 .51624 .71459 .51566 .72987 .51141 .72339 .51176 Mtetra
.412 .863 .857 r
.72339 .51176 .72987 .51141 .74519 .50644 .73879 .50645 Mtetra
.495 .905 .891 r
.73879 .50645 .74519 .50644 .76054 .50077 .75421 .50031 Mtetra
.571 .935 .92 r
.75421 .50031 .76054 .50077 .77591 .49445 .76964 .49342 Mtetra
.635 .952 .939 r
.76964 .49342 .77591 .49445 .79131 .48756 .78509 .48587 Mtetra
.684 .956 .95 r
.78509 .48587 .79131 .48756 .80673 .48017 .80056 .47777 Mtetra
.718 .949 .953 r
.80056 .47777 .80673 .48017 .82218 .47239 .81604 .46926 Mtetra
.74 .935 .951 r
.81604 .46926 .82218 .47239 .83766 .46435 .83156 .46047 Mtetra
.752 .917 .947 r
.83156 .46047 .83766 .46435 .85318 .45615 .8471 .45154 Mtetra
.756 .897 .941 r
.8471 .45154 .85318 .45615 .86875 .44791 .8627 .4426 Mtetra
.755 .877 .934 r
.8627 .4426 .86875 .44791 .88438 .43971 .87835 .43375 Mtetra
.751 .858 .929 r
.87835 .43375 .88438 .43971 .90009 .43164 .89408 .42509 Mtetra
.744 .84 .924 r
.89408 .42509 .90009 .43164 .91587 .42377 .90989 .41668 Mtetra
.736 .824 .919 r
.90989 .41668 .91587 .42377 .93175 .41613 .9258 .40858 Mtetra
.727 .81 .916 r
.9258 .40858 .93175 .41613 .94773 .40876 .9418 .4008 Mtetra
.654 .744 .916 r
.35701 .5596 .36522 .56704 .37855 .56318 .37038 .55576 Mtetra
.65 .745 .919 r
.37038 .55576 .37855 .56318 .39195 .55938 .38382 .55203 Mtetra
.646 .746 .922 r
.38382 .55203 .39195 .55938 .40542 .55568 .39732 .54842 Mtetra
.639 .748 .927 r
.39732 .54842 .40542 .55568 .41895 .5521 .41089 .54497 Mtetra
.631 .75 .933 r
.41089 .54497 .41895 .5521 .43255 .54868 .42453 .54173 Mtetra
.621 .753 .941 r
.42453 .54173 .43255 .54868 .44622 .54546 .43824 .53873 Mtetra
.607 .756 .95 r
.43824 .53873 .44622 .54546 .45997 .54247 .45203 .53602 Mtetra
.59 .76 .96 r
.45203 .53602 .45997 .54247 .47379 .53975 .46589 .53364 Mtetra
.568 .764 .971 r
.46589 .53364 .47379 .53975 .48769 .53732 .47983 .53163 Mtetra
.539 .768 .982 r
.47983 .53163 .48769 .53732 .50167 .53521 .49386 .53 Mtetra
.502 .77 .992 r
.49386 .53 .50167 .53521 .51575 .53344 .50798 .52878 Mtetra
.455 .769 .997 r
.50798 .52878 .51575 .53344 .52992 .53201 .52221 .52796 Mtetra
.396 .762 .993 r
.52221 .52796 .52992 .53201 .54419 .5309 .53654 .52752 Mtetra
.326 .746 .976 r
.53654 .52752 .54419 .5309 .55856 .53008 .55098 .52739 Mtetra
.247 .72 .941 r
.55098 .52739 .55856 .53008 .57304 .52948 .56554 .52752 Mtetra
.167 .684 .889 r
.56554 .52752 .57304 .52948 .58764 .52902 .58021 .52779 Mtetra
.095 .644 .825 r
.58021 .52779 .58764 .52902 .60234 .52861 .59501 .52807 Mtetra
.038 .606 .76 r
.59501 .52807 .60234 .52861 .61716 .52812 .60992 .52823 Mtetra
0 0 0 r
.60992 .52823 .61716 .52812 .63209 .52742 .62495 .5281 Mtetra
.011 0 0 r
.62495 .5281 .63209 .52742 .64711 .52638 .64008 .52751 Mtetra
.001 0 0 r
.64008 .52751 .64711 .52638 .66223 .52485 .6553 .52632 Mtetra
0 0 0 r
.6553 .52632 .66223 .52485 .67743 .52272 .67061 .52437 Mtetra
.67061 .52437 .67743 .52272 .6927 .51987 .68598 .52155 Mtetra
.68598 .52155 .6927 .51987 .70802 .51624 .7014 .51778 Mtetra
.258 .762 .732 r
.7014 .51778 .70802 .51624 .72339 .51176 .71686 .51301 Mtetra
.362 .831 .787 r
.71686 .51301 .72339 .51176 .73879 .50645 .73234 .50725 Mtetra
.466 .891 .84 r
.73234 .50725 .73879 .50645 .75421 .50031 .74783 .50054 Mtetra
.561 .936 .884 r
.74783 .50054 .75421 .50031 .76964 .49342 .76333 .49297 Mtetra
.639 .961 .915 r
.76333 .49297 .76964 .49342 .78509 .48587 .77883 .48466 Mtetra
.696 .968 .933 r
.77883 .48466 .78509 .48587 .80056 .47777 .79434 .47575 Mtetra
.735 .961 .941 r
.79434 .47575 .80056 .47777 .81604 .46926 .80985 .4664 Mtetra
.758 .946 .941 r
.80985 .4664 .81604 .46926 .83156 .46047 .82539 .45679 Mtetra
.769 .927 .938 r
.82539 .45679 .83156 .46047 .8471 .45154 .84096 .44706 Mtetra
.772 .905 .933 r
.84096 .44706 .8471 .45154 .8627 .4426 .85658 .43735 Mtetra
.77 .884 .928 r
.85658 .43735 .8627 .4426 .87835 .43375 .87225 .4278 Mtetra
.764 .863 .923 r
.87225 .4278 .87835 .43375 .89408 .42509 .888 .41851 Mtetra
.755 .845 .918 r
.888 .41851 .89408 .42509 .90989 .41668 .90384 .40954 Mtetra
.745 .828 .915 r
.90384 .40954 .90989 .41668 .9258 .40858 .91977 .40094 Mtetra
.735 .813 .912 r
.91977 .40094 .9258 .40858 .9418 .4008 .93581 .39274 Mtetra
.651 .744 .918 r
.34872 .55212 .35701 .5596 .37038 .55576 .36213 .54834 Mtetra
.646 .745 .921 r
.36213 .54834 .37038 .55576 .38382 .55203 .37561 .54469 Mtetra
.64 .747 .926 r
.37561 .54469 .38382 .55203 .39732 .54842 .38915 .5412 Mtetra
.632 .749 .932 r
.38915 .5412 .39732 .54842 .41089 .54497 .40275 .53792 Mtetra
.622 .751 .939 r
.40275 .53792 .41089 .54497 .42453 .54173 .41643 .53489 Mtetra
.608 .754 .948 r
.41643 .53489 .42453 .54173 .43824 .53873 .43017 .53216 Mtetra
.59 .758 .958 r
.43017 .53216 .43824 .53873 .45203 .53602 .44399 .52979 Mtetra
.566 .761 .97 r
.44399 .52979 .45203 .53602 .46589 .53364 .45789 .52782 Mtetra
.535 .764 .981 r
.45789 .52782 .46589 .53364 .47983 .53163 .47188 .52629 Mtetra
.494 .765 .991 r
.47188 .52629 .47983 .53163 .49386 .53 .48595 .52523 Mtetra
.441 .761 .996 r
.48595 .52523 .49386 .53 .50798 .52878 .50013 .52465 Mtetra
.372 .749 .99 r
.50013 .52465 .50798 .52878 .52221 .52796 .51441 .52453 Mtetra
.287 .725 .966 r
.51441 .52453 .52221 .52796 .53654 .52752 .5288 .52484 Mtetra
.191 .685 .919 r
.5288 .52484 .53654 .52752 .55098 .52739 .54331 .52551 Mtetra
.091 .632 .849 r
.54331 .52551 .55098 .52739 .56554 .52752 .55794 .52645 Mtetra
0 .572 .763 r
.55794 .52645 .56554 .52752 .58021 .52779 .5727 .52751 Mtetra
.074 0 0 r
.5727 .52751 .58021 .52779 .59501 .52807 .58759 .52856 Mtetra
.122 0 0 r
.58759 .52856 .59501 .52807 .60992 .52823 .6026 .52941 Mtetra
.146 0 0 r
.6026 .52941 .60992 .52823 .62495 .5281 .61773 .52987 Mtetra
.144 0 0 r
.61773 .52987 .62495 .5281 .64008 .52751 .63297 .52975 Mtetra
.12 0 0 r
.63297 .52975 .64008 .52751 .6553 .52632 .6483 .52887 Mtetra
.073 0 0 r
.6483 .52887 .6553 .52632 .67061 .52437 .66372 .52706 Mtetra
.003 0 0 r
.66372 .52706 .67061 .52437 .68598 .52155 .67919 .52421 Mtetra
0 0 0 r
.67919 .52421 .68598 .52155 .7014 .51778 .69471 .52021 Mtetra
.69471 .52021 .7014 .51778 .71686 .51301 .71026 .51505 Mtetra
.326 .801 .722 r
.71026 .51505 .71686 .51301 .73234 .50725 .72582 .50874 Mtetra
.451 .879 .793 r
.72582 .50874 .73234 .50725 .74783 .50054 .74139 .50135 Mtetra
.563 .936 .852 r
.74139 .50135 .74783 .50054 .76333 .49297 .75694 .49298 Mtetra
.652 .968 .893 r
.75694 .49298 .76333 .49297 .77883 .48466 .7725 .4838 Mtetra
.715 .978 .916 r
.7725 .4838 .77883 .48466 .79434 .47575 .78804 .47399 Mtetra
.756 .971 .927 r
.78804 .47399 .79434 .47575 .80985 .4664 .80359 .46372 Mtetra
.778 .954 .929 r
.80359 .46372 .80985 .4664 .82539 .45679 .81916 .45319 Mtetra
.788 .933 .927 r
.81916 .45319 .82539 .45679 .84096 .44706 .83475 .44259 Mtetra
.789 .91 .923 r
.83475 .44259 .84096 .44706 .85658 .43735 .85039 .43208 Mtetra
.784 .887 .919 r
.85039 .43208 .85658 .43735 .87225 .4278 .86608 .42179 Mtetra
.776 .866 .915 r
.86608 .42179 .87225 .4278 .888 .41851 .88185 .41183 Mtetra
.766 .847 .912 r
.88185 .41183 .888 .41851 .90384 .40954 .89771 .40228 Mtetra
.754 .829 .91 r
.89771 .40228 .90384 .40954 .91977 .40094 .91368 .39318 Mtetra
.743 .814 .908 r
.91368 .39318 .91977 .40094 .93581 .39274 .92975 .38455 Mtetra
.648 .745 .92 r
.34035 .54463 .34872 .55212 .36213 .54834 .3538 .54092 Mtetra
.642 .746 .925 r
.3538 .54092 .36213 .54834 .37561 .54469 .36731 .53738 Mtetra
.634 .748 .93 r
.36731 .53738 .37561 .54469 .38915 .5412 .38088 .53403 Mtetra
.624 .75 .937 r
.38088 .53403 .38915 .5412 .40275 .53792 .39452 .53095 Mtetra
.61 .752 .946 r
.39452 .53095 .40275 .53792 .41643 .53489 .40823 .52818 Mtetra
.592 .755 .956 r
.40823 .52818 .41643 .53489 .43017 .53216 .42201 .52578 Mtetra
.568 .758 .968 r
.42201 .52578 .43017 .53216 .44399 .52979 .43587 .52381 Mtetra
.535 .76 .98 r
.43587 .52381 .44399 .52979 .45789 .52782 .44981 .52232 Mtetra
.492 .759 .99 r
.44981 .52232 .45789 .52782 .47188 .52629 .46383 .52135 Mtetra
.434 .753 .995 r
.46383 .52135 .47188 .52629 .48595 .52523 .47795 .52094 Mtetra
.357 .737 .987 r
.47795 .52094 .48595 .52523 .50013 .52465 .49217 .52108 Mtetra
.261 .706 .959 r
.49217 .52108 .50013 .52465 .51441 .52453 .5065 .52175 Mtetra
.148 .655 .903 r
.5065 .52175 .51441 .52453 .5288 .52484 .52095 .52291 Mtetra
.03 .586 .817 r
.52095 .52291 .5288 .52484 .54331 .52551 .53553 .52446 Mtetra
0 .508 .711 r
.53553 .52446 .54331 .52551 .55794 .52645 .55024 .52628 Mtetra
.165 0 0 r
.55024 .52628 .55794 .52645 .5727 .52751 .56509 .52822 Mtetra
.224 0 0 r
.56509 .52822 .5727 .52751 .58759 .52856 .58007 .53008 Mtetra
.255 0 0 r
.58007 .53008 .58759 .52856 .6026 .52941 .59518 .53165 Mtetra
.262 0 0 r
.59518 .53165 .6026 .52941 .61773 .52987 .61042 .53271 Mtetra
.247 0 0 r
.61042 .53271 .61773 .52987 .63297 .52975 .62577 .53304 Mtetra
.21 0 0 r
.62577 .53304 .63297 .52975 .6483 .52887 .64122 .53244 Mtetra
.15 0 0 r
.64122 .53244 .6483 .52887 .66372 .52706 .65675 .53071 Mtetra
.068 0 0 r
.65675 .53071 .66372 .52706 .67919 .52421 .67233 .52774 Mtetra
0 0 0 r
.67233 .52774 .67919 .52421 .69471 .52021 .68795 .52343 Mtetra
.68795 .52343 .69471 .52021 .71026 .51505 .70359 .51777 Mtetra
.313 .783 .673 r
.70359 .51777 .71026 .51505 .72582 .50874 .71923 .51079 Mtetra
.455 .876 .76 r
.71923 .51079 .72582 .50874 .74139 .50135 .73487 .50259 Mtetra
.58 .942 .829 r
.73487 .50259 .74139 .50135 .75694 .49298 .75049 .49332 Mtetra
.676 .977 .876 r
.75049 .49332 .75694 .49298 .7725 .4838 .76609 .48317 Mtetra
.741 .985 .902 r
.76609 .48317 .7725 .4838 .78804 .47399 .78167 .47234 Mtetra
.78 .976 .913 r
.78167 .47234 .78804 .47399 .80359 .46372 .79725 .46107 Mtetra
.8 .957 .916 r
.79725 .46107 .80359 .46372 .81916 .45319 .81284 .44957 Mtetra
.807 .934 .915 r
.81284 .44957 .81916 .45319 .83475 .44259 .82846 .43805 Mtetra
.805 .911 .912 r
.82846 .43805 .83475 .44259 .85039 .43208 .84411 .42668 Mtetra
.798 .888 .909 r
.84411 .42668 .85039 .43208 .86608 .42179 .85983 .41562 Mtetra
.788 .866 .907 r
.85983 .41562 .86608 .42179 .88185 .41183 .87562 .40499 Mtetra
.776 .847 .905 r
.87562 .40499 .88185 .41183 .89771 .40228 .89151 .39484 Mtetra
.763 .829 .903 r
.89151 .39484 .89771 .40228 .91368 .39318 .9075 .38524 Mtetra
.75 .814 .903 r
.9075 .38524 .91368 .39318 .92975 .38455 .92361 .37618 Mtetra
.644 .745 .923 r
.3319 .53713 .34035 .54463 .3538 .54092 .34538 .53351 Mtetra
.636 .747 .928 r
.34538 .53351 .3538 .54092 .36731 .53738 .35892 .53009 Mtetra
.626 .748 .935 r
.35892 .53009 .36731 .53738 .38088 .53403 .37253 .52693 Mtetra
.613 .75 .943 r
.37253 .52693 .38088 .53403 .39452 .53095 .38621 .52408 Mtetra
.595 .753 .953 r
.38621 .52408 .39452 .53095 .40823 .52818 .39995 .52162 Mtetra
.571 .755 .965 r
.39995 .52162 .40823 .52818 .42201 .52578 .41376 .5196 Mtetra
.539 .756 .977 r
.41376 .5196 .42201 .52578 .43587 .52381 .42765 .51809 Mtetra
.494 .755 .988 r
.42765 .51809 .43587 .52381 .44981 .52232 .44162 .51716 Mtetra
.434 .747 .993 r
.44162 .51716 .44981 .52232 .46383 .52135 .45568 .51683 Mtetra
.353 .729 .987 r
.45568 .51683 .46383 .52135 .47795 .52094 .46984 .51715 Mtetra
.248 .693 .958 r
.46984 .51715 .47795 .52094 .49217 .52108 .4841 .5181 Mtetra
.122 .634 .895 r
.4841 .5181 .49217 .52108 .5065 .52175 .49849 .51965 Mtetra
0 .552 .798 r
.49849 .51965 .5065 .52175 .52095 .52291 .513 .52174 Mtetra
.136 0 0 r
.513 .52174 .52095 .52291 .53553 .52446 .52764 .52424 Mtetra
.234 0 0 r
.52764 .52424 .53553 .52446 .55024 .52628 .54243 .52702 Mtetra
.301 0 0 r
.54243 .52702 .55024 .52628 .56509 .52822 .55736 .52987 Mtetra
.34 0 0 r
.55736 .52987 .56509 .52822 .58007 .53008 .57244 .53257 Mtetra
.353 0 0 r
.57244 .53257 .58007 .53008 .59518 .53165 .58766 .53488 Mtetra
.346 0 0 r
.58766 .53488 .59518 .53165 .61042 .53271 .60301 .53653 Mtetra
.318 0 0 r
.60301 .53653 .61042 .53271 .62577 .53304 .61848 .53728 Mtetra
.27 0 0 r
.61848 .53728 .62577 .53304 .64122 .53244 .63404 .53689 Mtetra
.201 0 0 r
.63404 .53689 .64122 .53244 .65675 .53071 .64968 .53517 Mtetra
.106 0 0 r
.64968 .53517 .65675 .53071 .67233 .52774 .66537 .53198 Mtetra
0 0 0 r
.66537 .53198 .67233 .52774 .68795 .52343 .6811 .52725 Mtetra
.6811 .52725 .68795 .52343 .70359 .51777 .69683 .52097 Mtetra
.326 .784 .648 r
.69683 .52097 .70359 .51777 .71923 .51079 .71255 .5132 Mtetra
.483 .887 .745 r
.71255 .5132 .71923 .51079 .73487 .50259 .72826 .50408 Mtetra
.615 .955 .819 r
.72826 .50408 .73487 .50259 .75049 .49332 .74393 .4938 Mtetra
.711 .986 .865 r
.74393 .4938 .75049 .49332 .76609 .48317 .75958 .48257 Mtetra
.772 .99 .89 r
.75958 .48257 .76609 .48317 .78167 .47234 .7752 .47066 Mtetra
.806 .977 .9 r
.7752 .47066 .78167 .47234 .79725 .46107 .79081 .45831 Mtetra
.821 .956 .903 r
.79081 .45831 .79725 .46107 .81284 .44957 .80643 .44578 Mtetra
.825 .932 .902 r
.80643 .44578 .81284 .44957 .82846 .43805 .82206 .4333 Mtetra
.82 .907 .9 r
.82206 .4333 .82846 .43805 .84411 .42668 .83774 .42106 Mtetra
.811 .884 .898 r
.83774 .42106 .84411 .42668 .85983 .41562 .85348 .40923 Mtetra
.799 .863 .897 r
.85348 .40923 .85983 .41562 .87562 .40499 .8693 .3979 Mtetra
.785 .844 .896 r
.8693 .3979 .87562 .40499 .89151 .39484 .88521 .38717 Mtetra
.77 .827 .897 r
.88521 .38717 .89151 .39484 .9075 .38524 .90124 .37707 Mtetra
.756 .812 .897 r
.90124 .37707 .9075 .38524 .92361 .37618 .91739 .36761 Mtetra
.639 .746 .926 r
.32336 .52961 .3319 .53713 .34538 .53351 .33688 .52611 Mtetra
.629 .747 .932 r
.33688 .52611 .34538 .53351 .35892 .53009 .35045 .52285 Mtetra
.617 .749 .94 r
.35045 .52285 .35892 .53009 .37253 .52693 .36409 .5199 Mtetra
.6 .751 .95 r
.36409 .5199 .37253 .52693 .38621 .52408 .37779 .51734 Mtetra
.577 .752 .961 r
.37779 .51734 .38621 .52408 .39995 .52162 .39156 .51522 Mtetra
.545 .753 .973 r
.39156 .51522 .39995 .52162 .41376 .5196 .40541 .51364 Mtetra
.502 .751 .985 r
.40541 .51364 .41376 .5196 .42765 .51809 .41932 .51266 Mtetra
.442 .743 .992 r
.41932 .51266 .42765 .51809 .44162 .51716 .43333 .51234 Mtetra
.36 .725 .988 r
.43333 .51234 .44162 .51716 .45568 .51683 .44742 .51273 Mtetra
.251 .687 .961 r
.44742 .51273 .45568 .51683 .46984 .51715 .46162 .51386 Mtetra
.116 .623 .898 r
.46162 .51386 .46984 .51715 .4841 .5181 .47592 .5157 Mtetra
0 .532 .794 r
.47592 .5157 .4841 .5181 .49849 .51965 .49036 .5182 Mtetra
.17 0 0 r
.49036 .5182 .49849 .51965 .513 .52174 .50493 .52129 Mtetra
.281 0 0 r
.50493 .52129 .513 .52174 .52764 .52424 .51964 .52482 Mtetra
.357 0 0 r
.51964 .52482 .52764 .52424 .54243 .52702 .53451 .52859 Mtetra
.403 0 0 r
.53451 .52859 .54243 .52702 .55736 .52987 .54953 .53239 Mtetra
.423 0 0 r
.54953 .53239 .55736 .52987 .57244 .53257 .5647 .53595 Mtetra
.422 0 0 r
.5647 .53595 .57244 .53257 .58766 .53488 .58002 .53898 Mtetra
.403 0 0 r
.58002 .53898 .58766 .53488 .60301 .53653 .59549 .54119 Mtetra
.365 0 0 r
.59549 .54119 .60301 .53653 .61848 .53728 .61107 .5423 Mtetra
.308 0 0 r
.61107 .5423 .61848 .53728 .63404 .53689 .62675 .54205 Mtetra
.227 0 0 r
.62675 .54205 .63404 .53689 .64968 .53517 .6425 .54023 Mtetra
.118 0 0 r
.6425 .54023 .64968 .53517 .66537 .53198 .6583 .53672 Mtetra
0 0 0 r
.6583 .53672 .66537 .53198 .6811 .52725 .67413 .53144 Mtetra
.67413 .53144 .6811 .52725 .69683 .52097 .68996 .52441 Mtetra
.369 .808 .651 r
.68996 .52441 .69683 .52097 .71255 .5132 .70576 .51574 Mtetra
.535 .912 .752 r
.70576 .51574 .71255 .5132 .72826 .50408 .72153 .50558 Mtetra
.666 .972 .821 r
.72153 .50558 .72826 .50408 .74393 .4938 .73727 .49418 Mtetra
.754 .994 .861 r
.73727 .49418 .74393 .4938 .75958 .48257 .75296 .4818 Mtetra
.805 .99 .88 r
.75296 .4818 .75958 .48257 .7752 .47066 .76862 .46873 Mtetra
.832 .972 .887 r
.76862 .46873 .7752 .47066 .79081 .45831 .78426 .45526 Mtetra
.841 .949 .889 r
.78426 .45526 .79081 .45831 .80643 .44578 .7999 .44168 Mtetra
.84 .924 .888 r
.7999 .44168 .80643 .44578 .82206 .4333 .81556 .42822 Mtetra
.833 .9 .887 r
.81556 .42822 .82206 .4333 .83774 .42106 .83126 .41511 Mtetra
.821 .878 .886 r
.83126 .41511 .83774 .42106 .85348 .40923 .84703 .4025 Mtetra
.807 .858 .887 r
.84703 .4025 .85348 .40923 .8693 .3979 .86287 .39051 Mtetra
.792 .84 .888 r
.86287 .39051 .8693 .3979 .88521 .38717 .87882 .37921 Mtetra
.777 .823 .889 r
.87882 .37921 .88521 .38717 .90124 .37707 .89489 .36864 Mtetra
.761 .809 .891 r
.89489 .36864 .90124 .37707 .91739 .36761 .91108 .35879 Mtetra
.633 .746 .93 r
.31474 .5221 .32336 .52961 .33688 .52611 .32828 .51873 Mtetra
.621 .747 .937 r
.32828 .51873 .33688 .52611 .35045 .52285 .34189 .51566 Mtetra
.605 .749 .946 r
.34189 .51566 .35045 .52285 .36409 .5199 .35556 .51296 Mtetra
.584 .75 .957 r
.35556 .51296 .36409 .5199 .37779 .51734 .36929 .51071 Mtetra
.554 .75 .969 r
.36929 .51071 .37779 .51734 .39156 .51522 .38308 .509 Mtetra
.513 .748 .981 r
.38308 .509 .39156 .51522 .40541 .51364 .39695 .50791 Mtetra
.455 .741 .99 r
.39695 .50791 .40541 .51364 .41932 .51266 .41089 .50751 Mtetra
.375 .723 .989 r
.41089 .50751 .41932 .51266 .43333 .51234 .42492 .50788 Mtetra
.267 .687 .967 r
.42492 .50788 .43333 .51234 .44742 .51273 .43905 .50906 Mtetra
.128 .623 .91 r
.43905 .50906 .44742 .51273 .46162 .51386 .45328 .51105 Mtetra
0 .528 .807 r
.45328 .51105 .46162 .51386 .47592 .5157 .46763 .51385 Mtetra
.182 0 0 r
.46763 .51385 .47592 .5157 .49036 .5182 .48211 .51737 Mtetra
.306 0 0 r
.48211 .51737 .49036 .5182 .50493 .52129 .49673 .52152 Mtetra
.394 0 0 r
.49673 .52152 .50493 .52129 .51964 .52482 .51151 .5261 Mtetra
.448 0 0 r
.51151 .5261 .51964 .52482 .53451 .52859 .52645 .5309 Mtetra
.474 0 0 r
.52645 .5309 .53451 .52859 .54953 .53239 .54156 .53566 Mtetra
.48 0 0 r
.54156 .53566 .54953 .53239 .5647 .53595 .55683 .54006 Mtetra
.468 0 0 r
.55683 .54006 .5647 .53595 .58002 .53898 .57226 .54378 Mtetra
.44 0 0 r
.57226 .54378 .58002 .53898 .59549 .54119 .58783 .54649 Mtetra
.393 0 0 r
.58783 .54649 .59549 .54119 .61107 .5423 .60353 .54787 Mtetra
.326 0 0 r
.60353 .54787 .61107 .5423 .62675 .54205 .61933 .54765 Mtetra
.231 0 0 r
.61933 .54765 .62675 .54205 .6425 .54023 .6352 .54563 Mtetra
.104 0 0 r
.6352 .54563 .6425 .54023 .6583 .53672 .65111 .54166 Mtetra
0 0 0 r
.65111 .54166 .6583 .53672 .67413 .53144 .66704 .53571 Mtetra
.66704 .53571 .67413 .53144 .68996 .52441 .68296 .52781 Mtetra
.442 .853 .682 r
.68296 .52781 .68996 .52441 .70576 .51574 .69884 .51812 Mtetra
.608 .946 .775 r
.69884 .51812 .70576 .51574 .72153 .50558 .71468 .50683 Mtetra
.726 .989 .832 r
.71468 .50683 .72153 .50558 .73727 .49418 .73047 .49423 Mtetra
.799 .997 .86 r
.73047 .49423 .73727 .49418 .75296 .4818 .74621 .48063 Mtetra
.837 .983 .872 r
.74621 .48063 .75296 .4818 .76862 .46873 .76191 .46636 Mtetra
.854 .961 .874 r
.76191 .46636 .76862 .46873 .78426 .45526 .77759 .45175 Mtetra
.857 .936 .874 r
.77759 .45175 .78426 .45526 .7999 .44168 .79326 .4371 Mtetra
.852 .912 .873 r
.79326 .4371 .7999 .44168 .81556 .42822 .80894 .42268 Mtetra
.842 .889 .873 r
.80894 .42268 .81556 .42822 .83126 .41511 .82467 .4087 Mtetra
.829 .869 .874 r
.82467 .4087 .83126 .41511 .84703 .4025 .84046 .39535 Mtetra
.814 .85 .876 r
.84046 .39535 .84703 .4025 .86287 .39051 .85634 .38273 Mtetra
.798 .833 .879 r
.85634 .38273 .86287 .39051 .87882 .37921 .87233 .3709 Mtetra
.781 .818 .882 r
.87233 .3709 .87882 .37921 .89489 .36864 .88843 .35989 Mtetra
.765 .805 .885 r
.88843 .35989 .89489 .36864 .91108 .35879 .90467 .34968 Mtetra
.626 .746 .933 r
.30602 .51458 .31474 .5221 .32828 .51873 .3196 .51137 Mtetra
.611 .747 .942 r
.3196 .51137 .32828 .51873 .34189 .51566 .33323 .50851 Mtetra
.591 .748 .952 r
.33323 .50851 .34189 .51566 .35556 .51296 .34692 .5061 Mtetra
.564 .748 .963 r
.34692 .5061 .35556 .51296 .36929 .51071 .36068 .50421 Mtetra
.526 .746 .976 r
.36068 .50421 .36929 .51071 .38308 .509 .3745 .50294 Mtetra
.473 .74 .986 r
.3745 .50294 .38308 .509 .39695 .50791 .38839 .50239 Mtetra
.398 .724 .989 r
.38839 .50239 .39695 .50791 .41089 .50751 .40235 .50264 Mtetra
.294 .691 .975 r
.40235 .50264 .41089 .50751 .42492 .50788 .41641 .50375 Mtetra
.157 .631 .927 r
.41641 .50375 .42492 .50788 .43905 .50906 .43056 .50576 Mtetra
0 .538 .833 r
.43056 .50576 .43905 .50906 .45328 .51105 .44482 .50869 Mtetra
0 .418 .696 r
.44482 .50869 .45328 .51105 .46763 .51385 .4592 .5125 Mtetra
.311 0 0 r
.4592 .5125 .46763 .51385 .48211 .51737 .47373 .51708 Mtetra
.412 0 0 r
.47373 .51708 .48211 .51737 .49673 .52152 .4884 .52231 Mtetra
.476 0 0 r
.4884 .52231 .49673 .52152 .51151 .5261 .50325 .52797 Mtetra
.511 0 0 r
.50325 .52797 .51151 .5261 .52645 .5309 .51826 .5338 Mtetra
.524 0 0 r
.51826 .5338 .52645 .5309 .54156 .53566 .53345 .53949 Mtetra
.519 0 0 r
.53345 .53949 .54156 .53566 .55683 .54006 .54882 .54469 Mtetra
.499 0 0 r
.54882 .54469 .55683 .54006 .57226 .54378 .56436 .54903 Mtetra
.462 0 0 r
.56436 .54903 .57226 .54378 .58783 .54649 .58004 .55215 Mtetra
.406 0 0 r
.58004 .55215 .58783 .54649 .60353 .54787 .59586 .5537 Mtetra
.326 0 0 r
.59586 .5537 .60353 .54787 .61933 .54765 .61177 .5534 Mtetra
.214 0 0 r
.61177 .5534 .61933 .54765 .6352 .54563 .62775 .55104 Mtetra
.062 0 0 r
.62775 .55104 .6352 .54563 .65111 .54166 .64377 .54649 Mtetra
0 0 0 r
.64377 .54649 .65111 .54166 .66704 .53571 .6598 .53973 Mtetra
.6598 .53973 .66704 .53571 .68296 .52781 .67581 .53085 Mtetra
.541 .91 .733 r
.67581 .53085 .68296 .52781 .69884 .51812 .69177 .52003 Mtetra
.691 .978 .808 r
.69177 .52003 .69884 .51812 .71468 .50683 .70768 .50753 Mtetra
.787 .998 .845 r
.70768 .50753 .71468 .50683 .73047 .49423 .72353 .49367 Mtetra
.839 .99 .859 r
.72353 .49367 .73047 .49423 .74621 .48063 .73932 .47881 Mtetra
.864 .969 .862 r
.73932 .47881 .74621 .48063 .76191 .46636 .75506 .46333 Mtetra
.871 .944 .861 r
.75506 .46333 .76191 .46636 .77759 .45175 .77077 .44757 Mtetra
.869 .919 .859 r
.77077 .44757 .77759 .45175 .79326 .4371 .78647 .43188 Mtetra
.861 .896 .859 r
.78647 .43188 .79326 .4371 .80894 .42268 .80219 .41653 Mtetra
.849 .875 .86 r
.80219 .41653 .80894 .42268 .82467 .4087 .81795 .40175 Mtetra
.834 .857 .862 r
.81795 .40175 .82467 .4087 .84046 .39535 .83378 .3877 Mtetra
.818 .84 .866 r
.83378 .3877 .84046 .39535 .85634 .38273 .8497 .3745 Mtetra
.801 .825 .87 r
.8497 .3745 .85634 .38273 .87233 .3709 .86573 .36219 Mtetra
.784 .812 .874 r
.86573 .36219 .87233 .3709 .88843 .35989 .88188 .3508 Mtetra
.768 .8 .879 r
.88188 .3508 .88843 .35989 .90467 .34968 .89817 .34028 Mtetra
.618 .745 .937 r
.29722 .50706 .30602 .51458 .3196 .51137 .31082 .50403 Mtetra
.6 .746 .947 r
.31082 .50403 .3196 .51137 .33323 .50851 .32448 .50142 Mtetra
.576 .746 .958 r
.32448 .50142 .33323 .50851 .34692 .5061 .33819 .49932 Mtetra
.542 .745 .97 r
.33819 .49932 .34692 .5061 .36068 .50421 .35197 .49782 Mtetra
.494 .739 .982 r
.35197 .49782 .36068 .50421 .3745 .50294 .36581 .49704 Mtetra
.426 .726 .988 r
.36581 .49704 .3745 .50294 .38839 .50239 .37972 .49707 Mtetra
.331 .699 .982 r
.37972 .49707 .38839 .50239 .40235 .50264 .3937 .49801 Mtetra
.201 .646 .947 r
.3937 .49801 .40235 .50264 .41641 .50375 .40777 .49991 Mtetra
.039 .56 .868 r
.40777 .49991 .41641 .50375 .43056 .50576 .42194 .50281 Mtetra
0 .441 .74 r
.42194 .50281 .43056 .50576 .44482 .50869 .43623 .50671 Mtetra
.292 0 0 r
.43623 .50671 .44482 .50869 .4592 .5125 .45065 .51155 Mtetra
.411 0 0 r
.45065 .51155 .4592 .5125 .47373 .51708 .46521 .51721 Mtetra
.489 0 0 r
.46521 .51721 .47373 .51708 .4884 .52231 .47994 .52353 Mtetra
.534 0 0 r
.47994 .52353 .4884 .52231 .50325 .52797 .49484 .53026 Mtetra
.555 .004 0 r
.49484 .53026 .50325 .52797 .51826 .5338 .50993 .53708 Mtetra
.558 .02 0 r
.50993 .53708 .51826 .5338 .53345 .53949 .52521 .54365 Mtetra
.545 .016 0 r
.52521 .54365 .53345 .53949 .54882 .54469 .54067 .54957 Mtetra
.517 0 0 r
.54067 .54957 .54882 .54469 .56436 .54903 .55631 .55444 Mtetra
.472 0 0 r
.55631 .55444 .56436 .54903 .58004 .55215 .5721 .55785 Mtetra
.404 0 0 r
.5721 .55785 .58004 .55215 .59586 .5537 .58803 .55944 Mtetra
.307 0 0 r
.58803 .55944 .59586 .5537 .61177 .5534 .60406 .55892 Mtetra
.17 0 0 r
.60406 .55892 .61177 .5534 .62775 .55104 .62015 .55608 Mtetra
0 0 0 r
.62015 .55608 .62775 .55104 .64377 .54649 .63628 .55081 Mtetra
.63628 .55081 .64377 .54649 .6598 .53973 .65241 .54313 Mtetra
.468 .87 .702 r
.65241 .54313 .6598 .53973 .67581 .53085 .6685 .53316 Mtetra
.652 .964 .793 r
.6685 .53316 .67581 .53085 .69177 .52003 .68454 .52113 Mtetra
.771 .997 .837 r
.68454 .52113 .69177 .52003 .70768 .50753 .70052 .50736 Mtetra
.837 .993 .852 r
.70052 .50736 .70768 .50753 .72353 .49367 .71643 .49221 Mtetra
.869 .972 .853 r
.71643 .49221 .72353 .49367 .73932 .47881 .73227 .4761 Mtetra
.881 .947 .85 r
.73227 .4761 .73932 .47881 .75506 .46333 .74805 .45942 Mtetra
.882 .922 .846 r
.74805 .45942 .75506 .46333 .77077 .44757 .7638 .44257 Mtetra
.876 .898 .844 r
.7638 .44257 .77077 .44757 .78647 .43188 .77954 .42588 Mtetra
.865 .878 .845 r
.77954 .42588 .78647 .43188 .80219 .41653 .7953 .40967 Mtetra
.852 .859 .847 r
.7953 .40967 .80219 .41653 .81795 .40175 .8111 .39414 Mtetra
.837 .843 .85 r
.8111 .39414 .81795 .40175 .83378 .3877 .82697 .37947 Mtetra
.82 .829 .855 r
.82697 .37947 .83378 .3877 .8497 .3745 .84294 .36576 Mtetra
.803 .816 .861 r
.84294 .36576 .8497 .3745 .86573 .36219 .85902 .35304 Mtetra
.786 .804 .867 r
.85902 .35304 .86573 .36219 .88188 .3508 .87523 .34131 Mtetra
.769 .794 .873 r
.87523 .34131 .88188 .3508 .89817 .34028 .89158 .33054 Mtetra
.608 .745 .942 r
.28832 .49954 .29722 .50706 .31082 .50403 .30195 .49672 Mtetra
.587 .745 .952 r
.30195 .49672 .31082 .50403 .32448 .50142 .31563 .49437 Mtetra
.557 .743 .964 r
.31563 .49437 .32448 .50142 .33819 .49932 .32936 .4926 Mtetra
.515 .739 .976 r
.32936 .4926 .33819 .49932 .35197 .49782 .34316 .49154 Mtetra
.456 .729 .985 r
.34316 .49154 .35197 .49782 .36581 .49704 .35701 .49128 Mtetra
.371 .707 .986 r
.35701 .49128 .36581 .49704 .37972 .49707 .37093 .49193 Mtetra
.254 .664 .965 r
.37093 .49193 .37972 .49707 .3937 .49801 .38493 .49358 Mtetra
.1 .588 .905 r
.38493 .49358 .3937 .49801 .40777 .49991 .39902 .49629 Mtetra
0 .477 .794 r
.39902 .49629 .40777 .49991 .42194 .50281 .4132 .5001 Mtetra
.25 0 0 r
.4132 .5001 .42194 .50281 .43623 .50671 .42751 .50499 Mtetra
.389 0 0 r
.42751 .50499 .43623 .50671 .45065 .51155 .44196 .51087 Mtetra
.485 0 0 r
.44196 .51087 .45065 .51155 .46521 .51721 .45656 .51761 Mtetra
.544 0 0 r
.45656 .51761 .46521 .51721 .47994 .52353 .47133 .52499 Mtetra
.575 .019 0 r
.47133 .52499 .47994 .52353 .49484 .53026 .4863 .53273 Mtetra
.586 .045 0 r
.4863 .53273 .49484 .53026 .50993 .53708 .50145 .54049 Mtetra
.581 .05 0 r
.50145 .54049 .50993 .53708 .52521 .54365 .51681 .54785 Mtetra
.562 .036 0 r
.51681 .54785 .52521 .54365 .54067 .54957 .53236 .55439 Mtetra
.526 .001 0 r
.53236 .55439 .54067 .54957 .55631 .55444 .5481 .55965 Mtetra
.47 0 0 r
.5481 .55965 .55631 .55444 .5721 .55785 .564 .56322 Mtetra
.387 0 0 r
.564 .56322 .5721 .55785 .58803 .55944 .58004 .5647 Mtetra
.264 0 0 r
.58004 .5647 .58803 .55944 .60406 .55892 .59618 .56381 Mtetra
.09 0 0 r
.59618 .56381 .60406 .55892 .62015 .55608 .61239 .56035 Mtetra
0 0 0 r
.61239 .56035 .62015 .55608 .63628 .55081 .62862 .55424 Mtetra
.392 .828 .685 r
.62862 .55424 .63628 .55081 .65241 .54313 .64484 .54552 Mtetra
.608 .949 .792 r
.64484 .54552 .65241 .54313 .6685 .53316 .66102 .53438 Mtetra
.753 .995 .842 r
.66102 .53438 .6685 .53316 .68454 .52113 .67714 .5211 Mtetra
.833 .993 .854 r
.67714 .5211 .68454 .52113 .70052 .50736 .69318 .50603 Mtetra
.872 .972 .85 r
.69318 .50603 .70052 .50736 .71643 .49221 .70915 .4896 Mtetra
.888 .945 .843 r
.70915 .4896 .71643 .49221 .73227 .4761 .72504 .47226 Mtetra
.891 .919 .836 r
.72504 .47226 .73227 .4761 .74805 .45942 .74088 .45444 Mtetra
.886 .896 .831 r
.74088 .45444 .74805 .45942 .7638 .44257 .75667 .43656 Mtetra
.877 .875 .83 r
.75667 .43656 .7638 .44257 .77954 .42588 .77246 .41897 Mtetra
.866 .857 .831 r
.77246 .41897 .77954 .42588 .7953 .40967 .78826 .40198 Mtetra
.852 .842 .834 r
.78826 .40198 .7953 .40967 .8111 .39414 .80411 .3858 Mtetra
.837 .828 .84 r
.80411 .3858 .8111 .39414 .82697 .37947 .82003 .3706 Mtetra
.82 .816 .846 r
.82003 .3706 .82697 .37947 .84294 .36576 .83605 .35646 Mtetra
.803 .806 .853 r
.83605 .35646 .84294 .36576 .85902 .35304 .85219 .34341 Mtetra
.786 .796 .861 r
.85219 .34341 .85902 .35304 .87523 .34131 .86846 .33143 Mtetra
.769 .787 .868 r
.86846 .33143 .87523 .34131 .89158 .33054 .88488 .32045 Mtetra
.598 .744 .946 r
.27933 .49202 .28832 .49954 .30195 .49672 .29298 .48941 Mtetra
.572 .742 .957 r
.29298 .48941 .30195 .49672 .31563 .49437 .30668 .48735 Mtetra
.537 .739 .969 r
.30668 .48735 .31563 .49437 .32936 .4926 .32043 .48595 Mtetra
.486 .731 .98 r
.32043 .48595 .32936 .4926 .34316 .49154 .33424 .48533 Mtetra
.413 .714 .986 r
.33424 .48533 .34316 .49154 .35701 .49128 .3481 .48561 Mtetra
.311 .681 .977 r
.3481 .48561 .35701 .49128 .37093 .49193 .36203 .4869 Mtetra
.172 .62 .938 r
.36203 .4869 .37093 .49193 .38493 .49358 .37604 .48928 Mtetra
0 .523 .852 r
.37604 .48928 .38493 .49358 .39902 .49629 .39014 .49283 Mtetra
0 .394 .717 r
.39014 .49283 .39902 .49629 .4132 .5001 .40434 .49755 Mtetra
.343 0 0 r
.40434 .49755 .4132 .5001 .42751 .50499 .41867 .50341 Mtetra
.461 0 0 r
.41867 .50341 .42751 .50499 .44196 .51087 .43314 .51031 Mtetra
.538 0 0 r
.43314 .51031 .44196 .51087 .45656 .51761 .44777 .51808 Mtetra
.583 .018 0 r
.44777 .51808 .45656 .51761 .47133 .52499 .46259 .52647 Mtetra
.604 .055 0 r
.46259 .52647 .47133 .52499 .4863 .53273 .4776 .53514 Mtetra
.607 .07 0 r
.4776 .53514 .4863 .53273 .50145 .54049 .49283 .54372 Mtetra
.596 .065 0 r
.49283 .54372 .50145 .54049 .51681 .54785 .50826 .55175 Mtetra
.569 .04 0 r
.50826 .55175 .51681 .54785 .53236 .55439 .5239 .55876 Mtetra
.524 0 0 r
.5239 .55876 .53236 .55439 .5481 .55965 .53974 .56427 Mtetra
.454 0 0 r
.53974 .56427 .5481 .55965 .564 .56322 .55574 .56783 Mtetra
.347 0 0 r
.55574 .56783 .564 .56322 .58004 .5647 .57189 .56905 Mtetra
.187 0 0 r
.57189 .56905 .58004 .5647 .59618 .56381 .58813 .56764 Mtetra
0 0 0 r
.58813 .56764 .59618 .56381 .61239 .56035 .60444 .56342 Mtetra
.312 .785 .683 r
.60444 .56342 .61239 .56035 .62862 .55424 .62077 .55634 Mtetra
.562 .932 .807 r
.62077 .55634 .62862 .55424 .64484 .54552 .63709 .54651 Mtetra
.732 .991 .86 r
.63709 .54651 .64484 .54552 .66102 .53438 .65335 .53415 Mtetra
.825 .991 .866 r
.65335 .53415 .66102 .53438 .67714 .5211 .66955 .51959 Mtetra
.871 .968 .855 r
.66955 .51959 .67714 .5211 .69318 .50603 .68566 .50324 Mtetra
.889 .939 .841 r
.68566 .50324 .69318 .50603 .70915 .4896 .70169 .48558 Mtetra
.894 .912 .828 r
.70169 .48558 .70915 .4896 .72504 .47226 .71764 .46708 Mtetra
.892 .888 .82 r
.71764 .46708 .72504 .47226 .74088 .45444 .73353 .44822 Mtetra
.885 .868 .816 r
.73353 .44822 .74088 .45444 .75667 .43656 .74938 .42942 Mtetra
.875 .851 .816 r
.74938 .42942 .75667 .43656 .77246 .41897 .76522 .41104 Mtetra
.863 .836 .818 r
.76522 .41104 .77246 .41897 .78826 .40198 .78107 .39339 Mtetra
.849 .824 .823 r
.78107 .39339 .78826 .40198 .80411 .3858 .79698 .37668 Mtetra
.834 .813 .83 r
.79698 .37668 .80411 .3858 .82003 .3706 .81296 .36106 Mtetra
.818 .804 .837 r
.81296 .36106 .82003 .3706 .83605 .35646 .82905 .34659 Mtetra
.802 .795 .846 r
.82905 .34659 .83605 .35646 .85219 .34341 .84525 .33329 Mtetra
.785 .787 .855 r
.84525 .33329 .85219 .34341 .86846 .33143 .8616 .32113 Mtetra
.768 .78 .863 r
.8616 .32113 .86846 .33143 .88488 .32045 .87809 .31002 Mtetra
.587 .742 .95 r
.27024 .48447 .27933 .49202 .29298 .48941 .28391 .4821 Mtetra
.557 .739 .961 r
.28391 .4821 .29298 .48941 .30668 .48735 .29763 .48034 Mtetra
.514 .733 .973 r
.29763 .48034 .30668 .48735 .32043 .48595 .31139 .47931 Mtetra
.453 .721 .982 r
.31139 .47931 .32043 .48595 .33424 .48533 .32521 .47916 Mtetra
.367 .696 .983 r
.32521 .47916 .33424 .48533 .3481 .48561 .33909 .47999 Mtetra
.247 .649 .962 r
.33909 .47999 .3481 .48561 .36203 .4869 .35302 .48192 Mtetra
.09 .57 .904 r
.35302 .48192 .36203 .4869 .37604 .48928 .36704 .48505 Mtetra
0 .455 .796 r
.36704 .48505 .37604 .48928 .39014 .49283 .38114 .48941 Mtetra
.269 0 0 r
.38114 .48941 .39014 .49283 .40434 .49755 .39535 .49502 Mtetra
.413 0 0 r
.39535 .49502 .40434 .49755 .41867 .50341 .40969 .50182 Mtetra
.512 0 0 r
.40969 .50182 .41867 .50341 .43314 .51031 .42419 .50968 Mtetra
.575 .001 0 r
.42419 .50968 .43314 .51031 .44777 .51808 .43885 .5184 Mtetra
.609 .051 0 r
.43885 .5184 .44777 .51808 .46259 .52647 .45371 .52769 Mtetra
.623 .077 0 r
.45371 .52769 .46259 .52647 .4776 .53514 .46877 .53718 Mtetra
.62 .082 0 r
.46877 .53718 .4776 .53514 .49283 .54372 .48406 .54644 Mtetra
.602 .066 0 r
.48406 .54644 .49283 .54372 .50826 .55175 .49956 .55499 Mtetra
.567 .027 0 r
.49956 .55499 .50826 .55175 .5239 .55876 .51529 .5623 Mtetra
.509 0 0 r
.51529 .5623 .5239 .55876 .53974 .56427 .53121 .56788 Mtetra
.417 0 0 r
.53121 .56788 .53974 .56427 .55574 .56783 .54732 .57126 Mtetra
.273 0 0 r
.54732 .57126 .55574 .56783 .57189 .56905 .56356 .57204 Mtetra
.055 0 0 r
.56356 .57204 .57189 .56905 .58813 .56764 .57991 .56996 Mtetra
.229 .739 .698 r
.57991 .56996 .58813 .56764 .60444 .56342 .59632 .56485 Mtetra
.51 .912 .837 r
.59632 .56485 .60444 .56342 .62077 .55634 .61275 .55673 Mtetra
.706 .983 .89 r
.61275 .55673 .62077 .55634 .63709 .54651 .62915 .54573 Mtetra
.813 .984 .888 r
.62915 .54573 .63709 .54651 .65335 .53415 .6455 .53213 Mtetra
.864 .958 .866 r
.6455 .53213 .65335 .53415 .66955 .51959 .66177 .51631 Mtetra
.886 .928 .843 r
.66177 .51631 .66955 .51959 .68566 .50324 .67796 .49875 Mtetra
.893 .899 .825 r
.67796 .49875 .68566 .50324 .70169 .48558 .69405 .47994 Mtetra
.892 .876 .813 r
.69405 .47994 .70169 .48558 .71764 .46708 .71006 .4604 Mtetra
.887 .856 .805 r
.71006 .4604 .71764 .46708 .73353 .44822 .72601 .44062 Mtetra
.879 .84 .802 r
.72601 .44062 .73353 .44822 .74938 .42942 .74192 .42104 Mtetra
.87 .827 .803 r
.74192 .42104 .74938 .42942 .76522 .41104 .75782 .40201 Mtetra
.858 .816 .807 r
.75782 .40201 .76522 .41104 .78107 .39339 .77374 .38384 Mtetra
.845 .806 .813 r
.77374 .38384 .78107 .39339 .79698 .37668 .78971 .36673 Mtetra
.83 .798 .821 r
.78971 .36673 .79698 .37668 .81296 .36106 .80576 .35081 Mtetra
.815 .791 .83 r
.80576 .35081 .81296 .36106 .82905 .34659 .82192 .33612 Mtetra
.799 .785 .84 r
.82192 .33612 .82905 .34659 .84525 .33329 .8382 .32268 Mtetra
.782 .779 .85 r
.8382 .32268 .84525 .33329 .8616 .32113 .85462 .31041 Mtetra
.766 .773 .859 r
.85462 .31041 .8616 .32113 .87809 .31002 .87119 .29924 Mtetra
.575 .739 .954 r
.26105 .4769 .27024 .48447 .28391 .4821 .27474 .47476 Mtetra
.539 .735 .965 r
.27474 .47476 .28391 .4821 .29763 .48034 .28847 .47331 Mtetra
.49 .726 .976 r
.28847 .47331 .29763 .48034 .31139 .47931 .30225 .47267 Mtetra
.419 .708 .983 r
.30225 .47267 .31139 .47931 .32521 .47916 .31608 .47298 Mtetra
.319 .674 .976 r
.31608 .47298 .32521 .47916 .33909 .47999 .32996 .47436 Mtetra
.184 .614 .943 r
.32996 .47436 .33909 .47999 .35302 .48192 .3439 .47693 Mtetra
.014 .519 .867 r
.3439 .47693 .35302 .48192 .36704 .48505 .35792 .48076 Mtetra
0 .393 .743 r
.35792 .48076 .36704 .48505 .38114 .48941 .37203 .48591 Mtetra
.335 0 0 r
.37203 .48591 .38114 .48941 .39535 .49502 .38625 .49236 Mtetra
.462 0 0 r
.38625 .49236 .39535 .49502 .40969 .50182 .4006 .50003 Mtetra
.547 0 0 r
.4006 .50003 .40969 .50182 .42419 .50968 .41511 .50876 Mtetra
.598 .029 0 r
.41511 .50876 .42419 .50968 .43885 .5184 .4298 .51832 Mtetra
.625 .068 0 r
.4298 .51832 .43885 .5184 .45371 .52769 .44469 .52838 Mtetra
.633 .085 0 r
.44469 .52838 .45371 .52769 .46877 .53718 .4598 .53853 Mtetra
.624 .079 0 r
.4598 .53853 .46877 .53718 .48406 .54644 .47514 .54831 Mtetra
.599 .051 0 r
.47514 .54831 .48406 .54644 .49956 .55499 .49072 .55718 Mtetra
.553 0 0 r
.49072 .55718 .49956 .55499 .51529 .5623 .50652 .5646 Mtetra
.474 0 0 r
.50652 .5646 .51529 .5623 .53121 .56788 .52254 .57005 Mtetra
.346 0 0 r
.52254 .57005 .53121 .56788 .54732 .57126 .53873 .57306 Mtetra
.142 0 0 r
.53873 .57306 .54732 .57126 .56356 .57204 .55507 .57325 Mtetra
.145 .687 .724 r
.55507 .57325 .56356 .57204 .57991 .56996 .57152 .57036 Mtetra
.45 .883 .877 r
.57152 .57036 .57991 .56996 .59632 .56485 .58802 .56427 Mtetra
.672 .966 .928 r
.58802 .56427 .59632 .56485 .61275 .55673 .60454 .55503 Mtetra
.792 .969 .914 r
.60454 .55503 .61275 .55673 .62915 .54573 .62103 .54284 Mtetra
.85 .942 .881 r
.62103 .54284 .62915 .54573 .6455 .53213 .63746 .52803 Mtetra
.875 .91 .85 r
.63746 .52803 .6455 .53213 .66177 .51631 .6538 .51102 Mtetra
.885 .882 .825 r
.6538 .51102 .66177 .51631 .67796 .49875 .67006 .49234 Mtetra
.887 .859 .808 r
.67006 .49234 .67796 .49875 .69405 .47994 .68622 .47252 Mtetra
.884 .84 .797 r
.68622 .47252 .69405 .47994 .71006 .4604 .7023 .45209 Mtetra
.879 .825 .791 r
.7023 .45209 .71006 .4604 .72601 .44062 .71831 .43155 Mtetra
.871 .813 .789 r
.71831 .43155 .72601 .44062 .74192 .42104 .73429 .41135 Mtetra
.862 .803 .792 r
.73429 .41135 .74192 .42104 .75782 .40201 .75026 .39185 Mtetra
.851 .796 .797 r
.75026 .39185 .75782 .40201 .77374 .38384 .76625 .37332 Mtetra
.839 .789 .804 r
.76625 .37332 .77374 .38384 .78971 .36673 .7823 .35595 Mtetra
.825 .784 .814 r
.7823 .35595 .78971 .36673 .80576 .35081 .79843 .33986 Mtetra
.81 .779 .824 r
.79843 .33986 .80576 .35081 .82192 .33612 .81467 .32507 Mtetra
.795 .775 .835 r
.81467 .32507 .82192 .33612 .8382 .32268 .83103 .31157 Mtetra
.779 .771 .846 r
.83103 .31157 .8382 .32268 .85462 .31041 .84754 .29929 Mtetra
.763 .767 .856 r
.84754 .29929 .85462 .31041 .87119 .29924 .8642 .28813 Mtetra
.562 .736 .957 r
.25176 .46928 .26105 .4769 .27474 .47476 .26547 .46739 Mtetra
.522 .729 .968 r
.26547 .46739 .27474 .47476 .28847 .47331 .27922 .46624 Mtetra
.465 .717 .978 r
.27922 .46624 .28847 .47331 .30225 .47267 .29301 .46598 Mtetra
.385 .693 .981 r
.29301 .46598 .30225 .47267 .31608 .47298 .30684 .46674 Mtetra
.273 .649 .967 r
.30684 .46674 .31608 .47298 .32996 .47436 .32072 .46866 Mtetra
.126 .577 .922 r
.32072 .46866 .32996 .47436 .3439 .47693 .33467 .47182 Mtetra
0 .471 .832 r
.33467 .47182 .3439 .47693 .35792 .48076 .34869 .47633 Mtetra
0 .341 .701 r
.34869 .47633 .35792 .48076 .37203 .48591 .3628 .4822 Mtetra
.381 0 0 r
.3628 .4822 .37203 .48591 .38625 .49236 .37702 .4894 Mtetra
.493 0 0 r
.37702 .4894 .38625 .49236 .4006 .50003 .39138 .49783 Mtetra
.567 0 0 r
.39138 .49783 .4006 .50003 .41511 .50876 .40591 .50731 Mtetra
.61 .042 0 r
.40591 .50731 .41511 .50876 .4298 .51832 .42062 .51757 Mtetra
.631 .072 0 r
.42062 .51757 .4298 .51832 .44469 .52838 .43555 .52823 Mtetra
.633 .078 0 r
.43555 .52823 .44469 .52838 .4598 .53853 .4507 .53886 Mtetra
.618 .061 0 r
.4507 .53886 .4598 .53853 .47514 .54831 .4661 .54894 Mtetra
.582 .017 0 r
.4661 .54894 .47514 .54831 .49072 .55718 .48174 .55793 Mtetra
.516 0 0 r
.48174 .55793 .49072 .55718 .50652 .5646 .49762 .56525 Mtetra
.404 0 0 r
.49762 .56525 .50652 .5646 .52254 .57005 .51371 .57038 Mtetra
.216 0 0 r
.51371 .57038 .52254 .57005 .53873 .57306 .52999 .57284 Mtetra
.064 .628 .754 r
.52999 .57284 .53873 .57306 .55507 .57325 .54642 .57228 Mtetra
.383 .837 .917 r
.54642 .57228 .55507 .57325 .57152 .57036 .56296 .56846 Mtetra
.625 .933 .966 r
.56296 .56846 .57152 .57036 .58802 .56427 .57955 .56132 Mtetra
.76 .941 .941 r
.57955 .56132 .58802 .56427 .60454 .55503 .59615 .55094 Mtetra
.826 .916 .898 r
.59615 .55094 .60454 .55503 .62103 .54284 .61272 .53759 Mtetra
.857 .886 .858 r
.61272 .53759 .62103 .54284 .63746 .52803 .62923 .52163 Mtetra
.871 .86 .827 r
.62923 .52163 .63746 .52803 .6538 .51102 .64565 .50355 Mtetra
.876 .838 .805 r
.64565 .50355 .6538 .51102 .67006 .49234 .66198 .48389 Mtetra
.876 .82 .79 r
.66198 .48389 .67006 .49234 .68622 .47252 .67821 .46322 Mtetra
.873 .807 .782 r
.67821 .46322 .68622 .47252 .7023 .45209 .69436 .44208 Mtetra
.868 .796 .778 r
.69436 .44208 .7023 .45209 .71831 .43155 .71045 .42098 Mtetra
.861 .788 .778 r
.71045 .42098 .71831 .43155 .73429 .41135 .7265 .40036 Mtetra
.853 .782 .782 r
.7265 .40036 .73429 .41135 .75026 .39185 .74255 .38056 Mtetra
.843 .777 .789 r
.74255 .38056 .75026 .39185 .76625 .37332 .75862 .36183 Mtetra
.831 .774 .797 r
.75862 .36183 .76625 .37332 .7823 .35595 .77476 .34436 Mtetra
.818 .771 .808 r
.77476 .34436 .7823 .35595 .79843 .33986 .79098 .32823 Mtetra
.804 .768 .819 r
.79098 .32823 .79843 .33986 .81467 .32507 .80731 .31346 Mtetra
.79 .765 .831 r
.80731 .31346 .81467 .32507 .83103 .31157 .82376 .30001 Mtetra
.774 .763 .843 r
.82376 .30001 .83103 .31157 .84754 .29929 .84036 .2878 Mtetra
.759 .76 .854 r
.84036 .2878 .84754 .29929 .8642 .28813 .85711 .2767 Mtetra
.55 .732 .96 r
.24238 .46159 .25176 .46928 .26547 .46739 .25611 .45994 Mtetra
.504 .723 .971 r
.25611 .45994 .26547 .46739 .27922 .46624 .26987 .4591 Mtetra
.441 .706 .978 r
.26987 .4591 .27922 .46624 .29301 .46598 .28366 .4592 Mtetra
.352 .676 .977 r
.28366 .4592 .29301 .46598 .30684 .46674 .2975 .46039 Mtetra
.232 .624 .956 r
.2975 .46039 .30684 .46674 .32072 .46866 .31139 .46279 Mtetra
.078 .543 .902 r
.31139 .46279 .32072 .46866 .33467 .47182 .32533 .46651 Mtetra
0 .431 .805 r
.32533 .46651 .33467 .47182 .34869 .47633 .33935 .47161 Mtetra
0 .302 .675 r
.33935 .47161 .34869 .47633 .3628 .4822 .35346 .47811 Mtetra
.407 0 0 r
.35346 .47811 .3628 .4822 .37702 .4894 .36769 .48596 Mtetra
.508 0 0 r
.36769 .48596 .37702 .4894 .39138 .49783 .38206 .49503 Mtetra
.573 0 0 r
.38206 .49503 .39138 .49783 .40591 .50731 .3966 .50511 Mtetra
.61 .041 0 r
.3966 .50511 .40591 .50731 .42062 .51757 .41134 .51588 Mtetra
.625 .06 0 r
.41134 .51588 .42062 .51757 .43555 .52823 .4263 .52695 Mtetra
.62 .055 0 r
.4263 .52695 .43555 .52823 .4507 .53886 .44149 .53784 Mtetra
.594 .022 0 r
.44149 .53784 .4507 .53886 .4661 .54894 .45694 .54801 Mtetra
.539 0 0 r
.45694 .54801 .4661 .54894 .48174 .55793 .47264 .55689 Mtetra
.441 0 0 r
.47264 .55689 .48174 .55793 .49762 .56525 .48859 .5639 Mtetra
.271 0 0 r
.48859 .5639 .49762 .56525 .51371 .57038 .50476 .5685 Mtetra
0 .562 .782 r
.50476 .5685 .51371 .57038 .52999 .57284 .52111 .57025 Mtetra
.309 .772 .945 r
.52111 .57025 .52999 .57284 .54642 .57228 .53763 .5688 Mtetra
.565 .879 .992 r
.53763 .5688 .54642 .57228 .56296 .56846 .55424 .56397 Mtetra
.715 .898 .962 r
.55424 .56397 .56296 .56846 .57955 .56132 .57091 .55573 Mtetra
.791 .88 .911 r
.57091 .55573 .57955 .56132 .59615 .55094 .58759 .54424 Mtetra
.83 .855 .865 r
.58759 .54424 .59615 .55094 .61272 .53759 .60424 .52978 Mtetra
.849 .832 .83 r
.60424 .52978 .61272 .53759 .62923 .52163 .62082 .51279 Mtetra
.858 .813 .804 r
.62082 .51279 .62923 .52163 .64565 .50355 .63732 .49379 Mtetra
.862 .797 .786 r
.63732 .49379 .64565 .50355 .66198 .48389 .65372 .47333 Mtetra
.862 .786 .775 r
.65372 .47333 .66198 .48389 .67821 .46322 .67003 .45201 Mtetra
.86 .777 .769 r
.67003 .45201 .67821 .46322 .69436 .44208 .68626 .43038 Mtetra
.856 .771 .767 r
.68626 .43038 .69436 .44208 .71045 .42098 .70242 .40893 Mtetra
.85 .766 .769 r
.70242 .40893 .71045 .42098 .7265 .40036 .71856 .38808 Mtetra
.842 .763 .774 r
.71856 .38808 .7265 .40036 .74255 .38056 .7347 .36817 Mtetra
.834 .761 .782 r
.7347 .36817 .74255 .38056 .75862 .36183 .75086 .34942 Mtetra
.823 .759 .792 r
.75086 .34942 .75862 .36183 .77476 .34436 .76709 .332 Mtetra
.811 .758 .803 r
.76709 .332 .77476 .34436 .79098 .32823 .78341 .31597 Mtetra
.798 .757 .816 r
.78341 .31597 .79098 .32823 .80731 .31346 .79983 .30133 Mtetra
.784 .757 .828 r
.79983 .30133 .80731 .31346 .82376 .30001 .81639 .28802 Mtetra
.769 .756 .841 r
.81639 .28802 .82376 .30001 .84036 .2878 .83308 .27595 Mtetra
.754 .754 .853 r
.83308 .27595 .84036 .2878 .85711 .2767 .84993 .26499 Mtetra
.537 .727 .962 r
.2329 .45382 .24238 .46159 .25611 .45994 .24664 .45239 Mtetra
.488 .716 .972 r
.24664 .45239 .25611 .45994 .26987 .4591 .26041 .45182 Mtetra
.419 .695 .978 r
.26041 .45182 .26987 .4591 .28366 .4592 .27422 .45226 Mtetra
.324 .66 .972 r
.27422 .45226 .28366 .4592 .2975 .46039 .28806 .45383 Mtetra
.198 .601 .946 r
.28806 .45383 .2975 .46039 .31139 .46279 .30195 .45668 Mtetra
.042 .514 .886 r
.30195 .45668 .31139 .46279 .32533 .46651 .31589 .46088 Mtetra
0 .402 .788 r
.31589 .46088 .32533 .46651 .33935 .47161 .32991 .46649 Mtetra
0 .278 .665 r
.32991 .46649 .33935 .47161 .35346 .47811 .34403 .47351 Mtetra
.415 0 0 r
.34403 .47351 .35346 .47811 .36769 .48596 .35826 .48188 Mtetra
.506 0 0 r
.35826 .48188 .36769 .48596 .38206 .49503 .37264 .49142 Mtetra
.564 0 0 r
.37264 .49142 .38206 .49503 .3966 .50511 .3872 .50191 Mtetra
.594 .022 0 r
.3872 .50191 .3966 .50511 .41134 .51588 .40196 .51299 Mtetra
.602 .031 0 r
.40196 .51299 .41134 .51588 .4263 .52695 .41695 .52425 Mtetra
.586 .011 0 r
.41695 .52425 .4263 .52695 .44149 .53784 .43218 .53517 Mtetra
.541 0 0 r
.43218 .53517 .44149 .53784 .45694 .54801 .44768 .54519 Mtetra
.454 0 0 r
.44768 .54519 .45694 .54801 .47264 .55689 .46344 .55373 Mtetra
.301 0 0 r
.46344 .55373 .47264 .55689 .48859 .5639 .47945 .56021 Mtetra
0 .495 .8 r
.47945 .56021 .48859 .5639 .50476 .5685 .49568 .56411 Mtetra
.237 .692 .952 r
.49568 .56411 .50476 .5685 .52111 .57025 .51211 .56499 Mtetra
.494 .806 1 r
.51211 .56499 .52111 .57025 .53763 .5688 .5287 .56256 Mtetra
.657 .839 .97 r
.5287 .56256 .53763 .5688 .55424 .56397 .54539 .55667 Mtetra
.746 .834 .918 r
.54539 .55667 .55424 .56397 .57091 .55573 .56213 .54735 Mtetra
.794 .817 .87 r
.56213 .54735 .57091 .55573 .58759 .54424 .57889 .53479 Mtetra
.821 .799 .832 r
.57889 .53479 .58759 .54424 .60424 .52978 .59561 .51935 Mtetra
.835 .784 .803 r
.59561 .51935 .60424 .52978 .62082 .51279 .61226 .50148 Mtetra
.843 .772 .783 r
.61226 .50148 .62082 .51279 .63732 .49379 .62883 .48173 Mtetra
.847 .763 .769 r
.62883 .48173 .63732 .49379 .65372 .47333 .64531 .46069 Mtetra
.848 .756 .761 r
.64531 .46069 .65372 .47333 .67003 .45201 .66169 .43894 Mtetra
.846 .751 .758 r
.66169 .43894 .67003 .45201 .68626 .43038 .678 .41703 Mtetra
.843 .748 .758 r
.678 .41703 .68626 .43038 .70242 .40893 .69425 .39545 Mtetra
.838 .746 .762 r
.69425 .39545 .70242 .40893 .71856 .38808 .71048 .37459 Mtetra
.832 .745 .768 r
.71048 .37459 .71856 .38808 .7347 .36817 .72671 .35475 Mtetra
.824 .746 .777 r
.72671 .35475 .7347 .36817 .75086 .34942 .74298 .33617 Mtetra
.814 .746 .788 r
.74298 .33617 .75086 .34942 .76709 .332 .7593 .31895 Mtetra
.803 .747 .801 r
.7593 .31895 .76709 .332 .78341 .31597 .77572 .30314 Mtetra
.791 .748 .814 r
.77572 .30314 .78341 .31597 .79983 .30133 .79225 .28873 Mtetra
.777 .749 .827 r
.79225 .28873 .79983 .30133 .81639 .28802 .80891 .27565 Mtetra
.763 .749 .84 r
.80891 .27565 .81639 .28802 .83308 .27595 .82571 .26379 Mtetra
.749 .749 .852 r
.82571 .26379 .83308 .27595 .84993 .26499 .84266 .25301 Mtetra
.526 .722 .963 r
.22332 .44593 .2329 .45382 .24664 .45239 .23708 .4447 Mtetra
.473 .708 .972 r
.23708 .4447 .24664 .45239 .26041 .45182 .25086 .44439 Mtetra
.4 .684 .976 r
.25086 .44439 .26041 .45182 .27422 .45226 .26468 .44511 Mtetra
.302 .644 .968 r
.26468 .44511 .27422 .45226 .28806 .45383 .27853 .44702 Mtetra
.174 .582 .938 r
.27853 .44702 .28806 .45383 .30195 .45668 .29242 .45023 Mtetra
.022 .493 .877 r
.29242 .45023 .30195 .45668 .31589 .46088 .30637 .45482 Mtetra
0 .385 .784 r
.30637 .45482 .31589 .46088 .32991 .46649 .32039 .46083 Mtetra
0 .27 .672 r
.32039 .46083 .32991 .46649 .34403 .47351 .33451 .46825 Mtetra
.403 0 0 r
.33451 .46825 .34403 .47351 .35826 .48188 .34875 .47697 Mtetra
.485 0 0 r
.34875 .47697 .35826 .48188 .37264 .49142 .36314 .48681 Mtetra
.535 0 0 r
.36314 .48681 .37264 .49142 .3872 .50191 .37771 .4975 Mtetra
.558 0 0 r
.37771 .4975 .3872 .50191 .40196 .51299 .3925 .50868 Mtetra
.553 0 0 r
.3925 .50868 .40196 .51299 .41695 .52425 .40752 .51989 Mtetra
.518 0 0 r
.40752 .51989 .41695 .52425 .43218 .53517 .42279 .5306 Mtetra
.441 0 0 r
.42279 .5306 .43218 .53517 .44768 .54519 .43834 .54024 Mtetra
0 .265 .648 r
.43834 .54024 .44768 .54519 .46344 .55373 .45415 .54822 Mtetra
0 .436 .81 r
.45415 .54822 .46344 .55373 .47945 .56021 .47021 .55397 Mtetra
.177 .608 .941 r
.47021 .55397 .47945 .56021 .49568 .56411 .48651 .557 Mtetra
.421 .723 .988 r
.48651 .557 .49568 .56411 .51211 .56499 .50301 .55689 Mtetra
.591 .771 .966 r
.50301 .55689 .51211 .56499 .5287 .56256 .51966 .55341 Mtetra
.692 .78 .918 r
.51966 .55341 .5287 .56256 .54539 .55667 .53642 .54645 Mtetra
.751 .773 .871 r
.53642 .54645 .54539 .55667 .56213 .54735 .55323 .53609 Mtetra
.786 .763 .832 r
.55323 .53609 .56213 .54735 .57889 .53479 .57005 .52257 Mtetra
.807 .753 .802 r
.57005 .52257 .57889 .53479 .59561 .51935 .58683 .50629 Mtetra
.82 .744 .78 r
.58683 .50629 .59561 .51935 .61226 .50148 .60355 .48773 Mtetra
.828 .738 .765 r
.60355 .48773 .61226 .50148 .62883 .48173 .6202 .46745 Mtetra
.832 .733 .755 r
.6202 .46745 .62883 .48173 .64531 .46069 .63675 .44606 Mtetra
.834 .73 .75 r
.63675 .44606 .64531 .46069 .66169 .43894 .65321 .42412 Mtetra
.833 .729 .749 r
.65321 .42412 .66169 .43894 .678 .41703 .66961 .40217 Mtetra
.831 .728 .751 r
.66961 .40217 .678 .41703 .69425 .39545 .68595 .38067 Mtetra
.827 .729 .756 r
.68595 .38067 .69425 .39545 .71048 .37459 .70227 .36 Mtetra
.822 .731 .764 r
.70227 .36 .71048 .37459 .72671 .35475 .71861 .34043 Mtetra
.814 .733 .774 r
.71861 .34043 .72671 .35475 .74298 .33617 .73497 .32216 Mtetra
.806 .735 .786 r
.73497 .32216 .74298 .33617 .7593 .31895 .75141 .30528 Mtetra
.795 .738 .799 r
.75141 .30528 .7593 .31895 .77572 .30314 .76794 .28981 Mtetra
.783 .74 .813 r
.76794 .28981 .77572 .30314 .79225 .28873 .78457 .27573 Mtetra
.771 .742 .827 r
.78457 .27573 .79225 .28873 .80891 .27565 .80134 .26295 Mtetra
.757 .744 .84 r
.80134 .26295 .80891 .27565 .82571 .26379 .81825 .25136 Mtetra
.744 .745 .853 r
.81825 .25136 .82571 .26379 .84266 .25301 .83531 .2408 Mtetra
.516 .717 .963 r
.21365 .43789 .22332 .44593 .23708 .4447 .22742 .43685 Mtetra
.461 .701 .971 r
.22742 .43685 .23708 .4447 .25086 .44439 .24122 .43674 Mtetra
.386 .674 .973 r
.24122 .43674 .25086 .44439 .26468 .44511 .25504 .4377 Mtetra
.287 .631 .963 r
.25504 .4377 .26468 .44511 .27853 .44702 .2689 .43988 Mtetra
.162 .567 .932 r
.2689 .43988 .27853 .44702 .29242 .45023 .2828 .44337 Mtetra
.018 .481 .875 r
.2828 .44337 .29242 .45023 .30637 .45482 .29675 .44824 Mtetra
0 .38 .791 r
.29675 .44824 .30637 .45482 .32039 .46083 .31078 .45453 Mtetra
0 .277 .696 r
.31078 .45453 .32039 .46083 .33451 .46825 .32491 .46218 Mtetra
0 .187 .605 r
.32491 .46218 .33451 .46825 .34875 .47697 .33916 .47108 Mtetra
.442 0 0 r
.33916 .47108 .34875 .47697 .36314 .48681 .35357 .48102 Mtetra
.482 0 0 r
.35357 .48102 .36314 .48681 .37771 .4975 .36816 .49171 Mtetra
.491 0 0 r
.36816 .49171 .37771 .4975 .3925 .50868 .38297 .50275 Mtetra
.467 0 0 r
.38297 .50275 .3925 .50868 .40752 .51989 .39803 .51367 Mtetra
.402 0 0 r
.39803 .51367 .40752 .51989 .42279 .5306 .41334 .52393 Mtetra
0 .254 .686 r
.41334 .52393 .42279 .5306 .43834 .54024 .42893 .53296 Mtetra
0 .391 .814 r
.42893 .53296 .43834 .54024 .45415 .54822 .44479 .54018 Mtetra
.134 .534 .919 r
.44479 .54018 .45415 .54822 .47021 .55397 .46091 .54503 Mtetra
.356 .642 .963 r
.46091 .54503 .47021 .55397 .48651 .557 .47727 .54705 Mtetra
.524 .7 .95 r
.47727 .54705 .48651 .557 .50301 .55689 .49382 .54589 Mtetra
.635 .722 .911 r
.49382 .54589 .50301 .55689 .51966 .55341 .51053 .54133 Mtetra
.704 .727 .868 r
.51053 .54133 .51966 .55341 .53642 .54645 .52734 .53333 Mtetra
.747 .724 .831 r
.52734 .53333 .53642 .54645 .55323 .53609 .54421 .52202 Mtetra
.775 .72 .801 r
.54421 .52202 .55323 .53609 .57005 .52257 .56109 .50768 Mtetra
.793 .715 .779 r
.56109 .50768 .57005 .52257 .58683 .50629 .57794 .49073 Mtetra
.805 .712 .762 r
.57794 .49073 .58683 .50629 .60355 .48773 .59473 .47168 Mtetra
.813 .71 .751 r
.59473 .47168 .60355 .48773 .6202 .46745 .61144 .45111 Mtetra
.818 .709 .745 r
.61144 .45111 .6202 .46745 .63675 .44606 .62806 .4296 Mtetra
.82 .709 .742 r
.62806 .4296 .63675 .44606 .65321 .42412 .64461 .4077 Mtetra
.821 .71 .743 r
.64461 .4077 .65321 .42412 .66961 .40217 .66109 .38594 Mtetra
.819 .712 .746 r
.66109 .38594 .66961 .40217 .68595 .38067 .67753 .36475 Mtetra
.816 .714 .753 r
.67753 .36475 .68595 .38067 .70227 .36 .69395 .34446 Mtetra
.811 .718 .762 r
.69395 .34446 .70227 .36 .71861 .34043 .71039 .32533 Mtetra
.805 .722 .773 r
.71039 .32533 .71861 .34043 .73497 .32216 .72687 .30751 Mtetra
.797 .726 .786 r
.72687 .30751 .73497 .32216 .75141 .30528 .74341 .29109 Mtetra
.787 .73 .799 r
.74341 .29109 .75141 .30528 .76794 .28981 .76005 .27607 Mtetra
.776 .733 .814 r
.76005 .27607 .76794 .28981 .78457 .27573 .77681 .2624 Mtetra
.763 .736 .828 r
.77681 .2624 .78457 .27573 .80134 .26295 .79369 .24998 Mtetra
.751 .739 .841 r
.79369 .24998 .80134 .26295 .81825 .25136 .81071 .2387 Mtetra
.738 .741 .854 r
.81071 .2387 .81825 .25136 .83531 .2408 .82787 .22841 Mtetra
.509 .712 .963 r
.20389 .42969 .21365 .43789 .22742 .43685 .21768 .42878 Mtetra
.453 .694 .97 r
.21768 .42878 .22742 .43685 .24122 .43674 .23149 .42883 Mtetra
.378 .665 .97 r
.23149 .42883 .24122 .43674 .25504 .4377 .24532 .42998 Mtetra
.281 .621 .96 r
.24532 .42998 .25504 .4377 .2689 .43988 .25919 .43234 Mtetra
.162 .559 .931 r
.25919 .43234 .2689 .43988 .2828 .44337 .2731 .43601 Mtetra
.029 .478 .879 r
.2731 .43601 .2828 .44337 .29675 .44824 .28706 .44105 Mtetra
0 .386 .809 r
.28706 .44105 .29675 .44824 .31078 .45453 .3011 .44747 Mtetra
0 .296 .731 r
.3011 .44747 .31078 .45453 .32491 .46218 .31524 .45519 Mtetra
0 .22 .66 r
.31524 .45519 .32491 .46218 .33916 .47108 .32951 .46409 Mtetra
0 .167 .61 r
.32951 .46409 .33916 .47108 .35357 .48102 .34394 .47392 Mtetra
0 .141 .588 r
.34394 .47392 .35357 .48102 .36816 .49171 .35856 .48438 Mtetra
0 .146 .599 r
.35856 .48438 .36816 .49171 .38297 .50275 .3734 .49505 Mtetra
0 .185 .645 r
.3734 .49505 .38297 .50275 .39803 .51367 .38849 .50546 Mtetra
0 .26 .723 r
.38849 .50546 .39803 .51367 .41334 .52393 .40385 .51505 Mtetra
0 .364 .817 r
.40385 .51505 .41334 .52393 .42893 .53296 .41949 .52327 Mtetra
.11 .477 .896 r
.41949 .52327 .42893 .53296 .44479 .54018 .43539 .52954 Mtetra
.304 .572 .934 r
.43539 .52954 .44479 .54018 .46091 .54503 .45156 .53335 Mtetra
.463 .634 .928 r
.45156 .53335 .46091 .54503 .47727 .54705 .46797 .53428 Mtetra
.577 .665 .898 r
.46797 .53428 .47727 .54705 .49382 .54589 .48457 .53201 Mtetra
.654 .68 .862 r
.48457 .53201 .49382 .54589 .51053 .54133 .50133 .52639 Mtetra
.705 .685 .828 r
.50133 .52639 .51053 .54133 .52734 .53333 .51819 .51743 Mtetra
.74 .686 .799 r
.51819 .51743 .52734 .53333 .54421 .52202 .53511 .50529 Mtetra
.763 .686 .777 r
.53511 .50529 .54421 .52202 .56109 .50768 .55204 .49029 Mtetra
.78 .686 .76 r
.55204 .49029 .56109 .50768 .57794 .49073 .56895 .47288 Mtetra
.792 .686 .748 r
.56895 .47288 .57794 .49073 .59473 .47168 .58579 .45357 Mtetra
.799 .687 .741 r
.58579 .45357 .59473 .47168 .61144 .45111 .60257 .43293 Mtetra
.805 .689 .737 r
.60257 .43293 .61144 .45111 .62806 .4296 .61927 .41154 Mtetra
.808 .691 .736 r
.61927 .41154 .62806 .4296 .64461 .4077 .6359 .38993 Mtetra
.809 .694 .738 r
.6359 .38993 .64461 .4077 .66109 .38594 .65247 .36857 Mtetra
.808 .698 .744 r
.65247 .36857 .66109 .38594 .67753 .36475 .66901 .34787 Mtetra
.805 .702 .751 r
.66901 .34787 .67753 .36475 .69395 .34446 .68553 .32813 Mtetra
.801 .707 .761 r
.68553 .32813 .69395 .34446 .71039 .32533 .70208 .30958 Mtetra
.795 .712 .773 r
.70208 .30958 .71039 .32533 .72687 .30751 .71867 .29235 Mtetra
.788 .718 .786 r
.71867 .29235 .72687 .30751 .74341 .29109 .73533 .2765 Mtetra
.778 .723 .801 r
.73533 .2765 .74341 .29109 .76005 .27607 .75208 .262 Mtetra
.768 .727 .815 r
.75208 .262 .76005 .27607 .77681 .2624 .76895 .2488 Mtetra
.756 .732 .83 r
.76895 .2488 .77681 .2624 .79369 .24998 .78595 .23679 Mtetra
.744 .735 .843 r
.78595 .23679 .79369 .24998 .81071 .2387 .80308 .22586 Mtetra
.732 .737 .856 r
.80308 .22586 .81071 .2387 .82787 .22841 .82035 .21586 Mtetra
.504 .707 .962 r
.19403 .42129 .20389 .42969 .21768 .42878 .20784 .42047 Mtetra
.448 .688 .968 r
.20784 .42047 .21768 .42878 .23149 .42883 .22167 .42063 Mtetra
.375 .658 .968 r
.22167 .42063 .23149 .42883 .24532 .42998 .23552 .42188 Mtetra
.283 .615 .957 r
.23552 .42188 .24532 .42998 .25919 .43234 .2494 .42434 Mtetra
.174 .556 .931 r
.2494 .42434 .25919 .43234 .2731 .43601 .26333 .42809 Mtetra
.055 .483 .888 r
.26333 .42809 .2731 .43601 .28706 .44105 .27731 .43317 Mtetra
0 .403 .832 r
.27731 .43317 .28706 .44105 .3011 .44747 .29137 .43956 Mtetra
0 .326 .773 r
.29137 .43956 .3011 .44747 .31524 .45519 .30553 .44719 Mtetra
0 .265 .722 r
.30553 .44719 .31524 .45519 .32951 .46409 .31982 .4559 Mtetra
0 .226 .691 r
.31982 .4559 .32951 .46409 .34394 .47392 .33427 .46542 Mtetra
0 .214 .687 r
.33427 .46542 .34394 .47392 .35856 .48438 .34893 .47544 Mtetra
0 .232 .711 r
.34893 .47544 .35856 .48438 .3734 .49505 .36381 .48553 Mtetra
0 .28 .76 r
.36381 .48553 .3734 .49505 .38849 .50546 .37894 .4952 Mtetra
0 .354 .822 r
.37894 .4952 .38849 .50546 .40385 .51505 .39434 .50392 Mtetra
.104 .44 .878 r
.39434 .50392 .40385 .51505 .41949 .52327 .41002 .51114 Mtetra
.268 .518 .907 r
.41002 .51114 .41949 .52327 .43539 .52954 .42597 .51633 Mtetra
.412 .577 .906 r
.42597 .51633 .43539 .52954 .45156 .53335 .44219 .51901 Mtetra
.525 .614 .884 r
.44219 .51901 .45156 .53335 .46797 .53428 .45864 .51879 Mtetra
.606 .635 .854 r
.45864 .51879 .46797 .53428 .48457 .53201 .47528 .51542 Mtetra
.663 .647 .824 r
.47528 .51542 .48457 .53201 .50133 .52639 .49208 .5088 Mtetra
.703 .653 .797 r
.49208 .5088 .50133 .52639 .51819 .51743 .50899 .49897 Mtetra
.732 .657 .776 r
.50899 .49897 .51819 .51743 .53511 .50529 .52595 .48616 Mtetra
.753 .66 .759 r
.52595 .48616 .53511 .50529 .55204 .49029 .54292 .47069 Mtetra
.768 .663 .746 r
.54292 .47069 .55204 .49029 .56895 .47288 .55988 .45302 Mtetra
.779 .666 .738 r
.55988 .45302 .56895 .47288 .58579 .45357 .57678 .43368 Mtetra
.787 .669 .733 r
.57678 .43368 .58579 .45357 .60257 .43293 .59362 .41321 Mtetra
.793 .672 .731 r
.59362 .41321 .60257 .43293 .61927 .41154 .61039 .39216 Mtetra
.796 .677 .732 r
.61039 .39216 .61927 .41154 .6359 .38993 .6271 .37103 Mtetra
.798 .681 .736 r
.6271 .37103 .6359 .38993 .65247 .36857 .64376 .35027 Mtetra
.797 .687 .743 r
.64376 .35027 .65247 .36857 .66901 .34787 .66039 .33023 Mtetra
.795 .693 .751 r
.66039 .33023 .66901 .34787 .68553 .32813 .67702 .3112 Mtetra
.791 .699 .762 r
.67702 .3112 .68553 .32813 .70208 .30958 .69368 .29336 Mtetra
.786 .705 .775 r
.69368 .29336 .70208 .30958 .71867 .29235 .71038 .27682 Mtetra
.779 .711 .789 r
.71038 .27682 .71867 .29235 .73533 .2765 .72716 .2616 Mtetra
.77 .718 .804 r
.72716 .2616 .73533 .2765 .75208 .262 .74403 .24769 Mtetra
.76 .723 .818 r
.74403 .24769 .75208 .262 .76895 .2488 .76102 .235 Mtetra
.749 .728 .833 r
.76102 .235 .76895 .2488 .78595 .23679 .77813 .22344 Mtetra
.737 .732 .846 r
.77813 .22344 .78595 .23679 .80308 .22586 .79537 .21288 Mtetra
.726 .735 .858 r
.79537 .21288 .80308 .22586 .82035 .21586 .81276 .20318 Mtetra
.502 .703 .96 r
.18408 .41266 .19403 .42129 .20784 .42047 .19791 .4119 Mtetra
.448 .683 .965 r
.19791 .4119 .20784 .42047 .22167 .42063 .21176 .4121 Mtetra
.379 .653 .965 r
.21176 .4121 .22167 .42063 .23552 .42188 .22564 .41338 Mtetra
.294 .611 .955 r
.22564 .41338 .23552 .42188 .2494 .42434 .23955 .41584 Mtetra
.197 .557 .934 r
.23955 .41584 .2494 .42434 .26333 .42809 .25349 .41955 Mtetra
.093 .493 .9 r
.25349 .41955 .26333 .42809 .27731 .43317 .2675 .42453 Mtetra
0 .426 .858 r
.2675 .42453 .27731 .43317 .29137 .43956 .28158 .43076 Mtetra
0 .363 .815 r
.28158 .43076 .29137 .43956 .30553 .44719 .29577 .43813 Mtetra
0 .316 .782 r
.29577 .43813 .30553 .44719 .31982 .4559 .31009 .44645 Mtetra
0 .29 .766 r
.31009 .44645 .31982 .4559 .33427 .46542 .32458 .45548 Mtetra
0 .288 .771 r
.32458 .45548 .33427 .46542 .34893 .47544 .33927 .46485 Mtetra
0 .313 .795 r
.33927 .46485 .34893 .47544 .36381 .48553 .35419 .47415 Mtetra
0 .36 .831 r
.35419 .47415 .36381 .48553 .37894 .4952 .36937 .48291 Mtetra
.114 .421 .866 r
.36937 .48291 .37894 .4952 .39434 .50392 .38481 .49059 Mtetra
.248 .482 .886 r
.38481 .49059 .39434 .50392 .41002 .51114 .40054 .49668 Mtetra
.374 .533 .886 r
.40054 .49668 .41002 .51114 .42597 .51633 .41654 .50069 Mtetra
.48 .571 .869 r
.41654 .50069 .42597 .51633 .44219 .51901 .43279 .50217 Mtetra
.561 .596 .845 r
.43279 .50217 .44219 .51901 .45864 .51879 .44928 .5008 Mtetra
.622 .612 .819 r
.44928 .5008 .45864 .51879 .47528 .51542 .46597 .49637 Mtetra
.667 .622 .795 r
.46597 .49637 .47528 .51542 .49208 .5088 .4828 .48884 Mtetra
.7 .63 .775 r
.4828 .48884 .49208 .5088 .50899 .49897 .49974 .47829 Mtetra
.725 .636 .758 r
.49974 .47829 .50899 .49897 .52595 .48616 .51673 .46496 Mtetra
.744 .64 .745 r
.51673 .46496 .52595 .48616 .54292 .47069 .53375 .44922 Mtetra
.758 .645 .736 r
.53375 .44922 .54292 .47069 .55988 .45302 .55074 .43151 Mtetra
.769 .65 .73 r
.55074 .43151 .55988 .45302 .57678 .43368 .5677 .41235 Mtetra
.776 .654 .728 r
.5677 .41235 .57678 .43368 .59362 .41321 .5846 .39225 Mtetra
.782 .66 .728 r
.5846 .39225 .59362 .41321 .61039 .39216 .60144 .37175 Mtetra
.786 .665 .731 r
.60144 .37175 .61039 .39216 .6271 .37103 .61823 .35129 Mtetra
.787 .671 .736 r
.61823 .35129 .6271 .37103 .64376 .35027 .63497 .33129 Mtetra
.787 .678 .743 r
.63497 .33129 .64376 .35027 .66039 .33023 .6517 .31206 Mtetra
.786 .685 .753 r
.6517 .31206 .66039 .33023 .67702 .3112 .66844 .29385 Mtetra
.782 .692 .765 r
.66844 .29385 .67702 .3112 .69368 .29336 .6852 .27682 Mtetra
.777 .7 .778 r
.6852 .27682 .69368 .29336 .71038 .27682 .70202 .26103 Mtetra
.77 .707 .793 r
.70202 .26103 .71038 .27682 .72716 .2616 .71892 .24651 Mtetra
.761 .714 .807 r
.71892 .24651 .72716 .2616 .74403 .24769 .73591 .23322 Mtetra
.752 .72 .822 r
.73591 .23322 .74403 .24769 .76102 .235 .75301 .22108 Mtetra
.741 .725 .837 r
.75301 .22108 .76102 .235 .77813 .22344 .77023 .20998 Mtetra
.73 .73 .85 r
.77023 .20998 .77813 .22344 .79537 .21288 .78759 .1998 Mtetra
.72 .733 .862 r
.78759 .1998 .79537 .21288 .81276 .20318 .80508 .1904 Mtetra
.502 .699 .958 r
.17404 .4038 .18408 .41266 .19791 .4119 .1879 .40303 Mtetra
.451 .679 .962 r
.1879 .40303 .19791 .4119 .21176 .4121 .20178 .4032 Mtetra
.387 .65 .962 r
.20178 .4032 .21176 .4121 .22564 .41338 .21569 .40443 Mtetra
.312 .611 .954 r
.21569 .40443 .22564 .41338 .23955 .41584 .22962 .4068 Mtetra
.227 .563 .937 r
.22962 .4068 .23955 .41584 .25349 .41955 .24359 .41036 Mtetra
.14 .508 .911 r
.24359 .41036 .25349 .41955 .2675 .42453 .25763 .41512 Mtetra
.061 .452 .88 r
.25763 .41512 .2675 .42453 .28158 .43076 .27175 .42103 Mtetra
0 .403 .851 r
.27175 .42103 .28158 .43076 .29577 .43813 .28597 .42797 Mtetra
0 .367 .83 r
.28597 .42797 .29577 .43813 .31009 .44645 .30034 .43575 Mtetra
0 .351 .822 r
.30034 .43575 .31009 .44645 .32458 .45548 .31487 .44409 Mtetra
0 .355 .828 r
.31487 .44409 .32458 .45548 .33927 .46485 .32961 .45264 Mtetra
.048 .38 .844 r
.32961 .45264 .33927 .46485 .35419 .47415 .34458 .461 Mtetra
.138 .418 .861 r
.34458 .461 .35419 .47415 .36937 .48291 .3598 .46868 Mtetra
.243 .462 .872 r
.3598 .46868 .36937 .48291 .38481 .49059 .3753 .47519 Mtetra
.349 .503 .87 r
.3753 .47519 .38481 .49059 .40054 .49668 .39107 .48006 Mtetra
.444 .537 .857 r
.39107 .48006 .40054 .49668 .41654 .50069 .40711 .48282 Mtetra
.522 .563 .837 r
.40711 .48282 .41654 .50069 .43279 .50217 .4234 .48309 Mtetra
.584 .581 .815 r
.4234 .48309 .43279 .50217 .44928 .5008 .43993 .4806 Mtetra
.632 .595 .793 r
.43993 .4806 .44928 .5008 .46597 .49637 .45664 .4752 Mtetra
.669 .605 .774 r
.45664 .4752 .46597 .49637 .4828 .48884 .4735 .46687 Mtetra
.697 .613 .758 r
.4735 .46687 .4828 .48884 .49974 .47829 .49046 .45575 Mtetra
.719 .619 .745 r
.49046 .45575 .49974 .47829 .51673 .46496 .50749 .44209 Mtetra
.736 .625 .736 r
.50749 .44209 .51673 .46496 .53375 .44922 .52453 .42626 Mtetra
.749 .631 .73 r
.52453 .42626 .53375 .44922 .55074 .43151 .54157 .40872 Mtetra
.759 .637 .726 r
.54157 .40872 .55074 .43151 .5677 .41235 .55857 .38993 Mtetra
.767 .643 .725 r
.55857 .38993 .5677 .41235 .5846 .39225 .57552 .37041 Mtetra
.772 .65 .727 r
.57552 .37041 .5846 .39225 .60144 .37175 .59243 .35062 Mtetra
.776 .657 .731 r
.59243 .35062 .60144 .37175 .61823 .35129 .60929 .33099 Mtetra
.778 .664 .737 r
.60929 .33099 .61823 .35129 .63497 .33129 .62613 .31187 Mtetra
.778 .671 .746 r
.62613 .31187 .63497 .33129 .6517 .31206 .64295 .29356 Mtetra
.776 .679 .757 r
.64295 .29356 .6517 .31206 .66844 .29385 .65979 .27626 Mtetra
.773 .688 .769 r
.65979 .27626 .66844 .29385 .6852 .27682 .67666 .26009 Mtetra
.768 .696 .783 r
.67666 .26009 .6852 .27682 .70202 .26103 .69359 .24511 Mtetra
.761 .704 .797 r
.69359 .24511 .70202 .26103 .71892 .24651 .7106 .23133 Mtetra
.753 .711 .812 r
.7106 .23133 .71892 .24651 .73591 .23322 .72771 .21868 Mtetra
.744 .718 .827 r
.72771 .21868 .73591 .23322 .75301 .22108 .74493 .20709 Mtetra
.734 .723 .841 r
.74493 .20709 .75301 .22108 .77023 .20998 .76227 .19646 Mtetra
.724 .728 .854 r
.76227 .19646 .77023 .20998 .78759 .1998 .77973 .18665 Mtetra
.713 .732 .865 r
.77973 .18665 .78759 .1998 .80508 .1904 .79734 .17755 Mtetra
.506 .696 .955 r
.16392 .39468 .17404 .4038 .1879 .40303 .17781 .39385 Mtetra
.458 .676 .958 r
.17781 .39385 .1879 .40303 .20178 .4032 .19172 .39393 Mtetra
.401 .649 .958 r
.19172 .39393 .20178 .4032 .21569 .40443 .20566 .39503 Mtetra
.335 .614 .952 r
.20566 .39503 .21569 .40443 .22962 .4068 .21963 .39721 Mtetra
.263 .571 .939 r
.21963 .39721 .22962 .4068 .24359 .41036 .23364 .40051 Mtetra
.192 .525 .92 r
.23364 .40051 .24359 .41036 .25763 .41512 .24772 .40492 Mtetra
.131 .479 .898 r
.24772 .40492 .25763 .41512 .27175 .42103 .26188 .41038 Mtetra
.086 .44 .878 r
.26188 .41038 .27175 .42103 .28597 .42797 .27615 .41675 Mtetra
.066 .414 .863 r
.27615 .41675 .28597 .42797 .30034 .43575 .29057 .42382 Mtetra
.074 .403 .858 r
.29057 .42382 .30034 .43575 .31487 .44409 .30516 .43133 Mtetra
.111 .409 .859 r
.30516 .43133 .31487 .44409 .32961 .45264 .31995 .43891 Mtetra
.173 .428 .863 r
.31995 .43891 .32961 .45264 .34458 .461 .33497 .44617 Mtetra
.252 .456 .865 r
.33497 .44617 .34458 .461 .3598 .46868 .35025 .45267 Mtetra
.337 .486 .861 r
.35025 .45267 .3598 .46868 .3753 .47519 .36579 .45793 Mtetra
.419 .514 .849 r
.36579 .45793 .3753 .47519 .39107 .48006 .38161 .46152 Mtetra
.491 .537 .832 r
.38161 .46152 .39107 .48006 .40711 .48282 .39769 .46302 Mtetra
.551 .556 .812 r
.39769 .46302 .40711 .48282 .4234 .48309 .41402 .46212 Mtetra
.6 .571 .793 r
.41402 .46212 .4234 .48309 .43993 .4806 .43057 .45858 Mtetra
.639 .582 .775 r
.43057 .45858 .43993 .4806 .45664 .4752 .44731 .4523 Mtetra
.67 .592 .759 r
.44731 .4523 .45664 .4752 .4735 .46687 .46419 .44331 Mtetra
.694 .6 .747 r
.46419 .44331 .4735 .46687 .49046 .45575 .48117 .43178 Mtetra
.713 .607 .737 r
.48117 .43178 .49046 .45575 .50749 .44209 .49822 .41797 Mtetra
.729 .614 .73 r
.49822 .41797 .50749 .44209 .52453 .42626 .51529 .40224 Mtetra
.741 .621 .726 r
.51529 .40224 .52453 .42626 .54157 .40872 .53235 .38504 Mtetra
.751 .628 .724 r
.53235 .38504 .54157 .40872 .55857 .38993 .54939 .3668 Mtetra
.758 .635 .725 r
.54939 .3668 .55857 .38993 .57552 .37041 .5664 .348 Mtetra
.763 .643 .728 r
.5664 .348 .57552 .37041 .59243 .35062 .58336 .32907 Mtetra
.767 .65 .733 r
.58336 .32907 .59243 .35062 .60929 .33099 .6003 .31038 Mtetra
.769 .658 .741 r
.6003 .31038 .60929 .33099 .62613 .31187 .61722 .29225 Mtetra
.769 .667 .75 r
.61722 .29225 .62613 .31187 .64295 .29356 .63414 .27493 Mtetra
.767 .676 .762 r
.63414 .27493 .64295 .29356 .65979 .27626 .65108 .25859 Mtetra
.764 .685 .775 r
.65108 .25859 .65979 .27626 .67666 .26009 .66806 .24332 Mtetra
.759 .693 .789 r
.66806 .24332 .67666 .26009 .69359 .24511 .6851 .22917 Mtetra
.753 .702 .803 r
.6851 .22917 .69359 .24511 .7106 .23133 .70222 .21613 Mtetra
.745 .71 .818 r
.70222 .21613 .7106 .23133 .72771 .21868 .71944 .20413 Mtetra
.736 .716 .833 r
.71944 .20413 .72771 .21868 .74493 .20709 .73677 .19308 Mtetra
.727 .722 .846 r
.73677 .19308 .74493 .20709 .76227 .19646 .75422 .1829 Mtetra
.717 .727 .858 r
.75422 .1829 .76227 .19646 .77973 .18665 .7718 .17345 Mtetra
.708 .731 .869 r
.7718 .17345 .77973 .18665 .79734 .17755 .78951 .16463 Mtetra
.511 .694 .951 r
.1537 .38529 .16392 .39468 .17781 .39385 .16764 .38435 Mtetra
.468 .675 .954 r
.16764 .38435 .17781 .39385 .19172 .39393 .18159 .38428 Mtetra
.418 .65 .954 r
.18159 .38428 .19172 .39393 .20566 .39503 .19557 .38517 Mtetra
.361 .618 .949 r
.19557 .38517 .20566 .39503 .21963 .39721 .20958 .38707 Mtetra
.302 .581 .939 r
.20958 .38707 .21963 .39721 .23364 .40051 .22364 .39 Mtetra
.246 .542 .925 r
.22364 .39 .23364 .40051 .24772 .40492 .23777 .39395 Mtetra
.2 .505 .909 r
.23777 .39395 .24772 .40492 .26188 .41038 .25198 .39883 Mtetra
.171 .474 .893 r
.25198 .39883 .26188 .41038 .27615 .41675 .26631 .4045 Mtetra
.163 .453 .882 r
.26631 .4045 .27615 .41675 .29057 .42382 .28079 .41074 Mtetra
.178 .446 .874 r
.28079 .41074 .29057 .42382 .30516 .43133 .29543 .41729 Mtetra
.216 .449 .87 r
.29543 .41729 .30516 .43133 .31995 .43891 .31029 .42379 Mtetra
.271 .463 .865 r
.31029 .42379 .31995 .43891 .33497 .44617 .32537 .42987 Mtetra
.337 .481 .857 r
.32537 .42987 .33497 .44617 .35025 .45267 .3407 .4351 Mtetra
.404 .502 .845 r
.3407 .4351 .35025 .45267 .36579 .45793 .3563 .43907 Mtetra
.468 .521 .829 r
.3563 .43907 .36579 .45793 .38161 .46152 .37216 .44137 Mtetra
.524 .538 .811 r
.37216 .44137 .38161 .46152 .39769 .46302 .38828 .44164 Mtetra
.572 .552 .793 r
.38828 .44164 .39769 .46302 .41402 .46212 .40464 .43962 Mtetra
.612 .564 .777 r
.40464 .43962 .41402 .46212 .43057 .45858 .42122 .43512 Mtetra
.644 .574 .762 r
.42122 .43512 .43057 .45858 .44731 .4523 .43797 .4281 Mtetra
.67 .583 .749 r
.43797 .4281 .44731 .4523 .46419 .44331 .45487 .4186 Mtetra
.692 .592 .739 r
.45487 .4186 .46419 .44331 .48117 .43178 .47187 .40682 Mtetra
.709 .599 .732 r
.47187 .40682 .48117 .43178 .49822 .41797 .48893 .39302 Mtetra
.723 .607 .727 r
.48893 .39302 .49822 .41797 .51529 .40224 .50602 .37757 Mtetra
.734 .614 .724 r
.50602 .37757 .51529 .40224 .53235 .38504 .52311 .36086 Mtetra
.743 .622 .724 r
.52311 .36086 .53235 .38504 .54939 .3668 .54018 .34332 Mtetra
.75 .63 .726 r
.54018 .34332 .54939 .3668 .5664 .348 .55724 .32536 Mtetra
.755 .638 .731 r
.55724 .32536 .5664 .348 .58336 .32907 .57426 .30738 Mtetra
.759 .646 .737 r
.57426 .30738 .58336 .32907 .6003 .31038 .59127 .28971 Mtetra
.761 .655 .746 r
.59127 .28971 .6003 .31038 .61722 .29225 .60827 .27263 Mtetra
.761 .664 .756 r
.60827 .27263 .61722 .29225 .63414 .27493 .62528 .25634 Mtetra
.759 .674 .768 r
.62528 .25634 .63414 .27493 .65108 .25859 .64231 .24098 Mtetra
.756 .683 .781 r
.64231 .24098 .65108 .25859 .66806 .24332 .6594 .22662 Mtetra
.751 .692 .796 r
.6594 .22662 .66806 .24332 .6851 .22917 .67655 .2133 Mtetra
.744 .701 .81 r
.67655 .2133 .6851 .22917 .70222 .21613 .69378 .20098 Mtetra
.737 .709 .825 r
.69378 .20098 .70222 .21613 .71944 .20413 .71111 .18961 Mtetra
.728 .716 .839 r
.71111 .18961 .71944 .20413 .73677 .19308 .72855 .17909 Mtetra
.719 .722 .852 r
.72855 .17909 .73677 .19308 .75422 .1829 .74611 .16934 Mtetra
.711 .727 .863 r
.74611 .16934 .75422 .1829 .7718 .17345 .7638 .16024 Mtetra
.702 .731 .873 r
.7638 .16024 .7718 .17345 .78951 .16463 .78161 .15168 Mtetra
.519 .693 .948 r
.14341 .37563 .1537 .38529 .16764 .38435 .15738 .37452 Mtetra
.481 .675 .95 r
.15738 .37452 .16764 .38435 .18159 .38428 .17138 .37424 Mtetra
.437 .651 .95 r
.17138 .37424 .18159 .38428 .19557 .38517 .18541 .37484 Mtetra
.39 .623 .946 r
.18541 .37484 .19557 .38517 .20958 .38707 .19947 .37638 Mtetra
.342 .591 .937 r
.19947 .37638 .20958 .38707 .22364 .39 .21359 .37887 Mtetra
.299 .558 .926 r
.21359 .37887 .22364 .39 .23777 .39395 .22777 .38225 Mtetra
.265 .527 .913 r
.22777 .38225 .23777 .39395 .25198 .39883 .24205 .38645 Mtetra
.247 .502 .9 r
.24205 .38645 .25198 .39883 .26631 .4045 .25645 .39132 Mtetra
.247 .485 .889 r
.25645 .39132 .26631 .4045 .28079 .41074 .27099 .39663 Mtetra
.265 .478 .878 r
.27099 .39663 .28079 .41074 .29543 .41729 .28571 .40212 Mtetra
.3 .479 .869 r
.28571 .40212 .29543 .41729 .31029 .42379 .30063 .40747 Mtetra
.347 .487 .858 r
.30063 .40747 .31029 .42379 .32537 .42987 .31577 .4123 Mtetra
.4 .499 .845 r
.31577 .4123 .32537 .42987 .3407 .4351 .33117 .41624 Mtetra
.454 .513 .83 r
.33117 .41624 .3407 .4351 .3563 .43907 .34682 .41891 Mtetra
.504 .526 .813 r
.34682 .41891 .3563 .43907 .37216 .44137 .36273 .41995 Mtetra
.549 .539 .796 r
.36273 .41995 .37216 .44137 .38828 .44164 .37888 .41905 Mtetra
.588 .55 .78 r
.37888 .41905 .38828 .44164 .40464 .43962 .39527 .416 Mtetra
.62 .56 .766 r
.39527 .416 .40464 .43962 .42122 .43512 .41187 .41067 Mtetra
.648 .57 .753 r
.41187 .41067 .42122 .43512 .43797 .4281 .42864 .40303 Mtetra
.67 .578 .743 r
.42864 .40303 .43797 .4281 .45487 .4186 .44554 .39318 Mtetra
.689 .586 .735 r
.44554 .39318 .45487 .4186 .47187 .40682 .46255 .3813 Mtetra
.705 .594 .73 r
.46255 .3813 .47187 .40682 .48893 .39302 .47962 .36767 Mtetra
.718 .602 .726 r
.47962 .36767 .48893 .39302 .50602 .37757 .49672 .35262 Mtetra
.728 .61 .725 r
.49672 .35262 .50602 .37757 .52311 .36086 .51384 .33653 Mtetra
.737 .618 .726 r
.51384 .33653 .52311 .36086 .54018 .34332 .53094 .31979 Mtetra
.743 .627 .73 r
.53094 .31979 .54018 .34332 .55724 .32536 .54804 .30277 Mtetra
.748 .635 .735 r
.54804 .30277 .55724 .32536 .57426 .30738 .56512 .28581 Mtetra
.751 .644 .743 r
.56512 .28581 .57426 .30738 .59127 .28971 .58219 .2692 Mtetra
.753 .654 .752 r
.58219 .2692 .59127 .28971 .60827 .27263 .59927 .25319 Mtetra
.753 .664 .763 r
.59927 .25319 .60827 .27263 .62528 .25634 .61637 .23793 Mtetra
.751 .674 .776 r
.61637 .23793 .62528 .25634 .64231 .24098 .6335 .22355 Mtetra
.747 .683 .789 r
.6335 .22355 .64231 .24098 .6594 .22662 .65068 .21009 Mtetra
.743 .693 .804 r
.65068 .21009 .6594 .22662 .67655 .2133 .66793 .19757 Mtetra
.736 .702 .818 r
.66793 .19757 .67655 .2133 .69378 .20098 .68527 .18595 Mtetra
.729 .71 .832 r
.68527 .18595 .69378 .20098 .71111 .18961 .70271 .17517 Mtetra
.721 .717 .846 r
.70271 .17517 .71111 .18961 .72855 .17909 .72026 .16515 Mtetra
.713 .723 .858 r
.72026 .16515 .72855 .17909 .74611 .16934 .73793 .1558 Mtetra
.704 .727 .868 r
.73793 .1558 .74611 .16934 .7638 .16024 .75572 .14701 Mtetra
.697 .731 .877 r
.75572 .14701 .7638 .16024 .78161 .15168 .77363 .13869 Mtetra
.528 .693 .943 r
.13302 .3657 .14341 .37563 .15738 .37452 .14705 .36438 Mtetra
.495 .676 .945 r
.14705 .36438 .15738 .37452 .17138 .37424 .1611 .36382 Mtetra
.458 .654 .945 r
.1611 .36382 .17138 .37424 .18541 .37484 .17518 .36408 Mtetra
.419 .629 .941 r
.17518 .36408 .18541 .37484 .19947 .37638 .18931 .36519 Mtetra
.381 .601 .934 r
.18931 .36519 .19947 .37638 .21359 .37887 .20349 .36714 Mtetra
.348 .573 .924 r
.20349 .36714 .21359 .37887 .22777 .38225 .21774 .36989 Mtetra
.324 .547 .913 r
.21774 .36989 .22777 .38225 .24205 .38645 .23209 .37333 Mtetra
.313 .526 .901 r
.23209 .37333 .24205 .38645 .25645 .39132 .24656 .37731 Mtetra
.317 .511 .888 r
.24656 .37731 .25645 .39132 .27099 .39663 .26117 .38162 Mtetra
.336 .503 .876 r
.26117 .38162 .27099 .39663 .28571 .40212 .27597 .386 Mtetra
.366 .502 .863 r
.27597 .386 .28571 .40212 .30063 .40747 .29096 .39015 Mtetra
.405 .506 .849 r
.29096 .39015 .30063 .40747 .31577 .4123 .30618 .39372 Mtetra
.448 .514 .833 r
.30618 .39372 .31577 .4123 .33117 .41624 .32164 .39638 Mtetra
.491 .523 .817 r
.32164 .39638 .33117 .41624 .34682 .41891 .33734 .39778 Mtetra
.531 .532 .801 r
.33734 .39778 .34682 .41891 .36273 .41995 .35329 .39762 Mtetra
.568 .542 .785 r
.35329 .39762 .36273 .41995 .37888 .41905 .36949 .39565 Mtetra
.6 .551 .771 r
.36949 .39565 .37888 .41905 .39527 .416 .3859 .39168 Mtetra
.627 .559 .759 r
.3859 .39168 .39527 .416 .41187 .41067 .40252 .38564 Mtetra
.651 .568 .748 r
.40252 .38564 .41187 .41067 .42864 .40303 .41929 .37753 Mtetra
.671 .576 .74 r
.41929 .37753 .42864 .40303 .44554 .39318 .4362 .36746 Mtetra
.687 .584 .734 r
.4362 .36746 .44554 .39318 .46255 .3813 .45321 .35562 Mtetra
.702 .592 .73 r
.45321 .35562 .46255 .3813 .47962 .36767 .47029 .34228 Mtetra
.713 .6 .728 r
.47029 .34228 .47962 .36767 .49672 .35262 .4874 .32775 Mtetra
.723 .608 .728 r
.4874 .32775 .49672 .35262 .51384 .33653 .50454 .31238 Mtetra
.731 .617 .731 r
.50454 .31238 .51384 .33653 .53094 .31979 .52167 .29651 Mtetra
.737 .626 .735 r
.52167 .29651 .53094 .31979 .54804 .30277 .53881 .28047 Mtetra
.741 .635 .742 r
.53881 .28047 .54804 .30277 .56512 .28581 .55594 .26455 Mtetra
.744 .645 .75 r
.55594 .26455 .56512 .28581 .58219 .2692 .57308 .24902 Mtetra
.745 .655 .76 r
.57308 .24902 .58219 .2692 .59927 .25319 .59023 .23406 Mtetra
.745 .665 .772 r
.59023 .23406 .59927 .25319 .61637 .23793 .6074 .21982 Mtetra
.743 .675 .785 r
.6074 .21982 .61637 .23793 .6335 .22355 .62462 .20638 Mtetra
.739 .685 .798 r
.62462 .20638 .6335 .22355 .65068 .21009 .64191 .19379 Mtetra
.735 .694 .812 r
.64191 .19379 .65068 .21009 .66793 .19757 .65926 .18203 Mtetra
.728 .703 .826 r
.65926 .18203 .66793 .19757 .68527 .18595 .6767 .17106 Mtetra
.721 .711 .84 r
.6767 .17106 .68527 .18595 .70271 .17517 .69425 .16084 Mtetra
.714 .718 .852 r
.69425 .16084 .70271 .17517 .72026 .16515 .7119 .15127 Mtetra
.706 .723 .863 r
.7119 .15127 .72026 .16515 .73793 .1558 .72967 .14228 Mtetra
.699 .728 .873 r
.72967 .14228 .73793 .1558 .75572 .14701 .74756 .13377 Mtetra
.692 .732 .881 r
.74756 .13377 .75572 .14701 .77363 .13869 .76558 .12566 Mtetra
.539 .693 .939 r
.12256 .35551 .13302 .3657 .14705 .36438 .13663 .35394 Mtetra
.51 .677 .94 r
.13663 .35394 .14705 .36438 .1611 .36382 .15074 .35306 Mtetra
.479 .658 .939 r
.15074 .35306 .1611 .36382 .17518 .36408 .16489 .35292 Mtetra
.447 .635 .936 r
.16489 .35292 .17518 .36408 .18931 .36519 .17908 .35354 Mtetra
.417 .611 .929 r
.17908 .35354 .18931 .36519 .20349 .36714 .19333 .3549 Mtetra
.392 .587 .92 r
.19333 .3549 .20349 .36714 .21774 .36989 .20766 .35694 Mtetra
.376 .564 .909 r
.20766 .35694 .21774 .36989 .23209 .37333 .22208 .35957 Mtetra
.37 .546 .897 r
.22208 .35957 .23209 .37333 .24656 .37731 .23664 .36261 Mtetra
.376 .532 .884 r
.23664 .36261 .24656 .37731 .26117 .38162 .25133 .36588 Mtetra
.393 .524 .87 r
.25133 .36588 .26117 .38162 .27597 .386 .26621 .36913 Mtetra
.419 .521 .855 r
.26621 .36913 .27597 .386 .29096 .39015 .28128 .37207 Mtetra
.451 .522 .84 r
.28128 .37207 .29096 .39015 .30618 .39372 .29657 .3744 Mtetra
.485 .526 .824 r
.29657 .3744 .30618 .39372 .32164 .39638 .31209 .37581 Mtetra
.52 .532 .808 r
.31209 .37581 .32164 .39638 .33734 .39778 .32785 .37601 Mtetra
.553 .538 .793 r
.32785 .37601 .33734 .39778 .35329 .39762 .34385 .37474 Mtetra
.583 .546 .779 r
.34385 .37474 .35329 .39762 .36949 .39565 .36008 .37179 Mtetra
.61 .553 .766 r
.36008 .37179 .36949 .39565 .3859 .39168 .37652 .36704 Mtetra
.633 .561 .755 r
.37652 .36704 .3859 .39168 .40252 .38564 .39315 .36041 Mtetra
.654 .568 .747 r
.39315 .36041 .40252 .38564 .41929 .37753 .40993 .35197 Mtetra
.671 .576 .74 r
.40993 .35197 .41929 .37753 .4362 .36746 .42684 .34181 Mtetra
.686 .584 .735 r
.42684 .34181 .4362 .36746 .45321 .35562 .44385 .33013 Mtetra
.699 .592 .733 r
.44385 .33013 .45321 .35562 .47029 .34228 .46093 .31718 Mtetra
.709 .6 .732 r
.46093 .31718 .47029 .34228 .4874 .32775 .47806 .30326 Mtetra
.718 .609 .734 r
.47806 .30326 .4874 .32775 .50454 .31238 .4952 .28866 Mtetra
.725 .617 .737 r
.4952 .28866 .50454 .31238 .52167 .29651 .51237 .27369 Mtetra
.731 .627 .742 r
.51237 .27369 .52167 .29651 .53881 .28047 .52954 .25865 Mtetra
.735 .636 .75 r
.52954 .25865 .53881 .28047 .55594 .26455 .54672 .24379 Mtetra
.737 .647 .759 r
.54672 .24379 .55594 .26455 .57308 .24902 .56391 .2293 Mtetra
.738 .657 .769 r
.56391 .2293 .57308 .24902 .59023 .23406 .58113 .21537 Mtetra
.737 .667 .781 r
.58113 .21537 .59023 .23406 .6074 .21982 .59839 .2021 Mtetra
.735 .678 .794 r
.59839 .2021 .6074 .21982 .62462 .20638 .6157 .18956 Mtetra
.732 .687 .808 r
.6157 .18956 .62462 .20638 .64191 .19379 .63307 .17777 Mtetra
.727 .697 .822 r
.63307 .17777 .64191 .19379 .65926 .18203 .65052 .16671 Mtetra
.721 .705 .835 r
.65052 .16671 .65926 .18203 .6767 .17106 .66807 .15635 Mtetra
.714 .713 .848 r
.66807 .15635 .6767 .17106 .69425 .16084 .68571 .14663 Mtetra
.707 .719 .859 r
.68571 .14663 .69425 .16084 .7119 .15127 .70346 .13747 Mtetra
.7 .725 .869 r
.70346 .13747 .7119 .15127 .72967 .14228 .72133 .1288 Mtetra
.693 .729 .878 r
.72133 .1288 .72967 .14228 .74756 .13377 .73932 .12053 Mtetra
.687 .732 .885 r
.73932 .12053 .74756 .13377 .76558 .12566 .75744 .11259 Mtetra
.55 .694 .935 r
.112 .34508 .12256 .35551 .13663 .35394 .12613 .34321 Mtetra
.525 .679 .935 r
.12613 .34321 .13663 .35394 .15074 .35306 .14031 .34197 Mtetra
.499 .662 .934 r
.14031 .34197 .15074 .35306 .16489 .35292 .15452 .3414 Mtetra
.473 .642 .93 r
.15452 .3414 .16489 .35292 .17908 .35354 .16878 .34148 Mtetra
.45 .62 .924 r
.16878 .34148 .17908 .35354 .19333 .3549 .18311 .34221 Mtetra
.431 .599 .915 r
.18311 .34221 .19333 .3549 .20766 .35694 .19752 .34351 Mtetra
.42 .579 .905 r
.19752 .34351 .20766 .35694 .22208 .35957 .21204 .34528 Mtetra
.417 .563 .892 r
.21204 .34528 .22208 .35957 .23664 .36261 .22667 .34737 Mtetra
.424 .55 .879 r
.22667 .34737 .23664 .36261 .25133 .36588 .24146 .34959 Mtetra
.439 .541 .864 r
.24146 .34959 .25133 .36588 .26621 .36913 .25642 .35171 Mtetra
.461 .537 .849 r
.25642 .35171 .26621 .36913 .28128 .37207 .27157 .35347 Mtetra
.487 .536 .833 r
.27157 .35347 .28128 .37207 .29657 .3744 .28694 .3546 Mtetra
.515 .537 .817 r
.28694 .3546 .29657 .3744 .31209 .37581 .30253 .35484 Mtetra
.543 .541 .802 r
.30253 .35484 .31209 .37581 .32785 .37601 .31834 .35392 Mtetra
.57 .546 .788 r
.31834 .35392 .32785 .37601 .34385 .37474 .33439 .35165 Mtetra
.595 .551 .775 r
.33439 .35165 .34385 .37474 .36008 .37179 .35065 .34784 Mtetra
.618 .558 .764 r
.35065 .34784 .36008 .37179 .37652 .36704 .36711 .34242 Mtetra
.638 .564 .755 r
.36711 .34242 .37652 .36704 .39315 .36041 .38374 .33535 Mtetra
.656 .571 .748 r
.38374 .33535 .39315 .36041 .40993 .35197 .40053 .32668 Mtetra
.672 .578 .742 r
.40053 .32668 .40993 .35197 .42684 .34181 .41745 .31655 Mtetra
.685 .586 .739 r
.41745 .31655 .42684 .34181 .44385 .33013 .43446 .30513 Mtetra
.696 .594 .738 r
.43446 .30513 .44385 .33013 .46093 .31718 .45154 .29265 Mtetra
.706 .602 .738 r
.45154 .29265 .46093 .31718 .47806 .30326 .46867 .27938 Mtetra
.714 .611 .741 r
.46867 .27938 .47806 .30326 .4952 .28866 .48583 .26558 Mtetra
.72 .62 .745 r
.48583 .26558 .4952 .28866 .51237 .27369 .50302 .25153 Mtetra
.725 .63 .751 r
.50302 .25153 .51237 .27369 .52954 .25865 .52022 .23748 Mtetra
.729 .64 .759 r
.52022 .23748 .52954 .25865 .54672 .24379 .53745 .22362 Mtetra
.731 .65 .769 r
.53745 .22362 .54672 .24379 .56391 .2293 .5547 .21015 Mtetra
.731 .661 .78 r
.5547 .21015 .56391 .2293 .58113 .21537 .57199 .19719 Mtetra
.73 .671 .792 r
.57199 .19719 .58113 .21537 .59839 .2021 .58932 .18482 Mtetra
.728 .681 .805 r
.58932 .18482 .59839 .2021 .6157 .18956 .60671 .17311 Mtetra
.724 .691 .818 r
.60671 .17311 .6157 .18956 .63307 .17777 .62417 .16205 Mtetra
.719 .7 .831 r
.62417 .16205 .63307 .17777 .65052 .16671 .64172 .15163 Mtetra
.713 .708 .844 r
.64172 .15163 .65052 .16671 .66807 .15635 .65936 .14181 Mtetra
.707 .715 .855 r
.65936 .14181 .66807 .15635 .68571 .14663 .6771 .13254 Mtetra
.701 .721 .866 r
.6771 .13254 .68571 .14663 .70346 .13747 .69495 .12374 Mtetra
.694 .726 .875 r
.69495 .12374 .70346 .13747 .72133 .1288 .71292 .11534 Mtetra
.688 .73 .882 r
.71292 .11534 .72133 .1288 .73932 .12053 .73101 .10728 Mtetra
.683 .733 .888 r
.73101 .10728 .73932 .12053 .75744 .11259 .74922 .09949 Mtetra
.561 .695 .93 r
.10135 .33441 .112 .34508 .12613 .34321 .11555 .33223 Mtetra
.54 .682 .93 r
.11555 .33223 .12613 .34321 .14031 .34197 .12979 .33061 Mtetra
.519 .666 .929 r
.12979 .33061 .14031 .34197 .15452 .3414 .14408 .32956 Mtetra
.498 .648 .925 r
.14408 .32956 .15452 .3414 .16878 .34148 .15842 .32908 Mtetra
.48 .629 .918 r
.15842 .32908 .16878 .34148 .18311 .34221 .17283 .32915 Mtetra
.466 .611 .91 r
.17283 .32915 .18311 .34221 .19752 .34351 .18733 .32969 Mtetra
.458 .593 .899 r
.18733 .32969 .19752 .34351 .21204 .34528 .20193 .3306 Mtetra
.457 .578 .887 r
.20193 .3306 .21204 .34528 .22667 .34737 .21666 .33173 Mtetra
.464 .566 .873 r
.21666 .33173 .22667 .34737 .24146 .34959 .23154 .33292 Mtetra
.476 .557 .859 r
.23154 .33292 .24146 .34959 .25642 .35171 .24659 .33394 Mtetra
.494 .552 .844 r
.24659 .33394 .25642 .35171 .27157 .35347 .26183 .33457 Mtetra
.516 .549 .828 r
.26183 .33457 .27157 .35347 .28694 .3546 .27727 .33458 Mtetra
.539 .549 .813 r
.27727 .33458 .28694 .3546 .30253 .35484 .29292 .33372 Mtetra
.562 .551 .799 r
.29292 .33372 .30253 .35484 .31834 .35392 .30879 .3318 Mtetra
.585 .554 .786 r
.30879 .3318 .31834 .35392 .33439 .35165 .32488 .32864 Mtetra
.606 .558 .775 r
.32488 .32864 .33439 .35165 .35065 .34784 .34117 .3241 Mtetra
.625 .564 .765 r
.34117 .3241 .35065 .34784 .36711 .34242 .35765 .31813 Mtetra
.643 .569 .757 r
.35765 .31813 .36711 .34242 .38374 .33535 .3743 .31073 Mtetra
.658 .576 .751 r
.3743 .31073 .38374 .33535 .40053 .32668 .39109 .30196 Mtetra
.672 .583 .747 r
.39109 .30196 .40053 .32668 .41745 .31655 .408 .29194 Mtetra
.684 .59 .745 r
.408 .29194 .41745 .31655 .43446 .30513 .42501 .28084 Mtetra
.694 .598 .744 r
.42501 .28084 .43446 .30513 .45154 .29265 .44209 .26888 Mtetra
.703 .607 .746 r
.44209 .26888 .45154 .29265 .46867 .27938 .45923 .25629 Mtetra
.71 .615 .749 r
.45923 .25629 .46867 .27938 .48583 .26558 .47641 .2433 Mtetra
.716 .625 .755 r
.47641 .2433 .48583 .26558 .50302 .25153 .49362 .23015 Mtetra
.72 .635 .762 r
.49362 .23015 .50302 .25153 .52022 .23748 .51086 .21703 Mtetra
.723 .645 .77 r
.51086 .21703 .52022 .23748 .53745 .22362 .52813 .20414 Mtetra
.725 .655 .78 r
.52813 .20414 .53745 .22362 .5547 .21015 .54543 .19161 Mtetra
.725 .666 .791 r
.54543 .19161 .5547 .21015 .57199 .19719 .56279 .17954 Mtetra
.723 .676 .803 r
.56279 .17954 .57199 .19719 .58932 .18482 .58019 .16801 Mtetra
.721 .686 .816 r
.58019 .16801 .58932 .18482 .60671 .17311 .59766 .15704 Mtetra
.717 .695 .828 r
.59766 .15704 .60671 .17311 .62417 .16205 .61521 .14665 Mtetra
.712 .704 .841 r
.61521 .14665 .62417 .16205 .64172 .15163 .63285 .1368 Mtetra
.706 .711 .852 r
.63285 .1368 .64172 .15163 .65936 .14181 .65058 .12745 Mtetra
.701 .718 .863 r
.65058 .12745 .65936 .14181 .6771 .13254 .66841 .11856 Mtetra
.695 .723 .872 r
.66841 .11856 .6771 .13254 .69495 .12374 .68636 .11007 Mtetra
.689 .728 .88 r
.68636 .11007 .69495 .12374 .71292 .11534 .70442 .1019 Mtetra
.684 .731 .886 r
.70442 .1019 .71292 .11534 .73101 .10728 .7226 .09401 Mtetra
.68 .734 .892 r
.7226 .09401 .73101 .10728 .74922 .09949 .74091 .08633 Mtetra
.572 .697 .926 r
.0906 .32355 .10135 .33441 .11555 .33223 .10487 .32103 Mtetra
.555 .685 .926 r
.10487 .32103 .11555 .33223 .12979 .33061 .11918 .31899 Mtetra
.537 .671 .923 r
.11918 .31899 .12979 .33061 .14408 .32956 .13355 .31745 Mtetra
.521 .655 .919 r
.13355 .31745 .14408 .32956 .15842 .32908 .14798 .3164 Mtetra
.506 .638 .913 r
.14798 .3164 .15842 .32908 .17283 .32915 .16248 .3158 Mtetra
.496 .621 .905 r
.16248 .3158 .17283 .32915 .18733 .32969 .17707 .31558 Mtetra
.49 .605 .894 r
.17707 .31558 .18733 .32969 .20193 .3306 .19176 .31564 Mtetra
.491 .592 .882 r
.19176 .31564 .20193 .3306 .21666 .33173 .20659 .31585 Mtetra
.496 .58 .869 r
.20659 .31585 .21666 .33173 .23154 .33292 .22156 .31603 Mtetra
.507 .571 .855 r
.22156 .31603 .23154 .33292 .24659 .33394 .2367 .31601 Mtetra
.522 .565 .84 r
.2367 .31601 .24659 .33394 .26183 .33457 .25202 .31559 Mtetra
.54 .562 .826 r
.25202 .31559 .26183 .33457 .27727 .33458 .26753 .31456 Mtetra
.559 .561 .812 r
.26753 .31456 .27727 .33458 .29292 .33372 .28325 .31272 Mtetra
.578 .561 .799 r
.28325 .31272 .29292 .33372 .30879 .3318 .29918 .3099 Mtetra
.597 .564 .787 r
.29918 .3099 .30879 .3318 .32488 .32864 .3153 .30596 Mtetra
.615 .567 .777 r
.3153 .30596 .32488 .32864 .34117 .3241 .33163 .30082 Mtetra
.632 .571 .768 r
.33163 .30082 .34117 .3241 .35765 .31813 .34812 .29443 Mtetra
.647 .577 .762 r
.34812 .29443 .35765 .31813 .3743 .31073 .36478 .2868 Mtetra
.661 .583 .757 r
.36478 .2868 .3743 .31073 .39109 .30196 .38158 .27801 Mtetra
.673 .589 .754 r
.38158 .27801 .39109 .30196 .408 .29194 .39849 .26817 Mtetra
.683 .596 .752 r
.39849 .26817 .408 .29194 .42501 .28084 .4155 .25745 Mtetra
.692 .604 .753 r
.4155 .25745 .42501 .28084 .44209 .26888 .43259 .24603 Mtetra
.7 .613 .756 r
.43259 .24603 .44209 .26888 .45923 .25629 .44973 .23412 Mtetra
.707 .622 .76 r
.44973 .23412 .45923 .25629 .47641 .2433 .46692 .22191 Mtetra
.712 .631 .766 r
.46692 .22191 .47641 .2433 .49362 .23015 .48416 .20961 Mtetra
.715 .641 .773 r
.48416 .20961 .49362 .23015 .51086 .21703 .50143 .19738 Mtetra
.718 .651 .782 r
.50143 .19738 .51086 .21703 .52813 .20414 .51874 .18537 Mtetra
.719 .661 .792 r
.51874 .18537 .52813 .20414 .54543 .19161 .5361 .1737 Mtetra
.718 .671 .803 r
.5361 .1737 .54543 .19161 .56279 .17954 .55352 .16245 Mtetra
.716 .681 .815 r
.55352 .16245 .56279 .17954 .58019 .16801 .571 .15166 Mtetra
.714 .691 .827 r
.571 .15166 .58019 .16801 .59766 .15704 .58854 .14136 Mtetra
.71 .7 .839 r
.58854 .14136 .59766 .15704 .61521 .14665 .60617 .13154 Mtetra
.705 .708 .85 r
.60617 .13154 .61521 .14665 .63285 .1368 .6239 .12219 Mtetra
.7 .715 .86 r
.6239 .12219 .63285 .1368 .65058 .12745 .64172 .11325 Mtetra
.695 .721 .869 r
.64172 .11325 .65058 .12745 .66841 .11856 .65964 .10469 Mtetra
.69 .726 .878 r
.65964 .10469 .66841 .11856 .68636 .11007 .67768 .09645 Mtetra
.685 .729 .884 r
.67768 .09645 .68636 .11007 .70442 .1019 .69584 .08847 Mtetra
.68 .733 .89 r
.69584 .08847 .70442 .1019 .7226 .09401 .71411 .08071 Mtetra
.677 .735 .894 r
.71411 .08071 .7226 .09401 .74091 .08633 .73251 .07311 Mtetra
.583 .7 .923 r
.07976 .31249 .0906 .32355 .10487 .32103 .0941 .30963 Mtetra
.568 .688 .921 r
.0941 .30963 .10487 .32103 .11918 .31899 .10849 .30718 Mtetra
.554 .675 .919 r
.10849 .30718 .11918 .31899 .13355 .31745 .12293 .30515 Mtetra
.541 .661 .914 r
.12293 .30515 .13355 .31745 .14798 .3164 .13745 .30352 Mtetra
.53 .646 .908 r
.13745 .30352 .14798 .3164 .16248 .3158 .15204 .30226 Mtetra
.522 .631 .9 r
.15204 .30226 .16248 .3158 .17707 .31558 .16672 .3013 Mtetra
.518 .617 .89 r
.16672 .3013 .17707 .31558 .19176 .31564 .18152 .30053 Mtetra
.519 .604 .879 r
.18152 .30053 .19176 .31564 .20659 .31585 .19644 .29985 Mtetra
.524 .594 .866 r
.19644 .29985 .20659 .31585 .22156 .31603 .2115 .29909 Mtetra
.533 .585 .853 r
.2115 .29909 .22156 .31603 .2367 .31601 .22673 .2981 Mtetra
.546 .579 .839 r
.22673 .2981 .2367 .31601 .25202 .31559 .24213 .29671 Mtetra
.56 .575 .825 r
.24213 .29671 .25202 .31559 .26753 .31456 .25772 .29474 Mtetra
.576 .573 .813 r
.25772 .29474 .26753 .31456 .28325 .31272 .27351 .29202 Mtetra
.592 .573 .801 r
.27351 .29202 .28325 .31272 .29918 .3099 .28948 .28842 Mtetra
.608 .574 .79 r
.28948 .28842 .29918 .3099 .3153 .30596 .30565 .28384 Mtetra
.623 .577 .781 r
.30565 .28384 .3153 .30596 .33163 .30082 .322 .2782 Mtetra
.638 .581 .774 r
.322 .2782 .33163 .30082 .34812 .29443 .33852 .27148 Mtetra
.651 .585 .768 r
.33852 .27148 .34812 .29443 .36478 .2868 .35519 .26372 Mtetra
.663 .591 .764 r
.35519 .26372 .36478 .2868 .38158 .27801 .37199 .25498 Mtetra
.673 .597 .762 r
.37199 .25498 .38158 .27801 .39849 .26817 .38891 .24538 Mtetra
.683 .604 .762 r
.38891 .24538 .39849 .26817 .4155 .25745 .40592 .23506 Mtetra
.691 .612 .763 r
.40592 .23506 .4155 .25745 .43259 .24603 .423 .22418 Mtetra
.698 .62 .767 r
.423 .22418 .43259 .24603 .44973 .23412 .44016 .21293 Mtetra
.703 .629 .771 r
.44016 .21293 .44973 .23412 .46692 .22191 .45736 .20146 Mtetra
.707 .639 .778 r
.45736 .20146 .46692 .22191 .48416 .20961 .47462 .18995 Mtetra
.71 .648 .786 r
.47462 .18995 .48416 .20961 .50143 .19738 .49193 .17853 Mtetra
.712 .658 .795 r
.49193 .17853 .50143 .19738 .51874 .18537 .50929 .16733 Mtetra
.713 .668 .805 r
.50929 .16733 .51874 .18537 .5361 .1737 .5267 .15643 Mtetra
.712 .678 .816 r
.5267 .15643 .5361 .1737 .55352 .16245 .54418 .14589 Mtetra
.71 .688 .827 r
.54418 .14589 .55352 .16245 .571 .15166 .56172 .13576 Mtetra
.707 .697 .838 r
.56172 .13576 .571 .15166 .58854 .14136 .57935 .12604 Mtetra
.703 .705 .849 r
.57935 .12604 .58854 .14136 .60617 .13154 .59706 .11672 Mtetra
.699 .712 .859 r
.59706 .11672 .60617 .13154 .6239 .12219 .61487 .10778 Mtetra
.694 .718 .868 r
.61487 .10778 .6239 .12219 .64172 .11325 .63277 .09919 Mtetra
.689 .723 .876 r
.63277 .09919 .64172 .11325 .65964 .10469 .65079 .0909 Mtetra
.685 .728 .883 r
.65079 .0909 .65964 .10469 .67768 .09645 .66892 .08286 Mtetra
.681 .731 .888 r
.66892 .08286 .67768 .09645 .69584 .08847 .68716 .07503 Mtetra
.677 .734 .893 r
.68716 .07503 .69584 .08847 .71411 .08071 .70553 .06736 Mtetra
.674 .736 .897 r
.70553 .06736 .71411 .08071 .73251 .07311 .72402 .05982 Mtetra
.593 .702 .919 r
.06881 .30128 .07976 .31249 .0941 .30963 .08322 .29806 Mtetra
.581 .692 .918 r
.08322 .29806 .0941 .30963 .10849 .30718 .09769 .2952 Mtetra
.57 .68 .915 r
.09769 .2952 .10849 .30718 .12293 .30515 .11222 .29268 Mtetra
.559 .668 .91 r
.11222 .29268 .12293 .30515 .13745 .30352 .12682 .29049 Mtetra
.55 .654 .904 r
.12682 .29049 .13745 .30352 .15204 .30226 .14151 .28859 Mtetra
.544 .641 .896 r
.14151 .28859 .15204 .30226 .16672 .3013 .15629 .28692 Mtetra
.542 .628 .887 r
.15629 .28692 .16672 .3013 .18152 .30053 .17118 .28537 Mtetra
.543 .617 .876 r
.17118 .28537 .18152 .30053 .19644 .29985 .18619 .28385 Mtetra
.547 .607 .864 r
.18619 .28385 .19644 .29985 .2115 .29909 .20135 .28223 Mtetra
.555 .598 .852 r
.20135 .28223 .2115 .29909 .22673 .2981 .21667 .28036 Mtetra
.565 .592 .839 r
.21667 .28036 .22673 .2981 .24213 .29671 .23215 .27809 Mtetra
.577 .588 .827 r
.23215 .27809 .24213 .29671 .25772 .29474 .24781 .27528 Mtetra
.59 .586 .815 r
.24781 .27528 .25772 .29474 .27351 .29202 .26366 .2718 Mtetra
.604 .585 .805 r
.26366 .2718 .27351 .29202 .28948 .28842 .27969 .26753 Mtetra
.617 .586 .795 r
.27969 .26753 .28948 .28842 .30565 .28384 .2959 .26241 Mtetra
.63 .588 .787 r
.2959 .26241 .30565 .28384 .322 .2782 .31228 .25637 Mtetra
.643 .591 .781 r
.31228 .25637 .322 .2782 .33852 .27148 .32882 .24942 Mtetra
.654 .595 .777 r
.32882 .24942 .33852 .27148 .35519 .26372 .3455 .2416 Mtetra
.665 .601 .774 r
.3455 .2416 .35519 .26372 .37199 .25498 .36231 .23296 Mtetra
.674 .607 .772 r
.36231 .23296 .37199 .25498 .38891 .24538 .37922 .22363 Mtetra
.682 .614 .773 r
.37922 .22363 .38891 .24538 .40592 .23506 .39624 .21371 Mtetra
.689 .621 .775 r
.39624 .21371 .40592 .23506 .423 .22418 .41333 .20337 Mtetra
.695 .63 .779 r
.41333 .20337 .423 .22418 .44016 .21293 .4305 .19273 Mtetra
.7 .638 .784 r
.4305 .19273 .44016 .21293 .45736 .20146 .44772 .18195 Mtetra
.703 .647 .791 r
.44772 .18195 .45736 .20146 .47462 .18995 .46501 .17116 Mtetra
.706 .657 .799 r
.46501 .17116 .47462 .18995 .49193 .17853 .48235 .16047 Mtetra
.707 .667 .808 r
.48235 .16047 .49193 .17853 .50929 .16733 .49976 .14998 Mtetra
.707 .676 .818 r
.49976 .14998 .50929 .16733 .5267 .15643 .51722 .13976 Mtetra
.706 .685 .828 r
.51722 .13976 .5267 .15643 .54418 .14589 .53476 .12985 Mtetra
.703 .694 .838 r
.53476 .12985 .54418 .14589 .56172 .13576 .55237 .12027 Mtetra
.7 .702 .848 r
.55237 .12027 .56172 .13576 .57935 .12604 .57007 .11104 Mtetra
.697 .71 .858 r
.57007 .11104 .57935 .12604 .59706 .11672 .58786 .10215 Mtetra
.693 .716 .867 r
.58786 .10215 .59706 .11672 .61487 .10778 .60575 .09355 Mtetra
.689 .721 .875 r
.60575 .09355 .61487 .10778 .63277 .09919 .62374 .08524 Mtetra
.685 .726 .882 r
.62374 .08524 .63277 .09919 .65079 .0909 .64184 .07716 Mtetra
.681 .73 .887 r
.64184 .07716 .65079 .0909 .66892 .08286 .66006 .06928 Mtetra
.677 .733 .892 r
.66006 .06928 .66892 .08286 .68716 .07503 .6784 .06155 Mtetra
.674 .735 .896 r
.6784 .06155 .68716 .07503 .70553 .06736 .69685 .05395 Mtetra
.672 .737 .899 r
.69685 .05395 .70553 .06736 .72402 .05982 .71543 .04644 Mtetra
.602 .705 .916 r
.05775 .28994 .06881 .30128 .08322 .29806 .07224 .28637 Mtetra
.593 .696 .914 r
.07224 .28637 .08322 .29806 .09769 .2952 .08679 .2831 Mtetra
.583 .685 .911 r
.08679 .2831 .09769 .2952 .11222 .29268 .1014 .28011 Mtetra
.575 .674 .907 r
.1014 .28011 .11222 .29268 .12682 .29049 .11609 .27738 Mtetra
.568 .663 .901 r
.11609 .27738 .12682 .29049 .14151 .28859 .13087 .27487 Mtetra
.564 .651 .894 r
.13087 .27487 .14151 .28859 .15629 .28692 .14575 .27252 Mtetra
.562 .639 .885 r
.14575 .27252 .15629 .28692 .17118 .28537 .16073 .27026 Mtetra
.563 .629 .875 r
.16073 .27026 .17118 .28537 .18619 .28385 .17584 .26797 Mtetra
.567 .619 .864 r
.17584 .26797 .18619 .28385 .20135 .28223 .19109 .26555 Mtetra
.573 .612 .853 r
.19109 .26555 .20135 .28223 .21667 .28036 .2065 .26288 Mtetra
.582 .606 .841 r
.2065 .26288 .21667 .28036 .23215 .27809 .22206 .25984 Mtetra
.592 .601 .83 r
.22206 .25984 .23215 .27809 .24781 .27528 .23779 .2563 Mtetra
.603 .599 .82 r
.23779 .2563 .24781 .27528 .26366 .2718 .2537 .25216 Mtetra
.614 .598 .81 r
.2537 .25216 .26366 .2718 .27969 .26753 .26978 .24734 Mtetra
.626 .598 .802 r
.26978 .24734 .27969 .26753 .2959 .26241 .28603 .24177 Mtetra
.637 .6 .795 r
.28603 .24177 .2959 .26241 .31228 .25637 .30244 .23543 Mtetra
.647 .603 .79 r
.30244 .23543 .31228 .25637 .32882 .24942 .319 .22833 Mtetra
.657 .607 .786 r
.319 .22833 .32882 .24942 .3455 .2416 .33569 .2205 Mtetra
.666 .612 .784 r
.33569 .2205 .3455 .2416 .36231 .23296 .35251 .212 Mtetra
.674 .618 .784 r
.35251 .212 .36231 .23296 .37922 .22363 .36943 .20294 Mtetra
.682 .624 .785 r
.36943 .20294 .37922 .22363 .39624 .21371 .38646 .19343 Mtetra
.688 .632 .788 r
.38646 .19343 .39624 .21371 .41333 .20337 .40356 .18357 Mtetra
.693 .64 .792 r
.40356 .18357 .41333 .20337 .4305 .19273 .42074 .1735 Mtetra
.697 .648 .798 r
.42074 .1735 .4305 .19273 .44772 .18195 .43799 .16334 Mtetra
.699 .657 .804 r
.43799 .16334 .44772 .18195 .46501 .17116 .45531 .15319 Mtetra
.701 .666 .812 r
.45531 .15319 .46501 .17116 .48235 .16047 .47269 .14314 Mtetra
.702 .675 .821 r
.47269 .14314 .48235 .16047 .49976 .14998 .49014 .13327 Mtetra
.701 .684 .83 r
.49014 .13327 .49976 .14998 .51722 .13976 .50766 .12363 Mtetra
.7 .693 .84 r
.50766 .12363 .51722 .13976 .53476 .12985 .52525 .11425 Mtetra
.697 .701 .849 r
.52525 .11425 .53476 .12985 .55237 .12027 .54294 .10515 Mtetra
.695 .708 .858 r
.54294 .10515 .55237 .12027 .57007 .11104 .56071 .09633 Mtetra
.691 .714 .866 r
.56071 .09633 .57007 .11104 .58786 .10215 .57857 .08778 Mtetra
.688 .72 .874 r
.57857 .08778 .58786 .10215 .60575 .09355 .59654 .07946 Mtetra
.684 .725 .881 r
.59654 .07946 .60575 .09355 .62374 .08524 .61462 .07137 Mtetra
.68 .729 .887 r
.61462 .07137 .62374 .08524 .64184 .07716 .63281 .06345 Mtetra
.677 .732 .891 r
.63281 .06345 .64184 .07716 .66006 .06928 .65111 .05568 Mtetra
.674 .734 .895 r
.65111 .05568 .66006 .06928 .6784 .06155 .66953 .04804 Mtetra
.672 .736 .898 r
.66953 .04804 .6784 .06155 .69685 .05395 .68808 .04047 Mtetra
.67 .738 .901 r
.68808 .04047 .69685 .05395 .71543 .04644 .70675 .03297 Mtetra
.611 .708 .913 r
.04658 .27848 .05775 .28994 .07224 .28637 .06114 .27458 Mtetra
.603 .7 .911 r
.06114 .27458 .07224 .28637 .08679 .2831 .07577 .27091 Mtetra
.596 .691 .908 r
.07577 .27091 .08679 .2831 .1014 .28011 .09047 .26747 Mtetra
.589 .681 .904 r
.09047 .26747 .1014 .28011 .11609 .27738 .10525 .26423 Mtetra
.584 .67 .899 r
.10525 .26423 .11609 .27738 .13087 .27487 .12012 .26116 Mtetra
.581 .66 .892 r
.12012 .26116 .13087 .27487 .14575 .27252 .13509 .25819 Mtetra
.579 .65 .884 r
.13509 .25819 .14575 .27252 .16073 .27026 .15017 .25526 Mtetra
.581 .64 .875 r
.15017 .25526 .16073 .27026 .17584 .26797 .16537 .25228 Mtetra
.584 .632 .865 r
.16537 .25228 .17584 .26797 .19109 .26555 .18071 .24915 Mtetra
.589 .625 .855 r
.18071 .24915 .19109 .26555 .2065 .26288 .1962 .24578 Mtetra
.596 .619 .845 r
.1962 .24578 .2065 .26288 .22206 .25984 .21184 .24206 Mtetra
.605 .615 .835 r
.21184 .24206 .22206 .25984 .23779 .2563 .22765 .23789 Mtetra
.614 .612 .826 r
.22765 .23789 .23779 .2563 .2537 .25216 .24361 .2332 Mtetra
.623 .611 .817 r
.24361 .2332 .2537 .25216 .26978 .24734 .25974 .22791 Mtetra
.633 .611 .81 r
.25974 .22791 .26978 .24734 .28603 .24177 .27603 .22199 Mtetra
.643 .613 .804 r
.27603 .22199 .28603 .24177 .30244 .23543 .29247 .21542 Mtetra
.652 .615 .8 r
.29247 .21542 .30244 .23543 .319 .22833 .30905 .20822 Mtetra
.66 .619 .797 r
.30905 .20822 .319 .22833 .33569 .2205 .32576 .20042 Mtetra
.668 .624 .796 r
.32576 .20042 .33569 .2205 .35251 .212 .34259 .19209 Mtetra
.675 .629 .796 r
.34259 .19209 .35251 .212 .36943 .20294 .35953 .1833 Mtetra
.681 .636 .798 r
.35953 .1833 .36943 .20294 .38646 .19343 .37656 .17416 Mtetra
.686 .643 .801 r
.37656 .17416 .38646 .19343 .40356 .18357 .39368 .16476 Mtetra
.69 .651 .806 r
.39368 .16476 .40356 .18357 .42074 .1735 .41088 .1552 Mtetra
.693 .659 .811 r
.41088 .1552 .42074 .1735 .43799 .16334 .42815 .14558 Mtetra
.695 .667 .818 r
.42815 .14558 .43799 .16334 .45531 .15319 .4455 .13598 Mtetra
.697 .675 .826 r
.4455 .13598 .45531 .15319 .47269 .14314 .46292 .12649 Mtetra
.697 .684 .834 r
.46292 .12649 .47269 .14314 .49014 .13327 .48042 .11714 Mtetra
.696 .692 .842 r
.48042 .11714 .49014 .13327 .50766 .12363 .498 .10799 Mtetra
.694 .7 .851 r
.498 .10799 .50766 .12363 .52525 .11425 .51565 .09906 Mtetra
.692 .707 .859 r
.51565 .09906 .52525 .11425 .54294 .10515 .5334 .09034 Mtetra
.689 .713 .867 r
.5334 .09034 .54294 .10515 .56071 .09633 .55125 .08185 Mtetra
.686 .719 .874 r
.55125 .08185 .56071 .09633 .57857 .08778 .56919 .07357 Mtetra
.683 .724 .88 r
.56919 .07357 .57857 .08778 .59654 .07946 .58724 .06548 Mtetra
.68 .728 .886 r
.58724 .06548 .59654 .07946 .61462 .07137 .6054 .05754 Mtetra
.677 .731 .891 r
.6054 .05754 .61462 .07137 .63281 .06345 .62367 .04975 Mtetra
.674 .733 .895 r
.62367 .04975 .63281 .06345 .65111 .05568 .64206 .04206 Mtetra
.672 .736 .898 r
.64206 .04206 .65111 .05568 .66953 .04804 .66057 .03445 Mtetra
.67 .737 .9 r
.66057 .03445 .66953 .04804 .68808 .04047 .6792 .0269 Mtetra
.668 .738 .902 r
.6792 .0269 .68808 .04047 .70675 .03297 .69796 .01938 Mtetra
.619 .711 .911 r
.03529 .26693 .04658 .27848 .06114 .27458 .04993 .26271 Mtetra
.613 .704 .909 r
.04993 .26271 .06114 .27458 .07577 .27091 .06464 .25867 Mtetra
.607 .696 .906 r
.06464 .25867 .07577 .27091 .09047 .26747 .07942 .25481 Mtetra
.601 .687 .902 r
.07942 .25481 .09047 .26747 .10525 .26423 .09429 .2511 Mtetra
.597 .678 .897 r
.09429 .2511 .10525 .26423 .12012 .26116 .10925 .2475 Mtetra
.595 .669 .891 r
.10925 .2475 .12012 .26116 .13509 .25819 .12431 .24397 Mtetra
.594 .66 .884 r
.12431 .24397 .13509 .25819 .15017 .25526 .13948 .24044 Mtetra
.595 .651 .875 r
.13948 .24044 .15017 .25526 .16537 .25228 .15477 .23684 Mtetra
.598 .644 .867 r
.15477 .23684 .16537 .25228 .18071 .24915 .1702 .23308 Mtetra
.603 .637 .858 r
.1702 .23308 .18071 .24915 .1962 .24578 .18577 .22909 Mtetra
.609 .632 .849 r
.18577 .22909 .1962 .24578 .21184 .24206 .20149 .22479 Mtetra
.616 .628 .84 r
.20149 .22479 .21184 .24206 .22765 .23789 .21735 .22009 Mtetra
.623 .626 .832 r
.21735 .22009 .22765 .23789 .24361 .2332 .23338 .21493 Mtetra
.631 .624 .825 r
.23338 .21493 .24361 .2332 .25974 .22791 .24956 .20927 Mtetra
.639 .625 .819 r
.24956 .20927 .25974 .22791 .27603 .22199 .26588 .20307 Mtetra
.647 .626 .814 r
.26588 .20307 .27603 .22199 .29247 .21542 .28235 .19634 Mtetra
.655 .628 .811 r
.28235 .19634 .29247 .21542 .30905 .20822 .29896 .18908 Mtetra
.662 .632 .809 r
.29896 .18908 .30905 .20822 .32576 .20042 .31569 .18134 Mtetra
.669 .636 .808 r
.31569 .18134 .32576 .20042 .34259 .19209 .33254 .17318 Mtetra
.675 .642 .809 r
.33254 .17318 .34259 .19209 .35953 .1833 .34949 .16465 Mtetra
.68 .648 .811 r
.34949 .16465 .35953 .1833 .37656 .17416 .36654 .15584 Mtetra
.684 .655 .815 r
.36654 .15584 .37656 .17416 .39368 .16476 .38368 .14684 Mtetra
.688 .662 .819 r
.38368 .14684 .39368 .16476 .41088 .1552 .4009 .13773 Mtetra
.69 .669 .825 r
.4009 .13773 .41088 .1552 .42815 .14558 .41821 .12858 Mtetra
.691 .677 .831 r
.41821 .12858 .42815 .14558 .4455 .13598 .43559 .11946 Mtetra
.692 .685 .838 r
.43559 .11946 .4455 .13598 .46292 .12649 .45305 .11043 Mtetra
.692 .692 .846 r
.45305 .11043 .46292 .12649 .48042 .11714 .4706 .10152 Mtetra
.691 .7 .853 r
.4706 .10152 .48042 .11714 .498 .10799 .48823 .09277 Mtetra
.689 .706 .861 r
.48823 .09277 .498 .10799 .51565 .09906 .50595 .08419 Mtetra
.687 .712 .868 r
.50595 .08419 .51565 .09906 .5334 .09034 .52377 .07579 Mtetra
.684 .718 .875 r
.52377 .07579 .5334 .09034 .55125 .08185 .54169 .06756 Mtetra
.682 .723 .881 r
.54169 .06756 .55125 .08185 .56919 .07357 .5597 .05949 Mtetra
.679 .727 .886 r
.5597 .05949 .56919 .07357 .58724 .06548 .57783 .05155 Mtetra
.676 .73 .891 r
.57783 .05155 .58724 .06548 .6054 .05754 .59607 .04374 Mtetra
.674 .733 .894 r
.59607 .04374 .6054 .05754 .62367 .04975 .61443 .03602 Mtetra
.672 .735 .898 r
.61443 .03602 .62367 .04975 .64206 .04206 .6329 .02838 Mtetra
.67 .737 .9 r
.6329 .02838 .64206 .04206 .66057 .03445 .6515 .02078 Mtetra
.668 .738 .902 r
.6515 .02078 .66057 .03445 .6792 .0269 .67022 .01322 Mtetra
.667 .739 .904 r
.67022 .01322 .6792 .0269 .69796 .01938 .68907 .00568 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`006P3ooonDo`0003<0ooooU?l0000K0?ooo`006P3o
ool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0T03o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0T03oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`8000002`3oool00ol000000000000000070?ooo`800000103oool20000
00@0oooo00<000000?ooo`3oool0103oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo
00T0oooo00?o00000?ooo`3oool06@3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0B@3oool2o`0003<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool02Ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0
Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`0>0;>c/`030000002IVIT0VIVI00H0
VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@03o`0000000000000001H0
00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00oo00007P0I6ATC000001d0
6ATI00?o0000000000000000;@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo00[o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000
001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000
002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<03`2c/k<3000000H0VIVI00<0000007moO`1oOgl0
0`1oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0
1@0c<c<00`0000006ATI01TI6@0801TI6@03o`0000000000000001D000000`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo00go000000<0000001TI6@0I6AT06P0I6AT3000001<0<c<c
1000000J01TI6@;o0000;@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo00[o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI00@0VIVI00<000000;>c/`2c/k<04`2c/k<00ol00000VIVI09VIV@0409VIV@030000001o
Ogl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C0030000000c
<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6AT00ol0000000000000000D000000<0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0<o`0000030000000I6AT06ATI01H06ATI1@00
000J03<c<`0400000?l000000000000001P06ATI0_l0000[000000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool02_l000000`0000006ATI01TI6@0801TI6@030000000c
<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`0D0;>c/`030000002I
VIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6@03o`000000
0000000001@000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00co000000<0
000001TI6@0I6AT0500I6AT2000002<0<c<c0`00000G01TI6@03o`0000000000000002P000000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0:o`0000030000000I6AT0
6ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0
IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0
/k>c01H0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0
IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT0
6ATI00P06ATI00?o00000000000000004`0000030?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool02ol000000`0000006ATI01TI6@0C01TI6@800000:00c<c<3000001D06ATI00?o0000
0000000000009`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
00[o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI
00@0VIVI00<000000;>c/`2c/k<01P2c/k<00ol0000000000000000500000003o`00002c/k<0/k>c
00H0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`03o`00001VIVH0IVIV
0080IVIV00<0000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI
00L06ATI00?o00000000000000004`0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool02_l000000`0000006ATI01TI6@0C01TI6@030000000c<c<0<c<c02/0<c<c00<0000001TI
6@0I6AT04`0I6AT00ol0000000000000000V000000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool02_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080
Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`060;>c/`03o`00003<c<`0c<c<00L0
c<c<0P0000070;>c/`03o`0000000000VIVI00<0VIVI0P00000407moO`030000001VIVH0IVIV0080
IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P0
6ATI00?o00000000000000004P0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3o
ool02Ol000000`0000006ATI01TI6@0B01TI6@0300000?l00000<c<c02h0<c<c0P00000D01TI6@;o
00009P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00[o0000
00<0000001TI6@0I6AT02@0I6AT00ol00000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI
00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c00:0<c<c08000001`2c/k<00`000000VIVI
09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00204a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01`0I6AT00ol000000000
0000000B000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`09o`0000030000
000I6AT06ATI01006ATI0P00000c03<c<`800000500I6AT00ol0000000000000000S000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool02ol000000`0000006ATI01TI
6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c
/`040;>c/`030000003<c<`0c<c<00d0c<c<0P0000060;>c/`030000002IVIT0VIVI00<0VIVI00<0
000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<0080C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0701TI6@03o`00000000000000014000000`3o
ool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00So000000<0000001TI6@0I6AT0400I
6AT00`000000<c<c03<c<`0e03<c<`<000004P0I6AT00ol0000000000000000R000000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool03?l0000:01TI6@030000000c<c<0
<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`040;>c/`03o`00003<c<`0
c<c<0100c<c<00?o00000000002c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0
Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C003o`00000c<c<0
<c<c00D0<c<c00?o000001TI6@0I6AT01`0I6AT00ol0000000000000000@000000<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`07o`0000030000000I6AT06ATI01006ATI00<00000
03<c<`0c<c<04P0c<c<B00000003o`00000c<c<0<c<c0180<c<c00?o000001TI6@0I6AT0400I6AT0
0ol0000000000000000Q000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?oo
o`3oool02ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<
C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VI
V@2IVIT00P2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<0180c<c<00<000000;>c
/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI
6@0I6AT0200I6AT00ol0000000000000000?000000<0oooo00?o00000?ooo`3oool0<@3oool00ol0
0000oooo0?ooo`08o`0001806ATI00<0000003<c<`0c<c<0400c<c<200000003o`00001<C4`0C4a<
00l0C4a<1P00000@03<c<`800000400I6AT00ol0000000000000000Q000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool02ol000000`0000006ATI01TI6@0801TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`040;>c/`03
0000003<c<`0c<c<01<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@05
0000001oOgl0Ogmo07moO`0000001@1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT0200I6AT00ol0000000000000000?000000<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`07o`0000030000000I6AT06ATI00l06ATI00<0000003<c
<`0c<c<03P0c<c<3000001X0C4a<00<0000003<c<`0c<c<03`0c<c<00`0000006ATI01TI6@0>01TI
6@03o`00000000000000020000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`0<o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000
VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`05@3<c<`00ol00000
/k>c0;>c/`030;>c/`040000002IVIT0VIVI09VIV@8000000`1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI
6@03o`0000000000000000h000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
00Ko000000<0000001TI6@0I6AT03`0I6AT00`000000<c<c03<c<`0<03<c<`<000007P1<C4`30000
00l0<c<c00?o000001TI6@0I6AT03P0I6AT00ol0000000000000000O000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool03?l000000`0000006ATI01TI6@0801TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`03
0000003<c<`0c<c<00L0c<c<1P0000090<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00?o00000000000000003P0000030?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool01Ol000000`0000006ATI01TI6@0?01TI
6@030000000c<c<0<c<c00/0<c<c0P00000T04a<C0<000003@0c<c<2000000l06ATI0_l0000O0000
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool03?l000000`000000
6ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000
IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000
/k>c0;>c/`030;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0103Vi^H2000000P0
c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080
Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI
6@0I6AT01`0I6AT00ol0000000000000000>000000<0oooo00?o00000?ooo`3oool0<@3oool00ol0
0000oooo0?ooo`05o`0000030000000I6AT06ATI00l06ATI00<0000003<c<`0c<c<02P0c<c<00`00
0000C4a<04a<C00W04a<C0030000000c<c<0<c<c00`0<c<c00<0000001TI6@0I6AT03P0I6AT00ol0
000000000000000L000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3o
ool03?l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<
C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3V
i^H01`3Vi^H2000000L0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@03
0000001oOgl0Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT01`0I6AT00ol0000000000000000=000000<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`05o`0000030000000I6AT06ATI00h06ATI00<0000003<c
<`0c<c<02P0c<c<00`000000C4a<04a<C00Y04a<C08000003@0c<c<00`0000006ATI01TI6@0>01TI
6@03o`0000000000000001/000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`0=o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@000000
VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP0:0>KV
iP8000001P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00Go000007mo
O`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<0
0ol000006ATI01TI6@0701TI6@03o`0000000000000000`000000`3oool00ol00000oooo0?ooo`0a
0?ooo`03o`00003oool0oooo00Co000000<0000001TI6@0I6AT03P0I6AT00`000000<c<c03<c<`0:
03<c<`030000001<C4`0C4a<00d0C4a<4@00000>04a<C0800000300c<c<00`0000006ATI01TI6@0>
01TI6@03o`0000000000000001X000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`0=o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`00
0000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@00
0000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP0=
0>KViP8000001@3<c<`00`000000/k>c0;>c/`020;>c/`05o`00002IVIT0VIVI09VIV@000000101o
Ogl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c
<c<00`0000006ATI01TI6@0801TI6@03o`0000000000000000/000000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo00Co000000<0000001TI6@0I6AT03@0I6AT00`000000<c<c03<c
<`0903<c<`03o`0000000000C4a<00/0C4a<1000000A06IVIPD000002`1<C4`2000000/0<c<c0P00
000?01TI6@03o`0000000000000001T000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0=o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl0
1@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KV
iP0@0>KViP030000003<c<`0c<c<00<0c<c<00D000000;>c/`2c/k<0/k>c0000000409VIV@050000
001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0
<c<c00<0000001TI6@0I6AT0200I6AT00ol0000000000000000;000000<0oooo00?o00000?ooo`3o
ool0<@3oool00ol00000oooo0?ooo`05o`0000l06ATI00<0000003<c<`0c<c<02@0c<c<00`000000
C4a<04a<C00904a<C08000006P1VIVH2000000/0C4a<0P00000;03<c<`030000000I6AT06ATI00d0
6ATI00?o0000000000000000600000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo00ko000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000
001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0
VIVI00D000000;>c/`2c/k<0/k>c000000050<c<c0030000003Vi^H0i^KV0140i^KV00<000000<c<
c03<c<`00`3<c<`01Ol00000/k>c0;>c/`2c/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo0000
000406IVIP03o`00001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0801TI6@03o`0000000000000000X000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo00Co000000<0000001TI6@0I6AT0300I6AT00`000000<c<c03<c<`0903<c<`030000001<
C4`0C4a<00P0C4a<0P00000N06IVIP8000002`1<C4`2000000X0<c<c00<0000001TI6@0I6AT03@0I
6AT00ol0000000000000000G000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool03_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102I
VIT01@000000/k>c0;>c/`2c/k<0000000D0c<c<00<000000>KViP3Vi^H04P3Vi^H00`000000c<c<
0<c<c0030<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT01@000000Ogmo07moO`1oOgl00000
00@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI
00L06ATI00?o00000000000000002P0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool00ol000000`0000006ATI01TI6@0<01TI6@030000000c<c<0<c<c00T0<c<c00<0000004a<
C01<C4`0201<C4`00`000000IVIV06IVIP0P06IVIP80000000?o000004a<C01<C4`0201<C4`00ol0
0000<c<c03<c<`0803<c<`03o`00000I6AT06ATI00d06ATI00?o00000000000000005P0000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00oo00002P0I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000
Ogmo07moO`1oOgl0000000@0VIVI00Go00000;>c/`2c/k<0/k>c000000050<c<c0030000003Vi^H0
i^KV0180i^KV00<000000<c<c03<c<`00`3<c<`01@000000/k>c0;>c/`2c/k<0000000@0VIVI00D0
000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
100c<c<00`0000006ATI01TI6@0701TI6@03o`0000000000000000X000000`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo00?o000000<0000001TI6@0I6AT0300I6AT00ol00000<c<c
03<c<`0803<c<`03o`00001<C4`0C4a<00P0C4a<00?o000006IVIP1VIVH0901VIVH2000000T0C4a<
0P00000903<c<`030000000I6AT06ATI00`06ATI00?o00000000000000005P0000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00ko000000<0000001TI6@0I6AT0200I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1V
IVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00D000000;>c/`2c/k<0/k>c000000050<c<c003
0000003Vi^H0i^KV01<0i^KV00<000000<c<c03<c<`00`3<c<`01@000000/k>c0;>c/`2c/k<00000
00@0VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@03o`0000000000000000T000000`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00?o000000<0000001TI6@0I6AT0300I6AT0
0`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH02`1VIVH?
000000d0IVIV0P00000904a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT0
0ol0000000000000000E000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?oo
o`3oool03ol000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<
C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT0
0`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H01`3Vi^H4
o`0000T0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`05o`00002IVIT0
VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080C4a<00<0
000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`0000000000000000T000000`3o
ool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00;o000000<0000001TI6@0I6AT0300I
6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH02@1V
IVH3000000l0Ogmo1000000;06IVIP03o`00001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01`0c
<c<00`0000006ATI01TI6@0<01TI6@03o`0000000000000001@000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0@o`0000030000000I6AT06ATI00L06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D00000
07moO`1oOgl0Ogmo0000000309VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<
c<`00`000000i^KV0>KViP060>KViP03o`00003oool0oooo0080oooo0ol000070>KViP030000003<
c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo
00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c
00<0000001TI6@0I6AT01`0I6AT00ol00000000000000008000000<0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`02o`0000030000000I6AT06ATI00`06ATI00<0000003<c<`0c<c<0
1`0c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00P0IVIV0P00000F07moO`<00000
2@1VIVH2000000P0C4a<0P00000803<c<`03o`00000I6AT06ATI00`06ATI00?o0000000000000000
4`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo013o000000<0
000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0
000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgoo000000<0VIVI00<000000;>c/`2c/k<0
0P2c/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool0
1P3oool2o`0000H0i^KV00D000000<c<c03<c<`0c<c<000000040;>c/`050000002IVIT0VIVI09VI
V@000000101oOgl00`000000IVIV06IVIP0206IVIP050000001<C4`0C4a<04a<C00000001P0c<c<0
0`0000006ATI01TI6@0701TI6@03o`0000000000000000P000000`3oool00ol00000oooo0?ooo`0a
0?ooo`03o`00003oool0oooo00;o000000<0000001TI6@0I6AT0300I6AT00`000000<c<c03<c<`07
03<c<`030000001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01`1VIVH00`00003o000007moO`0J
07moO`<00000201VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00H0<c<c00<00000
01TI6@0I6AT02`0I6AT00ol0000000000000000C000000<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool04?l000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c
00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo
07moO`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080c<c<00<00000
0>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`080?ooo`03o`00003Vi^H0i^KV00@0i^KV00D00000
0<c<c03<c<`0c<c<000000040;>c/`050000002IVIT0VIVI09VIV@000000101oOgl01@000000IVIV
06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@03
o`0000000000000000L000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00;o
000000<0000001TI6@0I6AT02`0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00L0
C4a<00<0000006IVIP1VIVH01@1VIVH200000200Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000
C4a<04a<C00704a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT00ol00000
00000000000B000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
4Ol000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0
0P1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c
/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`090?oo
o`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0
000000<0VIVI00<0000007moOol000000P1oOgl00`000000IVIV06IVIP0206IVIP050000001<C4`0
C4a<04a<C00000001P0c<c<00`0000006ATI01TI6@0701TI6@03o`0000000000000000L000000`3o
ool00ol00000oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`00000000003P0I6AT00`000000<c<c
03<c<`0603<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo
07moO`0<07moO`030000001oOgl0000000<000003`1oOgl00ol00000IVIV06IVIP0606IVIP030000
001<C4`0C4a<00L0C4a<00?o000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@03o`00
000000000000014000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?oo
o`0Ao`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00204a<C0030000001VIVH0IVIV0080IVIV00Go000007moO`1oOgl0Ogmo0000000309VIV@050000
002c/k<0/k>c0;>c/`000000103<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0oooo00X0
oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0060000002c/k<0/k>c0;>c
/ol0000000000P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<
C4`00ol00000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00?o00000000000000001P00
00030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3ooooo00000000000=01TI6@030000
000c<c<0<c<c00L0<c<c00?o000004a<C01<C4`01@1<C4`2000000P0IVIV00?o000007moO`1oOgl0
1`1oOgl500000003o`0000000000VIVI00<0VIVI2000000807moO`<000001P1VIVH00ol000000000
0000000604a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02`0I6AT00ol000000000
0000000@000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool04Ol0
00000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c
0;>c/`2c/k<0000000@0c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0;0?ooo`03
o`00003Vi^H0i^KV00<0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`04
0000002IVIT0VIVI000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<
C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01`0I6AT00ol000000000000000060000
00<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000oooo0?ooool00000000000d06ATI00<00000
03<c<`0c<c<01`0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00L0IVIV00<00000
07moO`1oOgl01`1oOgl00`000000VIVI09VIV@0A09VIV@8000002@1oOgl2000000L0IVIV00<00000
04a<C01<C4`0101<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00/06ATI00?o0000
0000000000003`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
01;o000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<
0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00D00000
0;>c/`2c/k<0/k>c000000030<c<c0030000003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0303o
ool00ol00000i^KV0>KViP030>KViP030000003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c
/k<010000000VIVI09VIV@00000307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o0000000000000000
1@0000030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3ooooo00000000000<01TI6@03
0000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IVIP03
0000001oOgl0Ogmo00H0Ogmo0P00000F09VIV@8000002@1oOgl00`000000IVIV06IVIP0506IVIP03
0000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6@03
o`0000000000000000l000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0Bo`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00204a<C003o`00001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@05
0000002c/k<0/k>c0;>c/`000000103<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo
00d0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0/k>c
0;>c/`0000000`2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00?o000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00?o00000000000000001000
00030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3ooooo00000000000<01TI6@030000
000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0506IVIP03o`00
00000000Ogmo00H0Ogmo0P00000J09VIV@03o`0000000000Ogmo00L0Ogmo00?o000006IVIP1VIVH0
1@1VIVH00ol00000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0
2P0I6AT00ol0000000000000000>000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o
00000?ooo`3oool04_l000000`0000006ATI01TI6@0801TI6@03o`00000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000
0`2IVIT01@000000/k>c0;>c/`2c/k<0000000@0c<c<00<000000>KViP3Vi^H00`3Vi^H00ol00000
oooo0?ooo`0=0?ooo`03o`00003Vi^H0i^KV00<0i^KV00<000000<c<c03<c<`00P3<c<`01@000000
/k>c0;>c/`2c/k<0000000<0VIVI00<0000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1VIVH0
000000@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@03o`0000000000
000000@000000`3oool00ol00000oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`0000000000300I
6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01@1V
IVH00`000000Ogmo07moO`0507moO`03o`00002IVIT0VIVI01`0VIVI00<0000007moO`1oOgl01P1o
Ogl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c
<c<00`0000006ATI01TI6@0:01TI6@03o`0000000000000000h000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Co`0000030000000I6AT06ATI00L06ATI00<00000
03<c<`0c<c<0100c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV00D0000007moO`1oOgl0Ogmo
0000000309VIV@030000002c/k<0/k>c0080/k>c00D000000<c<c03<c<`0c<c<000000050>KViP03
o`00003oool0oooo00h0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c005
0000002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207moO`040000001VIVH0IVIV
000000D0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0801TI6@03o`0000000000
000000<000000`3oool00ol00000oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`0000000000300I
6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101V
IVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00P0VIVI3`00000709VIV@8000001`1o
Ogl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c
<c<00`0000006ATI01TI6@0:01TI6@03o`0000000000000000d000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Co`0000030000000I6AT06ATI00P06ATI00<00000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D00000
07moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/`000000103<c<`00`000000i^KV
0>KViP020>KViP03o`00003oool0oooo00l0oooo00?o00000>KViP3Vi^H00P3Vi^H00`000000c<c<
0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT01Ol00000Ogmo07moO`1oOgl00000
00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI
00L06ATI00?o00000000000000000`0000030?ooo`03o`00003oool0oooo0340oooo00Co00000?oo
o`3oool000003@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00L0VIVI0P00000?
0;>c/`03o`00002IVIT0VIVI00H0VIVI0P00000607moO`030000001VIVH0IVIV00@0IVIV00<00000
04a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI00?o0000
000000000000300000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
01Co000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<
0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00D00000
0;>c/`2c/k<0/k>co`0000040<c<c0030000003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool0403o
ool00ol00000i^KV0>KViP020>KViP030000003<c<`0c<c<0080c<c<00Go00000;>c/`2c/k<0/k>c
0000000309VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C003
o`00000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0200I6AT00ol00000000000000002000000<0
oooo00?o00000?ooo`3oool0<@3oool01?l00000oooo0?ooo`00000=01TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo
00@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`00003o00000;>c/`0A0;>c/`<000001`2IVIT20000
00D0Ogmo0P00000506IVIP03o`0000000000C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`00
00006ATI01TI6@0:01TI6@03o`0000000000000000/000000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`0Do`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c
<c<00`0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1o
Ogl00P1oOgl01?l00000VIVI09VIV@0000030;>c/`030000003<c<`0c<c<0080c<c<00<000000>KV
iP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0?0?ooo`03o`00003Vi^H0i^KV0080i^KV00<000000<c<
c03<c<`00`3<c<`010000000/k>c0;>c/`00000309VIV@050000001oOgl0Ogmo07moO`000000101V
IVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0200I
6AT00ol00000000000000002000000<0oooo00?o00000?ooo`3oool0<@3oool01?l00000oooo0?oo
o`00000=01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV
06IVIP0306IVIP03o`00001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT01P2IVIT00`000000/k>c
0;>c/`0E0;>c/`8000001`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV
00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI
00?o00000000000000002`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo01Go000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0303<c<`030000001<
C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI
00D000000;>c/`2c/k<0/k>c000000040<c<c0030000003Vi^H0i^KV0080i^KV00?o00000?ooo`3o
ool0403oool00ol00000i^KV0>KViP020>KViP030000003<c<`0c<c<0080c<c<00D000000;>c/`2c
/k<0/k>c0000000309VIV@050000001oOgl0Ogmo07moO`000000101VIVH01@000000C4a<04a<C01<
C4`0000000H0<c<c00<0000001TI6@0I6AT0200I6AT01?l0000000000000000000030?ooo`03o`00
003oool0oooo0340oooo00Co00000?ooo`3oool00000300I6AT00`000000<c<c03<c<`0603<c<`03
0000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`03
0000002IVIT0VIVI00@0VIVI0P00000J0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1o
Ogl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@03o`0000000000000000X000000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Eo`0000030000000I6AT06ATI00L06ATI
00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP00
00000`1oOgl01@000000VIVI09VIV@2IVIT0000000<0/k>c00<000000<c<c03<c<`00P3<c<`00`00
0000i^KV0>KViP020>KViP03o`00003oool0oooo0140oooo00?o00000>KViP3Vi^H00P3Vi^H00`00
0000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1o
Ogl0000000<0IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I
6AT06ATI00L06ATI00Co000000000000000000000`3oool00ol00000oooo0?ooo`0a0?ooo`04o`00
003oool0oooo000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00X0/k>c1`00000:0;>c/`03o`0000000000000000D0VIVI00?o00000000001o
Ogl0101oOgl00`000000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@03o`0000000000000000T000000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Eo`0000030000000I6AT06ATI00L06ATI
00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP00
00000`1oOgl01@000000VIVI09VIV@2IVIT0000000<0/k>c00<000000<c<c03<c<`00P3<c<`00`00
0000i^KV0>KViP020>KViP03o`00003oool0oooo0140oooo00?o00000>KViP3Vi^H00P3Vi^H00`00
0000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1o
Ogl0000000@0IVIV00D0000004a<C01<C4`0C4a<0000000603<c<`030000000I6AT06ATI00L06ATI
00Co000000000000000000000`3oool00ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo0000
00`06ATI00<0000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00404a<C0030000001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c
00P0/k>c0P0000070<c<c0<000002P2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo
00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00D0<c<c00<0000001TI6@0I6AT02P0I6AT00ol00000000000000009000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool05_l000000`0000006ATI01TI6@0701TI6@03
0000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP05
0000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k<0000000@0c<c<00<00000
0>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00<0i^KV00D00000
0<c<c03<c<`0c<c<000000030;>c/`050000002IVIT0VIVI09VIV@000000101oOgl01@000000IVIV
06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0701TI6@04
o`00000000000000000000<0oooo00?o00000?ooo`3oool0<@3oool01?l00000oooo0?ooo`00000<
01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`06
0;>c/`<00000303<c<`3000000P0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`03
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`06
03<c<`030000000I6AT06ATI00X06ATI00?o0000000000000000200000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo01Ko000000<0000001TI6@0I6AT0200I6AT00`00
0000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000101VIVH01@000000Ogmo07moO`1o
Ogl0000000<0VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c0030000003Vi^H0i^KV0080i^KV
00?o00000?ooo`3oool04@3oool00ol00000i^KV0>KViP020>KViP030000003<c<`0c<c<0080c<c<
00D000000;>c/`2c/k<0/k>c0000000309VIV@050000001oOgl0Ogmo07moOol00000101VIVH01@00
0000C4a<04a<C01<C4`0000000H0<c<c00<0000001TI6@0I6AT01`0I6AT00ol00000000000000003
0?ooo`03o`00003oool0oooo0340oooo00Co00000?ooo`3oool00000300I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0407moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<200000180c<c<00<0
0000o`00002c/k<01P2c/k<00`000000VIVI09VIV@0309VIV@800000101oOgl00`000000IVIV06IV
IP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI
6@0:01TI6@03o`0000000000000000P000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0Go`0000030000000I6AT06ATI00L06ATI00?o000003<c<`0c<c<00`0c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000
000309VIV@050000002c/k<0/k>c0;>c/`0000000`3<c<`00ol00000i^KV0>KViP030>KViP03o`00
003oool0oooo0100oooo00?o00000>KViP3Vi^H00`3Vi^H01@000000c<c<0<c<c03<c<`0000000<0
/k>c00Ko000009VIV@2IVIT0VIVIo`000000000207moO`030000001VIVH0IVIV0080IVIV00<00000
04a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00P06ATI00?o0000
0000003oool00P3oool00ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo000000`06ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0
000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00D0/k>c00<0
00000<c<c03<c<`0503<c<`2000000H0/k>c0P00000509VIV@030000001oOgl0Ogmo0080Ogmo00?o
00000000001VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00?o
000001TI6@0I6AT02P0I6AT00ol00000000000000007000000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool05ol000000`0000006ATI01TI6@0701TI6@030000000c<c<0
<c<c00@0<c<c00Go000004a<C01<C4`0C4a<0000000406IVIP050000001oOgl0Ogmo07moO`000000
0`2IVIT01@000000/k>c0;>c/`2c/k?o000000<0c<c<00<000000>KViP3Vi^H00`3Vi^H00ol00000
oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00<0i^KV00D000000<c<c03<c<`0c<c<000000040;>c
/`050000002IVIT0VIVI09VIV@0000000P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0801TI6@03o`0000000000
oooo0080oooo00?o00000?ooo`3oool0<@3oool01?l00000oooo0?ooo`00000<01TI6@030000000c
<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo00<0Ogmo00?o000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`050;>c/`030000003<
c<`0c<c<01H0c<c<0P0000060;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1o
Ogl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c
<c<00`0000006ATI01TI6@0901TI6@03o`0000000000000000L000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Go`0000030000000I6AT06ATI00L06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP000000101o
Ogl01@000000VIVI09VIV@2IVIT000000080/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV
0>KViP030>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H00P3Vi^H00`000000c<c<
0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1oOgl00000
00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI
00L06ATI00?o00000000003oool00P3oool00ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo
000000`06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0
/k>c00D0/k>c00<000000<c<c03<c<`06@3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0
VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@03o`0000000000
000000H000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Ho`00
00030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<01@000000C4a<04a<C01<C4`0
000000@0IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/`000000
0`3<c<`00`000000i^KV0>KViP030>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H0
0`3Vi^H01@000000c<c<0<c<c03<c<`0000000@0/k>c00D0000009VIV@2IVIT0VIVI0000000207mo
O`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c
<`030000000I6AT06ATI00P06ATI00Go00000?ooo`3oool0ooooo`00000c0?ooo`04o`00003oool0
oooo000000`06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c
/k<0/k>c00@0/k>c00<000000<c<c03<c<`01P3<c<`<o`0000T0c<c<00<000000;>c/`2c/k<00`2c
/k<00`000000VIVI09VIV@0309VIV@03o`00001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1V
IVH00`000000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I
6AT00ol00000000000000006000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o0000
0?ooo`3oool06?l000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`00P1<C4`01P000000IVIV06IVIP1VIVH00000o`0000<0Ogmo00Go000009VIV@2IVIT0
VIVI000000030;>c/`050000003<c<`0c<c<0<c<c00000001@3Vi^H00ol00000oooo0?ooo`0@0?oo
o`03o`00003Vi^H0i^KV0080i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0
000000<0VIVI00D0000007moO`1oOgl0Ogmo0000000306IVIP030000001<C4`0C4a<0080C4a<00<0
000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@05o`00003oool0oooo0?ooool00000
<`3oool01?l00000oooo0?ooo`00000<01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00H0c<c<0_l0000;0>KViP?o
00001`3<c<`00`000000/k>c0;>c/`030;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1o
Ogl00P1oOgl00ol00000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0901TI6@03o`0000000000000000D000000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Ho`0000030000000I6AT06ATI00L06ATI
00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV
00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/`000000103<c<`00`00
0000i^KV0>KViP020>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H00`3Vi^H01@00
0000c<c<0<c<c03<c<`0000000<0/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`050000001V
IVH0IVIV06IVIP000000101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI
00Go00000?ooo`3oool0ooooo`00000c0?ooo`04o`00003oool0oooo000000`06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0000007mo
O`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<
c03<c<`01@3<c<`00ol00000i^KV0>KViP0>0>KViP;o00001P3<c<`00`000000/k>c0;>c/`030;>c
/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI
6@03o`0000000000000000@000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`0Io`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VI
V@050000002c/k<0/k>c0;>c/`000000103<c<`00`000000i^KV0>KViP020>KViP03o`00003oool0
oooo00l0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0
/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00?o000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00Co00000?ooo`3ooooo
0000<`3oool01Ol00000oooo0?ooool00000000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`00
0000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`00
0000VIVI09VIV@0209VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0103<c<`2o`00
01<0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<
00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@03o`00000000000000
00@000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Ko`0000T0
6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C005o`00001VIVH0IVIV06IV
IP0000000`1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00D000000<c<c03<c<`0c<c<o`00
00050>KViP03o`00003oool0oooo00h0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<
c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1oOgl0000000@0
IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00L0
6ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`00000000002`0I6AT00`00
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`00
0000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV01@0i^KV00?o00000<c<c03<c<`0103<c<`00ol0
0000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00?o00000000001oOgl00`1oOgl00`00
0000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00ol0
00006ATI01TI6@0901TI6@03o`0000000000000000<000000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`0Jo`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl01@00
0000VIVI09VIV@2IVIT0000000@0/k>c00Go00000<c<c03<c<`0c<c<000000060>KViP03o`00003o
ool0oooo00d0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c0050000002c
/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<
C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00L06ATI0`3oool00ol00000
oooo0?ooo`0a0?ooo`05o`00003oool0ooooo`00000000002`0I6AT00`000000<c<c03<c<`0503<c
<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<
c003o`00003Vi^H0i^KV01D0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`020;>c
/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI
6@03o`0000000000000000<000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`0Ko`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<00`0c<c<00`000000
C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl01@000000VIVI09VIV@2IVIT0
000000<0/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP030>KViP03o`00003oool0
oooo00d0oooo00?o00000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0
/k>c0;>c/`0000000`2IVIT00`000000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP000000
101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo
0?ooo`0a0?ooo`05o`00003oool0ooooo`00000000002`0I6AT00`000000<c<c03<c<`0503<c<`03
0000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`03
0000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c003
o`00003Vi^H0i^KV01L0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`03
0000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03
0000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0:01TI6@03
o`00000000000000008000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0Ko`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<
04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl010000000VIVI09VIV@0000040;>c
/`050000003<c<`0c<c<0<c<c00000001P3Vi^H00ol00000oooo0?ooo`0=0?ooo`03o`00003Vi^H0
i^KV00<0i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00D0
000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
0`0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000oooo
0?ooool00000000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03
0000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP090>KViPGo
00002P3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00?o000009VIV@2I
VIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<
C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI00?o000000000000
00000P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01co0000
00<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00<0C4a<
00D0000006IVIP1VIVH0IVIV0000000307moO`05o`00002IVIT0VIVI09VIV@000000102c/k<01@00
0000c<c<0<c<c03<c<`0000000H0i^KV0_l0000=0?ooo`03o`00003Vi^H0i^KV00<0i^KV00<00000
0<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00D0000007moO`1oOgl0Ogmo
0000000406IVIP030000001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<0100c<c<00`0000006ATI
01TI6@0501TI6@<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000oooo0?ooool00000000000/0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080
IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080
/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP070>KViP?o00001@3oool4o`0000L0
i^KV00?o00000<c<c03<c<`00`3<c<`00ol00000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@04o`000000000000000000
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool07?l000000`000000
6ATI01TI6@0701TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`01@000000
IVIV06IVIP1VIVH0000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT01@000000/k>c0;>c/`2c/k<0
000000@0c<c<00?o00000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0:0?ooo`03o`00003Vi^H0
i^KV00<0i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00D0
000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0
0`0c<c<00`0000006ATI01TI6@0501TI6@<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000oooo
0?ooool00000000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03
0000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP060>KViP03
o`00003oool0oooo00X0oooo0_l000060>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c
/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I
6AT02P0I6AT01?l0000000000000000000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo01go000000<0000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0303<c<`03
0000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`030000002IVIT0VIVI
0080VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c0030000003Vi^H0i^KV00D0i^KV00?o0000
0?ooo`3oool0203oool00ol00000i^KV0>KViP040>KViP030000003<c<`0c<c<0080c<c<00<00000
0;>c/`2c/k<00P2c/k<01Ol00000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP1VIVH00P1V
IVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0100I
6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool00_l000000`0000006ATI01TI
6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c
/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H01@3Vi^H00ol00000oooo0?oo
o`0=0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c
/`020;>c/`030000002IVIT0VIVI0080VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI
6@0901TI6@04o`00000000000000000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o
00000?ooo`3oool07Ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00`1<C4`01Ol00000IVIV06IVIP1VIVH0000000<0Ogmo00<0000009VIV@2IVIT0
0P2IVIT01@000000/k>c0;>c/`2c/k<0000000@0c<c<00<000000>KViP3Vi^H01@3Vi^H00ol00000
oooo0?ooo`070?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000
/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0401TI
6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`02o`0000030000000I6AT06ATI
00T06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c
0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo
00l0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c
0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV
0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI
00T06ATI00?o00000000000000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`0Mo`0000030000000I6AT06ATI00P06ATI00?o000003<c<`0c<c<00`0c<c<00`000000
C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl00`000000VIVI09VIV@0209VI
V@05o`00002c/k<0/k>c0;>c/`000000103<c<`00`000000i^KV0>KViP060>KViP;o00001P3oool0
0ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<0
1@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0100I6AT30?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool00_l000000`0000006ATI01TI6@0901TI6@030000000c
<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<
c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0?0?ooo`03o`00003V
i^H0i^KV00D0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002I
VIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<
C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@03o`000000
0000000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool07_l00000
0`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`0
1@000000IVIV06IVIP1VIVH0000000<0Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000
003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H01`3Vi^H2o`000080oooo0_l000080>KViP030000
003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000<0
Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0
<c<c00<0000001TI6@0I6AT0100I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3o
ool00_l000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3V
i^H0103Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<
c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@000000101oOgl00`00
0000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`00
00006ATI01TI6@0901TI6@03o`0000000000000000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool07_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07mo
O`0000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080c<c<00<000000>KV
iP3Vi^H0203Vi^H2o`0000X0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c
/`050000002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0301TI6@<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`03o`0000030000000I6AT06ATI00P06ATI00<00000
03<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00`3<
c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H0103V
i^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2I
VIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<
C4`00ol00000<c<c03<c<`0403<c<`030000000I6AT06ATI00X06ATI00?o00000000003oool00P3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Oo`0000030000000I6AT0
6ATI00P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0
IVIV06IVI_l00000101oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`0
0P3<c<`00ol0000000000>KViP0C0>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<0
0P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000
C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT00`0I6AT30?ooo`03
o`00003oool0oooo0340oooo00?o00000?ooo`3oool00ol000000`0000006ATI01TI6@0901TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP03
0000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<
00<0c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV
00<0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI
09VIV@000000101oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@03o`0000000000oooo0080oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool07ol000000`0000006ATI01TI6@0801TI
6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`01Ol00000IVIV06IVIP1VIVH0
000000@0Ogmo00<0000009VIV@2IVIT00P2IVIT01@000000/k>c0;>c/`2c/k?o000000H0c<c<00<0
00000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00D0
000009VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00<06ATI0`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo00?o000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo
07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0030<c<c003
o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04`3oool00ol00000i^KV0>KViP030>KViP03
o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT00000
00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT02@0I6AT00ol0000000000?ooo`020?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo023o000000<0000001TI6@0I6AT0200I6AT00`000000
<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000
Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00D000000;>c/`2c/k<0/k>c000000060<c<
c0030000003Vi^H0i^KV0100i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c
/`050000002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0301TI6@<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`03o`0000030000000I6AT06ATI00T06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<00000
07moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00`3<
c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H00`3V
i^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2I
VIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<
C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI00Go00000?ooo`3oool0oooo
o`00000K0?ooo`006P3oool00ol00000oooo0?ooo`0Qo`0000030000000I6AT06ATI00L06ATI00<0
000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0
000007moO`1oOgl0Ogmo0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0
0`3<c<`00`000000i^KV0>KViP0@0>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<0
0P2c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`000000
C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT00P0I6AT30?ooo`03
o`00003oool0oooo0340oooo00?o00000?ooo`3oool01?l000000`0000006ATI01TI6@0901TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP05
0000001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<
0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV
00<0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI
09VIV@000000101oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@05o`00003oool0oooo0?ooool000006`3o
ool001X0oooo00?o00000?ooo`3oool08_l0000:01TI6@03o`00000c<c<0<c<c00<0<c<c00<00000
o`00001<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102I
VIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<0P00000@0>KViP030000003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@050000001o
Ogl0Ogmo07moOol00000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c
00<0000001TI6@0I6AT00P0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
1?l000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0
0`1<C4`00`000000IVIV06IVIP0306IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000
/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000
oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000
/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000
IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0901TI6@04o`00003oool0ooooo`0001/0oooo000J0?ooo`03o`00003oool0oooo027o
000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080
C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207moO`050000002IVIT0VIVI09VI
V@0000001@2c/k<00ol00000c<c<0<c<c0040<c<c08000003P3Vi^H00`000000c<c<0<c<c0030<c<
c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0
000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT0
6ATI00806ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00Co000000<00000
01TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<00000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`05o`00002IVIT0VIVI09VIV@000000102c
/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool04`3o
ool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1V
IVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I
6AT01?l00000oooo0?ooool0000K0?ooo`006P3oool00ol00000oooo0?ooo`0Ro`0000030000000I
6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001V
IVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000D0/k>c
00<000000<c<c03<c<`01@3<c<`2000000X0i^KV0P0000060<c<c003o`00002c/k<0/k>c0080/k>c
00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000D0IVIV00<0000004a<C01<
C4`00P1<C4`00`000000<c<c03<c<`0403<c<`040000000I6AT06ATI01TI6@<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`05o`0000030000000I6AT06ATI00T06ATI00<0000003<c
<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00D0000007mo
O`1oOgl0Ogmo0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`0
0ol00000i^KV0>KViP030>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H0103Vi^H0
0ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT0
0`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`0
0`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI0`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0So`0000030000000I6AT06ATI00P06ATI00<0000003<c
<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007mo
O`1oOgl00P1oOgl01P000000VIVI09VIV@2IVIT00000o`0000@0/k>c00<000000<c<c03<c<`01P3<
c<`2000000H0i^KV0P0000080<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2I
VIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<
C4`00ol00000<c<c03<c<`0403<c<`040000000I6AT06ATI01TI6@<0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`05o`0000030000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00D0000007moO`1oOgl0
Ogmo0000000409VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000
i^KV0>KViP040>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000
c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00?o000009VIV@2IVIT00P2IVIT00`000000
Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`00
6P3oool00ol00000oooo0?ooo`0So`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl0
0P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0
1`3<c<`00`000000i^KV0>KViP03000000X0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI
09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00@0000001TI6@0I6AT06ATI0`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo00Go000000<0000001TI6@0I6AT02@0I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH01@000000
Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<
c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0503oool00ol00000i^KV0>KViP030>KV
iP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VI
V@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<
C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6AT30?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo02Co000000<0000001TI6@0I6AT0200I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000
Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000
c<c<0<c<c0070<c<c08000003@3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080
C4a<00<0000003<c<`0c<c<0100c<c<0100000006ATI01TI6@0I6AT30?ooo`03o`00003oool0oooo
0340oooo00?o00000?ooo`3oool01Ol000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo
0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<
0080c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0i^KV
00<0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<
00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6@<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool09?l000000`0000006ATI01TI6@0801TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`03
0000003<c<`0c<c<01@0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C003
0000000c<c<0<c<c00<0<c<c00@0000001TI6@0I6AT06ATI0`3oool00ol00000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo00Ko000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c
<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<
c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool04`3oool00ol00000i^KV0>KViP040>KV
iP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VI
V@050000001oOgl0Ogmo07moO`0000001@1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo02Go000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c
<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0207mo
O`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c00C0<c<
c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207mo
O`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c
<`030000000I6AT06ATI00<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`06o`00
00030000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00304a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VI
V@050000002c/k<0/k>c0;>c/`0000001@3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0
oooo0180oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0
/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000D0IVIV00<0
000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI0`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Uo`0000030000000I6AT0
6ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C003o`00001VIVH0
IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0
/k>c00<0/k>c00?o00000000003<c<`04P3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0
VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool01_l000000`0000006ATI01TI6@0901TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT01Ol00000/k>c0;>c/`2c/k<0000000D0c<c<00?o
00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0B0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o
00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00D0
000007moO`1oOgl0Ogmo0000000506IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0
100c<c<00`0000006ATI01TI6@0801TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o
00000?ooo`3oool09_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`800000403<c<`00`000000/k>c0;>c
/`040;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool01_l000000`0000006ATI01TI
6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000
003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0A0?ooo`03o`00
003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000
002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo0000000506IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool09_l000000`0000006ATI01TI6@0801TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`050;>c/`030000
003<c<`0c<c<00`0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<C0030000
000c<c<0<c<c00D0<c<c00<0000001TI6@3oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00
003oool0oooo00Oo000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000
001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000
002IVIT0VIVI0080VIVI00D000000;>c/`2c/k<0/k>c000000050<c<c003o`00003Vi^H0i^KV00D0
i^KV00?o00000?ooo`3oool03`3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<00<0
c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080
Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0
<c<c00<0000001TI6@0I6AT01`0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo02Oo000000<00000o`00000I6AT0200I6AT00`00003o000003<c<`0403<c<`030000
0?l00000C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000
002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00ol0000000000000000:0<c<c0800000
1`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@3oool0
0P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00Oo000000<0000001TI6@0I6AT0
2@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
0`1VIVH01@000000Ogmo07moO`1oOgoo000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000
c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00D0i^KV0_l0000?0?ooo`03o`00003Vi^H0i^KV00@0
i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0701TI6@<0oooo00?o00000?ooo`3o
ool06@3oool001X0oooo00?o00000?ooo`3oool0:?l000000`0000006ATI01TI6@0801TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`060;>c/`<00000
1P3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
1@0c<c<00`0000006ATI0?ooo`020?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
1ol000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0
0`1<C4`00`000000IVIV06IVIP0306IVIP050000001oOgl0Ogmo07moO`0000001@2IVIT00`000000
/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H01`3Vi^H2o`0000/0
oooo0_l000070>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000
C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01`0I6AT30?ooo`03
o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02Wo000000<0000001TI6@0I6AT0
200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
0`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0
202c/k<6000000X0/k>c00?o000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000
001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000
000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`08o`0000030000
000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV00<0IVIV00D0000007moO`1oOgl0Ogmo0000000509VIV@030000002c/k<0/k>c0080
/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP080>KViP03o`00003oool0oooo00L0
oooo00?o00000>KViP3Vi^H01`3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080
/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00H0
6ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Zo`0000030000
000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C003o`00
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00ol00000000009VIV@0309VIV@030000
0?l00000000001H0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0207moO`030000
001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000
000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`09o`0000030000
000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV0080IVIV00?o000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000
002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`2o`0000T0i^KV1?l000020?ooo`?o0000
2P3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT0
0P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0
0`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0Zo`0000030000000I6AT06ATI00P06ATI00<0
000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00?o
000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c01<0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT0oooo0080oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`09o`0000030000000I6AT06ATI00T06ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<0
00000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP0:0>KViP;o0000303Vi^H00ol00000c<c<0<c<
c0040<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07mo
O`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0503<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0[o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<0
0`000000C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl0101oOgl0
0`000000VIVI09VIV@0409VIV@8000004P2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0
Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@3oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo00Wo000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0
VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0
i^KV01L0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0
VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0:ol000000`0000006ATI01TI6@0801TI
6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IV
IP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`0>0;>c
/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<01@000000oooo0?ooo`3ooooo
000003<0oooo00?o00000?ooo`3oool02_l000000`0000006ATI01TI6@0901TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00@0c<c<00?o00000>KViP3Vi^H05@3Vi^H00ol00000c<c<0<c<c0040<c<c0030000002c/k<0
/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0
IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT0
6ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0]o`00
00X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C003o`00001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl00`1oOgl2000000L0VIVI0P00000<0;>c/`800000202IVIT00`00
0000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0503<c<`050000003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`0:
o`0000030000000I6AT06ATI00X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c00<0/k>c00?o00000<c<c03<c<`0103<c<`3o`0001@0i^KV00?o0000
0<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<00000
07moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<00000
03<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool0;?l000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP03o`0000000000Ogmo
00@0Ogmo0P00000709VIV@800000202c/k<2000000X0VIVI00<0000007moO`1oOgl00`1oOgl00`00
0000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<01@00
0000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool03?l0000;01TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP03o`00001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00H0c<c<0_l0000A0>KViP03o`00003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<00`2c/k<0
0`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH0
0`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01P0I6AT3
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02go000000<0000001TI
6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00H0VIVI2000000;09VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00304a<
C0030000000c<c<0<c<c00D0<c<c00D000000?ooo`3oool0ooooo`00000c0?ooo`03o`00003oool0
oooo00_o000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0
VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<2000000P0c<c<00?o00000>KViP3Vi^H0303Vi^H2
o`0000L0c<c<00<000000;>c/`2c/k<00`2c/k<00ol00000VIVI09VIV@0209VIV@030000001oOgl0
Ogmo00<0Ogmo00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00D0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo02ko000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c
<`0300000?l00000C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407mo
O`030000002IVIT0VIVI01L0VIVI00?o000007moO`1oOgl0101oOgl00ol00000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<01@000000oooo0?ooo`3ooooo
000003<0oooo00?o00000?ooo`3oool03?l000000`0000006ATI01TI6@0:01TI6@030000000c<c<0
<c<c00@0<c<c00<00000o`00001<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0
c<c<00H0c<c<1?l000080>KViP;o0000203<c<`00ol00000/k>c0;>c/`040;>c/`030000002IVIT0
VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0;_l000000`0000006ATI01TI6@0901TI
6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000000006IVIP0506IV
IP03o`00001oOgl0Ogmo00@0Ogmo00?o00000000002IVIT05P2IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c
<`050000003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`0<o`0000030000000I6AT0
6ATI00X06ATI00?o000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C003o`00001VIVH0
IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0
/k>c00@0/k>c00<000000<c<c03<c<`02@3<c<`8o`0000X0c<c<00<000000;>c/`2c/k<0102c/k<0
0`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH0
0`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01P0I6AT3
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02oo000000<0000001TI
6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI01<0VIVI00<0000007mo
O`1oOgl01@1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c
<`0c<c<01@0c<c<01@000000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool03Ol00000
0`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT0
0`000000/k>c0;>c/`040;>c/`8000006P3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0
VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0<?l000000`0000006ATI01TI6@0901TI
6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IV
IP030000001oOgl0Ogmo00D0Ogmo0P00000B09VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00D000000?oo
o`3oool0ooooo`00000c0?ooo`03o`00003oool0oooo00go000000<0000001TI6@0I6AT02P0I6AT0
0`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<0
0`000000c<c<0<c<c00F0<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT00P2IVIT0
0`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`0
0`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0ao`0000030000000I6AT06ATI00T06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00@0IVIV0P00000707mo
O`8000003P2IVIT2000000P0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00D0<c<c00D000000?ooo`3oool0ooooo`00000c0?ooo`03o`00003oool0
oooo00ko000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0307moO`030000002IVIT0
VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<00`00003o00000000000D0<c<c003o`00002c/k<0
/k>c00D0/k>c00<0000009VIV@2IVIT00`2IVIT00ol00000Ogmo07moO`0307moO`030000001VIVH0
IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT0
6ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0ao`00
00030000000I6AT06ATI00T06ATI00?o000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<
C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01P1oOgl3000000T0VIVI0P00000:07mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c
<`050000003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`0?o`0000`06ATI00<00000
03<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV00@0IVIV00<00000
07moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@03o`0000000000/k>c00L0/k>c00<00000
0<c<c03<c<`03`3<c<`2000000P0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`03
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`05
03<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`0bo`0000030000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<01@0c<c<00`00
0000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0201oOgl90000
00`0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00D0<c<c00D000000?ooo`3oool0ooooo`00000c0?ooo`03o`00003oool0oooo00ko000000<00000
01TI6@0I6AT02`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00<00000
0;>c/`2c/k<01P2c/k<3000000X0c<c<100000090;>c/`030000002IVIT0VIVI00@0VIVI00<00000
07moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<00000
03<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool0<ol000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo
01/0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00H0<c<c00@000000?ooo`3ooooo0000<`3oool00ol00000oooo0?ooo`0?o`0000030000000I6AT0
6ATI00/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV00@0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@0300000?l00000
/k>c00P0/k>c100000020<c<c0@00000302c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0
Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0
<c<c00H0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo03Co0000300I6AT00`000000<c<c03<c<`0503<c<`8000001P1<C4`00`00
0000IVIV06IVIP0506IVIP03o`0000000000Ogmo01X0Ogmo00?o000006IVIP1VIVH01@1VIVH00`00
0000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00@000000?ooo`3ooooo0000<`3oool0
0ol00000oooo0?ooo`0@o`0000030000000I6AT06ATI00X06ATI00?o000003<c<`0c<c<01P0c<c<0
0`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl0101oOgl0
0`000000VIVI09VIV@0409VIV@800000302c/k<2000000l0/k>c00<0000009VIV@2IVIT01@2IVIT0
0`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`0
0`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0do`0000030000000I6AT06ATI00X06ATI00?o000003<c
<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00H0IVIV0P00000G07mo
O`800000201VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00@000000?oo
o`3ooooo0000<`3oool00ol00000oooo0?ooo`0@o`0000030000000I6AT06ATI00/06ATI00<00000
03<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@8000006P2c/k<00`000000VIVI09VIV@05
09VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C004
04a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo03Go000000<0000001TI6@0I6AT02P0I6AT00`00
0000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01`1VIVH20000
01@0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c
00H0<c<c00@000000?ooo`3ooooo0000<`3oool00ol00000oooo0?ooo`0Ao`0000030000000I6AT0
6ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@<000005@2c/k<2
000000L0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP03o`00001<C4`0
C4a<00@0C4a<00?o000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0=_l000000`0000006ATI01TI6@0:01TI
6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`00003o000006IVIP0806IV
IP8000004@1oOgl00ol00000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<00<0000003<c
<`0c<c<01P0c<c<010000000oooo0?ooool0000c0?ooo`03o`00003oool0oooo01;o000000<00000
01TI6@0I6AT02`0I6AT00`000000<c<c03<c<`0603<c<`03o`00001<C4`0C4a<00@0C4a<00?o0000
06IVIP1VIVH00`1VIVH00`00003o000007moO`0407moO`0300000?l00000000000P0VIVI0`00000@
0;>c/`03o`0000000000VIVI00L0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@06
01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0=ol0000<01TI
6@030000000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0806IV
IP8000003@1oOgl2000000X0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c
<`040000003oool0ooooo`0003<0oooo00?o00000?ooo`3oool04_l000000`0000006ATI01TI6@0;
01TI6@03o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0202IVIT4000000X0/k>c0P000009
09VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C005
04a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo03Oo000000<0000001TI6@0I6AT02P0I6AT00`00
0000<c<c03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH02@1VIVH30000
00T0Ogmo00<0000006IVIP1VIVH02P1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c
00H0<c<c00@000000?ooo`3ooooo0000<`3oool00ol00000oooo0?ooo`0Co`0000030000000I6AT0
6ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0
IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl2000000`0VIVI2P00000:09VIV@030000001oOgl0
Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0
<c<c00H0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo03So000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0603<c
<`030000001<C4`0C4a<00H0C4a<0P00000<06IVIPT00000301VIVH00`000000C4a<04a<C00604a<
C0030000000c<c<0<c<c00H0<c<c00D000000?ooo`3oool0ooooo`00000c0?ooo`03o`00003oool0
oooo01Co000000<0000001TI6@0I6AT02`0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0607moO`8000007@2IVIT0
0ol00000Ogmo07moO`0607moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`0
0`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00L06ATI0`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0io`0000030000000I6AT06ATI00X06ATI00?o000003<c
<`0c<c<01P0c<c<00`00003o000004a<C00704a<C0030000001VIVH0IVIV01h0IVIV00<0000004a<
C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c<`050000003oool0oooo0?ooool00000<`3oool0
0ol00000oooo0?ooo`0Eo`0000030000000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<0
0ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00@0IVIV00?o00000000001oOgl01`1oOgl3
000001P0VIVI0P00000807moO`03o`00001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`0
0`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00L06ATI0`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0ko`0000`06ATI00<0000003<c<`0c<c<01`0c<c<00`00
0000C4a<04a<C00604a<C003o`0000000000IVIV01`0IVIV00<0000004a<C01<C4`01`1<C4`00`00
0000<c<c03<c<`0603<c<`050000003oool0oooo0?ooool00000<`3oool00ol00000oooo0?ooo`0G
o`0000`06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0
IVIV00D0IVIV0P00000907moO`8000005@2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0
IVIV00H0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT0
6ATI00L06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0jo`00
00030000000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00704a<
C08000006P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00L0<c<c00D000000?oo
o`3oool0ooooo`00000c0?ooo`03o`00003oool0oooo01Ko000000<0000001TI6@0I6AT02`0I6AT0
0`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01P1VIVH2
000000T0Ogmo0P00000@09VIV@<000002@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0
C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0801TI6@<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0>ol000000`0000006ATI01TI6@0:01TI
6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0F06IV
IP03o`00001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<01`0c<c<01@000000oooo0?ooo`3ooooo
000003<0oooo00?o00000?ooo`3oool05ol000000`0000006ATI01TI6@0;01TI6@030000000c<c<0
<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0
Ogmo00P0Ogmo1@00000609VIV@03o`00000000000000008000002`1oOgl00`000000IVIV06IVIP06
06IVIP03o`00001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01P0c<c<00ol000006ATI01TI6@08
01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0??l000000`00
00006ATI01TI6@0:01TI6@8000002@0c<c<00ol00000000004a<C00804a<C003o`00000000000000
01<0IVIV0P00000;04a<C0030000000c<c<0<c<c00L0<c<c00D000000?ooo`3oool0ooooo`00000c
0?ooo`03o`00003oool0oooo01Oo000000<0000001TI6@0I6AT0300I6AT00`000000<c<c03<c<`06
03<c<`03o`0000000000C4a<00H0C4a<0P00000706IVIP03o`0000000000000000d0Ogmo1P00000>
07moO`0300000?l00000IVIV00L0IVIV00<0000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`07
03<c<`030000000I6AT06ATI00P06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`0lo`0000030000000I6AT06ATI00`06ATI00<0000003<c<`0c<c<0200c<c<00`00
0000C4a<04a<C00904a<C0<000003P1VIVH2000000d0C4a<00<0000003<c<`0c<c<01`0c<c<01@00
0000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool06?l000000`0000006ATI01TI6@0<
01TI6@030000000c<c<0<c<c00L0<c<c0P00000704a<C0800000201VIVH3000001d0Ogmo00<00000
06IVIP1VIVH01`1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<00000
01TI6@0I6AT0200I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
03go00000P00000=01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`02`1<C4`30000
00T0IVIV0P00000>04a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@3oool00P3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo01Wo000000<0000001TI6@0I6AT0300I6AT00`00
0000<c<c03<c<`0803<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH0201VIVH00`00
0000Ogmo07moO`0I07moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`00
0000<c<c03<c<`0703<c<`030000000I6AT06ATI00T06ATI0`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`0oo`0000030000000I6AT06ATI00/06ATI00?o00000000000c
<c<0200c<c<00ol00000C4a<04a<C00=04a<C0T000003`1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0Ko`0000h0
6ATI00?o000003<c<`0c<c<0200c<c<00ol00000C4a<04a<C00604a<C08000002@1VIVH01000003o
000000000000000C07moO`@000002@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c
00P0<c<c00<0000001TI6@0I6AT02@0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo03oo000000<0000001TI6@0I6AT03@0I6AT00`000000<c<c03<c<`0703<c<`03
0000001<C4`0C4a<02@0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI0?ooo`020?ooo`03
o`00003oool0oooo0340oooo00?o00000?ooo`3oool06ol000000`0000006ATI01TI6@0<01TI6@03
0000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`01`1<C4`2000000/0IVIV0`00000=07moO`<0
0000301VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I
6AT02@0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo043o0000
00<0000001TI6@0I6AT03@0I6AT00`000000<c<c03<c<`0703<c<`8000008`1<C4`00`000000<c<c
03<c<`0903<c<`030000000I6AT0oooo0080oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo
0?ooo`0Lo`0000030000000I6AT06ATI00`06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<
04a<C00804a<C0800000301VIVH=000000h0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c
03<c<`0803<c<`030000000I6AT06ATI00X06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00ol00000oooo0?ooo`11o`0000030000000I6AT06ATI00`06ATI00<0000003<c<`0c<c<02@0c
<c<200000200C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI0?ooo`020?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool07Ol000000`0000006ATI01TI6@0<01TI6@030000000c
<c<0<c<c00P0<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0S06IVIP03o`00001<
C4`0C4a<00T0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0:01TI6@<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0@ol0000>01TI6@030000000c<c<0
<c<c00X0<c<c0P00000M04a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@3oool00P3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo01ko00003`0I6AT00`000000<c<c03<c<`08
03<c<`8000002P1<C4`00`00003o00000000000P06IVIP8000002P1<C4`00`00003o000003<c<`08
03<c<`0300000?l000006ATI00`06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`13o`0000030000000I6AT06ATI00`06ATI00<0000003<c<`0c<c<02`0c<c<20000
01X0C4a<00<0000003<c<`0c<c<0300c<c<00`0000006ATI0?ooo`020?ooo`03o`00003oool0oooo
0340oooo00?o00000?ooo`3oool07_l000000`0000006ATI01TI6@0=01TI6@030000000c<c<0<c<c
00T0<c<c0P00000;04a<C0030000001VIVH0IVIV01X0IVIV0`00000;04a<C0030000000c<c<0<c<c
00T0<c<c00<0000001TI6@0I6AT0300I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo04Co000000<0000001TI6@0I6AT0300I6AT2000000d0<c<c0`00000E04a<C080
00003P0c<c<00`0000006ATI01TI6@030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3o
ool07ol000000`0000006ATI01TI6@0=01TI6@8000002`0c<c<00`000000C4a<04a<C00904a<C0<0
0000601VIVH00`000000C4a<04a<C00;04a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I
6AT03@0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo04Go0000
00<0000001TI6@0I6AT03@0I6AT2000000h0<c<c00@00000o`000000000000003`1<C4`2000000l0
<c<c00@0000001TI6@0I6AT06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
023o000000<00000o`00000I6AT03P0I6AT2000000X0<c<c00<00000o`00000000002`1<C4`40000
0100IVIV1000000<04a<C0800000300c<c<00`0000006ATI01TI6@0=01TI6@<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool0A_l000000`0000006ATI01TI6@0>01TI6@03
0000000c<c<0<c<c00l0<c<c0`00000:04a<C08000004@0c<c<0100000006ATI01TI6@0I6AT30?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool08Ol000000`0000006ATI01TI6@0?01TI
6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`0301<C4`00ol0000000000000000=0000
00l0C4a<00<0000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0=01TI6@04o`00003oool0oooo
o`0001/0oooo000J0?ooo`03o`00003oool0oooo04Oo000000<0000001TI6@0I6AT03P0I6AT00`00
0000<c<c03<c<`0A03<c<`X000004P0c<c<00`0000006ATI01TI6@0201TI6@<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`0Ro`0000030000000I6AT06ATI00l06ATI00<0000003<c
<`0c<c<02P0c<c<2000002X0C4a<00<0000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0>01TI
6@04o`00003oool0ooooo`0001/0oooo000J0?ooo`03o`00003oool0oooo04So000000<0000001TI
6@0I6AT03P0I6AT00`000000<c<c03<c<`0/03<c<`030000000I6AT06ATI00806ATI0`3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02?o000000<0000001TI6@0I6AT03`0I6AT00`00
0000<c<c03<c<`0;03<c<`8000009`1<C4`00ol00000<c<c03<c<`0<03<c<`03o`00000I6AT06ATI
00h06ATI00Go00000?ooo`3oool0ooooo`00000K0?ooo`006P3oool00ol00000oooo0?ooo`1:o`00
01006ATI0P00000[03<c<`030000000I6AT06ATI00<06ATI0`3oool00ol00000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo02Co00000P00000@01TI6@8000003@0c<c<300000280C4a<0P00000>03<c
<`030000000I6AT06ATI00l06ATI00Go00000?ooo`3oool0ooooo`00000K0?ooo`006P3oool00ol0
0000oooo0?ooo`1:o`0000030000000I6AT06ATI00l06ATI0P00000Y03<c<`030000000I6AT06ATI
00<06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02Ko000000<0000001TI
6@0I6AT03`0I6AT00`000000<c<c03<c<`0=03<c<`<000007@1<C4`2000000l0<c<c00<0000001TI
6@0I6AT0400I6AT01Ol00000oooo0?ooo`3ooooo000001/0oooo000J0?ooo`03o`00003oool0oooo
04_o000000<0000001TI6@0I6AT0400I6AT00`000000<c<c03<c<`0U03<c<`030000000I6AT06ATI
00@06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02Oo000000<0000001TI
6@0I6AT03`0I6AT00`000000<c<c03<c<`0?03<c<`@000005`1<C4`200000100<c<c00<0000001TI
6@0I6AT0400I6AT00ol0000000000?ooo`020?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo04co000000<0000001TI6@0I6AT0400I6AT00`000000<c<c03<c<`0T03<c<`03
0000000I6AT06ATI00@06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02So
000000<0000001TI6@0I6AT03`0I6AT2000001<0<c<c0P00000C04a<C08000004@0c<c<00ol00000
6ATI01TI6@0A01TI6@03o`0000000000oooo0080oooo00?o00000?ooo`3oool06@3oool001X0oooo
00?o00000?ooo`3oool0C_l000000`0000006ATI01TI6@0?01TI6@@00000800c<c<2000000L06ATI
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02Wo000000<0000001TI6@0I6AT0
400I6AT00`000000<c<c03<c<`0B03<c<a40000000?o00000000000c<c<04@0c<c<2000001806ATI
00?o00000000000000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?oo
o`1?o`0000030000000I6AT06ATI01806ATI00<0000003<c<`0c<c<0700c<c<00`0000006ATI01TI
6@0701TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0Zo`0000030000000I
6AT06ATI01006ATI00?o00000000000c<c<0=@0c<c<00`0000006ATI01TI6@0A01TI6@04o`000000
00000000000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0D?l0
00000`0000006ATI01TI6@0B01TI6@8000006P0c<c<2000000X06ATI0`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo02_o00000P00000B01TI6@800000<P0c<c<2000001@06ATI00Co
000000000000000000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?oo
o`1Bo`0001D06ATI0P00000G03<c<`03o`00000I6AT06ATI00X06ATI0`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo02go000000<0000001TI6@0I6AT04@0I6AT01000003o00000000
0000000/03<c<`8000005@0I6AT00ol00000000000000002000000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0D_l000000`0000006ATI01TI6@0D01TI6@<000004P0c
<c<2000000d06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo02ko000000<0
000001TI6@0I6AT0500I6AT2000002P0<c<c0P00000G01TI6@03o`00000000000000008000000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1Co`0000030000000I6AT0
6ATI01H06ATI1000000<03<c<`8000003`0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0;ol000000`0000006ATI01TI6@0E01TI6@030000000c<c<0<c<c02<0<c<c0P00000H
01TI6@03o`0000000000000000<000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`1Do`0000030000000I6AT06ATI01T06ATI3000000A01TI6@<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`0`o`0000030000000I6AT06ATI01D06ATI0`00000Q03<c
<`03o`00000I6AT06ATI01L06ATI00?o0000000000000000100000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo05Go00000P00000f01TI6@<0oooo00?o00000?ooo`3o
ool0<@3oool00ol00000oooo0?ooo`0ao`0000800000600I6AT4000001P0<c<c1@00000I01TI6@03
o`0000000000000000D000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`1Go`0000800000=00I6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
<ol00002000001X06ATI0`00000B03<c<`<000007@0I6AT00ol00000000000000006000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0FOl000000`0000006ATI01TI
6@0a01TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0eo`0000030000000I
6AT06ATI01X06ATI4P00000O01TI6@03o`0000000000000000L000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`1Jo`0000030000000I6AT06ATI03006ATI0`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03Ko000000<00000o`0000000000B00I6AT2
o`0000X000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1Ko`00
00030000000I6AT06ATI02l06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
03Wo000000<0000001TI6@0I6AT0A00I6AT00ol0000000000000000:000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool0G?l000000`0000006ATI01TI6@0^01TI6@<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0jo`0000800000@`0I6AT00ol00000
00000000000;000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
GOl000000`0000006ATI01TI6@0]01TI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo
0?ooo`0lo`0000030000000I6AT06ATI03l06ATI00?o0000000000000000300000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo05ko000000<00000o`0000000000;00I
6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0?Ol00002000003h06ATI00?o
00000000000000003@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0
oooo067o000000<0000001TI6@0I6AT0:@0I6AT30?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0?ol00002000003/06ATI00?o00000000000000003P0000030?ooo`03o`00003oool0
oooo01T0oooo000J0?ooo`03o`00003oool0oooo06;o00000P00000Y01TI6@<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`11o`0000800000=`0I6AT2o`00014000000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1To`0000030000000I6AT06ATI02H0
6ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo04?o00000P00000d01TI6@03
o`00000000000000014000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`1Uo`0000030000000I6AT06ATI02D06ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00
003oool0oooo04Go000000<0000001TI6@0I6AT0<00I6AT00ol0000000000000000B000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0T03oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo0900oooo00?o00000?ooo`3oool06@3oool001X0ooooU?l0000c
0?oooiCo00006`3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool008D0oooo0_l000350?ooo`;o0000@P3oool00880oooo0ol000000`3ooooo00000?ooo`310?oo
o`?o000000<0ooooo`00003oool0@@3oool00800oooo0_l000030?ooo`030:bliOl0003o00000;l0
oooo0_l000030?ooo`030:Zmiol0003o00000440oooo001m0?ooo`?o00000`3oool30:bli@03o`00
003ooooo00000;/0oooo0ol000030?ooo`<0Z[gW00?o00000?ooool00000@03oool007X0oooo0ol0
00040?ooo`80[[cT0`2/_>D00ol00000ooooo`00002h0?ooo`?o0000103oool20:^liP<0Z[gW00?o
00000?ooool00000@03oool007P0oooo0_l000040?ooo`030:nkhP2^_>@0[[cT00<0[[cT0P2/_>D0
1?l00000[KcU0?ooool0002e0?ooo`;o00000`3oool70:^liP80Z[gW00Co00000:^liP3ooooo0000
?`3oool007D0oooo0ol000050?ooo`<0[k_R0`2^_>@0102__><0[KcU0:fliOl000020:fli@030?oo
ool00000oooo0;00oooo0ol000020?ooo`030:bli@2[_>H0ZkcV00T0ZkcV00Go00000:^liP2[_>H0
ooooo`00000n0?ooo`00L`3oool2o`0000D0oooo0P2a^^050:nkhP0:0:jli02__><0[kcS0:nlh`2]
_>Go00000:fli@2^_>@0ooooo`000:l0oooo0_l000040?ooo`<0[;cU0`2[_>H00`2/_>D0ZkcV0:^l
iP040:^liP05o`00002[_>H0ZkcV0?ooool00000?P3oool00700oooo0ol000040?ooo`030;Big@2a
^^00/K[P00<0/K[P0P2_^n820;6kh@D0[kcS00Ko00000:jli02^_>@0[[cT0?ooool0002[0?ooo`?o
0000103oool20:bki0@0[;cU00@0ZkcV0:bli@2/_>D0[;cU0`2[_>H00`2/_>D0ZkcVo`0000030:^l
iP030?ooool00000oooo03`0oooo001^0?ooo`;o00001P3oool30;Big@<0/K[P00<0/k[N0;6kh@2a
^n400`2a^n420:nlh`80/;_R00?o00000:jli02^_>@00P2^_>@00ol00000oooo0?ooo`2W0?ooo`;o
0000103oool00`2]^^@0[;_T0:bki0030:bki080[;cU0P2/^nD40:bli@050:^liP2/_>D0[;cU0:bl
iOl000000`2[_>H00`3ooooo00000?ooo`0l0?ooo`00J`3oool3o`0000H0oooo00<0][SJ0;Big@2d
^Md00`2d^Md0102a^^00/k[N0;>jgP2c^]h30;6kh@030;:jh02`^n80/;_R0080/;_R00?o00000:jl
i02^_>@00P2__><00`3ooooo00000?ooo`2T0?ooo`?o00000`3oool00`2]^^80[K[T0:fji0020:fj
i0<0[;_T00<0[K_T0:bki@2/^nD00`2/^nD20:bli@80[;_U0`2/_>D00ol00000ZkcV0:^liP020:bl
iP030?ooool00000oooo03/0oooo001X0?ooo`?o0000203oool30;JhfP<0];WM00<0][WK0;>jgP2c
^]h00`2c^]h0102a^n40/[[P0;:jh02b^^030;2khP03o`00002__><0[kcS00<0[kcS00<0ooooo`00
003oool0X03oool3o`0000@0oooo102]^^830:fji0030:bki02]^n@0[K_T0080[K_T0`2/^nD00`2]
^n@0[;_U0:bki@030:bki@80[;cU00?o00000:bli@2/_>H00`2/_>H00`3ooooo00000?ooo`0j0?oo
o`00IP3oool2o`0000T0oooo00<0^KKF0;JhfP2f^=X00`2f^=X0102d^Md0][WK0;Jif`2f^M/30;>j
gP030;Big@2b^^00/[[P00<0/[[P00@0/;_R0;6kh@2a^n7o00000`2__><00`2`^n80ooooo`00002O
0?ooo`;o00001@3oool20:jih@@0[K[R0P2]^^@20:jjhP@0[K_T00<0[;_U0:fki02]^n@00P2]^n@3
0:bki@060:fki02/_>D0[;cU0:bliOl00000[;cU0P2/_>H00`2/_>D0ooooo`00000k0?ooo`00H`3o
ool3o`0000T0oooo102i]]H30;JhfP030;Rgf02f^M/0][WK00<0][WK00@0/k[N0;Big@2d^Md0];WM
0`2b^^001`2d^]h0/K_Q0;6kh@2a^n7o00000;6kh@2__><00`2`^n800`3ooooo00000?ooo`2J0?oo
o`?o0000103oool00`2_]ml0[[WQ0:jih@030:jih@80[K[R0P2^^N440:jjhP80[K_T0P2^^^<40:fk
i0030:bki@2]^n@0[K_T0080[K_T0P2/_>D00ol00000[K_T0:bli@030:bli@030?ooool00000oooo
03T0oooo001Q0?ooo`;o00002P3oool00`2k/m80^KKF0;VfeP030;VfeP030;JhfP2h]mP0^;OH0080
^;OH0`2f^M/00`2g^=T0];WM0;Big@030;Big@040;:jh02d^]h0];[N0;BjgP80/K_Q00?o00000;:k
g`2`^n80102`^n800`3ooooo00000?ooo`2G0?ooo`;o00001P3oool30:ngg`<0[[WQ00<0[kSO0:ji
h@2^^N400`2^^N420:jjhP030:nih@2^^^<0[[[S00<0[[[S0P2]^n@20:jjh`@0[K_T00<0[;cU0:fk
i?l000000P2]^n@20:bli@040:fli03oool0ooooo`0003T0oooo001N0?ooo`?o00002`3oool30;^c
dP<0^KKF00<0^kGC0;Rgf02h]mP00`2h]mP00`2f^M/0]kSI0;Nhf@020;Nhf@80];WM0P2f^M/30;Bj
gP040;Fjg@2b^ml0/[_Oo`000080/[_O0P2`^n820;6kh@030?ooool00000oooo09@0oooo0ol00006
0?ooo`030:nfgP2_]ml0[kOO00<0[kOO00@0[[WQ0:nhg`2_^=l0[kSO0`2^^N400`2`^=l0[kWQ0:ni
h@020:nih@<0[[[S00<0[kWQ0:jjh`2^^^<00`2^^^<20:fki080[[_S00D0[K_To`00002]^n@0[K_T
0:bli@030:fli0030?ooool00000oooo03P0oooo001L0?ooo`;o00003@3oool50;^cdP040;VfeP2k
]M<0^kGC0;^ed`<0^;OH0P2j]]D30;Nhf@030;Vge`2f^M/0][WK00<0][WK00P0];[N0;Fjg@2e^]d0
]K[M0;:kgol00000/[_O0;BjgPD0/K_Q00<0ooooo`00003oool0T@3oool2o`0000H0oooo00<0/;CL
0:nfgP2_]]h00P2_]]h20:ngg`80/;KM1@2_^=l0102^^N40/;SO0;2hg`2`^=l40:nih@040:jjh`2_
^N40[kWQ0:nih@<0[[[S00<0[k[R0:jkh`2^^n<00`2^^n<01?l00000[K_T0:jkh`2^^n<40:fli003
0?ooool00000oooo03L0oooo001I0?ooo`?o00003P3oool20;jac@<0^k?B00<0_K;?0;^ed`2k]M<0
0`2k]M<00`2h]mP0^[KE0;Zfe@020;Zfe@040;Nhf@2i]mL0^KOG0;Vge`<0][WK00<0^;SI0;Fjg@2e
^]d00`2e^]d01?l00000];[N0;BjgP2d^]h30;6kh@040;>kg`3oool0ooooo`0008h0oooo0ol00006
0?ooo`@0/;CL0P2_]]h00`2a]=/0/;KM0;2fg@030;2fg@<0[kSO00<0/;KM0;2hg`2`^=l00`2`^=l2
0:nih@030;2hg`2_^N40[kWQ00<0[kWQ00@0[[[S0:njhP2_^^80[k[R0`2^^n<00`2_^^;o00000:jk
h`030:jkh`80[KcT0P2^^n@00`3ooooo00000?ooo`0f0?ooo`00E`3oool2o`000100oooo102n/Ld0
102k/m80_K;?0;fbc`2m//l30;^ed`030;fdd@2j]]D0^[KE00<0^[KE1@2i]mL0102f^M/0^;SI0;Rh
f@2h^=T30;Fjg@030;Nifol00000];[N00<0];[N00H0/K_Q0;>kg`2c^ml0/k_O0?ooool0002<0?oo
o`;o00001`3oool00`2`/mX0/;CL0;2dg0030;2dg0040:nfgP2a]=/0/KCK0;6df`@0/;KM00<0[kSO
0;2fg@2`]]d00P2`]]d30;2hg`030;6gg@2`^=l0/;SO0080/;SO0P2_^N420;2ih0D0[k[R00@0[[_S
0:njhP2_^^;o00000`2^^n<00`2_^n80[[_T0:jki0030:jki003o`00003oool0oooo03D0oooo001D
0?ooo`?o0000403oool00`30[lT0_[7=0;jac@030;jac@D0_K;?00@0^kGC0;fdd@2m]=40_KCA0`2j
]]D20;bed`<0^KOG00<0^kOE0;Rhf@2h^=T00`2h^=T0102e^]d0]kWK0;Nifol000030;BjgP030;Jj
g@2c^ml0/k_O00<0/k_O00<0ooooo`00003oool0Q`3oool3o`0000H0oooo00<0/K7H0;2cfP2`/mX0
0P2`/mX30;2dg0030;6cf@2a]=/0/KCK00<0/KCK0P2`]]d20;6ef`@0/;KM00<0/;SO0;6gg@2a]md0
0P2a]md20;2hg`030;6ggP2`^N00/;WP00<0/;WP0P2_^^820;2ih0<0[k[R00?o00000:jkh`2_^n80
0`2_^n830:jki0030:jkh`3ooooo000003H0oooo001A0?ooo`?o00004P3oool30<2_b@<0_[7=0P30
/<X30;fbc`030;nac02m]=40_KCA00<0_KCA00<0^[KE0;bed`2l]M<00P2l]M<0102i]mL0^kOE0;^g
e@2k]mD30;Rhf@070;Zhe`2g^M/0]kWK0;Nifol00000]kWK0;BjgP030;Jjg@80/k_O0P2d^mh20?oo
o`03o`00003oool0oooo0880oooo0ol000080?ooo`<0/K7H102`/mX0102`]=`0/K?I0;6cf@2a/mT3
0;6df`030;:cf@2a]M/0/KGK00<0/KGK0P2`]]d20;:ef`@0/KOM00@0/;SO0;6ggP2a]mh0/KON0`2`
^N000`2a^=h0/;WP0;2ih0030;2ih080[k[R00?o00000;2jh@2_^n800`2_^n800`2^^n@0[[_S0:jk
h`020:jkh`030?ooool00000oooo03@0oooo001?0?ooo`;o00004`3oool00`31[<D0`:o90<2_b@03
0<2_b@030;jac@30/<X0`;3:0080`;3:00@0_K;?0;nac02o/L`0_k7<0`2m]=400`2o/lh0_;GC0;be
d`020;bed`030;jdd02k]mD0^kOE0080^kOE00<0^;SI0;Zhe`2j^=L00P2j^=L20;Nif`03o`00002i
^MT0][[M0080][[M00<0^;[K0;BkgP2d^mh00`2d^mh00`3ooooo00000?ooo`210?ooo`;o00002@3o
ool00`2a[mH0/K7H0;6af0030;6af080/;?J0P2b/ML40;6cf@040;6df`2b/mT0/[?I0;:cf@<0/KGK
00<0/k?I0;:ef`2b]M/00`2b]M/20;6gg@80/[KK102a]mh0102`^N00/KSN0;6hgP2a^=h30;2ih004
0;6ig`2`^^40/;[Qo`000080/;[Q0P2_^n820;2jh@<0[[_S00<0[k_R0?ooool00000=@3oool004`0
oooo0ol0000D0?ooo`80`Jc51030[lT00`32[LH0`;3:0<2`bP020<2`bP030<:_a`2o/L`0_k7<0080
_k7<00<0_KCA0;nccP2o/lh00P2o/lh00`2l]M<0_[C@0;jdd0020;jdd080^kOE00<0_KKB0;Zhe`2j
^=L00`2j^=L20;Vif@04o`00002i^MT0^KWI0;Jjg@<0^;[K0`2d^mh0102f^md0oooo0?ooool0001n
0?ooo`?o00002P3oool30;6_eP<0/K7H00<0/ZoE0;:ae`2b/ML00`2b/ML20;6cf@030;>ae`2b/mT0
/[?I00<0/[?I00@0/KGK0;>cf@2c/mT0/k?I0`2b]M/00`2c]=T0/[KK0;:ff`030;:ff`80/KON0P2c
]m`40;6hgP080;2ih02a^Ml0/KWO0;6ig`2`^^7o00000;2jh@2a^Ml50;2jh@060:jkh`2_^n80[k_R
0:nkhP3ooooo0000=03oool004X0oooo0_l0000F0?ooo`@0`Jc50P30[lT30<:]aP80`;3:0P32[lL4
0;nac0D0_k?>1@2n]=00102k]mD0_KKB0;ffdP2m]]830;Zhe`80_;OE00@0^KWIo`00002i^MT0^kWG
1@2h^]/01P2d^mh0][_M0;Jkg@2f^md0ooooo`0007`0oooo0_l0000;0?ooo`030;2]e02a[mH0/JoF
00<0/JoF00@0/K7H0;:_e@2b[mD0/ZoE0`2b/ML00`2c[m@0/k7G0;>ae`020;>ae`<0/[?I00<0/k7F
0;>cf@2c/mT00`2c/mT0102b]M/0/kCI0;>df@2c]=T30;:ff`030;Bef@2c]m`0/kOL00<0/kOL0P2a
^=h00`2c]m`0/KWO0;6ig`030;6ig`04o`00002a^Ml0/KWO0;6ig`80/;[Q0P2a^^040:nkhP030?oo
ool00000oooo03<0oooo00170?ooo`?o00005`3oool50<6/a@030<2_b@32[LH0`Zg60080`Zg600<0
`;3:0<:_a`32[lL00P32[lL20;nac080`[790`2o/lh20<6bb`<0_[C@00<0`KC>0;ffdP2m]]800`2m
]]800`2j^=L0_;OE0;bge@020;bge@04o`00002k^ML0^kWG0;^ie`<0^;[K00<0^K[I0;Jkg@2f^md0
0`2f^md00`3ooooo00000?ooo`1g0?ooo`?o00002P3oool00`2`Zm<0/:gD0;2]e0020;2]e0<0/JoF
00<0/ZcC0;:_e@2b[mD00`2b[mD0102b/ML0/joD0;>_e02c[m@40;>ae`040;:cf@2c/MH0/k7F0;>a
eP<0/k?I00<0];;F0;>df@2c]=T00`2c]=T0102b]]/0];GI0;Bef@2d]MT30;>gg0030;BffP2c]m`0
/kOL0080/kOL0P2a^Ml20;>hg@04o`00002a^Ml0/KWO0;>igPD0/K[P0P2_^n820;6kh@030?ooool0
0000oooo0380oooo00150?ooo`;o00006@3oool20<:Y`@@0`Jc51@32[LH50<:_a`030;nac032/LT0
`[790080`[7900<0_k?>0<6bb`31///00P31///0102n]=00`KC>0<6dcP31]<h30;ffdP80`;K@0`2l
]mD00`2n]m;o00000;^ie`030;^ie`040;Rjf`2i^]T0^K[I0;Vjf@80][_M0P2h^m/20?ooo`03o`00
003oool0oooo07<0oooo0_l0000<0?ooo`<0/:_C102`[M@0102a[mH0/ZcC0;:/d`2b[=<30;:_e@03
0;>/dP2c[m@0/joD00<0/joD0P2c/ML00`2d[m<0/k7F0;>aeP030;>aeP040;>cf@2d/]H0];;F0;Bb
eP<0/kCI00<0]K?F0;Bef@2d]MT00P2d]MT00`2c]m`0];KJ0;BffP020;BffP80/kOL00<0];OJ0;>h
g@2c^=d00P2c^=d00ol00000/KWO0;>igP020;>igP<0/K[P00<0/[[O0;6kh@2a^n400`2a^n400`3o
oooo00000?ooo`0a0?ooo`00@P3oool3o`0001X0oooo0`32ZL430<6/a@80`j_20`32[LH20<>/``@0
`Zo71@32/LT50<6bb`D0`KC>00<0_KKB0<2fd030]]000P30]]00102l]mD0_[OB0;jgd_l000030;^i
e`050;fhe@2i^]T0^K[I0;Vjf@2k^]P01@2h^m/00`3ooooo00000?ooo`1a0?ooo`?o0000303oool0
0`2`ZM40/:_C0;2[d`020;2[d`80/:gD0P2aZ]450;:/d`040;:_e@2c[=80/jcB0;>/dP<0/joD00<0
]:gA0;B_d`2d[m<00P2d[m<30;>aeP030;F`d`2d/]H0];;F0080];;F00<0/kCI0;FceP2e/mH00P2e
/mH20;Bef@030;Jde`2d]]X0];KJ00<0];KJ00@0/kOL0;BgfP2d]mX0];OJ0`2c^=d00ol00000];SK
0;>igP030;>igP040;6jh02b^]l0/[[O0;:jg`<0/K_Q00<0/[_P0?ooool00000<P3oool003l0oooo
0ol0000L0?ooo`D0`ZW100<0`Jc50<>[`P33Zl800P33Zl801032[LH0`jc30<>/``33[<<30<:_a`80
a:k50`32/LT20<B`aP<0`K;;0P33//P40<6dcP@0`;K@00H0`[G>0;jgdP2n]m80_[OBo`00002k^ML4
0;fhe@040;Vjf@2k^]P0^k[H0;^jf0<0^;_K0P2j^mX00`3ooooo00000?ooo`1]0?ooo`?o00003@3o
ool40;2Yd@80/:_C00<0/JS?0;6Zd@2aZ]400`2aZ]430;:/d`030;>Zc`2c[=80/jcB0080/jcB00<0
/joD0;B]d@2d[M400P2d[M430;B_d`030;>aeP2e/=<0]K3C0080]K3C0P2d/]H00`2f/=<0]K?F0;Fc
eP030;FceP040;Bef@2f]=L0][CG0;Jde`<0];KJ0P2f]MP40;BgfP030;>hg@2d^=_o00000080];SK
0P2c^Mh00`2d^M`0/[[O0;:jg`030;:jg`060;6kh@2b^n00/[_P0;:kh03ooooo0000<@3oool003d0
oooo0_l0000O0?ooo`030<>W_P32ZL40`ZW10080`ZW11@33Zl850<>/``030<:_a`34[/D0a:k50080
a:k500<0`[790<B`aP34/<H00P34/<H01031///0`k;80<>bb033//P30<6dcP80`k?;0P30]]030<:e
cP80_[OB00?o00000<6gd02m^=D00P2m^=D00`2o^=<0^k[H0;^jf0030;^jf0030;Rkf`2j^mX0^[_J
0080^[_J00<0ooooo`00003oool0JP3oool2o`0000h0oooo00<0[jO@0;2Yd@2`ZM400`2`ZM40102`
Zm<0/JS?0;6Xc`2aZ<l40;6Zd@030;:/d`2cZ/l0/j[?0080/j[?0P2c[=800`2dZ/h0]:gA0;B]d@03
0;B]d@80]:oC00<0]Zg@0;F`d`2e/=<00`2e/=<0102d/]H0][3C0;J`d`2f/=<30;FceP80]k7C102f
]=L00`2d]]X0][GH0;Jef0020;Jef080];OJ0P2f]]T0102d^=_o00000;Bhf`2f]mX40;Big080/[[O
0P2d^]h40;:kh080oooo00?o00000?ooo`3oool0;P3oool003X0oooo0ol0000P0?ooo`80`jNn0`32
ZL420<BX_P@0`j_200<0aJZo0<>/``33[<<00P33[<<50<B^a@D0a;361@33//P01@31]<h0`k?;0<>c
b`33/l/0`;K@00@0`[G>00<0_[OB0<6gd?l000000P31]m00102m^=D0_kSC0;nhd`2o^=<30;^jf003
0;fieP2j^mX0^[_J0080^[_J00<0^k_I0?ooool00000J03oool3o`0000d0oooo00<0[ZG?0:nWd02_
Ym000P2_Ym030;2Yd@030;2VcP2aZ<l0/JS?0080/JS?0`2aZ]400`2bZ<d0/j[?0;>Zc`030;>Zc`04
0;>/dP2dZ/h0]:[>0;BZcP<0]:gA00<0]Z_>0;J]d02f[M000P2f[M030;F`d`030;N^d02f/=<0][3C
00<0][3C00<0]K?F0;Nad`2g/M<00P2g/M<20;Jde`80^;?D0`2f]MP00`2h]=D0][KI0;Jff@030;Jf
f@04o`00002f]mX0][OJ0;JgfP80];WL00<0][WK0;BjgP2d^]h00`2d^]h20;:kh080/k_O00<0oooo
o`00003oool0;`3oool003P0oooo0_l0000R0?ooo`@0`jNn00@0`ZW10<BX_P34Z;h0a:Rn0`33Zl82
0<FZ_`<0`jc30P35[<030<B^a@80aZg20`34/<H20<J_a0<0`k;800<0aK760<>cb`33/l/00P33/l/5
0<:ecP80`KO@00?o00000<6gd031]m001@2o^=<01@2k^]P0_KWF0;fieP2m^MH0^[_J00@0^k_I00<0
ooooo`00003oool0I03oool2o`0000l0oooo0`2^YLl40:nWd0040;2Yd@2`Y/h0/:K>0;2VcP@0/JS?
00@0/J[A0;:Xc@2bZ<d0/ZS=0`2cZ/l00`2dZ<`0]:[>0;BZcP030;BZcP040;B]d@2fZlh0]Z_>0;J[
cP@0]Zg@00@0]K3C0;N^d02g[]00]jk@0`2f/=<20;R_d0<0]k7C00<0^K3A0;Rce02h/m@00`2h/m@0
102f]MP0^;CE0;Rde@2h]=D30;Jff@030;Rfeol00000][OJ0080][OJ00@0];WL0;Jif`2f^M/0][WK
0`2d^]h20;Jjg0@0/k_O00<0ooooo`00003oool0;P3oool003D0oooo0ol0000S0?ooo`D0`jNn1@34
Z;h00`33Zl80aJZo0<FZ_`020<FZ_`030<>/``35[<00aJc00080aJc000<0a:k50<J]`P36[L800P36
[L800`34/<H0aZo40<J_a0020<J_a0040<>bb035/LH0aK760<FaaP80`k?;0P35/lT30<:ecP80a;G<
00<0`KO@o`000031]m000P33]lh30;nhd`030<6hd@2m^MH0_KWF0080_KWF1@2k^mT20?ooo`03o`00
003oool0oooo05l0oooo0ol0000?0?ooo`030:bTc`2^YLl0[ZG?0080[ZG?0`2_Ym000`2_Y<d0/:K>
0;2VcP030;2VcP80/JS?00<0/ZG<0;:Xc@2bZ<d00`2bZ<d0102cZ/l0]:S<0;BXc02dZ<`30;BZcP03
0;JXb`2fZlh0]Z_>0080]Z_>0`2f[M000`2gZld0]jk@0;N^d0030;N^d0030;J`d`2h[m00^:o@0080
^:o@00@0]k7C0;V`d@2i/=40^K3A0`2h/m@00`2j/]80^;CE0;Rde@020;Rde@050;Jff@2h]]L0^;KG
0;Rfeol000000P2f]mX00`2h]mP0][WK0;Jif`030;Jif`030;BjgP2f^]`0][[L0080][[L0P2c^ml0
102e^mh0oooo0?ooool0000^0?ooo`00<`3oool2o`0002D0oooo0P33YK/40<>W_P030<BV^`34Z;h0
a:Rn0080a:Rn1@35Z[l50<F/`0D0aZg21@36[l@40<FaaP030<>cb`35/lT0aK?90080aK?900<0`[G>
0<Bec034]L`00P34]L`00ol00000`kO>0<>gcP020<>gcP040;nhd`31^=40`KSA0<6hd@80_KWF0P2o
^M@30;^kf@040;fke`3oool0ooooo`0005l0oooo0_l0000?0?ooo`030:^RcP2/Y<l0[:C?0080[:C?
102^YLl0102_Ym00[jC=0:nTc@2_Y<d30;2VcP030;6SbP2bYL`0/ZG<0080/ZG<0`2bZ<d00`2cYLX0
]:S<0;BXc0030;BXc0040;BZcP2fZ</0]ZS;0;JXb`@0]Z_>00@0]Zg@0;N[c@2gZld0]j_=0`2g[]00
0`2i[Ld0^:o@0;R_d0030;R_d0D0^K3A00@0^;?D0;ZbdP2j/]80^[;B0P2h]=D00`2j/m<0^;KG0;Rf
e`020;Rfe`03o`00002f]mX0^;OH0080^;OH0`2f^M/00`2h^=X0][[L0;Jjg0020;Jjg0030;Njf`2e
^mh0]K_N0080]K_N00<0ooooo`00003oool0;@3oool00300oooo0ol0000V0?ooo`<0`jFk0`33Ykh2
0<BV^`<0a:Rn0P35Z;`30<FZ_`80aZVm1035[<040<J]`P030<N]_`36[l@0aZo40080aZo400<0ajo2
0<FaaP35/LH00P35/LH50<Fcb@D0a;G<00Go00000<>gcP33]lh0`kO>0<Fgc@040<6hd@030;fieP2o
^M@0_kWD0080_kWD00@0^k_I0;fke`2m^mL0_K_G0P3oool00ol00000oooo0?ooo`1I0?ooo`?o0000
403oool30:^RcP@0[:C?0P2^YLl00`2^X/`0[jC=0:nTc@030:nTc@040;2VcP2aXlX0/J?:0;6SbP@0
/ZG<00@0/ZS=0;>UbP2cYLX0/jG:0`2dZ<`00`2eYLT0]ZS;0;JXb`020;JXb`<0]Z_>00<0^:W:0;N[
c@2gZld00`2gZld0102g[]00^Jg=0;V]c@2i[Ld30;R_d080^Zk>0`2i/=400`2k[lh0^[;B0;ZbdP02
0;ZbdP040;Rde@2j/m<0^[?C0;Zcd`<0^;KG00?o00000;Zee02h]mP00`2h]mP01@2f^M/0^;SJ0;Rh
fP2h^=X0][[L00@0]k[K0P2e^mh0102f^md0oooo0?ooool0000]0?ooo`00;@3oool3o`0002P0oooo
1@33YK/00`33Ykh0a:Jk0<BV^`020<BV^`030<BX_P35Z;`0aJRl0080aJRl00@0aJZo0<JY_@36ZKd0
aZVm0`35[<020<N[_P80aZg20`37[Kl20<J_a0<0ajo20P35/LH20<Naa0<0aK?90P37/lH30<Bec004
0<JebOl00000`kO>0<>gcP<0aKO=0P31^=420<>hd0<0_kWD00D0`K[C0;fke`2m^mL0_K_G0;nkeP02
0?ooo`03o`00003oool0oooo05H0oooo0ol0000A0?ooo`030:VQc`2[X/h0Zj;>0080Zj;>0`2/Y<l0
0`2/XL/0[Z;<0:jRc0020:jRc0<0[jC=00<0/:790;6SbP2aXlX00P2aXlX30;:Uc0030;>Sb02cYLX0
/jG:00<0/jG:00@0]:S<0;FUb@2eYLT0]JG9102fZ</0102fZlh0^:W:0;RYbP2hZLX30;N[c@030;VZ
bP2i[Ld0^Jg=00<0^Jg=00D0^:o@0;Z^cP2j[/h0^Zk>0;V`d@040;^_cP80^[;B00<0_;7?0;Zcd`2j
/m<00`2j/m<00`2h]]L0^[GDo`0000020;Zee080^;OH00D0^[OF0;RhfP2h^=X0^;SJ0;Zhf0050;Nj
f`060;FkgP2f^md0][_M0;Jkg@3ooooo0000;@3oool002/0oooo0_l0000Z0?ooo`030<:S^@33YK/0
`jFk0080`jFk00<0a:Bi0<BV^`34Y[/00`34Y[/50<FX_0D0aZVm00D0aJc00<N[_P37Zkh0aj^n0<J]
`P040<N]_`030<J_a037[l80ajo20080ajo200<0aK760<Naa037/L@00P37/L@00`35/lT0ak?60<Nc
aP020<NcaP050<Bec036]LT0a[G90<JebOl000001035]ld00`31^=40`kS@0<>hd0020<>hd0050;ni
e031^]<0`K[C0<6jd`2m^mL00`2o^mH20?ooo`03o`00003oool0oooo05<0oooo0_l0000A0?ooo`03
0:NPc`2YXLl0ZJ7?0080ZJ7?102[X/h0102/Y<l0[:7;0:bQb`2/XL/40:jRc0040:nTc@2`XLT0/:79
0;2Qb@@0/J?:00@0/ZG<0;>Sb02cXlP0/j?8102cYLX40;FUb@<0]ZS;00<0]jK80;RYbP2hZLX00`2h
ZLX0102gZld0^J[:0;VZbP2iZ/X30;V]c@030;Z[bP2j[/h0^Zk>0080^Zk>1@2k[lh0102j/]80_;7?
0;bac`2l/Ll30;Zcd`060;bcd@2j]M@0^[GD0;Zee?l00000_;GC102j]mH0102h^=X0^[SH0;Zhf02j
^=P30;Njf`030;VjfP2f^md0][_M00<0][_M00<0ooooo`00003oool0:`3oool002P0oooo0ol0000[
0?ooo`<0`Z>i0P33YK/20<BT^@@0a:Jk00<0aJJi0<FX_035Z;`00P35Z;`00`37YkX0aZVm0<JY_@02
0<JY_@030<RY^`37Zkh0aj^n0080aj^n1@37[Kl50<N_`PD0ak741@37/lH40<Jeb@03o`000035]ld0
aKO=0080aKO=1@33^=040<6jd`D0_k_F0P3oool00ol00000oooo0?ooo`1?0?ooo`?o00004P3oool3
0:NPc`@0ZJ7?0P2[X/h00`2[Wl/0[:7;0:bQb`020:bQb`<0[Z;<00<0[Yo80;2Qb@2`XLT00P2`XLT3
0;6SbP030;6Qa`2cXlP0/j?80080/j?80`2cYLX20;BSa`@0]JG900@0]ZS;0;NVb02gY/P0]jK80`2h
ZLX00`2iYlL0^J[:0;VZbP020;VZbP030;V]c@2jZlX0^Z_:0080^Z_:0P2j[/h20;b]b`<0^jo>00<0
_Jo<0;bac`2l/Ll00`2l/Ll01`2j/m<0_;?A0;bcd@2l/m40^[GD0;bedol000000P2l]M<20;ZgeP03
0;bge@2j^=P0^[SH00<0^[SH00@0]k[K0;VjfP2i^]X0^K[J0P2f^md20;Rkg080oooo00?o00000?oo
o`3oool0:@3oool002H0oooo0_l0000]0?ooo`@0`Z>i00<0`jFk0<BT^@34Y;T00P34Y;T20<BV^`<0
aJJi0P35Z;`30<NW^P80aZVm0`38ZK/20<N[_P80b:^l0`37[Kl20<V]_@<0ajo20P39[kl30<Naa080
bK720`37/lH20<Vca@80a[G900<0b;G7o`000035]ld00P35]ld20<Ngb`<0`kS@0P35^Lh20<6jd`80
`k[A0`2o^mH01031^m@0oooo0?ooool0001?0?ooo`;o00004`3oool00`2UX=00Yj3?0:NPc`020:NP
c`<0ZJ7?00<0Z9k<0:^Ob`2[Wl/00P2[Wl/40:bQb`040:jRc02^WlP0[Yo80:jOb0@0/:7900@0/J?:
0;6Qa`2aXLL0/J77102cXlP0102cYLX0]:?70;BSa`2dXlL30;FUb@030;NTa@2gY/P0]jK800<0]jK8
00@0^:W:0;VWa`2iYlL0^JO70P2iZ/X00`2kZLL0^Z_:0;Z[bP030;Z[bP030;Z^cP2l[L/0_:g;0080
_:g;00@0^jo>0;f_c02m[l`0_Jo<0`2l/Ll00`2n/Ld0_;?A0;bcd@020;bcd@80_;GC00Co00000;be
d`2l]M<0^[OF0`2l]mD30;Zhf0050;^ie`2i^]X0^K[J0;VjfP2j^]T01@2h^m`00`3ooooo00000?oo
o`0Z0?ooo`008`3oool3o`0002h0oooo1@32XkT50<BT^@030<BV^`35Y[T0aJJi0080aJJi00<0aJRl
0<NW^P37YkX00P37YkX00`36ZKd0b:Vk0<RY^`020<RY^`030<N[_P38Zk`0b:^l0080b:^l00<0ajfo
0<V]_@39[Kd00P39[Kd00`37[l80bJno0<V__`020<V__`030<Naa039/L80bK720080bK7200D0ak?6
0<Vca@39/lD0bK?50<Jeb@020<Rea`03o`000038]LL0aKO=00@0akO;00D0`kS@0<FicP35^Lh0aKW>
0<6jd`040<>jd@040;nkeP31^m@0`K_D0<6ke080oooo00?o00000?ooo`3oool0B@3oool3o`000180
oooo00<0XioA0:FPd02UX=000P2UX=040:NPc`040:VQc`2XW/`0Z9k<0:RNc0@0Zio;0P2/XL/00`2/
W/P0[Yo80:jOb0020:jOb0<0/:7900<0/9k60;6Qa`2aXLL00P2aXLL30;>Sb0030;>Qa@2dXlL0]:?7
00<0]:?700@0]JG90;NTa@2gY<D0]jC50`2gY/P00`2iYLD0^JO70;VWa`020;VWa`040;VZbP2kZLL0
^jW70;^Ya`<0^Z_:00<0_:[70;b]b`2l[L/00`2l[L/50;f_c0040;bac`2n/Ld0_[7=0;jac@80_;?A
0P2n/ll0102l]M?o00000;bed`2n]M450;bge@050;Zhf02k^ML0^kWG0;^ie`2i^]X00`2j^]T30;Rk
g0040;Vlf`3oool0ooooo`0002X0oooo000Q0?ooo`;o0000<03oool20<6Q^@@0`Z>i00<0`j:h0<BT
^@34Y;T00P34Y;T50<FV^@D0ajNj1@38ZK/50<R[_0D0bJfm1@39[kl40<Va`P030<^a`039/lD0bK?5
0080bK?50`38]LL00ol00000b;G70<Ngb`030<Ngb`040<Vgb@35^Lh0aKW>0<FicP80akW=0`33^]40
1@35^]00`K_D0<6ke031^m@0`kcC00<0oooo00?o00000?ooo`3oool0AP3oool2o`000180oooo00<0
XIoC0:>Od@2SWm400P2SWm440:FPd080Yj3?00<0YYg<0:RNc02XW/`00P2XW/`30:^Ob`030:ZLb02/
W/P0[9k80080[9k8102^WlP0102`XLT0/9k60;2NaP2`W/H40;6Qa`040;>Sb02cXLD0/j750;>Qa@<0
]:?700<0]Z740;NTa@2gY<D00P2gY<D0102gY/P0^JG50;VUa@2iYLD40;VWa`D0^jW700@0^Z_:0;bZ
a`2lZ/L0_:[70`2l[L/20;j/b0@0_Jo<102n/Ld00`2l/m40_[??0;jcc`020;jcc`04o`00002n]M40
_[GA0;jed@<0_;OE00D0_[OC0;^ie`2k^ML0^kWG0;fieP050;Zjf@040;Rkg02i_=/0^KcK0;Vlf`80
oooo00?o00000?ooo`3oool09`3oool001h0oooo0ol0000a0?ooo`<0`J6i0`32XkT20<>R^0@0a:Bi
00<0aJBh0<FV^@35Y[T00P35Y[T00`37YKP0ajNj0<NW^P020<NW^P030<RW^038ZK/0b:Vk0080b:Vk
00<0bJVi0<R[_038Zk`00P38Zk`00`3:ZkX0bJfm0<V]_@020<V]_@030<^]_039[kl0bJno0080bJno
00<0bjnn0<Va`P39/L800`3;/L020<Vca@80bk?30P38]LL00ol00000b[G60<ZeaP020<Ngb`<0bKO9
00<0aKW>0<Nic@37^Ld00P37^Ld01@33^]40aK[@0<Fjd035^]00`K_D00<0`kcC0P3oool00ol00000
oooo0?ooo`130?ooo`?o00004@3oool00`2OX=@0XIoC0:6Od`020:6Od`@0XioA0P2UX=000`2TW<d0
YYg<0:JMc0020:JMc0@0Z9k<00@0Zio;0:ZLb02ZW<P0ZYc80`2/W/P30:jOb0030:jMa@2`W/H0/9k6
0080/9k60`2aXLL00`2bW/@0/j750;>Qa@020;>Qa@040;BSa`2fXL@0]Z740;JQa0@0]jC51@2iYLD2
0;VWa`80^jK4102kZLL50;bZa`040;b]b`2n[<P0_Zc80;j/b0<0_Jo<0P2o[/T20;jac@030<2ab`2n
/ll0_[??00<0_[??00?o00000;jed@2n]M400P2n]M401@2l]mD0_[OC0;jgd`2n]m<0^kWG00<0_KWF
0`2j^]T0102l^mP0^KcK0;Vlf`2i_=/20;^lf`030?ooool00000oooo02P0oooo000L0?ooo`;o0000
<`3oool50<6Q^@040<:S^@33X[P0`j:h0<>R^0<0a:Bi0P35Y;P30<FV^@80ajFh0`37YkX20<RW^0<0
b:Vk0P39ZKT30<R[_080bZ^j0`39[Kd20<^]_0<0bJno0P3;[kh00`39/L80bk700<^a`0020<^a`003
0<Vca@3;/l<0bk?30080bk?300D0b;G7o`00003:]LH0b[G60<Ngb`040<Vgb@D0akW=1035^]050<>l
d`80oooo00?o00000?ooo`3oool0@03oool2o`000140oooo00<0WJ3G09nPe02OX=@00P2OX=@40:6O
d`80XioA00<0XYc?0:BLc@2TW<d00P2TW<d40:JMc080Z9k<00<0Z9_90:ZLb02ZW<P00P2ZW<P40:bN
b0030:jOb02^WLD0[Yg500D0/9k600@0/J770;:Na02bW/@0/Yk40P2cXLD00`2dWl80]Z740;JQa003
0;JQa080]jC50P2hX/<40;VUa@040;VWa`2kY/@0^jK40;^Va0<0^jW70P2lZ<@30;bZa`030;jZa@2n
[<P0_Zc800<0_Zc800D0_Jo<0;n^b@2o[/T0_jk90;jac@030<2ab`<0_[??00<0`;?=o`00002n]M40
0P2n]M401@30]/l0_[OC0;jgd`2n]m<0`;SB00D0_KWF00D0^[[I0;bkf02l^mP0_;_H0;Vlf`040;^l
f`030?ooool00000oooo02L0oooo000I0?ooo`?o0000=03oool20;nP^@@0`J6i1@33X[P00`34Y;T0
aJBh0<FT^0020<FT^0030<FV^@37YKP0ajFh0080ajFh00<0ajNj0<RW^038YkP00P38YkP00`38ZK/0
bJVi0<VY^@020<VY^@030<R[_03:ZkX0bZ^j0080bZ^j00<0bJfm0<^]_03;[K`00P3;[K`01039[kl0
bjnn0<^__P3;[kh50<^a`0D0bk?300D0b[G6o`00003:]LH0b[G60<bfa@030<Vgb@80bkS80`37^Ld2
0<Vjc080aK[@0P37^ll30<>ld`050<Bld`3oool0oooo0?ooool00000?P3oool3o`000100oooo00<0
Vj7I09fPe`2MX=L00P2MX=L409nPe080XIoC00<0WicA0::Lc`2RW<l00P2RW<l30:BLc@<0YYg<00@0
YI[:0:RKb@2XVlT0Z9_91@2ZW<P20:bNb0030:bKa@2^WLD0[Yg50080[Yg50`2`W/H00`2`W<<0/Yk4
0;:Na0020;:Na0040;>Qa@2dWl80]9o20;BO`P@0]Z7400@0]jC50;RR``2hX/<0^:;30`2iYLD00`2j
Xl80^jK40;^Va0030;^Va0030;^Ya`2lZ<@0_:S40080_:S400@0_:[70;jZa@2nZ/D0_Z[50`2n[<P0
0`30[<H0_jk90;n^b@020;n^b@D0`;7;00H0_[??0<2cc@30/lgo00000<2cc@2n]M430<2fc`040;jg
d`30^=80`;SB0<2hdP<0_KWF00@0_k[E0;bkf02l^mP0_;_H0P2n_=L30;^lf`040;bmfP3oool0oooo
o`0002L0oooo000F0?ooo`?o0000=P3oool30;nP^@@0`J6i00<0`Z6h0<>R^033X[P00P33X[P50<FT
^0D0ajFh1@38YkP50<VY^@D0bZ^j1@3;[K`40<^__P030<f`_03;/L00bk700080bk7000@0cK:o0<^c
``3;/l<0bk?30P3=]<800ol00000b[G60<bfa@020<bfa@030<Vgb@3;^<P0bkS80080bkS800D0akW=
0<Vjc039^/`0bK[<0<Fjd0040<Nkc`040<>ld`34_=<0a;cC0<Bld`80oooo00?o00000?ooo`3oool0
>@3oool3o`0000h0oooo00@0VJCM09ZSf`2JXm/0VZ?K0`2KXMT409fPe`80Wj3D00<0WIcC09nLd@2O
W=400P2OW=430::Lc`@0Y9c=00<0YYg<0:FJbP2UV/X0102XVlT30:ZLb0030:ZIaP2/VlD0[9_50080
[9_50`2^WLD0102`W/H0/9c30;2L``2`W<<40;:Na0@0]9o20`2fXL@00`2gWl40^:;30;RR``030;RR
``040;VUa@2jXl80^Z?20;ZS`P<0^jK400<0_:G20;bXa02lZ<@00`2lZ<@40;jZa@030;j/b030[<H0
`:c60080`:c60P2o[/T20<6^a`<0`;7;00H0`[790<2cc@30/ld0`;?=o`000032]<`40<2fc`D0`;SB
00D0_KWF0;nje@2o^]D0_k[E0;bkf0040;jle`060;^lf`2l_MX0_;gJ0;bmfP3ooooo00009`3oool0
01@0oooo0_l0000h0?ooo`@0_j2i0`31XKT20<:Q^0@0`j:h00<0a::g0<FT^035Y;P00P35Y;P00`36
Y;L0ajFh0<NU^0020<NU^0030<RV]`38YkP0b:Nh0080b:Nh00<0bJNg0<VY^@39ZKT00P39ZKT00`3;
ZKP0bZ^j0<Z[^P020<Z[^P030<b/^@3;[K`0bjfl0080bjfl00<0cJjj0<^__P3;[kh00P3=/;`30<^a
`0<0cK:o00D0bk?30<fd`P3=]<80cKC2o`0000040<bfa@@0bkS800<0cKW70<Vjc039^/`00P39^/`4
0<Nkc`050<RlcP34_=<0a;cC0<Bld`36_M800`3oool00ol00000oooo0?ooo`0f0?ooo`;o00003P3o
ool00`2HY]l0VJCM09VTg@0209VTg@<0VZ?K0`2KXMT209fPe`0309ZMe@2MW=<0WIcC0080WIcC0`2O
W=440::Lc`80Y9c=00<0XiW;0:FJbP2UV/X00P2UV/X30:RKb@040:ZLb02ZVLH0ZYW60:ZIaP@0[9_5
0P2^WLD00`2^V/<0/9c30;2L``030;2L``80/Yk40P2cW<440;BO`P040;JQa02gWl40]io10;NO`@@0
^:;31@2jXl80102kY/@0_:G20;bU`P2lYL830;bXa0030;jW`P2nZ/D0_Z[50080_Z[51@30[<H00`2o
[/T0`Jk70<6^a`020<6^a`070<2ab`32/LT0`[790<:ab@30/ld0`[C<o`0000020<:dc080`;K?0P32
]/h30<2hdP040<:id@2o^]D0_k[E0;nje@80`K_D0`2n_=L00`30_ML0_;gJ0;bmfP020;bmfP80oooo
00?o00000?ooo`3oool0903oool00140oooo0ol0000i0?ooo`80_9jj102oX;T01031XKT0`Z6h0<:Q
^032XKP30<>R^080a::g0`35Y;P20<JT]`<0ajFh0P38Y[L30<RW^080bJNg0`39ZKT20<^Y^0<0bZ^j
0P3<[;T30<^]_080cJjj00<0bjnn0<f`_03=/;`00P3=/;`00`3;/L00cK:o0<fb_`020<fb_`<0cKC2
0_l000040<bfa@030<jga03;^<P0bkS800<0cKW70P39^/`20<^kb`80ak_?0`38_<h01034_=<0a[gB
0<JmdP36_M830?ooo`03o`00003oool0oooo0380oooo0ol0000:0?ooo`0309R[i02HZ>80V:SR0080
V:SR0`2HY]l409VTg@<0VZ?K00<0Vj7I09RNf02JWMD00`2JWMD309fLd`@0WicA0P2RW<l00`2PVLd0
XiW;0:>Ib`020:>Ib`<0YI[:0P2XVlT00`2WV<H0ZYW60:ZIaP030:ZIaP80[9_500<0[9S30:jJ``2^
V/<00P2^V/<40;2L``040;:Na02cW<40/ic10;>L`@<0]9o200<0]Ifo0;NO`@2gWl400P2gWl430;RR
``80^J70102jXl850;bU`P040;bXa02nYl80_ZO20;jW`P80_Z[50P30ZL<30<2/aP030<:/a031[/L0
`Jk700<0`Jk71032/LT00`32]<co0000o`0000020<:dc0030<2fc`32]/h0`[K>0080`[K>00D0`;SB
0<:id@32^M40`[WA0;nje@040<6ke0040;jle`30_ML0`;gG0<2me`80_;gJ00D0_[kJ0?ooo`3oool0
ooooo`00000U0?ooo`00403oool2o`0003X0oooo0`2lW[X40;nP^@D0`Z6h00<0`j:h0<BR]`34X[L0
0P34X[L00`35Y;P0aZBg0<JT]`020<JT]`040<NU^038Y[L0b:Jg0<RV]`80b:Nh1039YkL00`39ZKT0
bjVh0<^Y^0020<^Y^0030<Z[^P3<[;T0c:bi0080c:bi00@0bjfl0<f^^P3=[[X0cJjj1@3=/;`50<fb
_`?o000000<0ckG1o`00003<]/D00P3<]/D20<jga0030<^hb03=^LL0cKW70080cKW700D0bK[<0<^k
b`3;^l/0bk_;0<Nkc`040<RlcP@0a[gB0`3oool00ol00000oooo0?ooo`0a0?ooo`;o00002P3oool2
09R]i@80V:_T102HZ>8309RVg`80VJCM00@0UJ7M09JOfP2FWmX0UYoJ0`2HW]P409ZMe@<0WIcC0P2O
W=400`2MVLl0X9W=0:2Ic@020:2Ic@<0XiW;0P2UV/X00`2TUlL0YiS60:NHaP020:NHaP@0ZYW600@0
[9_50:bH``2/V<<0[9S30`2^V/<30;2L``030;6J`02cW<40/ic100<0/ic100@0]9o20;FM_`2eWKl0
]Ifo102gWl40102hX/<0^J700;VQ`02iXL030;ZS`P80_::o102lYL840;jW`P030;jZa@30ZL<0`:W3
0080`:W300@0`:c60<:/a032[<@0`Zc40`31[/L20<>_aP070<:abOl0003o0000o`000032]<co0000
0<:dc0020<Fdb`<0`[K>00<0aKO=0<:id@32^M400P32^M440<6ke0030<>ld`30_ML0`;gG0080`;gG
00@0_;gJ0;jnfP2n_]X0_[kJ0P3oool00ol00000oooo0?ooo`0S0?ooo`00403oool00ol00000oooo
o`00000h0?ooo`@0_9jj0`2oX;T20;nP^0@0`Z6h1@34X[L50<JT]`D0b:Jg00<0b:Nh0<VW]`39YkL0
0P39YkL50<^Y^0D0c:bi103=[[X00`3>[[T0cK2l0<f`_0020<f`_0030<n`^`3=/[oo000000;o0000
00<0ck>n0<fd`P3?]L400P3?]L400ol00000c;K50<jga0020<jga0D0cKW7103;^l/0103=_<X0b;c>
0<RlcP38_<h20<ZmcP80a[gB0P37_]830?ooo`03o`00003oool0oooo0300oooo00?o00000?ooool0
00000`3oool209^bi`<0VJoV102H[ND209R[i080V:SR00@0U:KR09BSg`2DXml0U:?O102EXMd309JO
fP<0V9kH0P2JWMD0102GVM@0VYWA09ZId@2JVM4409fIc`<0X9W=0`2SVL/40:BGa`<0YiS60`2ZVLH0
0`2YUl<0[9S30:bH``020:bH``@0[Y[300@0/9c30;6J`02aV/00/I[0102cW<440;FM_`<0]io100<0
^9jn0;VQ`02iXL000`2iXL00102jXl80_::o0;bR_`2lX[l30;bU`P030;jU_`2nYl80_ZO20080_ZO2
1@30ZL<50<:/a0030<6^a`33[lKo000000;o00001034//P00`32]<co00000<Fdb`020<Fdb`040<:f
cP35]ld0aKO=0<Fgc@80`[WA0P34^]020<6ke0<0`kcC0P30_ML01031_]L0_[kJ0;jnfP2n_]X20;no
fP80oooo00?o00000?ooo`3oool08P3oool00100oooo00Co00000?ooo`3ooooo00000P2:^?@207jd
mP<0KZkg0`1IYOL00`11V?<0oooo0?ooo`0X0?ooo`030;VM_02lW[X0_9jj00@0_9jj00@0_j2i0;nP
^02oX;P0_j2h0`32XKP20<:Q]`@0a::g00<0aJ>f0<JT]`36Y;L00P36Y;L00`37Y;H0b:Jg0<RV]`02
0<RV]`D0bJNg00<0bjRf0<^Y^03;ZKP00P3;ZKP40<b/^@80cZbh0P3=[[X20<j^^@<0cK2l0ol00000
103=/[l0ck>n0<nc_P3?/kh50<ne`@05o`00003>]l@0c[O40<jga03@^<<00`3=^LL20<jjaP80bk_;
0`3=_<X01@38_<h0b[g>0<ZmcP3:_Lh0a[gB00@0akkB0P3oool00ol00000oooo0?ooo`0`0?ooo`04
o`00003oool0ooooo`000080W;CX0`2K/^L309V_iP80V:gU00@0UJ_V09BXi02DZ>@0U:ST0`2DY^83
09BSg`@0UJ7M0P2FWmX209RNf00309BKe`2GVM@0UiWD0080UiWD0`2JVM4309fIc`@0X9W=00<0XiW;
0:6Fb@2QU/T00`2TUlL40:NHaP040:ZIaP2YUl<0ZIO30:VG``<0[9S30`2^V/<00`2^V<00/I[00;6J
`0020;6J`0<0/ic10P2cVkh40;FM_`040;NO`@2hW[h0^9jn0;RN_P@0^J701@2lX[l0102lYL80_ZFo
0;jU_`2nYKl20;jW`P80`:O00`30ZL<20<:Y`@<0`Zc40ol000020<>_aPD0a;;80P35]</00ol00000
aKC;0<Nfb@040<Fgc@050<:id@34^]00a;[@0<Bjd031^m@01033_=<01@30_ML0`KkG0<6ne`31_]L0
_[kJ00@0_koJ00<0ooooo`00003oool08`3oool00100oooo00?o000009>jlP2C^_80102:^?@207jd
mP<0KZkg0`1IYOL01@11V?<0:8[/02R:k00XR^`04W_T02@0oooo0`2iWK`40;bN^P030;bO^P2oX;P0
_j2h00<0_j2h00@0`Z6h0<:Q]`32XKL0`Z6g0`34X[L20<FS]P<0aZBg0P37Y;H40<RV]`040<VV]P39
YkL0bJNg0<VW]`80bjRf0`3;ZKP20<fZ]`80c:bi0`3>[;P0103=[[X0cZji0<j^^@3>[[T3o`0000<0
ck2k103?/kh00`3A];d0ckG10<ne`@020<ne`@030=2f`?l00000c[O400<0d;S300D0cKW70<jjaP3>
^/H0c[[60<^kb`040<flbP@0b[g>00D0c;k>0<NndP37_]80akkB0<W0d@030?ooo`03o`00003oool0
oooo02l0oooo00?o000009jfj@2N]^T0102L]>P00`2K/^L0V;3X09J^i`0309J^i`<0UJ_V0`2DZ>@3
09BVhP<0U:?O0P2EXMd00`2AW]d0TYcJ09:LfP0409BKe`<0UiWD102JVM4309fIc`80X9W=00@0WIK;
0:6Fb@2QU/T0XIK9102TUlL20:NHaP030:JEa02YUl<0ZIO30080ZIO3102/V<<0102^V/<0[YS00:jH
`02^V<040;6J`0040;>L`@2cVkh0/i^n0;>K_P@0]Ifo102hW[h30;VQ`0030;^P_@2lX[l0_::o0080
_::o00<0_J:m0;jU_`2nYKl00P2nYKl00`2nYl80`:O00<2W`0020<2W`0040<2Y``32ZL40`ZW10<:Y
`@?o00000P34[L<20<>_aP80aK340`34//P20<Jca`80aKC;00?o00000<Nfb@37]/T00P35]ld01037
^Ld0a;[@0<Bjd034^]020<Jkd0<0`kcC00@0aKgC0<6ne`31_]L0`KkG0P33_mL30;nofP040<71fP3o
ool0ooooo`0002<0oooo000?0?ooo`03o`00003oool0oooo0080Tk[b0P2:^?@208bhm080OkGf0`1_
[oP305VVm`0503nIl`0XR^`0:8[/02R:k00BNn@00P02K]dP0?ooo`@0^Ifl0`2lW[X20;bO^PD0_j2h
1@32XKL01034X[L0aJ>f0<FS]P35XkH20<JT]`<0ajBf0`38Y[L20<VV]P80bJNg0`3;Z;H20<^Y^0<0
cJZg00<0c:bi0<j/^03>[;P00P3>[;P01@3>[[Wo0000o`000?l00000cZji00D0ck2k00<0dK:k0<nc
_P3?/kh00P3A];d30<ne`@80d;K000?o00000=2h``3@^<<00P3@^<<40<jjaP040=2kaP3=_<X0cKc:
0<flbP80c[g:0P3:_Lh30<bncP040<NndP39`=40bL3A0<W0d@<0oooo00?o00000?ooo`3oool0;@3o
ool00ol00000oooo09jfj@0209jfj@80W;CX0P2J/nT209R`j0@0UZkW0`2EZnH00`2DZ>@0T:KT08nS
hP0208nShP@0T:7O0`2AW]d209:LfP@0U9_G0`2GVM@209ZId@0409NFd02JULh0VYG>09ZEcP@0WIK;
0`2QU/T20:BGa`030:>DaP2VUL@0YYG40080YYG4102YUl<20:bH``030:bF`@2^V<00[YS00080[YS0
0`2aV/000`2aVKh0/i^n0;>K_P020;>K_P<0]Ifo0P2fW;d40;RN_P040;VQ`02kX;d0^j2m0;^P_@80
_::o0P2mX[d40;jU_`D0`:O000H0`ZW1o`000?l0003o00000<:Y`@32[<@30<B]``030<>_aP35/<@0
aK340080aK3400L0a;;80<Jca`36/lL0a[?70<Fdb`37]/Wo00000080akK900D0aKO=0<Nic@37^Ld0
akW=0<Bjd0040<Jkd0050<>ld`35_M<0aKgC0<Fmd`31_]L01033_mL0102o_mX0`L7J0<71fP31`MX2
0?ooo`03o`00003oool0oooo0200oooo000?0?ooo`04o`00003oool0oooo0?ooo`<0U;[a0`2<^?@2
07nemP<0Kjoh0`1IY_L203nIl`808XS[00@01gKP009^g@02K]d006OI7@3oool20;BL`0@0^Ifl00<0
_9jj0;bO^P2lWkX00P2lWkX30;nP^0030<2P^032XKL0`Z6g00<0`Z6g1@35XkH00`36Y;L0ajBf0<NT
]P020<NT]P030<RV]`39Y[H0bJJf0080bJJf00<0bJNg0<^X]P3;Z;H00P3;Z;H0103;ZKP0cJZg0<fZ
]`3=Z[L30<j/^0?o0000103>[[T0103@/;T0ck2k0<n`^`3?/;/20=6b^`030<nc_P3A];d0dKBm0080
dKBm00H0ckG10=2f`03@]/00d;K00=2h`ol000030=2h``030=6j``3>^/H0c[[600<0d;_600D0cKc:
0<jmbP3>_LX0c[g:0<ZmcP040<bncP@0bL3A0`3oool00ol00000oooo0?ooo`0]0?ooo`03o`00003o
ool0W;GY00<0W;GY102J/nT209R`j080UZkW00<0TjcX096YiP2AZNH00P2AZNH2092Vi0<0Sj?R102@
XMl2096Ng@<0TYcJ0P2DVmL0102@UmH0TiKC09>Fd`2CU]<309NFd0@0VYG>0`2MU//20:6Fb@0309nC
a`2SU<H0XiC60080XiC60`2VUL@30:VG``030:VE`@2/U/40[9K10080[9K1102^V<00102aV/00/IVn
0;6I_P2aVKh40;>K_P040;FM_`2fW;d0]Ybm0;JL_@<0^9jn00<0^Ifl0;^P_@2kX;d00P2kX;d00`2l
X[l0_J:m0;fR_@020;fR_@80_ZFo0P30Y;h20<2W`0?o00001032ZL440<B]``D0aK341036/lL30<Nf
b@03o`000037]/T0akW=00<0akW=1@36^m030<Fmd`80a[oC0`33_mL01@34`ML0`L7J0<71fP31`MX0
`/;J0080oooo00?o00000?ooo`3oool0803oool000l0oooo00?o00000?ooo`3oool00P3oool00`2D
^_40U[_a09Jkl@0308jil`@0P[Kf0P1a/?P305^Wn00403nJl`0OQnX07hOZ00Mfh08006KE00<006OI
0?ooo`3oool06@3oool30;BL`0@0^Ifl1@2lWkX20;nP^0<0`:2h0`32XKL00`33X[L0aJ>f0<FS]P03
0<FS]PD0ajBf1@39Y[H50<^X]P@0cJZg0ol000000`3>[;P0cjfg0<n]]`030<j^^@<0d;2i00@0ck2k
0=6b^`3A/[/0dK:k1@3A];d40=2f`0040=:h_`3@^<?o00000=2h``80dK[300<0c[[60=2kaP3@^lH0
0P3@^lH40<jmbP040=2obP3<_/h0c;k>0<bncP80cL3>0P39`=420<[1d@<0oooo00?o00000?ooo`3o
ool0;03oool00ol00000oooo0?ooo`0409bej@80V[?Y00@0Uk;Y09F_j@2E[nT0UJoY0`2C[>P4096Y
iP80T:KT0`2?Xn82092Qg`0308^Mh02<Vmd0S9_M00<0SYWJ102@UmH309>Fd`<0UiK@0`2JULh209fF
b`0309^BbP2OTlL0Wi?70080Wi?70`2SU<H40:JEa0040:VG``2YUL40ZIG10:VE`@<0[9K10`2^V<00
0`2_Ukh0/IVn0;6I_P020;6I_P<0/i^n00<0]9Zl0;JL_@2fW;d00`2fW;d00`2hW[h0^Ifl0;VM_004
0;^P_@D0_J:m00<0_ZFo0<2T_P30Y;h00ol000000`30Yl00`ZNn0<:W_P030<:Y`@80a:Zo0P34[L<2
0<J]`@<0aK340P38/L<20<Jca`80bKC60`37]/T01?l00000bKO90<Nic@37^Ld20<Vjc0<0a[_@0P38
_M000`35_M<0a[oC0<Jod`020<Jod`050<>oe`34`ML0a<7G0<C1e`31`MX00`32`]X20?ooo`03o`00
003oool0oooo01l0oooo000?0?ooo`03o`00003oool0oooo00<0oooo0`2F^o4308jil`80P[Kf0P24
]oH207Bbn0<0GZWh00@0@Icd01n7jP0OQnX007;L0P00I]D00`00Flh00VOJ0?ooo`0F0?ooo`030:fK
a@2dW<00]9c00080]9c00`2iWK`20;RN_@@0_9nj00<0_j2h0<2P^030X;P00P30X;P20<:Q]`<0`j:g
0`35XkH00`36Y;H0ajBf0<NT]P020<NT]P030<RU]P39Y[H0bJJf0080bJJf00<0bjNe0<^X]P3;Z;H0
0P3;Z;H00`3=ZKH0cJZgo`000002o`0000030<j[]P3>[;P0cZbh00@0cjfg00<0cZji0=2`^@3@/;T0
0P3@/;T40=6b^`030=:c^P3A];d0dKBm0080dKBm00<0dkJm0=2f`03@]/000`3B^;l0103@^<?o0000
0=6j``3A^/<50=2kaP030=:maP3>_LX0c[g:00<0d;o:00D0c;k>0<g0cP3=`<h0cL3>0<W0d@030<[1
d@050<c3dP3oool0oooo0?ooool00000;@3oool01?l00000oooo0?ooo`3oool209bej@80V[CZ0`2G
/^T309F_j@<0TjcX0P2AZNH00`2<YnL0RjCU08^Ti@0408ZPh`<0RigP0P2<Vmd308jIfP<0T9OF102C
U]<209NFd080VYG>00<0Ui;=09^BbP2KT/X00P2KT/X309nCa`@0XiC60P2VUL@00`2UTl<0ZIG10:VE
`@020:VE`@@0[9K100@0[YS00:nG_P2_Ukh0[iNn102aVKh00`2cVkh0]9Zl0;BJ_0040;JL_@030;NK
^`2iWK`0^Ifl0080^Ifl0P2kX;d20;bP_0@0_J:m0ol000020<2T_P030<2W`032Ykh0`ZNn0080`ZNn
00D0`ZW10<BZ_`34Z[l0a:Zo0<B]``040<J]`@050<F`a038/L<0b;730<Ra``36/lL01039]<H01@37
]/T0bKO90<VgbOl00000akW=00@0bK[<00@0a[_@0<Rmd038_M00b;g@1@36_m<30<C1e`040<K3e`32
`]X0`/;J0<;2fP80`lCK0P3oool00ol00000oooo0?ooo`0N0?ooo`003`3oool00ol00000oooo0?oo
o`040?ooo`0309Jkl@2H^o00V;_`00@0T;[c0`24]oH207Bbn0<0GZWh0P11W?@01P0NR>X007;L001N
c@00G/d005_>009WfP804fkO4`3oool30:fKa@@0]9c000@0^Ifl0;RN_@2hW[d0^9jm102lWkX50<2P
^0030<:Q]`33X[L0`j:g0080`j:g0P35XkH30<JT]P80ajBf0`38YKH20<VV]P<0bjNe0P3;Z;H0103=
ZKKo0000o`00003=Z[L40<j[]P030<j/^03?[KL0cjfg0080cjfg1@3@/;T30=6b^`80d[>j0`3A];d2
0=>f_@030=2f`03B^;l0d[Ro0080d[Ro00D0dK[3o`00003A^/<0dK[30=>l``030=2kaP80d[g600<0
c[g:0=2obP3@_lX00P3@_lX30<g0cP040<o2cP3:`M40b/7A0<[1d@<0c<?B0P3oool00ol00000oooo
0?ooo`0[0?ooo`03o`00003oool0oooo0080oooo102J]>X309Nbj@0309F_j@2A[^X0TJkZ00<0Sj_X
0`2<YnL208^Ti@@0RZ3S0`2;WN0208bKg@<0SYWJ0`2@UmH209>Fd`0308nCd`2CT]00Ti;@00@0Ui;=
0`2KT/X309nCa`<0XiC600<0XI;40:FC``2UTl<00P2UTl<30:VE`@<0[9K100<0[9Fo0:nG_P2_Ukh0
0P2_Ukh30;6I_P030;:H_02dV[`0]9Zl0080]9Zl0P2fW;d20;NK^`@0^Ifl00@0^j2m0;bP_02lX;`0
_:2l0P2mX[d2o`0000030;nR_030Y;h0`:Bn0080`:Bn1@32Ykh40<BZ_`D0aZg11038/L<50<VdaP<0
bKO900?o00000<bib@39^/`00P39^/`0103;_<`0b;g@0<Rmd038_M020<Zod0<0a[oC0P38`M<01@34
`ML0a/?G0<K3e`36`mL0`/;J00@0`lCK00<0ooooo`00003oool07`3oool000l0oooo00?o00000?oo
o`3oool01@3oool309Rkl080T;[c0P2B^_8308NhmP80N;Ch0`1S[?T204FOm@8088_[0P00G/d01000
Cl8005S=01=^g`0CK]l202mii0h0oooo00<0Y9[;0:fKa@2]VlD00P2]VlD30;BL`0030;>M`P2hW[d0
^9jm0080^9jm0`2lWkX20;fO^`@0`:2h1@33X[L00`35XkH0aZBf0<JT]P020<JT]P030<NT]P38YKH0
b:Ff0080b:Ff00<0bJJf0<^W]@3;YkD00P3;YkD3o`000080cJVf00<0cJZg0<j[]P3>ZkH00P3>ZkH5
0<n]]`040=6_]`3@/;T0d;2i0=2`^@80d[6i00<0dK:k0=:c^P3B/kX00P3B/kX0103A];d0dkJm0=>f
_@3C][d50=:h_`030=Bj`03A^/?o000000<0dkc300D0d;_60=:maP3B_LH0d[g60=>oa`030=2obP80
dL7:00D0cL3>0<o2cP3?`/h0cl;>0<[1d@040<c3dP<0oooo00?o00000?ooo`3oool0:P3oool00ol0
0000oooo0?ooo`030?ooo`80V[CZ0P2G/n/309Baj`<0TJkZ0`2?ZnP308bWi`80RjCU0P2:X><01024
WN<0Q9[Q08BJh@24V^4208JHg@<0R9GJ0`2;U=H308nCd`<0Ti;@0`2GT/d409^BbP<0Wi?700@0XiC6
0:6Ba02QT/@0XI;40`2UTl<40:VE`@040:bF`@2/UKl0[9Fo0:bE_`@0[iNn00<0/IVn0;:H_02bV;`0
102dV[`00`2fW;d0]i^k0;NK^`020;NK^`<0^Ifl0`2lX;`3o`0000<0_j:l0`30Y;h20<:U_0<0`ZNn
00<0a:Rm0<BZ_`34Z[l00P34Z[l00`37Zkh0aZg10<J]`@020<J]`@030<V_`038/L<0b;730080b[;3
0`39]<H20<^fa@80bKO900@0c;W9o`00003<^LT0bK[<0`3;_<`00`38_M00b[o@0<Zod0020<Zod004
0<Jod`38`M<0b<7C0<S1d`<0a/?G0P37aMP30<?4f`040<C5f`3oool0ooooo`0001l0oooo000>0?oo
o`03o`00003oool0oooo00L0oooo00<0V;_`09Vll02I_?00102B^_8308NhmP80N;Ch0`1S[?T204FO
m@<088_[00<005W7001?`P00F<d00P00GM<0100_NN@0ChCU04n4i@1?Q>D80?ooo`0309NHdP2TV//0
Y9[;0080Y9[;102]VlD0102dW<00/ig20;>M`P2cWL840;RN_@040;bO^P2mWk/0_Ink0;fO^`<0`:2h
0P31XKT40<>R]`D0aZBf1@38YKH20<^W]@?o00001@3=ZKH50<j[]P040=2]]P3?[KL0cjfg0<n]]`80
dJng0P3@/;T30=:a^@030=6b^`3B/kX0d[>j0080d[>j103C][d0103D^;d0d[Ro0=:h_`3B^;l20=Bj
`0030=6j``3C_<?o00000080dkc30`3B_LH30=>oa`040=2obP3A`LX0dL7:0=71bP@0cl;>00@0d<C?
0<c3dP3<`m80c<?B0P3<aM<30?ooo`03o`00003oool0oooo02P0oooo00?o00000?ooo`3oool01@3o
ool409Ncj`<0U;7[00<0TJkZ08f/j`2:ZNT00`2:ZNT208NUj0<0QJ7V0`24WN<308BJh@80QYSM0`28
UMX308^DeP<0Si?C0P2CT]0409NBc@80Vi;:00@0V93909fAaP2MTLH0WI76102QT/@40:FC``80ZIG1
00<0Z9?00:bE_`2/UKl00P2/UKl30:nG_P030:nF_@2bV;`0/YRl0080/YRl0P2dV[`00`2eVK/0]i^k
0;NK^`030;NK^`80^Ifl00@0^ifko`000?l0003o00000P2lX;`50;nR_0030<2T_P32YK`0`ZFl0080
`ZFl00@0`ZNn0<BX_@34Z;d0a:Rm0P34Z[l20<N[_P<0aZg10P39[l000`38/L<0b[;30<Zb``020<Zb
``050<VdaP3;]/D0bkK50<^fa@39]lT00`3<^LT00ol00000bkc<0<^lc0020<^lc0050<foc@3:_m00
b[o@0<Zod03<`M000`38`M<20<[3e0030<K3e`37aMP0alGH0080alGH00@0`lCK0<C5f`34aM/0a<GK
0P3oool00ol00000oooo0?ooo`0L0?ooo`003P3oool00ol00000oooo0?ooo`090?ooo`80VKc`0P2B
^_8209BklP<0RkWe0`1l]OP306R^n@80Bj;g0P0USnd01000M=X005K20015]P00GM<200iZg@80ChCU
0`1]S^4308FDfP@0UiSB0`2TV//30:fKa@030:^La`2cWL80/ig20080/ig20`2hW[d00`2hWkl0_Ink
0;fO^`030;fO^`040<2P^031XKT0`J6i0<6Q^@<0`j:g0P34XkP40<JT]P040<NU]`38YKH0b:Ff0<RU
]P?o00000`3;YkD00`3<ZKH0cJVf0<fY]P020<fY]P@0cZ^f0P3@[KH20<n]]`@0dJng00@0d;2i0=:a
^@3B/KT0d[6i1@3B/kX00`3D][/0dkJm0=>f_@030=Bh_@050=:h_`3D^/00e;[00=Bj`03F_<000P3C
_<<01?l00000eKk30=Fn``3B_LH40=>oa`@0dL7:00<0d/?;0<o2cP3?`/h00`3@a<l0103<`m80c<GC
0<c5d`3<aM<30?ooo`03o`00003oool0oooo02P0oooo00?o00000?ooo`3oool01P3oool209Ncj`80
UK?/0`2A/>/208f/j`@0RZWY0P27YNP308FQiP<0Q9gS0P24V^4308JHg@<0R9GJ0`2;U=H208nCd`<0
Ti;@0P2GT/d00`2CSl`0V93909R@b@0209R@b@<0WI760`2QT/@30:FC``040:BA`@2XTl00Z9?00:RC
`0D0[9Fo00<0[iNn0:nF_@2_U[d0102bV;`0102dV[`0]IVk0;FI^`2eVK/40;NK^`?o000000@0^ifk
0;bP_02lX;`0_:2l0P2nX;X40;nR_0D0`ZFl1034Z;d00`34Z[l0aj^n0<N[_P020<N[_P040<J]`@39
[l00bJo00<V_`0D0b[;3103;]/D01P3>^<D0c;W90<bib@3<^LT0c[c9o`000080bkc<0`3=_ld01@3:
_m00c<7@0<c1d03<`M00b<7C00<0b/?D00D0blKE0<O5f037aMP0alGH0<S7f@030<C5f`040<C7g03o
ool0ooooo`0001h0oooo000>0?ooo`03o`00003oool0oooo00X0oooo0`2K_>l309BklP0308^im@2>
^_@0S[[d00<0PKOg0`1^/OT205:Vn080;IC`00@007CJ001E`000?J`004_20P0>J]d204n4i@<0KHkQ
0`25U=X309NHdP@0Y9[;00@0[I_50:^La`2[W<L0Zic7102cWL80102hW[d0^9no0;RO_`2hWkl40;fO
^`D0`J6i00@0`j:g0<BS^034XkP0a:>h0`36Y;H20<NU]`?o00000P3:YkH30<^W]@80c:Vf0`3=ZKH4
0<j[]P@0d:ff00<0cjfg0=6_]`3A[kL00P3A[kL40=:a^@040=Bc^@3B/kX0d[>j0=:c^P80e;Jk00<0
dkJm0=Bh_@3D^;d00P3D^;d40=Bj`080e[c000@0dkc3o`00003E_/<0eKk31@3C_lL00`3E`/L0dL7:
0=71bP020=;3b`030<o2cP3@a<l0d<C?0080d<C?0`3<aM<00`3=a]@0oooo0?ooo`020?ooo`03o`00
003oool0oooo02L0oooo00?o00000?ooo`3oool01`3oool409Fck0<0TK3[0P2=[>/208ZYj@0308FW
j`21XnT0PJ?Y00<0OYkW0`1mV^@207fGh@<0OYCN0`21T]X308F@e`80RXoC0`2?Sll409>?c0<0V939
0`2MTLH40:6Ba0030:FC``2TTL40Y97100@0Z9?00`2/UKl00`2/Tkd0[iJm0:nF_@020:nF_@<0/YRl
102eVK/0102gVk_o0000o`000?l000050;^M^`040;bP_02nX;X0_Z2j0;jP^P<0_j:l0P31Xk/40<:U
_0@0a:Rm1@37Zkh40<V_`0040<^a`03://<0b[;30<Zb``80cKC20P3;]/D30<jha@050<bib@3>_<T0
c[c9o`00003;_<`0103=_ld30<c1d0040<g4d@3:`m@0b/?D0<[3e0<0blKE00D0alGH0<S7f@38amT0
b<OI0<C5f`030<C7g080oooo00?o00000?ooo`3oool06`3oool000h0oooo00?o00000?ooo`3oool0
2`3oool00`2K_>l0WKc_09flk`0409Nll@80S[[d0`21]oL306jan@80DZKh0`0]U?000`00EL0003f/
001;`P0200iZg@80<W[T0P1]S^4308FDfP@0UiSB0P2TV//00`2OV/l0Zic70:^La`020:^La`@0/ig2
102hWkl30;fO^`80_:6l1031XKT50<BS^0060<JT]_l0003o0000o`000037YKL0b:Ff103:YkH00`3;
YkD0c:Vf0<bY]P020<bY]P030<fY]P3>ZkH0cZ^f00<0cZ^f103@[KH40=6_]`80dk6g0P3B/KT30=Bc
^@040=:c^P3D][/0e;Jk0=Bf^`D0e;Rm00<0e[Zm0=Bj`03D^/000`3F_<020=Fn``03o`00003E_/<0
el7400<0dko70P3E`/L01@3A`LX0d/?;0=;3b`3B`l/0e<K<00<0d<C?0P3Aa]00103<aM<0cLKD0<g6
e03=a]@40?ooo`03o`00003oool0oooo02H0oooo00?o00000?ooo`3oool0203oool209Fck080T[;]
0P2>[nd308V[k0<0QJO[0P21XnT307jNi`<0OI[T0P1mUn4307jDgP<0PI;J0P25T=L308Z?d`<0Sho?
0`2CSl`309R@b@@0WI760P2QT/@00`2OT<<0Y9710:BA`@020:BA`@<0Z9?000@0[9Fo0:bC_@2/Tkd0
[9>m102_U[d20;:H_080/YNk00D0]IVko`000?l0003o00000;NK^`030;VK^P@0^ifk1@2nX;X0102o
X[`0`J>k0<6S^`31Xk/30<:U_080a:Jk0P34Z;d20<NY_0<0aj^n0P39[Kh20<V_`0<0bk7000D0b[;3
0<fd`P3=]<80cKC20<^fa@040<jha@@0c[c900Co00000<foc@3=_ld0cKo=0P3?`/d01@3<`M00cLCA
0<g4d@3=a=40b/?D00@0blKE0`38amT01@38bMX0a<OL0<C7g034am`0a<WN00<0oooo00?o00000?oo
o`3oool06P3oool000h0oooo00?o00000?ooo`3oool0303oool309flk`80Ukca0P2I_?02096kl`@0
QKSf0`1d/oT205ZZn@80=Y[b00<0283Q001H`@00=jh00P00Elh2039ji00405N8i@1gTN00Mi7P07NA
h0@0SYOH0`2OV/l40:^La`<0/ig20P2aW/@40;RO_`040;fO^`2lXK`0_:6l0;bQ_0@0`J6i00<0`J>j
0<BS^034XkP00ol000040<NU]`D0bZNf1@3<ZKH50<j[]PD0d:ff00<0dZng0=6_]`3A[kL00`3C/KL0
0`3B/KT0e;>i0=Bc^@020=Bc^@@0e;Jk00@0e[Rk0=Bh_@3D^;d0e;Rm0P3F^[d00`3D^/00e[c00=Jl
`0020=Jl`0040=Ro`@3E_/<0eKk3o`000080el7400@0dko70=G2a`3E`/L0eL;70`3B`l/30=C6c004
0=34c`3Aa]00dLK@0=76d0<0cLKD00<0c/SE0?ooo`3oool00P3oool00ol00000oooo0?ooo`0V0?oo
o`03o`00003oool0oooo00T0oooo102B/^d208j_k@<0RJ_/0`25Yn/2086Sj@<0OYkW0`1mV^@207fG
h@<0OYCN0P21T]X308F@e`80RXoC102?Sll309>?c0<0V9390P2MTLH0102KS/H0Wi3309n@``2OT<<4
0:BA`@80Z9?000<0Yi:o0:bC_@2/Tkd00`2/Tkd30:nF_@030;:H_02bUk_o000000;o00000`2eVK/4
0;VK^P<0^ifk0P2lW[T40;jP^PD0`J>k00D0`ZFl0<BV^`34Y[/0a:Jk0<BX_@040<NY_0050<N[_P39
[Kh0bJfn0<V]_P39[l00103;/L040<fd`PD0c[S500<0d;_60<jlb@3>_<T00P3@_/T00ol00000cKo=
0<o2c@020<o2c@@0cLCA00@0clOB0<_6e@3;a]D0blKE0P3<b=L01@38amT0b<WJ0<S9fP38bMX0a<OL
00<0a<WN0P3oool00ol00000oooo0?ooo`0J0?ooo`003P3oool00ol00000oooo0?ooo`0=0?ooo`03
09flk`2N_Nh0W[g^00@0VKc`0P2A^o<208FhmP80RK[f0P1j]_T306>^nP80@J3e0P08P>400`00=jh0
05O>001GcP0200iZg@0405N8i@1gTN00Mi7P07NAh0<0SYOH102OV/l40:^La`040;>M`P2aW/@0/Ik4
0;6Na0@0^9no102lXK`30<6Q^@040<6S^_l0003o0000o`000080a:>h00<0aJFi0<NU]`37YKL00P37
YKL00`38YkP0bZNf0<ZW]P020<ZW]P030<^Y]`3<ZKH0c:Vf0080c:Vf1@3>ZkH40=2]]P80dZng00<0
dJng0=>a]`3C/KL00P3C/KL50=Bc^@030=Jf^@3D][/0e;Jk00<0e[Rk00D0e;Rm0=Jj_@3F^[d0e[Zm
0=Rm_P030=Jl`080f;o100<0eKk30=O1a?l000000P3G`L@30=G2a`80e/G900<0d/?;0=C6c03Da/`0
0P3Da/`30=76d080dLWA00@0cLKD0<k8e@3>b=D0c/SE103oool00ol00000oooo0?ooo`0U0?ooo`03
o`00003oool0oooo00X0oooo0P2B/^d208nakP80RZk^0`24Z^d307nUk080NZ7[0`1gW>P207FGiP80
M9?S0`1fT=l307V>f`80QI3G0`2:Sm<208n?c`0408V<d02?SL`0Shg<08n=c0<0UHg90`2KS/H409n@
``<0Y97100@0Z9?00:NB_`2WT[l0Yi:o102/Tkd20:nF_@?o00000P2bUk/30;FI^`80]YVj102iVkX0
102kWK/0_9ji0;bN^@2lW[T30;jP^P030;nQ^@31Xk/0`J>k0080`J>k00<0`jBj0<BV^`34Y[/00P34
Y[/50<NY_0@0bJfn1@3;/L001@3>/l00cKC20<fd`P3=]<80ckO300<0c[S50P3@^lH01@3>_<T0d;k9
0=2nb@3@_/Wo000000<0cl;=0P3AaLh20<g4d@<0clOB00@0blKE0<c8e`3<b=L0c<SG0`38bMX01@39
bm`0a<WN0<C9gP34bMh0a<_O00<0oooo00?o00000?ooo`3oool06@3oool000d0oooo00?o00000?oo
o`3oool0403oool209jmkP80VKc`0P2K_?0309BllP<0RK[f0P1j]_T306>^nP<0@J3e0P0DR>L00`00
9YP0046i00iZg@0203Yni@80Mi7P102>UmP309nJc`80Zic70P2WWL`40;6Na0<0^9no0P2gX<840;bQ
_0?o000000@0`J>j0<BS^034XkP0a:>h0P35YKT30<NU]`80b:Nh0`3:YkH20<^Y]`<0c:Vf1@3>ZkH4
0=2]]P<0dZng1@3C/KL0103E];P0e;>i0=Bc^@3D/kT20=Jf^@030=Bf^`3F^;/0e[Rk0080e[Rk103F
^[d20=Rm_P050=Jl`03H_l40f;o10=Ro`@3I`/<00P3G`L@01?l00000f<C50=S4a@3E`/L30=K5b@04
0=O8b`3Da/`0e<K<0=C6c080eLS>00@0dLK@0=79d@3AbM40dLWA0`3>b=D30<k;e`80oooo00?o0000
0?ooo`3oool0903oool00ol00000oooo0?ooo`0<0?ooo`@0Sk7^0P2:[^h308BZk@<0OjG/0P1jXN/3
07NLj080MIOV0P1dTn<307J@g`80NHkK0P1nSMP308B<d`@0RHc@0`2?SL`209F=b@@0Vhk60`2OT<<2
0:BA`@030:>@`@2WT[l0Yi:o0080Yi:o0`2/Tkd3o`000080[iFl102bUk/0102eVK/0]YVj0;JI^P2f
VKX40;VK^PD0_9ji00@0_Z2j0;nQ^@2oXKT0_j6i0P31Xk/20<>T^P@0a:Jk00<0aZRk0<NY_037ZK`0
0P37ZK`00`39Zk`0bJfn0<V]_P020<b__P<0bk700`3>/l001@3=]<80ckO30<ng``3?]l<0c[S500<0
d;_600L0d[k60=2nb@3@_/T0d;k90=;2b_l00000cl;=00<0dLG>00<0cLCA0<o7dP3?am800P3?am83
0<c8e`80cL_H00D0b<WJ0<W;g039bm`0bL_L0<C9gP030<C;g`80oooo00?o00000?ooo`3oool06@3o
ool000d0oooo00?o00000?ooo`3oool0403oool40:2mk@<0Vkc`00<0U;cb09Nll@2G_?40102>^o@2
082hn0<0Jk;j0P1=Y_P202:Ak004001`d`00:Yl03V[M03Yni@<0HhgU0`2>UmP209nJc`0309RKe02W
WL`0Yig<0080Yig<1@2aW/@0102hWkl0]j320;NP`P2gX<820;bQ_0;o00001@31XkX01034XkP0aJFi
0<FU^@35YKT20<NU]`<0b:Nh0P3:YkH30<^Y]`80c:Vf1@3>ZkH40=2]]P@0dZng00@0dk:h0=>a]`3C
/KL0dk6g0P3E];P20=Bc^@<0e[Ji1@3F^;/00`3H^k`0e[Zm0=Jj_@030=Rm_P@0f;o10P3I`/<01@3G
`L@0f<C5o`00003Ha<D0fLO700<0e/G90P3Gb</0103Da/`0eLS>0=G8cP3Eb<h30=79d@80d/_C00<0
c/SE0<k;e`3>bmL00P3>bmL30?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3oool03@3o
ool208nakP80S;7_0P26[Nl307nYk`80NJC^0`1cW^`206jIjP80JiCW0`1dTn<307J@g`80NHkK0P1n
SMP308B<d`<0RHc@0`2?SL`309F=b@<0Vhk60P2OT<<00`2NS/<0Xi310:>@`@020:>@`@<0Yi:o00@0
[9>mo`000?l00000Zi>m102_UK`30;:G^`030;>G^P2fVKX0]YVj0080]YVj0`2iVkX20;ZL^@@0_9ji
102oXKT00`31Xk/0`jBj0<>T^P020<>T^P80a:Jk0P36Z;/30<NY_080bJ^l00<0bJfn0<b__P3<[kh0
0P3<[kh00`3;/L00c[?00<jc`0020<jc`0@0ckO30`3@^lH30=:naP050=2nb@3B`/X0d/;:0=;2b_l0
00000P3AaLh20=?8d0<0clOB0P3@b]@0103<b=L0cL_H0<g;f03=bmP30<W;g0040<W=g@34bml0a<_O
0<C;g`<0a<cQ00<0ooooo`00003oool06@3oool000d0oooo00?o00000?ooo`3oool04@3oool20:2m
k@80XKg]0`2M_Nl309Nll@80S[_d0P2A_?<208Jim`@0M;Gj0P1IZoT00`0aV_40073C000ZW`0203Yn
i@80HhgU0`23U]h409RKe0@0Yig<0`2aW/@0102_WlP0]j320;NP`P2gX<83o`0000030;bQ_02lXkl0
_:>o00@0`J>j1@35YKT00`37YKL0b:Nh0<RW^0020<RW^0030<ZW]P3;ZKL0bjVg0080bjVg00<0c:Vf
0<j[]P3>ZkH00P3>ZkH50=2]]P<0dZng0P3C/[P20=>a]`@0eKBh00D0e;>i0=Jf^@3F][T0e[Ji0=Ri
^`030=Jh^`80f;^l00<0e[Zm0=Rm_P3H_Kh00P3H_Kh00`3J`L00f;o10=Ro`@030=W2``<0f<C500Co
00000=W7a`3IalL0e/G90`3Gb</30=G8cP80eL_@00D0dLWA0=;;d`3Bbm<0d/_C0=;>e@030<k;e`80
c/gH0`3oool00ol00000oooo0?ooo`0R0?ooo`03o`00003oool0oooo00l0oooo0`2</Nl208J]k`<0
OjW_0P1iY>h307>Nk080KYWZ0P1[U>L206Z@i0<0K8cQ0P1`R]d307j=f0<0Q8cC0`29S=0308n=c080
UHg90P2KS/H00`2HSLH0WXk309j>``0209j>``<0Xi3100D0Yi:oo`000?l0003o00000:bC_@030:^C
_@@0[iFl00@0/YNk0;>G^P2cUkX0/iNj102fVKX0102iVkX0^Ybi0;ZL^@2jW;T30;bN^@030;jO^@2o
XKT0_j6i0080_j6i1@33Y;X00`34Y[/0aZRk0<JX^`020<JX^`040<NY_039Zk`0bJ^l0<V[_0D0c:nn
1@3>/l000`3@]/00ckO30<ng``020=:k``030=2kaP3B_/H0d[k60080d[k6103B`/X00`3Da/co0000
0=?8d0030=?8d0040<o7dP3@b]@0d<[D0=7=eP<0cL_H0P3=c]X01@39bm`0bLgM0<W=g@39cMd0a<_O
00<0a<cQ00@0`lkR0?ooo`3ooooo00006@3oool000d0oooo00?o00000?ooo`3oool04P3oool40:6m
k@0309fmk`2O_Nh0Wkg^00@0VKc`0`2A_?<208Jim`80M;Gj0P1k]oT206B`nP80@J;f00<007cL01A^
g`0DK]l00P1SSND308>FgP<0V9_D102WWL`0102aW/@0[io80:nOb02_WlP3o`000080]j3200@0_:6l
0;bS_`2lXkl0_:>o0`31XkX20<6U_@@0aJFi1@38YkP50<^Y]`D0cZ^f00@0cjjg0=2]]P3@[KH0d:ff
0P3B/;L00`3B[kL0dk:h0=>b^0020=>b^0030=>a]`3E];P0eKBh0080eKBh0`3F][T30=Ri^`050=Jh
^`3H^k`0f;^l0=Rk_03J_kh00`3H_Kh20=[1`0030=Ro`@3I`/<0fL;30080fL;300@0flK40=S4a@3H
a<Go00000P3IalL30=O8b`80f<_=00D0eLS>0=G;d03Ebm00eL_@0=K>dP030=;;d`80d/kE00@0c/_G
0<k=f03>cMP0c/gH0`3oool00ol00000oooo0?ooo`0R0?ooo`03o`00003oool0oooo0100oooo0`29
/O0208:]l0<0NZS`0P1bX^l206ZLk@<0I9K[0P1[U>L206Z@i0<0K8cQ00@0L8[M07J9f@1fRMT0MXWI
0`1lRMD308>9d@<0Rh[=0P2ARlT409R=aP<0WXk300@0Xi31o`000?l0003o00000P2WT[l00`2WTKl0
Zi>m0:^C_@020:^C_@@0[iFl102cUkX40;JI^PD0^Ybi00@0_9ji0;jO^@2nWkT0_Yni0P2oXKT20<:R
^@@0`jBj1@36Z;/40<V[_0030<b^_03<[kh0c:nn0080c:nn00@0c[:n0<jc`03>/l00c[?00P3@]/00
103?]l<0d[_30=:k``3B^l<50=:naP030=G2b03B`/X0d/;:0080e<K<00Co00000=?8d03Cb=00dlS@
0P3Dc=801@3@b]@0dLgF0=7=eP3AcMH0cL_H0080cLkJ0P3=d=`30<W=g@80b<oO00H0a<cQ0<?>hP33
c^80`lkR0?ooool0000I0?ooo`003@3oool00ol00000oooo0?ooo`0C0?ooo`80XKg]0P2R_N`309nm
kP80VKc`0P2L_Nl309FllP<0Rk_f0`1k]oT206B`nP<0@J;f00@056kO04N5i`17QNL0AhGW0`23U]h3
09RKe080Yig<00<0XYkA0:nOb?l000000_l000001@2_WlP0]j320;NP`P2gX<80]Z;500D0_:>o00@0
`J>j0<6U_@31YKd0`JFm0`35YKT20<FW^`@0b:Nh00<0bJVi0<^Y]`3;ZKL00P3;ZKL0103=ZkP0cZ^f
0<j[]P3>ZkH20<n^]`80d:ff0`3B/;L00`3B[kL0dk:h0=>b^0020=>b^0D0eKBh00<0ekNj0=Jf^@3H
^K/00`3H^K/40=Rk_080f[nn00D0f;fn0=[1`03J`L00f/700=c4`P030=W2``80flK400L0f<C50=W7
a`3IalOo00000=W7a`3KblT0elS;00<0f<_=0`3Ebm030=K>dP040=;;d`3Bc]D0d/kE0=;@f0<0c/gH
0P3>cm/30?ooo`03o`00003oool0oooo0240oooo00?o00000?ooo`3oool04@3oool308Val080PZg`
0`1jZ?0207:Rk`80JYc]0P1TU^/2062@j0<0GX_U0P1/S>42072:g@<0MXWI0`1lRMD208>9d@<0Rh[=
0`2ARlT309R=aP0409j>`ol0003o0000o`000080Xi3100<0XXo10:NA_`2WTKl00P2WTKl30:^C_@<0
[iFl0P2_UK/30;>G^P<0]YVj0P2gV[T40;ZL^@@0_Yni00@0_j6i0<:R^@32X[T0`Z:i0`33Y;X20<FV
^P<0aZRk0P39Z[/20<V[_080c:jl0`3<[kh30<jb_P040<jc`03@]/00d;K00=2f`0@0d[_300@0e;k4
0=:naP3B_/H0d[k60P3E`/P01`3B`/X0e<K<0=C6c03Da/`0e/W=o`00003Cb=000`3Dc=830=7=eP80
dM3H00<0cLkJ0<g@g03=d=`00P3=d=`01039cMd0b<oO0<S?g`37dN430<?>hP040<;?i03oool0oooo
o`0001P0oooo000=0?ooo`03o`00003oool0oooo01@0oooo102R_N`00`2O_Nh0X;g]0:2mk@0409bm
k`0309FllP2H_O40V;ga00@0T;cd0P23^OP306ndnP80D:Wi00<005O>04N5i`17QNL00`1aTn@308nK
f`040::NdOl0003o0000o`0000@0[io800@0]j320;JRa@2fX/D0]Z;5102lXkl00`2lYL80`JFm0<6U
_@030<6U_@040<FU^@35Yk/0aJNk0<FW^`<0b:Nh0P39ZKT30<^Y]`80cJ^h0P3>ZkH40<n^]`040=2]
]P3B/;L0d[2g0=:`]`D0dk:h00@0eKFi0=Fd^03E];P0eKBh0P3G]kX00`3F][T0f;Vk0=Ri^`020=Ri
^`030=Zm_03H^k`0f;^l00<0f[nn103J`L020=c4`P050=W2``3Ka/@0flK40=_6a03Lb/L00`3IalL0
0ol00000fl_90=S;c@020=S;c@80fLo?00<0eL_@0=K>dP3Fc]800P3Fc]800`3Fd]D0d/kE0=;@f002
0=;@f0040<k=f03>cm/0c/oK0<gAg@@0oooo00?o00000?ooo`3oool0803oool00ol00000oooo0?oo
o`0B0?ooo`80Qk7a0`1n[O4307FWl@80Jj7`0P1QVNl206BFj`80H93X0`1NRnD0101PR>80I8KN06B6
gP1TQ]h307J9f@80O8WE0`23RM4308^:c@80TH_900@0V8g6o`000?l0003o00000P2NS/<00`2LSL@0
XXo10::?`@020::?`@<0Yi6o102[Tkd0102_UK`0[iFk0:nE^`2_UK/40;>G^P040;JI^P2gV[T0]iZi
0;NJ^@<0^Ybi00<0^ifi0;jO^@2nWkT00P2nWkT50<:R^@030<>T^P35Y[X0aJJj0080aJJj00D0aZRk
0<VZ^`39Z[/0bJZk0<V[_0040<b^_0030<b__P3>/[h0c[:n0080c[:n103@]/000`3C^/40d[_30=:k
``030=Bna0050=:naP3E`/P0eL;80=G2b03Ga/T00P3Da/`30=K9c@03o`00003Dc=80e<cB0080eM3D
00D0dLgF0=7@f03Ad=P0dM3H0=7DfP030<g@g080cM?N00D0b<oO0<OAh@37dN40am7Q0<?>hP030<;?
i080oooo00?o00000?ooo`3oool05@3oool000`0oooo00?o00000?ooo`3oool05P3oool20::mk0<0
Xkg/0P2P_Nd209bmk`80W[g^0`2H_O42092lm080U;cc0P29^oH407RgnP0405n_nP00Elh0AhGW04N5
i`<0LI?T0ol000040::Nd@80[io800<0Zj;>0;JRa@2fX/D00`2fX/D20;bS_`80_:G21031YKd00`31
Z<00aJNk0<FW^`030<FW^`030<RW^039ZKT0bJVi0080bJVi00<0bjVg0<f[^03=ZkP00P3=ZkP00`3>
ZkH0cjjg0<n^]`020<n^]`@0d[2g00@0dk>i0=>b^03C/[P0dk:h0`3E]KT0103E];P0ekNj0=Ng^P3G
]kX40=Ri^`<0f[fl00D0f;^l0=Zo_P3J_kh0f[nn0=c3`0020=[1`0<0g<C20`3Ka/@30=c:a`060=W7
a`3KblT0fl_9o`00003Kcl`0f<_=0`3Icll0103Id]80e/kB0=K>dP3Fc]820=KBe@<0d]3H0P3AdmX0
103>cm/0cM7M0<gAg@3=dMd30?ooo`03o`00003oool0oooo01l0oooo00?o00000?ooo`3oool0503o
ool208Nal@<0OZga0`1eYo4206^Ql080HIW_0P1IT^`205:<j@<0GX_U00<0H8SR06B6gP1TQ]h00`1[
QMX307>5e`80PhWA0`2;R/d3o`000080V8g600<0UH_709b=a02LSL@00P2LSL@30::?`@@0Yi6o0`2[
Tkd40:nE^`<0/iNj00<0]9Rj0;NJ^@2gV[T00`2gV[T0102jW;T0^ifi0;^M^@2kWKT30;jO^@030<2P
^@32X[T0`Z:i0080`Z:i1@35Y[X40<VZ^`D0c:jl1@3>/[h00`3A][h0d;K00=2f`0030=>j`@040=:k
``3D_/@0e;k40=Bna0<0eL;80`3Ga/T01P3Da/`0e/W=0=K9c@3FbLd0f<k@o`0000<0eM3D00@0e]?G
0=7@f03Ad=P0dM3H0P3Ae=X0103=d=`0cM?N0<gCgP3<eN430<OAh@80a];S0P32cn@20<7?i@030?oo
ool00000oooo01H0oooo000<0?ooo`03o`00003oool0oooo01P0oooo0P2S_N`00`2T_N/0X[g]0::m
k@020::mk@<0W[g^00<0V;ga09^ml02K_O00102D_?<208VkmP80N;Oj0P21^OP00`1/]?/003^b021f
h`03o`000004076Ci02?Vm/0Si_K08nKf`80XYkA00<0Vj3H0:^RcP2[X/h00P2[X/h40;JRa@030;bS
_`2lYL80_:G20080_:G20P31YKd20<6X`0@0aJNk00<0aZZm0<VY^@39ZKT00`39ZKT50<f[^0@0cjjg
00@0dK6i0=:`]`3B/;L0d[2g0P3C/kT20=>b^0@0eKFi103G]kX00`3I^k/0f;Vk0=Ri^`040=Zm_0<0
f[nn0P3L`l000`3J`L00g<C20=c4`P020=c4`P030=g9a@3Ka/@0g<[700<0g<[70`3KblT00ol00000
flo<0=cCd0030=W?c`80fM;B00<0e/kB0=KBe@3Fd]D00P3EeMP0103Bd=P0dM?J0=7CfP3AdmX30<gA
g@80c=?O0`3oool00ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo01D0oooo0P24/O8307^/
l`80KjKc0`1SWo8205NGk`80FI;/0P1BS>T20526iP80DH;S0P1TQ]h306^5fP80LhGG0P1lQ]83o`00
00<0SHW;102ERlL309b=a0<0XXo10`2WTKl00`2VTKl0Zi>m0:^C_@020:^C_@@0[iFk00<0/iNj0;BH
^P2dV;X0102gV[T00`2iVkX0^ifi0;^M^@020;^M^@80_Yni0P30X;T40<:R^@030<BT^@35Y[X0aJJj
0080aJJj1039Z[/00`3;[K/0c:jl0<b^_0020<b^_0040<na_03>/[h0c[:n0<jb_P80dKJn00<0d;K0
0=>j`@3C^/400P3C^/430=Bna080el?600<0eL;80=O6b@3Ga/T00P3Ga/T30=K9c@80f<k@00?o0000
0=G@e03Ed=@00`3FdmL00`3Ad=P0dMCJ0=7DfP020=7Gg@050<gCgP3<eN40c=GQ0<cEh@37dN400P36
d^<01@35dnD0`LoU0<7?i@31cnD0_m3W0080oooo00?o00000?ooo`3oool0503oool000`0oooo00?o
00000?ooo`3oool06@3oool30:Bmj`80X[g]0P2S_N`30:2mkP<0Vkg`0P2D_?<209NmlP<0S[ce0P21
^OP3o`00008087KS0P1GS^T3082Kh`@0Vj3H0`2[X/h30;JRa@030;>UbP2lYL80_:G200<0_:G200<0
`JFm0<6X`031Z<000P31Z<020<FW^`80aZZm1039ZKT00`3:[;`0cJ^h0<f[^0020<f[^080cZnj0P3?
[[L30=6a^@030=:`]`3C/kT0dk>i0080dk>i00<0dk:h0=Fe^@3E]KT00P3E]KT00`3G^K/0ekNj0=Ng
^P030=Vk^`030=Ri^`3J_K`0f[fl0080f[fl00<0g<6o0=Zo_P3L`l000P3L`l00103Nb<<0g<C20=c4
`P3La<820=g9a@040=o>b03Lb/L0g<[70=c:a`80gLo:00@0fl_90=_?c03Kclco00000P3Ldm000`3I
cll0fM;B0=WBdP020=WFeP040=KBe@3EeMP0eMGH0=GEf0<0dM?J0P3@e]d0103=dMd0c=?O0<cCg`3:
e>840?ooo`03o`00003oool0oooo01d0oooo00?o00000?ooo`3oool05P3oool208BalP<0Njcc0P1_
Y_<306>OlP0405NGk`1<S^d0C8k]04b>k@80@hKY0P1@Q^H0101AP^<0EX3P05J0h01FP>0206^5fP05
07>5eol0003o0000o`00001lQ]800`25R<h308f9b`<0UH_70`2LSL@40::?`@040:NA_`2VTKl0YY6o
0:JA_`<0Zi>m0`2_UK/00`2`U[`0]9Rj0;BH^P020;BH^P80]iZi0P2iVkX40;^M^@040;jO^@30X;T0
`:2i0<2P^@<0`Z:i0P34Y;T30<FV^P80b:Rj0P39Z[/20<^]^`<0c:jl0`3?/K`0103>/[h0dKJn0=6f
_P3A][h50=>j`@030=Jn``3D_/@0el?60080el?600@0f/S80=O6b@3Ga/T0elK90P3Ibl`00`3FbLd0
f<k@0=S>d0020=WBdP04o`00003FdmL0e]?G0=KCe`80e]OI00@0dMCJ0=7Gg@3Aemd0dMOM0`3<eN42
0<[Gh`050<KBh`35dnD0aM?U0<GCi@31cnD00`2od>L20?ooo`03o`00003oool0oooo01<0oooo000<
0?ooo`03o`00003oool0oooo01X0oooo00<0Y;g[0:Fmj`2U_N/0102S_N`00`2P_Nh0X[g]0::mk@04
09fmk`0309NmlP2K_O00Vkg`0080Tkgc0_l0000208Rkm`80MkSj0P00Gm<205N>j@<0P9_S0`2KX=P4
0:^RcP040;JRa@2cYLX0/jG:0;>UbP@0_:G21@31Z<000`35Yk/0aZZm0<JZ_@020<JZ_@80bJVi0`3:
[;`20<f[^0<0cZnj00<0cjjg0=6a^@3A/KT00P3A/KT00`3B/;L0dk>i0=>c^@020=>c^@@0eKFi0P3G
^K/00`3G]kX0fK^k0=Vk^`020=Vk^`040=_0_P3J_K`0f[fl0=Zm_080g<6o00@0f[nn0=c3`03L`l00
g<?00P3Nb<<0103La<80gLW50=g9a@3MbLD20=o>b0060=c:a`3MclX0gLo:0=g?bP3Ndld0flo<0P3L
dm001?l00000g=?@0=cHd`3Id]830=WFeP<0eMGH0P3Df=/00`3AdmX0d=KM0=3Fg@020<kHh0040<cC
g`3:e>80b]CR0<[DhP<0oooo00?o00000?ooo`3oool07@3oool00ol00000oooo0?ooo`0H0?ooo`80
P[7c0`1g[?@01@1[Y_@0G9kb05bNlP1LW_80CIC`00<0C8k]0P13Q^T00`0oP>H0DH;S0562h`0205J0
h00305f0g?l0003o00000080LhGG0P1lQ]8308F8cP<0SHW;0`2ERlL409b=a080XXo100<0X8o20:JA
_`2VTKl00P2VTKl40:^C_@030:nE^`2`U[`0/9Jl00@0]9Rj00<0]iZi0;VK^P2iVkX00P2iVkX30;^M
^@D0`:2i00<0`Z:i0<BT^@34Y;T00P34Y;T01@35Y[X0b:Rj0<RX^P38Z;X0bJZk00@0bjfk00<0c:jl
0<na_03?/K`00P3?/K`40=6f_P040=Bj`03C^/40dk[10=>j`@80e[k3103G`lH20=[8b0060=O6b@3I
bl`0fL_<0=W;c03Kd<h0f<k@0`3Id]800`3JemGo00000=KCe`030=KGf@<0dMOM0P3@fN00103<eN40
b]OS0<[Gh`38f>D30<GCi@80`mCW0P2od>L20;k@j0030?ooool00000oooo01@0oooo000<0?ooo`03
o`00003oool0oooo01`0oooo0P2U_N/20:>mk0<0Y;g[0P2R_Nd209fmk`0309nmkP2K_O00Vkg`00?o
000000<0Tkgc09NmlP2>_?D00`2>_?D00`20^_T005oC001Od`0203:2j@<0P9_S0`2KX=P20:^RcP03
0:JUe02cYLX0/jG:0080/jG:0`2lYL820;^Xa`@0`JS01@36Z[d00`39ZKT0bZbl0<Z/_0020<Z/_003
0<f[^03>[kX0cZnj0080cZnj1@3A/KT50=>c^@030=Fg^`3E]KT0eKFi00<0ekVk1@3I^k/20=_0_P05
0=Zm_03L`Kl0g<6o0=c1_`3Nal800P3L`l030=k8``<0gLW50`3Oc/P30=g?bP80g]?=00H0g]WA0=cC
d03Ldm00g=?@o`00003Lf=<30=WFeP80f=[I00<0eMGH0=CHf`3Df=/00P3Bfml01@3@e]d0c]SP0<kH
h03>f>00c=WS00<0b]CR0P38e^@20?ooo`03o`00003oool0oooo01`0oooo00?o00000?ooo`3oool0
603oool3086bm0<0MJge00D0IZKe05bNlP1LW_80G9kb04fDl00303j:k080<h7X00<0?h3V03mlhol0
00000_l0000205f0g080Ih7I0`1bPmD308F8cP<0SHW;0`2ERlL209b=a00309V=a@2PSl80X8o20080
X8o20`2VTKl30:^C_@030:^C_P2`U[`0/9Jl0080/9Jl0`2dV;X50;VK^P80^ifi0P2mW[T40<2P^@D0
a:Bi1038Z;X50<^]^`D0ck6l00<0d[Fn0=6f_P3A][h00`3D^/001@3C^/40e[k30=Jn``3F_/<0fLC4
0080el?60`3Jb<P30=W;c080fm3>00@0g=KA0=WBdP3Id]80fM;B0P3JemD00ol00000e]OI0=KGf@02
0=GKg0030=7Gg@3@fN00d=WP0080c]_S00D0b]OS0<SHi@38f>D0b=SU0<GCi@020<?Di`050<7Dj02n
d>P0_]3X0;k@j02ld>T00P3oool00ol00000oooo0?ooo`0B0?ooo`00303oool00ol00000oooo0?oo
o`0L0?ooo`@0Y[gZ0P2T_N/00`2U_N/0Xkg/0:>mk0020:>mk0?o000000<0Vkg`09fmk`2M_Nl00`2G
_O8208jlm@80Tkgd0P28_?L00`00@KD0<X;Y06^Hj`0206^Hj`<0T:;Q102VYM@40;>UbP040;bU`P2k
Z<L0^jS70;^Xa`<0`JS00P31Zl@40<JZ_@D0bZbl1@3>[kX00`3?/kd0dK6i0=6a^@020=6a^@040=>e
_03C/kT0dk>i0=>c^@<0eKNk00D0eKFi0=Ni^`3G^K/0ekVk0=Vn_P030=Vk^`<0fl2n103L`Kl20=k7
`P060=c3`03Nb<<0g/S30=k8``3OcLH0gLW5103Oc/P00`3Pe<`0gLo:0=kCc@020=kCc@80g]WA00<0
g=?@0=cHdol000000P3Kg=L00`3Ie]H0f=[I0=SJf@020=KNg@040=CHf`3Bfml0d]_O0=;Kg`80d=gR
00D0c]SP0<cIh`3<fN<0c=WS0<[DhP020<SFi0040<KGi`3oool0ooooo`0001h0oooo00?o00000?oo
o`3oool06@3oool3086bm0<0MJge0P1VY_D205FMl`0404>Bl00nR^`0?X[/03j:k0?o00000P0oO><2
04=jh080GH3L0P1WPMT207:3e@<0OHGA0`27R<d3096:b0@0VHg50`2PSl840:JA_`030:^C_@2[Tkh0
Zi>n00@0/9Jl0P2dV;X20;FI^`@0^I^j00@0^ifi0;fN^@2mW[T0_Iji0`30X;T20<:S^@@0a:Bi1038
Z;X00`3;[;/0bjfk0<^]^`020<^]^`040<j`_03?/K`0ck6l0<na_080d[Fn00<0dKJn0=Bj`03D^/00
0P3D^/030=Jn``80fLC400<0el?60=[8b03Jb<P00P3Jb<P0103LcLX0fL_<0=_@cP3Kd<h30=cFd@06
0=WBdP3JemD0f]OE0=[Kf?l00000e]OI0P3Efm`20=CNg`030=3Ih03>fn<0c]_S0080c=cU0P38f>D2
0<KHi`050<?Di`31e>P0`MCX0<7Dj02nd>P00`2ld>T00`3ooooo00000?ooo`0C0?ooo`00303oool0
0ol00000oooo0?ooo`0M0?ooo`80Y[gZ0P2W_NX30:Fmj`?o000000@0Y;g[0:6mk@2Q_Nd0XKg]0`2M
_Nl0102G_O80Vkg`09^ml02K_O0309>mm080R;cg00<0MkSj005/g01[V>/00P1[V>/3092Rh@@0YZGD
0P2cYLX00`2`ZM40^jS70;^Xa`030;^Xa`040<6X`031Zl@0`J_40<6[a0<0aZZm0P37[/430<Z/_080
c;2o0`3>[kX20<nc_@<0dK6i0`3C]K`00`3C/kT0eKNk0=Fg^`020=Fg^`<0ekVk0`3I_[h00`3I^k/0
fl2n0=_0_P020=_0_P030=g5`P3L`Kl0g<6o00<0g/O20`3Nb<<20=o=aP040>7Cb`3Oc/P0glk80=o>
b080h=C<0`3Ndld30=kId@070=kNeP3Lf=<0fmcGo`00003Kg=L0fN7L0=SJf@020=KNg@<0e>7Q00@0
d]_O0=3MhP3@gN80d=gR0`3<fN<20<WKiP040<SFi036enL0a]OW0<KGi`80oooo00?o00000?ooo`3o
ool06`3oool00ol00000oooo0?ooo`0J0?ooo`<0P;;e0P1c[OH306>VmP80Cicd0ol00000100aQ^/0
8G[U02]ii00[NN@202Uch@0304=jh01<N]h0C7[N0080Ih7I0`1bPmD307f5d@<0QhS=0`2AR/P309V=
a@@0X8o20P2VTKl00`2UTL00Zi>n0:^C_P020:^C_P<0/9Jl00@0]9Rj0;FI^`2eVK/0]IVk102iVkX5
0;fN^@040<2P^@32XkT0`Z>i0<:S^@<0a:Bi0P36YkX20<RX^P80bjbk0`3;[K/30<j`_0040<na_03B
]Kh0d[Fn0=:e_PD0e;[000<0eko20=Jn``3Ia<@00P3Ia<@0103LbLL0f/S80=[8b03Jb<P20=c=bP03
0=kCc@3Kd<h0g=KA00<0g=KA00L0gM_D0=[Ge@3JfmP0f]_H0=WOg?l00000eM_L0080e=kO0P3Bh>80
103>fn<0c=cU0<cLi@3<g>D30<KHi`80a=SY0P31e>P20;kCjP80_=3Y0P2jcnX00`3ooooo00000?oo
o`0B0?ooo`002`3oool00ol00000oooo0?ooo`0O0?ooo`<0YkgZ0ol000000`2V_NX0Y;g[0:Bmj`02
0:Bmj`030:6mk@2S_N`0Xkg/00<0Wkg^0P2K_O0209fnk`<0Ukgb0`2?_OH01001K=`0JiS[06^Hj`1[
V>/3092Rh@80YZGD00<0WZSM0;2Yd@2`ZM400P2`ZM430;^Xa`030;V]c@31Zl@0`J_400<0`J_400<0
aZZm0<N^`@37[/400P37[/400`3:[;`0c;2o0<b`_`020<b`_`030<j_^P3?/kd0ck>m0080ck>m00<0
dK6i0=>e_03C]K`00P3C]K`50=Fg^`030=Nl_P3G^K/0fKjn00<0fKjn103K`;h20=g5`P030=c1_`3N
al80g/O20080g/O200<0glg60=k8``3OcLH00P3OcLH20>7Cb`030=o>b03Pe<`0h=C<0080h=[@00@0
g]?=0=kId@3NfM40g]WA0P3Ng]H30=_Le`04o`00003IhM`0enCP0=KNg@@0e>7Q0`3@gN820<gOiP03
0<cIh`39fnH0bM_V0080a]_Y0P36enL20<?Gj@80oooo00?o00000?ooo`3oool06@3oool00ol00000
oooo0?ooo`0L0?ooo`<0P;;e0P1c[OH01@1SY_Ko0000o`000?l00000Cicd0080>Y3_0P0SP^T01`0Q
N^D05W3P01I`h00YLn40;G;O04=jh01<N]h00`1HO=/307:3e@80OHGA0`27R<d3096:b0@0VHg50P2P
Sl80102NSl@0YI700:FA`02UTL040:^C_P80/9Jl00<0/INm0;FI^`2eVK/00P2eVK/30;VK^P80^Yfj
102mW[T50<:S^@050<BT^@36YkX0aZNj0<JW^P38Z;X0103;[;/00`3;[K/0c[2l0<j`_0020<j`_0@0
d[Fn00@0eKZo0=Bj`03D^/00e;[00P3G_l830=W4a0<0g<W700<0f/S80=c=bP3LcLX00P3Ndld0103O
fM00g=KA0=cFd@3Le]420=gKe0030=gPf03JfmP0fMoL0080fMoL00?o00000=CNg`3Bh>800P3Bh>82
0<oRi@040<cLi@39gNP0bMgX0<KHi`<0a=SY0P31f>/01@2ndnX0_=;[0;cBj`2ld^/0^/oZ0080^<k[
00<0ooooo`00003oool04@3oool000/0oooo00?o00000?ooo`3oool07`3oool3o`000080YkgY0`2V
_NX20:Bmj`80YKg[0`2S_N`00`2O_Nh0XKk]0:6nk@0409fnk`0309NmlP2K__00Vkk`00<0U;gc00<0
04fm04V@kP19T>h00`1nX^X409jXg@@0/:WA00@0^jS70;V]c@2i[Ld0^Jg=1031Zl@50<N^`@D0c;2o
1@3?/kd50=>e_0040=Bj`03E]k/0eKNk0=Fg^`80ekbn00<0ekVk0=Vn_P3I_[h00P3I_[h00`3Ka<80
fl2n0=_0_P030=g5`P040=o<aP3Nal80g/O20=k7`PD0glg60`3Qdl/00`3Qf/l0h=C<0>3Jd0020>3J
d080gn3E00<0g]WA0=kNeP3Ng]H00P3Lhm/01P3Kg=L0fN7L0=WQg?l00000enCP0=?Xi@<0e>7Q0P3@
hnD00`3@gN80cMoV0<gOiP020<[Pj@040<WKiP36fnT0a]_Y0<?Lj`<0`mOY0P30en/00`3ooooo0000
0?ooo`0J0?ooo`03o`00003oool0oooo01h0oooo00D0P;?eo`000?l0003o000007:^m`03066Wm`04
04^Lm00bS^l0<Xk_02>2j@803g?Q00@05W3P011Yg00@JM`0;G;O0P1<N]h205Qlf`<0IWoH0`1dPm@3
08N8c@<0TH[80P2ISLD0102FS<L0WXo409j?a02NSl@40:FA`0<0Zi>n00@0/9Jl0;6G_@2aUkd0/INm
102eVK/0102iVkX0^Yfj0;ZM^P2jWKX30;fN^@80_j6j1032XkT40<JW^PD0bjbk1@3>/;`00`3A]Kd0
d[Fn0=:e_P030=Fj_`060=Bj`03G_l80eko20=No`P3KaL@0fLC4103LbLL00`3Nd<T0g<g:0=kCc@02
0=kCc@80gmW@00<0g=KA0=gKe03Mfm@00P3Mh=P30=WOg080en?O00?o00000=GVh`3Bh>800P3?h^D2
0<cSj0050<WMj036gNX0a]gZ0<KMjP34f>T00P31f>/01@2nen`0_=;[0;cBj`2ld^/0^]7/00<0^<k[
00<0]/g[o`00003oool04@3oool000/0oooo00?o00000?ooo`3oool0703oool3o`0000<0oooo00<0
YkgY0:Rmj@2X_NT0102W_NX00`2U_N/0Y[gZ0:JmjP040:Bmj`80XKk]0P2M_^l20:2nkP<0Vkk`0P2D
_O<0102H__8004fm04V@kP19T>h307jRjP<0WZSM0`2`ZM400`2[[]T0^Jg=0;V]c@020;V]c@<0`J_4
0P31/<T40<N^`@030<NcaP3</;l0c;2o0080c;2o00<0cKK40<nc_@3?/kd00P3?/kd0103A^<40dkFl
0=>e_03C]K`30=Bj`0050=Fg^`3G_;h0ekbn0=Nl_P3I`/<00`3I_[h20=_4`P030=_0_P3MaL80gLG2
0080gLG20P3Oc<H01P3Nal80glg60=o=aP3OcLH0hM?:0=o=aP<0hM?;0P3Qf/l0103Qh]@0h=[@0>3J
d03Pf]020=oPe@040=kVfP3Ng]H0g>?K0=cSf`80fNSO00@0fN7L0=OTh?l00000enCP0P3Cj>D00`3D
hN40d>?U0=3Si@020<gUj@030<gOiP3:h>T0b^3Y0080a^7/00D0a]_Y0<?Lj`33g>/0`mc[0<?Gj@02
0<3Gj`040;gGk@3oool0ooooo`0001X0oooo00?o00000?ooo`3oool0703oool3o`000080PKCf0`1b
/?L205nXm`80B9gd0P0bS^l0100GO^H03g?Q00mch@00ImT2011Yg00302ebg`0gL]h0=g;N0080F7cK
0`1VOmP207B3e0<0PHK@0`2<RL/309J<a`@0WXo40`2UTL020:^C_P030:^E_`2aUkd0/INm0080/INm
0`2eVK/00`2fVk`0^Yfj0;ZM^P030;ZM^P040;fN^@2oXKX0_j6j0;nQ^P<0`Z>i00<0a:Jj0<JW^P36
YkX00P36YkX01039Zk/0bjbk0<^/^`3;[;/50<j`_080dKFm00<0d[Fn0=Fj_`3E^[l00P3E^[l30=No
`P80flG400@0g/_70=c9a`3LbLL0g<W70P3Nd<T00`3Qeld0g]?=0=kCc@030=oId0040>3Oe03Mfm@0
gN3H0=gPf080g>GK00D0fMoL0=OSg`3Ghml0en?Oo`0000020=7XiP030<oRi@3<hnP0c>?X0080b>?[
0P36gNX20<?Lk0050<7Hj`2nen`0_]O/0;kGk02ld^/00`2jdN`01@2hc^/0]/g[0;K=j`2fcN_o0000
0140oooo000;0?ooo`03o`00003oool0oooo01T0oooo0ol000070?ooo`<0Z;gY0P2W_NX00`2W_NT0
Y[gZ0:JmjP020:JmjP80Y;g[00<0YKg[0:>nk02S_^`00P2S_^`00`2P_^h0X[k]0::nk@0409jnk`80
V;kb00<0T;ge01QniP0HO^H00`1nX^X309jXg@040;2Yd@2[[]T0ZjkI0:^^f@@0^Jg=00@0`J_40<6`
b@31/<T0`K390`37[/420<NcaP<0c;2o0P3=]/@30<nc_@<0dKS100<0dkFl0=Bj`03D^/000P3D^/04
0=Nl_P80fL;300D0fKjn0=_4`P3Ka<80flC20=g;aP030=g5`P<0glc60`3OcLH20>7CbP80h]_?00@0
hM?;0>7Jc`3Qf/l0hM[?0P3Qh]@00`3Pf]00gn3E0=oPe@020=kVfP040=[/g`3Lhm/0fNSO0=WXg`<0
eNcT00<0enCPo`00003Cj>D00P3?j^T00`3@hnD0cNGY0<gUj@020<SVk0030<[Pj@36hN`0a^7/0080
`^7^0P33g>/20;oKk@040<3Gj`2mend0_MO]0;gGk@?o00006@3oool00ol00000oooo0?ooo`0I0?oo
o`?o0000103oool2086dmP<0L[3g0P1OZ?L304RMm00602b>kP0GO^H05gkV001]f`00ImT046WL0P0B
Im/203MbgP80AGKM0P1VOmP207B3e0<0PHK@0`2<RL/409J<a`<0WXo40`2UTL00102[Tkh0ZiFo0:^E
_`2[UKl40;6G_@040;FI^`2fVk`0]Y^l0;JK_0@0^Yfj1@2oXKX01032XkT0a:Jj0<BV^P34Y[X20<JW
^P<0bJ^k00<0bjbk0<j`_03>/;`00`3>/;`30=6e_@D0eKZo00<0f<320=No`P3KaL@00P3KaL@20=k;
a`040=c9a`3Nd<T0g]390=k@b@80hMO=00<0g]?=0=oId03OfM000P3Pgm@0103PiMP0gN3H0=cUf`3L
iM/30=[Yg`040=OSg`3Ei^<0dNSVo`000080c^WY00@0c>?X0<SSj`38hn/0aN;]0`33g>`20<3Kk@80
_]O/0P2keNd20;[Ak080]m3/0P2fcN/20;C<k003o`00003oool0oooo00h0oooo000;0?ooo`03o`00
003oool0oooo01H0oooo0ol0000;0?ooo`<0Z;gY0`2W_NT20:JmjP80YkgZ0`2U_N/20:>nk0030:Bn
j`2R_^d0X[k]0080X[k]0P2N_^l00`2P_^h0W;k`09bnl00209bnl08067kV0P1RWo84096/j0@0ZjkI
0P2i[Ld00`2f/]D0`K390<6`b@030<6`b@030<N^`@37/lH0ak?60080ak?600<0c;2o0<ffa03=]/@0
0P3=]/@00`3?/kd0dKS10=6h`@020=6h`@@0e;[00P3F`L@20=Nl_P<0fL;3103Ka<820=g;aP030=g5
`P3Oc<H0glc60080glc600@0h=?;0=o=aP3QdlX0hM?:0`3Rfll30>7Jc`<0hN;D00@0g^SJ0=oPe@3N
i]X0g^KJ0P3Jk=l00`3El>@0fNSO0=G/i0020=G/i080cnoY00<0dnSUo`00003?j^T00P39jnd00`3=
iNT0b>K/0<SVk0020<?Vk`030<KQk032hNh0`^7^0080_Mo`0P2ofnd20;cJk`80_MO]0P2je^h00`3o
oooo00000?ooo`0H0?ooo`03o`00003oool0oooo01H0oooo0ol000090?ooo`80P[Kf0`1c/OP2062Z
n080Aike00@0:Ho^00ikh`0>Nn<006OD0P00G=02019Wf`8076SK00@0AGKM05Ikf`1FNm/0EW_K0P1d
Pm@30866d0<0S8W;0`2FS<L309j?a080YI7000<0Y9;30:^E_`2[UKl00P2[UKl30;6G_@030;6I_`2f
Vk`0]Y^l0080]Y^l0`2jWKX20;bO_0@0_j6j1034Y[X00`36YkX0bJ^k0<V[^`020<V[^`D0c[2l103A
]Kd40=Fj_`80f<3200<0g<K40=_5a03KaL@00`3NblL30=k@b@<0hMO=00@0h]k@0=oId03Pgm@0h=oD
0P3PiMP00`3Njm/0g>GK0=[Yg`020=[Yg`80encS00@0dnkV0=7XiP3>jNWo00000P39j>`01@38hn/0
aN;]0<GRk@35h^d0`mc/0080`=_]0P2lfNh20;_Ek@80^M?^0P2gd>`20;G>k@80]<c/00<0//[/o`00
003oool03`3oool000/0oooo00?o00000?ooo`3oool0503oool2o`0000l0oooo0`2X_NT0102W_NT0
Z;gY0:Rmj@2X_NT30:NmjP040:Fmj`2V_NX0Y[gZ0:JmjP80Y;k[0P2R_^d30:>nk080X;k^0P2L__00
102O_^l0V[ka09Znl@00GlX206:OlP@0TJcX0P2[[]T00`2R/n@0][;E0;Jbe@020;Jbe@<0`K3900<0
_kKA0<NcaP37/lH00`37/lH50<ffa0D0dKS100<0d[k70=Bj`03D^/000`3F`L@00`3G_;h0fL;30=W2
``020=W2``030=_9b03Ka<80flC200<0gL_600@0gm?<0=o<aP3Oc<H0glc60P3Pdl/00`3Qg=00hM?:
0>;Kc`030>;Kc`030>7Se@3Qf/l0hN;D0080hN;D0P3Nj=X0103Kkn00g^KJ0=[/g`3Jk=l20=G`i080
c_CY00@0eNcT0<o_j@3?knT0bO7]0P32lO400ol00000bN_]0<?/l0020;g[l`80`nK_0P2niO800`32
hNh0_Mo`0;gOl0020;[NlP80_=[_0P2ifO020;[FkP80]mC_00?o00000?ooo`3oool05`3oool00ol0
0000oooo0?ooo`0D0?ooo`;o0000303oool308BgmP<0M[?h0P1R[?T204VQmP80:Ho^00@01g[Q001W
e000G=0005380P00FM800`0LJ=/0;6gL02a]g00205Ikf`80Ih3H0`21Q]0308b9b`<0UXc70P2NSl@0
0`2LT<H0Y9;30:BB``020:BB``@0ZiFo00@0/INm0;6I_`2aVKl0/IVo102fVk`0102jWKX0_9nl0;bO
_02lWk`30;nQ^P030<:U_034Y[X0a:Jj0080a:Jj1@39Zk/00`3<[kd0c[2l0<j`_0020<j`_0030=6e
_P3A]Kd0dKFm00@0eKZo0`3H`<820=c6a0060=_5a03NblL0g/_70=k;a`3QdlX0g]390`3Qeld20>;N
d0040>;Ue03Pgm@0h>GH0>3Uf080g^_K0P3Kkml0103JjMl0encS0=O/h`3Ck^H20<k_jP030<kYj@39
j>co00000080aNO^0P35h^d20<7Pk`040<3Kk@2lfNh0_=W^0;WGk`<0^M?^00D0]]7^0;G>k@2ec^d0
]Lk]0;?<k@030;;:k003o`00003oool0oooo00h0oooo000:0?ooo`03o`00003oool0oooo0180oooo
0ol0000B0?ooo`L0Z;gY0`2W_NT20:JmjP80YkgZ0`2U_^/20:>nk0030:Fnj`2R_^d0X[k]0080X[k]
0P2O_^l209Znl@<0=Y?`0P2A[>P00`1k[O<0X[?T0::ci0020::ci0@0][;E00@0`K390;nfd@2o]]40
_kKA0`37/lH20<Njc@<0cKK40P3=_<X30=6h`@80d[k700<0e;[00=K1a03F`L@00P3F`L@0103Hb<X0
fL;30=W2``3I`/<20=_9b0030=_4`P3MblH0gL_60080gL_60P3Odl`00`3Oc<H0h=?;0>3Cb`020>7L
d0040>3Ue`3Rfll0h]_?0>;Kc`80hN?E0P3Njm/0103Qh]@0g^SJ0=kXfP3Kkn020=Cdi@030=[/g`3E
l>@0eO3T0080c_CY0P36mNd01`3?knT0bO7]0<;al@32lO40^_3do`000033k?000P2mjo<20;SYmP80
_^Gb0P2jho@00`2mgo00^]kb0;[NlP020;KLl`80^MW`0P2feo420;ODk`030;GCkol00000oooo01L0
oooo00?o00000?ooo`3oool04P3oool3o`0000l0oooo0`24]oH00`1f/oP0NKGh07Ven00206J_n@80
BJ7f0P0YTNh200Akg`05001Ca@00D<P005WB001IdP00F]<00P0/KM`205Ikf`0406N0f01gQM@0MhGD
07N5e0<0QXW?0`2BSL/409b@aP<0Y9;30`2[UKl00`2[Ul80/IVo0;6I_`020;6I_`@0]Y^l1@2lWk`0
102oXKX0`ZFl0<:U_032YK`20<BV^P80ajZl0`39Zk/20<b__@<0c[2l0P3A]Kh00`3A]Kd0eKZo0=Fj
_`020=Fj_`<0f<320`3La/@30=k;a`80hM?:0P3Sflh00`3Qeld0h]k@0>;Nd0020>;Ue0030>7/f03P
iMP0g^_K0080g^_K00D0fnoO0=Obh`3Gl^<0encS0=?^iP020<k_jP80bNk]00<0bNS/o`000035inh0
0P31iO020<7Pk`80_Mk`00D0_=W^0;WGk`2ienl0^MO_0;WCkP030;KAkP040;G>k@2cc>d0/lc]0;?<
k@80//[/00?o00000?ooo`3oool03P3oool000X0oooo00?o00000?ooo`3oool03`3oool3o`0001H0
oooo0P2X_NT00`2X_NP0Z;gY0:Rmj@020:Rmj@030:Nmj@2X_NT0Z;gY00@0YkgZ00<0YKk[0:JmjP2V
_NX00`2U_^/20::nk@030:Bnk02Q_^h0XKk^0080XKk^00<0WKk`03JCl00fTo00101k[O<40::ci080
][;E00<0/KWP0;nfd@2o]]400`2o]]400`37/lH0ak[=0<Njc@020<Njc@030<ffa03=_<X0cKc:0080
cKc:00D0dKS10=:na`3B_/L0d[k70=?7cP030=K1a0<0f<S:00D0fL;30=_9b03KbLP0flW80=cBcP03
0=g;aP<0gm?<00<0gmcC0>3Cb`3Qg=000P3Qg=020>3Ue`030>;Kc`3QhmD0hN?E0080g^_K0P3Il^40
103Nj=X0fnoP0=Cdi@3Dm>D20<_hj@80`?W/00@0c_CY0<Kek@36mNd0_OG`0P2dm?<01P32lO40^_3d
0;[`m02dk_Ko00000;g[l`80^>Wf0P2ci_L20;[Sm080]N7e00@0^]kb0;KLl`2fg?<0/m[d0`2feo40
1P2ceO80]M?_0;GCk`2ednl0ooooo`0001L0oooo00?o00000?ooo`3oool03`3oool3o`0001@0oooo
0`26^?H207Ven0<0IZoi0P1=Y?L01@0/U?0017_O00Akg`00HLX004^k008004[400@005[C02a]g010
M=d0@7CM0P1WP=P307N5e0<0QXW?0`2BSL/309b@aP@0Y9;300@0ZiFo0:^G`P2[Ul80ZiO20`2aVKl3
0;JK_0030;RN_P2lWk`0_9nl0080_9nl00<0_Z>n0<:U_032YK`00P32YK`00`34Y[X0ajZl0<NZ_002
0<NZ_0030<V[^`3<[kd0c:nm0080c:nm00D0c[2l0=6e_P3A]Kh0dKFn0=Bk`@030=Fj_`80fL7200<0
f<320=c6a03La/@00P3La/@0103Oc/P0g/_70>7CbP3QdlX30>?KcP040>CSd@3Rg]00h^GD0>;Ue080
hNcH0P3NlM`0103Njm/0fnoO0=Obh`3Gl^<20=;di`040<cdjP3>knX0bNk]0<W^k@80a>g`00<0aNO^
o`000031iO000P2mh_820;gNl080^]_a0P2ienl20;ODk`80]]7^0P2dcnh20;?<k@@0oooo00?o0000
0?ooo`3oool03@3oool000X0oooo00?o00000?ooo`3oool0303oool3o`0001X0oooo0`2X_NP70:Rm
j@80YkgZ0P2W_NT30:JmjP040:Fnj`2V_^/0Y[k[0:Jnj`80Y;k/0P2Q_^h30:>nk0030:2nkP00MmX0
Njgc00<0Njgc0P2R/n@00`2C^O40/KWP0;6ih0020;6ih0<0_kKA0P2m_]/30<Njc@030<K2eP3=_<X0
cKc:0080cKc:00@0c/GA0=:na`3B_/L0d[k70`3Calh00`3F`L@0f<S:0=S8bP020=S8bP<0flW80`3L
d/h0103MblH0gm?<0=oCc03Odl`20=oLd`<0hMc@0`3PiML0103Mk]d0hN?E0=k[f`3Njm/20=Wbh@04
0=7hiP34n^T0a?[Y0=Cdi@80boSY0P30nN`0102dmnl0Z?C`0:Sdl02mmO020;Cdl`030:camP2Uk_P0
YNkh0080]>kf00<0[^_ho`00002Yj?X00P2ci_L20:oSn@80]N7e0P2bg_H01@2fg?<0/m[d0;?Jm02c
f_@0]]Oa00<0/mGb00@0]M?_0?ooo`3ooooo00005`3oool00ol00000oooo0?ooo`0<0?ooo`?o0000
603oool308VjmP<0O;Oh0P1[/OX305:Xn00603:IlP05O^001GkP001Rb000B/@004W50P0<HMP01010
M=d0EWcL05Ilg01FO=`207N5e0<0QXW?0`2BSL/409b@aP80Y9;300<0XiC60:^G`P2[Ul800P2[Ul84
0;6I_`040;JK_02hW[h0^9jn0;RN_P80_9nl0P2nXkh40<:U_0D0ajZl1@3<[kd40=6e_P80e;_100D0
eKZo0=W1`P3I`L80fL720=c9aP030=c6a080glk800<0h]O<0>7CbP3Sflh00`3Sflh00`3Thm40i>_F
0>;Ue0030>7/f0050=kag03Jm]l0f_KO0=Chh`3Gl^<00P3Bm>L0103<m>X0aoC]0<Odk@39k^d20<C]
l080`>[b00<0`NG`o`00002mh_800P2jgo820;[Kl@80]mSa0P2ge>l20;CBk`80]<o^1`3oool00ol0
0000oooo0?ooo`0=0?ooo`002P3oool00ol00000oooo0?ooo`090?ooo`?o00007P3oool0102X_NP0
ZKgX0:Vmj02Y_NP70:Rmj@030:Nmj@2X_NT0Z;gY00<0YkgZ0P2V_^/00`2V_NX0YKk[0:Fnj`020:Fn
j`80Xkk/00D0Y;k/0::nk@2R_^d0X[k]001?[@0205NXn0@0TkWa102a^N000`2o]]40_KkK0;fnf`02
0;fnf`040<Njc@36`]H0a/;F0<K2eP80cKc:0`3>aM400`3B_/L0dlO>0=?7cP020=?7cP040=C@eP3H
b<X0f<S:0=S8bP80fM;B00<0flW80=cBcP3Ld/h00P3Ld/h20=cLeP030=oCc03Og=<0gmcC0080g^KJ
00D0hMc@0>3Ue`3PiML0h>GG0=g^g@030=Kfh`030<[ji`3Il^40dOSV0080a?[Y0P2en^X20:GfjP05
0<3ik02dmnl0Z?C`0:Sdl02MlO800P2FkO@00`2/lOH0YNkh0:G^n0020:3[nP030:k[n02Yj?[o0000
0080Y^Ck0P2_hoT20:cPn@80/]kf0P2_foL20;?Jm080/=Od0P2ceO840?ooo`03o`00003oool0oooo
01D0oooo00?o00000?ooo`3oool02@3oool3o`0001`0oooo00<0RK[f08bkm@2<^oD01021^OP2072d
nP80FZgj00L0>iod00Z3hP0:Pn802X?R000hZ000BLD0367H00808f_L0P1FO=`306^3f@<0QXW?0`2B
SL/209b@aP0309VBb`2SU<H0XiC60080XiC60`2[Ul830;6I_`030;:L`P2hW[h0^9jn0080^9jn00<0
_9nl0;jS_P2nXkh00P2nXkh20<:U_080a:Vn1037Z[`0103:[kl0c:nm0<b__@3<[kd20=2e`080dKFn
0`3D^l440=W1`P80g<W600H0g<K40=o>b03Oc/P0glk80>;Gc03Th=030>?KcP80i>?A00D0i>_F0>7b
f@3Ql]T0hNcH0=kag0020=[fg`050=Chh`3>n^H0c_[V0=;di`3<m>X00P37m>d20<;bl080_Noc00@0
`>[b0;cWl`2lio?o00000P2jgo820;OKl`80]mSa0P2deO420;CBk`X0oooo00?o00000?ooo`3oool0
3@3oool000X0oooo00?o00000?ooo`3oool01P3oool3o`000280oooo102Y_NP30:Rmj0L0Z;gY00<0
YkgZ0:Nmj@2W_NT00`2V_NX20:Fnj`030:JnjP2T_^`0Y;k/0080Y;k/0P2R_^d0102T_^`0XKk^0:6n
kP0NTn/309>il@80/KWP0P2W`^d40;fnf`030;O8i`36`]H0a/;F0080a/;F00<0cKc:0<k5d@3>aM40
0P3>aM40103=cm/0dlO>0=?7cP3Calh30=C@eP050=S8bP3Id]80fM;B0=WBdP3HgMX00`3Ld/h20=cL
eP80f^ON00<0gmcC0=kVfP3Ni]X00`3Il>400`3PiML0gNkM0=Kfh`020=Kfh`050<[ji`2innP0XoKU
0:?fi@34n^T00P2en^X20:GfjP0309G`j@28jnT0O^K[0080NN?^0P2FkO@01@2AjOL0S^Kj08kVnP2>
i_X0X>_j0080WNOl0P2Lhod01Ol00000Y>3k0:CPn`2Th?/0[>3i0080ZMci0P2_foL20:cHm`80/=Od
1`3oool00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo00H0oooo0ol0000Q0?ooo`80S;_e
0P21^OP01025^_L0MkOj07NgnP1g]oX206:an`80>iod0`0CRnH01000=Zl0053;02=[g00SJm`205Il
g080Jh?I0`1mRM@308f>c`@0VI;;0`2SU<H40:^G`P030;6I_`2bW<80/Yc200@0^9jn1@2nXkh01032
YK`0a:Vn0<BY_P34ZKh30<NZ_0<0bZno00D0c:nm0=2e`03@]L00d;G00=6e_P040=Bk`@030=S3a03I
`L80fL7200<0g<W60`3Oc/P20>;Gc080i>3@00@0hm_>0>CSd@3Thm40i>_F0`3Ql]T0103Mn=`0e__O
0=[fg`3Dn><20<kjiP80aoWY00@0`OS]0;cfl02lm_00`_;`0P2mko<20;W[m@060;cWl`2hho@0^>?d
o`00002egoD0]m_c0P2df?<20;CEl@d0oooo00?o00000?ooo`3oool03@3oool000X0oooo00?o0000
0?ooo`3oool00`3oool3o`0002H0oooo102Y_NP00`2X_NP0ZKgX0:Vmj0070:Rmj@<0YkgY00@0Y[gZ
0:Nmj@2W_NT0YkgY0P2V_^X20:Bnk0<0YKk[0P2T_^`20:6nkP040:>nk@00K<80Mk[k07Njn`@0Yl;]
00<0_KkK0;O8i`2gb>L00P2gb>L20<K2eP80`lcQ0`3>aM430<g?f`030=?7cP3Dd=H0e=3F0080e=3F
0`3Id]830=SMfP030=cBcP3Lg=H0g=cF00<0f^ON00<0do;V0=kVfP3Il>400P3Il>401`3?n>H0___X
0;kkj02nnnP0e_KS0<[ji`2innP00P2Sm^D208g^h00407WUf`1Xg=T0G]KI05[Cg@<0F]?T00@0NN?^
07SQlP1hhO80Nmog0P1og_/208kSo080T>3n0P2Lhod209_Oo@05o`00002Th?/0Xmck0:?Ln`2Yg?T0
0P2XfOT20:cHm`X0oooo00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`030?ooo`?o0000
9@3oool308nlm080QK[g0`1g]oX206:an`<0AJKg0P0PTn`01000=Zl0053;02=[g00SJm`203ifg`80
Jh?I0`1mRM@308f>c`<0VI;;102SU<H20:^G`P030:^JaP2bW<80/Yc20080/Yc20P2hW[h20;VR`P@0
_Z>n1@34ZKh00`37Z[`0bZno0<Z__`020<Z__`@0d;G000@0dkc30=Bk`@3D^l40e;_10P3H`l@00`3I
`L80g<W60=c9aP020=c9aP040>3AbP3Oc/P0h]O<0>;Gc0<0i>3@00<0i>WC0>CSd@3TjmH00`3Ql]T0
0`3Mn=`0e__O0<kmh@020<Gmh`040<kjiP37nNT0aoWY0<7hk@80_?K`0P2gl_<00`2mko<0^N_e0;W[
m@020;KWmP060;SSm02egoD0]Moeo`00002cfo@0]=Sc403oool00ol00000oooo0?ooo`0=0?ooo`00
2@3oool01?l00000oooo0?ooo`3oool3o`0002X0oooo1`2Y_NP01@2X_NT0ZKgX0:Vmj02Y_NP0Z;gY
0080Z;gX0`2X_NT20:Nmj@030:Rmj@2W_^X0YkkZ0080YkkZ0P2U_^/00`2V_^X0YKk[0:Fnj`020:Fn
j`050:>nk@2T_^`0Y;k/05X00017[oP00P2W`^d209?8nP@0]lSW00<0a/;F0<?<h@33c>400P33c>40
103>aM40cLoK0<g?f`3=cm/20<SKi`<0e=3F0P3Bg>00103Id]80f=gJ0=SMfP3HgMX20=CXi0050=cL
eP3Jimh0f^ON0=[WgP3Cl^H00`35nNX00`3Il>40coSV0;kkj0020;kkj0070:Kgi029kM/0K=k@06cN
d01CclH0@L?003Jl_`0202Jac`80?L7H00<0BLOU05O=l01GcO000P1We_<2077GnP80Omkk0P24g?h2
093PoP80T]gn0P2Kgod209cKo@05o`00002Sg?/0X]Wk0:;In`2XfOT03@3oool00ol00000oooo0?oo
o`0D0?ooo`04o`00003oool0oooo0?ooo`?o0000:@3oool309>mm0<0RKcg0P1m^OT306^en`80DJci
0`0_WO401000>kH005cD001Le00nM]l305V0gP<0OHWD0`2=S/l309VBb`80XiC600@0XIS;0:^JaP2[
V/H0Zi[6102bW<80102hW[h0^J;20;VR`P2iX/830;jS_P80`:S21034ZKh50<Z__`030<jf``3@]L00
d;G000<0dkc300D0e;_10=S3a03H`l@0f<?40=c<b@030=c9aP80h=7:0P3Sflh00`3Rel`0i>3@0>CP
d0020>CYd`070>?ae`3Nn=X0g_SJ0>7bf@3Mn=`0e__O0<kmh@020<Gmh`80_OcV00@0]o[Z0;;gkP2b
mnh0_?K`0P2gl_<00`2dk_H0/^[h0;;Zn0020;KWmP80/n;g00@0]Moe0;?Km02cfoCo00004@3oool0
0ol00000oooo0?ooo`0=0?ooo`002@3oool4o`0002l0oooo2@2Y_NP40:Rmj0H0Z;gY0P2W_^X20:Nm
j@<0Y[kZ0P2U_^/00`2V_^/0Y;k/0:Bnk0020:Bnk0030::nk@2T_^`018kH00<0TlSj0P2gb>L30:[B
m@80`lcQ0`2lf>h00`3=cm/0b=_W0<SKi`020<SKi`030=C@eP3Bg>00d]cP00<0bnS[00<0f=gJ0=CX
i03Dj>@00`3:ln`00`3Jimh0do;V0<GijP020<GijP070:gij02;kMd0RngM08_]g@2nnnP0Y_OT0000
000205?0n@80Bkod0P19`O4205o8nP<0H<ci0P1VdOT207?Bo@80N]Om0P23e_l208[Jo`80SmOo0P2E
fOh209SFo@80WMSl00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0D0?ooo`Co0000;@3o
ool00`2C_O@0U[gc09Jml`0308jmmP<0Pk_i0P1c^?/305fbn`80?jKf00@003^f001Le00MJmd07F_M
0P1IP=h30769f`<0QI3F0`2EU=030:6Hb`@0Zi[60P2bW<800`2cXLH0^J;20;VR`P030;VR`P040;jS
_P30Z<80`:S20<2X`P<0a:Vn0P37[l830<Z__`80c[K300<0d;G00=>l``3C_<<00P3C_<<30=S3a0<0
g<c900<0g<W60>3AbP3PdLX00`3Sflh0103Ti]<0i>3@0>CYd`3TjM<20>?ae`030=khfP3FoM/0e_gK
0080`OkL00D0]_cM0:gjh02]n^00_OcV0;OjjP020;;gkP040:odl`2]l?H0[>ci0:c/n@80/^[h0P2`
iOP20;?Rm`050;7MmP3oool0oooo0?ooool000004@3oool00ol00000oooo0?ooo`0=0?ooo`002@3o
ool2o`000340oooo2P2Y_NP20:Rmj080ZKgX1`2X_NT30:Nmj@040:JnjP2W_^T0YkkY0:Nnj@80Y[k[
0P2T_^`20:Fnj`80Y;k/0P0j000306k7o`80Z];e0P2@f?l30;cHkP030:_RnP38fnL0b=_W0080b=_W
0P2nio80103Bg>00bnS[0<_Xj`3;j>/20;cblP050=CXi03:ln`0b_?/0<[ck02en>h00`2Cl>D00`35
nNX0[OWX08_]g@0208_]g@0406GJc01aa_l0LLKo0776o`80JLKn0P1jb?l307C:o`80L<co0P1ncOl3
07g?o`0307oBo`28dOl0R=7o00<0RmCo0P2?eol209CDo@80V=Km103oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo01<0oooo0_l0000a0?ooo`80U[gc00<0S[gf09:mm02B_O@01029_OP2
07bknP<0JKKl0P1?[_X00`00Al807F_M01e[g@0205V0gP80LHWK0`25T=H309FDd0@0XIS;0`2[V/H0
102bW<80/j760;>QaP2cXLH30;VR`P030;^XaP30Z<80`:S200<0`:S200<0a:Vn0<N_`P37[l800P37
[l80103:[kl0c[K30<jf``3>]/<50=>l``030=O5b03H`l@0g<c900<0g<c900<0h=K>0>3AbP3Sflh0
0P3Sflh20>CVd`050>?`e`3TjM<0ho7G0>?ae`3Nn=X00P3FoM/20<7ng0060;Klg@2]n^00[O[P0:Kg
i02Sm^X0X_?`0P2Sl?D00`2]l?H0[>ci0:c/n@020:_VnP80/>Gh0P2^goP00`2agOH0oooo0?ooo`03
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0303oool000/0oooo00?o00000?oo
o`3oool0;`3oool>0:Vmj0<0Z;gX1`2X_NT20:Nnj@030:Rmj@2W_^X0YkkZ0080YkkZ00<0YKk[0:Jn
jP2V_^X00`2U_^/00`2S_^`0<[3/03:`k00203:`k0<0T=So00D0_=S^0:_RnP2[h_X0Zn;j0<SKi`03
0;kWlP<0Y^gi00<0bnS[0;cblP2ll_800`2MlO000`3:ln`0]OS^09?`i@0209?`i@0406KJd02;a?X0
Q<Gm08C5o@80SLGj0`27a_`00`20aoh0RlOl08_7o00308K8o@<0P/_o0P1ncOl208W<oP<0Qlko00D0
R=7o08o?o@2?cod0Slom097Ao@0;0?ooo`03o`00003oool0oooo00h0oooo00?o00000?ooo`3oool0
5@3oool00ol00000oooo0?ooo`0_0?ooo`<0VKkb0P2B_O@208Vmn080S[kf0`23_OT207Bjo080G[Cl
00@004O201e[g@0oNn80?g_R0`1aRM/308F@eP<0UIC@0`2QV</20:^JaP030:ZOb`2cXLH0/j7600<0
/j7600@0^J;20;^XaP2kZ<H0^jS61030Z<840<N_`P030<^ga`3>]/<0c[K30080c[K300@0dKk70=>l
``3C_<<0dkc30P3GaLP0103Kd<d0g<c90=c<b@3Lc<T20>3FcP80h^7C00<0hm_>0>CVd`3Ti]<00P3S
l=L20=ohf@080=KnfP39omP0e_gK0:[hdP2Mm=40U?7D093_fP2?kn8209;_j`040:;cl02Sl?D0Xo3e
0:C/n@80YNOk0P2[i_X20:_QnP80[]oh203oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0
oooo00`0oooo000<0?ooo`03o`00003oool0oooo0300oooo3@2Y_NP00`2X_NP0ZKgX0:Vmj00:0:Rm
j@80YkkZ0P2W_^T30:JnjP040:Fnj`2V_^X0Y[kZ0:JnjP80YKk[0P2S_^d3063>n080Zn;j0`28h_/0
102nio80Y^gi0:K]n@2VkOT207_TkP050;cblP2MlO00WO7`09gal01^gmd00P0i_K`309S2m0<0Tl?g
0P2=aOX209C4m`<0T<Gi00@0RlOl09?6n@2Ca_T0TlKi0P2?ao/308c9o080RLcn0P2Ab_/308o<o080
Slom3P3oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo01H0oooo00?o00000?ooo`3o
ool0;`3oool309^nl@<0U[kc00<0S[kf09>nm@2C__D00`2:__P307jmn`0406fio000F]8005[B03mk
hP<0GhSR0`25T=H309FDd080XIS;00<0WicA0:ZOb`2ZWl/00P2ZWl/30;>QaP030;>Wc02kZ<H0^jS6
0080^jS60`30Z<820<>_aP80ajo20`3;]lL20<jf``<0dKk700@0dkc30=O5b03GaLP0elG80P3Kd<d0
103Lc<T0h=K>0>3FcP3Pe/h20>;Qd`040>;]e`3Ti]<0ho3G0>?`e`80goSI00P0e_kJ0<Wof02ioM@0
^OgD09gdd@2DlM@0T>oJ08o_hP80T^o[00<0U^kc09[[n@2JjoT00P2Nio/01@2Uio/0Y^;k0:KRn`2V
h_/0Zn7j00`0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0<0?ooo`003@3oool0
0ol00000oooo0?ooo`0_0?oooa40ZKgX0P2X_NT20:Vmj0L0Z;gY00<0YkkY0:Rmj@2W_^T00`2W_^T2
0:JnjP030:NnjP2V_^/0Y[k[0080Y[k[00<0Y;k/0:Jnj`2V_^/00`2T_^`20::okP030:Bnk02R_nh0
X[o^0080X[o^0P2O`?0209c1lP80Wl3`0`2L`O80102H`_@0W<7b09c1lP2L`O8209W2m080U<Cg0P2J
`o@309K4m`80TlKi00<0V<Cf09K6n02Fa_P00P2Fa_P209?8nP80TL[k503oool00ol00000oooo0?oo
o`0=0?ooo`03o`00003oool0oooo01L0oooo00?o00000?ooo`3oool0;`3oool00`2K__40W[k_09jn
k`0309VnlP<0Tkke00@0R[kh092omP2@_oH0T;of0P26__T0101i_O`005[B001JdP0JL>0305n8hP80
NY;N0`2?V=P409nLd@@0ZYo;00@0/j760;>Wc02cYl`0/jO<102kZ<H01@30Z<80`jo60<>_aP33[lH0
ajo200@0bkO700<0c[K30=6na`3A_/L00P3A_/L30=O5b0<0fm3=0`3Pe/h20>;Qd`80h^gG00H0g_OJ
0>?`e`3On=T0goSI0=KnfP39omP20;Wme00307CP`P1chL/0MnCG0080O^OT00@0QnW_093Ym`2Gi_`0
UnKl0P2Nio/00`2Rh_`0oooo0?ooo`0?0?ooo`03o`00003oool0oooo00d0oooo00?o00000?ooo`3o
ool0303oool000h0oooo0_l0000`0?oooa@0ZKgX102X_NP60:Rmj@80YkkY00<0Z;gY0:NnjP2W_^X0
0P2W_^X20:Jnj`030:NnjP2V_^/0Y[k[0080Y[k[00<0Y;k/0:Fnj`2U_^/00`2T_^`20::okP80Y;o]
0`2R_nh00`2O`?00X[o^09o0l00309o0l080W<7b00<0Wl7`09g2lP2M`_800P2M`_800`2J`o@0W/;b
09k2lP0309_3m0<0V<Cf0P2Fa_PJ0?ooo`03o`00003oool0oooo00`0oooo00?o00000?ooo`3oool0
603oool2o`000300oooo0`2N_^l0102I__80W;oa09bol@2L_o4209Nol`80T;of00<0UKod08fon02=
_oP00P2=_oP00`23_o/004:i01Y`h00305n8hP80NY;N0`2?V=P409nLd@80ZYo;00<0ZJGB0;>Wc02c
Yl`00P2cYl`30;^XaP030;f_c033[lH0`jo60080`jo61@3;]lL0103>`<d0dKk70=6na`3A_/L20=G8
c@040=O5b03Kd<d0fm3=0=_@c@80g]cC00<0h=K>0>;Qd`3RhM<00P3RkML01@3NmmX0eOkJ0=GnfP35
omH0/?[>0080Vo;600H0Dlfh05cDb@1Le<T0JMcK07ORj`24iOH208oTo080UnKl00<0W>;m0?ooo`3o
ool04`3oool00ol00000oooo0?ooo`0<0?ooo`03o`00003oool0oooo00`0oooo000@0?ooo`03o`00
003oool0oooo02l0oooo4`2Y_NP20:Rmj080ZKgX2@2X_NT20:NnjP80Z;kY0`2W_^X20:Jnj`80YkkZ
00<0YKk[0:JnjP2V_^X00`2U_^/20:Bok@030:Fnj`2T_nd0Y;o]0080Y;o]0P2R_nh209o0l080X/3^
0`2O`O0209g2lP80X<7`0`2N`_800`2K`o@0oooo0?ooo`0O0?ooo`03o`00003oool0oooo00/0oooo
00?o00000?ooo`3oool06P3oool00ol00000oooo0?ooo`0^0?ooo`<0X;k^0P2L_o400`2N_nl0V[ob
09ZolP0209ZolP80UKod0P2=_oP209?0mP80Rl3i00<005gA04B4j014Q>P00`1YTnL308nHf080WicA
00<0Vj;J0:VUdP2YYM800P2YYM840;>Wc0040;^XaP2m[l`0_Jo<0;f_c080`jo60P36^<d30<^ga`<0
c/3=00@0dKk70=G8c@3Eb<d0eLS=0P3Ie=@0103Kd<d0g]cC0=kLd`3Ng=<20=oXf@030=geg@3RkML0
g_OJ0080eOkJ00@0aOoF0;3jcP1NcZH000000`1`fo<00`1jh?@0R>7l09;NoP0209;NoP0309OPoP3o
ool0oooo01L0oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`0<0?ooo`004@3oool0
0ol00000oooo0?ooo`0_0?oooaX0ZKgX0P2X_NT00`2X_NP0Z;gY0:Rmj@020:Rmj@030:Rnj@2X_NT0
Z;gY00<0YkkY0P2W_^X00`2W_^T0Y[kZ0:JnjP020:JnjP030:Fnj`2V_^/0Y[k[00<0YKk[0P2T_nd0
0`2U_^`0Y;o]0:Bok@020:Bok@030:;0kP2T_nd0Y;o]00<0X/3^0P2P`O0W0?ooo`03o`00003oool0
oooo00X0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`0^0?ooo`040:2nkP2R_^h0
X[k^0::nkP80W[o_0P2J_o8209fol0<0VL3c00<0Tl3f09S0l`2H`?<00P2B`OL00`00GM40A8CX04B4
j00206VCi`<0QYgR102KX]X40:VUdP80/jO<00<0]:oC0;f_c02m[l`00P2m[l`00`33[lH0a[S=0<Jh
c@020<Jhc@030<^ga`3>`<d0c/3=0080c/3=0`3Eb<d30=WDe0<0g]cC0P3Oj=T20=geg@030=?mg@30
o]L0`?kG0080R^Rk00@0D<cQ06[Gl`1mfo`0OM_l0P22g_`208kLo`80T]kn703oool00ol00000oooo
0?ooo`0:0?ooo`03o`00003oool0oooo00`0oooo000B0?ooo`03o`00003oool0oooo02l0oooo6P2Y
_NP30:Rmj0L0Z;gY00@0YkkY0:Rmj@2X_NT0Z;gY0P2W_^T20:JnjP80YkkZ0`2V_^/0102U_^/0Y[k[
0:Jnj`2V_^/20:Fnk080Y;o]0P2U_n`30:Bok@030:;0kP3oool0oooo02P0oooo00?o00000?ooo`3o
ool02`3oool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo02h0oooo0P2R_^h00`2S_^d0
XKo^0:6okP020:6okP0309fol02P_nl0X;o_00<0W;oa0`2H`?<00`2B`OL0Ul7d0011[`0201aji@80
JI?W0`26WN8409^RfP80ZJGB00<0YjkL0;B_d`2d[m<00P2d[m<20;f_c080_kWD0`36^<d20<W3e0<0
c/3=0P3Bc=@0103Eb<d0fMCD0=WDe03Ie=@20=_Rf`030=kLd`3Oj=T0gnSI0080gOGM0P3CoMd01030
o]L0R^Rk08[X^`1kf?d308[Go`0308cJo`3oool0oooo0200oooo00?o00000?ooo`3oool02`3oool0
0ol00000oooo0?ooo`0;0?ooo`004`3oool2o`000300oooo6P2Y_NP01@2X_NP0ZKgX0:Vmj02Y_NP0
Z;gY0080ZKgX1P2X_NT40:Rnj@030:NnjP2X_^T0YkkZ00<0YkkZ0P2V_^/0102W_^X0Y[k[0:Jnj`2V
_^/20:Fok300oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0L0?ooo`;o0000<03o
ool20:>nk@80XKo^0P2R_nd30:2ok`0409bol@2O_nl0Wko_09nok`80W<3b0P2G`O@00`2K`O8077[U
04fBk`0204fBk`<0QYgR0P2KX]X00`2CZ^D0YjkL0:N^g0020:N^g0<0]:oC00<0_Jo<0;nie02o^M@0
0P2o^M@00`36^<d0bL?D0<W3e0020<W3e0040<k0c@3Bc=@0d/cD0=;<e080e=[M00<0fMCD0=_Rf`3K
h]/00`3IlN401P3@nn<0gOGM0=?mg@3CoMd0`?kG000000<0R]Go0P2:eolU0?ooo`03o`00003oool0
oooo00X0oooo00?o00000?ooo`3oool02`3oool001D0oooo00?o00000?ooo`3oool0;`3ooolP0:Vm
j0030:Rmj@2Y_NP0ZKgX00<0Z;gY0P2X_^T20:Rmj@80Z;kY0P2W_^X20:Rnj@<0YkkZ00<0Y[k[0?oo
o`3oool0<P3oool00ol00000oooo0?ooo`090?ooo`03o`00003oool0oooo01h0oooo00?o00000?oo
o`3oool0;P3oool30:Bnk0030::ok@2T_^`0Y;k/00<0X[o^0P2O_nl00`2Q_nh0Wl3`09o0l00209o0
l080Vl7b00<006C@04fBk`1=T^l00`1fX^d409>Zi@<0YjkL0P2d[m<20;BjgP<0_kWD0P30aMh30<W3
e0040<_AgP3Bc=@0d/cD0=;<e0<0e=[M00<0dn[U0=_Rf`3IlN400P3IlN401P3@nn<0^ogL0;_mg02K
l/X0SM3n08_Bob`0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0;0?ooo`005P3o
ool00ol00000oooo0?ooo`0^0?ooobL0ZKgX0P2X_NT00`2X_NP0Z;gY0:Rmj@020:Rmj@030:Rnj@3o
ool0oooo03P0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`0O0?ooo`03o`00003o
ool0oooo02h0oooo00@0Y;k/0:Fnj`2U_^/0YKk[0P2T_^`0102R_nh0Xko]0:>ok@2S_nd20:6okP80
Wl3`0P2Q_nh309k0l0030013Y@0RR>/0MZ;]0080MZ;]0`2CZ^D20:N^g080X[SY102d^]h00`2o^M@0
`<GN0<35gP020<35gP050<W3e03;dMh0bm7N0<_AgP3Bc=@00`3Df]d01P3Cj^D0b_SY0<[hj@3:n>T0
fO7Q0=3kh`80^ogL<@3oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo00/0oooo000G
0?ooo`03o`00003oool0oooo02h0oooo9`2Y_NP30:Rmj080Z;gY?03oool00ol00000oooo0?ooo`08
0?ooo`03o`00003oool0oooo0200oooo00?o00000?ooo`3oool0;P3oool20:Fnj`040:Jnj`2U_^/0
YKk[0:Fnj`80Xko]00<0YKk/0:>ok@2S_nd00P2S_nd00`2Q_nh0Xko]0:>ok@030:70k`80W/7a00<0
06o?05^TmP1KY?H00`26/o<40::hj@80];[N0P2aan/30<35gP040;kEj`3;dMh0bm7N0<_AgP<0b^7Y
00<0e=[M0=?Zi@3:n>T00P3:n>T00`2dnn<0Snk>08o^cP0c0?ooo`03o`00003oool0oooo00P0oooo
00?o00000?ooo`3oool02`3oool001P0oooo0_l0000`0?ooobH0ZKgX00<0Z;gX0?ooo`3oool0?P3o
ool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo0240oooo0_l0000`0?ooo`80Y[k[00@0
YKk[0:Jnj`2V_^/0Y[k[0P2U_^`20:>ok@80YKo/0`2S_nd01@2Q`>l0Xko]0:>ok@2S_nd0XL3_0080
C@0000@0;I_`08Jcl`26/o<0Q[?c0P2R^>T209O5m`@0/LO[00D0`<GN0;kEj`2neN/0_]G[0<_AgP03
0<[Qj@070<;`l02/mnd0[?O]0:cgk@3:n>T0]?_S0000000f0?ooo`03o`00003oool0oooo00L0oooo
00?o00000?ooo`3oool02`3oool001X0oooo00?o00000?ooo`3oool0;@3ooolR0:Vmj4H0oooo00?o
00000?ooo`3oool01`3oool00ol00000oooo0?ooo`0R0?ooo`03o`00003oool0oooo02d0oooo0`2W
_^X20:Jnj`030:NnjP2V_^/0Y[k[0080Y[k[00<0YKo/0:Jnj`2V_^/00`2U_n`20:>ok@050:Fok02S
`>d0Xl3]0:?0k@2Q`Nl00P00O/`306^io0<0UlGg0P2aan/20:SFn080_]G[0`2giOH00`3:hNT0`_3`
0:cgk@020:cgk@0308;YeP3oool0oooo03P0oooo00?o00000?ooo`3oool01`3oool00ol00000oooo
0?ooo`0:0?ooo`006`3oool00ol00000oooo0?ooo`0]0?oooal0ZKgXB@3oool00ol00000oooo0?oo
o`060?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3oool0;@3oool0102W_^X0YkkY0:Nn
j@2W_^T20:NnjP80Y[k[0P2W_^X30:Jnj`040:Fok02V_^/0Y[k[0:Jnj`80YKo/00@0Xl3]0:Fok02U
_n`0YKo/0P2S`>d303bal`<0O/ko0P2Xe_P3093Qo@80]nGf00@0Wnkg07?Rh01ch^00>[fb?P3oool0
0ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo00X0oooo000L0?ooo`03o`00003oool0oooo
02h0oooo602Y_NQ>0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool0903oool00ol0
0000oooo0?ooo`0^0?ooo`030:Nnj@2X_^T0YkkZ00T0YkkZ0P2V_^/0102W_^/0Y[o[0:Joj`2V_n/2
0:Fok080Y[o[0`2U_n`00`2T`>d0oooo0?ooo`0304o5l@80T>7m00<0H]KZ02F_^@0U[kT0@P3oool0
0ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo00X0oooo000M0?ooo`03o`00003oool0oooo
02h0oooo502Y_NQB0?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool09@3oool00ol0
0000oooo0?ooo`0^0?ooo`80Z;kY0P2W_^X20:Rnj@H0YkkZ0`2W_^/01@2V_n/0Ykk[0:Nnj`2W_^/0
Y[o[0580oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0:0?ooo`007P3oool2o`00
02l0oooo4@2Y_NQE0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool09P3oool2o`00
02h0oooo2P2X_^T0102W_^X0Z;kY0:Rnj@2X_^T20:NnjP80Ykk[E@3oool00ol00000oooo0?ooo`04
0?ooo`03o`00003oool0oooo00X0oooo000P0?ooo`03o`00003oool0oooo02d0oooo2`2Y_NQJ0?oo
o`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0:03oool00ol00000oooo0?ooo`0/0?oo
o`80Z;kY0P2X_NT80:RnjEX0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0:0?oo
o`008@3oool00ol00000oooo0?ooo`0]0?ooo`P0ZKgXG@3oool00ol00000oooo0?ooo`030?ooo`03
o`00003oool0oooo02T0oooo00?o00000?ooo`3oool0;@3oool00`2X_NT0ZKgX0:Vmj0030:Rmj@03
0:Rnj@3oool0oooo05`0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0:0?ooo`00
8P3oool00ol00000oooo0?ooo`0]0?ooo`@0ZKgXH@3oool00ol00000oooo0?ooo`030?ooo`03o`00
003oool0oooo02T0oooo00?o00000?ooo`3oool0;@3oool30:Vmj0030:Rmj@3oool0oooo05l0oooo
00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`090?ooo`008`3oool2o`0002d0oooo00?o
00000?ooo`3oool0H`3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo02X0oooo0_l0
000]0?ooo`03o`00003oool0oooo06<0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?oo
o`090?ooo`009@3oool00ol00000oooo0?ooo`0Z0?ooo`03o`00003oool0oooo06<0oooo00?o0000
0?ooo`3oool00P3oool00ol00000oooo0?ooo`0/0?ooo`03o`00003oool0oooo02X0oooo00?o0000
0?ooo`3oool0H`3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo00T0oooo000V0?oo
o`03o`00003oool0oooo02T0oooo00?o00000?ooo`3oool0I03oool01Ol00000oooo0?ooo`3ooooo
000002l0oooo00?o00000?ooo`3oool0:@3oool00ol00000oooo0?ooo`1T0?ooo`05o`00003oool0
oooo0?ooool000002`3oool002L0oooo00?o00000?ooo`3oool0:03oool00ol00000oooo0?ooo`1U
0?ooo`04o`00003oool0ooooo`000300oooo00?o00000?ooo`3oool0:03oool00ol00000oooo0?oo
o`1U0?ooo`04o`00003oool0ooooo`0000/0oooo000X0?ooo`;o0000:03oool00ol00000oooo0?oo
o`1V0?ooo`03o`00003ooooo00000340oooo0_l0000X0?ooo`03o`00003oool0oooo06H0oooo00?o
00000?ooool000002`3oool002X0oooo00?o00000?ooo`3oool09@3oool00ol00000oooo0?ooo`1V
0?ooo`03o`00003ooooo000003<0oooo00?o00000?ooo`3oool09@3oool00ol00000oooo0?ooo`1V
0?ooo`03o`00003ooooo000000/0oooo000[0?ooo`03o`00003oool0oooo02@0oooo00?o00000?oo
o`3oool0I`3oool00ol00000ooooo`00000c0?ooo`03o`00003oool0oooo02@0oooo00?o00000?oo
o`3oool0I`3oool00ol00000ooooo`00000:0?ooo`00;03oool00ol00000oooo0?ooo`0S0?ooo`03
o`00003oool0oooo06P0oooo0_l0000d0?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3o
ool0J03oool2o`0000X0oooo000]0?ooo`;o00008`3oool00ol00000oooo0?ooo`1W0?ooo`?o0000
=@3oool2o`0002<0oooo00?o00000?ooo`3oool0I`3oool3o`0000X0oooo000_0?ooo`03o`00003o
ool0oooo0200oooo00?o00000?ooo`3oool0H`3oool4o`0003X0oooo00?o00000?ooo`3oool0803o
ool00ol00000oooo0?ooo`1S0?ooo`Co00003@3oool00300oooo00?o00000?ooo`3oool07`3oool0
0ol00000oooo0?ooo`1P0?ooo`?o0000?`3oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0
oooo0600oooo0ol0000A0?ooo`00<@3oool00ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo
05`0oooo1?l000130?ooo`03o`00003oool0oooo01h0oooo00?o00000?ooo`3oool0G03oool4o`00
01@0oooo000b0?ooo`;o00007P3oool00ol00000oooo0?ooo`1H0?ooo`Co0000B03oool2o`0001h0
oooo00?o00000?ooo`3oool0F03oool4o`0001P0oooo000d0?ooo`03o`00003oool0oooo01/0oooo
00?o00000?ooo`3oool0E03oool4o`0004h0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo
0?ooo`1D0?ooo`Co0000703oool003D0oooo00?o00000?ooo`3oool06P3oool00ol00000oooo0?oo
o`1A0?ooo`?o0000D`3oool00ol00000oooo0?ooo`0J0?ooo`03o`00003oool0oooo0540oooo0ol0
000P0?ooo`00=P3oool00ol00000oooo0?ooo`0I0?ooo`03o`00003oool0oooo04d0oooo1?l0001G
0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool0C@3oool4o`0002<0oooo000g0?oo
o`;o00006@3oool00ol00000oooo0?ooo`190?ooo`Co0000G03oool2o`0001T0oooo00?o00000?oo
o`3oool0B@3oool4o`0002L0oooo000i0?ooo`03o`00003oool0oooo01H0oooo00?o00000?ooo`3o
ool0A@3oool4o`000680oooo00?o00000?ooo`3oool05P3oool00ol00000oooo0?ooo`150?ooo`Co
0000:`3oool003X0oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?ooo`130?ooo`?o0000
I`3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo04<0oooo0ol0000_0?ooo`00>`3o
ool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo03l0oooo1?l0001[0?ooo`03o`00003o
ool0oooo01<0oooo00?o00000?ooo`3oool0?`3oool4o`000380oooo000l0?ooo`;o00004`3oool0
0ol00000oooo0?ooo`0k0?ooo`Co0000L03oool2o`0001<0oooo00?o00000?ooo`3oool0>`3oool4
o`0003H0oooo000n0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool0=`3oool4o`00
07H0oooo00?o00000?ooo`3oool0403oool00ol00000oooo0?ooo`0g0?ooo`Co0000>P3oool003l0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?ooo`Co0000N`3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo1?l0000n0?ooo`00@03oool00ol00000oooo
0?ooo`0>0?ooo`03o`00003oool0oooo0300oooo0ol000200?ooo`03o`00003oool0oooo00h0oooo
00?o00000?ooo`3oool0<03oool3o`000480oooo00110?ooo`03o`00003oool0oooo00d0oooo00?o
00000?ooo`3oool0;03oool4o`0008@0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?oo
o`0/0?ooo`Co0000A@3oool00480oooo0_l0000=0?ooo`03o`00003oool0oooo02P0oooo1?l00029
0?ooo`;o00003@3oool00ol00000oooo0?ooo`0X0?ooo`Co0000B@3oool004@0oooo00?o00000?oo
o`3oool02P3oool00ol00000oooo0?ooo`0T0?ooo`Co0000S`3oool00ol00000oooo0?ooo`0:0?oo
o`03o`00003oool0oooo02@0oooo1?l0001=0?ooo`00A@3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo0240oooo0ol0002D0?ooo`03o`00003oool0oooo00T0oooo00?o00000?ooo`3o
ool08@3oool3o`000540oooo00160?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool0
7@3oool4o`0009P0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`0M0?ooo`Co0000
E03oool004L0oooo0_l000080?ooo`03o`00003oool0oooo01T0oooo1?l0002M0?ooo`;o0000203o
ool00ol00000oooo0?ooo`0I0?ooo`Co0000F03oool004T0oooo00?o00000?ooo`3oool01@3oool0
0ol00000oooo0?ooo`0E0?ooo`Co0000X`3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0
oooo01D0oooo1?l0001L0?ooo`00BP3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo
0180oooo0ol0002X0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool04P3oool3o`00
0600oooo001;0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool03P3oool4o`000:`0
oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0>0?ooo`Co0000H`3oool004`0oooo
0_l000030?ooo`03o`00003oool0oooo00X0oooo1?l0002a0?ooo`;o00000`3oool00ol00000oooo
0?ooo`0:0?ooo`Co0000I`3oool004h0oooo00Co00000?ooo`3ooooo0000203oool4o`000;L0oooo
00Co00000?ooo`3ooooo0000203oool4o`0006/0oooo001?0?ooo`03o`00003ooooo000000D0oooo
0ol0002l0?ooo`03o`00003ooooo000000D0oooo0ol0001_0?ooo`00D03oool2o`0000030?ooool0
003o000000;o0000`03oool2o`0000030?ooool0003o000000;o0000LP3oool00540oooo0_l00035
0?ooo`;o0000MP3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-53.3508, \
-19.1129, 1.80794, 1.80794}, {{208.5, 389.375}, {315.688, 169}} -> {-412.962, \
-19.1129, 1.80794, 1.80794}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification in 2d", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, 
        gbase, Axes \[Rule] False, Frame \[Rule] True, \ 
        FrameTicks \[Rule] False, yS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.80217 4e-05 m
.80218 4e-05 L
.80219 4e-05 L
.8022 4e-05 L
.8022 4e-05 L
.80221 4e-05 L
.80222 4e-05 L
.80222 4e-05 L
.80223 4e-05 L
.80224 4e-05 L
.80224 4e-05 L
.80225 4e-05 L
.80226 4e-05 L
.80227 4e-05 L
.80227 4e-05 L
.80228 4e-05 L
.80228 4e-05 L
.80229 4e-05 L
.80229 4e-05 L
.8023 4e-05 L
.80231 4e-05 L
.80231 4e-05 L
.80231 4e-05 L
.80232 4e-05 L
.80232 4e-05 L
.80233 4e-05 L
.80233 4e-05 L
.80234 4e-05 L
.80235 4e-05 L
.80236 4e-05 L
.80236 4e-05 L
.80237 4e-05 L
.80238 4e-05 L
.80238 4e-05 L
.80239 4e-05 L
.8024 4e-05 L
.80241 4e-05 L
.80241 4e-05 L
.80242 4e-05 L
.80242 4e-05 L
.80243 4e-05 L
.80243 4e-05 L
.80244 4e-05 L
.80244 4e-05 L
.80245 4e-05 L
.80246 4e-05 L
.80246 4e-05 L
.80247 4e-05 L
.80247 4e-05 L
.80248 4e-05 L
Mistroke
.80248 4e-05 L
.80249 4e-05 L
.80249 4e-05 L
.8025 4e-05 L
.8025 4e-05 L
.80251 4e-05 L
.80251 4e-05 L
.80252 4e-05 L
.80252 4e-05 L
.80252 4e-05 L
.80253 4e-05 L
.80253 4e-05 L
.80254 4e-05 L
.80255 4e-05 L
.80255 4e-05 L
.80256 4e-05 L
.80256 4e-05 L
.80257 4e-05 L
.80258 4e-05 L
.80259 4e-05 L
.80259 4e-05 L
.8026 4e-05 L
.8026 4e-05 L
.80261 4e-05 L
.80262 4e-05 L
.80262 4e-05 L
.80262 4e-05 L
.80263 4e-05 L
.80264 4e-05 L
.80264 4e-05 L
.80265 4e-05 L
.80265 4e-05 L
.80266 4e-05 L
.80267 4e-05 L
.80268 4e-05 L
.80268 4e-05 L
.80269 4e-05 L
.8027 4e-05 L
.8027 4e-05 L
.80271 4e-05 L
.80272 4e-05 L
.80272 4e-05 L
.80273 4e-05 L
.80274 4e-05 L
.80274 4e-05 L
.80274 4e-05 L
.80275 4e-05 L
.80275 4e-05 L
.80276 4e-05 L
.80277 4e-05 L
Mistroke
.80277 4e-05 L
.80278 4e-05 L
.80278 4e-05 L
.80279 4e-05 L
.8028 4e-05 L
.80281 4e-05 L
.80281 4e-05 L
.80282 4e-05 L
.80283 4e-05 L
.80283 4e-05 L
.80284 4e-05 L
.80285 4e-05 L
.80285 4e-05 L
.80286 4e-05 L
.80287 4e-05 L
.80288 4e-05 L
.80288 4e-05 L
.80289 4e-05 L
.8029 4e-05 L
.8029 4e-05 L
.80291 4e-05 L
.80291 4e-05 L
.80292 4e-05 L
.80293 4e-05 L
.80294 4e-05 L
.80294 4e-05 L
.80295 4e-05 L
.80296 4e-05 L
.80297 4e-05 L
.80297 4e-05 L
.80298 4e-05 L
.80299 4e-05 L
.803 4e-05 L
.803 4e-05 L
.80301 4e-05 L
.80302 4e-05 L
.80302 4e-05 L
.80303 4e-05 L
.80304 4e-05 L
.80304 4e-05 L
.80305 4e-05 L
.80306 4e-05 L
.80306 4e-05 L
.80307 4e-05 L
.80308 4e-05 L
.80308 4e-05 L
.80309 4e-05 L
.8031 4e-05 L
.8031 4e-05 L
.80311 4e-05 L
Mistroke
.80312 4e-05 L
.80313 4e-05 L
.80313 4e-05 L
.80313 4e-05 L
.80314 4e-05 L
.80315 4e-05 L
.80316 4e-05 L
.80317 4e-05 L
.80317 4e-05 L
.80318 4e-05 L
.80319 4e-05 L
.80319 4e-05 L
.8032 4e-05 L
.80321 4e-05 L
.80322 4e-05 L
.80322 4e-05 L
.80323 4e-05 L
.80324 4e-05 L
.80325 4e-05 L
.80325 4e-05 L
.80326 4e-05 L
.80326 4e-05 L
.80327 4e-05 L
.80328 4e-05 L
.80328 4e-05 L
.80329 4e-05 L
.8033 4e-05 L
.80331 4e-05 L
.80331 4e-05 L
.80332 4e-05 L
.80333 4e-05 L
.80333 4e-05 L
.80334 4e-05 L
.80335 4e-05 L
.80335 4e-05 L
.80336 4e-05 L
.80337 4e-05 L
.80337 4e-05 L
.80338 4e-05 L
.80338 4e-05 L
.80339 4e-05 L
.8034 4e-05 L
.80341 4e-05 L
.80342 4e-05 L
.80342 4e-05 L
.80343 4e-05 L
.80344 4e-05 L
.80344 4e-05 L
.80345 4e-05 L
.80346 4e-05 L
Mistroke
.80347 4e-05 L
.80347 4e-05 L
.80348 4e-05 L
.80349 4e-05 L
.80349 4e-05 L
.8035 4e-05 L
.80351 4e-05 L
.80351 4e-05 L
.80352 4e-05 L
.80353 4e-05 L
.80353 4e-05 L
.80354 4e-05 L
.80355 4e-05 L
.80355 4e-05 L
.80356 4e-05 L
.80357 4e-05 L
.80358 4e-05 L
.80358 4e-05 L
.80359 4e-05 L
.8036 4e-05 L
.8036 4e-05 L
.80361 4e-05 L
.80361 4e-05 L
.80362 4e-05 L
.80363 4e-05 L
.80364 4e-05 L
.80364 4e-05 L
.80365 4e-05 L
.80366 4e-05 L
.80366 4e-05 L
.80367 4e-05 L
.80368 4e-05 L
.80369 4e-05 L
.8037 4e-05 L
.8037 4e-05 L
.80371 4e-05 L
.80372 4e-05 L
.80372 4e-05 L
.80373 4e-05 L
.80373 4e-05 L
.80374 4e-05 L
.80375 4e-05 L
.80376 4e-05 L
.80376 4e-05 L
.80377 4e-05 L
.80378 4e-05 L
.80378 4e-05 L
.80379 4e-05 L
.8038 4e-05 L
.8038 4e-05 L
Mistroke
.80381 4e-05 L
.80382 4e-05 L
.80383 4e-05 L
.80383 4e-05 L
.80384 4e-05 L
.80384 4e-05 L
.80385 4e-05 L
.80386 4e-05 L
.80386 4e-05 L
.80387 4e-05 L
.80387 4e-05 L
.80388 4e-05 L
.80389 4e-05 L
.80389 4e-05 L
.8039 4e-05 L
.80391 4e-05 L
.80392 4e-05 L
.80392 4e-05 L
.80393 4e-05 L
.80393 4e-05 L
.80394 4e-05 L
.80394 4e-05 L
.80395 4e-05 L
.80396 4e-05 L
.80396 4e-05 L
.80397 4e-05 L
.80398 4e-05 L
.80399 4e-05 L
.80399 4e-05 L
.804 4e-05 L
.80401 4e-05 L
.80401 4e-05 L
.80402 4e-05 L
.80403 4e-05 L
.80403 4e-05 L
.80404 4e-05 L
.80405 4e-05 L
.80406 4e-05 L
.80406 4e-05 L
.80407 4e-05 L
.80408 4e-05 L
.80409 4e-05 L
.80409 4e-05 L
.8041 4e-05 L
.80411 4e-05 L
.80411 4e-05 L
.80412 4e-05 L
.80412 4e-05 L
.80413 4e-05 L
.80413 4e-05 L
Mistroke
.80414 4e-05 L
.80415 4e-05 L
.80416 4e-05 L
.80416 4e-05 L
.80417 4e-05 L
.80418 4e-05 L
.80418 4e-05 L
.80419 4e-05 L
.8042 4e-05 L
.80421 4e-05 L
.80421 4e-05 L
.80422 4e-05 L
.80423 4e-05 L
.80424 4e-05 L
.80424 4e-05 L
.80425 4e-05 L
.80426 4e-05 L
.80426 4e-05 L
.80427 4e-05 L
.80427 4e-05 L
.80428 4e-05 L
.80428 4e-05 L
.80429 4e-05 L
.80429 4e-05 L
.8043 4e-05 L
.8043 4e-05 L
.80431 4e-05 L
.80431 4e-05 L
.80432 4e-05 L
.80432 4e-05 L
.80433 4e-05 L
.80433 4e-05 L
.80434 4e-05 L
.80434 4e-05 L
.80435 4e-05 L
.80436 4e-05 L
.80437 4e-05 L
.80438 4e-05 L
.80438 4e-05 L
.80439 4e-05 L
.8044 4e-05 L
.8044 4e-05 L
.80441 4e-05 L
.80442 4e-05 L
.80443 4e-05 L
.80443 4e-05 L
.80444 4e-05 L
.80445 4e-05 L
.80445 4e-05 L
.80446 4e-05 L
Mistroke
.80447 4e-05 L
.80447 4e-05 L
.80448 4e-05 L
.80449 4e-05 L
.80449 4e-05 L
.8045 4e-05 L
.80451 4e-05 L
.80451 4e-05 L
.80452 4e-05 L
.80453 4e-05 L
.80454 4e-05 L
.80454 4e-05 L
.80455 4e-05 L
.80456 4e-05 L
.80456 4e-05 L
.80457 4e-05 L
.80457 4e-05 L
.80458 4e-05 L
.80459 4e-05 L
.8046 4e-05 L
.8046 4e-05 L
.80461 4e-05 L
.80462 4e-05 L
.80462 4e-05 L
.80463 4e-05 L
.80464 4e-05 L
.80465 4e-05 L
.80465 4e-05 L
.80466 4e-05 L
.80467 4e-05 L
.80468 4e-05 L
.80468 4e-05 L
.80469 4e-05 L
.80469 4e-05 L
.8047 4e-05 L
.80471 4e-05 L
.80472 4e-05 L
.80472 4e-05 L
.80473 4e-05 L
.80474 4e-05 L
.80474 4e-05 L
.80475 4e-05 L
.80476 4e-05 L
.80476 4e-05 L
.80477 4e-05 L
.80478 4e-05 L
.80479 4e-05 L
.80479 4e-05 L
.8048 4e-05 L
.8048 4e-05 L
Mistroke
.80481 4e-05 L
.80482 4e-05 L
.80482 4e-05 L
.80483 4e-05 L
.80483 4e-05 L
.80484 4e-05 L
.80485 4e-05 L
.80485 4e-05 L
.80486 4e-05 L
.80487 4e-05 L
.80488 4e-05 L
.80488 4e-05 L
.80489 4e-05 L
.80489 4e-05 L
.8049 4e-05 L
.8049 4e-05 L
.80491 4e-05 L
.80492 4e-05 L
.80492 4e-05 L
.80493 4e-05 L
.80494 4e-05 L
.80494 4e-05 L
.80495 4e-05 L
.80496 4e-05 L
.80496 4e-05 L
.80497 4e-05 L
.80498 4e-05 L
.80499 4e-05 L
.80499 4e-05 L
.805 4e-05 L
.80501 4e-05 L
.80502 4e-05 L
.80502 4e-05 L
.80503 4e-05 L
.80504 4e-05 L
.80504 4e-05 L
.80505 4e-05 L
.80506 4e-05 L
.80507 4e-05 L
.80507 4e-05 L
.80508 4e-05 L
.80508 4e-05 L
.80509 4e-05 L
.80509 4e-05 L
.8051 4e-05 L
.80511 4e-05 L
.80512 4e-05 L
.80512 4e-05 L
.80513 4e-05 L
.80514 4e-05 L
Mistroke
.80514 4e-05 L
.80515 4e-05 L
.80516 4e-05 L
.80517 4e-05 L
.80517 4e-05 L
.80518 4e-05 L
.80519 4e-05 L
.8052 4e-05 L
.8052 4e-05 L
.80521 4e-05 L
.80522 4e-05 L
.80522 4e-05 L
.80523 4e-05 L
.80523 4e-05 L
.80524 4e-05 L
.80524 4e-05 L
.80525 4e-05 L
.80525 4e-05 L
.80526 4e-05 L
.80526 4e-05 L
.80527 4e-05 L
.80527 4e-05 L
.80528 4e-05 L
.80528 4e-05 L
.80528 4e-05 L
.80529 4e-05 L
.8053 4e-05 L
.8053 4e-05 L
.80531 4e-05 L
.80532 4e-05 L
.80533 4e-05 L
.80533 4e-05 L
.80534 4e-05 L
.80535 4e-05 L
.80536 4e-05 L
.80536 4e-05 L
.80537 4e-05 L
.80538 4e-05 L
.80539 4e-05 L
.80539 4e-05 L
.8054 4e-05 L
.80541 4e-05 L
.80541 4e-05 L
.80542 4e-05 L
.80543 4e-05 L
.80543 4e-05 L
.80544 4e-05 L
.80545 4e-05 L
.80545 4e-05 L
.80546 4e-05 L
Mistroke
.80547 4e-05 L
.80547 4e-05 L
.80548 4e-05 L
.80549 4e-05 L
.8055 4e-05 L
.8055 4e-05 L
.80551 4e-05 L
.80552 4e-05 L
.80552 4e-05 L
.80552 4e-05 L
.80553 4e-05 L
.80554 4e-05 L
.80555 4e-05 L
.80556 4e-05 L
.80556 4e-05 L
.80557 4e-05 L
.80558 4e-05 L
.80558 4e-05 L
.80559 4e-05 L
.8056 4e-05 L
.80561 4e-05 L
.80561 4e-05 L
.80562 4e-05 L
.80563 4e-05 L
.80564 4e-05 L
.80564 4e-05 L
.80565 4e-05 L
.80565 4e-05 L
.80566 4e-05 L
.80567 4e-05 L
.80568 4e-05 L
.80568 4e-05 L
.80569 4e-05 L
.8057 4e-05 L
.8057 4e-05 L
.80571 4e-05 L
.80572 4e-05 L
.80572 4e-05 L
.80573 4e-05 L
.80574 4e-05 L
.80574 4e-05 L
.80575 4e-05 L
.80576 4e-05 L
.80576 4e-05 L
.80577 4e-05 L
.80578 4e-05 L
.80578 4e-05 L
.80579 4e-05 L
.80579 4e-05 L
.8058 4e-05 L
Mistroke
.80581 4e-05 L
.80581 4e-05 L
.80582 4e-05 L
.80583 4e-05 L
.80583 4e-05 L
.80584 4e-05 L
.80585 4e-05 L
.80585 4e-05 L
.80586 4e-05 L
.80586 4e-05 L
.80587 4e-05 L
.80587 4e-05 L
.80588 4e-05 L
.80589 4e-05 L
.8059 4e-05 L
.8059 4e-05 L
.80591 4e-05 L
.80592 4e-05 L
.80592 4e-05 L
.80593 4e-05 L
.80594 4e-05 L
.80595 4e-05 L
.80595 4e-05 L
.80596 4e-05 L
.80597 4e-05 L
.80597 4e-05 L
.80598 4e-05 L
.80599 4e-05 L
.806 4e-05 L
.806 4e-05 L
.80601 4e-05 L
.80602 4e-05 L
.80603 4e-05 L
.80603 4e-05 L
.80604 4e-05 L
.80604 4e-05 L
.80604 4e-05 L
.80605 4e-05 L
.80606 4e-05 L
.80607 4e-05 L
.80608 4e-05 L
.80608 4e-05 L
.80609 4e-05 L
.8061 4e-05 L
.8061 4e-05 L
.80611 4e-05 L
.80612 4e-05 L
.80613 4e-05 L
.80613 4e-05 L
.80614 4e-05 L
Mistroke
.80615 4e-05 L
.80616 4e-05 L
.80616 4e-05 L
.80617 4e-05 L
.80618 4e-05 L
.80618 4e-05 L
.80619 4e-05 L
.80619 4e-05 L
.8062 4e-05 L
.8062 4e-05 L
.80621 4e-05 L
.80621 4e-05 L
.80622 4e-05 L
.80622 4e-05 L
.80623 4e-05 L
.80623 4e-05 L
.80624 4e-05 L
.80624 4e-05 L
.80624 4e-05 L
.80625 4e-05 L
.80626 4e-05 L
.80626 4e-05 L
.80627 4e-05 L
.80628 4e-05 L
.80629 4e-05 L
.80629 4e-05 L
.8063 4e-05 L
.80631 4e-05 L
.80631 4e-05 L
.80632 4e-05 L
.80633 4e-05 L
.80634 4e-05 L
.80634 4e-05 L
.80635 4e-05 L
.80636 4e-05 L
.80636 4e-05 L
.80637 4e-05 L
.80638 4e-05 L
.80638 4e-05 L
.80639 4e-05 L
.8064 4e-05 L
.80641 4e-05 L
.80641 4e-05 L
.80642 4e-05 L
.80643 4e-05 L
.80643 4e-05 L
.80644 4e-05 L
.80645 4e-05 L
.80645 4e-05 L
.80646 4e-05 L
Mistroke
.80647 4e-05 L
.80648 4e-05 L
.80648 4e-05 L
.80648 4e-05 L
.80649 4e-05 L
.8065 4e-05 L
.80651 4e-05 L
.80651 4e-05 L
.80652 4e-05 L
.80653 4e-05 L
.80654 4e-05 L
.80654 4e-05 L
.80655 4e-05 L
.80656 4e-05 L
.80657 4e-05 L
.80657 4e-05 L
.80658 4e-05 L
.80659 4e-05 L
.8066 4e-05 L
.8066 4e-05 L
.8066 4e-05 L
.80661 4e-05 L
.80662 4e-05 L
.80663 4e-05 L
.80663 4e-05 L
.80664 4e-05 L
.80665 4e-05 L
.80666 4e-05 L
.80666 4e-05 L
.80667 4e-05 L
.80668 4e-05 L
.80668 4e-05 L
.80669 4e-05 L
.8067 4e-05 L
.8067 4e-05 L
.80671 4e-05 L
.80672 4e-05 L
.80672 4e-05 L
.80673 4e-05 L
.80673 4e-05 L
.80674 4e-05 L
.80675 4e-05 L
.80675 4e-05 L
.80676 4e-05 L
.80677 4e-05 L
.80677 4e-05 L
.80678 4e-05 L
.80679 4e-05 L
.80679 4e-05 L
.8068 4e-05 L
Mistroke
.80681 4e-05 L
.80681 4e-05 L
.80682 4e-05 L
.80682 4e-05 L
.80683 4e-05 L
.80683 4e-05 L
.80684 4e-05 L
.80685 4e-05 L
.80686 4e-05 L
.80686 4e-05 L
.80687 4e-05 L
.80688 4e-05 L
.80688 4e-05 L
.80689 4e-05 L
.8069 4e-05 L
.80691 4e-05 L
.80691 4e-05 L
.80692 4e-05 L
.80693 4e-05 L
.80693 4e-05 L
.80694 4e-05 L
.80695 4e-05 L
.80696 4e-05 L
.80696 4e-05 L
.80697 4e-05 L
.80698 4e-05 L
.80699 4e-05 L
.80699 4e-05 L
.80699 4e-05 L
.807 4e-05 L
.807 4e-05 L
.80701 4e-05 L
.80702 4e-05 L
.80703 4e-05 L
.80703 4e-05 L
.80704 4e-05 L
.80705 4e-05 L
.80706 4e-05 L
.80706 4e-05 L
.80707 4e-05 L
.80708 4e-05 L
.80709 4e-05 L
.80709 4e-05 L
.8071 4e-05 L
.80711 4e-05 L
.80712 4e-05 L
.80712 4e-05 L
.80713 4e-05 L
.80714 4e-05 L
.80714 4e-05 L
Mistroke
.80715 4e-05 L
.80715 4e-05 L
.80716 4e-05 L
.80716 4e-05 L
.80716 4e-05 L
.80717 4e-05 L
.80718 4e-05 L
.80718 4e-05 L
.80719 4e-05 L
.80719 4e-05 L
.80719 4e-05 L
.8072 4e-05 L
.8072 4e-05 L
.80721 4e-05 L
.80721 4e-05 L
.80722 4e-05 L
.80723 4e-05 L
.80724 4e-05 L
.80725 4e-05 L
.80725 4e-05 L
.80726 4e-05 L
.80727 4e-05 L
.80727 4e-05 L
.80728 4e-05 L
.80729 4e-05 L
.8073 4e-05 L
.8073 4e-05 L
.80731 4e-05 L
.80732 4e-05 L
.80732 4e-05 L
.80733 4e-05 L
.80734 4e-05 L
.80734 4e-05 L
.80735 4e-05 L
.80736 4e-05 L
.80737 4e-05 L
.80737 4e-05 L
.80738 4e-05 L
.80738 4e-05 L
.80739 4e-05 L
.8074 4e-05 L
.80741 4e-05 L
.80741 4e-05 L
.80742 4e-05 L
.80743 4e-05 L
.80743 4e-05 L
.80744 4e-05 L
.80744 4e-05 L
.80745 4e-05 L
.80746 4e-05 L
Mistroke
.80747 4e-05 L
.80747 4e-05 L
.80748 4e-05 L
.80749 4e-05 L
.8075 4e-05 L
.8075 4e-05 L
.80751 4e-05 L
.80752 4e-05 L
.80752 4e-05 L
.80753 4e-05 L
.80754 4e-05 L
.80755 4e-05 L
.80755 4e-05 L
.80756 4e-05 L
.80756 4e-05 L
.80757 4e-05 L
.80758 4e-05 L
.80759 4e-05 L
.80759 4e-05 L
.8076 4e-05 L
.80761 4e-05 L
.80761 4e-05 L
.80762 4e-05 L
.80763 4e-05 L
.80763 4e-05 L
.80764 4e-05 L
.80765 4e-05 L
.80766 4e-05 L
.80766 4e-05 L
.80767 4e-05 L
.80767 4e-05 L
.80768 4e-05 L
.80769 4e-05 L
.80769 4e-05 L
.8077 4e-05 L
.80771 4e-05 L
.80771 4e-05 L
.80772 4e-05 L
.80772 4e-05 L
.80773 4e-05 L
.80774 4e-05 L
.80774 4e-05 L
.80775 4e-05 L
.80776 4e-05 L
.80776 4e-05 L
.80777 4e-05 L
.80778 4e-05 L
.80778 4e-05 L
.80779 4e-05 L
.80779 4e-05 L
Mistroke
.8078 4e-05 L
.80781 4e-05 L
.80782 4e-05 L
.80782 4e-05 L
.80783 4e-05 L
.80784 4e-05 L
.80784 4e-05 L
.80785 4e-05 L
.80786 4e-05 L
.80786 4e-05 L
.80787 4e-05 L
.80788 4e-05 L
.80789 4e-05 L
.80789 4e-05 L
.8079 4e-05 L
.80791 4e-05 L
.80791 4e-05 L
.80792 4e-05 L
.80793 4e-05 L
.80793 4e-05 L
.80794 4e-05 L
.80795 4e-05 L
.80795 4e-05 L
.80796 4e-05 L
.80796 4e-05 L
.80797 4e-05 L
.80797 4e-05 L
.80798 4e-05 L
.80798 4e-05 L
.80799 4e-05 L
.80799 4e-05 L
.808 4e-05 L
.808 4e-05 L
.80801 4e-05 L
.80801 4e-05 L
.80802 4e-05 L
.80802 4e-05 L
.80803 4e-05 L
.80803 4e-05 L
.80804 4e-05 L
.80804 4e-05 L
.80805 4e-05 L
.80805 4e-05 L
.80806 4e-05 L
.80806 4e-05 L
.80807 4e-05 L
.80808 4e-05 L
.80808 4e-05 L
.80809 4e-05 L
.80809 4e-05 L
Mistroke
.8081 4e-05 L
Mfstroke
.80217 .76297 m
.80241 .76497 L
.80268 .76721 L
.80292 .76937 L
.80316 .77151 L
.80341 .77385 L
.80365 .77617 L
.80391 .77872 L
.80416 .78127 L
.8044 .7838 L
.80465 .78661 L
.8049 .78942 L
.80513 .79224 L
.80538 .79539 L
.80563 .79858 L
.80588 .80217 L
.80613 .80585 L
.80637 .80964 L
.80662 .814 L
.80686 .81861 L
.80712 .82409 L
.80737 .83016 L
.80761 .83718 L
.80773 .84145 L
.80787 .84713 L
.80792 .85013 L
.80799 .85401 L
.80802 .8563 L
.80805 .85891 L
.80807 .86198 L
.80808 .86306 L
.80809 .86443 L
.80809 .86596 L
.8081 .86998 L
s
.5 1 1 r
.80217 4e-05 m
.80218 4e-05 L
.80219 4e-05 L
.8022 4e-05 L
.8022 4e-05 L
.80221 4e-05 L
.80222 4e-05 L
.80222 4e-05 L
.80223 4e-05 L
.80224 4e-05 L
.80224 4e-05 L
.80225 4e-05 L
.80226 4e-05 L
.80227 4e-05 L
.80227 4e-05 L
.80228 4e-05 L
.80228 4e-05 L
.80229 4e-05 L
.80229 4e-05 L
.8023 4e-05 L
.80231 4e-05 L
.80231 4e-05 L
.80231 4e-05 L
.80232 4e-05 L
.80232 4e-05 L
.80233 4e-05 L
.80233 4e-05 L
.80234 4e-05 L
.80235 4e-05 L
.80236 4e-05 L
.80236 4e-05 L
.80237 4e-05 L
.80238 4e-05 L
.80238 4e-05 L
.80239 4e-05 L
.8024 4e-05 L
.80241 4e-05 L
.80241 4e-05 L
.80242 4e-05 L
.80242 4e-05 L
.80243 4e-05 L
.80243 4e-05 L
.80244 4e-05 L
.80244 4e-05 L
.80245 4e-05 L
.80246 4e-05 L
.80246 4e-05 L
.80247 4e-05 L
.80247 4e-05 L
.80248 4e-05 L
.80248 4e-05 L
.80249 4e-05 L
.80249 4e-05 L
.8025 4e-05 L
.8025 4e-05 L
.80251 4e-05 L
.80251 4e-05 L
.80252 4e-05 L
.80252 4e-05 L
.80252 4e-05 L
.80253 4e-05 L
.80253 4e-05 L
.80254 4e-05 L
.80255 4e-05 L
.80255 4e-05 L
.80256 4e-05 L
.80256 4e-05 L
.80257 4e-05 L
.80258 4e-05 L
.80259 4e-05 L
.80259 4e-05 L
.8026 4e-05 L
.8026 4e-05 L
.80261 4e-05 L
.80262 4e-05 L
.80262 4e-05 L
.80262 4e-05 L
.80263 4e-05 L
.80264 4e-05 L
.80264 4e-05 L
.80265 4e-05 L
.80265 4e-05 L
.80266 4e-05 L
.80267 4e-05 L
.80268 4e-05 L
.80268 4e-05 L
.80269 4e-05 L
.8027 4e-05 L
.8027 4e-05 L
.80271 4e-05 L
.80272 4e-05 L
.80272 4e-05 L
.80273 4e-05 L
.80274 4e-05 L
.80274 4e-05 L
.80274 4e-05 L
.80275 4e-05 L
.80275 4e-05 L
.80276 4e-05 L
.80277 4e-05 L
.80277 4e-05 L
.80278 4e-05 L
.80278 4e-05 L
.80279 4e-05 L
.8028 4e-05 L
.80281 4e-05 L
.80281 4e-05 L
.80282 4e-05 L
.80283 4e-05 L
.80283 4e-05 L
.80284 4e-05 L
.80285 4e-05 L
.80285 4e-05 L
.80286 4e-05 L
.80287 4e-05 L
.80288 4e-05 L
.80288 4e-05 L
.80289 4e-05 L
.8029 4e-05 L
.8029 4e-05 L
.80291 4e-05 L
.80291 4e-05 L
.80292 4e-05 L
.80293 4e-05 L
.80294 4e-05 L
.80294 4e-05 L
.80295 4e-05 L
.80296 4e-05 L
.80297 4e-05 L
.80297 4e-05 L
.80298 4e-05 L
.80299 4e-05 L
.803 4e-05 L
.803 4e-05 L
.80301 4e-05 L
.80302 4e-05 L
.80302 4e-05 L
.80303 4e-05 L
.80304 4e-05 L
.80304 4e-05 L
.80305 4e-05 L
.80306 4e-05 L
.80306 4e-05 L
.80307 4e-05 L
.80308 4e-05 L
.80308 4e-05 L
.80309 4e-05 L
.8031 4e-05 L
.8031 4e-05 L
.80311 4e-05 L
.80312 4e-05 L
.80313 4e-05 L
.80313 4e-05 L
.80313 4e-05 L
.80314 4e-05 L
.80315 4e-05 L
.80316 4e-05 L
.80317 4e-05 L
.80317 4e-05 L
.80318 4e-05 L
.80319 4e-05 L
.80319 4e-05 L
.8032 4e-05 L
.80321 4e-05 L
.80322 4e-05 L
.80322 4e-05 L
.80323 4e-05 L
.80324 4e-05 L
.80325 4e-05 L
.80325 4e-05 L
.80326 4e-05 L
.80326 4e-05 L
.80327 4e-05 L
.80328 4e-05 L
.80328 4e-05 L
.80329 4e-05 L
.8033 4e-05 L
.80331 4e-05 L
.80331 4e-05 L
.80332 4e-05 L
.80333 4e-05 L
.80333 4e-05 L
.80334 4e-05 L
.80335 4e-05 L
.80335 4e-05 L
.80336 4e-05 L
.80337 4e-05 L
.80337 4e-05 L
.80338 4e-05 L
.80338 4e-05 L
.80339 4e-05 L
.8034 4e-05 L
.80341 4e-05 L
.80342 4e-05 L
.80342 4e-05 L
.80343 4e-05 L
.80344 4e-05 L
.80344 4e-05 L
.80345 4e-05 L
.80346 4e-05 L
.80347 4e-05 L
.80347 4e-05 L
.80348 4e-05 L
.80349 4e-05 L
.80349 4e-05 L
.8035 4e-05 L
.80351 4e-05 L
.80351 4e-05 L
.80352 4e-05 L
.80353 4e-05 L
.80353 4e-05 L
.80354 4e-05 L
.80355 4e-05 L
.80355 4e-05 L
.80356 4e-05 L
.80357 4e-05 L
.80358 4e-05 L
.80358 4e-05 L
.80359 4e-05 L
.8036 4e-05 L
.8036 4e-05 L
.80361 4e-05 L
.80361 4e-05 L
.80362 4e-05 L
.80363 4e-05 L
.80364 4e-05 L
.80364 4e-05 L
.80365 4e-05 L
.80366 4e-05 L
.80366 4e-05 L
.80367 4e-05 L
.80368 4e-05 L
.80369 4e-05 L
.8037 4e-05 L
.8037 4e-05 L
.80371 4e-05 L
.80372 4e-05 L
.80372 4e-05 L
.80373 4e-05 L
.80373 4e-05 L
.80374 4e-05 L
.80375 4e-05 L
.80376 4e-05 L
.80376 4e-05 L
.80377 4e-05 L
.80378 4e-05 L
.80378 4e-05 L
.80379 4e-05 L
.8038 4e-05 L
.8038 4e-05 L
.80381 4e-05 L
.80382 4e-05 L
.80383 4e-05 L
.80383 4e-05 L
.80384 4e-05 L
.80384 4e-05 L
.80385 4e-05 L
.80386 4e-05 L
.80386 4e-05 L
.80387 4e-05 L
.80387 4e-05 L
.80388 4e-05 L
.80389 4e-05 L
.80389 4e-05 L
.8039 4e-05 L
.80391 4e-05 L
.80392 4e-05 L
.80392 4e-05 L
.80393 4e-05 L
.80393 4e-05 L
.80394 4e-05 L
.80394 4e-05 L
.80395 4e-05 L
.80396 4e-05 L
.80396 4e-05 L
.80397 4e-05 L
.80398 4e-05 L
.80399 4e-05 L
.80399 4e-05 L
.804 4e-05 L
.80401 4e-05 L
.80401 4e-05 L
.80402 4e-05 L
.80403 4e-05 L
.80403 4e-05 L
.80404 4e-05 L
.80405 4e-05 L
.80406 4e-05 L
.80406 4e-05 L
.80407 4e-05 L
.80408 4e-05 L
.80409 4e-05 L
.80409 4e-05 L
.8041 4e-05 L
.80411 4e-05 L
.80411 4e-05 L
.80412 4e-05 L
.80412 4e-05 L
.80413 4e-05 L
.80413 4e-05 L
.80414 4e-05 L
.80415 4e-05 L
.80416 4e-05 L
.80416 4e-05 L
.80417 4e-05 L
.80418 4e-05 L
.80418 4e-05 L
.80419 4e-05 L
.8042 4e-05 L
.80421 4e-05 L
.80421 4e-05 L
.80422 4e-05 L
.80423 4e-05 L
.80424 4e-05 L
.80424 4e-05 L
.80425 4e-05 L
.80426 4e-05 L
.80426 4e-05 L
.80427 4e-05 L
.80427 4e-05 L
.80428 4e-05 L
.80428 4e-05 L
.80429 4e-05 L
.80429 4e-05 L
.8043 4e-05 L
.8043 4e-05 L
.80431 4e-05 L
.80431 4e-05 L
.80432 4e-05 L
.80432 4e-05 L
.80433 4e-05 L
.80433 4e-05 L
.80434 4e-05 L
.80434 4e-05 L
.80435 4e-05 L
.80436 4e-05 L
.80437 4e-05 L
.80438 4e-05 L
.80438 4e-05 L
.80439 4e-05 L
.8044 4e-05 L
.8044 4e-05 L
.80441 4e-05 L
.80442 4e-05 L
.80443 4e-05 L
.80443 4e-05 L
.80444 4e-05 L
.80445 4e-05 L
.80445 4e-05 L
.80446 4e-05 L
.80447 4e-05 L
.80447 4e-05 L
.80448 4e-05 L
.80449 4e-05 L
.80449 4e-05 L
.8045 4e-05 L
.80451 4e-05 L
.80451 4e-05 L
.80452 4e-05 L
.80453 4e-05 L
.80454 4e-05 L
.80454 4e-05 L
.80455 4e-05 L
.80456 4e-05 L
.80456 4e-05 L
.80457 4e-05 L
.80457 4e-05 L
.80458 4e-05 L
.80459 4e-05 L
.8046 4e-05 L
.8046 4e-05 L
.80461 4e-05 L
.80462 4e-05 L
.80462 4e-05 L
.80463 4e-05 L
.80464 4e-05 L
.80465 4e-05 L
.80465 4e-05 L
.80466 4e-05 L
.80467 4e-05 L
.80468 4e-05 L
.80468 4e-05 L
.80469 4e-05 L
.80469 4e-05 L
.8047 4e-05 L
.80471 4e-05 L
.80472 4e-05 L
.80472 4e-05 L
.80473 4e-05 L
.80474 4e-05 L
.80474 4e-05 L
.80475 4e-05 L
.80476 4e-05 L
.80476 4e-05 L
.80477 4e-05 L
.80478 4e-05 L
.80479 4e-05 L
.80479 4e-05 L
.8048 4e-05 L
.8048 4e-05 L
.80481 4e-05 L
.80482 4e-05 L
.80482 4e-05 L
.80483 4e-05 L
.80483 4e-05 L
.80484 4e-05 L
.80485 4e-05 L
.80485 4e-05 L
.80486 4e-05 L
.80487 4e-05 L
.80488 4e-05 L
.80488 4e-05 L
.80489 4e-05 L
.80489 4e-05 L
.8049 4e-05 L
.8049 4e-05 L
.80491 4e-05 L
.80492 4e-05 L
.80492 4e-05 L
.80493 4e-05 L
.80494 4e-05 L
.80494 4e-05 L
.80495 4e-05 L
.80496 4e-05 L
.80496 4e-05 L
.80497 4e-05 L
.80498 4e-05 L
.80499 4e-05 L
.80499 4e-05 L
.805 4e-05 L
.80501 4e-05 L
.80502 4e-05 L
.80502 4e-05 L
.80503 4e-05 L
.80504 4e-05 L
.80504 4e-05 L
.80505 4e-05 L
.80506 4e-05 L
.80507 4e-05 L
.80507 4e-05 L
.80508 4e-05 L
.80508 4e-05 L
.80509 4e-05 L
.80509 4e-05 L
.8051 4e-05 L
.80511 4e-05 L
.80512 4e-05 L
.80512 4e-05 L
.80513 4e-05 L
.80514 4e-05 L
.80514 4e-05 L
.80515 4e-05 L
.80516 4e-05 L
.80517 4e-05 L
.80517 4e-05 L
.80518 4e-05 L
.80519 4e-05 L
.8052 4e-05 L
.8052 4e-05 L
.80521 4e-05 L
.80522 4e-05 L
.80522 4e-05 L
.80523 4e-05 L
.80523 4e-05 L
.80524 4e-05 L
.80524 4e-05 L
.80525 4e-05 L
.80525 4e-05 L
.80526 4e-05 L
.80526 4e-05 L
.80527 4e-05 L
.80527 4e-05 L
.80528 4e-05 L
.80528 4e-05 L
.80528 4e-05 L
.80529 4e-05 L
.8053 4e-05 L
.8053 4e-05 L
.80531 4e-05 L
.80532 4e-05 L
.80533 4e-05 L
.80533 4e-05 L
.80534 4e-05 L
.80535 4e-05 L
.80536 4e-05 L
.80536 4e-05 L
.80537 4e-05 L
.80538 4e-05 L
.80539 4e-05 L
.80539 4e-05 L
.8054 4e-05 L
.80541 4e-05 L
.80541 4e-05 L
.80542 4e-05 L
.80543 4e-05 L
.80543 4e-05 L
.80544 4e-05 L
.80545 4e-05 L
.80545 4e-05 L
.80546 4e-05 L
.80547 4e-05 L
.80547 4e-05 L
.80548 4e-05 L
.80549 4e-05 L
.8055 4e-05 L
.8055 4e-05 L
.80551 4e-05 L
.80552 4e-05 L
.80552 4e-05 L
.80552 4e-05 L
.80553 4e-05 L
.80554 4e-05 L
.80555 4e-05 L
.80556 4e-05 L
.80556 4e-05 L
.80557 4e-05 L
.80558 4e-05 L
.80558 4e-05 L
.80559 4e-05 L
.8056 4e-05 L
.80561 4e-05 L
.80561 4e-05 L
.80562 4e-05 L
.80563 4e-05 L
.80564 4e-05 L
.80564 4e-05 L
.80565 4e-05 L
.80565 4e-05 L
.80566 4e-05 L
.80567 4e-05 L
.80568 4e-05 L
.80568 4e-05 L
.80569 4e-05 L
.8057 4e-05 L
.8057 4e-05 L
.80571 4e-05 L
.80572 4e-05 L
.80572 4e-05 L
.80573 4e-05 L
.80574 4e-05 L
.80574 4e-05 L
.80575 4e-05 L
.80576 4e-05 L
.80576 4e-05 L
.80577 4e-05 L
.80578 4e-05 L
.80578 4e-05 L
.80579 4e-05 L
.80579 4e-05 L
.8058 4e-05 L
.80581 4e-05 L
.80581 4e-05 L
.80582 4e-05 L
.80583 4e-05 L
.80583 4e-05 L
.80584 4e-05 L
.80585 4e-05 L
.80585 4e-05 L
.80586 4e-05 L
.80586 4e-05 L
.80587 4e-05 L
.80587 4e-05 L
.80588 4e-05 L
.80589 4e-05 L
.8059 4e-05 L
.8059 4e-05 L
.80591 4e-05 L
.80592 4e-05 L
.80592 4e-05 L
.80593 4e-05 L
.80594 4e-05 L
.80595 4e-05 L
.80595 4e-05 L
.80596 4e-05 L
.80597 4e-05 L
.80597 4e-05 L
.80598 4e-05 L
.80599 4e-05 L
.806 4e-05 L
.806 4e-05 L
.80601 4e-05 L
.80602 4e-05 L
.80603 4e-05 L
.80603 4e-05 L
.80604 4e-05 L
.80604 4e-05 L
.80604 4e-05 L
.80605 4e-05 L
.80606 4e-05 L
.80607 4e-05 L
.80608 4e-05 L
.80608 4e-05 L
.80609 4e-05 L
.8061 4e-05 L
.8061 4e-05 L
.80611 4e-05 L
.80612 4e-05 L
.80613 4e-05 L
.80613 4e-05 L
.80614 4e-05 L
.80615 4e-05 L
.80616 4e-05 L
.80616 4e-05 L
.80617 4e-05 L
.80618 4e-05 L
.80618 4e-05 L
.80619 4e-05 L
.80619 4e-05 L
.8062 4e-05 L
.8062 4e-05 L
.80621 4e-05 L
.80621 4e-05 L
.80622 4e-05 L
.80622 4e-05 L
.80623 4e-05 L
.80623 4e-05 L
.80624 4e-05 L
.80624 4e-05 L
.80624 4e-05 L
.80625 4e-05 L
.80626 4e-05 L
.80626 4e-05 L
.80627 4e-05 L
.80628 4e-05 L
.80629 4e-05 L
.80629 4e-05 L
.8063 4e-05 L
.80631 4e-05 L
.80631 4e-05 L
.80632 4e-05 L
.80633 4e-05 L
.80634 4e-05 L
.80634 4e-05 L
.80635 4e-05 L
.80636 4e-05 L
.80636 4e-05 L
.80637 4e-05 L
.80638 4e-05 L
.80638 4e-05 L
.80639 4e-05 L
.8064 4e-05 L
.80641 4e-05 L
.80641 4e-05 L
.80642 4e-05 L
.80643 4e-05 L
.80643 4e-05 L
.80644 4e-05 L
.80645 4e-05 L
.80645 4e-05 L
.80646 4e-05 L
.80647 4e-05 L
.80648 4e-05 L
.80648 4e-05 L
.80648 4e-05 L
.80649 4e-05 L
.8065 4e-05 L
.80651 4e-05 L
.80651 4e-05 L
.80652 4e-05 L
.80653 4e-05 L
.80654 4e-05 L
.80654 4e-05 L
.80655 4e-05 L
.80656 4e-05 L
.80657 4e-05 L
.80657 4e-05 L
.80658 4e-05 L
.80659 4e-05 L
.8066 4e-05 L
.8066 4e-05 L
.8066 4e-05 L
.80661 4e-05 L
.80662 4e-05 L
.80663 4e-05 L
.80663 4e-05 L
.80664 4e-05 L
.80665 4e-05 L
.80666 4e-05 L
.80666 4e-05 L
.80667 4e-05 L
.80668 4e-05 L
.80668 4e-05 L
.80669 4e-05 L
.8067 4e-05 L
.8067 4e-05 L
.80671 4e-05 L
.80672 4e-05 L
.80672 4e-05 L
.80673 4e-05 L
.80673 4e-05 L
.80674 4e-05 L
.80675 4e-05 L
.80675 4e-05 L
.80676 4e-05 L
.80677 4e-05 L
.80677 4e-05 L
.80678 4e-05 L
.80679 4e-05 L
.80679 4e-05 L
.8068 4e-05 L
.80681 4e-05 L
.80681 4e-05 L
.80682 4e-05 L
.80682 4e-05 L
.80683 4e-05 L
.80683 4e-05 L
.80684 4e-05 L
.80685 4e-05 L
.80686 4e-05 L
.80686 4e-05 L
.80687 4e-05 L
.80688 4e-05 L
.80688 4e-05 L
.80689 4e-05 L
.8069 4e-05 L
.80691 4e-05 L
.80691 4e-05 L
.80692 4e-05 L
.80693 4e-05 L
.80693 4e-05 L
.80694 4e-05 L
.80695 4e-05 L
.80696 4e-05 L
.80696 4e-05 L
.80697 4e-05 L
.80698 4e-05 L
.80699 4e-05 L
.80699 4e-05 L
.80699 4e-05 L
.807 4e-05 L
.807 4e-05 L
.80701 4e-05 L
.80702 4e-05 L
.80703 4e-05 L
.80703 4e-05 L
.80704 4e-05 L
.80705 4e-05 L
.80706 4e-05 L
.80706 4e-05 L
.80707 4e-05 L
.80708 4e-05 L
.80709 4e-05 L
.80709 4e-05 L
.8071 4e-05 L
.80711 4e-05 L
.80712 4e-05 L
.80712 4e-05 L
.80713 4e-05 L
.80714 4e-05 L
.80714 4e-05 L
.80715 4e-05 L
.80715 4e-05 L
.80716 4e-05 L
.80716 4e-05 L
.80716 4e-05 L
.80717 4e-05 L
.80718 4e-05 L
.80718 4e-05 L
.80719 4e-05 L
.80719 4e-05 L
.80719 4e-05 L
.8072 4e-05 L
.8072 4e-05 L
.80721 4e-05 L
.80721 4e-05 L
.80722 4e-05 L
.80723 4e-05 L
.80724 4e-05 L
.80725 4e-05 L
.80725 4e-05 L
.80726 4e-05 L
.80727 4e-05 L
.80727 4e-05 L
.80728 4e-05 L
.80729 4e-05 L
.8073 4e-05 L
.8073 4e-05 L
.80731 4e-05 L
.80732 4e-05 L
.80732 4e-05 L
.80733 4e-05 L
.80734 4e-05 L
.80734 4e-05 L
.80735 4e-05 L
.80736 4e-05 L
.80737 4e-05 L
.80737 4e-05 L
.80738 4e-05 L
.80738 4e-05 L
.80739 4e-05 L
.8074 4e-05 L
.80741 4e-05 L
.80741 4e-05 L
.80742 4e-05 L
.80743 4e-05 L
.80743 4e-05 L
.80744 4e-05 L
.80744 4e-05 L
.80745 4e-05 L
.80746 4e-05 L
.80747 4e-05 L
.80747 4e-05 L
.80748 4e-05 L
.80749 4e-05 L
.8075 4e-05 L
.8075 4e-05 L
.80751 4e-05 L
.80752 4e-05 L
.80752 4e-05 L
.80753 4e-05 L
.80754 4e-05 L
.80755 4e-05 L
.80755 4e-05 L
.80756 4e-05 L
.80756 4e-05 L
.80757 4e-05 L
.80758 4e-05 L
.80759 4e-05 L
.80759 4e-05 L
.8076 4e-05 L
.80761 4e-05 L
.80761 4e-05 L
.80762 4e-05 L
.80763 4e-05 L
.80763 4e-05 L
.80764 4e-05 L
.80765 4e-05 L
.80766 4e-05 L
.80766 4e-05 L
.80767 4e-05 L
.80767 4e-05 L
.80768 4e-05 L
.80769 4e-05 L
.80769 4e-05 L
.8077 4e-05 L
.80771 4e-05 L
.80771 4e-05 L
.80772 4e-05 L
.80772 4e-05 L
.80773 4e-05 L
.80774 4e-05 L
.80774 4e-05 L
.80775 4e-05 L
.80776 4e-05 L
.80776 4e-05 L
.80777 4e-05 L
.80778 4e-05 L
.80778 4e-05 L
.80779 4e-05 L
.80779 4e-05 L
.8078 4e-05 L
.80781 4e-05 L
.80782 4e-05 L
.80782 4e-05 L
.80783 4e-05 L
.80784 4e-05 L
.80784 4e-05 L
.80785 4e-05 L
.80786 4e-05 L
.80786 4e-05 L
.80787 4e-05 L
.80788 4e-05 L
.80789 4e-05 L
.80789 4e-05 L
.8079 4e-05 L
.80791 4e-05 L
.80791 4e-05 L
.80792 4e-05 L
.80793 4e-05 L
.80793 4e-05 L
.80794 4e-05 L
.80795 4e-05 L
.80795 4e-05 L
.80796 4e-05 L
.80796 4e-05 L
.80797 4e-05 L
.80797 4e-05 L
.80798 4e-05 L
.80798 4e-05 L
.80799 4e-05 L
.80799 4e-05 L
.808 4e-05 L
.808 4e-05 L
.80801 4e-05 L
.80801 4e-05 L
.80802 4e-05 L
.80802 4e-05 L
.80803 4e-05 L
.80803 4e-05 L
.80804 4e-05 L
.80804 4e-05 L
.80805 4e-05 L
.80805 4e-05 L
.80806 4e-05 L
.80806 4e-05 L
.80807 4e-05 L
.80808 4e-05 L
.80808 4e-05 L
.80809 4e-05 L
.80809 4e-05 L
.8081 4e-05 L
.8081 .86998 L
.80809 .86596 L
.80809 .86443 L
.80808 .86306 L
.80807 .86198 L
.80805 .85891 L
.80802 .8563 L
.80799 .85401 L
.80792 .85013 L
.80787 .84713 L
.80773 .84145 L
.80761 .83718 L
.80737 .83016 L
.80712 .82409 L
.80686 .81861 L
.80662 .814 L
.80637 .80964 L
.80613 .80585 L
.80588 .80217 L
.80563 .79858 L
.80538 .79539 L
.80513 .79224 L
.8049 .78942 L
.80465 .78661 L
.8044 .7838 L
.80416 .78127 L
.80391 .77872 L
.80365 .77617 L
.80341 .77385 L
.80316 .77151 L
.80292 .76937 L
.80268 .76721 L
.80241 .76497 L
.80217 .76297 L
F
0 g
.80217 4e-05 m
.80218 4e-05 L
.80219 4e-05 L
.8022 4e-05 L
.8022 4e-05 L
.80221 4e-05 L
.80222 4e-05 L
.80222 4e-05 L
.80223 4e-05 L
.80224 4e-05 L
.80224 4e-05 L
.80225 4e-05 L
.80226 4e-05 L
.80227 4e-05 L
.80227 4e-05 L
.80228 4e-05 L
.80228 4e-05 L
.80229 4e-05 L
.80229 4e-05 L
.8023 4e-05 L
.80231 4e-05 L
.80231 4e-05 L
.80231 4e-05 L
.80232 4e-05 L
.80232 4e-05 L
.80233 4e-05 L
.80233 4e-05 L
.80234 4e-05 L
.80235 4e-05 L
.80236 4e-05 L
.80236 4e-05 L
.80237 4e-05 L
.80238 4e-05 L
.80238 4e-05 L
.80239 4e-05 L
.8024 4e-05 L
.80241 4e-05 L
.80241 4e-05 L
.80242 4e-05 L
.80242 4e-05 L
.80243 4e-05 L
.80243 4e-05 L
.80244 4e-05 L
.80244 4e-05 L
.80245 4e-05 L
.80246 4e-05 L
.80246 4e-05 L
.80247 4e-05 L
.80247 4e-05 L
.80248 4e-05 L
Mistroke
.80248 4e-05 L
.80249 4e-05 L
.80249 4e-05 L
.8025 4e-05 L
.8025 4e-05 L
.80251 4e-05 L
.80251 4e-05 L
.80252 4e-05 L
.80252 4e-05 L
.80252 4e-05 L
.80253 4e-05 L
.80253 4e-05 L
.80254 4e-05 L
.80255 4e-05 L
.80255 4e-05 L
.80256 4e-05 L
.80256 4e-05 L
.80257 4e-05 L
.80258 4e-05 L
.80259 4e-05 L
.80259 4e-05 L
.8026 4e-05 L
.8026 4e-05 L
.80261 4e-05 L
.80262 4e-05 L
.80262 4e-05 L
.80262 4e-05 L
.80263 4e-05 L
.80264 4e-05 L
.80264 4e-05 L
.80265 4e-05 L
.80265 4e-05 L
.80266 4e-05 L
.80267 4e-05 L
.80268 4e-05 L
.80268 4e-05 L
.80269 4e-05 L
.8027 4e-05 L
.8027 4e-05 L
.80271 4e-05 L
.80272 4e-05 L
.80272 4e-05 L
.80273 4e-05 L
.80274 4e-05 L
.80274 4e-05 L
.80274 4e-05 L
.80275 4e-05 L
.80275 4e-05 L
.80276 4e-05 L
.80277 4e-05 L
Mistroke
.80277 4e-05 L
.80278 4e-05 L
.80278 4e-05 L
.80279 4e-05 L
.8028 4e-05 L
.80281 4e-05 L
.80281 4e-05 L
.80282 4e-05 L
.80283 4e-05 L
.80283 4e-05 L
.80284 4e-05 L
.80285 4e-05 L
.80285 4e-05 L
.80286 4e-05 L
.80287 4e-05 L
.80288 4e-05 L
.80288 4e-05 L
.80289 4e-05 L
.8029 4e-05 L
.8029 4e-05 L
.80291 4e-05 L
.80291 4e-05 L
.80292 4e-05 L
.80293 4e-05 L
.80294 4e-05 L
.80294 4e-05 L
.80295 4e-05 L
.80296 4e-05 L
.80297 4e-05 L
.80297 4e-05 L
.80298 4e-05 L
.80299 4e-05 L
.803 4e-05 L
.803 4e-05 L
.80301 4e-05 L
.80302 4e-05 L
.80302 4e-05 L
.80303 4e-05 L
.80304 4e-05 L
.80304 4e-05 L
.80305 4e-05 L
.80306 4e-05 L
.80306 4e-05 L
.80307 4e-05 L
.80308 4e-05 L
.80308 4e-05 L
.80309 4e-05 L
.8031 4e-05 L
.8031 4e-05 L
.80311 4e-05 L
Mistroke
.80312 4e-05 L
.80313 4e-05 L
.80313 4e-05 L
.80313 4e-05 L
.80314 4e-05 L
.80315 4e-05 L
.80316 4e-05 L
.80317 4e-05 L
.80317 4e-05 L
.80318 4e-05 L
.80319 4e-05 L
.80319 4e-05 L
.8032 4e-05 L
.80321 4e-05 L
.80322 4e-05 L
.80322 4e-05 L
.80323 4e-05 L
.80324 4e-05 L
.80325 4e-05 L
.80325 4e-05 L
.80326 4e-05 L
.80326 4e-05 L
.80327 4e-05 L
.80328 4e-05 L
.80328 4e-05 L
.80329 4e-05 L
.8033 4e-05 L
.80331 4e-05 L
.80331 4e-05 L
.80332 4e-05 L
.80333 4e-05 L
.80333 4e-05 L
.80334 4e-05 L
.80335 4e-05 L
.80335 4e-05 L
.80336 4e-05 L
.80337 4e-05 L
.80337 4e-05 L
.80338 4e-05 L
.80338 4e-05 L
.80339 4e-05 L
.8034 4e-05 L
.80341 4e-05 L
.80342 4e-05 L
.80342 4e-05 L
.80343 4e-05 L
.80344 4e-05 L
.80344 4e-05 L
.80345 4e-05 L
.80346 4e-05 L
Mistroke
.80347 4e-05 L
.80347 4e-05 L
.80348 4e-05 L
.80349 4e-05 L
.80349 4e-05 L
.8035 4e-05 L
.80351 4e-05 L
.80351 4e-05 L
.80352 4e-05 L
.80353 4e-05 L
.80353 4e-05 L
.80354 4e-05 L
.80355 4e-05 L
.80355 4e-05 L
.80356 4e-05 L
.80357 4e-05 L
.80358 4e-05 L
.80358 4e-05 L
.80359 4e-05 L
.8036 4e-05 L
.8036 4e-05 L
.80361 4e-05 L
.80361 4e-05 L
.80362 4e-05 L
.80363 4e-05 L
.80364 4e-05 L
.80364 4e-05 L
.80365 4e-05 L
.80366 4e-05 L
.80366 4e-05 L
.80367 4e-05 L
.80368 4e-05 L
.80369 4e-05 L
.8037 4e-05 L
.8037 4e-05 L
.80371 4e-05 L
.80372 4e-05 L
.80372 4e-05 L
.80373 4e-05 L
.80373 4e-05 L
.80374 4e-05 L
.80375 4e-05 L
.80376 4e-05 L
.80376 4e-05 L
.80377 4e-05 L
.80378 4e-05 L
.80378 4e-05 L
.80379 4e-05 L
.8038 4e-05 L
.8038 4e-05 L
Mistroke
.80381 4e-05 L
.80382 4e-05 L
.80383 4e-05 L
.80383 4e-05 L
.80384 4e-05 L
.80384 4e-05 L
.80385 4e-05 L
.80386 4e-05 L
.80386 4e-05 L
.80387 4e-05 L
.80387 4e-05 L
.80388 4e-05 L
.80389 4e-05 L
.80389 4e-05 L
.8039 4e-05 L
.80391 4e-05 L
.80392 4e-05 L
.80392 4e-05 L
.80393 4e-05 L
.80393 4e-05 L
.80394 4e-05 L
.80394 4e-05 L
.80395 4e-05 L
.80396 4e-05 L
.80396 4e-05 L
.80397 4e-05 L
.80398 4e-05 L
.80399 4e-05 L
.80399 4e-05 L
.804 4e-05 L
.80401 4e-05 L
.80401 4e-05 L
.80402 4e-05 L
.80403 4e-05 L
.80403 4e-05 L
.80404 4e-05 L
.80405 4e-05 L
.80406 4e-05 L
.80406 4e-05 L
.80407 4e-05 L
.80408 4e-05 L
.80409 4e-05 L
.80409 4e-05 L
.8041 4e-05 L
.80411 4e-05 L
.80411 4e-05 L
.80412 4e-05 L
.80412 4e-05 L
.80413 4e-05 L
.80413 4e-05 L
Mistroke
.80414 4e-05 L
.80415 4e-05 L
.80416 4e-05 L
.80416 4e-05 L
.80417 4e-05 L
.80418 4e-05 L
.80418 4e-05 L
.80419 4e-05 L
.8042 4e-05 L
.80421 4e-05 L
.80421 4e-05 L
.80422 4e-05 L
.80423 4e-05 L
.80424 4e-05 L
.80424 4e-05 L
.80425 4e-05 L
.80426 4e-05 L
.80426 4e-05 L
.80427 4e-05 L
.80427 4e-05 L
.80428 4e-05 L
.80428 4e-05 L
.80429 4e-05 L
.80429 4e-05 L
.8043 4e-05 L
.8043 4e-05 L
.80431 4e-05 L
.80431 4e-05 L
.80432 4e-05 L
.80432 4e-05 L
.80433 4e-05 L
.80433 4e-05 L
.80434 4e-05 L
.80434 4e-05 L
.80435 4e-05 L
.80436 4e-05 L
.80437 4e-05 L
.80438 4e-05 L
.80438 4e-05 L
.80439 4e-05 L
.8044 4e-05 L
.8044 4e-05 L
.80441 4e-05 L
.80442 4e-05 L
.80443 4e-05 L
.80443 4e-05 L
.80444 4e-05 L
.80445 4e-05 L
.80445 4e-05 L
.80446 4e-05 L
Mistroke
.80447 4e-05 L
.80447 4e-05 L
.80448 4e-05 L
.80449 4e-05 L
.80449 4e-05 L
.8045 4e-05 L
.80451 4e-05 L
.80451 4e-05 L
.80452 4e-05 L
.80453 4e-05 L
.80454 4e-05 L
.80454 4e-05 L
.80455 4e-05 L
.80456 4e-05 L
.80456 4e-05 L
.80457 4e-05 L
.80457 4e-05 L
.80458 4e-05 L
.80459 4e-05 L
.8046 4e-05 L
.8046 4e-05 L
.80461 4e-05 L
.80462 4e-05 L
.80462 4e-05 L
.80463 4e-05 L
.80464 4e-05 L
.80465 4e-05 L
.80465 4e-05 L
.80466 4e-05 L
.80467 4e-05 L
.80468 4e-05 L
.80468 4e-05 L
.80469 4e-05 L
.80469 4e-05 L
.8047 4e-05 L
.80471 4e-05 L
.80472 4e-05 L
.80472 4e-05 L
.80473 4e-05 L
.80474 4e-05 L
.80474 4e-05 L
.80475 4e-05 L
.80476 4e-05 L
.80476 4e-05 L
.80477 4e-05 L
.80478 4e-05 L
.80479 4e-05 L
.80479 4e-05 L
.8048 4e-05 L
.8048 4e-05 L
Mistroke
.80481 4e-05 L
.80482 4e-05 L
.80482 4e-05 L
.80483 4e-05 L
.80483 4e-05 L
.80484 4e-05 L
.80485 4e-05 L
.80485 4e-05 L
.80486 4e-05 L
.80487 4e-05 L
.80488 4e-05 L
.80488 4e-05 L
.80489 4e-05 L
.80489 4e-05 L
.8049 4e-05 L
.8049 4e-05 L
.80491 4e-05 L
.80492 4e-05 L
.80492 4e-05 L
.80493 4e-05 L
.80494 4e-05 L
.80494 4e-05 L
.80495 4e-05 L
.80496 4e-05 L
.80496 4e-05 L
.80497 4e-05 L
.80498 4e-05 L
.80499 4e-05 L
.80499 4e-05 L
.805 4e-05 L
.80501 4e-05 L
.80502 4e-05 L
.80502 4e-05 L
.80503 4e-05 L
.80504 4e-05 L
.80504 4e-05 L
.80505 4e-05 L
.80506 4e-05 L
.80507 4e-05 L
.80507 4e-05 L
.80508 4e-05 L
.80508 4e-05 L
.80509 4e-05 L
.80509 4e-05 L
.8051 4e-05 L
.80511 4e-05 L
.80512 4e-05 L
.80512 4e-05 L
.80513 4e-05 L
.80514 4e-05 L
Mistroke
.80514 4e-05 L
.80515 4e-05 L
.80516 4e-05 L
.80517 4e-05 L
.80517 4e-05 L
.80518 4e-05 L
.80519 4e-05 L
.8052 4e-05 L
.8052 4e-05 L
.80521 4e-05 L
.80522 4e-05 L
.80522 4e-05 L
.80523 4e-05 L
.80523 4e-05 L
.80524 4e-05 L
.80524 4e-05 L
.80525 4e-05 L
.80525 4e-05 L
.80526 4e-05 L
.80526 4e-05 L
.80527 4e-05 L
.80527 4e-05 L
.80528 4e-05 L
.80528 4e-05 L
.80528 4e-05 L
.80529 4e-05 L
.8053 4e-05 L
.8053 4e-05 L
.80531 4e-05 L
.80532 4e-05 L
.80533 4e-05 L
.80533 4e-05 L
.80534 4e-05 L
.80535 4e-05 L
.80536 4e-05 L
.80536 4e-05 L
.80537 4e-05 L
.80538 4e-05 L
.80539 4e-05 L
.80539 4e-05 L
.8054 4e-05 L
.80541 4e-05 L
.80541 4e-05 L
.80542 4e-05 L
.80543 4e-05 L
.80543 4e-05 L
.80544 4e-05 L
.80545 4e-05 L
.80545 4e-05 L
.80546 4e-05 L
Mistroke
.80547 4e-05 L
.80547 4e-05 L
.80548 4e-05 L
.80549 4e-05 L
.8055 4e-05 L
.8055 4e-05 L
.80551 4e-05 L
.80552 4e-05 L
.80552 4e-05 L
.80552 4e-05 L
.80553 4e-05 L
.80554 4e-05 L
.80555 4e-05 L
.80556 4e-05 L
.80556 4e-05 L
.80557 4e-05 L
.80558 4e-05 L
.80558 4e-05 L
.80559 4e-05 L
.8056 4e-05 L
.80561 4e-05 L
.80561 4e-05 L
.80562 4e-05 L
.80563 4e-05 L
.80564 4e-05 L
.80564 4e-05 L
.80565 4e-05 L
.80565 4e-05 L
.80566 4e-05 L
.80567 4e-05 L
.80568 4e-05 L
.80568 4e-05 L
.80569 4e-05 L
.8057 4e-05 L
.8057 4e-05 L
.80571 4e-05 L
.80572 4e-05 L
.80572 4e-05 L
.80573 4e-05 L
.80574 4e-05 L
.80574 4e-05 L
.80575 4e-05 L
.80576 4e-05 L
.80576 4e-05 L
.80577 4e-05 L
.80578 4e-05 L
.80578 4e-05 L
.80579 4e-05 L
.80579 4e-05 L
.8058 4e-05 L
Mistroke
.80581 4e-05 L
.80581 4e-05 L
.80582 4e-05 L
.80583 4e-05 L
.80583 4e-05 L
.80584 4e-05 L
.80585 4e-05 L
.80585 4e-05 L
.80586 4e-05 L
.80586 4e-05 L
.80587 4e-05 L
.80587 4e-05 L
.80588 4e-05 L
.80589 4e-05 L
.8059 4e-05 L
.8059 4e-05 L
.80591 4e-05 L
.80592 4e-05 L
.80592 4e-05 L
.80593 4e-05 L
.80594 4e-05 L
.80595 4e-05 L
.80595 4e-05 L
.80596 4e-05 L
.80597 4e-05 L
.80597 4e-05 L
.80598 4e-05 L
.80599 4e-05 L
.806 4e-05 L
.806 4e-05 L
.80601 4e-05 L
.80602 4e-05 L
.80603 4e-05 L
.80603 4e-05 L
.80604 4e-05 L
.80604 4e-05 L
.80604 4e-05 L
.80605 4e-05 L
.80606 4e-05 L
.80607 4e-05 L
.80608 4e-05 L
.80608 4e-05 L
.80609 4e-05 L
.8061 4e-05 L
.8061 4e-05 L
.80611 4e-05 L
.80612 4e-05 L
.80613 4e-05 L
.80613 4e-05 L
.80614 4e-05 L
Mistroke
.80615 4e-05 L
.80616 4e-05 L
.80616 4e-05 L
.80617 4e-05 L
.80618 4e-05 L
.80618 4e-05 L
.80619 4e-05 L
.80619 4e-05 L
.8062 4e-05 L
.8062 4e-05 L
.80621 4e-05 L
.80621 4e-05 L
.80622 4e-05 L
.80622 4e-05 L
.80623 4e-05 L
.80623 4e-05 L
.80624 4e-05 L
.80624 4e-05 L
.80624 4e-05 L
.80625 4e-05 L
.80626 4e-05 L
.80626 4e-05 L
.80627 4e-05 L
.80628 4e-05 L
.80629 4e-05 L
.80629 4e-05 L
.8063 4e-05 L
.80631 4e-05 L
.80631 4e-05 L
.80632 4e-05 L
.80633 4e-05 L
.80634 4e-05 L
.80634 4e-05 L
.80635 4e-05 L
.80636 4e-05 L
.80636 4e-05 L
.80637 4e-05 L
.80638 4e-05 L
.80638 4e-05 L
.80639 4e-05 L
.8064 4e-05 L
.80641 4e-05 L
.80641 4e-05 L
.80642 4e-05 L
.80643 4e-05 L
.80643 4e-05 L
.80644 4e-05 L
.80645 4e-05 L
.80645 4e-05 L
.80646 4e-05 L
Mistroke
.80647 4e-05 L
.80648 4e-05 L
.80648 4e-05 L
.80648 4e-05 L
.80649 4e-05 L
.8065 4e-05 L
.80651 4e-05 L
.80651 4e-05 L
.80652 4e-05 L
.80653 4e-05 L
.80654 4e-05 L
.80654 4e-05 L
.80655 4e-05 L
.80656 4e-05 L
.80657 4e-05 L
.80657 4e-05 L
.80658 4e-05 L
.80659 4e-05 L
.8066 4e-05 L
.8066 4e-05 L
.8066 4e-05 L
.80661 4e-05 L
.80662 4e-05 L
.80663 4e-05 L
.80663 4e-05 L
.80664 4e-05 L
.80665 4e-05 L
.80666 4e-05 L
.80666 4e-05 L
.80667 4e-05 L
.80668 4e-05 L
.80668 4e-05 L
.80669 4e-05 L
.8067 4e-05 L
.8067 4e-05 L
.80671 4e-05 L
.80672 4e-05 L
.80672 4e-05 L
.80673 4e-05 L
.80673 4e-05 L
.80674 4e-05 L
.80675 4e-05 L
.80675 4e-05 L
.80676 4e-05 L
.80677 4e-05 L
.80677 4e-05 L
.80678 4e-05 L
.80679 4e-05 L
.80679 4e-05 L
.8068 4e-05 L
Mistroke
.80681 4e-05 L
.80681 4e-05 L
.80682 4e-05 L
.80682 4e-05 L
.80683 4e-05 L
.80683 4e-05 L
.80684 4e-05 L
.80685 4e-05 L
.80686 4e-05 L
.80686 4e-05 L
.80687 4e-05 L
.80688 4e-05 L
.80688 4e-05 L
.80689 4e-05 L
.8069 4e-05 L
.80691 4e-05 L
.80691 4e-05 L
.80692 4e-05 L
.80693 4e-05 L
.80693 4e-05 L
.80694 4e-05 L
.80695 4e-05 L
.80696 4e-05 L
.80696 4e-05 L
.80697 4e-05 L
.80698 4e-05 L
.80699 4e-05 L
.80699 4e-05 L
.80699 4e-05 L
.807 4e-05 L
.807 4e-05 L
.80701 4e-05 L
.80702 4e-05 L
.80703 4e-05 L
.80703 4e-05 L
.80704 4e-05 L
.80705 4e-05 L
.80706 4e-05 L
.80706 4e-05 L
.80707 4e-05 L
.80708 4e-05 L
.80709 4e-05 L
.80709 4e-05 L
.8071 4e-05 L
.80711 4e-05 L
.80712 4e-05 L
.80712 4e-05 L
.80713 4e-05 L
.80714 4e-05 L
.80714 4e-05 L
Mistroke
.80715 4e-05 L
.80715 4e-05 L
.80716 4e-05 L
.80716 4e-05 L
.80716 4e-05 L
.80717 4e-05 L
.80718 4e-05 L
.80718 4e-05 L
.80719 4e-05 L
.80719 4e-05 L
.80719 4e-05 L
.8072 4e-05 L
.8072 4e-05 L
.80721 4e-05 L
.80721 4e-05 L
.80722 4e-05 L
.80723 4e-05 L
.80724 4e-05 L
.80725 4e-05 L
.80725 4e-05 L
.80726 4e-05 L
.80727 4e-05 L
.80727 4e-05 L
.80728 4e-05 L
.80729 4e-05 L
.8073 4e-05 L
.8073 4e-05 L
.80731 4e-05 L
.80732 4e-05 L
.80732 4e-05 L
.80733 4e-05 L
.80734 4e-05 L
.80734 4e-05 L
.80735 4e-05 L
.80736 4e-05 L
.80737 4e-05 L
.80737 4e-05 L
.80738 4e-05 L
.80738 4e-05 L
.80739 4e-05 L
.8074 4e-05 L
.80741 4e-05 L
.80741 4e-05 L
.80742 4e-05 L
.80743 4e-05 L
.80743 4e-05 L
.80744 4e-05 L
.80744 4e-05 L
.80745 4e-05 L
.80746 4e-05 L
Mistroke
.80747 4e-05 L
.80747 4e-05 L
.80748 4e-05 L
.80749 4e-05 L
.8075 4e-05 L
.8075 4e-05 L
.80751 4e-05 L
.80752 4e-05 L
.80752 4e-05 L
.80753 4e-05 L
.80754 4e-05 L
.80755 4e-05 L
.80755 4e-05 L
.80756 4e-05 L
.80756 4e-05 L
.80757 4e-05 L
.80758 4e-05 L
.80759 4e-05 L
.80759 4e-05 L
.8076 4e-05 L
.80761 4e-05 L
.80761 4e-05 L
.80762 4e-05 L
.80763 4e-05 L
.80763 4e-05 L
.80764 4e-05 L
.80765 4e-05 L
.80766 4e-05 L
.80766 4e-05 L
.80767 4e-05 L
.80767 4e-05 L
.80768 4e-05 L
.80769 4e-05 L
.80769 4e-05 L
.8077 4e-05 L
.80771 4e-05 L
.80771 4e-05 L
.80772 4e-05 L
.80772 4e-05 L
.80773 4e-05 L
.80774 4e-05 L
.80774 4e-05 L
.80775 4e-05 L
.80776 4e-05 L
.80776 4e-05 L
.80777 4e-05 L
.80778 4e-05 L
.80778 4e-05 L
.80779 4e-05 L
.80779 4e-05 L
Mistroke
.8078 4e-05 L
.80781 4e-05 L
.80782 4e-05 L
.80782 4e-05 L
.80783 4e-05 L
.80784 4e-05 L
.80784 4e-05 L
.80785 4e-05 L
.80786 4e-05 L
.80786 4e-05 L
.80787 4e-05 L
.80788 4e-05 L
.80789 4e-05 L
.80789 4e-05 L
.8079 4e-05 L
.80791 4e-05 L
.80791 4e-05 L
.80792 4e-05 L
.80793 4e-05 L
.80793 4e-05 L
.80794 4e-05 L
.80795 4e-05 L
.80795 4e-05 L
.80796 4e-05 L
.80796 4e-05 L
.80797 4e-05 L
.80797 4e-05 L
.80798 4e-05 L
.80798 4e-05 L
.80799 4e-05 L
.80799 4e-05 L
.808 4e-05 L
.808 4e-05 L
.80801 4e-05 L
.80801 4e-05 L
.80802 4e-05 L
.80802 4e-05 L
.80803 4e-05 L
.80803 4e-05 L
.80804 4e-05 L
.80804 4e-05 L
.80805 4e-05 L
.80805 4e-05 L
.80806 4e-05 L
.80806 4e-05 L
.80807 4e-05 L
.80808 4e-05 L
.80808 4e-05 L
.80809 4e-05 L
.80809 4e-05 L
Mistroke
.8081 4e-05 L
Mfstroke
.80217 .76297 m
.80241 .76497 L
.80268 .76721 L
.80292 .76937 L
.80316 .77151 L
.80341 .77385 L
.80365 .77617 L
.80391 .77872 L
.80416 .78127 L
.8044 .7838 L
.80465 .78661 L
.8049 .78942 L
.80513 .79224 L
.80538 .79539 L
.80563 .79858 L
.80588 .80217 L
.80613 .80585 L
.80637 .80964 L
.80662 .814 L
.80686 .81861 L
.80712 .82409 L
.80737 .83016 L
.80761 .83718 L
.80773 .84145 L
.80787 .84713 L
.80792 .85013 L
.80799 .85401 L
.80802 .8563 L
.80805 .85891 L
.80807 .86198 L
.80808 .86306 L
.80809 .86443 L
.80809 .86596 L
.8081 .86998 L
s
.02713 4e-05 m
.02808 4e-05 L
.02895 4e-05 L
.02996 4e-05 L
.03091 4e-05 L
.03179 4e-05 L
.0326 4e-05 L
.03349 4e-05 L
.03443 4e-05 L
.03538 4e-05 L
.0364 4e-05 L
.03736 4e-05 L
.03824 4e-05 L
.03927 4e-05 L
.03985 4e-05 L
.04039 4e-05 L
.04138 4e-05 L
.04243 4e-05 L
.04296 4e-05 L
.04352 4e-05 L
.04453 4e-05 L
.04508 4e-05 L
.04561 4e-05 L
.04618 4e-05 L
.04679 4e-05 L
.04732 4e-05 L
.04789 4e-05 L
.04894 4e-05 L
.04995 4e-05 L
.0509 4e-05 L
.05181 4e-05 L
.05266 4e-05 L
.0536 4e-05 L
.05462 4e-05 L
.05562 4e-05 L
.05668 4e-05 L
.05758 4e-05 L
.05857 4e-05 L
.05915 4e-05 L
.05968 4e-05 L
.06026 4e-05 L
.06088 4e-05 L
.06192 4e-05 L
.06252 4e-05 L
.06307 4e-05 L
.0641 4e-05 L
.06504 4e-05 L
.06556 4e-05 L
.06613 4e-05 L
.06716 4e-05 L
Mistroke
.06778 4e-05 L
.06837 4e-05 L
.06889 4e-05 L
.06946 4e-05 L
.07009 4e-05 L
.07074 4e-05 L
.0713 4e-05 L
.07192 4e-05 L
.0725 4e-05 L
.07302 4e-05 L
.07363 4e-05 L
.0742 4e-05 L
.07522 4e-05 L
.0758 4e-05 L
.07633 4e-05 L
.07728 4e-05 L
.0783 4e-05 L
.07926 4e-05 L
.08015 4e-05 L
.08113 4e-05 L
.0822 4e-05 L
.08274 4e-05 L
.08331 4e-05 L
.08435 4e-05 L
.08492 4e-05 L
.08545 4e-05 L
.08603 4e-05 L
.08665 4e-05 L
.08768 4e-05 L
.08826 4e-05 L
.08881 4e-05 L
.08983 4e-05 L
.09076 4e-05 L
.09184 4e-05 L
.09286 4e-05 L
.09378 4e-05 L
.09478 4e-05 L
.09572 4e-05 L
.09658 4e-05 L
.09754 4e-05 L
.09859 4e-05 L
.09912 4e-05 L
.09968 4e-05 L
.1007 4e-05 L
.10126 4e-05 L
.10178 4e-05 L
.10235 4e-05 L
.10295 4e-05 L
.10396 4e-05 L
.10453 4e-05 L
Mistroke
.10507 4e-05 L
.10607 4e-05 L
.10698 4e-05 L
.10804 4e-05 L
.10904 4e-05 L
.10998 4e-05 L
.11084 4e-05 L
.11183 4e-05 L
.11276 4e-05 L
.11362 4e-05 L
.11441 4e-05 L
.11529 4e-05 L
.11621 4e-05 L
.11714 4e-05 L
.11813 4e-05 L
.11908 4e-05 L
.11993 4e-05 L
.12094 4e-05 L
.12151 4e-05 L
.12204 4e-05 L
.123 4e-05 L
.12402 4e-05 L
.12495 4e-05 L
.12597 4e-05 L
.12702 4e-05 L
.12801 4e-05 L
.12893 4e-05 L
.12977 4e-05 L
.13074 4e-05 L
.13166 4e-05 L
.13266 4e-05 L
.13371 4e-05 L
.13461 4e-05 L
.13561 4e-05 L
.13667 4e-05 L
.13727 4e-05 L
.13782 4e-05 L
.13888 4e-05 L
.13988 4e-05 L
.14082 4e-05 L
.14167 4e-05 L
.14265 4e-05 L
.14358 4e-05 L
.14444 4e-05 L
.14522 4e-05 L
.14609 4e-05 L
.147 4e-05 L
.14793 4e-05 L
.14892 4e-05 L
.14985 4e-05 L
Mistroke
.15071 4e-05 L
.15171 4e-05 L
.15227 4e-05 L
.15279 4e-05 L
.15375 4e-05 L
.15476 4e-05 L
.15574 4e-05 L
.15681 4e-05 L
.15782 4e-05 L
.15876 4e-05 L
.15969 4e-05 L
.16053 4e-05 L
.1615 4e-05 L
.16242 4e-05 L
.16342 4e-05 L
.16448 4e-05 L
.16538 4e-05 L
.16637 4e-05 L
.16744 4e-05 L
.16804 4e-05 L
.16858 4e-05 L
.16965 4e-05 L
.17065 4e-05 L
.17151 4e-05 L
.17245 4e-05 L
.17343 4e-05 L
.17436 4e-05 L
.17522 4e-05 L
.176 4e-05 L
.17687 4e-05 L
.17778 4e-05 L
.17871 4e-05 L
.1797 4e-05 L
.18064 4e-05 L
.18149 4e-05 L
.18249 4e-05 L
.18305 4e-05 L
.18357 4e-05 L
.18453 4e-05 L
.18554 4e-05 L
.18653 4e-05 L
.1876 4e-05 L
.18861 4e-05 L
.18955 4e-05 L
.19048 4e-05 L
.19133 4e-05 L
.1923 4e-05 L
.19322 4e-05 L
.19422 4e-05 L
.19528 4e-05 L
Mistroke
.19619 4e-05 L
.19718 4e-05 L
.19825 4e-05 L
.19885 4e-05 L
.1994 4e-05 L
.20046 4e-05 L
.20146 4e-05 L
.20232 4e-05 L
.20326 4e-05 L
.20425 4e-05 L
.20517 4e-05 L
.20604 4e-05 L
.20683 4e-05 L
.20769 4e-05 L
.2086 4e-05 L
.20953 4e-05 L
.21053 4e-05 L
.21146 4e-05 L
.21231 4e-05 L
.21331 4e-05 L
.21388 4e-05 L
.2144 4e-05 L
.21535 4e-05 L
.21636 4e-05 L
.21735 4e-05 L
.21843 4e-05 L
.21945 4e-05 L
.22039 4e-05 L
.22123 4e-05 L
.22217 4e-05 L
.22314 4e-05 L
.22406 4e-05 L
.22507 4e-05 L
.22613 4e-05 L
.22704 4e-05 L
.22803 4e-05 L
.2291 4e-05 L
.22971 4e-05 L
.23025 4e-05 L
.23131 4e-05 L
.23232 4e-05 L
.23318 4e-05 L
.23412 4e-05 L
.23511 4e-05 L
.23604 4e-05 L
.2369 4e-05 L
.23769 4e-05 L
.2386 4e-05 L
.23947 4e-05 L
.2404 4e-05 L
Mistroke
.24139 4e-05 L
.24233 4e-05 L
.24318 4e-05 L
.24418 4e-05 L
.24475 4e-05 L
.24527 4e-05 L
.24622 4e-05 L
.24723 4e-05 L
.24822 4e-05 L
.24878 4e-05 L
.2493 4e-05 L
.25025 4e-05 L
.25127 4e-05 L
.25217 4e-05 L
.25302 4e-05 L
.25394 4e-05 L
.25495 4e-05 L
.25595 4e-05 L
.25652 4e-05 L
.25705 4e-05 L
.25812 4e-05 L
.25872 4e-05 L
.25926 4e-05 L
.26024 4e-05 L
.2613 4e-05 L
.26229 4e-05 L
.26322 4e-05 L
.26408 4e-05 L
.265 4e-05 L
.26587 4e-05 L
.26667 4e-05 L
.2676 4e-05 L
.26862 4e-05 L
.26958 4e-05 L
.27046 4e-05 L
.27147 4e-05 L
.27242 4e-05 L
.27326 4e-05 L
.27418 4e-05 L
.27518 4e-05 L
.27624 4e-05 L
.27715 4e-05 L
.27814 4e-05 L
.2792 4e-05 L
.28019 4e-05 L
.2807 4e-05 L
.28127 4e-05 L
.28186 4e-05 L
.28242 4e-05 L
.28344 4e-05 L
Mistroke
.28437 4e-05 L
.28544 4e-05 L
.28647 4e-05 L
.28738 4e-05 L
.28835 4e-05 L
.28926 4e-05 L
.29009 4e-05 L
.29107 4e-05 L
.29213 4e-05 L
.29313 4e-05 L
.29405 4e-05 L
.29503 4e-05 L
.29609 4e-05 L
.29709 4e-05 L
.298 4e-05 L
.29906 4e-05 L
.29966 4e-05 L
.30022 4e-05 L
.30124 4e-05 L
.30176 4e-05 L
.30233 4e-05 L
.30288 4e-05 L
.30346 4e-05 L
.3045 4e-05 L
.30508 4e-05 L
.30562 4e-05 L
.30621 4e-05 L
.30684 4e-05 L
.30739 4e-05 L
.30799 4e-05 L
.30855 4e-05 L
.30906 4e-05 L
.31004 4e-05 L
.31108 4e-05 L
.31207 4e-05 L
.31314 4e-05 L
.31415 4e-05 L
.31509 4e-05 L
.31602 4e-05 L
.31686 4e-05 L
.31784 4e-05 L
.31875 4e-05 L
.31976 4e-05 L
.32082 4e-05 L
.32172 4e-05 L
.32271 4e-05 L
.32378 4e-05 L
.32438 4e-05 L
.32493 4e-05 L
.32599 4e-05 L
Mistroke
.327 4e-05 L
.32785 4e-05 L
.3288 4e-05 L
.32978 4e-05 L
.33071 4e-05 L
.33157 4e-05 L
.33236 4e-05 L
.33322 4e-05 L
.33414 4e-05 L
.33507 4e-05 L
.33606 4e-05 L
.33699 4e-05 L
.33784 4e-05 L
.33884 4e-05 L
.33941 4e-05 L
.33993 4e-05 L
.34088 4e-05 L
.3419 4e-05 L
.34288 4e-05 L
.34396 4e-05 L
.34497 4e-05 L
.34592 4e-05 L
.34685 4e-05 L
.34769 4e-05 L
.34867 4e-05 L
.34959 4e-05 L
.35059 4e-05 L
.35166 4e-05 L
.35256 4e-05 L
.35356 4e-05 L
.35463 4e-05 L
.35523 4e-05 L
.35578 4e-05 L
.35684 4e-05 L
.35784 4e-05 L
.3587 4e-05 L
.35965 4e-05 L
.36063 4e-05 L
.36156 4e-05 L
.36242 4e-05 L
.36321 4e-05 L
.36412 4e-05 L
.36499 4e-05 L
.36592 4e-05 L
.36691 4e-05 L
.36785 4e-05 L
.3687 4e-05 L
.3697 4e-05 L
.37027 4e-05 L
.37079 4e-05 L
Mistroke
.37174 4e-05 L
.37275 4e-05 L
.37374 4e-05 L
.3743 4e-05 L
.37482 4e-05 L
.37577 4e-05 L
.37678 4e-05 L
.37769 4e-05 L
.37853 4e-05 L
.37946 4e-05 L
.38046 4e-05 L
.38147 4e-05 L
.38203 4e-05 L
.38256 4e-05 L
.38363 4e-05 L
.38423 4e-05 L
.38477 4e-05 L
.38575 4e-05 L
.38681 4e-05 L
.38781 4e-05 L
.38873 4e-05 L
.38959 4e-05 L
.39051 4e-05 L
.39138 4e-05 L
.39218 4e-05 L
.39311 4e-05 L
.39413 4e-05 L
.39509 4e-05 L
.39598 4e-05 L
.39698 4e-05 L
.39793 4e-05 L
.39877 4e-05 L
.39969 4e-05 L
.4007 4e-05 L
.40175 4e-05 L
.40266 4e-05 L
.40365 4e-05 L
.40471 4e-05 L
.4057 4e-05 L
.40621 4e-05 L
.40678 4e-05 L
.40737 4e-05 L
.40793 4e-05 L
.40894 4e-05 L
.40987 4e-05 L
.4109 4e-05 L
.41197 4e-05 L
.41288 4e-05 L
.41385 4e-05 L
.41477 4e-05 L
Mistroke
.4156 4e-05 L
.41657 4e-05 L
.41763 4e-05 L
.41863 4e-05 L
.41955 4e-05 L
.42054 4e-05 L
.42159 4e-05 L
.42259 4e-05 L
.4235 4e-05 L
.42456 4e-05 L
.42516 4e-05 L
.42572 4e-05 L
.42674 4e-05 L
.42726 4e-05 L
.42783 4e-05 L
.42838 4e-05 L
.42896 4e-05 L
.43 4e-05 L
.43058 4e-05 L
.43112 4e-05 L
.43171 4e-05 L
.43234 4e-05 L
.43289 4e-05 L
.43349 4e-05 L
.43405 4e-05 L
.43456 4e-05 L
.43555 4e-05 L
.43658 4e-05 L
.43757 4e-05 L
.43864 4e-05 L
.43965 4e-05 L
.44059 4e-05 L
.44152 4e-05 L
.44236 4e-05 L
.44333 4e-05 L
.44425 4e-05 L
.44525 4e-05 L
.44631 4e-05 L
.44722 4e-05 L
.44821 4e-05 L
.44928 4e-05 L
.44988 4e-05 L
.45042 4e-05 L
.45149 4e-05 L
.45249 4e-05 L
.45335 4e-05 L
.45429 4e-05 L
.45527 4e-05 L
.4562 4e-05 L
.45706 4e-05 L
Mistroke
.45785 4e-05 L
.45872 4e-05 L
.45963 4e-05 L
.46056 4e-05 L
.46155 4e-05 L
.46248 4e-05 L
.46333 4e-05 L
.46433 4e-05 L
.4649 4e-05 L
.46542 4e-05 L
.46638 4e-05 L
.46739 4e-05 L
.46837 4e-05 L
.46945 4e-05 L
.47046 4e-05 L
.4714 4e-05 L
.47234 4e-05 L
.47318 4e-05 L
.47416 4e-05 L
.47507 4e-05 L
.47608 4e-05 L
.47714 4e-05 L
.47805 4e-05 L
.47904 4e-05 L
.48011 4e-05 L
.48071 4e-05 L
.48126 4e-05 L
.48232 4e-05 L
.48333 4e-05 L
.48418 4e-05 L
.48513 4e-05 L
.48612 4e-05 L
.48704 4e-05 L
.4879 4e-05 L
.48869 4e-05 L
.4896 4e-05 L
.49047 4e-05 L
.4914 4e-05 L
.49239 4e-05 L
.49333 4e-05 L
.49418 4e-05 L
.49518 4e-05 L
.49575 4e-05 L
.49627 4e-05 L
.49722 4e-05 L
.49823 4e-05 L
.49922 4e-05 L
.49978 4e-05 L
.5003 4e-05 L
.50125 4e-05 L
Mistroke
.50226 4e-05 L
.50316 4e-05 L
.50401 4e-05 L
.50494 4e-05 L
.50594 4e-05 L
.50694 4e-05 L
.50751 4e-05 L
.50804 4e-05 L
.50911 4e-05 L
.5097 4e-05 L
.51025 4e-05 L
.51122 4e-05 L
.51228 4e-05 L
.51328 4e-05 L
.5142 4e-05 L
.51506 4e-05 L
.51598 4e-05 L
.51686 4e-05 L
.51765 4e-05 L
.51858 4e-05 L
.5196 4e-05 L
.52056 4e-05 L
.52145 4e-05 L
.52245 4e-05 L
.5234 4e-05 L
.52424 4e-05 L
.52516 4e-05 L
.52617 4e-05 L
.52722 4e-05 L
.52813 4e-05 L
.52912 4e-05 L
.53018 4e-05 L
.53117 4e-05 L
.53168 4e-05 L
.53225 4e-05 L
.53284 4e-05 L
.53339 4e-05 L
.53441 4e-05 L
.53534 4e-05 L
.53636 4e-05 L
.53744 4e-05 L
.53835 4e-05 L
.53932 4e-05 L
.54023 4e-05 L
.54106 4e-05 L
.54204 4e-05 L
.5431 4e-05 L
.5441 4e-05 L
.54502 4e-05 L
.546 4e-05 L
Mistroke
.54706 4e-05 L
.54805 4e-05 L
.54896 4e-05 L
.55002 4e-05 L
.55063 4e-05 L
.55118 4e-05 L
.55221 4e-05 L
.55272 4e-05 L
.55329 4e-05 L
.55384 4e-05 L
.55442 4e-05 L
.55546 4e-05 L
.55604 4e-05 L
.55658 4e-05 L
.55717 4e-05 L
.5578 4e-05 L
.55835 4e-05 L
.55895 4e-05 L
.55951 4e-05 L
.56002 4e-05 L
.56101 4e-05 L
.56205 4e-05 L
.56303 4e-05 L
.5641 4e-05 L
.56511 4e-05 L
.56605 4e-05 L
.56697 4e-05 L
.56782 4e-05 L
.56879 4e-05 L
.56971 4e-05 L
.57071 4e-05 L
.57177 4e-05 L
.57267 4e-05 L
.57366 4e-05 L
.57473 4e-05 L
.57533 4e-05 L
.57588 4e-05 L
.57694 4e-05 L
.57794 4e-05 L
.5788 4e-05 L
.57974 4e-05 L
.58073 4e-05 L
.58165 4e-05 L
.58251 4e-05 L
.5833 4e-05 L
.58417 4e-05 L
.58508 4e-05 L
.58601 4e-05 L
.587 4e-05 L
.58793 4e-05 L
Mistroke
.58878 4e-05 L
.58978 4e-05 L
.59035 4e-05 L
.59087 4e-05 L
.59183 4e-05 L
.59284 4e-05 L
.59382 4e-05 L
.5949 4e-05 L
.59591 4e-05 L
.59685 4e-05 L
.59778 4e-05 L
.59863 4e-05 L
.5996 4e-05 L
.60052 4e-05 L
.60152 4e-05 L
.60259 4e-05 L
.60349 4e-05 L
.60448 4e-05 L
.60556 4e-05 L
.60616 4e-05 L
.6067 4e-05 L
.60776 4e-05 L
.60877 4e-05 L
.60963 4e-05 L
.61057 4e-05 L
.61156 4e-05 L
.61248 4e-05 L
.61334 4e-05 L
.61413 4e-05 L
.615 4e-05 L
.61591 4e-05 L
.61684 4e-05 L
.61784 4e-05 L
.61877 4e-05 L
.61962 4e-05 L
.62062 4e-05 L
.62119 4e-05 L
.62171 4e-05 L
.62266 4e-05 L
.62367 4e-05 L
.62466 4e-05 L
.62522 4e-05 L
.62574 4e-05 L
.62669 4e-05 L
.6277 4e-05 L
.6286 4e-05 L
.62945 4e-05 L
.63037 4e-05 L
.63137 4e-05 L
.63238 4e-05 L
Mistroke
.63294 4e-05 L
.63347 4e-05 L
.63454 4e-05 L
.63514 4e-05 L
.63568 4e-05 L
.63666 4e-05 L
.63772 4e-05 L
.63871 4e-05 L
.63964 4e-05 L
.64049 4e-05 L
.64142 4e-05 L
.64229 4e-05 L
.64308 4e-05 L
.64401 4e-05 L
.64503 4e-05 L
.64599 4e-05 L
.64688 4e-05 L
.64788 4e-05 L
.64883 4e-05 L
.64968 4e-05 L
.65059 4e-05 L
.6516 4e-05 L
.65265 4e-05 L
.65356 4e-05 L
.65455 4e-05 L
.65561 4e-05 L
.6566 4e-05 L
.65711 4e-05 L
.65768 4e-05 L
.65827 4e-05 L
.65882 4e-05 L
.65984 4e-05 L
.66077 4e-05 L
.66179 4e-05 L
.66286 4e-05 L
.66377 4e-05 L
.66474 4e-05 L
.66565 4e-05 L
.66648 4e-05 L
.66746 4e-05 L
.66852 4e-05 L
.66952 4e-05 L
.67044 4e-05 L
.67142 4e-05 L
.67248 4e-05 L
.67347 4e-05 L
.67438 4e-05 L
.67545 4e-05 L
.67605 4e-05 L
.6766 4e-05 L
Mistroke
.67763 4e-05 L
.6782 4e-05 L
.67871 4e-05 L
.67926 4e-05 L
.67984 4e-05 L
.68088 4e-05 L
.68146 4e-05 L
.682 4e-05 L
.68259 4e-05 L
.68322 4e-05 L
.68377 4e-05 L
.68437 4e-05 L
.68493 4e-05 L
.68545 4e-05 L
.68643 4e-05 L
.68747 4e-05 L
.68845 4e-05 L
.68951 4e-05 L
.69053 4e-05 L
.69146 4e-05 L
.69239 4e-05 L
.69323 4e-05 L
.69421 4e-05 L
.69512 4e-05 L
.69612 4e-05 L
.69718 4e-05 L
.69808 4e-05 L
.69908 4e-05 L
.70015 4e-05 L
.70074 4e-05 L
.70129 4e-05 L
.70235 4e-05 L
.70336 4e-05 L
.70421 4e-05 L
.70515 4e-05 L
.70614 4e-05 L
.70706 4e-05 L
.70792 4e-05 L
.70871 4e-05 L
.70958 4e-05 L
.71049 4e-05 L
.71142 4e-05 L
.71241 4e-05 L
.71334 4e-05 L
.71419 4e-05 L
.71519 4e-05 L
.71576 4e-05 L
.71628 4e-05 L
.71724 4e-05 L
.71825 4e-05 L
Mistroke
.71923 4e-05 L
.72031 4e-05 L
.72132 4e-05 L
.72226 4e-05 L
.72319 4e-05 L
.72403 4e-05 L
.72501 4e-05 L
.72592 4e-05 L
.72693 4e-05 L
.72799 4e-05 L
.7289 4e-05 L
.72989 4e-05 L
.73096 4e-05 L
.73156 4e-05 L
.73211 4e-05 L
.73317 4e-05 L
.73417 4e-05 L
.73503 4e-05 L
.73597 4e-05 L
.73696 4e-05 L
.73788 4e-05 L
.73875 4e-05 L
.73954 4e-05 L
.7404 4e-05 L
.74131 4e-05 L
.74224 4e-05 L
.74324 4e-05 L
.74417 4e-05 L
.74502 4e-05 L
.74602 4e-05 L
.74659 4e-05 L
.74711 4e-05 L
.74806 4e-05 L
.74907 4e-05 L
.75006 4e-05 L
.75062 4e-05 L
.75114 4e-05 L
.75209 4e-05 L
.7531 4e-05 L
.754 4e-05 L
.75484 4e-05 L
.75577 4e-05 L
.75677 4e-05 L
.75777 4e-05 L
.75834 4e-05 L
.75887 4e-05 L
.75993 4e-05 L
.76053 4e-05 L
.76108 4e-05 L
.76205 4e-05 L
Mistroke
.76311 4e-05 L
.76411 4e-05 L
.76503 4e-05 L
.76589 4e-05 L
.76681 4e-05 L
.76768 4e-05 L
.76847 4e-05 L
.7694 4e-05 L
.77042 4e-05 L
.77138 4e-05 L
.77227 4e-05 L
.77327 4e-05 L
.77422 4e-05 L
.77507 4e-05 L
.77598 4e-05 L
.77699 4e-05 L
.77804 4e-05 L
.77895 4e-05 L
.77994 4e-05 L
.78066 4e-05 L
.78132 4e-05 L
.78205 4e-05 L
.78282 4e-05 L
.78349 4e-05 L
.78412 4e-05 L
.78481 4e-05 L
.78556 4e-05 L
.78618 4e-05 L
.78686 4e-05 L
.78757 4e-05 L
.78823 4e-05 L
.78885 4e-05 L
.78941 4e-05 L
.79006 4e-05 L
.79067 4e-05 L
.79134 4e-05 L
.79207 4e-05 L
.79283 4e-05 L
.79354 4e-05 L
.79421 4e-05 L
.79482 4e-05 L
.79552 4e-05 L
.79619 4e-05 L
.79691 4e-05 L
.79768 4e-05 L
.7984 4e-05 L
.79905 4e-05 L
.79983 4e-05 L
.80066 4e-05 L
.80145 4e-05 L
Mistroke
.80217 4e-05 L
Mfstroke
.02713 4e-05 m
.05857 .01972 L
.09286 .04131 L
.12506 .06171 L
.15603 .08148 L
.189 .10268 L
.22073 .12328 L
.25446 .1454 L
.28695 .16696 L
.31821 .18797 L
.35147 .21066 L
.3835 .2329 L
.41429 .25471 L
.44707 .27847 L
.47862 .30199 L
.51217 .32785 L
.54449 .35381 L
.57557 .38002 L
.60865 .40968 L
.64049 .44057 L
.67433 .47702 L
.70694 .51757 L
.73831 .56516 L
.75422 .59481 L
.77168 .63501 L
.77929 .65663 L
.78745 .68446 L
.7914 .70058 L
.79515 .71827 L
.80217 .76297 L
s
.5 1 1 r
.02713 4e-05 m
.02808 4e-05 L
.02895 4e-05 L
.02996 4e-05 L
.03091 4e-05 L
.03179 4e-05 L
.0326 4e-05 L
.03349 4e-05 L
.03443 4e-05 L
.03538 4e-05 L
.0364 4e-05 L
.03736 4e-05 L
.03824 4e-05 L
.03927 4e-05 L
.03985 4e-05 L
.04039 4e-05 L
.04138 4e-05 L
.04243 4e-05 L
.04296 4e-05 L
.04352 4e-05 L
.04453 4e-05 L
.04508 4e-05 L
.04561 4e-05 L
.04618 4e-05 L
.04679 4e-05 L
.04732 4e-05 L
.04789 4e-05 L
.04894 4e-05 L
.04995 4e-05 L
.0509 4e-05 L
.05181 4e-05 L
.05266 4e-05 L
.0536 4e-05 L
.05462 4e-05 L
.05562 4e-05 L
.05668 4e-05 L
.05758 4e-05 L
.05857 4e-05 L
.05915 4e-05 L
.05968 4e-05 L
.06026 4e-05 L
.06088 4e-05 L
.06192 4e-05 L
.06252 4e-05 L
.06307 4e-05 L
.0641 4e-05 L
.06504 4e-05 L
.06556 4e-05 L
.06613 4e-05 L
.06716 4e-05 L
.06778 4e-05 L
.06837 4e-05 L
.06889 4e-05 L
.06946 4e-05 L
.07009 4e-05 L
.07074 4e-05 L
.0713 4e-05 L
.07192 4e-05 L
.0725 4e-05 L
.07302 4e-05 L
.07363 4e-05 L
.0742 4e-05 L
.07522 4e-05 L
.0758 4e-05 L
.07633 4e-05 L
.07728 4e-05 L
.0783 4e-05 L
.07926 4e-05 L
.08015 4e-05 L
.08113 4e-05 L
.0822 4e-05 L
.08274 4e-05 L
.08331 4e-05 L
.08435 4e-05 L
.08492 4e-05 L
.08545 4e-05 L
.08603 4e-05 L
.08665 4e-05 L
.08768 4e-05 L
.08826 4e-05 L
.08881 4e-05 L
.08983 4e-05 L
.09076 4e-05 L
.09184 4e-05 L
.09286 4e-05 L
.09378 4e-05 L
.09478 4e-05 L
.09572 4e-05 L
.09658 4e-05 L
.09754 4e-05 L
.09859 4e-05 L
.09912 4e-05 L
.09968 4e-05 L
.1007 4e-05 L
.10126 4e-05 L
.10178 4e-05 L
.10235 4e-05 L
.10295 4e-05 L
.10396 4e-05 L
.10453 4e-05 L
.10507 4e-05 L
.10607 4e-05 L
.10698 4e-05 L
.10804 4e-05 L
.10904 4e-05 L
.10998 4e-05 L
.11084 4e-05 L
.11183 4e-05 L
.11276 4e-05 L
.11362 4e-05 L
.11441 4e-05 L
.11529 4e-05 L
.11621 4e-05 L
.11714 4e-05 L
.11813 4e-05 L
.11908 4e-05 L
.11993 4e-05 L
.12094 4e-05 L
.12151 4e-05 L
.12204 4e-05 L
.123 4e-05 L
.12402 4e-05 L
.12495 4e-05 L
.12597 4e-05 L
.12702 4e-05 L
.12801 4e-05 L
.12893 4e-05 L
.12977 4e-05 L
.13074 4e-05 L
.13166 4e-05 L
.13266 4e-05 L
.13371 4e-05 L
.13461 4e-05 L
.13561 4e-05 L
.13667 4e-05 L
.13727 4e-05 L
.13782 4e-05 L
.13888 4e-05 L
.13988 4e-05 L
.14082 4e-05 L
.14167 4e-05 L
.14265 4e-05 L
.14358 4e-05 L
.14444 4e-05 L
.14522 4e-05 L
.14609 4e-05 L
.147 4e-05 L
.14793 4e-05 L
.14892 4e-05 L
.14985 4e-05 L
.15071 4e-05 L
.15171 4e-05 L
.15227 4e-05 L
.15279 4e-05 L
.15375 4e-05 L
.15476 4e-05 L
.15574 4e-05 L
.15681 4e-05 L
.15782 4e-05 L
.15876 4e-05 L
.15969 4e-05 L
.16053 4e-05 L
.1615 4e-05 L
.16242 4e-05 L
.16342 4e-05 L
.16448 4e-05 L
.16538 4e-05 L
.16637 4e-05 L
.16744 4e-05 L
.16804 4e-05 L
.16858 4e-05 L
.16965 4e-05 L
.17065 4e-05 L
.17151 4e-05 L
.17245 4e-05 L
.17343 4e-05 L
.17436 4e-05 L
.17522 4e-05 L
.176 4e-05 L
.17687 4e-05 L
.17778 4e-05 L
.17871 4e-05 L
.1797 4e-05 L
.18064 4e-05 L
.18149 4e-05 L
.18249 4e-05 L
.18305 4e-05 L
.18357 4e-05 L
.18453 4e-05 L
.18554 4e-05 L
.18653 4e-05 L
.1876 4e-05 L
.18861 4e-05 L
.18955 4e-05 L
.19048 4e-05 L
.19133 4e-05 L
.1923 4e-05 L
.19322 4e-05 L
.19422 4e-05 L
.19528 4e-05 L
.19619 4e-05 L
.19718 4e-05 L
.19825 4e-05 L
.19885 4e-05 L
.1994 4e-05 L
.20046 4e-05 L
.20146 4e-05 L
.20232 4e-05 L
.20326 4e-05 L
.20425 4e-05 L
.20517 4e-05 L
.20604 4e-05 L
.20683 4e-05 L
.20769 4e-05 L
.2086 4e-05 L
.20953 4e-05 L
.21053 4e-05 L
.21146 4e-05 L
.21231 4e-05 L
.21331 4e-05 L
.21388 4e-05 L
.2144 4e-05 L
.21535 4e-05 L
.21636 4e-05 L
.21735 4e-05 L
.21843 4e-05 L
.21945 4e-05 L
.22039 4e-05 L
.22123 4e-05 L
.22217 4e-05 L
.22314 4e-05 L
.22406 4e-05 L
.22507 4e-05 L
.22613 4e-05 L
.22704 4e-05 L
.22803 4e-05 L
.2291 4e-05 L
.22971 4e-05 L
.23025 4e-05 L
.23131 4e-05 L
.23232 4e-05 L
.23318 4e-05 L
.23412 4e-05 L
.23511 4e-05 L
.23604 4e-05 L
.2369 4e-05 L
.23769 4e-05 L
.2386 4e-05 L
.23947 4e-05 L
.2404 4e-05 L
.24139 4e-05 L
.24233 4e-05 L
.24318 4e-05 L
.24418 4e-05 L
.24475 4e-05 L
.24527 4e-05 L
.24622 4e-05 L
.24723 4e-05 L
.24822 4e-05 L
.24878 4e-05 L
.2493 4e-05 L
.25025 4e-05 L
.25127 4e-05 L
.25217 4e-05 L
.25302 4e-05 L
.25394 4e-05 L
.25495 4e-05 L
.25595 4e-05 L
.25652 4e-05 L
.25705 4e-05 L
.25812 4e-05 L
.25872 4e-05 L
.25926 4e-05 L
.26024 4e-05 L
.2613 4e-05 L
.26229 4e-05 L
.26322 4e-05 L
.26408 4e-05 L
.265 4e-05 L
.26587 4e-05 L
.26667 4e-05 L
.2676 4e-05 L
.26862 4e-05 L
.26958 4e-05 L
.27046 4e-05 L
.27147 4e-05 L
.27242 4e-05 L
.27326 4e-05 L
.27418 4e-05 L
.27518 4e-05 L
.27624 4e-05 L
.27715 4e-05 L
.27814 4e-05 L
.2792 4e-05 L
.28019 4e-05 L
.2807 4e-05 L
.28127 4e-05 L
.28186 4e-05 L
.28242 4e-05 L
.28344 4e-05 L
.28437 4e-05 L
.28544 4e-05 L
.28647 4e-05 L
.28738 4e-05 L
.28835 4e-05 L
.28926 4e-05 L
.29009 4e-05 L
.29107 4e-05 L
.29213 4e-05 L
.29313 4e-05 L
.29405 4e-05 L
.29503 4e-05 L
.29609 4e-05 L
.29709 4e-05 L
.298 4e-05 L
.29906 4e-05 L
.29966 4e-05 L
.30022 4e-05 L
.30124 4e-05 L
.30176 4e-05 L
.30233 4e-05 L
.30288 4e-05 L
.30346 4e-05 L
.3045 4e-05 L
.30508 4e-05 L
.30562 4e-05 L
.30621 4e-05 L
.30684 4e-05 L
.30739 4e-05 L
.30799 4e-05 L
.30855 4e-05 L
.30906 4e-05 L
.31004 4e-05 L
.31108 4e-05 L
.31207 4e-05 L
.31314 4e-05 L
.31415 4e-05 L
.31509 4e-05 L
.31602 4e-05 L
.31686 4e-05 L
.31784 4e-05 L
.31875 4e-05 L
.31976 4e-05 L
.32082 4e-05 L
.32172 4e-05 L
.32271 4e-05 L
.32378 4e-05 L
.32438 4e-05 L
.32493 4e-05 L
.32599 4e-05 L
.327 4e-05 L
.32785 4e-05 L
.3288 4e-05 L
.32978 4e-05 L
.33071 4e-05 L
.33157 4e-05 L
.33236 4e-05 L
.33322 4e-05 L
.33414 4e-05 L
.33507 4e-05 L
.33606 4e-05 L
.33699 4e-05 L
.33784 4e-05 L
.33884 4e-05 L
.33941 4e-05 L
.33993 4e-05 L
.34088 4e-05 L
.3419 4e-05 L
.34288 4e-05 L
.34396 4e-05 L
.34497 4e-05 L
.34592 4e-05 L
.34685 4e-05 L
.34769 4e-05 L
.34867 4e-05 L
.34959 4e-05 L
.35059 4e-05 L
.35166 4e-05 L
.35256 4e-05 L
.35356 4e-05 L
.35463 4e-05 L
.35523 4e-05 L
.35578 4e-05 L
.35684 4e-05 L
.35784 4e-05 L
.3587 4e-05 L
.35965 4e-05 L
.36063 4e-05 L
.36156 4e-05 L
.36242 4e-05 L
.36321 4e-05 L
.36412 4e-05 L
.36499 4e-05 L
.36592 4e-05 L
.36691 4e-05 L
.36785 4e-05 L
.3687 4e-05 L
.3697 4e-05 L
.37027 4e-05 L
.37079 4e-05 L
.37174 4e-05 L
.37275 4e-05 L
.37374 4e-05 L
.3743 4e-05 L
.37482 4e-05 L
.37577 4e-05 L
.37678 4e-05 L
.37769 4e-05 L
.37853 4e-05 L
.37946 4e-05 L
.38046 4e-05 L
.38147 4e-05 L
.38203 4e-05 L
.38256 4e-05 L
.38363 4e-05 L
.38423 4e-05 L
.38477 4e-05 L
.38575 4e-05 L
.38681 4e-05 L
.38781 4e-05 L
.38873 4e-05 L
.38959 4e-05 L
.39051 4e-05 L
.39138 4e-05 L
.39218 4e-05 L
.39311 4e-05 L
.39413 4e-05 L
.39509 4e-05 L
.39598 4e-05 L
.39698 4e-05 L
.39793 4e-05 L
.39877 4e-05 L
.39969 4e-05 L
.4007 4e-05 L
.40175 4e-05 L
.40266 4e-05 L
.40365 4e-05 L
.40471 4e-05 L
.4057 4e-05 L
.40621 4e-05 L
.40678 4e-05 L
.40737 4e-05 L
.40793 4e-05 L
.40894 4e-05 L
.40987 4e-05 L
.4109 4e-05 L
.41197 4e-05 L
.41288 4e-05 L
.41385 4e-05 L
.41477 4e-05 L
.4156 4e-05 L
.41657 4e-05 L
.41763 4e-05 L
.41863 4e-05 L
.41955 4e-05 L
.42054 4e-05 L
.42159 4e-05 L
.42259 4e-05 L
.4235 4e-05 L
.42456 4e-05 L
.42516 4e-05 L
.42572 4e-05 L
.42674 4e-05 L
.42726 4e-05 L
.42783 4e-05 L
.42838 4e-05 L
.42896 4e-05 L
.43 4e-05 L
.43058 4e-05 L
.43112 4e-05 L
.43171 4e-05 L
.43234 4e-05 L
.43289 4e-05 L
.43349 4e-05 L
.43405 4e-05 L
.43456 4e-05 L
.43555 4e-05 L
.43658 4e-05 L
.43757 4e-05 L
.43864 4e-05 L
.43965 4e-05 L
.44059 4e-05 L
.44152 4e-05 L
.44236 4e-05 L
.44333 4e-05 L
.44425 4e-05 L
.44525 4e-05 L
.44631 4e-05 L
.44722 4e-05 L
.44821 4e-05 L
.44928 4e-05 L
.44988 4e-05 L
.45042 4e-05 L
.45149 4e-05 L
.45249 4e-05 L
.45335 4e-05 L
.45429 4e-05 L
.45527 4e-05 L
.4562 4e-05 L
.45706 4e-05 L
.45785 4e-05 L
.45872 4e-05 L
.45963 4e-05 L
.46056 4e-05 L
.46155 4e-05 L
.46248 4e-05 L
.46333 4e-05 L
.46433 4e-05 L
.4649 4e-05 L
.46542 4e-05 L
.46638 4e-05 L
.46739 4e-05 L
.46837 4e-05 L
.46945 4e-05 L
.47046 4e-05 L
.4714 4e-05 L
.47234 4e-05 L
.47318 4e-05 L
.47416 4e-05 L
.47507 4e-05 L
.47608 4e-05 L
.47714 4e-05 L
.47805 4e-05 L
.47904 4e-05 L
.48011 4e-05 L
.48071 4e-05 L
.48126 4e-05 L
.48232 4e-05 L
.48333 4e-05 L
.48418 4e-05 L
.48513 4e-05 L
.48612 4e-05 L
.48704 4e-05 L
.4879 4e-05 L
.48869 4e-05 L
.4896 4e-05 L
.49047 4e-05 L
.4914 4e-05 L
.49239 4e-05 L
.49333 4e-05 L
.49418 4e-05 L
.49518 4e-05 L
.49575 4e-05 L
.49627 4e-05 L
.49722 4e-05 L
.49823 4e-05 L
.49922 4e-05 L
.49978 4e-05 L
.5003 4e-05 L
.50125 4e-05 L
.50226 4e-05 L
.50316 4e-05 L
.50401 4e-05 L
.50494 4e-05 L
.50594 4e-05 L
.50694 4e-05 L
.50751 4e-05 L
.50804 4e-05 L
.50911 4e-05 L
.5097 4e-05 L
.51025 4e-05 L
.51122 4e-05 L
.51228 4e-05 L
.51328 4e-05 L
.5142 4e-05 L
.51506 4e-05 L
.51598 4e-05 L
.51686 4e-05 L
.51765 4e-05 L
.51858 4e-05 L
.5196 4e-05 L
.52056 4e-05 L
.52145 4e-05 L
.52245 4e-05 L
.5234 4e-05 L
.52424 4e-05 L
.52516 4e-05 L
.52617 4e-05 L
.52722 4e-05 L
.52813 4e-05 L
.52912 4e-05 L
.53018 4e-05 L
.53117 4e-05 L
.53168 4e-05 L
.53225 4e-05 L
.53284 4e-05 L
.53339 4e-05 L
.53441 4e-05 L
.53534 4e-05 L
.53636 4e-05 L
.53744 4e-05 L
.53835 4e-05 L
.53932 4e-05 L
.54023 4e-05 L
.54106 4e-05 L
.54204 4e-05 L
.5431 4e-05 L
.5441 4e-05 L
.54502 4e-05 L
.546 4e-05 L
.54706 4e-05 L
.54805 4e-05 L
.54896 4e-05 L
.55002 4e-05 L
.55063 4e-05 L
.55118 4e-05 L
.55221 4e-05 L
.55272 4e-05 L
.55329 4e-05 L
.55384 4e-05 L
.55442 4e-05 L
.55546 4e-05 L
.55604 4e-05 L
.55658 4e-05 L
.55717 4e-05 L
.5578 4e-05 L
.55835 4e-05 L
.55895 4e-05 L
.55951 4e-05 L
.56002 4e-05 L
.56101 4e-05 L
.56205 4e-05 L
.56303 4e-05 L
.5641 4e-05 L
.56511 4e-05 L
.56605 4e-05 L
.56697 4e-05 L
.56782 4e-05 L
.56879 4e-05 L
.56971 4e-05 L
.57071 4e-05 L
.57177 4e-05 L
.57267 4e-05 L
.57366 4e-05 L
.57473 4e-05 L
.57533 4e-05 L
.57588 4e-05 L
.57694 4e-05 L
.57794 4e-05 L
.5788 4e-05 L
.57974 4e-05 L
.58073 4e-05 L
.58165 4e-05 L
.58251 4e-05 L
.5833 4e-05 L
.58417 4e-05 L
.58508 4e-05 L
.58601 4e-05 L
.587 4e-05 L
.58793 4e-05 L
.58878 4e-05 L
.58978 4e-05 L
.59035 4e-05 L
.59087 4e-05 L
.59183 4e-05 L
.59284 4e-05 L
.59382 4e-05 L
.5949 4e-05 L
.59591 4e-05 L
.59685 4e-05 L
.59778 4e-05 L
.59863 4e-05 L
.5996 4e-05 L
.60052 4e-05 L
.60152 4e-05 L
.60259 4e-05 L
.60349 4e-05 L
.60448 4e-05 L
.60556 4e-05 L
.60616 4e-05 L
.6067 4e-05 L
.60776 4e-05 L
.60877 4e-05 L
.60963 4e-05 L
.61057 4e-05 L
.61156 4e-05 L
.61248 4e-05 L
.61334 4e-05 L
.61413 4e-05 L
.615 4e-05 L
.61591 4e-05 L
.61684 4e-05 L
.61784 4e-05 L
.61877 4e-05 L
.61962 4e-05 L
.62062 4e-05 L
.62119 4e-05 L
.62171 4e-05 L
.62266 4e-05 L
.62367 4e-05 L
.62466 4e-05 L
.62522 4e-05 L
.62574 4e-05 L
.62669 4e-05 L
.6277 4e-05 L
.6286 4e-05 L
.62945 4e-05 L
.63037 4e-05 L
.63137 4e-05 L
.63238 4e-05 L
.63294 4e-05 L
.63347 4e-05 L
.63454 4e-05 L
.63514 4e-05 L
.63568 4e-05 L
.63666 4e-05 L
.63772 4e-05 L
.63871 4e-05 L
.63964 4e-05 L
.64049 4e-05 L
.64142 4e-05 L
.64229 4e-05 L
.64308 4e-05 L
.64401 4e-05 L
.64503 4e-05 L
.64599 4e-05 L
.64688 4e-05 L
.64788 4e-05 L
.64883 4e-05 L
.64968 4e-05 L
.65059 4e-05 L
.6516 4e-05 L
.65265 4e-05 L
.65356 4e-05 L
.65455 4e-05 L
.65561 4e-05 L
.6566 4e-05 L
.65711 4e-05 L
.65768 4e-05 L
.65827 4e-05 L
.65882 4e-05 L
.65984 4e-05 L
.66077 4e-05 L
.66179 4e-05 L
.66286 4e-05 L
.66377 4e-05 L
.66474 4e-05 L
.66565 4e-05 L
.66648 4e-05 L
.66746 4e-05 L
.66852 4e-05 L
.66952 4e-05 L
.67044 4e-05 L
.67142 4e-05 L
.67248 4e-05 L
.67347 4e-05 L
.67438 4e-05 L
.67545 4e-05 L
.67605 4e-05 L
.6766 4e-05 L
.67763 4e-05 L
.6782 4e-05 L
.67871 4e-05 L
.67926 4e-05 L
.67984 4e-05 L
.68088 4e-05 L
.68146 4e-05 L
.682 4e-05 L
.68259 4e-05 L
.68322 4e-05 L
.68377 4e-05 L
.68437 4e-05 L
.68493 4e-05 L
.68545 4e-05 L
.68643 4e-05 L
.68747 4e-05 L
.68845 4e-05 L
.68951 4e-05 L
.69053 4e-05 L
.69146 4e-05 L
.69239 4e-05 L
.69323 4e-05 L
.69421 4e-05 L
.69512 4e-05 L
.69612 4e-05 L
.69718 4e-05 L
.69808 4e-05 L
.69908 4e-05 L
.70015 4e-05 L
.70074 4e-05 L
.70129 4e-05 L
.70235 4e-05 L
.70336 4e-05 L
.70421 4e-05 L
.70515 4e-05 L
.70614 4e-05 L
.70706 4e-05 L
.70792 4e-05 L
.70871 4e-05 L
.70958 4e-05 L
.71049 4e-05 L
.71142 4e-05 L
.71241 4e-05 L
.71334 4e-05 L
.71419 4e-05 L
.71519 4e-05 L
.71576 4e-05 L
.71628 4e-05 L
.71724 4e-05 L
.71825 4e-05 L
.71923 4e-05 L
.72031 4e-05 L
.72132 4e-05 L
.72226 4e-05 L
.72319 4e-05 L
.72403 4e-05 L
.72501 4e-05 L
.72592 4e-05 L
.72693 4e-05 L
.72799 4e-05 L
.7289 4e-05 L
.72989 4e-05 L
.73096 4e-05 L
.73156 4e-05 L
.73211 4e-05 L
.73317 4e-05 L
.73417 4e-05 L
.73503 4e-05 L
.73597 4e-05 L
.73696 4e-05 L
.73788 4e-05 L
.73875 4e-05 L
.73954 4e-05 L
.7404 4e-05 L
.74131 4e-05 L
.74224 4e-05 L
.74324 4e-05 L
.74417 4e-05 L
.74502 4e-05 L
.74602 4e-05 L
.74659 4e-05 L
.74711 4e-05 L
.74806 4e-05 L
.74907 4e-05 L
.75006 4e-05 L
.75062 4e-05 L
.75114 4e-05 L
.75209 4e-05 L
.7531 4e-05 L
.754 4e-05 L
.75484 4e-05 L
.75577 4e-05 L
.75677 4e-05 L
.75777 4e-05 L
.75834 4e-05 L
.75887 4e-05 L
.75993 4e-05 L
.76053 4e-05 L
.76108 4e-05 L
.76205 4e-05 L
.76311 4e-05 L
.76411 4e-05 L
.76503 4e-05 L
.76589 4e-05 L
.76681 4e-05 L
.76768 4e-05 L
.76847 4e-05 L
.7694 4e-05 L
.77042 4e-05 L
.77138 4e-05 L
.77227 4e-05 L
.77327 4e-05 L
.77422 4e-05 L
.77507 4e-05 L
.77598 4e-05 L
.77699 4e-05 L
.77804 4e-05 L
.77895 4e-05 L
.77994 4e-05 L
.78066 4e-05 L
.78132 4e-05 L
.78205 4e-05 L
.78282 4e-05 L
.78349 4e-05 L
.78412 4e-05 L
.78481 4e-05 L
.78556 4e-05 L
.78618 4e-05 L
.78686 4e-05 L
.78757 4e-05 L
.78823 4e-05 L
.78885 4e-05 L
.78941 4e-05 L
.79006 4e-05 L
.79067 4e-05 L
.79134 4e-05 L
.79207 4e-05 L
.79283 4e-05 L
.79354 4e-05 L
.79421 4e-05 L
.79482 4e-05 L
.79552 4e-05 L
.79619 4e-05 L
.79691 4e-05 L
.79768 4e-05 L
.7984 4e-05 L
.79905 4e-05 L
.79983 4e-05 L
.80066 4e-05 L
.80145 4e-05 L
.80217 4e-05 L
.80217 .76297 L
.79515 .71827 L
.7914 .70058 L
.78745 .68446 L
.77929 .65663 L
.77168 .63501 L
.75422 .59481 L
.73831 .56516 L
.70694 .51757 L
.67433 .47702 L
.64049 .44057 L
.60865 .40968 L
.57557 .38002 L
.54449 .35381 L
.51217 .32785 L
.47862 .30199 L
.44707 .27847 L
.41429 .25471 L
.3835 .2329 L
.35147 .21066 L
.31821 .18797 L
.28695 .16696 L
.25446 .1454 L
.22073 .12328 L
.189 .10268 L
.15603 .08148 L
.12506 .06171 L
.09286 .04131 L
.05857 .01972 L
.02713 4e-05 L
F
0 g
.02713 4e-05 m
.02808 4e-05 L
.02895 4e-05 L
.02996 4e-05 L
.03091 4e-05 L
.03179 4e-05 L
.0326 4e-05 L
.03349 4e-05 L
.03443 4e-05 L
.03538 4e-05 L
.0364 4e-05 L
.03736 4e-05 L
.03824 4e-05 L
.03927 4e-05 L
.03985 4e-05 L
.04039 4e-05 L
.04138 4e-05 L
.04243 4e-05 L
.04296 4e-05 L
.04352 4e-05 L
.04453 4e-05 L
.04508 4e-05 L
.04561 4e-05 L
.04618 4e-05 L
.04679 4e-05 L
.04732 4e-05 L
.04789 4e-05 L
.04894 4e-05 L
.04995 4e-05 L
.0509 4e-05 L
.05181 4e-05 L
.05266 4e-05 L
.0536 4e-05 L
.05462 4e-05 L
.05562 4e-05 L
.05668 4e-05 L
.05758 4e-05 L
.05857 4e-05 L
.05915 4e-05 L
.05968 4e-05 L
.06026 4e-05 L
.06088 4e-05 L
.06192 4e-05 L
.06252 4e-05 L
.06307 4e-05 L
.0641 4e-05 L
.06504 4e-05 L
.06556 4e-05 L
.06613 4e-05 L
.06716 4e-05 L
Mistroke
.06778 4e-05 L
.06837 4e-05 L
.06889 4e-05 L
.06946 4e-05 L
.07009 4e-05 L
.07074 4e-05 L
.0713 4e-05 L
.07192 4e-05 L
.0725 4e-05 L
.07302 4e-05 L
.07363 4e-05 L
.0742 4e-05 L
.07522 4e-05 L
.0758 4e-05 L
.07633 4e-05 L
.07728 4e-05 L
.0783 4e-05 L
.07926 4e-05 L
.08015 4e-05 L
.08113 4e-05 L
.0822 4e-05 L
.08274 4e-05 L
.08331 4e-05 L
.08435 4e-05 L
.08492 4e-05 L
.08545 4e-05 L
.08603 4e-05 L
.08665 4e-05 L
.08768 4e-05 L
.08826 4e-05 L
.08881 4e-05 L
.08983 4e-05 L
.09076 4e-05 L
.09184 4e-05 L
.09286 4e-05 L
.09378 4e-05 L
.09478 4e-05 L
.09572 4e-05 L
.09658 4e-05 L
.09754 4e-05 L
.09859 4e-05 L
.09912 4e-05 L
.09968 4e-05 L
.1007 4e-05 L
.10126 4e-05 L
.10178 4e-05 L
.10235 4e-05 L
.10295 4e-05 L
.10396 4e-05 L
.10453 4e-05 L
Mistroke
.10507 4e-05 L
.10607 4e-05 L
.10698 4e-05 L
.10804 4e-05 L
.10904 4e-05 L
.10998 4e-05 L
.11084 4e-05 L
.11183 4e-05 L
.11276 4e-05 L
.11362 4e-05 L
.11441 4e-05 L
.11529 4e-05 L
.11621 4e-05 L
.11714 4e-05 L
.11813 4e-05 L
.11908 4e-05 L
.11993 4e-05 L
.12094 4e-05 L
.12151 4e-05 L
.12204 4e-05 L
.123 4e-05 L
.12402 4e-05 L
.12495 4e-05 L
.12597 4e-05 L
.12702 4e-05 L
.12801 4e-05 L
.12893 4e-05 L
.12977 4e-05 L
.13074 4e-05 L
.13166 4e-05 L
.13266 4e-05 L
.13371 4e-05 L
.13461 4e-05 L
.13561 4e-05 L
.13667 4e-05 L
.13727 4e-05 L
.13782 4e-05 L
.13888 4e-05 L
.13988 4e-05 L
.14082 4e-05 L
.14167 4e-05 L
.14265 4e-05 L
.14358 4e-05 L
.14444 4e-05 L
.14522 4e-05 L
.14609 4e-05 L
.147 4e-05 L
.14793 4e-05 L
.14892 4e-05 L
.14985 4e-05 L
Mistroke
.15071 4e-05 L
.15171 4e-05 L
.15227 4e-05 L
.15279 4e-05 L
.15375 4e-05 L
.15476 4e-05 L
.15574 4e-05 L
.15681 4e-05 L
.15782 4e-05 L
.15876 4e-05 L
.15969 4e-05 L
.16053 4e-05 L
.1615 4e-05 L
.16242 4e-05 L
.16342 4e-05 L
.16448 4e-05 L
.16538 4e-05 L
.16637 4e-05 L
.16744 4e-05 L
.16804 4e-05 L
.16858 4e-05 L
.16965 4e-05 L
.17065 4e-05 L
.17151 4e-05 L
.17245 4e-05 L
.17343 4e-05 L
.17436 4e-05 L
.17522 4e-05 L
.176 4e-05 L
.17687 4e-05 L
.17778 4e-05 L
.17871 4e-05 L
.1797 4e-05 L
.18064 4e-05 L
.18149 4e-05 L
.18249 4e-05 L
.18305 4e-05 L
.18357 4e-05 L
.18453 4e-05 L
.18554 4e-05 L
.18653 4e-05 L
.1876 4e-05 L
.18861 4e-05 L
.18955 4e-05 L
.19048 4e-05 L
.19133 4e-05 L
.1923 4e-05 L
.19322 4e-05 L
.19422 4e-05 L
.19528 4e-05 L
Mistroke
.19619 4e-05 L
.19718 4e-05 L
.19825 4e-05 L
.19885 4e-05 L
.1994 4e-05 L
.20046 4e-05 L
.20146 4e-05 L
.20232 4e-05 L
.20326 4e-05 L
.20425 4e-05 L
.20517 4e-05 L
.20604 4e-05 L
.20683 4e-05 L
.20769 4e-05 L
.2086 4e-05 L
.20953 4e-05 L
.21053 4e-05 L
.21146 4e-05 L
.21231 4e-05 L
.21331 4e-05 L
.21388 4e-05 L
.2144 4e-05 L
.21535 4e-05 L
.21636 4e-05 L
.21735 4e-05 L
.21843 4e-05 L
.21945 4e-05 L
.22039 4e-05 L
.22123 4e-05 L
.22217 4e-05 L
.22314 4e-05 L
.22406 4e-05 L
.22507 4e-05 L
.22613 4e-05 L
.22704 4e-05 L
.22803 4e-05 L
.2291 4e-05 L
.22971 4e-05 L
.23025 4e-05 L
.23131 4e-05 L
.23232 4e-05 L
.23318 4e-05 L
.23412 4e-05 L
.23511 4e-05 L
.23604 4e-05 L
.2369 4e-05 L
.23769 4e-05 L
.2386 4e-05 L
.23947 4e-05 L
.2404 4e-05 L
Mistroke
.24139 4e-05 L
.24233 4e-05 L
.24318 4e-05 L
.24418 4e-05 L
.24475 4e-05 L
.24527 4e-05 L
.24622 4e-05 L
.24723 4e-05 L
.24822 4e-05 L
.24878 4e-05 L
.2493 4e-05 L
.25025 4e-05 L
.25127 4e-05 L
.25217 4e-05 L
.25302 4e-05 L
.25394 4e-05 L
.25495 4e-05 L
.25595 4e-05 L
.25652 4e-05 L
.25705 4e-05 L
.25812 4e-05 L
.25872 4e-05 L
.25926 4e-05 L
.26024 4e-05 L
.2613 4e-05 L
.26229 4e-05 L
.26322 4e-05 L
.26408 4e-05 L
.265 4e-05 L
.26587 4e-05 L
.26667 4e-05 L
.2676 4e-05 L
.26862 4e-05 L
.26958 4e-05 L
.27046 4e-05 L
.27147 4e-05 L
.27242 4e-05 L
.27326 4e-05 L
.27418 4e-05 L
.27518 4e-05 L
.27624 4e-05 L
.27715 4e-05 L
.27814 4e-05 L
.2792 4e-05 L
.28019 4e-05 L
.2807 4e-05 L
.28127 4e-05 L
.28186 4e-05 L
.28242 4e-05 L
.28344 4e-05 L
Mistroke
.28437 4e-05 L
.28544 4e-05 L
.28647 4e-05 L
.28738 4e-05 L
.28835 4e-05 L
.28926 4e-05 L
.29009 4e-05 L
.29107 4e-05 L
.29213 4e-05 L
.29313 4e-05 L
.29405 4e-05 L
.29503 4e-05 L
.29609 4e-05 L
.29709 4e-05 L
.298 4e-05 L
.29906 4e-05 L
.29966 4e-05 L
.30022 4e-05 L
.30124 4e-05 L
.30176 4e-05 L
.30233 4e-05 L
.30288 4e-05 L
.30346 4e-05 L
.3045 4e-05 L
.30508 4e-05 L
.30562 4e-05 L
.30621 4e-05 L
.30684 4e-05 L
.30739 4e-05 L
.30799 4e-05 L
.30855 4e-05 L
.30906 4e-05 L
.31004 4e-05 L
.31108 4e-05 L
.31207 4e-05 L
.31314 4e-05 L
.31415 4e-05 L
.31509 4e-05 L
.31602 4e-05 L
.31686 4e-05 L
.31784 4e-05 L
.31875 4e-05 L
.31976 4e-05 L
.32082 4e-05 L
.32172 4e-05 L
.32271 4e-05 L
.32378 4e-05 L
.32438 4e-05 L
.32493 4e-05 L
.32599 4e-05 L
Mistroke
.327 4e-05 L
.32785 4e-05 L
.3288 4e-05 L
.32978 4e-05 L
.33071 4e-05 L
.33157 4e-05 L
.33236 4e-05 L
.33322 4e-05 L
.33414 4e-05 L
.33507 4e-05 L
.33606 4e-05 L
.33699 4e-05 L
.33784 4e-05 L
.33884 4e-05 L
.33941 4e-05 L
.33993 4e-05 L
.34088 4e-05 L
.3419 4e-05 L
.34288 4e-05 L
.34396 4e-05 L
.34497 4e-05 L
.34592 4e-05 L
.34685 4e-05 L
.34769 4e-05 L
.34867 4e-05 L
.34959 4e-05 L
.35059 4e-05 L
.35166 4e-05 L
.35256 4e-05 L
.35356 4e-05 L
.35463 4e-05 L
.35523 4e-05 L
.35578 4e-05 L
.35684 4e-05 L
.35784 4e-05 L
.3587 4e-05 L
.35965 4e-05 L
.36063 4e-05 L
.36156 4e-05 L
.36242 4e-05 L
.36321 4e-05 L
.36412 4e-05 L
.36499 4e-05 L
.36592 4e-05 L
.36691 4e-05 L
.36785 4e-05 L
.3687 4e-05 L
.3697 4e-05 L
.37027 4e-05 L
.37079 4e-05 L
Mistroke
.37174 4e-05 L
.37275 4e-05 L
.37374 4e-05 L
.3743 4e-05 L
.37482 4e-05 L
.37577 4e-05 L
.37678 4e-05 L
.37769 4e-05 L
.37853 4e-05 L
.37946 4e-05 L
.38046 4e-05 L
.38147 4e-05 L
.38203 4e-05 L
.38256 4e-05 L
.38363 4e-05 L
.38423 4e-05 L
.38477 4e-05 L
.38575 4e-05 L
.38681 4e-05 L
.38781 4e-05 L
.38873 4e-05 L
.38959 4e-05 L
.39051 4e-05 L
.39138 4e-05 L
.39218 4e-05 L
.39311 4e-05 L
.39413 4e-05 L
.39509 4e-05 L
.39598 4e-05 L
.39698 4e-05 L
.39793 4e-05 L
.39877 4e-05 L
.39969 4e-05 L
.4007 4e-05 L
.40175 4e-05 L
.40266 4e-05 L
.40365 4e-05 L
.40471 4e-05 L
.4057 4e-05 L
.40621 4e-05 L
.40678 4e-05 L
.40737 4e-05 L
.40793 4e-05 L
.40894 4e-05 L
.40987 4e-05 L
.4109 4e-05 L
.41197 4e-05 L
.41288 4e-05 L
.41385 4e-05 L
.41477 4e-05 L
Mistroke
.4156 4e-05 L
.41657 4e-05 L
.41763 4e-05 L
.41863 4e-05 L
.41955 4e-05 L
.42054 4e-05 L
.42159 4e-05 L
.42259 4e-05 L
.4235 4e-05 L
.42456 4e-05 L
.42516 4e-05 L
.42572 4e-05 L
.42674 4e-05 L
.42726 4e-05 L
.42783 4e-05 L
.42838 4e-05 L
.42896 4e-05 L
.43 4e-05 L
.43058 4e-05 L
.43112 4e-05 L
.43171 4e-05 L
.43234 4e-05 L
.43289 4e-05 L
.43349 4e-05 L
.43405 4e-05 L
.43456 4e-05 L
.43555 4e-05 L
.43658 4e-05 L
.43757 4e-05 L
.43864 4e-05 L
.43965 4e-05 L
.44059 4e-05 L
.44152 4e-05 L
.44236 4e-05 L
.44333 4e-05 L
.44425 4e-05 L
.44525 4e-05 L
.44631 4e-05 L
.44722 4e-05 L
.44821 4e-05 L
.44928 4e-05 L
.44988 4e-05 L
.45042 4e-05 L
.45149 4e-05 L
.45249 4e-05 L
.45335 4e-05 L
.45429 4e-05 L
.45527 4e-05 L
.4562 4e-05 L
.45706 4e-05 L
Mistroke
.45785 4e-05 L
.45872 4e-05 L
.45963 4e-05 L
.46056 4e-05 L
.46155 4e-05 L
.46248 4e-05 L
.46333 4e-05 L
.46433 4e-05 L
.4649 4e-05 L
.46542 4e-05 L
.46638 4e-05 L
.46739 4e-05 L
.46837 4e-05 L
.46945 4e-05 L
.47046 4e-05 L
.4714 4e-05 L
.47234 4e-05 L
.47318 4e-05 L
.47416 4e-05 L
.47507 4e-05 L
.47608 4e-05 L
.47714 4e-05 L
.47805 4e-05 L
.47904 4e-05 L
.48011 4e-05 L
.48071 4e-05 L
.48126 4e-05 L
.48232 4e-05 L
.48333 4e-05 L
.48418 4e-05 L
.48513 4e-05 L
.48612 4e-05 L
.48704 4e-05 L
.4879 4e-05 L
.48869 4e-05 L
.4896 4e-05 L
.49047 4e-05 L
.4914 4e-05 L
.49239 4e-05 L
.49333 4e-05 L
.49418 4e-05 L
.49518 4e-05 L
.49575 4e-05 L
.49627 4e-05 L
.49722 4e-05 L
.49823 4e-05 L
.49922 4e-05 L
.49978 4e-05 L
.5003 4e-05 L
.50125 4e-05 L
Mistroke
.50226 4e-05 L
.50316 4e-05 L
.50401 4e-05 L
.50494 4e-05 L
.50594 4e-05 L
.50694 4e-05 L
.50751 4e-05 L
.50804 4e-05 L
.50911 4e-05 L
.5097 4e-05 L
.51025 4e-05 L
.51122 4e-05 L
.51228 4e-05 L
.51328 4e-05 L
.5142 4e-05 L
.51506 4e-05 L
.51598 4e-05 L
.51686 4e-05 L
.51765 4e-05 L
.51858 4e-05 L
.5196 4e-05 L
.52056 4e-05 L
.52145 4e-05 L
.52245 4e-05 L
.5234 4e-05 L
.52424 4e-05 L
.52516 4e-05 L
.52617 4e-05 L
.52722 4e-05 L
.52813 4e-05 L
.52912 4e-05 L
.53018 4e-05 L
.53117 4e-05 L
.53168 4e-05 L
.53225 4e-05 L
.53284 4e-05 L
.53339 4e-05 L
.53441 4e-05 L
.53534 4e-05 L
.53636 4e-05 L
.53744 4e-05 L
.53835 4e-05 L
.53932 4e-05 L
.54023 4e-05 L
.54106 4e-05 L
.54204 4e-05 L
.5431 4e-05 L
.5441 4e-05 L
.54502 4e-05 L
.546 4e-05 L
Mistroke
.54706 4e-05 L
.54805 4e-05 L
.54896 4e-05 L
.55002 4e-05 L
.55063 4e-05 L
.55118 4e-05 L
.55221 4e-05 L
.55272 4e-05 L
.55329 4e-05 L
.55384 4e-05 L
.55442 4e-05 L
.55546 4e-05 L
.55604 4e-05 L
.55658 4e-05 L
.55717 4e-05 L
.5578 4e-05 L
.55835 4e-05 L
.55895 4e-05 L
.55951 4e-05 L
.56002 4e-05 L
.56101 4e-05 L
.56205 4e-05 L
.56303 4e-05 L
.5641 4e-05 L
.56511 4e-05 L
.56605 4e-05 L
.56697 4e-05 L
.56782 4e-05 L
.56879 4e-05 L
.56971 4e-05 L
.57071 4e-05 L
.57177 4e-05 L
.57267 4e-05 L
.57366 4e-05 L
.57473 4e-05 L
.57533 4e-05 L
.57588 4e-05 L
.57694 4e-05 L
.57794 4e-05 L
.5788 4e-05 L
.57974 4e-05 L
.58073 4e-05 L
.58165 4e-05 L
.58251 4e-05 L
.5833 4e-05 L
.58417 4e-05 L
.58508 4e-05 L
.58601 4e-05 L
.587 4e-05 L
.58793 4e-05 L
Mistroke
.58878 4e-05 L
.58978 4e-05 L
.59035 4e-05 L
.59087 4e-05 L
.59183 4e-05 L
.59284 4e-05 L
.59382 4e-05 L
.5949 4e-05 L
.59591 4e-05 L
.59685 4e-05 L
.59778 4e-05 L
.59863 4e-05 L
.5996 4e-05 L
.60052 4e-05 L
.60152 4e-05 L
.60259 4e-05 L
.60349 4e-05 L
.60448 4e-05 L
.60556 4e-05 L
.60616 4e-05 L
.6067 4e-05 L
.60776 4e-05 L
.60877 4e-05 L
.60963 4e-05 L
.61057 4e-05 L
.61156 4e-05 L
.61248 4e-05 L
.61334 4e-05 L
.61413 4e-05 L
.615 4e-05 L
.61591 4e-05 L
.61684 4e-05 L
.61784 4e-05 L
.61877 4e-05 L
.61962 4e-05 L
.62062 4e-05 L
.62119 4e-05 L
.62171 4e-05 L
.62266 4e-05 L
.62367 4e-05 L
.62466 4e-05 L
.62522 4e-05 L
.62574 4e-05 L
.62669 4e-05 L
.6277 4e-05 L
.6286 4e-05 L
.62945 4e-05 L
.63037 4e-05 L
.63137 4e-05 L
.63238 4e-05 L
Mistroke
.63294 4e-05 L
.63347 4e-05 L
.63454 4e-05 L
.63514 4e-05 L
.63568 4e-05 L
.63666 4e-05 L
.63772 4e-05 L
.63871 4e-05 L
.63964 4e-05 L
.64049 4e-05 L
.64142 4e-05 L
.64229 4e-05 L
.64308 4e-05 L
.64401 4e-05 L
.64503 4e-05 L
.64599 4e-05 L
.64688 4e-05 L
.64788 4e-05 L
.64883 4e-05 L
.64968 4e-05 L
.65059 4e-05 L
.6516 4e-05 L
.65265 4e-05 L
.65356 4e-05 L
.65455 4e-05 L
.65561 4e-05 L
.6566 4e-05 L
.65711 4e-05 L
.65768 4e-05 L
.65827 4e-05 L
.65882 4e-05 L
.65984 4e-05 L
.66077 4e-05 L
.66179 4e-05 L
.66286 4e-05 L
.66377 4e-05 L
.66474 4e-05 L
.66565 4e-05 L
.66648 4e-05 L
.66746 4e-05 L
.66852 4e-05 L
.66952 4e-05 L
.67044 4e-05 L
.67142 4e-05 L
.67248 4e-05 L
.67347 4e-05 L
.67438 4e-05 L
.67545 4e-05 L
.67605 4e-05 L
.6766 4e-05 L
Mistroke
.67763 4e-05 L
.6782 4e-05 L
.67871 4e-05 L
.67926 4e-05 L
.67984 4e-05 L
.68088 4e-05 L
.68146 4e-05 L
.682 4e-05 L
.68259 4e-05 L
.68322 4e-05 L
.68377 4e-05 L
.68437 4e-05 L
.68493 4e-05 L
.68545 4e-05 L
.68643 4e-05 L
.68747 4e-05 L
.68845 4e-05 L
.68951 4e-05 L
.69053 4e-05 L
.69146 4e-05 L
.69239 4e-05 L
.69323 4e-05 L
.69421 4e-05 L
.69512 4e-05 L
.69612 4e-05 L
.69718 4e-05 L
.69808 4e-05 L
.69908 4e-05 L
.70015 4e-05 L
.70074 4e-05 L
.70129 4e-05 L
.70235 4e-05 L
.70336 4e-05 L
.70421 4e-05 L
.70515 4e-05 L
.70614 4e-05 L
.70706 4e-05 L
.70792 4e-05 L
.70871 4e-05 L
.70958 4e-05 L
.71049 4e-05 L
.71142 4e-05 L
.71241 4e-05 L
.71334 4e-05 L
.71419 4e-05 L
.71519 4e-05 L
.71576 4e-05 L
.71628 4e-05 L
.71724 4e-05 L
.71825 4e-05 L
Mistroke
.71923 4e-05 L
.72031 4e-05 L
.72132 4e-05 L
.72226 4e-05 L
.72319 4e-05 L
.72403 4e-05 L
.72501 4e-05 L
.72592 4e-05 L
.72693 4e-05 L
.72799 4e-05 L
.7289 4e-05 L
.72989 4e-05 L
.73096 4e-05 L
.73156 4e-05 L
.73211 4e-05 L
.73317 4e-05 L
.73417 4e-05 L
.73503 4e-05 L
.73597 4e-05 L
.73696 4e-05 L
.73788 4e-05 L
.73875 4e-05 L
.73954 4e-05 L
.7404 4e-05 L
.74131 4e-05 L
.74224 4e-05 L
.74324 4e-05 L
.74417 4e-05 L
.74502 4e-05 L
.74602 4e-05 L
.74659 4e-05 L
.74711 4e-05 L
.74806 4e-05 L
.74907 4e-05 L
.75006 4e-05 L
.75062 4e-05 L
.75114 4e-05 L
.75209 4e-05 L
.7531 4e-05 L
.754 4e-05 L
.75484 4e-05 L
.75577 4e-05 L
.75677 4e-05 L
.75777 4e-05 L
.75834 4e-05 L
.75887 4e-05 L
.75993 4e-05 L
.76053 4e-05 L
.76108 4e-05 L
.76205 4e-05 L
Mistroke
.76311 4e-05 L
.76411 4e-05 L
.76503 4e-05 L
.76589 4e-05 L
.76681 4e-05 L
.76768 4e-05 L
.76847 4e-05 L
.7694 4e-05 L
.77042 4e-05 L
.77138 4e-05 L
.77227 4e-05 L
.77327 4e-05 L
.77422 4e-05 L
.77507 4e-05 L
.77598 4e-05 L
.77699 4e-05 L
.77804 4e-05 L
.77895 4e-05 L
.77994 4e-05 L
.78066 4e-05 L
.78132 4e-05 L
.78205 4e-05 L
.78282 4e-05 L
.78349 4e-05 L
.78412 4e-05 L
.78481 4e-05 L
.78556 4e-05 L
.78618 4e-05 L
.78686 4e-05 L
.78757 4e-05 L
.78823 4e-05 L
.78885 4e-05 L
.78941 4e-05 L
.79006 4e-05 L
.79067 4e-05 L
.79134 4e-05 L
.79207 4e-05 L
.79283 4e-05 L
.79354 4e-05 L
.79421 4e-05 L
.79482 4e-05 L
.79552 4e-05 L
.79619 4e-05 L
.79691 4e-05 L
.79768 4e-05 L
.7984 4e-05 L
.79905 4e-05 L
.79983 4e-05 L
.80066 4e-05 L
.80145 4e-05 L
Mistroke
.80217 4e-05 L
Mfstroke
.02713 4e-05 m
.05857 .01972 L
.09286 .04131 L
.12506 .06171 L
.15603 .08148 L
.189 .10268 L
.22073 .12328 L
.25446 .1454 L
.28695 .16696 L
.31821 .18797 L
.35147 .21066 L
.3835 .2329 L
.41429 .25471 L
.44707 .27847 L
.47862 .30199 L
.51217 .32785 L
.54449 .35381 L
.57557 .38002 L
.60865 .40968 L
.64049 .44057 L
.67433 .47702 L
.70694 .51757 L
.73831 .56516 L
.75422 .59481 L
.77168 .63501 L
.77929 .65663 L
.78745 .68446 L
.7914 .70058 L
.79515 .71827 L
.80217 .76297 L
s
.8081 4e-05 m
.80834 4e-05 L
.80855 4e-05 L
.8088 4e-05 L
.80904 4e-05 L
.80925 4e-05 L
.80945 4e-05 L
.80967 4e-05 L
.80991 4e-05 L
.81014 4e-05 L
.81039 4e-05 L
.81063 4e-05 L
.81085 4e-05 L
.8111 4e-05 L
.81125 4e-05 L
.81138 4e-05 L
.81163 4e-05 L
.81189 4e-05 L
.81202 4e-05 L
.81216 4e-05 L
.81241 4e-05 L
.81254 4e-05 L
.81267 4e-05 L
.81282 4e-05 L
.81297 4e-05 L
.8131 4e-05 L
.81324 4e-05 L
.8135 4e-05 L
.81375 4e-05 L
.81398 4e-05 L
.81421 4e-05 L
.81442 4e-05 L
.81465 4e-05 L
.8149 4e-05 L
.81515 4e-05 L
.81541 4e-05 L
.81564 4e-05 L
.81588 4e-05 L
.81603 4e-05 L
.81616 4e-05 L
.8163 4e-05 L
.81646 4e-05 L
.81671 4e-05 L
.81686 4e-05 L
.817 4e-05 L
.81725 4e-05 L
.81748 4e-05 L
.81761 4e-05 L
.81775 4e-05 L
.81801 4e-05 L
Mistroke
.81816 4e-05 L
.81831 4e-05 L
.81844 4e-05 L
.81858 4e-05 L
.81873 4e-05 L
.8189 4e-05 L
.81903 4e-05 L
.81919 4e-05 L
.81933 4e-05 L
.81946 4e-05 L
.81961 4e-05 L
.81975 4e-05 L
.82001 4e-05 L
.82015 4e-05 L
.82028 4e-05 L
.82051 4e-05 L
.82077 4e-05 L
.82101 4e-05 L
.82122 4e-05 L
.82147 4e-05 L
.82173 4e-05 L
.82187 4e-05 L
.82201 4e-05 L
.82226 4e-05 L
.82241 4e-05 L
.82254 4e-05 L
.82268 4e-05 L
.82283 4e-05 L
.82309 4e-05 L
.82323 4e-05 L
.82337 4e-05 L
.82362 4e-05 L
.82385 4e-05 L
.82412 4e-05 L
.82437 4e-05 L
.8246 4e-05 L
.82485 4e-05 L
.82508 4e-05 L
.82529 4e-05 L
.82553 4e-05 L
.82579 4e-05 L
.82592 4e-05 L
.82606 4e-05 L
.82631 4e-05 L
.82645 4e-05 L
.82658 4e-05 L
.82672 4e-05 L
.82687 4e-05 L
.82712 4e-05 L
.82726 4e-05 L
Mistroke
.82739 4e-05 L
.82764 4e-05 L
.82787 4e-05 L
.82813 4e-05 L
.82838 4e-05 L
.82861 4e-05 L
.82882 4e-05 L
.82907 4e-05 L
.8293 4e-05 L
.82951 4e-05 L
.82971 4e-05 L
.82992 4e-05 L
.83015 4e-05 L
.83038 4e-05 L
.83063 4e-05 L
.83086 4e-05 L
.83107 4e-05 L
.83132 4e-05 L
.83146 4e-05 L
.83159 4e-05 L
.83183 4e-05 L
.83209 4e-05 L
.83232 4e-05 L
.83257 4e-05 L
.83283 4e-05 L
.83307 4e-05 L
.8333 4e-05 L
.83351 4e-05 L
.83375 4e-05 L
.83398 4e-05 L
.83422 4e-05 L
.83448 4e-05 L
.83471 4e-05 L
.83495 4e-05 L
.83522 4e-05 L
.83536 4e-05 L
.8355 4e-05 L
.83576 4e-05 L
.83601 4e-05 L
.83624 4e-05 L
.83645 4e-05 L
.8367 4e-05 L
.83693 4e-05 L
.83714 4e-05 L
.83733 4e-05 L
.83755 4e-05 L
.83777 4e-05 L
.838 4e-05 L
.83825 4e-05 L
.83848 4e-05 L
Mistroke
.83869 4e-05 L
.83894 4e-05 L
.83908 4e-05 L
.83921 4e-05 L
.83944 4e-05 L
.8397 4e-05 L
.83994 4e-05 L
.8402 4e-05 L
.84045 4e-05 L
.84068 4e-05 L
.84091 4e-05 L
.84112 4e-05 L
.84136 4e-05 L
.84159 4e-05 L
.84184 4e-05 L
.8421 4e-05 L
.84232 4e-05 L
.84257 4e-05 L
.84283 4e-05 L
.84298 4e-05 L
.84312 4e-05 L
.84338 4e-05 L
.84363 4e-05 L
.84384 4e-05 L
.84407 4e-05 L
.84432 4e-05 L
.84455 4e-05 L
.84476 4e-05 L
.84495 4e-05 L
.84517 4e-05 L
.84539 4e-05 L
.84562 4e-05 L
.84587 4e-05 L
.8461 4e-05 L
.84631 4e-05 L
.84656 4e-05 L
.8467 4e-05 L
.84683 4e-05 L
.84706 4e-05 L
.84731 4e-05 L
.84756 4e-05 L
.84782 4e-05 L
.84807 4e-05 L
.84831 4e-05 L
.84854 4e-05 L
.84875 4e-05 L
.84899 4e-05 L
.84921 4e-05 L
.84946 4e-05 L
.84973 4e-05 L
Mistroke
.84995 4e-05 L
.8502 4e-05 L
.85046 4e-05 L
.85061 4e-05 L
.85074 4e-05 L
.85101 4e-05 L
.85126 4e-05 L
.85147 4e-05 L
.8517 4e-05 L
.85195 4e-05 L
.85217 4e-05 L
.85239 4e-05 L
.85258 4e-05 L
.8528 4e-05 L
.85302 4e-05 L
.85325 4e-05 L
.8535 4e-05 L
.85373 4e-05 L
.85394 4e-05 L
.85419 4e-05 L
.85433 4e-05 L
.85446 4e-05 L
.85469 4e-05 L
.85494 4e-05 L
.85519 4e-05 L
.85546 4e-05 L
.85571 4e-05 L
.85594 4e-05 L
.85615 4e-05 L
.85638 4e-05 L
.85662 4e-05 L
.85685 4e-05 L
.8571 4e-05 L
.85736 4e-05 L
.85759 4e-05 L
.85783 4e-05 L
.8581 4e-05 L
.85825 4e-05 L
.85838 4e-05 L
.85865 4e-05 L
.85889 4e-05 L
.85911 4e-05 L
.85934 4e-05 L
.85959 4e-05 L
.85981 4e-05 L
.86003 4e-05 L
.86022 4e-05 L
.86045 4e-05 L
.86066 4e-05 L
.86089 4e-05 L
Mistroke
.86114 4e-05 L
.86137 4e-05 L
.86158 4e-05 L
.86183 4e-05 L
.86197 4e-05 L
.8621 4e-05 L
.86234 4e-05 L
.86259 4e-05 L
.86283 4e-05 L
.86297 4e-05 L
.8631 4e-05 L
.86333 4e-05 L
.86358 4e-05 L
.86381 4e-05 L
.86402 4e-05 L
.86425 4e-05 L
.8645 4e-05 L
.86474 4e-05 L
.86488 4e-05 L
.86502 4e-05 L
.86528 4e-05 L
.86543 4e-05 L
.86556 4e-05 L
.86581 4e-05 L
.86607 4e-05 L
.86631 4e-05 L
.86654 4e-05 L
.86676 4e-05 L
.86698 4e-05 L
.8672 4e-05 L
.8674 4e-05 L
.86763 4e-05 L
.86788 4e-05 L
.86812 4e-05 L
.86834 4e-05 L
.86859 4e-05 L
.86882 4e-05 L
.86903 4e-05 L
.86926 4e-05 L
.86951 4e-05 L
.86977 4e-05 L
.86999 4e-05 L
.87024 4e-05 L
.8705 4e-05 L
.87074 4e-05 L
.87087 4e-05 L
.87101 4e-05 L
.87116 4e-05 L
.8713 4e-05 L
.87155 4e-05 L
Mistroke
.87178 4e-05 L
.87205 4e-05 L
.8723 4e-05 L
.87252 4e-05 L
.87276 4e-05 L
.87299 4e-05 L
.8732 4e-05 L
.87344 4e-05 L
.8737 4e-05 L
.87395 4e-05 L
.87418 4e-05 L
.87442 4e-05 L
.87468 4e-05 L
.87493 4e-05 L
.87515 4e-05 L
.87542 4e-05 L
.87557 4e-05 L
.8757 4e-05 L
.87596 4e-05 L
.87608 4e-05 L
.87623 4e-05 L
.87636 4e-05 L
.87651 4e-05 L
.87676 4e-05 L
.87691 4e-05 L
.87704 4e-05 L
.87719 4e-05 L
.87734 4e-05 L
.87748 4e-05 L
.87763 4e-05 L
.87776 4e-05 L
.87789 4e-05 L
.87814 4e-05 L
.87839 4e-05 L
.87864 4e-05 L
.8789 4e-05 L
.87915 4e-05 L
.87938 4e-05 L
.87961 4e-05 L
.87982 4e-05 L
.88006 4e-05 L
.88029 4e-05 L
.88054 4e-05 L
.8808 4e-05 L
.88103 4e-05 L
.88127 4e-05 L
.88154 4e-05 L
.88168 4e-05 L
.88182 4e-05 L
.88208 4e-05 L
Mistroke
.88233 4e-05 L
.88254 4e-05 L
.88278 4e-05 L
.88302 4e-05 L
.88325 4e-05 L
.88346 4e-05 L
.88366 4e-05 L
.88387 4e-05 L
.8841 4e-05 L
.88433 4e-05 L
.88457 4e-05 L
.88481 4e-05 L
.88502 4e-05 L
.88526 4e-05 L
.8854 4e-05 L
.88553 4e-05 L
.88577 4e-05 L
.88602 4e-05 L
.88626 4e-05 L
.88653 4e-05 L
.88678 4e-05 L
.88701 4e-05 L
.88725 4e-05 L
.88746 4e-05 L
.8877 4e-05 L
.88792 4e-05 L
.88817 4e-05 L
.88844 4e-05 L
.88866 4e-05 L
.88891 4e-05 L
.88917 4e-05 L
.88932 4e-05 L
.88946 4e-05 L
.88972 4e-05 L
.88997 4e-05 L
.89018 4e-05 L
.89041 4e-05 L
.89066 4e-05 L
.89089 4e-05 L
.8911 4e-05 L
.8913 4e-05 L
.89152 4e-05 L
.89174 4e-05 L
.89197 4e-05 L
.89221 4e-05 L
.89244 4e-05 L
.89266 4e-05 L
.8929 4e-05 L
.89304 4e-05 L
.89317 4e-05 L
Mistroke
.89341 4e-05 L
.89366 4e-05 L
.8939 4e-05 L
.89404 4e-05 L
.89417 4e-05 L
.89441 4e-05 L
.89466 4e-05 L
.89488 4e-05 L
.89509 4e-05 L
.89532 4e-05 L
.89557 4e-05 L
.89582 4e-05 L
.89596 4e-05 L
.89609 4e-05 L
.89635 4e-05 L
.8965 4e-05 L
.89663 4e-05 L
.89688 4e-05 L
.89714 4e-05 L
.89739 4e-05 L
.89761 4e-05 L
.89783 4e-05 L
.89805 4e-05 L
.89827 4e-05 L
.89847 4e-05 L
.8987 4e-05 L
.89895 4e-05 L
.89919 4e-05 L
.89941 4e-05 L
.89966 4e-05 L
.89989 4e-05 L
.9001 4e-05 L
.90033 4e-05 L
.90058 4e-05 L
.90084 4e-05 L
.90106 4e-05 L
.90131 4e-05 L
.90157 4e-05 L
.90181 4e-05 L
.90194 4e-05 L
.90208 4e-05 L
.90223 4e-05 L
.90237 4e-05 L
.90262 4e-05 L
.90285 4e-05 L
.9031 4e-05 L
.90337 4e-05 L
.90359 4e-05 L
.90383 4e-05 L
.90406 4e-05 L
Mistroke
.90426 4e-05 L
.90451 4e-05 L
.90477 4e-05 L
.90502 4e-05 L
.90524 4e-05 L
.90549 4e-05 L
.90575 4e-05 L
.906 4e-05 L
.90622 4e-05 L
.90648 4e-05 L
.90663 4e-05 L
.90677 4e-05 L
.90702 4e-05 L
.90715 4e-05 L
.90729 4e-05 L
.90743 4e-05 L
.90757 4e-05 L
.90783 4e-05 L
.90797 4e-05 L
.90811 4e-05 L
.90825 4e-05 L
.90841 4e-05 L
.90855 4e-05 L
.90869 4e-05 L
.90883 4e-05 L
.90896 4e-05 L
.9092 4e-05 L
.90946 4e-05 L
.9097 4e-05 L
.90997 4e-05 L
.91022 4e-05 L
.91045 4e-05 L
.91068 4e-05 L
.91089 4e-05 L
.91113 4e-05 L
.91136 4e-05 L
.91161 4e-05 L
.91187 4e-05 L
.91209 4e-05 L
.91234 4e-05 L
.9126 4e-05 L
.91275 4e-05 L
.91289 4e-05 L
.91315 4e-05 L
.9134 4e-05 L
.91361 4e-05 L
.91384 4e-05 L
.91409 4e-05 L
.91432 4e-05 L
.91453 4e-05 L
Mistroke
.91472 4e-05 L
.91494 4e-05 L
.91516 4e-05 L
.91539 4e-05 L
.91564 4e-05 L
.91587 4e-05 L
.91608 4e-05 L
.91633 4e-05 L
.91647 4e-05 L
.9166 4e-05 L
.91683 4e-05 L
.91708 4e-05 L
.91733 4e-05 L
.9176 4e-05 L
.91785 4e-05 L
.91808 4e-05 L
.91831 4e-05 L
.91852 4e-05 L
.91876 4e-05 L
.91899 4e-05 L
.91924 4e-05 L
.9195 4e-05 L
.91972 4e-05 L
.91997 4e-05 L
.92023 4e-05 L
.92038 4e-05 L
.92052 4e-05 L
.92078 4e-05 L
.92103 4e-05 L
.92124 4e-05 L
.92148 4e-05 L
.92172 4e-05 L
.92195 4e-05 L
.92216 4e-05 L
.92236 4e-05 L
.92258 4e-05 L
.9228 4e-05 L
.92303 4e-05 L
.92328 4e-05 L
.92351 4e-05 L
.92372 4e-05 L
.92397 4e-05 L
.92411 4e-05 L
.92423 4e-05 L
.92447 4e-05 L
.92472 4e-05 L
.92497 4e-05 L
.9251 4e-05 L
.92523 4e-05 L
.92547 4e-05 L
Mistroke
.92572 4e-05 L
.92594 4e-05 L
.92615 4e-05 L
.92638 4e-05 L
.92663 4e-05 L
.92688 4e-05 L
.92702 4e-05 L
.92715 4e-05 L
.92741 4e-05 L
.92756 4e-05 L
.9277 4e-05 L
.92794 4e-05 L
.9282 4e-05 L
.92845 4e-05 L
.92867 4e-05 L
.92889 4e-05 L
.92912 4e-05 L
.92933 4e-05 L
.92953 4e-05 L
.92976 4e-05 L
.93001 4e-05 L
.93025 4e-05 L
.93047 4e-05 L
.93072 4e-05 L
.93095 4e-05 L
.93116 4e-05 L
.93139 4e-05 L
.93164 4e-05 L
.9319 4e-05 L
.93212 4e-05 L
.93237 4e-05 L
.93263 4e-05 L
.93287 4e-05 L
.933 4e-05 L
.93314 4e-05 L
.93329 4e-05 L
.93342 4e-05 L
.93368 4e-05 L
.93391 4e-05 L
.93416 4e-05 L
.93443 4e-05 L
.93465 4e-05 L
.93489 4e-05 L
.93512 4e-05 L
.93532 4e-05 L
.93556 4e-05 L
.93583 4e-05 L
.93607 4e-05 L
.9363 4e-05 L
.93655 4e-05 L
Mistroke
.93681 4e-05 L
.93705 4e-05 L
.93728 4e-05 L
.93754 4e-05 L
.93769 4e-05 L
.93783 4e-05 L
.93808 4e-05 L
.93821 4e-05 L
.93835 4e-05 L
.93849 4e-05 L
.93863 4e-05 L
.93889 4e-05 L
.93903 4e-05 L
.93916 4e-05 L
.93931 4e-05 L
.93947 4e-05 L
.9396 4e-05 L
.93975 4e-05 L
.93989 4e-05 L
.94002 4e-05 L
.94026 4e-05 L
.94052 4e-05 L
.94076 4e-05 L
.94103 4e-05 L
.94128 4e-05 L
.94151 4e-05 L
.94174 4e-05 L
.94195 4e-05 L
.94219 4e-05 L
.94241 4e-05 L
.94266 4e-05 L
.94292 4e-05 L
.94315 4e-05 L
.94339 4e-05 L
.94366 4e-05 L
.94381 4e-05 L
.94394 4e-05 L
.9442 4e-05 L
.94445 4e-05 L
.94466 4e-05 L
.9449 4e-05 L
.94514 4e-05 L
.94537 4e-05 L
.94558 4e-05 L
.94578 4e-05 L
.94599 4e-05 L
.94622 4e-05 L
.94645 4e-05 L
.94669 4e-05 L
.94693 4e-05 L
Mistroke
.94714 4e-05 L
.94738 4e-05 L
.94752 4e-05 L
.94765 4e-05 L
.94789 4e-05 L
.94814 4e-05 L
.94838 4e-05 L
.94865 4e-05 L
.9489 4e-05 L
.94913 4e-05 L
.94936 4e-05 L
.94957 4e-05 L
.94981 4e-05 L
.95004 4e-05 L
.95029 4e-05 L
.95055 4e-05 L
.95078 4e-05 L
.95102 4e-05 L
.95129 4e-05 L
.95144 4e-05 L
.95157 4e-05 L
.95183 4e-05 L
.95208 4e-05 L
.9523 4e-05 L
.95253 4e-05 L
.95277 4e-05 L
.953 4e-05 L
.95322 4e-05 L
.95341 4e-05 L
.95363 4e-05 L
.95385 4e-05 L
.95408 4e-05 L
.95433 4e-05 L
.95456 4e-05 L
.95477 4e-05 L
.95502 4e-05 L
.95516 4e-05 L
.95529 4e-05 L
.95552 4e-05 L
.95577 4e-05 L
.95602 4e-05 L
.95616 4e-05 L
.95628 4e-05 L
.95652 4e-05 L
.95677 4e-05 L
.95699 4e-05 L
.9572 4e-05 L
.95743 4e-05 L
.95768 4e-05 L
.95793 4e-05 L
Mistroke
.95807 4e-05 L
.9582 4e-05 L
.95846 4e-05 L
.95861 4e-05 L
.95875 4e-05 L
.95899 4e-05 L
.95925 4e-05 L
.9595 4e-05 L
.95972 4e-05 L
.95994 4e-05 L
.96017 4e-05 L
.96038 4e-05 L
.96058 4e-05 L
.96081 4e-05 L
.96106 4e-05 L
.9613 4e-05 L
.96152 4e-05 L
.96177 4e-05 L
.962 4e-05 L
.96221 4e-05 L
.96244 4e-05 L
.96269 4e-05 L
.96295 4e-05 L
.96317 4e-05 L
.96342 4e-05 L
.96368 4e-05 L
.96392 4e-05 L
.96405 4e-05 L
.96419 4e-05 L
.96434 4e-05 L
.96447 4e-05 L
.96473 4e-05 L
.96496 4e-05 L
.96521 4e-05 L
.96548 4e-05 L
.9657 4e-05 L
.96594 4e-05 L
.96617 4e-05 L
.96637 4e-05 L
.96661 4e-05 L
.96688 4e-05 L
.96712 4e-05 L
.96735 4e-05 L
.96759 4e-05 L
.96785 4e-05 L
.9681 4e-05 L
.96833 4e-05 L
.96859 4e-05 L
.96874 4e-05 L
.96888 4e-05 L
Mistroke
.96913 4e-05 L
.96927 4e-05 L
.9694 4e-05 L
.96953 4e-05 L
.96968 4e-05 L
.96994 4e-05 L
.97008 4e-05 L
.97021 4e-05 L
.97036 4e-05 L
.97052 4e-05 L
.97065 4e-05 L
.9708 4e-05 L
.97094 4e-05 L
.97106 4e-05 L
.97131 4e-05 L
.97157 4e-05 L
.97181 4e-05 L
.97207 4e-05 L
.97232 4e-05 L
.97255 4e-05 L
.97278 4e-05 L
.97299 4e-05 L
.97323 4e-05 L
.97346 4e-05 L
.97371 4e-05 L
.97397 4e-05 L
.97419 4e-05 L
.97444 4e-05 L
.9747 4e-05 L
.97485 4e-05 L
.97499 4e-05 L
.97525 4e-05 L
.9755 4e-05 L
.97571 4e-05 L
.97594 4e-05 L
.97619 4e-05 L
.97642 4e-05 L
.97663 4e-05 L
.97682 4e-05 L
.97704 4e-05 L
.97726 4e-05 L
.97749 4e-05 L
.97774 4e-05 L
.97797 4e-05 L
.97818 4e-05 L
.97843 4e-05 L
.97857 4e-05 L
.9787 4e-05 L
.97893 4e-05 L
.97919 4e-05 L
Mistroke
.97943 4e-05 L
.97969 4e-05 L
.97995 4e-05 L
.98018 4e-05 L
.98041 4e-05 L
.98062 4e-05 L
.98086 4e-05 L
.98109 4e-05 L
.98133 4e-05 L
.9816 4e-05 L
.98182 4e-05 L
.98207 4e-05 L
.98233 4e-05 L
.98248 4e-05 L
.98262 4e-05 L
.98288 4e-05 L
.98313 4e-05 L
.98334 4e-05 L
.98357 4e-05 L
.98382 4e-05 L
.98405 4e-05 L
.98426 4e-05 L
.98445 4e-05 L
.98467 4e-05 L
.98489 4e-05 L
.98513 4e-05 L
.98537 4e-05 L
.9856 4e-05 L
.98581 4e-05 L
.98606 4e-05 L
.9862 4e-05 L
.98633 4e-05 L
.98657 4e-05 L
.98682 4e-05 L
.98706 4e-05 L
.9872 4e-05 L
.98733 4e-05 L
.98756 4e-05 L
.98781 4e-05 L
.98803 4e-05 L
.98824 4e-05 L
.98847 4e-05 L
.98872 4e-05 L
.98897 4e-05 L
.98911 4e-05 L
.98924 4e-05 L
.9895 4e-05 L
.98965 4e-05 L
.98979 4e-05 L
.99003 4e-05 L
Mistroke
.99029 4e-05 L
.99054 4e-05 L
.99077 4e-05 L
.99098 4e-05 L
.99121 4e-05 L
.99142 4e-05 L
.99162 4e-05 L
.99185 4e-05 L
.9921 4e-05 L
.99234 4e-05 L
.99256 4e-05 L
.99281 4e-05 L
.99304 4e-05 L
.99325 4e-05 L
.99348 4e-05 L
.99373 4e-05 L
.99399 4e-05 L
.99421 4e-05 L
.99446 4e-05 L
.99463 4e-05 L
.9948 4e-05 L
.99498 4e-05 L
.99517 4e-05 L
.99534 4e-05 L
.99549 4e-05 L
.99566 4e-05 L
.99585 4e-05 L
.996 4e-05 L
.99617 4e-05 L
.99634 4e-05 L
.99651 4e-05 L
.99666 4e-05 L
.9968 4e-05 L
.99696 4e-05 L
.99711 4e-05 L
.99728 4e-05 L
.99746 4e-05 L
.99765 4e-05 L
.99782 4e-05 L
.99799 4e-05 L
.99814 4e-05 L
.99831 4e-05 L
.99848 4e-05 L
.99866 4e-05 L
.99885 4e-05 L
.99903 4e-05 L
.99919 4e-05 L
.99938 4e-05 L
.99959 4e-05 L
.99978 4e-05 L
Mistroke
.99996 4e-05 L
Mfstroke
.8081 .99996 m
.81588 .99996 L
.82437 .99996 L
.83234 .99996 L
.84001 .99996 L
.84817 .99996 L
.85603 .99996 L
.86437 .99996 L
.87242 .99996 L
.88016 .99996 L
.88839 .99996 L
.89632 .99996 L
.90394 .99996 L
.91206 .99996 L
.91987 .99996 L
.92817 .99996 L
.93617 .99996 L
.94387 .99996 L
.95205 .99996 L
.95994 .99996 L
.96831 .99996 L
.97638 .99996 L
.98415 .99996 L
.99241 .99996 L
.99996 .99996 L
s
.5 1 1 r
.8081 4e-05 m
.80834 4e-05 L
.80855 4e-05 L
.8088 4e-05 L
.80904 4e-05 L
.80925 4e-05 L
.80945 4e-05 L
.80967 4e-05 L
.80991 4e-05 L
.81014 4e-05 L
.81039 4e-05 L
.81063 4e-05 L
.81085 4e-05 L
.8111 4e-05 L
.81125 4e-05 L
.81138 4e-05 L
.81163 4e-05 L
.81189 4e-05 L
.81202 4e-05 L
.81216 4e-05 L
.81241 4e-05 L
.81254 4e-05 L
.81267 4e-05 L
.81282 4e-05 L
.81297 4e-05 L
.8131 4e-05 L
.81324 4e-05 L
.8135 4e-05 L
.81375 4e-05 L
.81398 4e-05 L
.81421 4e-05 L
.81442 4e-05 L
.81465 4e-05 L
.8149 4e-05 L
.81515 4e-05 L
.81541 4e-05 L
.81564 4e-05 L
.81588 4e-05 L
.81603 4e-05 L
.81616 4e-05 L
.8163 4e-05 L
.81646 4e-05 L
.81671 4e-05 L
.81686 4e-05 L
.817 4e-05 L
.81725 4e-05 L
.81748 4e-05 L
.81761 4e-05 L
.81775 4e-05 L
.81801 4e-05 L
.81816 4e-05 L
.81831 4e-05 L
.81844 4e-05 L
.81858 4e-05 L
.81873 4e-05 L
.8189 4e-05 L
.81903 4e-05 L
.81919 4e-05 L
.81933 4e-05 L
.81946 4e-05 L
.81961 4e-05 L
.81975 4e-05 L
.82001 4e-05 L
.82015 4e-05 L
.82028 4e-05 L
.82051 4e-05 L
.82077 4e-05 L
.82101 4e-05 L
.82122 4e-05 L
.82147 4e-05 L
.82173 4e-05 L
.82187 4e-05 L
.82201 4e-05 L
.82226 4e-05 L
.82241 4e-05 L
.82254 4e-05 L
.82268 4e-05 L
.82283 4e-05 L
.82309 4e-05 L
.82323 4e-05 L
.82337 4e-05 L
.82362 4e-05 L
.82385 4e-05 L
.82412 4e-05 L
.82437 4e-05 L
.8246 4e-05 L
.82485 4e-05 L
.82508 4e-05 L
.82529 4e-05 L
.82553 4e-05 L
.82579 4e-05 L
.82592 4e-05 L
.82606 4e-05 L
.82631 4e-05 L
.82645 4e-05 L
.82658 4e-05 L
.82672 4e-05 L
.82687 4e-05 L
.82712 4e-05 L
.82726 4e-05 L
.82739 4e-05 L
.82764 4e-05 L
.82787 4e-05 L
.82813 4e-05 L
.82838 4e-05 L
.82861 4e-05 L
.82882 4e-05 L
.82907 4e-05 L
.8293 4e-05 L
.82951 4e-05 L
.82971 4e-05 L
.82992 4e-05 L
.83015 4e-05 L
.83038 4e-05 L
.83063 4e-05 L
.83086 4e-05 L
.83107 4e-05 L
.83132 4e-05 L
.83146 4e-05 L
.83159 4e-05 L
.83183 4e-05 L
.83209 4e-05 L
.83232 4e-05 L
.83257 4e-05 L
.83283 4e-05 L
.83307 4e-05 L
.8333 4e-05 L
.83351 4e-05 L
.83375 4e-05 L
.83398 4e-05 L
.83422 4e-05 L
.83448 4e-05 L
.83471 4e-05 L
.83495 4e-05 L
.83522 4e-05 L
.83536 4e-05 L
.8355 4e-05 L
.83576 4e-05 L
.83601 4e-05 L
.83624 4e-05 L
.83645 4e-05 L
.8367 4e-05 L
.83693 4e-05 L
.83714 4e-05 L
.83733 4e-05 L
.83755 4e-05 L
.83777 4e-05 L
.838 4e-05 L
.83825 4e-05 L
.83848 4e-05 L
.83869 4e-05 L
.83894 4e-05 L
.83908 4e-05 L
.83921 4e-05 L
.83944 4e-05 L
.8397 4e-05 L
.83994 4e-05 L
.8402 4e-05 L
.84045 4e-05 L
.84068 4e-05 L
.84091 4e-05 L
.84112 4e-05 L
.84136 4e-05 L
.84159 4e-05 L
.84184 4e-05 L
.8421 4e-05 L
.84232 4e-05 L
.84257 4e-05 L
.84283 4e-05 L
.84298 4e-05 L
.84312 4e-05 L
.84338 4e-05 L
.84363 4e-05 L
.84384 4e-05 L
.84407 4e-05 L
.84432 4e-05 L
.84455 4e-05 L
.84476 4e-05 L
.84495 4e-05 L
.84517 4e-05 L
.84539 4e-05 L
.84562 4e-05 L
.84587 4e-05 L
.8461 4e-05 L
.84631 4e-05 L
.84656 4e-05 L
.8467 4e-05 L
.84683 4e-05 L
.84706 4e-05 L
.84731 4e-05 L
.84756 4e-05 L
.84782 4e-05 L
.84807 4e-05 L
.84831 4e-05 L
.84854 4e-05 L
.84875 4e-05 L
.84899 4e-05 L
.84921 4e-05 L
.84946 4e-05 L
.84973 4e-05 L
.84995 4e-05 L
.8502 4e-05 L
.85046 4e-05 L
.85061 4e-05 L
.85074 4e-05 L
.85101 4e-05 L
.85126 4e-05 L
.85147 4e-05 L
.8517 4e-05 L
.85195 4e-05 L
.85217 4e-05 L
.85239 4e-05 L
.85258 4e-05 L
.8528 4e-05 L
.85302 4e-05 L
.85325 4e-05 L
.8535 4e-05 L
.85373 4e-05 L
.85394 4e-05 L
.85419 4e-05 L
.85433 4e-05 L
.85446 4e-05 L
.85469 4e-05 L
.85494 4e-05 L
.85519 4e-05 L
.85546 4e-05 L
.85571 4e-05 L
.85594 4e-05 L
.85615 4e-05 L
.85638 4e-05 L
.85662 4e-05 L
.85685 4e-05 L
.8571 4e-05 L
.85736 4e-05 L
.85759 4e-05 L
.85783 4e-05 L
.8581 4e-05 L
.85825 4e-05 L
.85838 4e-05 L
.85865 4e-05 L
.85889 4e-05 L
.85911 4e-05 L
.85934 4e-05 L
.85959 4e-05 L
.85981 4e-05 L
.86003 4e-05 L
.86022 4e-05 L
.86045 4e-05 L
.86066 4e-05 L
.86089 4e-05 L
.86114 4e-05 L
.86137 4e-05 L
.86158 4e-05 L
.86183 4e-05 L
.86197 4e-05 L
.8621 4e-05 L
.86234 4e-05 L
.86259 4e-05 L
.86283 4e-05 L
.86297 4e-05 L
.8631 4e-05 L
.86333 4e-05 L
.86358 4e-05 L
.86381 4e-05 L
.86402 4e-05 L
.86425 4e-05 L
.8645 4e-05 L
.86474 4e-05 L
.86488 4e-05 L
.86502 4e-05 L
.86528 4e-05 L
.86543 4e-05 L
.86556 4e-05 L
.86581 4e-05 L
.86607 4e-05 L
.86631 4e-05 L
.86654 4e-05 L
.86676 4e-05 L
.86698 4e-05 L
.8672 4e-05 L
.8674 4e-05 L
.86763 4e-05 L
.86788 4e-05 L
.86812 4e-05 L
.86834 4e-05 L
.86859 4e-05 L
.86882 4e-05 L
.86903 4e-05 L
.86926 4e-05 L
.86951 4e-05 L
.86977 4e-05 L
.86999 4e-05 L
.87024 4e-05 L
.8705 4e-05 L
.87074 4e-05 L
.87087 4e-05 L
.87101 4e-05 L
.87116 4e-05 L
.8713 4e-05 L
.87155 4e-05 L
.87178 4e-05 L
.87205 4e-05 L
.8723 4e-05 L
.87252 4e-05 L
.87276 4e-05 L
.87299 4e-05 L
.8732 4e-05 L
.87344 4e-05 L
.8737 4e-05 L
.87395 4e-05 L
.87418 4e-05 L
.87442 4e-05 L
.87468 4e-05 L
.87493 4e-05 L
.87515 4e-05 L
.87542 4e-05 L
.87557 4e-05 L
.8757 4e-05 L
.87596 4e-05 L
.87608 4e-05 L
.87623 4e-05 L
.87636 4e-05 L
.87651 4e-05 L
.87676 4e-05 L
.87691 4e-05 L
.87704 4e-05 L
.87719 4e-05 L
.87734 4e-05 L
.87748 4e-05 L
.87763 4e-05 L
.87776 4e-05 L
.87789 4e-05 L
.87814 4e-05 L
.87839 4e-05 L
.87864 4e-05 L
.8789 4e-05 L
.87915 4e-05 L
.87938 4e-05 L
.87961 4e-05 L
.87982 4e-05 L
.88006 4e-05 L
.88029 4e-05 L
.88054 4e-05 L
.8808 4e-05 L
.88103 4e-05 L
.88127 4e-05 L
.88154 4e-05 L
.88168 4e-05 L
.88182 4e-05 L
.88208 4e-05 L
.88233 4e-05 L
.88254 4e-05 L
.88278 4e-05 L
.88302 4e-05 L
.88325 4e-05 L
.88346 4e-05 L
.88366 4e-05 L
.88387 4e-05 L
.8841 4e-05 L
.88433 4e-05 L
.88457 4e-05 L
.88481 4e-05 L
.88502 4e-05 L
.88526 4e-05 L
.8854 4e-05 L
.88553 4e-05 L
.88577 4e-05 L
.88602 4e-05 L
.88626 4e-05 L
.88653 4e-05 L
.88678 4e-05 L
.88701 4e-05 L
.88725 4e-05 L
.88746 4e-05 L
.8877 4e-05 L
.88792 4e-05 L
.88817 4e-05 L
.88844 4e-05 L
.88866 4e-05 L
.88891 4e-05 L
.88917 4e-05 L
.88932 4e-05 L
.88946 4e-05 L
.88972 4e-05 L
.88997 4e-05 L
.89018 4e-05 L
.89041 4e-05 L
.89066 4e-05 L
.89089 4e-05 L
.8911 4e-05 L
.8913 4e-05 L
.89152 4e-05 L
.89174 4e-05 L
.89197 4e-05 L
.89221 4e-05 L
.89244 4e-05 L
.89266 4e-05 L
.8929 4e-05 L
.89304 4e-05 L
.89317 4e-05 L
.89341 4e-05 L
.89366 4e-05 L
.8939 4e-05 L
.89404 4e-05 L
.89417 4e-05 L
.89441 4e-05 L
.89466 4e-05 L
.89488 4e-05 L
.89509 4e-05 L
.89532 4e-05 L
.89557 4e-05 L
.89582 4e-05 L
.89596 4e-05 L
.89609 4e-05 L
.89635 4e-05 L
.8965 4e-05 L
.89663 4e-05 L
.89688 4e-05 L
.89714 4e-05 L
.89739 4e-05 L
.89761 4e-05 L
.89783 4e-05 L
.89805 4e-05 L
.89827 4e-05 L
.89847 4e-05 L
.8987 4e-05 L
.89895 4e-05 L
.89919 4e-05 L
.89941 4e-05 L
.89966 4e-05 L
.89989 4e-05 L
.9001 4e-05 L
.90033 4e-05 L
.90058 4e-05 L
.90084 4e-05 L
.90106 4e-05 L
.90131 4e-05 L
.90157 4e-05 L
.90181 4e-05 L
.90194 4e-05 L
.90208 4e-05 L
.90223 4e-05 L
.90237 4e-05 L
.90262 4e-05 L
.90285 4e-05 L
.9031 4e-05 L
.90337 4e-05 L
.90359 4e-05 L
.90383 4e-05 L
.90406 4e-05 L
.90426 4e-05 L
.90451 4e-05 L
.90477 4e-05 L
.90502 4e-05 L
.90524 4e-05 L
.90549 4e-05 L
.90575 4e-05 L
.906 4e-05 L
.90622 4e-05 L
.90648 4e-05 L
.90663 4e-05 L
.90677 4e-05 L
.90702 4e-05 L
.90715 4e-05 L
.90729 4e-05 L
.90743 4e-05 L
.90757 4e-05 L
.90783 4e-05 L
.90797 4e-05 L
.90811 4e-05 L
.90825 4e-05 L
.90841 4e-05 L
.90855 4e-05 L
.90869 4e-05 L
.90883 4e-05 L
.90896 4e-05 L
.9092 4e-05 L
.90946 4e-05 L
.9097 4e-05 L
.90997 4e-05 L
.91022 4e-05 L
.91045 4e-05 L
.91068 4e-05 L
.91089 4e-05 L
.91113 4e-05 L
.91136 4e-05 L
.91161 4e-05 L
.91187 4e-05 L
.91209 4e-05 L
.91234 4e-05 L
.9126 4e-05 L
.91275 4e-05 L
.91289 4e-05 L
.91315 4e-05 L
.9134 4e-05 L
.91361 4e-05 L
.91384 4e-05 L
.91409 4e-05 L
.91432 4e-05 L
.91453 4e-05 L
.91472 4e-05 L
.91494 4e-05 L
.91516 4e-05 L
.91539 4e-05 L
.91564 4e-05 L
.91587 4e-05 L
.91608 4e-05 L
.91633 4e-05 L
.91647 4e-05 L
.9166 4e-05 L
.91683 4e-05 L
.91708 4e-05 L
.91733 4e-05 L
.9176 4e-05 L
.91785 4e-05 L
.91808 4e-05 L
.91831 4e-05 L
.91852 4e-05 L
.91876 4e-05 L
.91899 4e-05 L
.91924 4e-05 L
.9195 4e-05 L
.91972 4e-05 L
.91997 4e-05 L
.92023 4e-05 L
.92038 4e-05 L
.92052 4e-05 L
.92078 4e-05 L
.92103 4e-05 L
.92124 4e-05 L
.92148 4e-05 L
.92172 4e-05 L
.92195 4e-05 L
.92216 4e-05 L
.92236 4e-05 L
.92258 4e-05 L
.9228 4e-05 L
.92303 4e-05 L
.92328 4e-05 L
.92351 4e-05 L
.92372 4e-05 L
.92397 4e-05 L
.92411 4e-05 L
.92423 4e-05 L
.92447 4e-05 L
.92472 4e-05 L
.92497 4e-05 L
.9251 4e-05 L
.92523 4e-05 L
.92547 4e-05 L
.92572 4e-05 L
.92594 4e-05 L
.92615 4e-05 L
.92638 4e-05 L
.92663 4e-05 L
.92688 4e-05 L
.92702 4e-05 L
.92715 4e-05 L
.92741 4e-05 L
.92756 4e-05 L
.9277 4e-05 L
.92794 4e-05 L
.9282 4e-05 L
.92845 4e-05 L
.92867 4e-05 L
.92889 4e-05 L
.92912 4e-05 L
.92933 4e-05 L
.92953 4e-05 L
.92976 4e-05 L
.93001 4e-05 L
.93025 4e-05 L
.93047 4e-05 L
.93072 4e-05 L
.93095 4e-05 L
.93116 4e-05 L
.93139 4e-05 L
.93164 4e-05 L
.9319 4e-05 L
.93212 4e-05 L
.93237 4e-05 L
.93263 4e-05 L
.93287 4e-05 L
.933 4e-05 L
.93314 4e-05 L
.93329 4e-05 L
.93342 4e-05 L
.93368 4e-05 L
.93391 4e-05 L
.93416 4e-05 L
.93443 4e-05 L
.93465 4e-05 L
.93489 4e-05 L
.93512 4e-05 L
.93532 4e-05 L
.93556 4e-05 L
.93583 4e-05 L
.93607 4e-05 L
.9363 4e-05 L
.93655 4e-05 L
.93681 4e-05 L
.93705 4e-05 L
.93728 4e-05 L
.93754 4e-05 L
.93769 4e-05 L
.93783 4e-05 L
.93808 4e-05 L
.93821 4e-05 L
.93835 4e-05 L
.93849 4e-05 L
.93863 4e-05 L
.93889 4e-05 L
.93903 4e-05 L
.93916 4e-05 L
.93931 4e-05 L
.93947 4e-05 L
.9396 4e-05 L
.93975 4e-05 L
.93989 4e-05 L
.94002 4e-05 L
.94026 4e-05 L
.94052 4e-05 L
.94076 4e-05 L
.94103 4e-05 L
.94128 4e-05 L
.94151 4e-05 L
.94174 4e-05 L
.94195 4e-05 L
.94219 4e-05 L
.94241 4e-05 L
.94266 4e-05 L
.94292 4e-05 L
.94315 4e-05 L
.94339 4e-05 L
.94366 4e-05 L
.94381 4e-05 L
.94394 4e-05 L
.9442 4e-05 L
.94445 4e-05 L
.94466 4e-05 L
.9449 4e-05 L
.94514 4e-05 L
.94537 4e-05 L
.94558 4e-05 L
.94578 4e-05 L
.94599 4e-05 L
.94622 4e-05 L
.94645 4e-05 L
.94669 4e-05 L
.94693 4e-05 L
.94714 4e-05 L
.94738 4e-05 L
.94752 4e-05 L
.94765 4e-05 L
.94789 4e-05 L
.94814 4e-05 L
.94838 4e-05 L
.94865 4e-05 L
.9489 4e-05 L
.94913 4e-05 L
.94936 4e-05 L
.94957 4e-05 L
.94981 4e-05 L
.95004 4e-05 L
.95029 4e-05 L
.95055 4e-05 L
.95078 4e-05 L
.95102 4e-05 L
.95129 4e-05 L
.95144 4e-05 L
.95157 4e-05 L
.95183 4e-05 L
.95208 4e-05 L
.9523 4e-05 L
.95253 4e-05 L
.95277 4e-05 L
.953 4e-05 L
.95322 4e-05 L
.95341 4e-05 L
.95363 4e-05 L
.95385 4e-05 L
.95408 4e-05 L
.95433 4e-05 L
.95456 4e-05 L
.95477 4e-05 L
.95502 4e-05 L
.95516 4e-05 L
.95529 4e-05 L
.95552 4e-05 L
.95577 4e-05 L
.95602 4e-05 L
.95616 4e-05 L
.95628 4e-05 L
.95652 4e-05 L
.95677 4e-05 L
.95699 4e-05 L
.9572 4e-05 L
.95743 4e-05 L
.95768 4e-05 L
.95793 4e-05 L
.95807 4e-05 L
.9582 4e-05 L
.95846 4e-05 L
.95861 4e-05 L
.95875 4e-05 L
.95899 4e-05 L
.95925 4e-05 L
.9595 4e-05 L
.95972 4e-05 L
.95994 4e-05 L
.96017 4e-05 L
.96038 4e-05 L
.96058 4e-05 L
.96081 4e-05 L
.96106 4e-05 L
.9613 4e-05 L
.96152 4e-05 L
.96177 4e-05 L
.962 4e-05 L
.96221 4e-05 L
.96244 4e-05 L
.96269 4e-05 L
.96295 4e-05 L
.96317 4e-05 L
.96342 4e-05 L
.96368 4e-05 L
.96392 4e-05 L
.96405 4e-05 L
.96419 4e-05 L
.96434 4e-05 L
.96447 4e-05 L
.96473 4e-05 L
.96496 4e-05 L
.96521 4e-05 L
.96548 4e-05 L
.9657 4e-05 L
.96594 4e-05 L
.96617 4e-05 L
.96637 4e-05 L
.96661 4e-05 L
.96688 4e-05 L
.96712 4e-05 L
.96735 4e-05 L
.96759 4e-05 L
.96785 4e-05 L
.9681 4e-05 L
.96833 4e-05 L
.96859 4e-05 L
.96874 4e-05 L
.96888 4e-05 L
.96913 4e-05 L
.96927 4e-05 L
.9694 4e-05 L
.96953 4e-05 L
.96968 4e-05 L
.96994 4e-05 L
.97008 4e-05 L
.97021 4e-05 L
.97036 4e-05 L
.97052 4e-05 L
.97065 4e-05 L
.9708 4e-05 L
.97094 4e-05 L
.97106 4e-05 L
.97131 4e-05 L
.97157 4e-05 L
.97181 4e-05 L
.97207 4e-05 L
.97232 4e-05 L
.97255 4e-05 L
.97278 4e-05 L
.97299 4e-05 L
.97323 4e-05 L
.97346 4e-05 L
.97371 4e-05 L
.97397 4e-05 L
.97419 4e-05 L
.97444 4e-05 L
.9747 4e-05 L
.97485 4e-05 L
.97499 4e-05 L
.97525 4e-05 L
.9755 4e-05 L
.97571 4e-05 L
.97594 4e-05 L
.97619 4e-05 L
.97642 4e-05 L
.97663 4e-05 L
.97682 4e-05 L
.97704 4e-05 L
.97726 4e-05 L
.97749 4e-05 L
.97774 4e-05 L
.97797 4e-05 L
.97818 4e-05 L
.97843 4e-05 L
.97857 4e-05 L
.9787 4e-05 L
.97893 4e-05 L
.97919 4e-05 L
.97943 4e-05 L
.97969 4e-05 L
.97995 4e-05 L
.98018 4e-05 L
.98041 4e-05 L
.98062 4e-05 L
.98086 4e-05 L
.98109 4e-05 L
.98133 4e-05 L
.9816 4e-05 L
.98182 4e-05 L
.98207 4e-05 L
.98233 4e-05 L
.98248 4e-05 L
.98262 4e-05 L
.98288 4e-05 L
.98313 4e-05 L
.98334 4e-05 L
.98357 4e-05 L
.98382 4e-05 L
.98405 4e-05 L
.98426 4e-05 L
.98445 4e-05 L
.98467 4e-05 L
.98489 4e-05 L
.98513 4e-05 L
.98537 4e-05 L
.9856 4e-05 L
.98581 4e-05 L
.98606 4e-05 L
.9862 4e-05 L
.98633 4e-05 L
.98657 4e-05 L
.98682 4e-05 L
.98706 4e-05 L
.9872 4e-05 L
.98733 4e-05 L
.98756 4e-05 L
.98781 4e-05 L
.98803 4e-05 L
.98824 4e-05 L
.98847 4e-05 L
.98872 4e-05 L
.98897 4e-05 L
.98911 4e-05 L
.98924 4e-05 L
.9895 4e-05 L
.98965 4e-05 L
.98979 4e-05 L
.99003 4e-05 L
.99029 4e-05 L
.99054 4e-05 L
.99077 4e-05 L
.99098 4e-05 L
.99121 4e-05 L
.99142 4e-05 L
.99162 4e-05 L
.99185 4e-05 L
.9921 4e-05 L
.99234 4e-05 L
.99256 4e-05 L
.99281 4e-05 L
.99304 4e-05 L
.99325 4e-05 L
.99348 4e-05 L
.99373 4e-05 L
.99399 4e-05 L
.99421 4e-05 L
.99446 4e-05 L
.99463 4e-05 L
.9948 4e-05 L
.99498 4e-05 L
.99517 4e-05 L
.99534 4e-05 L
.99549 4e-05 L
.99566 4e-05 L
.99585 4e-05 L
.996 4e-05 L
.99617 4e-05 L
.99634 4e-05 L
.99651 4e-05 L
.99666 4e-05 L
.9968 4e-05 L
.99696 4e-05 L
.99711 4e-05 L
.99728 4e-05 L
.99746 4e-05 L
.99765 4e-05 L
.99782 4e-05 L
.99799 4e-05 L
.99814 4e-05 L
.99831 4e-05 L
.99848 4e-05 L
.99866 4e-05 L
.99885 4e-05 L
.99903 4e-05 L
.99919 4e-05 L
.99938 4e-05 L
.99959 4e-05 L
.99978 4e-05 L
.99996 4e-05 L
.99996 .99996 L
.99241 .99996 L
.98415 .99996 L
.97638 .99996 L
.96831 .99996 L
.95994 .99996 L
.95205 .99996 L
.94387 .99996 L
.93617 .99996 L
.92817 .99996 L
.91987 .99996 L
.91206 .99996 L
.90394 .99996 L
.89632 .99996 L
.88839 .99996 L
.88016 .99996 L
.87242 .99996 L
.86437 .99996 L
.85603 .99996 L
.84817 .99996 L
.84001 .99996 L
.83234 .99996 L
.82437 .99996 L
.81588 .99996 L
.8081 .99996 L
F
0 g
.8081 4e-05 m
.80834 4e-05 L
.80855 4e-05 L
.8088 4e-05 L
.80904 4e-05 L
.80925 4e-05 L
.80945 4e-05 L
.80967 4e-05 L
.80991 4e-05 L
.81014 4e-05 L
.81039 4e-05 L
.81063 4e-05 L
.81085 4e-05 L
.8111 4e-05 L
.81125 4e-05 L
.81138 4e-05 L
.81163 4e-05 L
.81189 4e-05 L
.81202 4e-05 L
.81216 4e-05 L
.81241 4e-05 L
.81254 4e-05 L
.81267 4e-05 L
.81282 4e-05 L
.81297 4e-05 L
.8131 4e-05 L
.81324 4e-05 L
.8135 4e-05 L
.81375 4e-05 L
.81398 4e-05 L
.81421 4e-05 L
.81442 4e-05 L
.81465 4e-05 L
.8149 4e-05 L
.81515 4e-05 L
.81541 4e-05 L
.81564 4e-05 L
.81588 4e-05 L
.81603 4e-05 L
.81616 4e-05 L
.8163 4e-05 L
.81646 4e-05 L
.81671 4e-05 L
.81686 4e-05 L
.817 4e-05 L
.81725 4e-05 L
.81748 4e-05 L
.81761 4e-05 L
.81775 4e-05 L
.81801 4e-05 L
Mistroke
.81816 4e-05 L
.81831 4e-05 L
.81844 4e-05 L
.81858 4e-05 L
.81873 4e-05 L
.8189 4e-05 L
.81903 4e-05 L
.81919 4e-05 L
.81933 4e-05 L
.81946 4e-05 L
.81961 4e-05 L
.81975 4e-05 L
.82001 4e-05 L
.82015 4e-05 L
.82028 4e-05 L
.82051 4e-05 L
.82077 4e-05 L
.82101 4e-05 L
.82122 4e-05 L
.82147 4e-05 L
.82173 4e-05 L
.82187 4e-05 L
.82201 4e-05 L
.82226 4e-05 L
.82241 4e-05 L
.82254 4e-05 L
.82268 4e-05 L
.82283 4e-05 L
.82309 4e-05 L
.82323 4e-05 L
.82337 4e-05 L
.82362 4e-05 L
.82385 4e-05 L
.82412 4e-05 L
.82437 4e-05 L
.8246 4e-05 L
.82485 4e-05 L
.82508 4e-05 L
.82529 4e-05 L
.82553 4e-05 L
.82579 4e-05 L
.82592 4e-05 L
.82606 4e-05 L
.82631 4e-05 L
.82645 4e-05 L
.82658 4e-05 L
.82672 4e-05 L
.82687 4e-05 L
.82712 4e-05 L
.82726 4e-05 L
Mistroke
.82739 4e-05 L
.82764 4e-05 L
.82787 4e-05 L
.82813 4e-05 L
.82838 4e-05 L
.82861 4e-05 L
.82882 4e-05 L
.82907 4e-05 L
.8293 4e-05 L
.82951 4e-05 L
.82971 4e-05 L
.82992 4e-05 L
.83015 4e-05 L
.83038 4e-05 L
.83063 4e-05 L
.83086 4e-05 L
.83107 4e-05 L
.83132 4e-05 L
.83146 4e-05 L
.83159 4e-05 L
.83183 4e-05 L
.83209 4e-05 L
.83232 4e-05 L
.83257 4e-05 L
.83283 4e-05 L
.83307 4e-05 L
.8333 4e-05 L
.83351 4e-05 L
.83375 4e-05 L
.83398 4e-05 L
.83422 4e-05 L
.83448 4e-05 L
.83471 4e-05 L
.83495 4e-05 L
.83522 4e-05 L
.83536 4e-05 L
.8355 4e-05 L
.83576 4e-05 L
.83601 4e-05 L
.83624 4e-05 L
.83645 4e-05 L
.8367 4e-05 L
.83693 4e-05 L
.83714 4e-05 L
.83733 4e-05 L
.83755 4e-05 L
.83777 4e-05 L
.838 4e-05 L
.83825 4e-05 L
.83848 4e-05 L
Mistroke
.83869 4e-05 L
.83894 4e-05 L
.83908 4e-05 L
.83921 4e-05 L
.83944 4e-05 L
.8397 4e-05 L
.83994 4e-05 L
.8402 4e-05 L
.84045 4e-05 L
.84068 4e-05 L
.84091 4e-05 L
.84112 4e-05 L
.84136 4e-05 L
.84159 4e-05 L
.84184 4e-05 L
.8421 4e-05 L
.84232 4e-05 L
.84257 4e-05 L
.84283 4e-05 L
.84298 4e-05 L
.84312 4e-05 L
.84338 4e-05 L
.84363 4e-05 L
.84384 4e-05 L
.84407 4e-05 L
.84432 4e-05 L
.84455 4e-05 L
.84476 4e-05 L
.84495 4e-05 L
.84517 4e-05 L
.84539 4e-05 L
.84562 4e-05 L
.84587 4e-05 L
.8461 4e-05 L
.84631 4e-05 L
.84656 4e-05 L
.8467 4e-05 L
.84683 4e-05 L
.84706 4e-05 L
.84731 4e-05 L
.84756 4e-05 L
.84782 4e-05 L
.84807 4e-05 L
.84831 4e-05 L
.84854 4e-05 L
.84875 4e-05 L
.84899 4e-05 L
.84921 4e-05 L
.84946 4e-05 L
.84973 4e-05 L
Mistroke
.84995 4e-05 L
.8502 4e-05 L
.85046 4e-05 L
.85061 4e-05 L
.85074 4e-05 L
.85101 4e-05 L
.85126 4e-05 L
.85147 4e-05 L
.8517 4e-05 L
.85195 4e-05 L
.85217 4e-05 L
.85239 4e-05 L
.85258 4e-05 L
.8528 4e-05 L
.85302 4e-05 L
.85325 4e-05 L
.8535 4e-05 L
.85373 4e-05 L
.85394 4e-05 L
.85419 4e-05 L
.85433 4e-05 L
.85446 4e-05 L
.85469 4e-05 L
.85494 4e-05 L
.85519 4e-05 L
.85546 4e-05 L
.85571 4e-05 L
.85594 4e-05 L
.85615 4e-05 L
.85638 4e-05 L
.85662 4e-05 L
.85685 4e-05 L
.8571 4e-05 L
.85736 4e-05 L
.85759 4e-05 L
.85783 4e-05 L
.8581 4e-05 L
.85825 4e-05 L
.85838 4e-05 L
.85865 4e-05 L
.85889 4e-05 L
.85911 4e-05 L
.85934 4e-05 L
.85959 4e-05 L
.85981 4e-05 L
.86003 4e-05 L
.86022 4e-05 L
.86045 4e-05 L
.86066 4e-05 L
.86089 4e-05 L
Mistroke
.86114 4e-05 L
.86137 4e-05 L
.86158 4e-05 L
.86183 4e-05 L
.86197 4e-05 L
.8621 4e-05 L
.86234 4e-05 L
.86259 4e-05 L
.86283 4e-05 L
.86297 4e-05 L
.8631 4e-05 L
.86333 4e-05 L
.86358 4e-05 L
.86381 4e-05 L
.86402 4e-05 L
.86425 4e-05 L
.8645 4e-05 L
.86474 4e-05 L
.86488 4e-05 L
.86502 4e-05 L
.86528 4e-05 L
.86543 4e-05 L
.86556 4e-05 L
.86581 4e-05 L
.86607 4e-05 L
.86631 4e-05 L
.86654 4e-05 L
.86676 4e-05 L
.86698 4e-05 L
.8672 4e-05 L
.8674 4e-05 L
.86763 4e-05 L
.86788 4e-05 L
.86812 4e-05 L
.86834 4e-05 L
.86859 4e-05 L
.86882 4e-05 L
.86903 4e-05 L
.86926 4e-05 L
.86951 4e-05 L
.86977 4e-05 L
.86999 4e-05 L
.87024 4e-05 L
.8705 4e-05 L
.87074 4e-05 L
.87087 4e-05 L
.87101 4e-05 L
.87116 4e-05 L
.8713 4e-05 L
.87155 4e-05 L
Mistroke
.87178 4e-05 L
.87205 4e-05 L
.8723 4e-05 L
.87252 4e-05 L
.87276 4e-05 L
.87299 4e-05 L
.8732 4e-05 L
.87344 4e-05 L
.8737 4e-05 L
.87395 4e-05 L
.87418 4e-05 L
.87442 4e-05 L
.87468 4e-05 L
.87493 4e-05 L
.87515 4e-05 L
.87542 4e-05 L
.87557 4e-05 L
.8757 4e-05 L
.87596 4e-05 L
.87608 4e-05 L
.87623 4e-05 L
.87636 4e-05 L
.87651 4e-05 L
.87676 4e-05 L
.87691 4e-05 L
.87704 4e-05 L
.87719 4e-05 L
.87734 4e-05 L
.87748 4e-05 L
.87763 4e-05 L
.87776 4e-05 L
.87789 4e-05 L
.87814 4e-05 L
.87839 4e-05 L
.87864 4e-05 L
.8789 4e-05 L
.87915 4e-05 L
.87938 4e-05 L
.87961 4e-05 L
.87982 4e-05 L
.88006 4e-05 L
.88029 4e-05 L
.88054 4e-05 L
.8808 4e-05 L
.88103 4e-05 L
.88127 4e-05 L
.88154 4e-05 L
.88168 4e-05 L
.88182 4e-05 L
.88208 4e-05 L
Mistroke
.88233 4e-05 L
.88254 4e-05 L
.88278 4e-05 L
.88302 4e-05 L
.88325 4e-05 L
.88346 4e-05 L
.88366 4e-05 L
.88387 4e-05 L
.8841 4e-05 L
.88433 4e-05 L
.88457 4e-05 L
.88481 4e-05 L
.88502 4e-05 L
.88526 4e-05 L
.8854 4e-05 L
.88553 4e-05 L
.88577 4e-05 L
.88602 4e-05 L
.88626 4e-05 L
.88653 4e-05 L
.88678 4e-05 L
.88701 4e-05 L
.88725 4e-05 L
.88746 4e-05 L
.8877 4e-05 L
.88792 4e-05 L
.88817 4e-05 L
.88844 4e-05 L
.88866 4e-05 L
.88891 4e-05 L
.88917 4e-05 L
.88932 4e-05 L
.88946 4e-05 L
.88972 4e-05 L
.88997 4e-05 L
.89018 4e-05 L
.89041 4e-05 L
.89066 4e-05 L
.89089 4e-05 L
.8911 4e-05 L
.8913 4e-05 L
.89152 4e-05 L
.89174 4e-05 L
.89197 4e-05 L
.89221 4e-05 L
.89244 4e-05 L
.89266 4e-05 L
.8929 4e-05 L
.89304 4e-05 L
.89317 4e-05 L
Mistroke
.89341 4e-05 L
.89366 4e-05 L
.8939 4e-05 L
.89404 4e-05 L
.89417 4e-05 L
.89441 4e-05 L
.89466 4e-05 L
.89488 4e-05 L
.89509 4e-05 L
.89532 4e-05 L
.89557 4e-05 L
.89582 4e-05 L
.89596 4e-05 L
.89609 4e-05 L
.89635 4e-05 L
.8965 4e-05 L
.89663 4e-05 L
.89688 4e-05 L
.89714 4e-05 L
.89739 4e-05 L
.89761 4e-05 L
.89783 4e-05 L
.89805 4e-05 L
.89827 4e-05 L
.89847 4e-05 L
.8987 4e-05 L
.89895 4e-05 L
.89919 4e-05 L
.89941 4e-05 L
.89966 4e-05 L
.89989 4e-05 L
.9001 4e-05 L
.90033 4e-05 L
.90058 4e-05 L
.90084 4e-05 L
.90106 4e-05 L
.90131 4e-05 L
.90157 4e-05 L
.90181 4e-05 L
.90194 4e-05 L
.90208 4e-05 L
.90223 4e-05 L
.90237 4e-05 L
.90262 4e-05 L
.90285 4e-05 L
.9031 4e-05 L
.90337 4e-05 L
.90359 4e-05 L
.90383 4e-05 L
.90406 4e-05 L
Mistroke
.90426 4e-05 L
.90451 4e-05 L
.90477 4e-05 L
.90502 4e-05 L
.90524 4e-05 L
.90549 4e-05 L
.90575 4e-05 L
.906 4e-05 L
.90622 4e-05 L
.90648 4e-05 L
.90663 4e-05 L
.90677 4e-05 L
.90702 4e-05 L
.90715 4e-05 L
.90729 4e-05 L
.90743 4e-05 L
.90757 4e-05 L
.90783 4e-05 L
.90797 4e-05 L
.90811 4e-05 L
.90825 4e-05 L
.90841 4e-05 L
.90855 4e-05 L
.90869 4e-05 L
.90883 4e-05 L
.90896 4e-05 L
.9092 4e-05 L
.90946 4e-05 L
.9097 4e-05 L
.90997 4e-05 L
.91022 4e-05 L
.91045 4e-05 L
.91068 4e-05 L
.91089 4e-05 L
.91113 4e-05 L
.91136 4e-05 L
.91161 4e-05 L
.91187 4e-05 L
.91209 4e-05 L
.91234 4e-05 L
.9126 4e-05 L
.91275 4e-05 L
.91289 4e-05 L
.91315 4e-05 L
.9134 4e-05 L
.91361 4e-05 L
.91384 4e-05 L
.91409 4e-05 L
.91432 4e-05 L
.91453 4e-05 L
Mistroke
.91472 4e-05 L
.91494 4e-05 L
.91516 4e-05 L
.91539 4e-05 L
.91564 4e-05 L
.91587 4e-05 L
.91608 4e-05 L
.91633 4e-05 L
.91647 4e-05 L
.9166 4e-05 L
.91683 4e-05 L
.91708 4e-05 L
.91733 4e-05 L
.9176 4e-05 L
.91785 4e-05 L
.91808 4e-05 L
.91831 4e-05 L
.91852 4e-05 L
.91876 4e-05 L
.91899 4e-05 L
.91924 4e-05 L
.9195 4e-05 L
.91972 4e-05 L
.91997 4e-05 L
.92023 4e-05 L
.92038 4e-05 L
.92052 4e-05 L
.92078 4e-05 L
.92103 4e-05 L
.92124 4e-05 L
.92148 4e-05 L
.92172 4e-05 L
.92195 4e-05 L
.92216 4e-05 L
.92236 4e-05 L
.92258 4e-05 L
.9228 4e-05 L
.92303 4e-05 L
.92328 4e-05 L
.92351 4e-05 L
.92372 4e-05 L
.92397 4e-05 L
.92411 4e-05 L
.92423 4e-05 L
.92447 4e-05 L
.92472 4e-05 L
.92497 4e-05 L
.9251 4e-05 L
.92523 4e-05 L
.92547 4e-05 L
Mistroke
.92572 4e-05 L
.92594 4e-05 L
.92615 4e-05 L
.92638 4e-05 L
.92663 4e-05 L
.92688 4e-05 L
.92702 4e-05 L
.92715 4e-05 L
.92741 4e-05 L
.92756 4e-05 L
.9277 4e-05 L
.92794 4e-05 L
.9282 4e-05 L
.92845 4e-05 L
.92867 4e-05 L
.92889 4e-05 L
.92912 4e-05 L
.92933 4e-05 L
.92953 4e-05 L
.92976 4e-05 L
.93001 4e-05 L
.93025 4e-05 L
.93047 4e-05 L
.93072 4e-05 L
.93095 4e-05 L
.93116 4e-05 L
.93139 4e-05 L
.93164 4e-05 L
.9319 4e-05 L
.93212 4e-05 L
.93237 4e-05 L
.93263 4e-05 L
.93287 4e-05 L
.933 4e-05 L
.93314 4e-05 L
.93329 4e-05 L
.93342 4e-05 L
.93368 4e-05 L
.93391 4e-05 L
.93416 4e-05 L
.93443 4e-05 L
.93465 4e-05 L
.93489 4e-05 L
.93512 4e-05 L
.93532 4e-05 L
.93556 4e-05 L
.93583 4e-05 L
.93607 4e-05 L
.9363 4e-05 L
.93655 4e-05 L
Mistroke
.93681 4e-05 L
.93705 4e-05 L
.93728 4e-05 L
.93754 4e-05 L
.93769 4e-05 L
.93783 4e-05 L
.93808 4e-05 L
.93821 4e-05 L
.93835 4e-05 L
.93849 4e-05 L
.93863 4e-05 L
.93889 4e-05 L
.93903 4e-05 L
.93916 4e-05 L
.93931 4e-05 L
.93947 4e-05 L
.9396 4e-05 L
.93975 4e-05 L
.93989 4e-05 L
.94002 4e-05 L
.94026 4e-05 L
.94052 4e-05 L
.94076 4e-05 L
.94103 4e-05 L
.94128 4e-05 L
.94151 4e-05 L
.94174 4e-05 L
.94195 4e-05 L
.94219 4e-05 L
.94241 4e-05 L
.94266 4e-05 L
.94292 4e-05 L
.94315 4e-05 L
.94339 4e-05 L
.94366 4e-05 L
.94381 4e-05 L
.94394 4e-05 L
.9442 4e-05 L
.94445 4e-05 L
.94466 4e-05 L
.9449 4e-05 L
.94514 4e-05 L
.94537 4e-05 L
.94558 4e-05 L
.94578 4e-05 L
.94599 4e-05 L
.94622 4e-05 L
.94645 4e-05 L
.94669 4e-05 L
.94693 4e-05 L
Mistroke
.94714 4e-05 L
.94738 4e-05 L
.94752 4e-05 L
.94765 4e-05 L
.94789 4e-05 L
.94814 4e-05 L
.94838 4e-05 L
.94865 4e-05 L
.9489 4e-05 L
.94913 4e-05 L
.94936 4e-05 L
.94957 4e-05 L
.94981 4e-05 L
.95004 4e-05 L
.95029 4e-05 L
.95055 4e-05 L
.95078 4e-05 L
.95102 4e-05 L
.95129 4e-05 L
.95144 4e-05 L
.95157 4e-05 L
.95183 4e-05 L
.95208 4e-05 L
.9523 4e-05 L
.95253 4e-05 L
.95277 4e-05 L
.953 4e-05 L
.95322 4e-05 L
.95341 4e-05 L
.95363 4e-05 L
.95385 4e-05 L
.95408 4e-05 L
.95433 4e-05 L
.95456 4e-05 L
.95477 4e-05 L
.95502 4e-05 L
.95516 4e-05 L
.95529 4e-05 L
.95552 4e-05 L
.95577 4e-05 L
.95602 4e-05 L
.95616 4e-05 L
.95628 4e-05 L
.95652 4e-05 L
.95677 4e-05 L
.95699 4e-05 L
.9572 4e-05 L
.95743 4e-05 L
.95768 4e-05 L
.95793 4e-05 L
Mistroke
.95807 4e-05 L
.9582 4e-05 L
.95846 4e-05 L
.95861 4e-05 L
.95875 4e-05 L
.95899 4e-05 L
.95925 4e-05 L
.9595 4e-05 L
.95972 4e-05 L
.95994 4e-05 L
.96017 4e-05 L
.96038 4e-05 L
.96058 4e-05 L
.96081 4e-05 L
.96106 4e-05 L
.9613 4e-05 L
.96152 4e-05 L
.96177 4e-05 L
.962 4e-05 L
.96221 4e-05 L
.96244 4e-05 L
.96269 4e-05 L
.96295 4e-05 L
.96317 4e-05 L
.96342 4e-05 L
.96368 4e-05 L
.96392 4e-05 L
.96405 4e-05 L
.96419 4e-05 L
.96434 4e-05 L
.96447 4e-05 L
.96473 4e-05 L
.96496 4e-05 L
.96521 4e-05 L
.96548 4e-05 L
.9657 4e-05 L
.96594 4e-05 L
.96617 4e-05 L
.96637 4e-05 L
.96661 4e-05 L
.96688 4e-05 L
.96712 4e-05 L
.96735 4e-05 L
.96759 4e-05 L
.96785 4e-05 L
.9681 4e-05 L
.96833 4e-05 L
.96859 4e-05 L
.96874 4e-05 L
.96888 4e-05 L
Mistroke
.96913 4e-05 L
.96927 4e-05 L
.9694 4e-05 L
.96953 4e-05 L
.96968 4e-05 L
.96994 4e-05 L
.97008 4e-05 L
.97021 4e-05 L
.97036 4e-05 L
.97052 4e-05 L
.97065 4e-05 L
.9708 4e-05 L
.97094 4e-05 L
.97106 4e-05 L
.97131 4e-05 L
.97157 4e-05 L
.97181 4e-05 L
.97207 4e-05 L
.97232 4e-05 L
.97255 4e-05 L
.97278 4e-05 L
.97299 4e-05 L
.97323 4e-05 L
.97346 4e-05 L
.97371 4e-05 L
.97397 4e-05 L
.97419 4e-05 L
.97444 4e-05 L
.9747 4e-05 L
.97485 4e-05 L
.97499 4e-05 L
.97525 4e-05 L
.9755 4e-05 L
.97571 4e-05 L
.97594 4e-05 L
.97619 4e-05 L
.97642 4e-05 L
.97663 4e-05 L
.97682 4e-05 L
.97704 4e-05 L
.97726 4e-05 L
.97749 4e-05 L
.97774 4e-05 L
.97797 4e-05 L
.97818 4e-05 L
.97843 4e-05 L
.97857 4e-05 L
.9787 4e-05 L
.97893 4e-05 L
.97919 4e-05 L
Mistroke
.97943 4e-05 L
.97969 4e-05 L
.97995 4e-05 L
.98018 4e-05 L
.98041 4e-05 L
.98062 4e-05 L
.98086 4e-05 L
.98109 4e-05 L
.98133 4e-05 L
.9816 4e-05 L
.98182 4e-05 L
.98207 4e-05 L
.98233 4e-05 L
.98248 4e-05 L
.98262 4e-05 L
.98288 4e-05 L
.98313 4e-05 L
.98334 4e-05 L
.98357 4e-05 L
.98382 4e-05 L
.98405 4e-05 L
.98426 4e-05 L
.98445 4e-05 L
.98467 4e-05 L
.98489 4e-05 L
.98513 4e-05 L
.98537 4e-05 L
.9856 4e-05 L
.98581 4e-05 L
.98606 4e-05 L
.9862 4e-05 L
.98633 4e-05 L
.98657 4e-05 L
.98682 4e-05 L
.98706 4e-05 L
.9872 4e-05 L
.98733 4e-05 L
.98756 4e-05 L
.98781 4e-05 L
.98803 4e-05 L
.98824 4e-05 L
.98847 4e-05 L
.98872 4e-05 L
.98897 4e-05 L
.98911 4e-05 L
.98924 4e-05 L
.9895 4e-05 L
.98965 4e-05 L
.98979 4e-05 L
.99003 4e-05 L
Mistroke
.99029 4e-05 L
.99054 4e-05 L
.99077 4e-05 L
.99098 4e-05 L
.99121 4e-05 L
.99142 4e-05 L
.99162 4e-05 L
.99185 4e-05 L
.9921 4e-05 L
.99234 4e-05 L
.99256 4e-05 L
.99281 4e-05 L
.99304 4e-05 L
.99325 4e-05 L
.99348 4e-05 L
.99373 4e-05 L
.99399 4e-05 L
.99421 4e-05 L
.99446 4e-05 L
.99463 4e-05 L
.9948 4e-05 L
.99498 4e-05 L
.99517 4e-05 L
.99534 4e-05 L
.99549 4e-05 L
.99566 4e-05 L
.99585 4e-05 L
.996 4e-05 L
.99617 4e-05 L
.99634 4e-05 L
.99651 4e-05 L
.99666 4e-05 L
.9968 4e-05 L
.99696 4e-05 L
.99711 4e-05 L
.99728 4e-05 L
.99746 4e-05 L
.99765 4e-05 L
.99782 4e-05 L
.99799 4e-05 L
.99814 4e-05 L
.99831 4e-05 L
.99848 4e-05 L
.99866 4e-05 L
.99885 4e-05 L
.99903 4e-05 L
.99919 4e-05 L
.99938 4e-05 L
.99959 4e-05 L
.99978 4e-05 L
Mistroke
.99996 4e-05 L
Mfstroke
.8081 .99996 m
.81588 .99996 L
.82437 .99996 L
.83234 .99996 L
.84001 .99996 L
.84817 .99996 L
.85603 .99996 L
.86437 .99996 L
.87242 .99996 L
.88016 .99996 L
.88839 .99996 L
.89632 .99996 L
.90394 .99996 L
.91206 .99996 L
.91987 .99996 L
.92817 .99996 L
.93617 .99996 L
.94387 .99996 L
.95205 .99996 L
.95994 .99996 L
.96831 .99996 L
.97638 .99996 L
.98415 .99996 L
.99241 .99996 L
.99996 .99996 L
s
.80217 .99996 m
.80241 .99703 L
.80268 .99378 L
.80292 .99066 L
.80316 .98761 L
.80341 .98429 L
.80365 .98103 L
.80391 .97748 L
.80416 .97398 L
.8044 .97052 L
.80465 .96673 L
.8049 .96297 L
.80513 .95924 L
.80538 .95512 L
.80563 .951 L
.80588 .94641 L
.80613 .94178 L
.80637 .93707 L
.80662 .93172 L
.80686 .92618 L
.80712 .9197 L
.80737 .91266 L
.80761 .90471 L
.80773 .89997 L
.80787 .89378 L
.80792 .89055 L
.80799 .88643 L
.80802 .88402 L
.80805 .8813 L
.80807 .87813 L
.80808 .87703 L
.80809 .87563 L
.80809 .87407 L
.8081 .87003 L
s
.80217 .99996 m
.80241 .99996 L
.80268 .99996 L
.80292 .99996 L
.80316 .99996 L
.80341 .99996 L
.80365 .99996 L
.80391 .99996 L
.80416 .99996 L
.8044 .99996 L
.80465 .99996 L
.8049 .99996 L
.80513 .99996 L
.80538 .99996 L
.80563 .99996 L
.80588 .99996 L
.80613 .99996 L
.80637 .99996 L
.80662 .99996 L
.80686 .99996 L
.80712 .99996 L
.80737 .99996 L
.80761 .99996 L
.80787 .99996 L
.8081 .99996 L
s
.5 1 1 r
.80217 .99996 m
.80241 .99703 L
.80268 .99378 L
.80292 .99066 L
.80316 .98761 L
.80341 .98429 L
.80365 .98103 L
.80391 .97748 L
.80416 .97398 L
.8044 .97052 L
.80465 .96673 L
.8049 .96297 L
.80513 .95924 L
.80538 .95512 L
.80563 .951 L
.80588 .94641 L
.80613 .94178 L
.80637 .93707 L
.80662 .93172 L
.80686 .92618 L
.80712 .9197 L
.80737 .91266 L
.80761 .90471 L
.80773 .89997 L
.80787 .89378 L
.80792 .89055 L
.80799 .88643 L
.80802 .88402 L
.80805 .8813 L
.80807 .87813 L
.80808 .87703 L
.80809 .87563 L
.80809 .87407 L
.8081 .87003 L
.8081 .99996 L
.80787 .99996 L
.80761 .99996 L
.80737 .99996 L
.80712 .99996 L
.80686 .99996 L
.80662 .99996 L
.80637 .99996 L
.80613 .99996 L
.80588 .99996 L
.80563 .99996 L
.80538 .99996 L
.80513 .99996 L
.8049 .99996 L
.80465 .99996 L
.8044 .99996 L
.80416 .99996 L
.80391 .99996 L
.80365 .99996 L
.80341 .99996 L
.80316 .99996 L
.80292 .99996 L
.80268 .99996 L
.80241 .99996 L
.80217 .99996 L
F
0 g
.80217 .99996 m
.80241 .99703 L
.80268 .99378 L
.80292 .99066 L
.80316 .98761 L
.80341 .98429 L
.80365 .98103 L
.80391 .97748 L
.80416 .97398 L
.8044 .97052 L
.80465 .96673 L
.8049 .96297 L
.80513 .95924 L
.80538 .95512 L
.80563 .951 L
.80588 .94641 L
.80613 .94178 L
.80637 .93707 L
.80662 .93172 L
.80686 .92618 L
.80712 .9197 L
.80737 .91266 L
.80761 .90471 L
.80773 .89997 L
.80787 .89378 L
.80792 .89055 L
.80799 .88643 L
.80802 .88402 L
.80805 .8813 L
.80807 .87813 L
.80808 .87703 L
.80809 .87563 L
.80809 .87407 L
.8081 .87003 L
s
.80217 .99996 m
.80241 .99996 L
.80268 .99996 L
.80292 .99996 L
.80316 .99996 L
.80341 .99996 L
.80365 .99996 L
.80391 .99996 L
.80416 .99996 L
.8044 .99996 L
.80465 .99996 L
.8049 .99996 L
.80513 .99996 L
.80538 .99996 L
.80563 .99996 L
.80588 .99996 L
.80613 .99996 L
.80637 .99996 L
.80662 .99996 L
.80686 .99996 L
.80712 .99996 L
.80737 .99996 L
.80761 .99996 L
.80787 .99996 L
.8081 .99996 L
s
4e-05 4e-05 m
7e-05 4e-05 L
.0001 4e-05 L
.00014 4e-05 L
.00017 4e-05 L
.0002 4e-05 L
.00023 4e-05 L
.00026 4e-05 L
.00029 4e-05 L
.00033 4e-05 L
.00036 4e-05 L
.0004 4e-05 L
.00043 4e-05 L
.00046 4e-05 L
.00048 4e-05 L
.0005 4e-05 L
.00054 4e-05 L
.00057 4e-05 L
.00059 4e-05 L
.00061 4e-05 L
.00065 4e-05 L
.00067 4e-05 L
.00069 4e-05 L
.00071 4e-05 L
.00073 4e-05 L
.00074 4e-05 L
.00076 4e-05 L
.0008 4e-05 L
.00084 4e-05 L
.00087 4e-05 L
.0009 4e-05 L
.00093 4e-05 L
.00096 4e-05 L
.001 4e-05 L
.00104 4e-05 L
.00107 4e-05 L
.0011 4e-05 L
.00114 4e-05 L
.00116 4e-05 L
.00118 4e-05 L
.0012 4e-05 L
.00122 4e-05 L
.00126 4e-05 L
.00128 4e-05 L
.0013 4e-05 L
.00133 4e-05 L
.00136 4e-05 L
.00138 4e-05 L
.0014 4e-05 L
.00144 4e-05 L
Mistroke
.00146 4e-05 L
.00148 4e-05 L
.0015 4e-05 L
.00152 4e-05 L
.00154 4e-05 L
.00156 4e-05 L
.00158 4e-05 L
.0016 4e-05 L
.00162 4e-05 L
.00164 4e-05 L
.00166 4e-05 L
.00168 4e-05 L
.00172 4e-05 L
.00174 4e-05 L
.00176 4e-05 L
.00179 4e-05 L
.00183 4e-05 L
.00186 4e-05 L
.00189 4e-05 L
.00193 4e-05 L
.00196 4e-05 L
.00198 4e-05 L
.002 4e-05 L
.00204 4e-05 L
.00206 4e-05 L
.00208 4e-05 L
.0021 4e-05 L
.00212 4e-05 L
.00216 4e-05 L
.00218 4e-05 L
.0022 4e-05 L
.00223 4e-05 L
.00226 4e-05 L
.0023 4e-05 L
.00234 4e-05 L
.00237 4e-05 L
.0024 4e-05 L
.00244 4e-05 L
.00247 4e-05 L
.0025 4e-05 L
.00254 4e-05 L
.00256 4e-05 L
.00258 4e-05 L
.00261 4e-05 L
.00263 4e-05 L
.00265 4e-05 L
.00267 4e-05 L
.00269 4e-05 L
.00272 4e-05 L
.00274 4e-05 L
Mistroke
.00276 4e-05 L
.0028 4e-05 L
.00283 4e-05 L
.00287 4e-05 L
.0029 4e-05 L
.00294 4e-05 L
.00296 4e-05 L
.003 4e-05 L
.00303 4e-05 L
.00306 4e-05 L
.00309 4e-05 L
.00312 4e-05 L
.00315 4e-05 L
.00319 4e-05 L
.00322 4e-05 L
.00325 4e-05 L
.00328 4e-05 L
.00332 4e-05 L
.00334 4e-05 L
.00336 4e-05 L
.00339 4e-05 L
.00343 4e-05 L
.00346 4e-05 L
.00349 4e-05 L
.00353 4e-05 L
.00357 4e-05 L
.0036 4e-05 L
.00363 4e-05 L
.00366 4e-05 L
.00369 4e-05 L
.00373 4e-05 L
.00376 4e-05 L
.0038 4e-05 L
.00383 4e-05 L
.00387 4e-05 L
.00389 4e-05 L
.00391 4e-05 L
.00394 4e-05 L
.00398 4e-05 L
.00401 4e-05 L
.00404 4e-05 L
.00408 4e-05 L
.00411 4e-05 L
.00414 4e-05 L
.00417 4e-05 L
.0042 4e-05 L
.00423 4e-05 L
.00426 4e-05 L
.0043 4e-05 L
.00433 4e-05 L
Mistroke
.00436 4e-05 L
.00439 4e-05 L
.00441 4e-05 L
.00443 4e-05 L
.00446 4e-05 L
.0045 4e-05 L
.00453 4e-05 L
.00457 4e-05 L
.00461 4e-05 L
.00464 4e-05 L
.00467 4e-05 L
.0047 4e-05 L
.00474 4e-05 L
.00477 4e-05 L
.0048 4e-05 L
.00484 4e-05 L
.00487 4e-05 L
.00491 4e-05 L
.00494 4e-05 L
.00496 4e-05 L
.00498 4e-05 L
.00502 4e-05 L
.00506 4e-05 L
.00509 4e-05 L
.00512 4e-05 L
.00515 4e-05 L
.00518 4e-05 L
.00521 4e-05 L
.00524 4e-05 L
.00527 4e-05 L
.0053 4e-05 L
.00534 4e-05 L
.00537 4e-05 L
.0054 4e-05 L
.00543 4e-05 L
.00547 4e-05 L
.00549 4e-05 L
.00551 4e-05 L
.00554 4e-05 L
.00558 4e-05 L
.00561 4e-05 L
.00565 4e-05 L
.00568 4e-05 L
.00572 4e-05 L
.00575 4e-05 L
.00578 4e-05 L
.00581 4e-05 L
.00584 4e-05 L
.00588 4e-05 L
.00592 4e-05 L
Mistroke
.00595 4e-05 L
.00598 4e-05 L
.00602 4e-05 L
.00604 4e-05 L
.00606 4e-05 L
.0061 4e-05 L
.00613 4e-05 L
.00616 4e-05 L
.0062 4e-05 L
.00623 4e-05 L
.00626 4e-05 L
.00629 4e-05 L
.00632 4e-05 L
.00635 4e-05 L
.00638 4e-05 L
.00641 4e-05 L
.00645 4e-05 L
.00648 4e-05 L
.00651 4e-05 L
.00655 4e-05 L
.00657 4e-05 L
.00658 4e-05 L
.00662 4e-05 L
.00665 4e-05 L
.00669 4e-05 L
.00673 4e-05 L
.00676 4e-05 L
.00679 4e-05 L
.00682 4e-05 L
.00686 4e-05 L
.00689 4e-05 L
.00692 4e-05 L
.00696 4e-05 L
.00699 4e-05 L
.00703 4e-05 L
.00706 4e-05 L
.0071 4e-05 L
.00712 4e-05 L
.00714 4e-05 L
.00718 4e-05 L
.00721 4e-05 L
.00724 4e-05 L
.00727 4e-05 L
.00731 4e-05 L
.00734 4e-05 L
.00737 4e-05 L
.0074 4e-05 L
.00743 4e-05 L
.00746 4e-05 L
.00749 4e-05 L
Mistroke
.00753 4e-05 L
.00756 4e-05 L
.00759 4e-05 L
.00763 4e-05 L
.00765 4e-05 L
.00766 4e-05 L
.0077 4e-05 L
.00773 4e-05 L
.00777 4e-05 L
.00779 4e-05 L
.0078 4e-05 L
.00784 4e-05 L
.00787 4e-05 L
.0079 4e-05 L
.00793 4e-05 L
.00797 4e-05 L
.008 4e-05 L
.00804 4e-05 L
.00806 4e-05 L
.00808 4e-05 L
.00811 4e-05 L
.00813 4e-05 L
.00815 4e-05 L
.00819 4e-05 L
.00822 4e-05 L
.00826 4e-05 L
.00829 4e-05 L
.00832 4e-05 L
.00835 4e-05 L
.00838 4e-05 L
.00841 4e-05 L
.00844 4e-05 L
.00848 4e-05 L
.00851 4e-05 L
.00854 4e-05 L
.00858 4e-05 L
.00861 4e-05 L
.00864 4e-05 L
.00867 4e-05 L
.00871 4e-05 L
.00875 4e-05 L
.00878 4e-05 L
.00881 4e-05 L
.00885 4e-05 L
.00888 4e-05 L
.0089 4e-05 L
.00892 4e-05 L
.00894 4e-05 L
.00896 4e-05 L
.009 4e-05 L
Mistroke
.00903 4e-05 L
.00907 4e-05 L
.0091 4e-05 L
.00913 4e-05 L
.00917 4e-05 L
.0092 4e-05 L
.00923 4e-05 L
.00926 4e-05 L
.0093 4e-05 L
.00934 4e-05 L
.00937 4e-05 L
.0094 4e-05 L
.00944 4e-05 L
.00947 4e-05 L
.00951 4e-05 L
.00954 4e-05 L
.00956 4e-05 L
.00958 4e-05 L
.00962 4e-05 L
.00964 4e-05 L
.00966 4e-05 L
.00968 4e-05 L
.0097 4e-05 L
.00973 4e-05 L
.00975 4e-05 L
.00977 4e-05 L
.00979 4e-05 L
.00982 4e-05 L
.00983 4e-05 L
.00986 4e-05 L
.00987 4e-05 L
.00989 4e-05 L
.00993 4e-05 L
.00996 4e-05 L
.01 4e-05 L
.01004 4e-05 L
.01007 4e-05 L
.0101 4e-05 L
.01014 4e-05 L
.01017 4e-05 L
.0102 4e-05 L
.01023 4e-05 L
.01027 4e-05 L
.0103 4e-05 L
.01034 4e-05 L
.01037 4e-05 L
.01041 4e-05 L
.01043 4e-05 L
.01045 4e-05 L
.01048 4e-05 L
Mistroke
.01052 4e-05 L
.01055 4e-05 L
.01058 4e-05 L
.01062 4e-05 L
.01065 4e-05 L
.01068 4e-05 L
.01071 4e-05 L
.01074 4e-05 L
.01077 4e-05 L
.0108 4e-05 L
.01084 4e-05 L
.01087 4e-05 L
.0109 4e-05 L
.01093 4e-05 L
.01095 4e-05 L
.01097 4e-05 L
.01101 4e-05 L
.01104 4e-05 L
.01107 4e-05 L
.01111 4e-05 L
.01115 4e-05 L
.01118 4e-05 L
.01121 4e-05 L
.01124 4e-05 L
.01128 4e-05 L
.01131 4e-05 L
.01134 4e-05 L
.01138 4e-05 L
.01141 4e-05 L
.01145 4e-05 L
.01149 4e-05 L
.01151 4e-05 L
.01153 4e-05 L
.01156 4e-05 L
.0116 4e-05 L
.01163 4e-05 L
.01166 4e-05 L
.0117 4e-05 L
.01173 4e-05 L
.01176 4e-05 L
.01179 4e-05 L
.01182 4e-05 L
.01185 4e-05 L
.01188 4e-05 L
.01191 4e-05 L
.01195 4e-05 L
.01198 4e-05 L
.01201 4e-05 L
.01203 4e-05 L
.01205 4e-05 L
Mistroke
.01208 4e-05 L
.01212 4e-05 L
.01215 4e-05 L
.01217 4e-05 L
.01219 4e-05 L
.01222 4e-05 L
.01226 4e-05 L
.01229 4e-05 L
.01232 4e-05 L
.01235 4e-05 L
.01239 4e-05 L
.01242 4e-05 L
.01244 4e-05 L
.01246 4e-05 L
.0125 4e-05 L
.01252 4e-05 L
.01254 4e-05 L
.01257 4e-05 L
.01261 4e-05 L
.01265 4e-05 L
.01268 4e-05 L
.01271 4e-05 L
.01274 4e-05 L
.01277 4e-05 L
.0128 4e-05 L
.01283 4e-05 L
.01287 4e-05 L
.0129 4e-05 L
.01293 4e-05 L
.01297 4e-05 L
.013 4e-05 L
.01303 4e-05 L
.01306 4e-05 L
.0131 4e-05 L
.01313 4e-05 L
.01316 4e-05 L
.0132 4e-05 L
.01324 4e-05 L
.01327 4e-05 L
.01329 4e-05 L
.01331 4e-05 L
.01333 4e-05 L
.01335 4e-05 L
.01338 4e-05 L
.01342 4e-05 L
.01345 4e-05 L
.01349 4e-05 L
.01352 4e-05 L
.01356 4e-05 L
.01359 4e-05 L
Mistroke
.01362 4e-05 L
.01365 4e-05 L
.01369 4e-05 L
.01372 4e-05 L
.01375 4e-05 L
.01379 4e-05 L
.01383 4e-05 L
.01386 4e-05 L
.01389 4e-05 L
.01393 4e-05 L
.01395 4e-05 L
.01397 4e-05 L
.01401 4e-05 L
.01402 4e-05 L
.01404 4e-05 L
.01406 4e-05 L
.01408 4e-05 L
.01412 4e-05 L
.01414 4e-05 L
.01416 4e-05 L
.01418 4e-05 L
.0142 4e-05 L
.01422 4e-05 L
.01424 4e-05 L
.01426 4e-05 L
.01428 4e-05 L
.01431 4e-05 L
.01435 4e-05 L
.01438 4e-05 L
.01442 4e-05 L
.01446 4e-05 L
.01449 4e-05 L
.01452 4e-05 L
.01455 4e-05 L
.01459 4e-05 L
.01462 4e-05 L
.01465 4e-05 L
.01469 4e-05 L
.01472 4e-05 L
.01476 4e-05 L
.01479 4e-05 L
.01481 4e-05 L
.01483 4e-05 L
.01487 4e-05 L
.01491 4e-05 L
.01494 4e-05 L
.01497 4e-05 L
.015 4e-05 L
.01504 4e-05 L
.01507 4e-05 L
Mistroke
.01509 4e-05 L
.01512 4e-05 L
.01516 4e-05 L
.01519 4e-05 L
.01522 4e-05 L
.01526 4e-05 L
.01528 4e-05 L
.01532 4e-05 L
.01534 4e-05 L
.01536 4e-05 L
.01539 4e-05 L
.01543 4e-05 L
.01546 4e-05 L
.0155 4e-05 L
.01553 4e-05 L
.01557 4e-05 L
.0156 4e-05 L
.01563 4e-05 L
.01566 4e-05 L
.0157 4e-05 L
.01573 4e-05 L
.01577 4e-05 L
.0158 4e-05 L
.01583 4e-05 L
.01587 4e-05 L
.01589 4e-05 L
.01591 4e-05 L
.01595 4e-05 L
.01598 4e-05 L
.01601 4e-05 L
.01605 4e-05 L
.01608 4e-05 L
.01611 4e-05 L
.01614 4e-05 L
.01617 4e-05 L
.0162 4e-05 L
.01623 4e-05 L
.01627 4e-05 L
.0163 4e-05 L
.01633 4e-05 L
.01636 4e-05 L
.0164 4e-05 L
.01642 4e-05 L
.01644 4e-05 L
.01647 4e-05 L
.0165 4e-05 L
.01654 4e-05 L
.01656 4e-05 L
.01658 4e-05 L
.01661 4e-05 L
Mistroke
.01665 4e-05 L
.01668 4e-05 L
.01671 4e-05 L
.01674 4e-05 L
.01677 4e-05 L
.01681 4e-05 L
.01683 4e-05 L
.01685 4e-05 L
.01688 4e-05 L
.01691 4e-05 L
.01692 4e-05 L
.01696 4e-05 L
.017 4e-05 L
.01703 4e-05 L
.01706 4e-05 L
.01709 4e-05 L
.01712 4e-05 L
.01716 4e-05 L
.01718 4e-05 L
.01722 4e-05 L
.01725 4e-05 L
.01728 4e-05 L
.01732 4e-05 L
.01735 4e-05 L
.01738 4e-05 L
.01741 4e-05 L
.01745 4e-05 L
.01748 4e-05 L
.01752 4e-05 L
.01755 4e-05 L
.01758 4e-05 L
.01762 4e-05 L
.01766 4e-05 L
.01767 4e-05 L
.01769 4e-05 L
.01771 4e-05 L
.01773 4e-05 L
.01777 4e-05 L
.0178 4e-05 L
.01784 4e-05 L
.01787 4e-05 L
.01791 4e-05 L
.01794 4e-05 L
.01797 4e-05 L
.018 4e-05 L
.01804 4e-05 L
.01807 4e-05 L
.01811 4e-05 L
.01814 4e-05 L
.01817 4e-05 L
Mistroke
.01821 4e-05 L
.01825 4e-05 L
.01828 4e-05 L
.01831 4e-05 L
.01834 4e-05 L
.01836 4e-05 L
.01839 4e-05 L
.01841 4e-05 L
.01843 4e-05 L
.01845 4e-05 L
.01847 4e-05 L
.0185 4e-05 L
.01852 4e-05 L
.01854 4e-05 L
.01856 4e-05 L
.01859 4e-05 L
.01861 4e-05 L
.01863 4e-05 L
.01865 4e-05 L
.01866 4e-05 L
.0187 4e-05 L
.01873 4e-05 L
.01877 4e-05 L
.01881 4e-05 L
.01884 4e-05 L
.01887 4e-05 L
.01891 4e-05 L
.01894 4e-05 L
.01897 4e-05 L
.019 4e-05 L
.01904 4e-05 L
.01907 4e-05 L
.01911 4e-05 L
.01914 4e-05 L
.01918 4e-05 L
.0192 4e-05 L
.01922 4e-05 L
.01926 4e-05 L
.01929 4e-05 L
.01932 4e-05 L
.01935 4e-05 L
.01939 4e-05 L
.01942 4e-05 L
.01945 4e-05 L
.01948 4e-05 L
.01951 4e-05 L
.01954 4e-05 L
.01957 4e-05 L
.01961 4e-05 L
.01964 4e-05 L
Mistroke
.01967 4e-05 L
.0197 4e-05 L
.01972 4e-05 L
.01974 4e-05 L
.01978 4e-05 L
.01981 4e-05 L
.01985 4e-05 L
.01988 4e-05 L
.01992 4e-05 L
.01995 4e-05 L
.01998 4e-05 L
.02001 4e-05 L
.02005 4e-05 L
.02008 4e-05 L
.02011 4e-05 L
.02015 4e-05 L
.02018 4e-05 L
.02022 4e-05 L
.02026 4e-05 L
.02028 4e-05 L
.0203 4e-05 L
.02033 4e-05 L
.02037 4e-05 L
.0204 4e-05 L
.02043 4e-05 L
.02047 4e-05 L
.0205 4e-05 L
.02053 4e-05 L
.02056 4e-05 L
.02059 4e-05 L
.02062 4e-05 L
.02065 4e-05 L
.02068 4e-05 L
.02072 4e-05 L
.02075 4e-05 L
.02078 4e-05 L
.0208 4e-05 L
.02082 4e-05 L
.02085 4e-05 L
.02089 4e-05 L
.02092 4e-05 L
.02094 4e-05 L
.02096 4e-05 L
.02099 4e-05 L
.02103 4e-05 L
.02106 4e-05 L
.02109 4e-05 L
.02112 4e-05 L
.02116 4e-05 L
.02119 4e-05 L
Mistroke
.02121 4e-05 L
.02123 4e-05 L
.02127 4e-05 L
.02129 4e-05 L
.02131 4e-05 L
.02134 4e-05 L
.02138 4e-05 L
.02141 4e-05 L
.02145 4e-05 L
.02148 4e-05 L
.02151 4e-05 L
.02154 4e-05 L
.02157 4e-05 L
.0216 4e-05 L
.02164 4e-05 L
.02167 4e-05 L
.0217 4e-05 L
.02173 4e-05 L
.02177 4e-05 L
.0218 4e-05 L
.02183 4e-05 L
.02186 4e-05 L
.0219 4e-05 L
.02193 4e-05 L
.02197 4e-05 L
.02201 4e-05 L
.02204 4e-05 L
.02206 4e-05 L
.02208 4e-05 L
.0221 4e-05 L
.02212 4e-05 L
.02215 4e-05 L
.02219 4e-05 L
.02222 4e-05 L
.02226 4e-05 L
.02229 4e-05 L
.02232 4e-05 L
.02236 4e-05 L
.02238 4e-05 L
.02242 4e-05 L
.02246 4e-05 L
.02249 4e-05 L
.02252 4e-05 L
.02256 4e-05 L
.02259 4e-05 L
.02263 4e-05 L
.02266 4e-05 L
.0227 4e-05 L
.02272 4e-05 L
.02274 4e-05 L
Mistroke
.02277 4e-05 L
.02279 4e-05 L
.02281 4e-05 L
.02283 4e-05 L
.02285 4e-05 L
.02289 4e-05 L
.02291 4e-05 L
.02293 4e-05 L
.02295 4e-05 L
.02297 4e-05 L
.02299 4e-05 L
.02301 4e-05 L
.02303 4e-05 L
.02305 4e-05 L
.02308 4e-05 L
.02312 4e-05 L
.02315 4e-05 L
.02319 4e-05 L
.02323 4e-05 L
.02326 4e-05 L
.02329 4e-05 L
.02332 4e-05 L
.02335 4e-05 L
.02339 4e-05 L
.02342 4e-05 L
.02346 4e-05 L
.02349 4e-05 L
.02352 4e-05 L
.02356 4e-05 L
.02358 4e-05 L
.0236 4e-05 L
.02364 4e-05 L
.02367 4e-05 L
.0237 4e-05 L
.02374 4e-05 L
.02377 4e-05 L
.0238 4e-05 L
.02383 4e-05 L
.02386 4e-05 L
.02389 4e-05 L
.02392 4e-05 L
.02396 4e-05 L
.02399 4e-05 L
.02402 4e-05 L
.02405 4e-05 L
.02409 4e-05 L
.02411 4e-05 L
.02413 4e-05 L
.02416 4e-05 L
.02419 4e-05 L
Mistroke
.02423 4e-05 L
.02427 4e-05 L
.0243 4e-05 L
.02433 4e-05 L
.02437 4e-05 L
.0244 4e-05 L
.02443 4e-05 L
.02446 4e-05 L
.0245 4e-05 L
.02453 4e-05 L
.02457 4e-05 L
.0246 4e-05 L
.02464 4e-05 L
.02466 4e-05 L
.02468 4e-05 L
.02472 4e-05 L
.02475 4e-05 L
.02478 4e-05 L
.02481 4e-05 L
.02485 4e-05 L
.02488 4e-05 L
.02491 4e-05 L
.02494 4e-05 L
.02497 4e-05 L
.025 4e-05 L
.02503 4e-05 L
.02507 4e-05 L
.0251 4e-05 L
.02513 4e-05 L
.02516 4e-05 L
.02518 4e-05 L
.0252 4e-05 L
.02524 4e-05 L
.02527 4e-05 L
.02531 4e-05 L
.02533 4e-05 L
.02534 4e-05 L
.02538 4e-05 L
.02541 4e-05 L
.02544 4e-05 L
.02547 4e-05 L
.02551 4e-05 L
.02554 4e-05 L
.02558 4e-05 L
.0256 4e-05 L
.02561 4e-05 L
.02565 4e-05 L
.02567 4e-05 L
.02569 4e-05 L
.02573 4e-05 L
Mistroke
.02576 4e-05 L
.0258 4e-05 L
.02583 4e-05 L
.02586 4e-05 L
.02589 4e-05 L
.02592 4e-05 L
.02595 4e-05 L
.02598 4e-05 L
.02602 4e-05 L
.02605 4e-05 L
.02608 4e-05 L
.02612 4e-05 L
.02615 4e-05 L
.02618 4e-05 L
.02621 4e-05 L
.02625 4e-05 L
.02628 4e-05 L
.02632 4e-05 L
.02635 4e-05 L
.02638 4e-05 L
.0264 4e-05 L
.02642 4e-05 L
.02645 4e-05 L
.02647 4e-05 L
.0265 4e-05 L
.02652 4e-05 L
.02655 4e-05 L
.02657 4e-05 L
.02659 4e-05 L
.02662 4e-05 L
.02664 4e-05 L
.02666 4e-05 L
.02668 4e-05 L
.0267 4e-05 L
.02673 4e-05 L
.02675 4e-05 L
.02677 4e-05 L
.0268 4e-05 L
.02683 4e-05 L
.02685 4e-05 L
.02687 4e-05 L
.02689 4e-05 L
.02692 4e-05 L
.02694 4e-05 L
.02697 4e-05 L
.027 4e-05 L
.02702 4e-05 L
.02705 4e-05 L
.02707 4e-05 L
.0271 4e-05 L
Mistroke
.02713 4e-05 L
Mfstroke
4e-05 .99996 m
.00114 .99996 L
.00234 .99996 L
.00346 .99996 L
.00454 .99996 L
.0057 .99996 L
.00681 .99996 L
.00798 .99996 L
.00912 .99996 L
.01021 .99996 L
.01138 .99996 L
.01249 .99996 L
.01357 .99996 L
.01472 .99996 L
.01582 .99996 L
.01699 .99996 L
.01812 .99996 L
.01921 .99996 L
.02036 .99996 L
.02148 .99996 L
.02266 .99996 L
.0238 .99996 L
.0249 .99996 L
.02606 .99996 L
.02713 .99996 L
s
1 1 .5 r
4e-05 4e-05 m
7e-05 4e-05 L
.0001 4e-05 L
.00014 4e-05 L
.00017 4e-05 L
.0002 4e-05 L
.00023 4e-05 L
.00026 4e-05 L
.00029 4e-05 L
.00033 4e-05 L
.00036 4e-05 L
.0004 4e-05 L
.00043 4e-05 L
.00046 4e-05 L
.00048 4e-05 L
.0005 4e-05 L
.00054 4e-05 L
.00057 4e-05 L
.00059 4e-05 L
.00061 4e-05 L
.00065 4e-05 L
.00067 4e-05 L
.00069 4e-05 L
.00071 4e-05 L
.00073 4e-05 L
.00074 4e-05 L
.00076 4e-05 L
.0008 4e-05 L
.00084 4e-05 L
.00087 4e-05 L
.0009 4e-05 L
.00093 4e-05 L
.00096 4e-05 L
.001 4e-05 L
.00104 4e-05 L
.00107 4e-05 L
.0011 4e-05 L
.00114 4e-05 L
.00116 4e-05 L
.00118 4e-05 L
.0012 4e-05 L
.00122 4e-05 L
.00126 4e-05 L
.00128 4e-05 L
.0013 4e-05 L
.00133 4e-05 L
.00136 4e-05 L
.00138 4e-05 L
.0014 4e-05 L
.00144 4e-05 L
.00146 4e-05 L
.00148 4e-05 L
.0015 4e-05 L
.00152 4e-05 L
.00154 4e-05 L
.00156 4e-05 L
.00158 4e-05 L
.0016 4e-05 L
.00162 4e-05 L
.00164 4e-05 L
.00166 4e-05 L
.00168 4e-05 L
.00172 4e-05 L
.00174 4e-05 L
.00176 4e-05 L
.00179 4e-05 L
.00183 4e-05 L
.00186 4e-05 L
.00189 4e-05 L
.00193 4e-05 L
.00196 4e-05 L
.00198 4e-05 L
.002 4e-05 L
.00204 4e-05 L
.00206 4e-05 L
.00208 4e-05 L
.0021 4e-05 L
.00212 4e-05 L
.00216 4e-05 L
.00218 4e-05 L
.0022 4e-05 L
.00223 4e-05 L
.00226 4e-05 L
.0023 4e-05 L
.00234 4e-05 L
.00237 4e-05 L
.0024 4e-05 L
.00244 4e-05 L
.00247 4e-05 L
.0025 4e-05 L
.00254 4e-05 L
.00256 4e-05 L
.00258 4e-05 L
.00261 4e-05 L
.00263 4e-05 L
.00265 4e-05 L
.00267 4e-05 L
.00269 4e-05 L
.00272 4e-05 L
.00274 4e-05 L
.00276 4e-05 L
.0028 4e-05 L
.00283 4e-05 L
.00287 4e-05 L
.0029 4e-05 L
.00294 4e-05 L
.00296 4e-05 L
.003 4e-05 L
.00303 4e-05 L
.00306 4e-05 L
.00309 4e-05 L
.00312 4e-05 L
.00315 4e-05 L
.00319 4e-05 L
.00322 4e-05 L
.00325 4e-05 L
.00328 4e-05 L
.00332 4e-05 L
.00334 4e-05 L
.00336 4e-05 L
.00339 4e-05 L
.00343 4e-05 L
.00346 4e-05 L
.00349 4e-05 L
.00353 4e-05 L
.00357 4e-05 L
.0036 4e-05 L
.00363 4e-05 L
.00366 4e-05 L
.00369 4e-05 L
.00373 4e-05 L
.00376 4e-05 L
.0038 4e-05 L
.00383 4e-05 L
.00387 4e-05 L
.00389 4e-05 L
.00391 4e-05 L
.00394 4e-05 L
.00398 4e-05 L
.00401 4e-05 L
.00404 4e-05 L
.00408 4e-05 L
.00411 4e-05 L
.00414 4e-05 L
.00417 4e-05 L
.0042 4e-05 L
.00423 4e-05 L
.00426 4e-05 L
.0043 4e-05 L
.00433 4e-05 L
.00436 4e-05 L
.00439 4e-05 L
.00441 4e-05 L
.00443 4e-05 L
.00446 4e-05 L
.0045 4e-05 L
.00453 4e-05 L
.00457 4e-05 L
.00461 4e-05 L
.00464 4e-05 L
.00467 4e-05 L
.0047 4e-05 L
.00474 4e-05 L
.00477 4e-05 L
.0048 4e-05 L
.00484 4e-05 L
.00487 4e-05 L
.00491 4e-05 L
.00494 4e-05 L
.00496 4e-05 L
.00498 4e-05 L
.00502 4e-05 L
.00506 4e-05 L
.00509 4e-05 L
.00512 4e-05 L
.00515 4e-05 L
.00518 4e-05 L
.00521 4e-05 L
.00524 4e-05 L
.00527 4e-05 L
.0053 4e-05 L
.00534 4e-05 L
.00537 4e-05 L
.0054 4e-05 L
.00543 4e-05 L
.00547 4e-05 L
.00549 4e-05 L
.00551 4e-05 L
.00554 4e-05 L
.00558 4e-05 L
.00561 4e-05 L
.00565 4e-05 L
.00568 4e-05 L
.00572 4e-05 L
.00575 4e-05 L
.00578 4e-05 L
.00581 4e-05 L
.00584 4e-05 L
.00588 4e-05 L
.00592 4e-05 L
.00595 4e-05 L
.00598 4e-05 L
.00602 4e-05 L
.00604 4e-05 L
.00606 4e-05 L
.0061 4e-05 L
.00613 4e-05 L
.00616 4e-05 L
.0062 4e-05 L
.00623 4e-05 L
.00626 4e-05 L
.00629 4e-05 L
.00632 4e-05 L
.00635 4e-05 L
.00638 4e-05 L
.00641 4e-05 L
.00645 4e-05 L
.00648 4e-05 L
.00651 4e-05 L
.00655 4e-05 L
.00657 4e-05 L
.00658 4e-05 L
.00662 4e-05 L
.00665 4e-05 L
.00669 4e-05 L
.00673 4e-05 L
.00676 4e-05 L
.00679 4e-05 L
.00682 4e-05 L
.00686 4e-05 L
.00689 4e-05 L
.00692 4e-05 L
.00696 4e-05 L
.00699 4e-05 L
.00703 4e-05 L
.00706 4e-05 L
.0071 4e-05 L
.00712 4e-05 L
.00714 4e-05 L
.00718 4e-05 L
.00721 4e-05 L
.00724 4e-05 L
.00727 4e-05 L
.00731 4e-05 L
.00734 4e-05 L
.00737 4e-05 L
.0074 4e-05 L
.00743 4e-05 L
.00746 4e-05 L
.00749 4e-05 L
.00753 4e-05 L
.00756 4e-05 L
.00759 4e-05 L
.00763 4e-05 L
.00765 4e-05 L
.00766 4e-05 L
.0077 4e-05 L
.00773 4e-05 L
.00777 4e-05 L
.00779 4e-05 L
.0078 4e-05 L
.00784 4e-05 L
.00787 4e-05 L
.0079 4e-05 L
.00793 4e-05 L
.00797 4e-05 L
.008 4e-05 L
.00804 4e-05 L
.00806 4e-05 L
.00808 4e-05 L
.00811 4e-05 L
.00813 4e-05 L
.00815 4e-05 L
.00819 4e-05 L
.00822 4e-05 L
.00826 4e-05 L
.00829 4e-05 L
.00832 4e-05 L
.00835 4e-05 L
.00838 4e-05 L
.00841 4e-05 L
.00844 4e-05 L
.00848 4e-05 L
.00851 4e-05 L
.00854 4e-05 L
.00858 4e-05 L
.00861 4e-05 L
.00864 4e-05 L
.00867 4e-05 L
.00871 4e-05 L
.00875 4e-05 L
.00878 4e-05 L
.00881 4e-05 L
.00885 4e-05 L
.00888 4e-05 L
.0089 4e-05 L
.00892 4e-05 L
.00894 4e-05 L
.00896 4e-05 L
.009 4e-05 L
.00903 4e-05 L
.00907 4e-05 L
.0091 4e-05 L
.00913 4e-05 L
.00917 4e-05 L
.0092 4e-05 L
.00923 4e-05 L
.00926 4e-05 L
.0093 4e-05 L
.00934 4e-05 L
.00937 4e-05 L
.0094 4e-05 L
.00944 4e-05 L
.00947 4e-05 L
.00951 4e-05 L
.00954 4e-05 L
.00956 4e-05 L
.00958 4e-05 L
.00962 4e-05 L
.00964 4e-05 L
.00966 4e-05 L
.00968 4e-05 L
.0097 4e-05 L
.00973 4e-05 L
.00975 4e-05 L
.00977 4e-05 L
.00979 4e-05 L
.00982 4e-05 L
.00983 4e-05 L
.00986 4e-05 L
.00987 4e-05 L
.00989 4e-05 L
.00993 4e-05 L
.00996 4e-05 L
.01 4e-05 L
.01004 4e-05 L
.01007 4e-05 L
.0101 4e-05 L
.01014 4e-05 L
.01017 4e-05 L
.0102 4e-05 L
.01023 4e-05 L
.01027 4e-05 L
.0103 4e-05 L
.01034 4e-05 L
.01037 4e-05 L
.01041 4e-05 L
.01043 4e-05 L
.01045 4e-05 L
.01048 4e-05 L
.01052 4e-05 L
.01055 4e-05 L
.01058 4e-05 L
.01062 4e-05 L
.01065 4e-05 L
.01068 4e-05 L
.01071 4e-05 L
.01074 4e-05 L
.01077 4e-05 L
.0108 4e-05 L
.01084 4e-05 L
.01087 4e-05 L
.0109 4e-05 L
.01093 4e-05 L
.01095 4e-05 L
.01097 4e-05 L
.01101 4e-05 L
.01104 4e-05 L
.01107 4e-05 L
.01111 4e-05 L
.01115 4e-05 L
.01118 4e-05 L
.01121 4e-05 L
.01124 4e-05 L
.01128 4e-05 L
.01131 4e-05 L
.01134 4e-05 L
.01138 4e-05 L
.01141 4e-05 L
.01145 4e-05 L
.01149 4e-05 L
.01151 4e-05 L
.01153 4e-05 L
.01156 4e-05 L
.0116 4e-05 L
.01163 4e-05 L
.01166 4e-05 L
.0117 4e-05 L
.01173 4e-05 L
.01176 4e-05 L
.01179 4e-05 L
.01182 4e-05 L
.01185 4e-05 L
.01188 4e-05 L
.01191 4e-05 L
.01195 4e-05 L
.01198 4e-05 L
.01201 4e-05 L
.01203 4e-05 L
.01205 4e-05 L
.01208 4e-05 L
.01212 4e-05 L
.01215 4e-05 L
.01217 4e-05 L
.01219 4e-05 L
.01222 4e-05 L
.01226 4e-05 L
.01229 4e-05 L
.01232 4e-05 L
.01235 4e-05 L
.01239 4e-05 L
.01242 4e-05 L
.01244 4e-05 L
.01246 4e-05 L
.0125 4e-05 L
.01252 4e-05 L
.01254 4e-05 L
.01257 4e-05 L
.01261 4e-05 L
.01265 4e-05 L
.01268 4e-05 L
.01271 4e-05 L
.01274 4e-05 L
.01277 4e-05 L
.0128 4e-05 L
.01283 4e-05 L
.01287 4e-05 L
.0129 4e-05 L
.01293 4e-05 L
.01297 4e-05 L
.013 4e-05 L
.01303 4e-05 L
.01306 4e-05 L
.0131 4e-05 L
.01313 4e-05 L
.01316 4e-05 L
.0132 4e-05 L
.01324 4e-05 L
.01327 4e-05 L
.01329 4e-05 L
.01331 4e-05 L
.01333 4e-05 L
.01335 4e-05 L
.01338 4e-05 L
.01342 4e-05 L
.01345 4e-05 L
.01349 4e-05 L
.01352 4e-05 L
.01356 4e-05 L
.01359 4e-05 L
.01362 4e-05 L
.01365 4e-05 L
.01369 4e-05 L
.01372 4e-05 L
.01375 4e-05 L
.01379 4e-05 L
.01383 4e-05 L
.01386 4e-05 L
.01389 4e-05 L
.01393 4e-05 L
.01395 4e-05 L
.01397 4e-05 L
.01401 4e-05 L
.01402 4e-05 L
.01404 4e-05 L
.01406 4e-05 L
.01408 4e-05 L
.01412 4e-05 L
.01414 4e-05 L
.01416 4e-05 L
.01418 4e-05 L
.0142 4e-05 L
.01422 4e-05 L
.01424 4e-05 L
.01426 4e-05 L
.01428 4e-05 L
.01431 4e-05 L
.01435 4e-05 L
.01438 4e-05 L
.01442 4e-05 L
.01446 4e-05 L
.01449 4e-05 L
.01452 4e-05 L
.01455 4e-05 L
.01459 4e-05 L
.01462 4e-05 L
.01465 4e-05 L
.01469 4e-05 L
.01472 4e-05 L
.01476 4e-05 L
.01479 4e-05 L
.01481 4e-05 L
.01483 4e-05 L
.01487 4e-05 L
.01491 4e-05 L
.01494 4e-05 L
.01497 4e-05 L
.015 4e-05 L
.01504 4e-05 L
.01507 4e-05 L
.01509 4e-05 L
.01512 4e-05 L
.01516 4e-05 L
.01519 4e-05 L
.01522 4e-05 L
.01526 4e-05 L
.01528 4e-05 L
.01532 4e-05 L
.01534 4e-05 L
.01536 4e-05 L
.01539 4e-05 L
.01543 4e-05 L
.01546 4e-05 L
.0155 4e-05 L
.01553 4e-05 L
.01557 4e-05 L
.0156 4e-05 L
.01563 4e-05 L
.01566 4e-05 L
.0157 4e-05 L
.01573 4e-05 L
.01577 4e-05 L
.0158 4e-05 L
.01583 4e-05 L
.01587 4e-05 L
.01589 4e-05 L
.01591 4e-05 L
.01595 4e-05 L
.01598 4e-05 L
.01601 4e-05 L
.01605 4e-05 L
.01608 4e-05 L
.01611 4e-05 L
.01614 4e-05 L
.01617 4e-05 L
.0162 4e-05 L
.01623 4e-05 L
.01627 4e-05 L
.0163 4e-05 L
.01633 4e-05 L
.01636 4e-05 L
.0164 4e-05 L
.01642 4e-05 L
.01644 4e-05 L
.01647 4e-05 L
.0165 4e-05 L
.01654 4e-05 L
.01656 4e-05 L
.01658 4e-05 L
.01661 4e-05 L
.01665 4e-05 L
.01668 4e-05 L
.01671 4e-05 L
.01674 4e-05 L
.01677 4e-05 L
.01681 4e-05 L
.01683 4e-05 L
.01685 4e-05 L
.01688 4e-05 L
.01691 4e-05 L
.01692 4e-05 L
.01696 4e-05 L
.017 4e-05 L
.01703 4e-05 L
.01706 4e-05 L
.01709 4e-05 L
.01712 4e-05 L
.01716 4e-05 L
.01718 4e-05 L
.01722 4e-05 L
.01725 4e-05 L
.01728 4e-05 L
.01732 4e-05 L
.01735 4e-05 L
.01738 4e-05 L
.01741 4e-05 L
.01745 4e-05 L
.01748 4e-05 L
.01752 4e-05 L
.01755 4e-05 L
.01758 4e-05 L
.01762 4e-05 L
.01766 4e-05 L
.01767 4e-05 L
.01769 4e-05 L
.01771 4e-05 L
.01773 4e-05 L
.01777 4e-05 L
.0178 4e-05 L
.01784 4e-05 L
.01787 4e-05 L
.01791 4e-05 L
.01794 4e-05 L
.01797 4e-05 L
.018 4e-05 L
.01804 4e-05 L
.01807 4e-05 L
.01811 4e-05 L
.01814 4e-05 L
.01817 4e-05 L
.01821 4e-05 L
.01825 4e-05 L
.01828 4e-05 L
.01831 4e-05 L
.01834 4e-05 L
.01836 4e-05 L
.01839 4e-05 L
.01841 4e-05 L
.01843 4e-05 L
.01845 4e-05 L
.01847 4e-05 L
.0185 4e-05 L
.01852 4e-05 L
.01854 4e-05 L
.01856 4e-05 L
.01859 4e-05 L
.01861 4e-05 L
.01863 4e-05 L
.01865 4e-05 L
.01866 4e-05 L
.0187 4e-05 L
.01873 4e-05 L
.01877 4e-05 L
.01881 4e-05 L
.01884 4e-05 L
.01887 4e-05 L
.01891 4e-05 L
.01894 4e-05 L
.01897 4e-05 L
.019 4e-05 L
.01904 4e-05 L
.01907 4e-05 L
.01911 4e-05 L
.01914 4e-05 L
.01918 4e-05 L
.0192 4e-05 L
.01922 4e-05 L
.01926 4e-05 L
.01929 4e-05 L
.01932 4e-05 L
.01935 4e-05 L
.01939 4e-05 L
.01942 4e-05 L
.01945 4e-05 L
.01948 4e-05 L
.01951 4e-05 L
.01954 4e-05 L
.01957 4e-05 L
.01961 4e-05 L
.01964 4e-05 L
.01967 4e-05 L
.0197 4e-05 L
.01972 4e-05 L
.01974 4e-05 L
.01978 4e-05 L
.01981 4e-05 L
.01985 4e-05 L
.01988 4e-05 L
.01992 4e-05 L
.01995 4e-05 L
.01998 4e-05 L
.02001 4e-05 L
.02005 4e-05 L
.02008 4e-05 L
.02011 4e-05 L
.02015 4e-05 L
.02018 4e-05 L
.02022 4e-05 L
.02026 4e-05 L
.02028 4e-05 L
.0203 4e-05 L
.02033 4e-05 L
.02037 4e-05 L
.0204 4e-05 L
.02043 4e-05 L
.02047 4e-05 L
.0205 4e-05 L
.02053 4e-05 L
.02056 4e-05 L
.02059 4e-05 L
.02062 4e-05 L
.02065 4e-05 L
.02068 4e-05 L
.02072 4e-05 L
.02075 4e-05 L
.02078 4e-05 L
.0208 4e-05 L
.02082 4e-05 L
.02085 4e-05 L
.02089 4e-05 L
.02092 4e-05 L
.02094 4e-05 L
.02096 4e-05 L
.02099 4e-05 L
.02103 4e-05 L
.02106 4e-05 L
.02109 4e-05 L
.02112 4e-05 L
.02116 4e-05 L
.02119 4e-05 L
.02121 4e-05 L
.02123 4e-05 L
.02127 4e-05 L
.02129 4e-05 L
.02131 4e-05 L
.02134 4e-05 L
.02138 4e-05 L
.02141 4e-05 L
.02145 4e-05 L
.02148 4e-05 L
.02151 4e-05 L
.02154 4e-05 L
.02157 4e-05 L
.0216 4e-05 L
.02164 4e-05 L
.02167 4e-05 L
.0217 4e-05 L
.02173 4e-05 L
.02177 4e-05 L
.0218 4e-05 L
.02183 4e-05 L
.02186 4e-05 L
.0219 4e-05 L
.02193 4e-05 L
.02197 4e-05 L
.02201 4e-05 L
.02204 4e-05 L
.02206 4e-05 L
.02208 4e-05 L
.0221 4e-05 L
.02212 4e-05 L
.02215 4e-05 L
.02219 4e-05 L
.02222 4e-05 L
.02226 4e-05 L
.02229 4e-05 L
.02232 4e-05 L
.02236 4e-05 L
.02238 4e-05 L
.02242 4e-05 L
.02246 4e-05 L
.02249 4e-05 L
.02252 4e-05 L
.02256 4e-05 L
.02259 4e-05 L
.02263 4e-05 L
.02266 4e-05 L
.0227 4e-05 L
.02272 4e-05 L
.02274 4e-05 L
.02277 4e-05 L
.02279 4e-05 L
.02281 4e-05 L
.02283 4e-05 L
.02285 4e-05 L
.02289 4e-05 L
.02291 4e-05 L
.02293 4e-05 L
.02295 4e-05 L
.02297 4e-05 L
.02299 4e-05 L
.02301 4e-05 L
.02303 4e-05 L
.02305 4e-05 L
.02308 4e-05 L
.02312 4e-05 L
.02315 4e-05 L
.02319 4e-05 L
.02323 4e-05 L
.02326 4e-05 L
.02329 4e-05 L
.02332 4e-05 L
.02335 4e-05 L
.02339 4e-05 L
.02342 4e-05 L
.02346 4e-05 L
.02349 4e-05 L
.02352 4e-05 L
.02356 4e-05 L
.02358 4e-05 L
.0236 4e-05 L
.02364 4e-05 L
.02367 4e-05 L
.0237 4e-05 L
.02374 4e-05 L
.02377 4e-05 L
.0238 4e-05 L
.02383 4e-05 L
.02386 4e-05 L
.02389 4e-05 L
.02392 4e-05 L
.02396 4e-05 L
.02399 4e-05 L
.02402 4e-05 L
.02405 4e-05 L
.02409 4e-05 L
.02411 4e-05 L
.02413 4e-05 L
.02416 4e-05 L
.02419 4e-05 L
.02423 4e-05 L
.02427 4e-05 L
.0243 4e-05 L
.02433 4e-05 L
.02437 4e-05 L
.0244 4e-05 L
.02443 4e-05 L
.02446 4e-05 L
.0245 4e-05 L
.02453 4e-05 L
.02457 4e-05 L
.0246 4e-05 L
.02464 4e-05 L
.02466 4e-05 L
.02468 4e-05 L
.02472 4e-05 L
.02475 4e-05 L
.02478 4e-05 L
.02481 4e-05 L
.02485 4e-05 L
.02488 4e-05 L
.02491 4e-05 L
.02494 4e-05 L
.02497 4e-05 L
.025 4e-05 L
.02503 4e-05 L
.02507 4e-05 L
.0251 4e-05 L
.02513 4e-05 L
.02516 4e-05 L
.02518 4e-05 L
.0252 4e-05 L
.02524 4e-05 L
.02527 4e-05 L
.02531 4e-05 L
.02533 4e-05 L
.02534 4e-05 L
.02538 4e-05 L
.02541 4e-05 L
.02544 4e-05 L
.02547 4e-05 L
.02551 4e-05 L
.02554 4e-05 L
.02558 4e-05 L
.0256 4e-05 L
.02561 4e-05 L
.02565 4e-05 L
.02567 4e-05 L
.02569 4e-05 L
.02573 4e-05 L
.02576 4e-05 L
.0258 4e-05 L
.02583 4e-05 L
.02586 4e-05 L
.02589 4e-05 L
.02592 4e-05 L
.02595 4e-05 L
.02598 4e-05 L
.02602 4e-05 L
.02605 4e-05 L
.02608 4e-05 L
.02612 4e-05 L
.02615 4e-05 L
.02618 4e-05 L
.02621 4e-05 L
.02625 4e-05 L
.02628 4e-05 L
.02632 4e-05 L
.02635 4e-05 L
.02638 4e-05 L
.0264 4e-05 L
.02642 4e-05 L
.02645 4e-05 L
.02647 4e-05 L
.0265 4e-05 L
.02652 4e-05 L
.02655 4e-05 L
.02657 4e-05 L
.02659 4e-05 L
.02662 4e-05 L
.02664 4e-05 L
.02666 4e-05 L
.02668 4e-05 L
.0267 4e-05 L
.02673 4e-05 L
.02675 4e-05 L
.02677 4e-05 L
.0268 4e-05 L
.02683 4e-05 L
.02685 4e-05 L
.02687 4e-05 L
.02689 4e-05 L
.02692 4e-05 L
.02694 4e-05 L
.02697 4e-05 L
.027 4e-05 L
.02702 4e-05 L
.02705 4e-05 L
.02707 4e-05 L
.0271 4e-05 L
.02713 4e-05 L
.02713 .99996 L
.02606 .99996 L
.0249 .99996 L
.0238 .99996 L
.02266 .99996 L
.02148 .99996 L
.02036 .99996 L
.01921 .99996 L
.01812 .99996 L
.01699 .99996 L
.01582 .99996 L
.01472 .99996 L
.01357 .99996 L
.01249 .99996 L
.01138 .99996 L
.01021 .99996 L
.00912 .99996 L
.00798 .99996 L
.00681 .99996 L
.0057 .99996 L
.00454 .99996 L
.00346 .99996 L
.00234 .99996 L
.00114 .99996 L
4e-05 .99996 L
F
0 g
4e-05 4e-05 m
7e-05 4e-05 L
.0001 4e-05 L
.00014 4e-05 L
.00017 4e-05 L
.0002 4e-05 L
.00023 4e-05 L
.00026 4e-05 L
.00029 4e-05 L
.00033 4e-05 L
.00036 4e-05 L
.0004 4e-05 L
.00043 4e-05 L
.00046 4e-05 L
.00048 4e-05 L
.0005 4e-05 L
.00054 4e-05 L
.00057 4e-05 L
.00059 4e-05 L
.00061 4e-05 L
.00065 4e-05 L
.00067 4e-05 L
.00069 4e-05 L
.00071 4e-05 L
.00073 4e-05 L
.00074 4e-05 L
.00076 4e-05 L
.0008 4e-05 L
.00084 4e-05 L
.00087 4e-05 L
.0009 4e-05 L
.00093 4e-05 L
.00096 4e-05 L
.001 4e-05 L
.00104 4e-05 L
.00107 4e-05 L
.0011 4e-05 L
.00114 4e-05 L
.00116 4e-05 L
.00118 4e-05 L
.0012 4e-05 L
.00122 4e-05 L
.00126 4e-05 L
.00128 4e-05 L
.0013 4e-05 L
.00133 4e-05 L
.00136 4e-05 L
.00138 4e-05 L
.0014 4e-05 L
.00144 4e-05 L
Mistroke
.00146 4e-05 L
.00148 4e-05 L
.0015 4e-05 L
.00152 4e-05 L
.00154 4e-05 L
.00156 4e-05 L
.00158 4e-05 L
.0016 4e-05 L
.00162 4e-05 L
.00164 4e-05 L
.00166 4e-05 L
.00168 4e-05 L
.00172 4e-05 L
.00174 4e-05 L
.00176 4e-05 L
.00179 4e-05 L
.00183 4e-05 L
.00186 4e-05 L
.00189 4e-05 L
.00193 4e-05 L
.00196 4e-05 L
.00198 4e-05 L
.002 4e-05 L
.00204 4e-05 L
.00206 4e-05 L
.00208 4e-05 L
.0021 4e-05 L
.00212 4e-05 L
.00216 4e-05 L
.00218 4e-05 L
.0022 4e-05 L
.00223 4e-05 L
.00226 4e-05 L
.0023 4e-05 L
.00234 4e-05 L
.00237 4e-05 L
.0024 4e-05 L
.00244 4e-05 L
.00247 4e-05 L
.0025 4e-05 L
.00254 4e-05 L
.00256 4e-05 L
.00258 4e-05 L
.00261 4e-05 L
.00263 4e-05 L
.00265 4e-05 L
.00267 4e-05 L
.00269 4e-05 L
.00272 4e-05 L
.00274 4e-05 L
Mistroke
.00276 4e-05 L
.0028 4e-05 L
.00283 4e-05 L
.00287 4e-05 L
.0029 4e-05 L
.00294 4e-05 L
.00296 4e-05 L
.003 4e-05 L
.00303 4e-05 L
.00306 4e-05 L
.00309 4e-05 L
.00312 4e-05 L
.00315 4e-05 L
.00319 4e-05 L
.00322 4e-05 L
.00325 4e-05 L
.00328 4e-05 L
.00332 4e-05 L
.00334 4e-05 L
.00336 4e-05 L
.00339 4e-05 L
.00343 4e-05 L
.00346 4e-05 L
.00349 4e-05 L
.00353 4e-05 L
.00357 4e-05 L
.0036 4e-05 L
.00363 4e-05 L
.00366 4e-05 L
.00369 4e-05 L
.00373 4e-05 L
.00376 4e-05 L
.0038 4e-05 L
.00383 4e-05 L
.00387 4e-05 L
.00389 4e-05 L
.00391 4e-05 L
.00394 4e-05 L
.00398 4e-05 L
.00401 4e-05 L
.00404 4e-05 L
.00408 4e-05 L
.00411 4e-05 L
.00414 4e-05 L
.00417 4e-05 L
.0042 4e-05 L
.00423 4e-05 L
.00426 4e-05 L
.0043 4e-05 L
.00433 4e-05 L
Mistroke
.00436 4e-05 L
.00439 4e-05 L
.00441 4e-05 L
.00443 4e-05 L
.00446 4e-05 L
.0045 4e-05 L
.00453 4e-05 L
.00457 4e-05 L
.00461 4e-05 L
.00464 4e-05 L
.00467 4e-05 L
.0047 4e-05 L
.00474 4e-05 L
.00477 4e-05 L
.0048 4e-05 L
.00484 4e-05 L
.00487 4e-05 L
.00491 4e-05 L
.00494 4e-05 L
.00496 4e-05 L
.00498 4e-05 L
.00502 4e-05 L
.00506 4e-05 L
.00509 4e-05 L
.00512 4e-05 L
.00515 4e-05 L
.00518 4e-05 L
.00521 4e-05 L
.00524 4e-05 L
.00527 4e-05 L
.0053 4e-05 L
.00534 4e-05 L
.00537 4e-05 L
.0054 4e-05 L
.00543 4e-05 L
.00547 4e-05 L
.00549 4e-05 L
.00551 4e-05 L
.00554 4e-05 L
.00558 4e-05 L
.00561 4e-05 L
.00565 4e-05 L
.00568 4e-05 L
.00572 4e-05 L
.00575 4e-05 L
.00578 4e-05 L
.00581 4e-05 L
.00584 4e-05 L
.00588 4e-05 L
.00592 4e-05 L
Mistroke
.00595 4e-05 L
.00598 4e-05 L
.00602 4e-05 L
.00604 4e-05 L
.00606 4e-05 L
.0061 4e-05 L
.00613 4e-05 L
.00616 4e-05 L
.0062 4e-05 L
.00623 4e-05 L
.00626 4e-05 L
.00629 4e-05 L
.00632 4e-05 L
.00635 4e-05 L
.00638 4e-05 L
.00641 4e-05 L
.00645 4e-05 L
.00648 4e-05 L
.00651 4e-05 L
.00655 4e-05 L
.00657 4e-05 L
.00658 4e-05 L
.00662 4e-05 L
.00665 4e-05 L
.00669 4e-05 L
.00673 4e-05 L
.00676 4e-05 L
.00679 4e-05 L
.00682 4e-05 L
.00686 4e-05 L
.00689 4e-05 L
.00692 4e-05 L
.00696 4e-05 L
.00699 4e-05 L
.00703 4e-05 L
.00706 4e-05 L
.0071 4e-05 L
.00712 4e-05 L
.00714 4e-05 L
.00718 4e-05 L
.00721 4e-05 L
.00724 4e-05 L
.00727 4e-05 L
.00731 4e-05 L
.00734 4e-05 L
.00737 4e-05 L
.0074 4e-05 L
.00743 4e-05 L
.00746 4e-05 L
.00749 4e-05 L
Mistroke
.00753 4e-05 L
.00756 4e-05 L
.00759 4e-05 L
.00763 4e-05 L
.00765 4e-05 L
.00766 4e-05 L
.0077 4e-05 L
.00773 4e-05 L
.00777 4e-05 L
.00779 4e-05 L
.0078 4e-05 L
.00784 4e-05 L
.00787 4e-05 L
.0079 4e-05 L
.00793 4e-05 L
.00797 4e-05 L
.008 4e-05 L
.00804 4e-05 L
.00806 4e-05 L
.00808 4e-05 L
.00811 4e-05 L
.00813 4e-05 L
.00815 4e-05 L
.00819 4e-05 L
.00822 4e-05 L
.00826 4e-05 L
.00829 4e-05 L
.00832 4e-05 L
.00835 4e-05 L
.00838 4e-05 L
.00841 4e-05 L
.00844 4e-05 L
.00848 4e-05 L
.00851 4e-05 L
.00854 4e-05 L
.00858 4e-05 L
.00861 4e-05 L
.00864 4e-05 L
.00867 4e-05 L
.00871 4e-05 L
.00875 4e-05 L
.00878 4e-05 L
.00881 4e-05 L
.00885 4e-05 L
.00888 4e-05 L
.0089 4e-05 L
.00892 4e-05 L
.00894 4e-05 L
.00896 4e-05 L
.009 4e-05 L
Mistroke
.00903 4e-05 L
.00907 4e-05 L
.0091 4e-05 L
.00913 4e-05 L
.00917 4e-05 L
.0092 4e-05 L
.00923 4e-05 L
.00926 4e-05 L
.0093 4e-05 L
.00934 4e-05 L
.00937 4e-05 L
.0094 4e-05 L
.00944 4e-05 L
.00947 4e-05 L
.00951 4e-05 L
.00954 4e-05 L
.00956 4e-05 L
.00958 4e-05 L
.00962 4e-05 L
.00964 4e-05 L
.00966 4e-05 L
.00968 4e-05 L
.0097 4e-05 L
.00973 4e-05 L
.00975 4e-05 L
.00977 4e-05 L
.00979 4e-05 L
.00982 4e-05 L
.00983 4e-05 L
.00986 4e-05 L
.00987 4e-05 L
.00989 4e-05 L
.00993 4e-05 L
.00996 4e-05 L
.01 4e-05 L
.01004 4e-05 L
.01007 4e-05 L
.0101 4e-05 L
.01014 4e-05 L
.01017 4e-05 L
.0102 4e-05 L
.01023 4e-05 L
.01027 4e-05 L
.0103 4e-05 L
.01034 4e-05 L
.01037 4e-05 L
.01041 4e-05 L
.01043 4e-05 L
.01045 4e-05 L
.01048 4e-05 L
Mistroke
.01052 4e-05 L
.01055 4e-05 L
.01058 4e-05 L
.01062 4e-05 L
.01065 4e-05 L
.01068 4e-05 L
.01071 4e-05 L
.01074 4e-05 L
.01077 4e-05 L
.0108 4e-05 L
.01084 4e-05 L
.01087 4e-05 L
.0109 4e-05 L
.01093 4e-05 L
.01095 4e-05 L
.01097 4e-05 L
.01101 4e-05 L
.01104 4e-05 L
.01107 4e-05 L
.01111 4e-05 L
.01115 4e-05 L
.01118 4e-05 L
.01121 4e-05 L
.01124 4e-05 L
.01128 4e-05 L
.01131 4e-05 L
.01134 4e-05 L
.01138 4e-05 L
.01141 4e-05 L
.01145 4e-05 L
.01149 4e-05 L
.01151 4e-05 L
.01153 4e-05 L
.01156 4e-05 L
.0116 4e-05 L
.01163 4e-05 L
.01166 4e-05 L
.0117 4e-05 L
.01173 4e-05 L
.01176 4e-05 L
.01179 4e-05 L
.01182 4e-05 L
.01185 4e-05 L
.01188 4e-05 L
.01191 4e-05 L
.01195 4e-05 L
.01198 4e-05 L
.01201 4e-05 L
.01203 4e-05 L
.01205 4e-05 L
Mistroke
.01208 4e-05 L
.01212 4e-05 L
.01215 4e-05 L
.01217 4e-05 L
.01219 4e-05 L
.01222 4e-05 L
.01226 4e-05 L
.01229 4e-05 L
.01232 4e-05 L
.01235 4e-05 L
.01239 4e-05 L
.01242 4e-05 L
.01244 4e-05 L
.01246 4e-05 L
.0125 4e-05 L
.01252 4e-05 L
.01254 4e-05 L
.01257 4e-05 L
.01261 4e-05 L
.01265 4e-05 L
.01268 4e-05 L
.01271 4e-05 L
.01274 4e-05 L
.01277 4e-05 L
.0128 4e-05 L
.01283 4e-05 L
.01287 4e-05 L
.0129 4e-05 L
.01293 4e-05 L
.01297 4e-05 L
.013 4e-05 L
.01303 4e-05 L
.01306 4e-05 L
.0131 4e-05 L
.01313 4e-05 L
.01316 4e-05 L
.0132 4e-05 L
.01324 4e-05 L
.01327 4e-05 L
.01329 4e-05 L
.01331 4e-05 L
.01333 4e-05 L
.01335 4e-05 L
.01338 4e-05 L
.01342 4e-05 L
.01345 4e-05 L
.01349 4e-05 L
.01352 4e-05 L
.01356 4e-05 L
.01359 4e-05 L
Mistroke
.01362 4e-05 L
.01365 4e-05 L
.01369 4e-05 L
.01372 4e-05 L
.01375 4e-05 L
.01379 4e-05 L
.01383 4e-05 L
.01386 4e-05 L
.01389 4e-05 L
.01393 4e-05 L
.01395 4e-05 L
.01397 4e-05 L
.01401 4e-05 L
.01402 4e-05 L
.01404 4e-05 L
.01406 4e-05 L
.01408 4e-05 L
.01412 4e-05 L
.01414 4e-05 L
.01416 4e-05 L
.01418 4e-05 L
.0142 4e-05 L
.01422 4e-05 L
.01424 4e-05 L
.01426 4e-05 L
.01428 4e-05 L
.01431 4e-05 L
.01435 4e-05 L
.01438 4e-05 L
.01442 4e-05 L
.01446 4e-05 L
.01449 4e-05 L
.01452 4e-05 L
.01455 4e-05 L
.01459 4e-05 L
.01462 4e-05 L
.01465 4e-05 L
.01469 4e-05 L
.01472 4e-05 L
.01476 4e-05 L
.01479 4e-05 L
.01481 4e-05 L
.01483 4e-05 L
.01487 4e-05 L
.01491 4e-05 L
.01494 4e-05 L
.01497 4e-05 L
.015 4e-05 L
.01504 4e-05 L
.01507 4e-05 L
Mistroke
.01509 4e-05 L
.01512 4e-05 L
.01516 4e-05 L
.01519 4e-05 L
.01522 4e-05 L
.01526 4e-05 L
.01528 4e-05 L
.01532 4e-05 L
.01534 4e-05 L
.01536 4e-05 L
.01539 4e-05 L
.01543 4e-05 L
.01546 4e-05 L
.0155 4e-05 L
.01553 4e-05 L
.01557 4e-05 L
.0156 4e-05 L
.01563 4e-05 L
.01566 4e-05 L
.0157 4e-05 L
.01573 4e-05 L
.01577 4e-05 L
.0158 4e-05 L
.01583 4e-05 L
.01587 4e-05 L
.01589 4e-05 L
.01591 4e-05 L
.01595 4e-05 L
.01598 4e-05 L
.01601 4e-05 L
.01605 4e-05 L
.01608 4e-05 L
.01611 4e-05 L
.01614 4e-05 L
.01617 4e-05 L
.0162 4e-05 L
.01623 4e-05 L
.01627 4e-05 L
.0163 4e-05 L
.01633 4e-05 L
.01636 4e-05 L
.0164 4e-05 L
.01642 4e-05 L
.01644 4e-05 L
.01647 4e-05 L
.0165 4e-05 L
.01654 4e-05 L
.01656 4e-05 L
.01658 4e-05 L
.01661 4e-05 L
Mistroke
.01665 4e-05 L
.01668 4e-05 L
.01671 4e-05 L
.01674 4e-05 L
.01677 4e-05 L
.01681 4e-05 L
.01683 4e-05 L
.01685 4e-05 L
.01688 4e-05 L
.01691 4e-05 L
.01692 4e-05 L
.01696 4e-05 L
.017 4e-05 L
.01703 4e-05 L
.01706 4e-05 L
.01709 4e-05 L
.01712 4e-05 L
.01716 4e-05 L
.01718 4e-05 L
.01722 4e-05 L
.01725 4e-05 L
.01728 4e-05 L
.01732 4e-05 L
.01735 4e-05 L
.01738 4e-05 L
.01741 4e-05 L
.01745 4e-05 L
.01748 4e-05 L
.01752 4e-05 L
.01755 4e-05 L
.01758 4e-05 L
.01762 4e-05 L
.01766 4e-05 L
.01767 4e-05 L
.01769 4e-05 L
.01771 4e-05 L
.01773 4e-05 L
.01777 4e-05 L
.0178 4e-05 L
.01784 4e-05 L
.01787 4e-05 L
.01791 4e-05 L
.01794 4e-05 L
.01797 4e-05 L
.018 4e-05 L
.01804 4e-05 L
.01807 4e-05 L
.01811 4e-05 L
.01814 4e-05 L
.01817 4e-05 L
Mistroke
.01821 4e-05 L
.01825 4e-05 L
.01828 4e-05 L
.01831 4e-05 L
.01834 4e-05 L
.01836 4e-05 L
.01839 4e-05 L
.01841 4e-05 L
.01843 4e-05 L
.01845 4e-05 L
.01847 4e-05 L
.0185 4e-05 L
.01852 4e-05 L
.01854 4e-05 L
.01856 4e-05 L
.01859 4e-05 L
.01861 4e-05 L
.01863 4e-05 L
.01865 4e-05 L
.01866 4e-05 L
.0187 4e-05 L
.01873 4e-05 L
.01877 4e-05 L
.01881 4e-05 L
.01884 4e-05 L
.01887 4e-05 L
.01891 4e-05 L
.01894 4e-05 L
.01897 4e-05 L
.019 4e-05 L
.01904 4e-05 L
.01907 4e-05 L
.01911 4e-05 L
.01914 4e-05 L
.01918 4e-05 L
.0192 4e-05 L
.01922 4e-05 L
.01926 4e-05 L
.01929 4e-05 L
.01932 4e-05 L
.01935 4e-05 L
.01939 4e-05 L
.01942 4e-05 L
.01945 4e-05 L
.01948 4e-05 L
.01951 4e-05 L
.01954 4e-05 L
.01957 4e-05 L
.01961 4e-05 L
.01964 4e-05 L
Mistroke
.01967 4e-05 L
.0197 4e-05 L
.01972 4e-05 L
.01974 4e-05 L
.01978 4e-05 L
.01981 4e-05 L
.01985 4e-05 L
.01988 4e-05 L
.01992 4e-05 L
.01995 4e-05 L
.01998 4e-05 L
.02001 4e-05 L
.02005 4e-05 L
.02008 4e-05 L
.02011 4e-05 L
.02015 4e-05 L
.02018 4e-05 L
.02022 4e-05 L
.02026 4e-05 L
.02028 4e-05 L
.0203 4e-05 L
.02033 4e-05 L
.02037 4e-05 L
.0204 4e-05 L
.02043 4e-05 L
.02047 4e-05 L
.0205 4e-05 L
.02053 4e-05 L
.02056 4e-05 L
.02059 4e-05 L
.02062 4e-05 L
.02065 4e-05 L
.02068 4e-05 L
.02072 4e-05 L
.02075 4e-05 L
.02078 4e-05 L
.0208 4e-05 L
.02082 4e-05 L
.02085 4e-05 L
.02089 4e-05 L
.02092 4e-05 L
.02094 4e-05 L
.02096 4e-05 L
.02099 4e-05 L
.02103 4e-05 L
.02106 4e-05 L
.02109 4e-05 L
.02112 4e-05 L
.02116 4e-05 L
.02119 4e-05 L
Mistroke
.02121 4e-05 L
.02123 4e-05 L
.02127 4e-05 L
.02129 4e-05 L
.02131 4e-05 L
.02134 4e-05 L
.02138 4e-05 L
.02141 4e-05 L
.02145 4e-05 L
.02148 4e-05 L
.02151 4e-05 L
.02154 4e-05 L
.02157 4e-05 L
.0216 4e-05 L
.02164 4e-05 L
.02167 4e-05 L
.0217 4e-05 L
.02173 4e-05 L
.02177 4e-05 L
.0218 4e-05 L
.02183 4e-05 L
.02186 4e-05 L
.0219 4e-05 L
.02193 4e-05 L
.02197 4e-05 L
.02201 4e-05 L
.02204 4e-05 L
.02206 4e-05 L
.02208 4e-05 L
.0221 4e-05 L
.02212 4e-05 L
.02215 4e-05 L
.02219 4e-05 L
.02222 4e-05 L
.02226 4e-05 L
.02229 4e-05 L
.02232 4e-05 L
.02236 4e-05 L
.02238 4e-05 L
.02242 4e-05 L
.02246 4e-05 L
.02249 4e-05 L
.02252 4e-05 L
.02256 4e-05 L
.02259 4e-05 L
.02263 4e-05 L
.02266 4e-05 L
.0227 4e-05 L
.02272 4e-05 L
.02274 4e-05 L
Mistroke
.02277 4e-05 L
.02279 4e-05 L
.02281 4e-05 L
.02283 4e-05 L
.02285 4e-05 L
.02289 4e-05 L
.02291 4e-05 L
.02293 4e-05 L
.02295 4e-05 L
.02297 4e-05 L
.02299 4e-05 L
.02301 4e-05 L
.02303 4e-05 L
.02305 4e-05 L
.02308 4e-05 L
.02312 4e-05 L
.02315 4e-05 L
.02319 4e-05 L
.02323 4e-05 L
.02326 4e-05 L
.02329 4e-05 L
.02332 4e-05 L
.02335 4e-05 L
.02339 4e-05 L
.02342 4e-05 L
.02346 4e-05 L
.02349 4e-05 L
.02352 4e-05 L
.02356 4e-05 L
.02358 4e-05 L
.0236 4e-05 L
.02364 4e-05 L
.02367 4e-05 L
.0237 4e-05 L
.02374 4e-05 L
.02377 4e-05 L
.0238 4e-05 L
.02383 4e-05 L
.02386 4e-05 L
.02389 4e-05 L
.02392 4e-05 L
.02396 4e-05 L
.02399 4e-05 L
.02402 4e-05 L
.02405 4e-05 L
.02409 4e-05 L
.02411 4e-05 L
.02413 4e-05 L
.02416 4e-05 L
.02419 4e-05 L
Mistroke
.02423 4e-05 L
.02427 4e-05 L
.0243 4e-05 L
.02433 4e-05 L
.02437 4e-05 L
.0244 4e-05 L
.02443 4e-05 L
.02446 4e-05 L
.0245 4e-05 L
.02453 4e-05 L
.02457 4e-05 L
.0246 4e-05 L
.02464 4e-05 L
.02466 4e-05 L
.02468 4e-05 L
.02472 4e-05 L
.02475 4e-05 L
.02478 4e-05 L
.02481 4e-05 L
.02485 4e-05 L
.02488 4e-05 L
.02491 4e-05 L
.02494 4e-05 L
.02497 4e-05 L
.025 4e-05 L
.02503 4e-05 L
.02507 4e-05 L
.0251 4e-05 L
.02513 4e-05 L
.02516 4e-05 L
.02518 4e-05 L
.0252 4e-05 L
.02524 4e-05 L
.02527 4e-05 L
.02531 4e-05 L
.02533 4e-05 L
.02534 4e-05 L
.02538 4e-05 L
.02541 4e-05 L
.02544 4e-05 L
.02547 4e-05 L
.02551 4e-05 L
.02554 4e-05 L
.02558 4e-05 L
.0256 4e-05 L
.02561 4e-05 L
.02565 4e-05 L
.02567 4e-05 L
.02569 4e-05 L
.02573 4e-05 L
Mistroke
.02576 4e-05 L
.0258 4e-05 L
.02583 4e-05 L
.02586 4e-05 L
.02589 4e-05 L
.02592 4e-05 L
.02595 4e-05 L
.02598 4e-05 L
.02602 4e-05 L
.02605 4e-05 L
.02608 4e-05 L
.02612 4e-05 L
.02615 4e-05 L
.02618 4e-05 L
.02621 4e-05 L
.02625 4e-05 L
.02628 4e-05 L
.02632 4e-05 L
.02635 4e-05 L
.02638 4e-05 L
.0264 4e-05 L
.02642 4e-05 L
.02645 4e-05 L
.02647 4e-05 L
.0265 4e-05 L
.02652 4e-05 L
.02655 4e-05 L
.02657 4e-05 L
.02659 4e-05 L
.02662 4e-05 L
.02664 4e-05 L
.02666 4e-05 L
.02668 4e-05 L
.0267 4e-05 L
.02673 4e-05 L
.02675 4e-05 L
.02677 4e-05 L
.0268 4e-05 L
.02683 4e-05 L
.02685 4e-05 L
.02687 4e-05 L
.02689 4e-05 L
.02692 4e-05 L
.02694 4e-05 L
.02697 4e-05 L
.027 4e-05 L
.02702 4e-05 L
.02705 4e-05 L
.02707 4e-05 L
.0271 4e-05 L
Mistroke
.02713 4e-05 L
Mfstroke
4e-05 .99996 m
.00114 .99996 L
.00234 .99996 L
.00346 .99996 L
.00454 .99996 L
.0057 .99996 L
.00681 .99996 L
.00798 .99996 L
.00912 .99996 L
.01021 .99996 L
.01138 .99996 L
.01249 .99996 L
.01357 .99996 L
.01472 .99996 L
.01582 .99996 L
.01699 .99996 L
.01812 .99996 L
.01921 .99996 L
.02036 .99996 L
.02148 .99996 L
.02266 .99996 L
.0238 .99996 L
.0249 .99996 L
.02606 .99996 L
.02713 .99996 L
s
.80217 .76297 m
.80241 .76497 L
.80268 .76721 L
.80292 .76937 L
.80316 .77151 L
.80341 .77385 L
.80365 .77617 L
.80391 .77872 L
.80416 .78127 L
.8044 .7838 L
.80465 .78661 L
.8049 .78942 L
.80513 .79224 L
.80538 .79539 L
.80563 .79858 L
.80588 .80217 L
.80613 .80585 L
.80637 .80964 L
.80662 .814 L
.80686 .81861 L
.80712 .82409 L
.80737 .83016 L
.80761 .83718 L
.80773 .84145 L
.80787 .84713 L
.80792 .85013 L
.80799 .85401 L
.80802 .8563 L
.80805 .85891 L
.80807 .86198 L
.80808 .86306 L
.80809 .86443 L
.80809 .86596 L
.8081 .86998 L
s
.80217 .99996 m
.80241 .99703 L
.80268 .99378 L
.80292 .99066 L
.80316 .98761 L
.80341 .98429 L
.80365 .98103 L
.80391 .97748 L
.80416 .97398 L
.8044 .97052 L
.80465 .96673 L
.8049 .96297 L
.80513 .95924 L
.80538 .95512 L
.80563 .951 L
.80588 .94641 L
.80613 .94178 L
.80637 .93707 L
.80662 .93172 L
.80686 .92618 L
.80712 .9197 L
.80737 .91266 L
.80761 .90471 L
.80773 .89997 L
.80787 .89378 L
.80792 .89055 L
.80799 .88643 L
.80802 .88402 L
.80805 .8813 L
.80807 .87813 L
.80808 .87703 L
.80809 .87563 L
.80809 .87407 L
.8081 .87003 L
s
1 1 .5 r
.80217 .76297 m
.80241 .76497 L
.80268 .76721 L
.80292 .76937 L
.80316 .77151 L
.80341 .77385 L
.80365 .77617 L
.80391 .77872 L
.80416 .78127 L
.8044 .7838 L
.80465 .78661 L
.8049 .78942 L
.80513 .79224 L
.80538 .79539 L
.80563 .79858 L
.80588 .80217 L
.80613 .80585 L
.80637 .80964 L
.80662 .814 L
.80686 .81861 L
.80712 .82409 L
.80737 .83016 L
.80761 .83718 L
.80773 .84145 L
.80787 .84713 L
.80792 .85013 L
.80799 .85401 L
.80802 .8563 L
.80805 .85891 L
.80807 .86198 L
.80808 .86306 L
.80809 .86443 L
.80809 .86596 L
.8081 .86998 L
.8081 .87003 L
.80809 .87407 L
.80809 .87563 L
.80808 .87703 L
.80807 .87813 L
.80805 .8813 L
.80802 .88402 L
.80799 .88643 L
.80792 .89055 L
.80787 .89378 L
.80773 .89997 L
.80761 .90471 L
.80737 .91266 L
.80712 .9197 L
.80686 .92618 L
.80662 .93172 L
.80637 .93707 L
.80613 .94178 L
.80588 .94641 L
.80563 .951 L
.80538 .95512 L
.80513 .95924 L
.8049 .96297 L
.80465 .96673 L
.8044 .97052 L
.80416 .97398 L
.80391 .97748 L
.80365 .98103 L
.80341 .98429 L
.80316 .98761 L
.80292 .99066 L
.80268 .99378 L
.80241 .99703 L
.80217 .99996 L
F
0 g
.80217 .76297 m
.80241 .76497 L
.80268 .76721 L
.80292 .76937 L
.80316 .77151 L
.80341 .77385 L
.80365 .77617 L
.80391 .77872 L
.80416 .78127 L
.8044 .7838 L
.80465 .78661 L
.8049 .78942 L
.80513 .79224 L
.80538 .79539 L
.80563 .79858 L
.80588 .80217 L
.80613 .80585 L
.80637 .80964 L
.80662 .814 L
.80686 .81861 L
.80712 .82409 L
.80737 .83016 L
.80761 .83718 L
.80773 .84145 L
.80787 .84713 L
.80792 .85013 L
.80799 .85401 L
.80802 .8563 L
.80805 .85891 L
.80807 .86198 L
.80808 .86306 L
.80809 .86443 L
.80809 .86596 L
.8081 .86998 L
s
.80217 .99996 m
.80241 .99703 L
.80268 .99378 L
.80292 .99066 L
.80316 .98761 L
.80341 .98429 L
.80365 .98103 L
.80391 .97748 L
.80416 .97398 L
.8044 .97052 L
.80465 .96673 L
.8049 .96297 L
.80513 .95924 L
.80538 .95512 L
.80563 .951 L
.80588 .94641 L
.80613 .94178 L
.80637 .93707 L
.80662 .93172 L
.80686 .92618 L
.80712 .9197 L
.80737 .91266 L
.80761 .90471 L
.80773 .89997 L
.80787 .89378 L
.80792 .89055 L
.80799 .88643 L
.80802 .88402 L
.80805 .8813 L
.80807 .87813 L
.80808 .87703 L
.80809 .87563 L
.80809 .87407 L
.8081 .87003 L
s
.02713 4e-05 m
.05857 .01972 L
.09286 .04131 L
.12506 .06171 L
.15603 .08148 L
.189 .10268 L
.22073 .12328 L
.25446 .1454 L
.28695 .16696 L
.31821 .18797 L
.35147 .21066 L
.3835 .2329 L
.41429 .25471 L
.44707 .27847 L
.47862 .30199 L
.51217 .32785 L
.54449 .35381 L
.57557 .38002 L
.60865 .40968 L
.64049 .44057 L
.67433 .47702 L
.70694 .51757 L
.73831 .56516 L
.75422 .59481 L
.77168 .63501 L
.77929 .65663 L
.78745 .68446 L
.7914 .70058 L
.79515 .71827 L
.80217 .76297 L
s
.02713 .99996 m
.05857 .99996 L
.09286 .99996 L
.12506 .99996 L
.15603 .99996 L
.189 .99996 L
.22073 .99996 L
.25446 .99996 L
.28695 .99996 L
.31821 .99996 L
.35147 .99996 L
.3835 .99996 L
.41429 .99996 L
.44707 .99996 L
.47862 .99996 L
.51217 .99996 L
.54449 .99996 L
.57557 .99996 L
.60865 .99996 L
.64049 .99996 L
.67433 .99996 L
.70694 .99996 L
.73831 .99996 L
.77168 .99996 L
.80217 .99996 L
s
1 1 .5 r
.02713 4e-05 m
.05857 .01972 L
.09286 .04131 L
.12506 .06171 L
.15603 .08148 L
.189 .10268 L
.22073 .12328 L
.25446 .1454 L
.28695 .16696 L
.31821 .18797 L
.35147 .21066 L
.3835 .2329 L
.41429 .25471 L
.44707 .27847 L
.47862 .30199 L
.51217 .32785 L
.54449 .35381 L
.57557 .38002 L
.60865 .40968 L
.64049 .44057 L
.67433 .47702 L
.70694 .51757 L
.73831 .56516 L
.75422 .59481 L
.77168 .63501 L
.77929 .65663 L
.78745 .68446 L
.7914 .70058 L
.79515 .71827 L
.80217 .76297 L
.80217 .99996 L
.77168 .99996 L
.73831 .99996 L
.70694 .99996 L
.67433 .99996 L
.64049 .99996 L
.60865 .99996 L
.57557 .99996 L
.54449 .99996 L
.51217 .99996 L
.47862 .99996 L
.44707 .99996 L
.41429 .99996 L
.3835 .99996 L
.35147 .99996 L
.31821 .99996 L
.28695 .99996 L
.25446 .99996 L
.22073 .99996 L
.189 .99996 L
.15603 .99996 L
.12506 .99996 L
.09286 .99996 L
.05857 .99996 L
.02713 .99996 L
F
0 g
.02713 4e-05 m
.05857 .01972 L
.09286 .04131 L
.12506 .06171 L
.15603 .08148 L
.189 .10268 L
.22073 .12328 L
.25446 .1454 L
.28695 .16696 L
.31821 .18797 L
.35147 .21066 L
.3835 .2329 L
.41429 .25471 L
.44707 .27847 L
.47862 .30199 L
.51217 .32785 L
.54449 .35381 L
.57557 .38002 L
.60865 .40968 L
.64049 .44057 L
.67433 .47702 L
.70694 .51757 L
.73831 .56516 L
.75422 .59481 L
.77168 .63501 L
.77929 .65663 L
.78745 .68446 L
.7914 .70058 L
.79515 .71827 L
.80217 .76297 L
s
.02713 .99996 m
.05857 .99996 L
.09286 .99996 L
.12506 .99996 L
.15603 .99996 L
.189 .99996 L
.22073 .99996 L
.25446 .99996 L
.28695 .99996 L
.31821 .99996 L
.35147 .99996 L
.3835 .99996 L
.41429 .99996 L
.44707 .99996 L
.47862 .99996 L
.51217 .99996 L
.54449 .99996 L
.57557 .99996 L
.60865 .99996 L
.64049 .99996 L
.67433 .99996 L
.70694 .99996 L
.73831 .99996 L
.77168 .99996 L
.80217 .99996 L
s
1 .5 0 r
.01 w
.15689 .04709 Mdot
.30198 .09415 Mdot
.6392 .29806 Mdot
.58823 .22747 Mdot
.69018 .36472 Mdot
.3059 .10591 Mdot
.75292 .27845 Mdot
.66665 .31766 Mdot
.29413 .10591 Mdot
.54509 .17257 Mdot
.44706 .03141 Mdot
.61568 .31374 Mdot
.63528 .32158 Mdot
.81174 .05494 Mdot
.63136 .24316 Mdot
.58039 .19218 Mdot
.41569 .01572 Mdot
.84703 .05886 Mdot
.49804 .07062 Mdot
.57254 .20002 Mdot
.43922 .00396 Mdot
.79606 .07062 Mdot
.57254 .02749 Mdot
.6196 .32943 Mdot
.40393 4e-05 Mdot
.62744 .04709 Mdot
.52549 .02357 Mdot
.85487 .79998 Mdot
.59215 .28237 Mdot
.61176 .02357 Mdot
.87056 .13728 Mdot
.49804 .01572 Mdot
.58431 .25884 Mdot
.54117 .02357 Mdot
.64705 .04317 Mdot
.6941 .03533 Mdot
.81174 .79213 Mdot
.57254 .27061 Mdot
.59607 .02357 Mdot
.65881 .03925 Mdot
.61568 .03141 Mdot
.6745 .6196 Mdot
.39217 .02749 Mdot
.6392 .03533 Mdot
.68234 .05494 Mdot
.55686 .04317 Mdot
.76076 .72155 Mdot
.40001 .02357 Mdot
.60783 .01965 Mdot
.67057 .05102 Mdot
.24316 .03533 Mdot
.84311 .8039 Mdot
.38824 .08631 Mdot
.61176 .02357 Mdot
.6941 .05102 Mdot
.55686 .46275 Mdot
.83527 .71371 Mdot
.12944 .04709 Mdot
.55294 .02357 Mdot
.68626 .03533 Mdot
.81566 .6941 Mdot
.58431 .01965 Mdot
.79606 .8235 Mdot
.43922 .02357 Mdot
.65489 .03533 Mdot
.48628 .09415 Mdot
.91369 .84703 Mdot
.87448 .8235 Mdot
.51765 .06278 Mdot
.54902 .01572 Mdot
.68626 .05102 Mdot
.92546 .89801 Mdot
.47843 .06278 Mdot
.83135 .84703 Mdot
.30982 4e-05 Mdot
.59215 .02357 Mdot
.63528 .05102 Mdot
.90193 .90585 Mdot
.49412 .07846 Mdot
.80782 .82743 Mdot
.43922 .0118 Mdot
.63528 .02357 Mdot
.83135 .70194 Mdot
.90193 .90585 Mdot
.89409 .83527 Mdot
.65881 .59215 Mdot
.45491 .0118 Mdot
.62744 .03141 Mdot
.90977 .8784 Mdot
.88232 .88232 Mdot
.72155 .65097 Mdot
.66273 .51765 Mdot
.56078 .01965 Mdot
.62744 .03533 Mdot
.88624 .8784 Mdot
.89017 .88624 Mdot
.76076 .62352 Mdot
.57646 .48628 Mdot
.73724 .05102 Mdot
.61176 .02749 Mdot
.89801 .89409 Mdot
.88232 .88232 Mdot
.41569 .10199 Mdot
.75292 .72547 Mdot
.74508 .03533 Mdot
.62744 .02749 Mdot
.88624 .8784 Mdot
.87448 .88624 Mdot
.52549 .03141 Mdot
.81566 .83135 Mdot
.70194 .03925 Mdot
.63136 .02749 Mdot
.87056 .86664 Mdot
.89801 .88232 Mdot
.48628 .04317 Mdot
.79998 .82743 Mdot
.60391 .00788 Mdot
.53333 .0118 Mdot
.8235 .67057 Mdot
.89017 .81958 Mdot
.87448 .84703 Mdot
.79998 .77253 Mdot
.5098 .0118 Mdot
.79213 .04709 Mdot
.56078 .0667 Mdot
.88624 .86272 Mdot
.87056 .86664 Mdot
.78821 .71371 Mdot
.34511 .08239 Mdot
.72547 .03141 Mdot
.63528 .03925 Mdot
.88232 .8784 Mdot
.61568 .0667 Mdot
.56862 .0667 Mdot
.81566 .84311 Mdot
.67842 .03533 Mdot
.8039 .04317 Mdot
.8588 .83135 Mdot
.62352 .07846 Mdot
.84703 .85487 Mdot
.81958 .79606 Mdot
.53333 4e-05 Mdot
.76076 .03533 Mdot
.59607 .03141 Mdot
.88624 .78429 Mdot
.61568 .04317 Mdot
.49412 .03141 Mdot
.75292 .78429 Mdot
.65097 .02357 Mdot
.81174 .03925 Mdot
.84703 .83527 Mdot
.65097 .05886 Mdot
.84703 .84703 Mdot
.71763 .67057 Mdot
.55294 .00788 Mdot
.73332 .04317 Mdot
.58039 .02357 Mdot
.6196 .18826 Mdot
.61568 .03141 Mdot
.51372 .03925 Mdot
.79998 .83135 Mdot
.64705 .03141 Mdot
.79998 .03925 Mdot
.87056 .84703 Mdot
.65881 .05886 Mdot
.87056 .8039 Mdot
.76076 .6941 Mdot
.35687 .18826 Mdot
.72155 .03925 Mdot
.83919 .05886 Mdot
.64705 .09023 Mdot
.65489 .04317 Mdot
.64705 .14513 Mdot
.79998 .82743 Mdot
.58039 .01572 Mdot
.77645 .04317 Mdot
.84311 .83919 Mdot
.65489 .0667 Mdot
.55294 .00788 Mdot
.66665 .3255 Mdot
.54117 .47059 Mdot
.63528 .02357 Mdot
.81958 .04317 Mdot
.64705 .41961 Mdot
.16081 .02357 Mdot
.85487 .84311 Mdot
.64705 .60783 Mdot
.43922 .13336 Mdot
.74508 .04317 Mdot
.83527 .70979 Mdot
.66273 .05886 Mdot
.61568 .03141 Mdot
.65097 .13336 Mdot
.73332 .76469 Mdot
.56862 .0118 Mdot
.78821 .03925 Mdot
.86272 .85487 Mdot
.72155 .60783 Mdot
.53333 .00396 Mdot
.4353 .18434 Mdot
.36864 .27453 Mdot
.63136 .02749 Mdot
.82743 .05102 Mdot
.66273 .05886 Mdot
.89409 .79998 Mdot
.76076 .58431 Mdot
.66273 .64313 Mdot
.62744 .63528 Mdot
.73332 .03533 Mdot
.89017 .88624 Mdot
.23531 .03925 Mdot
.61176 .04317 Mdot
.68234 .05494 Mdot
.73724 .78037 Mdot
.55686 .02357 Mdot
.78037 .03533 Mdot
.83919 .62352 Mdot
.89017 .87448 Mdot
.54902 .01572 Mdot
.54509 .21179 Mdot
.47059 .44314 Mdot
.60391 .02749 Mdot
.81174 .05494 Mdot
.62744 .05494 Mdot
.8784 .88232 Mdot
.83527 .75684 Mdot
.6941 .64313 Mdot
.45883 .50196 Mdot
.71371 .04317 Mdot
.88624 .89409 Mdot
.88232 .81566 Mdot
.51765 .1961 Mdot
.75292 .04709 Mdot
.77253 .81958 Mdot
.20394 .00396 Mdot
.78037 .03925 Mdot
.749 .09415 Mdot
.87056 .86664 Mdot
.60391 .02749 Mdot
.51372 .02749 Mdot
.56078 .61568 Mdot
.56078 .02749 Mdot
.78429 .05886 Mdot
.62352 .09415 Mdot
.87056 .87056 Mdot
.86272 .83135 Mdot
.8039 .6745 Mdot
.76469 .72547 Mdot
.6392 .06278 Mdot
.8784 .89017 Mdot
.8784 .86272 Mdot
.68626 .48628 Mdot
.72547 .04709 Mdot
.8039 .84311 Mdot
.16865 .01965 Mdot
.76076 .04709 Mdot
.81958 .05886 Mdot
.89409 .8784 Mdot
.6392 .02357 Mdot
.6745 .05102 Mdot
.52549 .58039 Mdot
.47843 .0118 Mdot
.73724 .06278 Mdot
.44706 .20787 Mdot
.85487 .77645 Mdot
.83527 .8039 Mdot
.58039 .21963 Mdot
.50588 .27061 Mdot
.64313 .05494 Mdot
.8588 .86664 Mdot
.86664 .86272 Mdot
.51765 .21963 Mdot
.54117 .00396 Mdot
.79606 .83527 Mdot
.14513 .01572 Mdot
.63136 .07062 Mdot
.77253 .04709 Mdot
.56078 .18434 Mdot
.62744 .02357 Mdot
.70587 .02749 Mdot
.79606 .86664 Mdot
.03533 4e-05 Mdot
.76469 .03533 Mdot
.4353 .14513 Mdot
.34903 .03925 Mdot
.75684 .47451 Mdot
.50588 .05102 Mdot
.21571 .22355 Mdot
.44314 .0118 Mdot
.86272 .89017 Mdot
.85095 .85095 Mdot
.8039 .68626 Mdot
.53725 .03533 Mdot
.81174 .61176 Mdot
.32158 .35687 Mdot
.6392 .04709 Mdot
.749 .04317 Mdot
.59215 .08631 Mdot
.6392 .05102 Mdot
.52549 .0118 Mdot
.79998 .83527 Mdot
.05102 .00788 Mdot
.749 .04709 Mdot
.75292 .0667 Mdot
.29806 .03925 Mdot
.58431 .02357 Mdot
.69018 .02749 Mdot
.6941 .76861 Mdot
.16081 .00396 Mdot
.69018 .49412 Mdot
.84311 .83919 Mdot
.88232 .8235 Mdot
.83527 .79213 Mdot
.52157 .01572 Mdot
.43922 .24708 Mdot
.41177 .02357 Mdot
.61568 .20002 Mdot
.8784 .83919 Mdot
.65097 .05494 Mdot
.53725 .01965 Mdot
.73332 .61568 Mdot
.24316 .31374 Mdot
.68234 .04317 Mdot
.46275 .04317 Mdot
.28237 .11376 Mdot
.63528 .03533 Mdot
.52549 .0118 Mdot
.73724 .8039 Mdot
.00396 4e-05 Mdot
.76469 .04709 Mdot
.8588 .82743 Mdot
.86664 .85095 Mdot
.76861 .44314 Mdot
.68234 .03533 Mdot
.49804 .59999 Mdot
.21179 4e-05 Mdot
.87056 .89017 Mdot
.76469 .11376 Mdot
.18826 .03141 Mdot
.51372 .03141 Mdot
.47843 .04317 Mdot
.30198 .1412 Mdot
.43138 .01965 Mdot
.68234 .55686 Mdot
.88624 .84703 Mdot
.55294 .07846 Mdot
.51765 .0118 Mdot
.64705 .60391 Mdot
.03925 .00396 Mdot
.69018 .03925 Mdot
.66665 .31374 Mdot
.70979 .72155 Mdot
.63136 .02749 Mdot
.51372 .0118 Mdot
.78821 .85487 Mdot
.08239 .00396 Mdot
.88232 .65097 Mdot
.32943 .24708 Mdot
.86272 .77645 Mdot
.83527 .81174 Mdot
.67057 .02357 Mdot
.48628 .54509 Mdot
.23139 .00396 Mdot
.36472 .08239 Mdot
.8039 .71763 Mdot
.87056 .85095 Mdot
.56078 .02357 Mdot
.53725 .03925 Mdot
.31766 .37648 Mdot
.43138 .03141 Mdot
.86272 .83919 Mdot
.84703 .79213 Mdot
.51765 .06278 Mdot
.53725 .03141 Mdot
.65489 .65881 Mdot
.00396 .00396 Mdot
.75292 .04317 Mdot
.89409 .78429 Mdot
.86664 .86272 Mdot
.74508 .36864 Mdot
.50196 .01965 Mdot
.72939 .82743 Mdot
.15297 .00396 Mdot
.79213 .80782 Mdot
.88624 .85095 Mdot
.86664 .8588 Mdot
.44314 .06278 Mdot
.6745 .02357 Mdot
.63528 .56078 Mdot
.24708 4e-05 Mdot
.83135 .81566 Mdot
.81566 .72155 Mdot
.85095 .85487 Mdot
.56078 .01965 Mdot
.59215 .07454 Mdot
.08239 .11768 Mdot
.50588 .03141 Mdot
.75292 .04317 Mdot
.90193 .90977 Mdot
.60391 .05494 Mdot
.51372 .00788 Mdot
.65489 .70587 Mdot
4e-05 4e-05 Mdot
.76076 .03925 Mdot
.76861 .07454 Mdot
.86272 .8588 Mdot
.83135 .82743 Mdot
.51372 .01965 Mdot
.72155 .8235 Mdot
.1765 .00396 Mdot
.65881 .18042 Mdot
.3255 .05102 Mdot
.86272 .78821 Mdot
.58039 .02749 Mdot
.6745 .03925 Mdot
.26276 .05886 Mdot
.41177 .02749 Mdot
.76469 .04709 Mdot
.89017 .89017 Mdot
.85095 .83135 Mdot
.53333 .01965 Mdot
.50196 .04709 Mdot
.00396 4e-05 Mdot
.54117 .01965 Mdot
.75684 .05494 Mdot
.94898 .79213 Mdot
.58039 .14513 Mdot
.52549 .01572 Mdot
.72939 .81566 Mdot
.09807 .00396 Mdot
.78429 .03533 Mdot
.56862 .0667 Mdot
.75292 .08239 Mdot
.84703 .81174 Mdot
.52549 .01572 Mdot
.4353 .52549 Mdot
.34119 .01572 Mdot
.72155 .03141 Mdot
.84703 .85487 Mdot
.84703 .81958 Mdot
.5647 .01965 Mdot
.6941 .04709 Mdot
.34903 .36472 Mdot
.59215 .03925 Mdot
.749 .04709 Mdot
.8039 .40001 Mdot
.59215 .05886 Mdot
.52157 .0118 Mdot
.65489 .51765 Mdot
.02749 .00396 Mdot
.57254 .01965 Mdot
.73724 .04317 Mdot
.8235 .07062 Mdot
.84703 .8039 Mdot
.51765 .02357 Mdot
.76861 .8588 Mdot
.28237 .01965 Mdot
.75684 .03533 Mdot
.85487 .85487 Mdot
.39217 .22355 Mdot
.45491 .35687 Mdot
.56078 .02357 Mdot
.42746 .39609 Mdot
.1961 .0118 Mdot
.76469 .04317 Mdot
.71763 .23531 Mdot
.4353 .18826 Mdot
.53333 .0118 Mdot
.70194 .05102 Mdot
.05886 .08631 Mdot
.45098 .04709 Mdot
.74116 .04709 Mdot
.81958 .05494 Mdot
.59607 .05494 Mdot
.49804 .00788 Mdot
.56862 .40393 Mdot
.16865 .00396 Mdot
.61568 .01572 Mdot
.8588 .8039 Mdot
.24708 .04709 Mdot
.80782 .8235 Mdot
.50588 .01572 Mdot
.68626 .78037 Mdot
.31374 .01965 Mdot
.76469 .04709 Mdot
.32943 .35687 Mdot
.77253 .75684 Mdot
.23531 .1961 Mdot
.63136 .04709 Mdot
.23924 .07454 Mdot
.59215 .36864 Mdot
.73724 .05102 Mdot
.72155 .12944 Mdot
.50196 .38824 Mdot
.51765 .0118 Mdot
.69018 .06278 Mdot
.20002 .00396 Mdot
.55686 .01965 Mdot
.70587 .21179 Mdot
.23531 .02357 Mdot
.74508 .47059 Mdot
.49804 .01572 Mdot
.62352 .63528 Mdot
.27453 .02749 Mdot
.62352 .02357 Mdot
.8235 .77253 Mdot
.86272 .8784 Mdot
.8039 .82743 Mdot
.44706 .02357 Mdot
.58431 .67842 Mdot
.27845 .00788 Mdot
.72547 .03925 Mdot
.84311 .85095 Mdot
.83527 .85095 Mdot
.66273 .62352 Mdot
.6745 .05102 Mdot
.63528 .749 Mdot
.50196 .04317 Mdot
.6941 .01965 Mdot
.20394 .06278 Mdot
.64313 .47059 Mdot
.51372 .0118 Mdot
.65097 .15689 Mdot
.22747 .01572 Mdot
.57646 .02749 Mdot
.8588 .81174 Mdot
.84311 .86272 Mdot
.84311 .83527 Mdot
.4902 .01572 Mdot
.61568 .68234 Mdot
.19218 .00788 Mdot
.63528 .02749 Mdot
.83527 .8039 Mdot
.83919 .85487 Mdot
.79998 .83135 Mdot
.40785 .00788 Mdot
.33335 .34511 Mdot
.38432 .0118 Mdot
.65097 .01965 Mdot
.10199 .11768 Mdot
.8235 .85095 Mdot
.47451 .08631 Mdot
.67842 .07454 Mdot
.66273 .749 Mdot
.51372 .01965 Mdot
.71371 .04317 Mdot
.8588 .86664 Mdot
.58039 .07062 Mdot
.49804 .00396 Mdot
.63528 .05494 Mdot
.1412 .00396 Mdot
.55686 .01965 Mdot
.65881 .13336 Mdot
.85095 .85487 Mdot
.82743 .749 Mdot
.47843 .00788 Mdot
.6392 .70979 Mdot
.18826 .00788 Mdot
.57254 .01572 Mdot
.64705 .17257 Mdot
.47059 .24316 Mdot
.81566 .83527 Mdot
.3608 .00396 Mdot
.45098 .53725 Mdot
.3059 .0118 Mdot
.66273 .02357 Mdot
.8039 .76076 Mdot
.83919 .86272 Mdot
.50196 .03533 Mdot
.50588 .04709 Mdot
.44314 .43138 Mdot
.48628 .02357 Mdot
.70194 .03925 Mdot
.83527 .85095 Mdot
.21179 .03141 Mdot
.52157 .00396 Mdot
.69018 .05886 Mdot
.17257 .00788 Mdot
.55686 .02749 Mdot
.70587 .03925 Mdot
.67057 .23139 Mdot
.59999 .05886 Mdot
.51765 .01572 Mdot
.42354 .09023 Mdot
.14905 .00396 Mdot
.56078 .03141 Mdot
.56862 .09023 Mdot
.66273 .61568 Mdot
.80782 .8235 Mdot
.47451 .00788 Mdot
.71763 .8235 Mdot
.20002 .00396 Mdot
.56078 .02749 Mdot
.83135 .84703 Mdot
.84311 .84703 Mdot
.62352 .5098 Mdot
.85095 .70194 Mdot
.18042 .05494 Mdot
.40785 .01572 Mdot
.67842 .05886 Mdot
.83919 .75684 Mdot
.81958 .84703 Mdot
.53725 .0118 Mdot
.57646 .05494 Mdot
.16473 .10983 Mdot
.50196 .03925 Mdot
.70194 .04317 Mdot
.14905 .0667 Mdot
.58431 .07846 Mdot
.50588 .00396 Mdot
.63136 .06278 Mdot
.13336 .00396 Mdot
.54117 .01965 Mdot
.34511 .04709 Mdot
.8588 .87448 Mdot
.55294 .05886 Mdot
.46667 .00396 Mdot
.74116 .8039 Mdot
.15689 4e-05 Mdot
.55686 .02749 Mdot
.84311 .85095 Mdot
.83527 .86272 Mdot
.79606 .81566 Mdot
.45098 .00788 Mdot
.4902 .53333 Mdot
.34511 .02357 Mdot
.6196 .02749 Mdot
.37256 .12944 Mdot
.8235 .84311 Mdot
.5098 .02749 Mdot
.45491 .0118 Mdot
.42746 .40001 Mdot
.47451 .03533 Mdot
.68234 .03141 Mdot
.85095 .83527 Mdot
.54117 .09807 Mdot
.51765 .01572 Mdot
.58823 .04317 Mdot
.13336 4e-05 Mdot
.50588 .03533 Mdot
.73332 .46667 Mdot
.84703 .87056 Mdot
.60783 .06278 Mdot
.4902 .0118 Mdot
.47451 .09415 Mdot
.18434 .00396 Mdot
.52941 .01572 Mdot
.81566 .85487 Mdot
.36472 .39609 Mdot
.52941 .0667 Mdot
.45883 .00788 Mdot
.75684 .87056 Mdot
.3255 .0118 Mdot
.57254 .03141 Mdot
.67057 .64705 Mdot
.83527 .8588 Mdot
.8039 .81174 Mdot
.45098 .0118 Mdot
.34119 .05102 Mdot
.38432 .02357 Mdot
.69018 .04317 Mdot
.84311 .86272 Mdot
.60783 .07062 Mdot
.50588 .0118 Mdot
.59607 .05102 Mdot
.1216 .00396 Mdot
.44314 .00788 Mdot
.58431 .04317 Mdot
.81566 .69802 Mdot
.62352 .05102 Mdot
.50588 .0118 Mdot
.57254 .05102 Mdot
.13728 .00396 Mdot
.53725 .02749 Mdot
.81174 .83919 Mdot
.61568 .58823 Mdot
.59607 .05886 Mdot
.4902 .01965 Mdot
.77645 .8235 Mdot
.26276 .00788 Mdot
.5647 .02749 Mdot
.83135 .84311 Mdot
.749 .51372 Mdot
.56078 .05102 Mdot
.45491 .01965 Mdot
.47451 .42354 Mdot
.32158 .0118 Mdot
.62352 .03533 Mdot
.85095 .85095 Mdot
.71371 .07454 Mdot
.6392 .55686 Mdot
.5098 .02357 Mdot
.21179 .00788 Mdot
.42354 .02357 Mdot
.68626 .03533 Mdot
.70194 .12944 Mdot
.58823 .0667 Mdot
.49412 .01572 Mdot
.55294 .03925 Mdot
.12552 .00788 Mdot
.4902 .00788 Mdot
.75292 .67842 Mdot
.85487 .85487 Mdot
.48235 .08239 Mdot
.47451 .00788 Mdot
.42746 .05494 Mdot
.24316 .01572 Mdot
.55686 .02357 Mdot
.83919 .86272 Mdot
.75292 .10199 Mdot
.53333 .05494 Mdot
.45098 .00396 Mdot
.47451 .56862 Mdot
.27845 .00788 Mdot
.59607 .02749 Mdot
.6745 .15689 Mdot
.15297 .02357 Mdot
.57254 .04317 Mdot
.46275 .02357 Mdot
.21179 4e-05 Mdot
.3608 .01572 Mdot
.6941 .04709 Mdot
.78037 .09023 Mdot
.56862 .57254 Mdot
.52549 .03533 Mdot
.61176 .03925 Mdot
.10591 .00788 Mdot
.4902 .01572 Mdot
.59607 .13728 Mdot
.6745 .28629 Mdot
.78821 .77645 Mdot
.4902 .01572 Mdot
.51765 .02357 Mdot
.21963 .0118 Mdot
.54117 .01965 Mdot
.71371 .59607 Mdot
.08239 .04709 Mdot
.76076 .75292 Mdot
.44706 .00396 Mdot
.56078 .59215 Mdot
.26276 .00396 Mdot
.60391 .04317 Mdot
.65881 .21571 Mdot
.84311 .8588 Mdot
.09415 .05102 Mdot
.45098 .0118 Mdot
.33727 .26668 Mdot
.35687 .01572 Mdot
.66665 .05886 Mdot
.77253 .08631 Mdot
.8235 .85487 Mdot
.52157 .02749 Mdot
.53725 .03141 Mdot
.11768 4e-05 Mdot
.43922 .01965 Mdot
.71371 .0667 Mdot
.16865 .0118 Mdot
.81958 .84703 Mdot
.47059 .00788 Mdot
.53725 .03533 Mdot
.13728 .00396 Mdot
.37256 .00788 Mdot
.18434 .04317 Mdot
.87056 .86664 Mdot
.81174 .83919 Mdot
.46667 .0118 Mdot
.36864 .05102 Mdot
.23924 .00788 Mdot
.57646 .02749 Mdot
.84703 .85487 Mdot
.83919 .87056 Mdot
.79998 .82743 Mdot
.37648 .00396 Mdot
.47059 .49804 Mdot
.30198 .00396 Mdot
.59607 .03925 Mdot
.65097 .11768 Mdot
.83527 .86664 Mdot
.46275 .32943 Mdot
.45491 .0118 Mdot
.23924 .00788 Mdot
.40001 .00788 Mdot
.67842 .05102 Mdot
.80782 .81958 Mdot
.8039 .84311 Mdot
.49412 .01572 Mdot
.56862 .02749 Mdot
.11768 .00788 Mdot
.4902 .01572 Mdot
.749 .54117 Mdot
.87448 .89017 Mdot
.82743 .84311 Mdot
.44314 .0118 Mdot
.51372 .02749 Mdot
.20002 .00396 Mdot
.55294 .02357 Mdot
.85095 .86272 Mdot
.8588 .8784 Mdot
.81566 .84311 Mdot
.45883 .01572 Mdot
.51765 .54902 Mdot
.13728 4e-05 Mdot
.59999 .03141 Mdot
.30982 .31766 Mdot
.81958 .76469 Mdot
.79213 .82743 Mdot
.48628 .03141 Mdot
.1216 .03141 Mdot
.36472 .01572 Mdot
.64313 .04709 Mdot
.85487 .88232 Mdot
.47451 .13728 Mdot
.40785 .11376 Mdot
.56862 .05102 Mdot
.28629 .00788 Mdot
.42746 .01965 Mdot
.70587 .0667 Mdot
.88624 .90585 Mdot
.04709 .05102 Mdot
.5098 .01965 Mdot
.57646 .02749 Mdot
.1765 4e-05 Mdot
.44706 .00396 Mdot
.68234 .07062 Mdot
.85095 .8784 Mdot
.51372 .33727 Mdot
.52157 .03925 Mdot
.53333 .02749 Mdot
.12552 .00396 Mdot
.4902 .00788 Mdot
.80782 .52157 Mdot
.86272 .70587 Mdot
.52549 .10983 Mdot
.4902 .02749 Mdot
.45883 .01572 Mdot
.20394 .00788 Mdot
.52549 .00788 Mdot
.41961 .3608 Mdot
.72155 .13336 Mdot
.55294 .04709 Mdot
.4902 .04317 Mdot
.6196 .56862 Mdot
.12944 .00396 Mdot
.56862 .02749 Mdot
.88624 .90585 Mdot
.41961 .41961 Mdot
.6392 .63136 Mdot
.50196 .03141 Mdot
.14905 .11768 Mdot
.14905 .01572 Mdot
.58823 .03533 Mdot
.87056 .89801 Mdot
.84703 .87056 Mdot
.79606 .83135 Mdot
.52941 .03925 Mdot
.12944 .02357 Mdot
.25492 .01572 Mdot
.59607 .05494 Mdot
.86664 .89409 Mdot
.8235 .8588 Mdot
.44706 .09807 Mdot
.35687 .00396 Mdot
.24316 .00396 Mdot
.32943 4e-05 Mdot
.67057 .05494 Mdot
.73332 .31766 Mdot
.75684 .70979 Mdot
.49804 .04317 Mdot
.32158 .0118 Mdot
.22355 .00788 Mdot
.40393 .00396 Mdot
.58039 .10591 Mdot
.79998 .09415 Mdot
.60391 .05494 Mdot
.48628 .03533 Mdot
.58431 .03533 Mdot
.12552 .00396 Mdot
.47451 .01572 Mdot
.83527 .85095 Mdot
.3255 .1412 Mdot
.52549 .05102 Mdot
.51372 .04317 Mdot
.51372 .02749 Mdot
.18434 .00396 Mdot
.50196 .00788 Mdot
.83919 .87056 Mdot
.85487 .8784 Mdot
.34903 .34903 Mdot
.49804 .03141 Mdot
.4902 .251 Mdot
.24708 .00788 Mdot
.52157 .00396 Mdot
.8588 .88232 Mdot
.83527 .86272 Mdot
.81566 .84311 Mdot
.49804 .02749 Mdot
.41569 .40785 Mdot
.27453 .0118 Mdot
.53725 .00788 Mdot
.64313 .31374 Mdot
.78821 .69018 Mdot
.47843 .10199 Mdot
.5098 .04317 Mdot
.15297 .01965 Mdot
.3255 .0118 Mdot
.58039 .03925 Mdot
.80782 .08239 Mdot
.60783 .09415 Mdot
.53333 .03925 Mdot
.58039 .04317 Mdot
.3059 4e-05 Mdot
.27845 .0118 Mdot
.27845 .02357 Mdot
.83527 .08631 Mdot
.50588 .09415 Mdot
.51372 .01965 Mdot
.67842 .06278 Mdot
.21179 .00396 Mdot
.47059 .02357 Mdot
.83135 .83919 Mdot
.84703 .5098 Mdot
.34119 .3804 Mdot
.49804 .01965 Mdot
.64705 .05102 Mdot
.1765 .00396 Mdot
.4902 .04709 Mdot
.83527 .85487 Mdot
.86272 .87056 Mdot
.82743 .86272 Mdot
.47451 .01965 Mdot
.54902 .03141 Mdot
.17257 .00788 Mdot
.38432 .03141 Mdot
.78037 .67057 Mdot
.71763 .72547 Mdot
.26276 .27453 Mdot
.5098 .03141 Mdot
.44706 .03925 Mdot
.24316 .0118 Mdot
.51765 .0118 Mdot
.71371 .08239 Mdot
.09023 .03141 Mdot
.03141 .03533 Mdot
.48628 .02749 Mdot
.38824 .35295 Mdot
.22747 4e-05 Mdot
.54117 .01572 Mdot
.72155 .08239 Mdot
.39609 .42354 Mdot
.18042 .20787 Mdot
.51372 .03141 Mdot
.03925 .00396 Mdot
.16865 .00396 Mdot
.32943 .03141 Mdot
.72939 .10199 Mdot
.8039 .84311 Mdot
.03533 .0118 Mdot
.54509 .03141 Mdot
.22747 .0118 Mdot
.41569 .03925 Mdot
.81174 .81958 Mdot
.75292 .07454 Mdot
.78429 .85487 Mdot
.47059 .05886 Mdot
.64313 .04709 Mdot
.18434 .00396 Mdot
.36472 .03925 Mdot
.81174 .83919 Mdot
.73724 .07454 Mdot
.33335 .41961 Mdot
.52157 .03533 Mdot
.65489 .0667 Mdot
.16473 .00788 Mdot
.23531 .00788 Mdot
.57646 .21571 Mdot
.68626 .27061 Mdot
.83135 .8588 Mdot
.52157 .02357 Mdot
.59607 .03533 Mdot
.15689 .00396 Mdot
.53725 .03533 Mdot
.23139 .02357 Mdot
.72155 .41177 Mdot
.81566 .85095 Mdot
.51765 .02749 Mdot
.47451 .01965 Mdot
.24316 .00788 Mdot
.55294 .02749 Mdot
.72547 .73332 Mdot
.67057 .1765 Mdot
.80782 .84311 Mdot
.48628 .02749 Mdot
.45883 .38824 Mdot
.29021 .00396 Mdot
.54902 .0667 Mdot
.86664 .88232 Mdot
.35295 .05102 Mdot
.8039 .84703 Mdot
.48235 .03141 Mdot
.01572 4e-05 Mdot
.35295 .02357 Mdot
.78821 .79606 Mdot
.84311 .87056 Mdot
.68626 .71763 Mdot
.80782 .85487 Mdot
.56078 .03925 Mdot
.27061 .01572 Mdot
.47843 .30982 Mdot
.79998 .82743 Mdot
.79998 .66665 Mdot
.81958 .85487 Mdot
.71371 .69018 Mdot
.60783 .04317 Mdot
.15297 .00396 Mdot
.37648 .06278 Mdot
.36864 .11768 Mdot
.76076 .07454 Mdot
.81958 .8588 Mdot
.52941 .05102 Mdot
.61568 .03533 Mdot
.26276 .11376 Mdot
.47059 .02749 Mdot
.73724 .75684 Mdot
.78037 .08631 Mdot
.8039 .83919 Mdot
.48628 .02749 Mdot
.57254 .03533 Mdot
.08631 .00396 Mdot
.51372 .04317 Mdot
.6941 .55294 Mdot
.73332 .07846 Mdot
.46667 .15689 Mdot
.49804 .03533 Mdot
.50196 .02357 Mdot
.16865 .00788 Mdot
.54117 .03533 Mdot
.71371 .07846 Mdot
.61568 .6196 Mdot
.4353 .09807 Mdot
.43922 .01572 Mdot
.56078 .46275 Mdot
.23924 .00396 Mdot
.42746 .30198 Mdot
.39217 .3608 Mdot
.85487 .8784 Mdot
.71763 .76076 Mdot
.43138 .01572 Mdot
.00396 .00396 Mdot
.28629 .00788 Mdot
.79998 .83919 Mdot
.87448 .8784 Mdot
.83527 .87056 Mdot
.78821 .81566 Mdot
.51372 .01572 Mdot
.18434 .00788 Mdot
.3608 .01965 Mdot
.0667 .07062 Mdot
.75684 .10591 Mdot
.36472 .45883 Mdot
.51372 .05494 Mdot
.52157 .01572 Mdot
.29806 .03141 Mdot
.41177 .02357 Mdot
.81958 .83527 Mdot
.78429 .08631 Mdot
.49804 .1216 Mdot
.49412 .02749 Mdot
.57254 .03141 Mdot
.08631 .00396 Mdot
.35295 .04317 Mdot
.59607 .09415 Mdot
.76469 .09023 Mdot
.39609 .07454 Mdot
.50196 .03533 Mdot
.57254 .03141 Mdot
.08631 4e-05 Mdot
.43138 .02357 Mdot
.22355 .01965 Mdot
.40785 .30982 Mdot
.15297 .18826 Mdot
.48628 .02749 Mdot
.57254 .03533 Mdot
.09023 .00396 Mdot
.52941 .03533 Mdot
.5647 .61176 Mdot
.83919 .86664 Mdot
.79606 .82743 Mdot
.49412 .04317 Mdot
.46667 .03925 Mdot
.07454 4e-05 Mdot
.52941 .03925 Mdot
.84311 .86272 Mdot
.86272 .87448 Mdot
.74508 .75292 Mdot
.45883 .02357 Mdot
.20787 .11376 Mdot
.20002 .00788 Mdot
.62744 .42354 Mdot
.58823 .24316 Mdot
.55686 .20002 Mdot
.4902 .10591 Mdot
.44314 .00788 Mdot
.00396 4e-05 Mdot
.27061 .0118 Mdot
.78821 .81958 Mdot
.71763 .06278 Mdot
.3608 .07454 Mdot
.40001 .07846 Mdot
.49412 .01572 Mdot
.04709 .00396 Mdot
.31374 .00788 Mdot
.72939 .76861 Mdot
.71371 .0667 Mdot
.08631 .12552 Mdot
.12944 .00788 Mdot
.48628 .0118 Mdot
.25492 .01572 Mdot
.3608 .01572 Mdot
.79998 .83527 Mdot
.70587 .05886 Mdot
.67842 .73332 Mdot
.06278 .00788 Mdot
.4902 .0118 Mdot
.251 .00396 Mdot
.38432 .01965 Mdot
.76469 .79213 Mdot
.68234 .05494 Mdot
.81958 .87056 Mdot
.13336 .01572 Mdot
.50588 .02357 Mdot
.37256 .03141 Mdot
.41177 .01965 Mdot
.81566 .83527 Mdot
.71371 .07846 Mdot
.79213 .84703 Mdot
.39609 .05102 Mdot
.52941 .03141 Mdot
.11376 4e-05 Mdot
.45098 .03141 Mdot
.55294 .20394 Mdot
.72547 .07454 Mdot
.68234 .74508 Mdot
.47843 .03533 Mdot
.53333 .02357 Mdot
.05886 4e-05 Mdot
.48235 .03925 Mdot
.65097 .0667 Mdot
.71371 .09807 Mdot
.78037 .8235 Mdot
.44706 .01572 Mdot
.53725 .03141 Mdot
.05102 4e-05 Mdot
.50588 .04317 Mdot
.65881 .05886 Mdot
.66665 .11768 Mdot
.8235 .85487 Mdot
.44314 .01572 Mdot
.44706 .09415 Mdot
.05494 .00396 Mdot
.50588 .02749 Mdot
.69802 .07454 Mdot
.65097 .10199 Mdot
.8235 .86272 Mdot
.4902 .02749 Mdot
.13336 .08239 Mdot
.06278 .00396 Mdot
.5098 .03141 Mdot
.69018 .06278 Mdot
.43138 .08239 Mdot
.82743 .86664 Mdot
.54509 .02749 Mdot
.00396 .00396 Mdot
.19218 .0118 Mdot
.54902 .30982 Mdot
.70194 .05886 Mdot
.20394 .25492 Mdot
.82743 .86664 Mdot
.52941 .02357 Mdot
.05886 .00396 Mdot
.26276 .00396 Mdot
.79998 .83135 Mdot
.71371 .0667 Mdot
.83135 .87056 Mdot
.81566 .86272 Mdot
.54509 .03141 Mdot
.27845 .01965 Mdot
.30982 .0118 Mdot
.78429 .82743 Mdot
.71371 .07062 Mdot
.83919 .87448 Mdot
.81958 .86272 Mdot
.54117 .03533 Mdot
.30198 .00788 Mdot
.35687 .01572 Mdot
.76076 .8039 Mdot
.73724 .07062 Mdot
.83919 .8784 Mdot
.81566 .86272 Mdot
.55294 .03141 Mdot
.21179 4e-05 Mdot
.3804 .01965 Mdot
.1412 .1412 Mdot
.74116 .0667 Mdot
.83919 .8784 Mdot
.66665 .66273 Mdot
.58431 .04317 Mdot
.32158 .00788 Mdot
.43138 .02749 Mdot
.30198 .05494 Mdot
.51372 .10199 Mdot
.8039 .79606 Mdot
.47451 .0667 Mdot
.61568 .05494 Mdot
.3608 .22355 Mdot
.45491 .03925 Mdot
.59215 .07846 Mdot
.3608 .39609 Mdot
.54902 .16473 Mdot
.47843 .02749 Mdot
.63136 .07846 Mdot
.09807 .0118 Mdot
.45883 .03925 Mdot
.62744 .07454 Mdot
.8235 .86272 Mdot
.62352 .07454 Mdot
.50588 .02749 Mdot
.58431 .22747 Mdot
.10983 .05102 Mdot
.47451 .04317 Mdot
.64313 .05494 Mdot
.85487 .89017 Mdot
.56078 .08239 Mdot
.52549 .02749 Mdot
.64705 .49804 Mdot
.04317 .00396 Mdot
.47843 .04709 Mdot
.67842 .06278 Mdot
.83919 .8784 Mdot
.13728 .0118 Mdot
.53725 .02749 Mdot
.47059 .35687 Mdot
.03141 4e-05 Mdot
.46275 .03533 Mdot
.67842 .05494 Mdot
.84311 .88232 Mdot
.3059 .3608 Mdot
.52941 .01965 Mdot
.40001 .32158 Mdot
.03141 .00396 Mdot
.47451 .03925 Mdot
.67842 .05886 Mdot
.84311 .88232 Mdot
.72547 .76861 Mdot
.53725 .03533 Mdot
.07454 .03533 Mdot
.02357 4e-05 Mdot
.47843 .03925 Mdot
.68626 .05886 Mdot
.6745 .72547 Mdot
.81174 .85095 Mdot
.54509 .03533 Mdot
.09415 .04709 Mdot
.02357 4e-05 Mdot
.49804 .04317 Mdot
.66665 .05886 Mdot
.06278 .13728 Mdot
.79998 .84311 Mdot
.54117 .03141 Mdot
.11768 .02357 Mdot
.02749 .00396 Mdot
.50588 .02749 Mdot
.51765 .09415 Mdot
.66273 .71371 Mdot
.8039 .84703 Mdot
.54509 .03141 Mdot
.22355 .01572 Mdot
.08631 4e-05 Mdot
.54117 .02749 Mdot
.10983 .0667 Mdot
.84311 .87448 Mdot
.8039 .84703 Mdot
.56862 .03925 Mdot
.33727 .02749 Mdot
.20394 .01572 Mdot
.59215 .05102 Mdot
.6745 .71371 Mdot
.81566 .76076 Mdot
.8039 .84703 Mdot
.58039 .04709 Mdot
.41569 .00788 Mdot
.27453 .0118 Mdot
.61568 .05102 Mdot
.83527 .87056 Mdot
.53333 .21963 Mdot
.79998 .86272 Mdot
.57646 .04317 Mdot
.49804 .01572 Mdot
.29806 .0118 Mdot
.61568 .05886 Mdot
.83919 .87448 Mdot
.15297 .03533 Mdot
.67057 .749 Mdot
.55686 .03533 Mdot
.47451 .0118 Mdot
.30198 .00788 Mdot
.60391 .07846 Mdot
.83135 .87056 Mdot
.59999 .65881 Mdot
.69802 .76076 Mdot
.55294 .02357 Mdot
.40001 .00788 Mdot
.3255 .0118 Mdot
.57646 .09023 Mdot
.85095 .87056 Mdot
.83527 .8784 Mdot
.79998 .83919 Mdot
.54902 .02749 Mdot
.32943 .00396 Mdot
.3608 .01965 Mdot
.53333 .1216 Mdot
.59607 .37256 Mdot
.83527 .87448 Mdot
.79606 .84703 Mdot
.52941 .03141 Mdot
.29021 .00788 Mdot
.35295 .00788 Mdot
.54117 .20787 Mdot
.63528 .10983 Mdot
.83135 .87448 Mdot
.4902 .59215 Mdot
.4902 .16473 Mdot
.27453 .00396 Mdot
.3608 .01965 Mdot
.60391 .3608 Mdot
.51765 .10591 Mdot
.81566 .85487 Mdot
.60783 .68234 Mdot
.83135 .76861 Mdot
.27845 .00396 Mdot
.33335 .0118 Mdot
.64313 .49412 Mdot
.15297 .11376 Mdot
.83527 .85095 Mdot
.78037 .83135 Mdot
.55686 .52941 Mdot
.07062 .00396 Mdot
.34903 .01965 Mdot
.55294 .27845 Mdot
.52941 .56862 Mdot
.65489 .54509 Mdot
.78037 .83135 Mdot
.33335 .29021 Mdot
.13728 .00396 Mdot
.35687 .02357 Mdot
.49804 .12944 Mdot
.69018 .73724 Mdot
.51765 .21571 Mdot
.78037 .83135 Mdot
.20394 .1412 Mdot
.1412 .00396 Mdot
.38824 .05102 Mdot
.43922 .09807 Mdot
.81958 .86664 Mdot
.4902 .14905 Mdot
.78037 .83135 Mdot
.24316 .14513 Mdot
.14905 .01572 Mdot
.3804 .02357 Mdot
.24708 .03925 Mdot
.83527 .87448 Mdot
.19218 .03141 Mdot
.78037 .83135 Mdot
.43138 .33727 Mdot
.14513 .0118 Mdot
.39217 .01965 Mdot
.10983 .04317 Mdot
.83919 .83135 Mdot
.07454 .09415 Mdot
.77253 .82743 Mdot
.62744 .5647 Mdot
.15297 .0118 Mdot
.38432 .02749 Mdot
.29021 .30982 Mdot
.64705 .49412 Mdot
.54117 .61176 Mdot
.77645 .82743 Mdot
.72547 .68626 Mdot
.1412 .00396 Mdot
.33335 .02357 Mdot
.56862 .6196 Mdot
.58039 .20394 Mdot
.72155 .77645 Mdot
.78037 .83135 Mdot
.78429 .76076 Mdot
.14513 .00788 Mdot
.3059 .01965 Mdot
.74508 .79606 Mdot
.6941 .12944 Mdot
.81958 .86664 Mdot
.76076 .79606 Mdot
.76076 .75292 Mdot
.1412 .00788 Mdot
.34903 .03141 Mdot
.77253 .81566 Mdot
.78821 .10199 Mdot
.84311 .88232 Mdot
.61176 .57646 Mdot
.72155 .74508 Mdot
.14513 .00396 Mdot
.39217 .03141 Mdot
.77645 .8235 Mdot
.87056 .11376 Mdot
.87056 .89801 Mdot
.47059 .30198 Mdot
.6941 .74116 Mdot
.1412 .00396 Mdot
.38432 .01965 Mdot
.77645 .8235 Mdot
.95683 .15689 Mdot
.89801 .92154 Mdot
.5098 .16081 Mdot
.70587 .76469 Mdot
.14905 .00788 Mdot
.37256 .02357 Mdot
.78821 .83527 Mdot
.99212 .21571 Mdot
.92154 .93722 Mdot
.60391 .10199 Mdot
.68234 .75292 Mdot
.15297 .00788 Mdot
.36864 .02357 Mdot
.8039 .83527 Mdot
.99996 .251 Mdot
.94114 .95683 Mdot
.66665 .0667 Mdot
.63528 .71763 Mdot
.15297 .00788 Mdot
.37648 .02749 Mdot
.85095 .8235 Mdot
.97643 .23139 Mdot
.9333 .95291 Mdot
.72547 .0667 Mdot
.67057 .74508 Mdot
.15689 .00788 Mdot
.38432 .02749 Mdot
.85487 .74116 Mdot
.99212 .27453 Mdot
.94506 .95683 Mdot
.76076 .08239 Mdot
.6941 .76469 Mdot
.15689 .00396 Mdot
.39609 .01965 Mdot
.71371 .5647 Mdot
.99604 .25884 Mdot
.99996 .95291 Mdot
.749 .07846 Mdot
.60783 .69018 Mdot
.15689 .00396 Mdot
.41177 .02357 Mdot
.40393 .30982 Mdot
.98428 .1961 Mdot
.87056 .5098 Mdot
.74116 .07454 Mdot
.51765 .59999 Mdot
.14513 4e-05 Mdot
.43138 .03141 Mdot
.1765 .1765 Mdot
.90977 .12944 Mdot
.83135 .21963 Mdot
.69018 .03925 Mdot
.70587 .77645 Mdot
.13728 4e-05 Mdot
.47059 .04709 Mdot
.24316 .29413 Mdot
.80782 .09023 Mdot
.79998 .11376 Mdot
.63528 .00396 Mdot
.73332 .81566 Mdot
.13728 4e-05 Mdot
.47843 .04709 Mdot
.62352 .69018 Mdot
.75684 .07846 Mdot
.79213 .09807 Mdot
.76076 .10983 Mdot
.61568 .70194 Mdot
.27845 .00396 Mdot
.59215 .15689 Mdot
.73724 .79213 Mdot
.79606 .08239 Mdot
.83135 .09807 Mdot
.83919 .18434 Mdot
.66665 .74508 Mdot
.28237 .00396 Mdot
.59999 .13336 Mdot
.78429 .82743 Mdot
.90193 .13336 Mdot
.91369 .11376 Mdot
.65881 .04709 Mdot
.61176 .69018 Mdot
.27845 .00788 Mdot
.57254 .07062 Mdot
.78429 .8039 Mdot
.96859 .18042 Mdot
.97643 .16473 Mdot
.54509 .00396 Mdot
.57254 .65881 Mdot
.26276 .00396 Mdot
.50196 .05494 Mdot
.65881 .50196 Mdot
.99996 .23924 Mdot
.96075 .26276 Mdot
.58431 .0118 Mdot
.51765 .61568 Mdot
.27061 4e-05 Mdot
.70194 .39609 Mdot
.63528 .18826 Mdot
.99996 .251 Mdot
.97643 .58039 Mdot
.65489 .03533 Mdot
.5098 .59999 Mdot
.28629 .00788 Mdot
.48235 .27453 Mdot
.74116 .10591 Mdot
.97251 .18826 Mdot
.90977 .64705 Mdot
.71371 .05886 Mdot
.52941 .6196 Mdot
.27061 .00396 Mdot
.56862 .33727 Mdot
.79998 .10983 Mdot
.99212 .20787 Mdot
.90585 .67057 Mdot
.73332 .07846 Mdot
.51765 .60783 Mdot
.27061 .00396 Mdot
.40393 .07846 Mdot
.81174 .13728 Mdot
.99604 .21571 Mdot
.94506 .77645 Mdot
.72939 .07454 Mdot
.48235 .57646 Mdot
.26276 .00396 Mdot
.41569 .02749 Mdot
.73724 .12944 Mdot
.95291 .14905 Mdot
.91369 .75292 Mdot
.73724 .07454 Mdot
.49412 .58431 Mdot
.26276 .00396 Mdot
.44314 .03141 Mdot
.6196 .12552 Mdot
.90977 .11376 Mdot
.73724 .55294 Mdot
.70587 .07846 Mdot
.58431 .6745 Mdot
.28237 .00788 Mdot
.46275 .03533 Mdot
.38432 .05494 Mdot
.88232 .10983 Mdot
.84311 .63528 Mdot
.61568 .0667 Mdot
.60391 .6941 Mdot
.29021 .00396 Mdot
.46667 .03925 Mdot
.16081 .00788 Mdot
.89017 .10983 Mdot
.91369 .52941 Mdot
.52941 .07062 Mdot
.54117 .63528 Mdot
.29413 .00396 Mdot
.4353 .0118 Mdot
.15297 .11768 Mdot
.92938 .13728 Mdot
.89017 .25884 Mdot
.45491 .09023 Mdot
.60391 .68234 Mdot
.31374 4e-05 Mdot
.4353 .0118 Mdot
.30982 .34511 Mdot
.98035 .19218 Mdot
.99604 .31374 Mdot
.55294 .27453 Mdot
.749 .8235 Mdot
.32943 .00788 Mdot
.42354 .02357 Mdot
.53725 .59607 Mdot
.99996 .25492 Mdot
.99996 .3255 Mdot
.78821 .58823 Mdot
.69018 .78821 Mdot
.30982 4e-05 Mdot
.41177 .03925 Mdot
.71763 .77253 Mdot
.98428 .21571 Mdot
.94506 .21179 Mdot
.90193 .77253 Mdot
.58823 .68626 Mdot
.33335 .00396 Mdot
.51372 .13336 Mdot
.78429 .81958 Mdot
.97643 .15297 Mdot
.89017 .12944 Mdot
.85487 .79998 Mdot
.60783 .6745 Mdot
.34119 .00396 Mdot
.48235 .05102 Mdot
.84703 .83527 Mdot
.96859 .16081 Mdot
.94114 .18042 Mdot
.8235 .8235 Mdot
.65097 .71371 Mdot
.34903 .00396 Mdot
.45491 .02357 Mdot
.70979 .41177 Mdot
.99604 .22747 Mdot
.98428 .23531 Mdot
.79213 .82743 Mdot
.55686 .58431 Mdot
.39609 .0667 Mdot
.43922 .02357 Mdot
.77645 .12552 Mdot
.99996 .32943 Mdot
.99604 .26276 Mdot
.78429 .8235 Mdot
.10591 .09807 Mdot
.33335 .00396 Mdot
.47451 .02749 Mdot
.83527 .09023 Mdot
.97643 .30198 Mdot
.99604 .23531 Mdot
.81958 .82743 Mdot
.10983 .06278 Mdot
.19218 .00396 Mdot
.62744 .04317 Mdot
.8784 .11376 Mdot
.98428 .28629 Mdot
.86664 .04317 Mdot
.52941 .13728 Mdot
.18826 .1412 Mdot
.21179 4e-05 Mdot
.65097 .02749 Mdot
.83135 .09807 Mdot
.99212 .23531 Mdot
.84703 .05102 Mdot
.77645 .61568 Mdot
.31766 .03141 Mdot
.39609 .03533 Mdot
.68234 .03533 Mdot
.91761 .10591 Mdot
.99212 .20002 Mdot
.64705 .0118 Mdot
.76469 .86664 Mdot
.4902 .03925 Mdot
.12552 4e-05 Mdot
.72939 .05494 Mdot
.98035 .12552 Mdot
.98428 .1765 Mdot
.68626 .05494 Mdot
.81566 .90585 Mdot
.34903 .01965 Mdot
.04709 .00396 Mdot
.70587 .09415 Mdot
.96075 .16865 Mdot
.88624 .20002 Mdot
.83527 .67842 Mdot
.85095 .93722 Mdot
.49804 .03533 Mdot
.29806 .01572 Mdot
.73724 .05102 Mdot
.85095 .69018 Mdot
.68626 .27845 Mdot
.75292 .81958 Mdot
.77645 .8588 Mdot
.29021 .00396 Mdot
.42746 .02749 Mdot
.79998 .12552 Mdot
.60783 .49412 Mdot
.51765 .37256 Mdot
.40785 .10591 Mdot
.5098 .10591 Mdot
.22747 .00788 Mdot
.66273 .05494 Mdot
.72155 .45883 Mdot
.53333 .55294 Mdot
.45883 .45491 Mdot
.71763 .81566 Mdot
.63136 .07062 Mdot
.18434 .00788 Mdot
.75292 .10983 Mdot
.6941 .69802 Mdot
.60391 .64705 Mdot
.43922 .47451 Mdot
.6941 .82743 Mdot
.59999 .03925 Mdot
.19218 .00396 Mdot
.57254 .29021 Mdot
.78037 .79606 Mdot
.81174 .8588 Mdot
.40785 .47451 Mdot
.749 .87448 Mdot
.40785 4e-05 Mdot
.40785 .12552 Mdot
.47059 .52941 Mdot
.87448 .92546 Mdot
.83135 .85095 Mdot
.39609 .47843 Mdot
.65489 .8039 Mdot
.44706 .07062 Mdot
.54509 .15297 Mdot
.58039 .65881 Mdot
.45491 .46275 Mdot
.54117 .53333 Mdot
.37648 .46275 Mdot
.46667 .10199 Mdot
.34511 .0118 Mdot
.45883 .50588 Mdot
.43138 .41569 Mdot
.43922 .38824 Mdot
.56862 .55686 Mdot
.3608 .43922 Mdot
.53725 .00788 Mdot
.21963 .02357 Mdot
.4902 .49804 Mdot
.45491 .37648 Mdot
.45491 .41569 Mdot
.52157 .43138 Mdot
.35687 .44706 Mdot
.27061 .06278 Mdot
.41177 .47843 Mdot
.4902 .39217 Mdot
.46275 .38824 Mdot
.58039 .60391 Mdot
.52549 .42746 Mdot
.41961 .07846 Mdot
.35295 .01965 Mdot
.37256 .33727 Mdot
.45491 .36472 Mdot
.46667 .42354 Mdot
.45098 .3804 Mdot
.5647 .54509 Mdot
.61176 .05102 Mdot
.35295 .40393 Mdot
.47451 .36472 Mdot
.46667 .36864 Mdot
.44706 .39217 Mdot
.40393 .28629 Mdot
.3608 .45883 Mdot
.43138 .04317 Mdot
.45491 .37256 Mdot
.47451 .37256 Mdot
.44314 .40001 Mdot
.50196 .36472 Mdot
.47059 .34903 Mdot
.54509 .07846 Mdot
.35687 .39217 Mdot
.5098 .38432 Mdot
.45883 .36864 Mdot
.4353 .38432 Mdot
.46275 .3255 Mdot
.50588 .3804 Mdot
.41569 .04317 Mdot
.46667 .34903 Mdot
.49412 .38824 Mdot
.43922 .40001 Mdot
.45098 .3059 Mdot
.48235 .38824 Mdot
.34119 .3608 Mdot
.37256 .34511 Mdot
.50588 .3804 Mdot
.44706 .39609 Mdot
.43138 .40393 Mdot
.48235 .34511 Mdot
.43138 .29021 Mdot
.42746 .21571 Mdot
.4902 .36472 Mdot
.47843 .36472 Mdot
.53333 .55294 Mdot
.45491 .30982 Mdot
.48235 .34903 Mdot
.32943 .38824 Mdot
.45098 .33727 Mdot
.48628 .35687 Mdot
.42746 .4353 Mdot
.40785 .43138 Mdot
.46667 .37648 Mdot
.4353 .3059 Mdot
.38824 .29806 Mdot
.47059 .35295 Mdot
.47451 .41569 Mdot
.11768 .21963 Mdot
.42354 .33335 Mdot
.47059 .37256 Mdot
.29413 .21963 Mdot
.48628 .37256 Mdot
.4902 .37256 Mdot
.24316 .32943 Mdot
.38824 .3804 Mdot
.45491 .36472 Mdot
.251 .24708 Mdot
.36472 .27845 Mdot
.4902 .35295 Mdot
.1961 .25884 Mdot
.51372 .54509 Mdot
.47843 .35295 Mdot
.47451 .34511 Mdot
.39609 .02749 Mdot
.48628 .3608 Mdot
.39609 .36864 Mdot
.54117 .56862 Mdot
.4902 .34903 Mdot
.4902 .34511 Mdot
.1961 .21571 Mdot
.3804 .3608 Mdot
.48235 .35687 Mdot
.40785 .32943 Mdot
.57646 .54117 Mdot
.43922 .34903 Mdot
.40001 .37256 Mdot
.36864 .32943 Mdot
.4902 .34903 Mdot
.19218 .25492 Mdot
.6745 .62352 Mdot
.47843 .3804 Mdot
.47843 .38824 Mdot
.41961 .251 Mdot
.40393 .35295 Mdot
.23139 .29021 Mdot
.46667 .25884 Mdot
.46667 .25492 Mdot
.50196 .37256 Mdot
.20002 .251 Mdot
.34511 .35295 Mdot
.51372 .40001 Mdot
.51372 .23924 Mdot
.51372 .38432 Mdot
.50196 .37256 Mdot
.39217 .34511 Mdot
.27845 .04709 Mdot
.37256 .27453 Mdot
.36864 .29413 Mdot
.37256 .32943 Mdot
.50588 .30198 Mdot
.47059 .33727 Mdot
.30982 .36864 Mdot
.43138 .44706 Mdot
.50588 .41569 Mdot
.55686 .30198 Mdot
.3059 .27453 Mdot
.52157 .38824 Mdot
.3255 .32158 Mdot
.47451 .47843 Mdot
.43922 .33727 Mdot
.51372 .30982 Mdot
.23531 .28629 Mdot
.52941 .38432 Mdot
.29806 .3059 Mdot
.55686 .17257 Mdot
.46275 .48628 Mdot
.46667 .27453 Mdot
.69018 .63528 Mdot
.53333 .39609 Mdot
.3804 .28629 Mdot
.3804 .42746 Mdot
.5098 .57254 Mdot
.51765 .23924 Mdot
.53333 .34903 Mdot
.58039 .38432 Mdot
.40785 .30982 Mdot
.39609 .45883 Mdot
.52941 .59999 Mdot
.47843 .44706 Mdot
.56862 .55294 Mdot
.63528 .40785 Mdot
.45098 .33727 Mdot
.40785 .46275 Mdot
.53725 .59215 Mdot
.50196 .52157 Mdot
.43922 .41961 Mdot
.73724 .47843 Mdot
.47843 .3804 Mdot
.44706 .50196 Mdot
.57254 .57646 Mdot
.53725 .57646 Mdot
.52941 .38432 Mdot
.82743 .65097 Mdot
.53725 .50588 Mdot
.45883 .52941 Mdot
.51765 .50196 Mdot
.56862 .60783 Mdot
.56862 .35295 Mdot
.85095 .77645 Mdot
.58431 .56078 Mdot
.45098 .52549 Mdot
.58039 .64313 Mdot
.55294 .60783 Mdot
.56862 .50196 Mdot
.87448 .83919 Mdot
.70979 .58823 Mdot
.43138 .47843 Mdot
.60783 .68234 Mdot
.61568 .67842 Mdot
.9882 .95291 Mdot
.78037 .83135 Mdot
.54117 .59215 Mdot
.31374 .1216 Mdot
.61568 .69018 Mdot
.75292 .8039 Mdot
.99212 .99212 Mdot
.67057 .69018 Mdot
.46667 .53333 Mdot
.64313 .71371 Mdot
.64705 .71763 Mdot
.99604 .99604 Mdot
.75292 .81174 Mdot
.54509 .61176 Mdot
.66665 .69018 Mdot
.66273 .73724 Mdot
.94506 .96075 Mdot
.88624 .92154 Mdot
.59607 .65097 Mdot
.65881 .64705 Mdot
.6941 .76076 Mdot
.92546 .93722 Mdot
.88232 .92546 Mdot
.54117 .59999 Mdot
.6941 .76469 Mdot
.78429 .83919 Mdot
.99212 .99212 Mdot
.79998 .85487 Mdot
.1765 .08239 Mdot
.72939 .79998 Mdot
.9333 .95683 Mdot
.92154 .95291 Mdot
.45491 .26276 Mdot
.75292 .81566 Mdot
.91369 .94114 Mdot
.91369 .95291 Mdot
.3255 .15297 Mdot
.76469 .82743 Mdot
.9882 .9882 Mdot
.70194 .72155 Mdot
.67057 .52157 Mdot
.96467 .9882 Mdot
.61176 .57254 Mdot
.64705 .44706 Mdot
.75684 .70194 Mdot
.40785 .21179 Mdot
.628 .126 .941 r
.34903 .20394 Mdot
.47451 .38824 Mdot
.79998 .68234 Mdot
.74116 .73332 Mdot
.71371 .54117 Mdot
.43138 .44314 Mdot
.77253 .68234 Mdot
.76076 .63528 Mdot
.73724 .75684 Mdot
.79213 .78429 Mdot
.81174 .62744 Mdot
.83919 .80782 Mdot
.79213 .83135 Mdot
.72939 .43922 Mdot
.76861 .61176 Mdot
.61568 .6392 Mdot
.78037 .82743 Mdot
.74508 .51372 Mdot
.72547 .60391 Mdot
.71763 .75292 Mdot
.76076 .80782 Mdot
.71763 .48235 Mdot
.84311 .66665 Mdot
.83919 .81566 Mdot
.78429 .83135 Mdot
.11768 .05102 Mdot
.65097 .54509 Mdot
.76861 .72939 Mdot
.16865 .43138 Mdot
.75684 .81174 Mdot
.71763 .51372 Mdot
.87448 .72547 Mdot
.73724 .68626 Mdot
.79213 .83919 Mdot
.74116 .77253 Mdot
.8039 .63136 Mdot
.87056 .72939 Mdot
.73332 .70587 Mdot
.77645 .8235 Mdot
.33335 .21571 Mdot
.82743 .64705 Mdot
.84703 .70587 Mdot
.72155 .72547 Mdot
.78821 .85487 Mdot
.10199 .05102 Mdot
.8235 .66273 Mdot
.86664 .70979 Mdot
.83919 .81174 Mdot
.79606 .84703 Mdot
.44314 .54117 Mdot
.79998 .6196 Mdot
.80782 .81958 Mdot
.83527 .76861 Mdot
.78821 .85095 Mdot
.75292 .81566 Mdot
.74508 .57646 Mdot
.84703 .64705 Mdot
.81174 .71763 Mdot
.66273 .77253 Mdot
.75292 .8039 Mdot
.69018 .45883 Mdot
.79606 .61568 Mdot
.87056 .70194 Mdot
.74508 .67842 Mdot
.8039 .86664 Mdot
.72155 .81566 Mdot
.76861 .59999 Mdot
.83919 .63136 Mdot
.83135 .68626 Mdot
.38824 .52157 Mdot
.76469 .8235 Mdot
.65489 .41177 Mdot
.76076 .58431 Mdot
.84703 .6745 Mdot
.86664 .81174 Mdot
.08631 .36864 Mdot
.77253 .83919 Mdot
.69802 .49804 Mdot
.79213 .60391 Mdot
.8588 .6941 Mdot
.80782 .749 Mdot
.8039 .85487 Mdot
.70587 .76076 Mdot
.84311 .5098 Mdot
.44314 .39609 Mdot
.85095 .66665 Mdot
.79606 .75684 Mdot
.79213 .8588 Mdot
.50588 .62352 Mdot
.70194 .09415 Mdot
.60391 .53333 Mdot
.83919 .65489 Mdot
.79998 .74116 Mdot
.78821 .85487 Mdot
.25492 .40001 Mdot
.6941 .08239 Mdot
.65097 .54117 Mdot
.83919 .66665 Mdot
.71763 .67057 Mdot
.79998 .86664 Mdot
.18434 .34511 Mdot
.61176 .1765 Mdot
.6196 .53725 Mdot
.85095 .68234 Mdot
.82743 .79998 Mdot
.8039 .84703 Mdot
.74508 .84311 Mdot
.68234 .51372 Mdot
.77253 .53333 Mdot
.85095 .65881 Mdot
.76469 .64313 Mdot
.72939 .48628 Mdot
.749 .75292 Mdot
.61568 .47843 Mdot
.75684 .5098 Mdot
.8235 .6392 Mdot
.78429 .61568 Mdot
.67057 .37256 Mdot
.77253 .83527 Mdot
.50588 .32943 Mdot
.72155 .50196 Mdot
.36472 .40001 Mdot
.83527 .65881 Mdot
.70979 .61568 Mdot
.78429 .66665 Mdot
.39609 .5098 Mdot
.67842 .50196 Mdot
.74508 .43922 Mdot
.85487 .67057 Mdot
.8235 .69018 Mdot
.71763 .03925 Mdot
.73724 .58431 Mdot
.54509 .44314 Mdot
.70587 .46667 Mdot
.81174 .6196 Mdot
.8039 .63528 Mdot
.71371 .04317 Mdot
.8039 .82743 Mdot
.51765 .55686 Mdot
.68626 .51765 Mdot
.72939 .43922 Mdot
.85095 .68234 Mdot
.76076 .57254 Mdot
.69018 .02357 Mdot
.78037 .71763 Mdot
.56862 .48628 Mdot
.70194 .44314 Mdot
.79998 .57646 Mdot
.81174 .63136 Mdot
.70979 .03141 Mdot
.57646 .25884 Mdot
.61176 .68234 Mdot
.64313 .47451 Mdot
.74508 .41569 Mdot
.83527 .68626 Mdot
.83135 .57254 Mdot
.70194 .02749 Mdot
.66273 .03925 Mdot
.66273 .75684 Mdot
.68234 .45491 Mdot
.78037 .50196 Mdot
.46275 .43138 Mdot
.72939 .03925 Mdot
.67057 .03141 Mdot
.20787 .31766 Mdot
.60391 .53333 Mdot
.70979 .37648 Mdot
.79998 .60391 Mdot
.8039 .63136 Mdot
.67842 .03925 Mdot
.749 .59215 Mdot
.10591 .05102 Mdot
.6392 .48235 Mdot
.75684 .43922 Mdot
.53725 .45883 Mdot
.78037 .05494 Mdot
.40001 .40393 Mdot
.65097 .1961 Mdot
.73724 .80782 Mdot
.68626 .47843 Mdot
.77253 .49412 Mdot
.51372 .51372 Mdot
.76076 .05102 Mdot
.21963 .42354 Mdot
.68626 .0118 Mdot
.79998 .83527 Mdot
.6745 .43138 Mdot
.79606 .54902 Mdot
.81958 .68234 Mdot
.65097 .11768 Mdot
.58431 .33727 Mdot
.41177 .38824 Mdot
.57646 .51765 Mdot
.6941 .37648 Mdot
.80782 .6196 Mdot
.88624 .57646 Mdot
.15297 .38432 Mdot
.63136 .03925 Mdot
.53333 .52941 Mdot
.62744 .53725 Mdot
.71763 .40393 Mdot
.82743 .66273 Mdot
.81174 .0667 Mdot
.80782 .8235 Mdot
.66665 .71371 Mdot
.69802 .76469 Mdot
.62352 .48628 Mdot
.75292 .47451 Mdot
.86664 .70194 Mdot
.79998 .05102 Mdot
.70194 .68626 Mdot
.66665 .08239 Mdot
.70587 .81566 Mdot
.64705 .50588 Mdot
.76861 .55686 Mdot
.85095 .72155 Mdot
.70979 .39217 Mdot
.72155 .79213 Mdot
.57254 .02357 Mdot
.47451 .60783 Mdot
.64705 .47451 Mdot
.78429 .57646 Mdot
.83527 .69802 Mdot
.12944 .41961 Mdot
.21179 .38432 Mdot
.51372 .03925 Mdot
.57254 .67842 Mdot
.67057 .46275 Mdot
.78037 .59215 Mdot
.84703 .68234 Mdot
.67842 .58039 Mdot
.6941 .8588 Mdot
.43138 .01572 Mdot
.77253 .84703 Mdot
.67057 .42354 Mdot
.79998 .61176 Mdot
.72155 .23139 Mdot
.74508 .41961 Mdot
.77253 .85487 Mdot
.4902 .04709 Mdot
.65881 .70194 Mdot
.67842 .38824 Mdot
.78821 .61176 Mdot
.8235 .0667 Mdot
.70979 .05102 Mdot
.78429 .8588 Mdot
.3804 .02749 Mdot
.52157 .54117 Mdot
.67842 .39609 Mdot
.80782 .62744 Mdot
.83919 .05886 Mdot
.71763 .04317 Mdot
.79213 .85487 Mdot
.29413 .00396 Mdot
.54902 .54117 Mdot
.69802 .41569 Mdot
.8039 .62744 Mdot
.81566 .05886 Mdot
.71371 .03533 Mdot
.77645 .77253 Mdot
.39217 .01572 Mdot
.5647 .54902 Mdot
.67842 .41177 Mdot
.81566 .64313 Mdot
.75684 .29806 Mdot
.70587 .03533 Mdot
.59215 .42354 Mdot
.54902 .05886 Mdot
.58431 .56078 Mdot
.70587 .45491 Mdot
.8235 .65881 Mdot
.1961 .46275 Mdot
.63136 .12552 Mdot
.52549 .1216 Mdot
.56078 .06278 Mdot
.58431 .56078 Mdot
.69802 .46275 Mdot
.80782 .65489 Mdot
.12944 .49804 Mdot
.51372 .43922 Mdot
.51765 .11376 Mdot
.52549 .02357 Mdot
.58823 .56078 Mdot
.71763 .49804 Mdot
.81174 .64705 Mdot
.46667 .69802 Mdot
.08239 .36472 Mdot
.52157 .10983 Mdot
.54509 .02357 Mdot
.58431 .55686 Mdot
.71371 .50588 Mdot
.8039 .64705 Mdot
.71371 .76469 Mdot
.3255 .53333 Mdot
.52549 .10199 Mdot
.49804 .00788 Mdot
.59215 .56862 Mdot
.70587 .5098 Mdot
.79998 .63528 Mdot
.78037 .70979 Mdot
.77645 .78037 Mdot
.52549 .08631 Mdot
.52157 .03141 Mdot
.54509 .53333 Mdot
.71371 .52549 Mdot
.79606 .63136 Mdot
.80782 .6745 Mdot
.70979 .58431 Mdot
.53725 .09807 Mdot
.59215 .08239 Mdot
.52549 .51372 Mdot
.71763 .52549 Mdot
.8039 .63528 Mdot
.8588 .62352 Mdot
.72939 .45883 Mdot
.54509 .09807 Mdot
.58431 .15689 Mdot
.52549 .50196 Mdot
.73724 .54117 Mdot
.8039 .64313 Mdot
.71371 .24316 Mdot
.63528 .15297 Mdot
.54902 .08239 Mdot
.58823 .29021 Mdot
.50196 .47843 Mdot
.73724 .55294 Mdot
.79998 .63528 Mdot
.75684 .10199 Mdot
.68234 .06278 Mdot
.5647 .08239 Mdot
.65097 .50588 Mdot
.50196 .48235 Mdot
.72547 .54902 Mdot
.8039 .63136 Mdot
.78037 .08239 Mdot
.66273 .05102 Mdot
.57646 .08239 Mdot
.60391 .58039 Mdot
.4902 .47451 Mdot
.72155 .54509 Mdot
.81566 .65097 Mdot
.73724 .09023 Mdot
.60783 .21179 Mdot
.56862 .0667 Mdot
.5098 .53333 Mdot
.48235 .46667 Mdot
.72155 .54117 Mdot
.8039 .64313 Mdot
.70587 .23531 Mdot
.32943 .25884 Mdot
.56078 .06278 Mdot
.68234 .73724 Mdot
.44314 .46275 Mdot
.69802 .52941 Mdot
.78429 .62744 Mdot
.73724 .30982 Mdot
.66273 .34119 Mdot
.49804 .09023 Mdot
.47843 .60783 Mdot
.65881 .70194 Mdot
.68234 .54117 Mdot
.78429 .61568 Mdot
.73724 .50196 Mdot
.6392 .04317 Mdot
.52941 .34119 Mdot
.30982 .50196 Mdot
.72939 .78037 Mdot
.69802 .56078 Mdot
.79213 .63136 Mdot
.50588 .56862 Mdot
.6941 .05886 Mdot
.35295 .42746 Mdot
.62744 .81174 Mdot
.70587 .78429 Mdot
.71763 .58039 Mdot
.76861 .60783 Mdot
.20787 .45883 Mdot
.63136 .07846 Mdot
.37648 .52549 Mdot
.35687 .58039 Mdot
.54902 .66665 Mdot
.70979 .58431 Mdot
.78037 .6196 Mdot
.65489 .70587 Mdot
.61568 .16473 Mdot
.5647 .69018 Mdot
.70979 .87448 Mdot
.40393 .52549 Mdot
.70194 .59215 Mdot
.77253 .61568 Mdot
.81566 .72547 Mdot
.65489 .25884 Mdot
.58039 .49412 Mdot
.72547 .84703 Mdot
.38432 .51765 Mdot
.6745 .59999 Mdot
.76076 .59607 Mdot
.81174 .70979 Mdot
.6745 .3059 Mdot
.54902 .07846 Mdot
.70587 .83135 Mdot
.33335 .47059 Mdot
.68234 .60783 Mdot
.74508 .58823 Mdot
.81566 .71371 Mdot
.66273 .30198 Mdot
.6392 .02749 Mdot
.73332 .84311 Mdot
.31766 .45098 Mdot
.68626 .61568 Mdot
.74116 .58823 Mdot
.81958 .72155 Mdot
.65489 .3059 Mdot
.65881 .03533 Mdot
.72155 .83919 Mdot
.34903 .50588 Mdot
.66665 .60783 Mdot
.74116 .57646 Mdot
.8235 .72155 Mdot
.77253 .59999 Mdot
.6392 .42354 Mdot
.72155 .85095 Mdot
.56078 .70979 Mdot
.63136 .59215 Mdot
.73332 .56078 Mdot
.79998 .6941 Mdot
.73332 .64705 Mdot
.62352 .66273 Mdot
.72547 .8235 Mdot
.53725 .55294 Mdot
.60783 .5647 Mdot
.73724 .55294 Mdot
.8039 .69018 Mdot
.73724 .6745 Mdot
.6196 .60391 Mdot
.72939 .83135 Mdot
.68626 .40785 Mdot
.55686 .52549 Mdot
.72939 .54902 Mdot
.79606 .67057 Mdot
.72939 .67057 Mdot
.61176 .54902 Mdot
.71763 .85487 Mdot
.31374 .21963 Mdot
.55686 .53725 Mdot
.71763 .54117 Mdot
.79998 .66665 Mdot
.73724 .6941 Mdot
.6196 .56078 Mdot
.6392 .80782 Mdot
.10983 .21179 Mdot
.56078 .55294 Mdot
.6941 .52157 Mdot
.8039 .67842 Mdot
.74508 .69802 Mdot
.62744 .56862 Mdot
.43922 .3255 Mdot
.52549 .63136 Mdot
.54509 .56078 Mdot
.70194 .52941 Mdot
.79998 .67842 Mdot
.75292 .6941 Mdot
.64705 .59607 Mdot
.54509 .05886 Mdot
.5647 .65881 Mdot
.65881 .71371 Mdot
.70194 .54902 Mdot
.79606 .66273 Mdot
.75684 .69802 Mdot
.61568 .57646 Mdot
.59215 .02749 Mdot
.40785 .51372 Mdot
.33335 .44706 Mdot
.68626 .56078 Mdot
.79606 .65489 Mdot
.77645 .73332 Mdot
.5647 .14513 Mdot
.50588 .29806 Mdot
.40001 .60783 Mdot
.55294 .6745 Mdot
.66273 .55686 Mdot
.77645 .6392 Mdot
.78821 .72939 Mdot
.6745 .06278 Mdot
.65097 .59607 Mdot
.6745 .83527 Mdot
.16865 .33335 Mdot
.67057 .58823 Mdot
.77253 .6392 Mdot
.78037 .71371 Mdot
.70194 .05886 Mdot
.61176 .05102 Mdot
.70979 .84703 Mdot
.34511 .49804 Mdot
.67057 .61176 Mdot
.749 .60391 Mdot
.78037 .71371 Mdot
.69802 .09415 Mdot
.66273 .03141 Mdot
.69802 .83527 Mdot
.44706 .59215 Mdot
.6392 .59999 Mdot
.73332 .59215 Mdot
.76469 .70587 Mdot
.62352 .27453 Mdot
.65489 .02357 Mdot
.72155 .84311 Mdot
.49804 .63136 Mdot
.6196 .59607 Mdot
.74116 .57646 Mdot
.76469 .69802 Mdot
.73332 .66665 Mdot
.66273 .03925 Mdot
.70979 .70979 Mdot
.69802 .60391 Mdot
.59607 .58039 Mdot
.71371 .56078 Mdot
.75684 .68626 Mdot
.75292 .69802 Mdot
.65097 .03533 Mdot
.52157 .06278 Mdot
.27453 .12944 Mdot
.58039 .58431 Mdot
.70979 .53725 Mdot
.77253 .69018 Mdot
.72939 .69802 Mdot
.66665 .04709 Mdot
.57646 .04317 Mdot
.01572 .18434 Mdot
.52549 .5647 Mdot
.69802 .53333 Mdot
.75292 .66273 Mdot
.74508 .72547 Mdot
.68626 .05494 Mdot
.59215 .04709 Mdot
.02357 .20002 Mdot
.76469 .85487 Mdot
.68234 .54117 Mdot
.74116 .61176 Mdot
.75292 .72939 Mdot
.70194 .05102 Mdot
.53725 .49412 Mdot
.57646 .70194 Mdot
.251 .38824 Mdot
.64313 .54117 Mdot
.6941 .55686 Mdot
.76076 .73332 Mdot
.70979 .04709 Mdot
.41569 .53333 Mdot
.16473 .40393 Mdot
.58431 .72547 Mdot
.61568 .52549 Mdot
.68626 .51765 Mdot
.76469 .75292 Mdot
.72155 .05494 Mdot
.58039 .07846 Mdot
.68626 .85095 Mdot
.23139 .37256 Mdot
.62352 .55294 Mdot
.66273 .49412 Mdot
.56862 .58823 Mdot
.70979 .07454 Mdot
.65489 .03533 Mdot
.67057 .84311 Mdot
.37256 .52157 Mdot
.60391 .54509 Mdot
.68626 .50588 Mdot
.66273 .64705 Mdot
.60783 .1412 Mdot
.6392 .03141 Mdot
.65097 .86272 Mdot
.66665 .78821 Mdot
.60783 .56862 Mdot
.69018 .50196 Mdot
.72547 .67057 Mdot
.78037 .63528 Mdot
.64705 .03533 Mdot
.29413 .62352 Mdot
.6392 .53725 Mdot
.57646 .55294 Mdot
.67057 .48235 Mdot
.66665 .58431 Mdot
.70587 .68234 Mdot
.64705 .03533 Mdot
.03533 .3255 Mdot
.33727 .3059 Mdot
.5647 .55294 Mdot
.66273 .48235 Mdot
.66273 .5647 Mdot
.70979 .69802 Mdot
.67842 .05102 Mdot
.15297 .25884 Mdot
.22355 .29806 Mdot
.52549 .55294 Mdot
.66665 .4902 Mdot
.66665 .57254 Mdot
.73332 .71371 Mdot
.67842 .03533 Mdot
.57254 .54509 Mdot
.32943 .37648 Mdot
.47059 .50196 Mdot
.64313 .48628 Mdot
.64705 .51765 Mdot
.74508 .73724 Mdot
.6941 .04317 Mdot
.60391 .79213 Mdot
.41177 .4902 Mdot
.43138 .43922 Mdot
.63136 .50196 Mdot
.64705 .48628 Mdot
.76076 .74116 Mdot
.68626 .04709 Mdot
.36864 .74508 Mdot
.64705 .76861 Mdot
.42746 .38824 Mdot
.61568 .49412 Mdot
.65881 .44314 Mdot
.77253 .75292 Mdot
.69802 .04709 Mdot
.04709 .37648 Mdot
.27453 .49412 Mdot
.44314 .51765 Mdot
.59999 .50588 Mdot
.64313 .4353 Mdot
.76861 .73724 Mdot
.71763 .05886 Mdot
.38432 .45098 Mdot
.28629 .47843 Mdot
.65881 .78821 Mdot
.59607 .53725 Mdot
.63136 .44706 Mdot
.73724 .71763 Mdot
.71371 .04317 Mdot
.5647 .37648 Mdot
.6941 .83527 Mdot
.68626 .8235 Mdot
.56078 .5098 Mdot
.63136 .4353 Mdot
.63528 .58431 Mdot
.60783 .13336 Mdot
.51765 .18042 Mdot
.3608 .45491 Mdot
.6745 .58431 Mdot
.56862 .54902 Mdot
.62352 .42746 Mdot
.62352 .55294 Mdot
.70587 .70587 Mdot
.57646 .0667 Mdot
.5647 .47451 Mdot
.1765 .27453 Mdot
.52941 .53333 Mdot
.6196 .41961 Mdot
.62352 .53333 Mdot
.70979 .72547 Mdot
.46667 .1412 Mdot
.74116 .86272 Mdot
.25884 .36472 Mdot
.45491 .4902 Mdot
.63136 .45098 Mdot
.61568 .51765 Mdot
.70979 .73724 Mdot
.56862 .65489 Mdot
.4902 .73332 Mdot
.14513 .34119 Mdot
.37648 .14905 Mdot
.6196 .49804 Mdot
.66273 .57254 Mdot
.72547 .74116 Mdot
.57254 .62744 Mdot
.20394 .40393 Mdot
.31374 .49804 Mdot
.45491 .36472 Mdot
.63528 .52941 Mdot
.6196 .50588 Mdot
.74116 .74508 Mdot
.51765 .16865 Mdot
.58823 .58431 Mdot
.01572 .29806 Mdot
.43922 .18434 Mdot
.62352 .52157 Mdot
.63136 .50196 Mdot
.74508 .749 Mdot
.57646 .18042 Mdot
.58039 .40393 Mdot
.54509 .68234 Mdot
.31374 .1216 Mdot
.56862 .48628 Mdot
.6392 .50196 Mdot
.53725 .57646 Mdot
.58823 .21179 Mdot
.51372 .17257 Mdot
.30982 .52157 Mdot
.32158 .21571 Mdot
.54117 .4902 Mdot
.61568 .45883 Mdot
.53725 .53725 Mdot
.74508 .66665 Mdot
.50196 .12944 Mdot
.70587 .83135 Mdot
.30198 .08239 Mdot
.54902 .50196 Mdot
.61568 .46667 Mdot
.66273 .62352 Mdot
.69018 .70194 Mdot
.53725 .18434 Mdot
.44706 .18042 Mdot
.00396 .18826 Mdot
.4902 .48628 Mdot
.61176 .45098 Mdot
.66273 .62744 Mdot
.71371 .73332 Mdot
.53725 .16865 Mdot
.58039 .04709 Mdot
.00396 .1961 Mdot
.47451 .4902 Mdot
.6196 .45491 Mdot
.6941 .65881 Mdot
.6941 .72155 Mdot
.56862 .18434 Mdot
.56862 .03141 Mdot
.00788 .20787 Mdot
.46667 .43922 Mdot
.60391 .48235 Mdot
.66665 .63528 Mdot
.70979 .749 Mdot
.55294 .25492 Mdot
.59607 .02749 Mdot
.3255 .42746 Mdot
.38824 .23531 Mdot
.58431 .47059 Mdot
.66273 .61176 Mdot
.70587 .71763 Mdot
.43138 .47451 Mdot
.61568 .04709 Mdot
.36864 .45883 Mdot
.32943 .09807 Mdot
.53333 .41569 Mdot
.66273 .59999 Mdot
.6941 .70979 Mdot
.21179 .39217 Mdot
.59607 .04317 Mdot
.37648 .48235 Mdot
.47451 .22747 Mdot
.50196 .41569 Mdot
.64705 .5647 Mdot
.69802 .71371 Mdot
.27061 .43138 Mdot
.55686 .04317 Mdot
.35687 .48628 Mdot
.3804 .18042 Mdot
.47451 .41961 Mdot
.65097 .56078 Mdot
.69018 .72939 Mdot
.70194 .68626 Mdot
.52941 .0667 Mdot
.33335 .22747 Mdot
.46667 .26276 Mdot
.50196 .46275 Mdot
.6196 .52549 Mdot
.68234 .71763 Mdot
.68626 .70587 Mdot
.51765 .10199 Mdot
.49804 .03533 Mdot
.26668 .33727 Mdot
.43922 .4353 Mdot
.59999 .48628 Mdot
.68626 .70979 Mdot
.65097 .67842 Mdot
.50588 .10591 Mdot
.44706 .20394 Mdot
.24708 .37256 Mdot
.40785 .40001 Mdot
.61568 .49412 Mdot
.65097 .65097 Mdot
.68234 .72155 Mdot
.57646 .05886 Mdot
.53333 .53725 Mdot
.32943 .40001 Mdot
.34511 .35687 Mdot
.60391 .48628 Mdot
.68234 .65489 Mdot
.66665 .70979 Mdot
.63528 .03925 Mdot
.55294 .07454 Mdot
.00788 .18434 Mdot
.30198 .32158 Mdot
.58431 .50196 Mdot
.69018 .66665 Mdot
.65097 .6941 Mdot
.67057 .05102 Mdot
.60783 .04317 Mdot
.36472 .43922 Mdot
.33727 .31766 Mdot
.55294 .43922 Mdot
.67842 .63528 Mdot
.70979 .73332 Mdot
.65881 .03533 Mdot
.61176 .02749 Mdot
.39609 .47451 Mdot
.39609 .11376 Mdot
.51372 .43138 Mdot
.67057 .59607 Mdot
.6941 .72155 Mdot
.70587 .05886 Mdot
.59607 .03533 Mdot
.48235 .69018 Mdot
.47451 .31766 Mdot
.4902 .44706 Mdot
.65489 .55294 Mdot
.66665 .69018 Mdot
.6941 .0667 Mdot
.50588 .08631 Mdot
.41569 .09415 Mdot
.19218 .32158 Mdot
.38432 .38824 Mdot
.65097 .53725 Mdot
.58431 .56078 Mdot
.65097 .38432 Mdot
.51765 .57646 Mdot
.55686 .49804 Mdot
.00396 .23531 Mdot
.31374 .33335 Mdot
.61568 .50196 Mdot
.53333 .49412 Mdot
.66273 .69802 Mdot
.49804 .62352 Mdot
.63136 .90585 Mdot
.01572 .20394 Mdot
.27845 .29413 Mdot
.59607 .49412 Mdot
.61176 .58823 Mdot
.63136 .6745 Mdot
.34119 .62352 Mdot
.10199 .40001 Mdot
.35295 .4353 Mdot
.29806 .27453 Mdot
.58039 .47451 Mdot
.66665 .62744 Mdot
.67057 .72155 Mdot
.03533 .46275 Mdot
.02357 .39217 Mdot
.39609 .46667 Mdot
.39609 .38824 Mdot
.5098 .4353 Mdot
.62352 .57646 Mdot
.68234 .70587 Mdot
.42746 .48628 Mdot
.02357 .36472 Mdot
.40785 .4902 Mdot
.43138 .37648 Mdot
.48235 .43922 Mdot
.60391 .50196 Mdot
.6392 .69802 Mdot
.60391 .09023 Mdot
.52941 .22747 Mdot
.62352 .80782 Mdot
.20787 .30982 Mdot
.40393 .3804 Mdot
.56862 .4353 Mdot
.61176 .60391 Mdot
.66665 .04709 Mdot
.5098 .34903 Mdot
.14513 .34511 Mdot
.28629 .42354 Mdot
.3059 .30982 Mdot
.52157 .40001 Mdot
.63528 .64313 Mdot
.65881 .09415 Mdot
.54117 .58039 Mdot
.47843 .13728 Mdot
.32158 .39609 Mdot
.29413 .1412 Mdot
.55294 .43138 Mdot
.65097 .63136 Mdot
.66665 .66273 Mdot
.54902 .1961 Mdot
.52941 .05494 Mdot
.34903 .43138 Mdot
.35687 .29413 Mdot
.53333 .44314 Mdot
.54902 .49804 Mdot
.60783 .65489 Mdot
.55294 .12944 Mdot
.51765 .07062 Mdot
.38432 .46275 Mdot
.41569 .38824 Mdot
.54902 .4902 Mdot
.58431 .5098 Mdot
.64705 .6941 Mdot
.57254 .51765 Mdot
.40785 .32158 Mdot
.46275 .48628 Mdot
.1961 .27453 Mdot
.45883 .42354 Mdot
.54509 .37648 Mdot
.63136 .66273 Mdot
.1216 .48235 Mdot
.6196 .6941 Mdot
.47843 .07846 Mdot
4e-05 .23531 Mdot
.37648 .37256 Mdot
.54902 .39609 Mdot
.67842 .71763 Mdot
.58431 .33335 Mdot
.34511 .58431 Mdot
.55686 .03925 Mdot
.00396 .23531 Mdot
.3608 .33727 Mdot
.52941 .3804 Mdot
.66273 .65881 Mdot
.72155 .07846 Mdot
.56078 .08631 Mdot
.55294 .05886 Mdot
.00396 .29021 Mdot
.26668 .23139 Mdot
.4902 .38824 Mdot
.54117 .50196 Mdot
.68234 .54509 Mdot
.50196 .6392 Mdot
.50196 .09415 Mdot
.00788 .28629 Mdot
.45883 .30198 Mdot
.54902 .47843 Mdot
.58431 .53333 Mdot
.65881 .70587 Mdot
.13336 .54117 Mdot
.4902 .48628 Mdot
.41961 .3608 Mdot
.56862 .31374 Mdot
.51372 .48628 Mdot
.60783 .50588 Mdot
.67842 .72155 Mdot
.40785 .50588 Mdot
.69802 .84311 Mdot
.52549 .03533 Mdot
.30982 .39217 Mdot
.41569 .38824 Mdot
.59999 .47059 Mdot
.65881 .70587 Mdot
.67842 .08631 Mdot
.53725 .66665 Mdot
.44314 .13728 Mdot
.29413 .41569 Mdot
.35295 .3255 Mdot
.53333 .38824 Mdot
.55686 .57646 Mdot
.72547 .22747 Mdot
.06278 .39217 Mdot
.46667 .13728 Mdot
.01572 .23139 Mdot
.32158 .27061 Mdot
.47843 .33335 Mdot
.78821 .8235 Mdot
.71763 .09023 Mdot
.52941 .35687 Mdot
.48235 .04709 Mdot
.33335 .47059 Mdot
.3255 .21571 Mdot
.53333 .44706 Mdot
.48235 .4902 Mdot
.60391 .66273 Mdot
.59607 .07454 Mdot
.54902 .03141 Mdot
.06278 .34511 Mdot
.38824 .28237 Mdot
.52549 .47059 Mdot
.60391 .54117 Mdot
.65881 .71371 Mdot
.62352 .1216 Mdot
.55686 .05494 Mdot
.04317 .31374 Mdot
.10983 .27453 Mdot
.49804 .46667 Mdot
.58039 .47059 Mdot
.65097 .69018 Mdot
.54902 .19218 Mdot
.57646 .71763 Mdot
.43138 .10591 Mdot
.00788 .25884 Mdot
.39609 .37648 Mdot
.57254 .45098 Mdot
.6392 .66665 Mdot
.69018 .0667 Mdot
.42746 .54902 Mdot
.67057 .73724 Mdot
.05102 .23924 Mdot
.33335 .27845 Mdot
.51372 .40001 Mdot
.5098 .52941 Mdot
.57254 .12944 Mdot
.63136 .73724 Mdot
.45098 .07846 Mdot
.06278 .30198 Mdot
.32943 .08239 Mdot
.52157 .40785 Mdot
.52941 .52941 Mdot
.65097 .71371 Mdot
.53725 .72547 Mdot
.07062 .31374 Mdot
.31766 .4902 Mdot
.47059 .27845 Mdot
.44706 .40001 Mdot
.58823 .54509 Mdot
.66273 .71371 Mdot
.19218 .53333 Mdot
.52157 .05886 Mdot
.07454 .37648 Mdot
.17257 .3059 Mdot
.43138 .0667 Mdot
.56862 .45883 Mdot
.59215 .63528 Mdot
.251 .62744 Mdot
.46275 .59607 Mdot
.31374 .31374 Mdot
.10983 .28237 Mdot
.34119 .17257 Mdot
.53333 .42354 Mdot
.50196 .52549 Mdot
.67057 .10983 Mdot
.48628 .62744 Mdot
.47451 .07454 Mdot
.34511 .4353 Mdot
.32943 .25884 Mdot
.51372 .41177 Mdot
.48628 .48235 Mdot
.58431 .32943 Mdot
.52549 .62352 Mdot
.48628 .05494 Mdot
.3804 .47843 Mdot
.33727 .26276 Mdot
.48628 .40393 Mdot
.53725 .53725 Mdot
.63528 .69802 Mdot
.64313 .73332 Mdot
.40785 .07846 Mdot
.32943 .46275 Mdot
.36864 .01572 Mdot
.38824 .32943 Mdot
.59607 .55294 Mdot
.65097 .70587 Mdot
.59999 .6745 Mdot
.65097 .67057 Mdot
.41569 .3059 Mdot
.01572 .1765 Mdot
.39609 .35687 Mdot
.57254 .47451 Mdot
.46667 .5098 Mdot
.24708 .39609 Mdot
.5098 .74508 Mdot
.42746 .07454 Mdot
.251 .37256 Mdot
.37648 .28629 Mdot
.51765 .42354 Mdot
.46275 .47843 Mdot
.72155 .07062 Mdot
.53725 .68234 Mdot
.52549 .03533 Mdot
.36472 .46275 Mdot
.3804 .0667 Mdot
.51765 .42354 Mdot
.43138 .45491 Mdot
.62744 .68626 Mdot
.57254 .67842 Mdot
.40001 .1765 Mdot
.35687 .43138 Mdot
.30198 .01572 Mdot
.36472 .30982 Mdot
.49804 .45491 Mdot
.58823 .66273 Mdot
.57646 .67057 Mdot
.58039 .59215 Mdot
.43138 .02749 Mdot
.00396 .17257 Mdot
.37256 .31766 Mdot
.58431 .51765 Mdot
.44706 .50588 Mdot
.55686 .46667 Mdot
.74116 .85487 Mdot
.45491 .03141 Mdot
.00396 .20002 Mdot
.3608 .32158 Mdot
.57646 .47843 Mdot
.4353 .48235 Mdot
.71371 .05102 Mdot
.46667 .77253 Mdot
.5098 .02749 Mdot
.02749 .24708 Mdot
.3255 .29021 Mdot
.54117 .43922 Mdot
.36472 .43922 Mdot
.60391 .35687 Mdot
.60783 .81958 Mdot
.50588 .03141 Mdot
.31766 .41177 Mdot
.4353 .19218 Mdot
.41961 .34903 Mdot
.28629 .33335 Mdot
.57646 .64705 Mdot
.60391 .70194 Mdot
.51765 .03141 Mdot
.34511 .05494 Mdot
.14513 .1216 Mdot
.32943 .28237 Mdot
.4902 .44314 Mdot
.51372 .57254 Mdot
.56862 .13336 Mdot
.55686 .03533 Mdot
.32943 .34119 Mdot
.21179 .34119 Mdot
.34119 .30982 Mdot
.56078 .49412 Mdot
.42746 .48235 Mdot
.70194 .07062 Mdot
.56078 .08239 Mdot
.08239 .40785 Mdot
4e-05 .21963 Mdot
.34119 .13336 Mdot
.54509 .45098 Mdot
.40785 .45098 Mdot
.67842 .6745 Mdot
.6745 .68626 Mdot
.42746 .16865 Mdot
.32943 .45098 Mdot
.48235 .38824 Mdot
.48235 .41569 Mdot
.4902 .4902 Mdot
.50588 .59607 Mdot
.61176 .68234 Mdot
.5647 .44706 Mdot
.05102 .25884 Mdot
.05886 .03533 Mdot
.35687 .3059 Mdot
.44706 .41961 Mdot
.49412 .5647 Mdot
.6941 .06278 Mdot
.44314 .1216 Mdot
.44706 .02357 Mdot
.25492 .35295 Mdot
.35687 .3059 Mdot
.57254 .50588 Mdot
.76861 .87448 Mdot
.68234 .07454 Mdot
.58039 .04709 Mdot
.41961 .12944 Mdot
.11376 .26276 Mdot
.30982 .20787 Mdot
.51372 .40393 Mdot
.44706 .47451 Mdot
.55686 .63528 Mdot
.61176 .03925 Mdot
.28237 .52941 Mdot
.30198 .39217 Mdot
.45098 .13728 Mdot
.47451 .41961 Mdot
.47059 .48628 Mdot
.48235 .58039 Mdot
.59215 .11376 Mdot
.45883 .23924 Mdot
.31374 .07062 Mdot
.25492 .03141 Mdot
.37648 .31766 Mdot
.45098 .43138 Mdot
.53333 .60391 Mdot
.66273 .07454 Mdot
.44706 .31374 Mdot
.44706 .03141 Mdot
.28629 .35687 Mdot
.3255 .28237 Mdot
.49412 .4353 Mdot
.46667 .53333 Mdot
.53333 .29413 Mdot
.04317 .4353 Mdot
.4902 .04709 Mdot
.28629 .3804 Mdot
.31374 .17257 Mdot
.56078 .32158 Mdot
.47843 .52941 Mdot
.6745 .76861 Mdot
.47451 .3608 Mdot
.51765 .03141 Mdot
.28629 .39217 Mdot
.51372 .3059 Mdot
.48235 .40001 Mdot
.45491 .46275 Mdot
.45883 .55294 Mdot
.69802 .0667 Mdot
.41961 .48628 Mdot
.32158 .09807 Mdot
.13336 .10983 Mdot
.33727 .09023 Mdot
.4353 .42746 Mdot
.50196 .58823 Mdot
.68626 .1412 Mdot
.49412 .18826 Mdot
.41569 .37648 Mdot
.251 .34511 Mdot
.33727 .29021 Mdot
.53725 .47451 Mdot
.44314 .50588 Mdot
.70587 .79213 Mdot
.5098 .22355 Mdot
.28629 .3608 Mdot
.28237 .3804 Mdot
.3059 .25492 Mdot
.51372 .41961 Mdot
.44706 .48235 Mdot
.54117 .65097 Mdot
.32943 .61176 Mdot
.42354 .05102 Mdot
.29413 .39217 Mdot
.46275 .23924 Mdot
.40001 .34119 Mdot
.46667 .46667 Mdot
.69018 .78429 Mdot
.62352 .16473 Mdot
.54902 .04317 Mdot
.31374 .20394 Mdot
.24316 .00788 Mdot
.37648 .27845 Mdot
.46667 .45098 Mdot
.52549 .62352 Mdot
.72155 .08631 Mdot
.50588 .65881 Mdot
.44706 .02749 Mdot
.27061 .3608 Mdot
.33727 .06278 Mdot
.54902 .50196 Mdot
.38824 .46275 Mdot
.6392 .47451 Mdot
.51765 .40393 Mdot
.41961 .18826 Mdot
.29806 .40001 Mdot
.3255 .26276 Mdot
.51372 .4353 Mdot
.41569 .45098 Mdot
.55686 .66665 Mdot
.73724 .34119 Mdot
.02357 .30982 Mdot
.251 .37256 Mdot
.37256 .1216 Mdot
.35687 .31766 Mdot
.42354 .45883 Mdot
.70194 .78821 Mdot
.67057 .07062 Mdot
.56862 .04317 Mdot
.41177 .0118 Mdot
.20394 .28629 Mdot
.37648 .32158 Mdot
.55294 .53333 Mdot
.27061 .43922 Mdot
.62352 .11768 Mdot
.74116 .8784 Mdot
.44314 .01572 Mdot
.28237 .36472 Mdot
.34119 .25492 Mdot
.51765 .46275 Mdot
.40393 .48235 Mdot
.54902 .34511 Mdot
.11376 .52157 Mdot
.51372 .03533 Mdot
.27845 .37648 Mdot
.32943 .1961 Mdot
.47451 .42746 Mdot
.42354 .47451 Mdot
.74116 .84311 Mdot
.53333 .21963 Mdot
.52549 .05494 Mdot
.20002 .37648 Mdot
.32943 4e-05 Mdot
.44314 .38824 Mdot
.47059 .45883 Mdot
.50588 .60391 Mdot
.63136 .10199 Mdot
.48628 .21571 Mdot
.40785 .02749 Mdot
.27061 .3608 Mdot
.37256 .32158 Mdot
.52941 .50196 Mdot
.37256 .55686 Mdot
.20002 .38432 Mdot
.749 .87056 Mdot
.26668 .31374 Mdot
.28237 .3804 Mdot
.3059 .25492 Mdot
.40393 .31374 Mdot
.42746 .4902 Mdot
.73332 .72547 Mdot
.71371 .91761 Mdot
.47843 .05102 Mdot
.29021 .39609 Mdot
.34903 .05102 Mdot
.42746 .38824 Mdot
.78037 .83135 Mdot
.70194 .8039 Mdot
.59607 .07062 Mdot
.51765 .04317 Mdot
.00788 .23531 Mdot
.23924 .26668 Mdot
.44314 .14905 Mdot
.54117 .5098 Mdot
.44706 .54117 Mdot
.73332 .52157 Mdot
.74116 .85095 Mdot
.42746 .04709 Mdot
.25492 .35687 Mdot
.36864 .16473 Mdot
.47451 .42354 Mdot
.04317 .35295 Mdot
.56862 .33727 Mdot
.74508 .87056 Mdot
.48628 .72939 Mdot
.28629 .39609 Mdot
.36864 .25492 Mdot
.44706 .41961 Mdot
.41177 .45883 Mdot
.77645 .88624 Mdot
.05886 .44314 Mdot
.15689 .35687 Mdot
.29413 .38824 Mdot
.48235 .05494 Mdot
.46275 .43138 Mdot
.44706 .50588 Mdot
.49412 .58823 Mdot
.59999 .09415 Mdot
.32943 .24708 Mdot
.23139 .45491 Mdot
.24708 .34511 Mdot
.40785 .30198 Mdot
.49804 .47451 Mdot
.64705 .749 Mdot
.10591 .55294 Mdot
.74508 .86272 Mdot
.4902 .59215 Mdot
.27845 .3804 Mdot
.39217 .10199 Mdot
.50196 .18434 Mdot
.0118 .32943 Mdot
.59215 .79606 Mdot
.76076 .86664 Mdot
.44314 .65881 Mdot
.29021 .38824 Mdot
.36864 .1961 Mdot
.47843 .38824 Mdot
.45098 .48235 Mdot
.73332 .84703 Mdot
.03141 .40001 Mdot
.49804 .72939 Mdot
.30982 .42354 Mdot
.26668 .32943 Mdot
.42354 .41569 Mdot
.55294 .54509 Mdot
.60783 .71371 Mdot
.64705 .09023 Mdot
.73332 .8588 Mdot
.48235 .60391 Mdot
.26668 .36472 Mdot
.3804 .36472 Mdot
.48235 .38432 Mdot
.40001 .4902 Mdot
.03925 .47843 Mdot
.75684 .87448 Mdot
.63136 .79606 Mdot
.29021 .39609 Mdot
.34903 .0118 Mdot
.48628 .24316 Mdot
.41961 .47451 Mdot
.77253 .88232 Mdot
.76861 .8784 Mdot
.53333 .76076 Mdot
.31766 .42354 Mdot
.29413 .3059 Mdot
.4353 .18434 Mdot
.54902 .55294 Mdot
.52157 .64705 Mdot
.03925 .47059 Mdot
.71371 .86664 Mdot
.39609 .51765 Mdot
.27845 .37256 Mdot
.38824 .35687 Mdot
.47843 .44314 Mdot
.48628 .58431 Mdot
.59215 .20002 Mdot
.74508 .86272 Mdot
.51765 .66273 Mdot
.29021 .40785 Mdot
.4353 .18042 Mdot
.52157 .49804 Mdot
.05886 .44314 Mdot
.76861 .89017 Mdot
.77253 .88624 Mdot
.23139 .48235 Mdot
.30198 .41569 Mdot
.3608 .02749 Mdot
.47059 .43138 Mdot
.57646 .61176 Mdot
.59607 .6941 Mdot
.78429 .88624 Mdot
.72547 .8588 Mdot
.43138 .55294 Mdot
.27845 .3608 Mdot
.3608 .21179 Mdot
.52941 .52549 Mdot
.76469 .86272 Mdot
.49804 .91369 Mdot
.749 .87056 Mdot
.68234 .8235 Mdot
.29021 .38824 Mdot
.40393 .26668 Mdot
.50196 .45098 Mdot
.49804 .61176 Mdot
.74508 .8784 Mdot
.77645 .88232 Mdot
.41961 .63136 Mdot
.30982 .41177 Mdot
.3804 .07454 Mdot
.47059 .43922 Mdot
.46275 .6392 Mdot
.62352 .73332 Mdot
.78429 .88624 Mdot
.74508 .87448 Mdot
.44706 .57646 Mdot
.251 .34511 Mdot
.40785 .40393 Mdot
.50588 .49412 Mdot
.5098 .63528 Mdot
.50196 .85487 Mdot
.76469 .88232 Mdot
.56078 .6941 Mdot
.29021 .39217 Mdot
.38824 .1216 Mdot
.47843 .34511 Mdot
.52941 .64705 Mdot
.56862 .90977 Mdot
.78037 .88624 Mdot
.38824 .64705 Mdot
.3255 .4353 Mdot
.36472 .09023 Mdot
.55294 .251 Mdot
.00788 .46667 Mdot
.91369 .99996 Mdot
.8039 .90193 Mdot
.749 .90193 Mdot
.48235 .61176 Mdot
.27845 .35687 Mdot
.45491 .40001 Mdot
.55294 .57254 Mdot
.76469 .86664 Mdot
.87448 .94506 Mdot
.76469 .89801 Mdot
.69802 .81958 Mdot
.29021 .39217 Mdot
.37648 .35295 Mdot
.50588 .45098 Mdot
.67842 .81566 Mdot
.8235 .94506 Mdot
.79213 .89801 Mdot
.52157 .72155 Mdot
.3608 .46667 Mdot
.34511 .06278 Mdot
.55686 .3059 Mdot
4e-05 .52157 Mdot
.98035 .99996 Mdot
.81566 .91369 Mdot
.67842 .86272 Mdot
.60783 .69802 Mdot
.29413 .36472 Mdot
.50196 .32943 Mdot
.52157 .56078 Mdot
.92546 .96467 Mdot
.8588 .95291 Mdot
.76076 .88232 Mdot
.65097 .79998 Mdot
.33335 .42746 Mdot
.40001 .34119 Mdot
.54117 .50588 Mdot
.83527 .89801 Mdot
.75292 .9882 Mdot
.74116 .88624 Mdot
.17257 .4902 Mdot
.3804 .49412 Mdot
.34511 .11768 Mdot
.53725 .22355 Mdot
.00788 .6392 Mdot
.92938 .95683 Mdot
.76076 .89017 Mdot
.71371 .87056 Mdot
.52549 .64705 Mdot
.32943 .38824 Mdot
.42746 .34119 Mdot
.63136 .65489 Mdot
.98035 .99996 Mdot
.79213 .90977 Mdot
.74508 .87448 Mdot
.37648 .52941 Mdot
.36472 .46275 Mdot
.38824 .1216 Mdot
.59215 .59215 Mdot
.84311 .91369 Mdot
.74116 .9882 Mdot
.749 .8784 Mdot
.28629 .54902 Mdot
.35295 .46667 Mdot
.34119 .12552 Mdot
.50196 .23924 Mdot
.00788 .69802 Mdot
.39217 .65489 Mdot
.77253 .89017 Mdot
.71763 .89017 Mdot
.41961 .54509 Mdot
.34903 .42746 Mdot
.44706 .10983 Mdot
.76076 .77645 Mdot
.68234 .82743 Mdot
.79213 .90193 Mdot
.64705 .97643 Mdot
.42746 .65489 Mdot
.32158 .43138 Mdot
.42746 .18042 Mdot
.76076 .65097 Mdot
.75292 .85095 Mdot
.61176 .92546 Mdot
.32158 .92938 Mdot
.1216 .63528 Mdot
.40393 .52157 Mdot
.33727 .12944 Mdot
.49804 .22355 Mdot
.02357 .61176 Mdot
.74116 .89409 Mdot
.1961 .90977 Mdot
.07846 .60391 Mdot
.20002 .54509 Mdot
.51765 .6196 Mdot
.43138 .251 Mdot
.70194 .72155 Mdot
.78037 .88624 Mdot
.32943 .94506 Mdot
.43138 .5098 Mdot
.13728 .41177 Mdot
.3059 .40785 Mdot
.39609 .13336 Mdot
.71371 .65489 Mdot
.76861 .8784 Mdot
.28629 .94114 Mdot
.14905 .91369 Mdot
.55686 .18042 Mdot
.03141 .38824 Mdot
.3255 .02749 Mdot
.62744 .25884 Mdot
.02357 .41177 Mdot
.31374 .93722 Mdot
.0667 .99996 Mdot
.6392 .08631 Mdot
.38824 .18042 Mdot
.50588 .62352 Mdot
.55686 .41569 Mdot
.60391 .65097 Mdot
.23139 .8784 Mdot
.35687 .99996 Mdot
.68626 .09415 Mdot
.5098 .08239 Mdot
.1961 .47059 Mdot
.41569 .26276 Mdot
.62352 .62744 Mdot
.3608 .86272 Mdot
.40001 .99212 Mdot
.65881 .20394 Mdot
.5647 .3804 Mdot
.39609 .16081 Mdot
.36472 .03141 Mdot
.56078 .57254 Mdot
.33727 .78821 Mdot
.04709 .99604 Mdot
.41569 .48235 Mdot
.72939 .55686 Mdot
.44314 .02357 Mdot
.34119 .3255 Mdot
.51765 .5098 Mdot
.50588 .74116 Mdot
.02357 .98035 Mdot
.62352 .44706 Mdot
.59999 .52157 Mdot
.70587 .59607 Mdot
.0667 .45883 Mdot
.47451 .28237 Mdot
.59999 .67842 Mdot
.01572 .97251 Mdot
.68626 .47843 Mdot
.76861 .10591 Mdot
.60783 .62744 Mdot
.48235 .05886 Mdot
.33335 .1765 Mdot
.61568 .60391 Mdot
.0118 .84311 Mdot
.69802 .52549 Mdot
.45491 .67842 Mdot
.63136 .64705 Mdot
.4353 .1765 Mdot
.44314 .1765 Mdot
.50588 .50196 Mdot
.0118 .73332 Mdot
.56862 .54117 Mdot
.03141 .99604 Mdot
.75684 .67057 Mdot
.43922 .0118 Mdot
.3255 .07454 Mdot
.45491 .43922 Mdot
.02749 .6941 Mdot
.4353 .4902 Mdot
.02749 .94898 Mdot
.59215 .45491 Mdot
.40001 .36864 Mdot
.52941 .18042 Mdot
.40393 .40393 Mdot
.00788 .65881 Mdot
.47059 .45098 Mdot
.03533 .9333 Mdot
.75684 .09807 Mdot
.51372 .29021 Mdot
.70194 .63136 Mdot
.46667 .4353 Mdot
.00396 .61176 Mdot
.00788 .52157 Mdot
.00788 .9333 Mdot
.76469 .26668 Mdot
.65097 .20394 Mdot
.54509 .45883 Mdot
.57254 .33335 Mdot
.00788 .58039 Mdot
.32158 .45883 Mdot
4e-05 .92154 Mdot
.00396 .95291 Mdot
.749 .09807 Mdot
.67842 .4902 Mdot
.52549 .21179 Mdot
.00396 .47451 Mdot
.21963 .3059 Mdot
4e-05 .89017 Mdot
.03533 .99604 Mdot
.77645 .10983 Mdot
.52549 .04709 Mdot
.04709 .09023 Mdot
.09807 .38824 Mdot
.32943 .33727 Mdot
4e-05 .83527 Mdot
.33727 .99996 Mdot
.78037 .12552 Mdot
.53333 .03141 Mdot
.59215 .23924 Mdot
.39217 .47843 Mdot
.42746 .29806 Mdot
4e-05 .79213 Mdot
.54509 .98035 Mdot
.74508 .14905 Mdot
.59999 .06278 Mdot
.58823 .50196 Mdot
.4353 .40393 Mdot
.44314 .25884 Mdot
4e-05 .70979 Mdot
.24708 .89409 Mdot
.47059 .38824 Mdot
.50588 .18826 Mdot
.56078 .10591 Mdot
.4353 .39609 Mdot
.28237 .34903 Mdot
.01965 .76861 Mdot
.03141 .96075 Mdot
.09023 .68626 Mdot
.20002 .41177 Mdot
.58039 .06278 Mdot
.43138 .36864 Mdot
.11376 .4353 Mdot
.00396 .79213 Mdot
.00788 .97251 Mdot
.00396 .76076 Mdot
.02357 .58431 Mdot
.55294 .05886 Mdot
.43922 .30982 Mdot
.07454 .41961 Mdot
.05494 .95291 Mdot
4e-05 .9333 Mdot
.0118 .76861 Mdot
.00788 .62352 Mdot
.35295 .1412 Mdot
.41177 .25884 Mdot
.05494 .41961 Mdot
.01965 .81958 Mdot
.00396 .88624 Mdot
.01965 .72547 Mdot
.05886 .53333 Mdot
.05886 .40393 Mdot
.41177 .24708 Mdot
.0118 .45098 Mdot
.0118 .78037 Mdot
.00396 .86664 Mdot
.16865 .61176 Mdot
.35295 .57646 Mdot
.00396 .47451 Mdot
.41961 .23139 Mdot
.00396 .4902 Mdot
4e-05 .749 Mdot
.00396 .83135 Mdot
.40785 .57646 Mdot
.6196 .70979 Mdot
.03533 .39609 Mdot
.47843 .17257 Mdot
.0118 .51765 Mdot
.0118 .78429 Mdot
.02749 .76861 Mdot
.51372 .60391 Mdot
.70587 .77253 Mdot
.21963 .40001 Mdot
.49804 .1216 Mdot
.00788 .54509 Mdot
.00788 .73332 Mdot
.18042 .62744 Mdot
.60783 .6745 Mdot
.72155 .80782 Mdot
.25884 .37256 Mdot
.35295 .07454 Mdot
.00396 .55686 Mdot
.01572 .71371 Mdot
.43922 .57254 Mdot
.85095 .88232 Mdot
.46275 .52549 Mdot
.23531 .34903 Mdot
.03141 .12944 Mdot
.00396 .58039 Mdot
.00396 .61568 Mdot
.51765 .59215 Mdot
.58823 .58823 Mdot
.47059 .37648 Mdot
.23924 .31766 Mdot
.00788 .21571 Mdot
.00396 .58823 Mdot
.07846 .51765 Mdot
.74116 .78821 Mdot
.52157 .40393 Mdot
.46275 .29021 Mdot
.25492 .29806 Mdot
.24708 .09023 Mdot
.00396 .59215 Mdot
.43138 .53333 Mdot
.56078 .58039 Mdot
.45491 .3059 Mdot
.40393 .28629 Mdot
.25492 .28629 Mdot
.00788 .36864 Mdot
4e-05 .62352 Mdot
.53725 .59999 Mdot
.48235 .37256 Mdot
.37648 .24316 Mdot
.38432 .30982 Mdot
.20394 .251 Mdot
.00396 .52157 Mdot
.10591 .52549 Mdot
.56862 .63136 Mdot
.40393 .29021 Mdot
.37648 .25884 Mdot
.36472 .28629 Mdot
.14513 .20394 Mdot
.00396 .47843 Mdot
.4902 .57646 Mdot
.41177 .27845 Mdot
.40393 .26276 Mdot
.36472 .25492 Mdot
.35295 .25884 Mdot
.22747 .03533 Mdot
.00396 .53333 Mdot
.6941 .749 Mdot
.42354 .28629 Mdot
.37648 .251 Mdot
.39609 .29413 Mdot
.33727 .251 Mdot
.01965 .15689 Mdot
.03925 .43138 Mdot
.41569 .3804 Mdot
.43138 .31766 Mdot
.38824 .251 Mdot
.37256 .29021 Mdot
.28237 .27845 Mdot
.00396 .45098 Mdot
.4902 .5647 Mdot
.48235 .38432 Mdot
.43138 .33335 Mdot
.3804 .251 Mdot
.3608 .27453 Mdot
.1961 .20002 Mdot
4e-05 .49412 Mdot
.6392 .6941 Mdot
.50588 .46275 Mdot
.40785 .32943 Mdot
.34511 .23531 Mdot
.39217 .33335 Mdot
.30198 .24316 Mdot
.02357 .42354 Mdot
.52549 .45491 Mdot
.55686 .49412 Mdot
.35687 .31374 Mdot
.34903 .27453 Mdot
.34511 .28629 Mdot
.23531 .02749 Mdot
.60783 .64313 Mdot
.58039 .59607 Mdot
.4353 .39609 Mdot
.34903 .34903 Mdot
.35687 .3804 Mdot
.28237 .3059 Mdot
4e-05 .52549 Mdot
.34511 .31374 Mdot
.44314 .39217 Mdot
.45098 .48235 Mdot
.24316 .32158 Mdot
.34903 .32158 Mdot
.34903 .36472 Mdot
.12944 .43138 Mdot
.42746 .28629 Mdot
.43138 .31766 Mdot
.10983 .21571 Mdot
.19218 .24316 Mdot
.40785 .38432 Mdot
.35687 .29806 Mdot
.5098 .54902 Mdot
.4353 .25492 Mdot
.42354 .41961 Mdot
.23139 .3059 Mdot
.12552 .18042 Mdot
.26668 .3059 Mdot
.03533 .6196 Mdot
.43922 .30982 Mdot
.46667 .29021 Mdot
.3255 .40001 Mdot
.34511 .33335 Mdot
.36472 .3608 Mdot
.38432 .40785 Mdot
.44706 .42746 Mdot
.43922 .27453 Mdot
.36864 .33335 Mdot
.56078 .47059 Mdot
.4902 .33335 Mdot
.34119 .32158 Mdot
.18826 .04709 Mdot
.44706 .28629 Mdot
.45491 .25884 Mdot
.6196 .6941 Mdot
.52941 .26668 Mdot
.38824 .3059 Mdot
.4353 .46667 Mdot
.37648 .31766 Mdot
.43138 .29021 Mdot
.40785 .31374 Mdot
.54117 .43922 Mdot
.42354 .26276 Mdot
.3608 .40001 Mdot
.43922 .1765 Mdot
.45491 .28237 Mdot
.42354 .27453 Mdot
.45883 .39217 Mdot
.3804 .251 Mdot
.43922 .3255 Mdot
.46275 .52549 Mdot
.30198 .16865 Mdot
.44314 .27061 Mdot
.73332 .76469 Mdot
.27845 .33335 Mdot
.37256 .3804 Mdot
.52549 .59215 Mdot
.35295 .18826 Mdot
.4353 .29806 Mdot
.45098 .21963 Mdot
.42354 .40393 Mdot
.42354 .43922 Mdot
.54902 .61568 Mdot
.40785 .27845 Mdot
.40001 .14513 Mdot
.42354 .1961 Mdot
.47059 .38824 Mdot
.44314 .37256 Mdot
.50196 .46667 Mdot
.52941 .59607 Mdot
.31766 .27845 Mdot
.46275 .33727 Mdot
.42354 .23531 Mdot
.59607 .64313 Mdot
.45883 .41177 Mdot
.67057 .71763 Mdot
.18434 .16473 Mdot
.43138 .28629 Mdot
.48235 .3608 Mdot
.57254 .57254 Mdot
.49412 .52157 Mdot
.75292 .79606 Mdot
.43922 .19218 Mdot
.41569 .29413 Mdot
.45883 .32158 Mdot
.59607 .42354 Mdot
.67842 .6392 Mdot
.87056 .89409 Mdot
.46667 .07846 Mdot
.40001 .32943 Mdot
.46667 .34511 Mdot
.54117 .29806 Mdot
.65097 .48628 Mdot
.90193 .93722 Mdot
.4902 .09023 Mdot
.3804 .33335 Mdot
.47059 .36864 Mdot
.57646 .42746 Mdot
.91761 .81566 Mdot
.81958 .89017 Mdot
.36472 .1961 Mdot
.35687 .32158 Mdot
.45098 .37648 Mdot
.60783 .55294 Mdot
.99604 .9882 Mdot
.78037 .84703 Mdot
.24708 .30198 Mdot
.43922 .43922 Mdot
.4902 .45098 Mdot
.87056 .84703 Mdot
.98428 .99604 Mdot
.69802 .74116 Mdot
.37256 .38824 Mdot
.42746 .42746 Mdot
.57646 .56078 Mdot
.99212 .99212 Mdot
.83527 .89409 Mdot
.42354 .16473 Mdot
.36472 .3608 Mdot
.50588 .55294 Mdot
.99604 .99212 Mdot
.8784 .90977 Mdot
.75292 .78037 Mdot
.40393 .43138 Mdot
.52157 .58431 Mdot
.99212 .99212 Mdot
.95291 .98035 Mdot
.77253 .82743 Mdot
.36864 .41569 Mdot
.51765 .55294 Mdot
.86664 .92154 Mdot
.97251 .98035 Mdot
.79606 .84311 Mdot
.35295 .38824 Mdot
.52941 .59215 Mdot
.8588 .90585 Mdot
.90585 .92938 Mdot
.79998 .84703 Mdot
.40001 .43138 Mdot
.59999 .66273 Mdot
.98035 .99212 Mdot
.89409 .92938 Mdot
.60783 .44314 Mdot
.47843 .51372 Mdot
.84311 .90585 Mdot
.9333 .96075 Mdot
.81566 .85487 Mdot
.42354 .43922 Mdot
.68626 .74508 Mdot
.94114 .96467 Mdot
.85487 .89017 Mdot
.41961 .25492 Mdot
.65881 .72547 Mdot
.91369 .93722 Mdot
.89801 .90977 Mdot
.46667 .41569 Mdot
.77645 .83919 Mdot
.89801 .92938 Mdot
.34119 .18826 Mdot
.61176 .68626 Mdot
.90977 .94114 Mdot
.3608 .20787 Mdot
.67057 .6745 Mdot
.74116 .59607 Mdot
.60391 .32158 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol00000oomo0?ooO`020?mo00030?ooO`3oO`00ogl001D0
ogl00P1ooolD0?mo000307ooo`3oO`00ogl000L0ogl00`1oool90?mo000307ooo`3oO`00ogl000L0
ogl00P2P8?060?mo0080Oooo0P2P8?000`3oO`00Oooo0?mo00060?mo00<0Oooo0P3oO`0607ooo`<0
ogl01`1oool50?mo00<0Oooo0P3oO`0707ooo`@0ogl00P1oool20?mo0080Oooo1@3oO`0H07ooo`80
ogl0I`1oool1o`00007ooooo00000ol00000oomo0?ooO`040?ooO`h0ogl000<0Oooo0?mo003oO`00
1`3oO`000`1oool0ogl00?mo000A0?mo000307ooo`3oO`00ogl000L0ogl00P1oool50?mo0080X23`
0`3oO`000`1oool0ogl00?mo00070?mo0080X23`0P3oO`0207ooo`L0ogl000<0Oooo0?mo003oO`00
1@3oO`0207ooo`<0ogl0101oool70?mo00D0Oooo1`3oO`000`1oool0ogl00?mo00030?mo000407oo
o`3oO`00ogl007ooo`80X23`1`3oO`000`1oool0ogl00?mo00050?mo00d0Oooo0P3oO`0707ooo`80
ogl0I`1oool1o`00007ooooo00000ol00000oomo0?ooO`060?ooO`80ogl00P3oogl20?mo0080Oooo
0P3oO`0807ooo`@0ogl000@0Oooo0?mo003oO`00Oooo3`3oO`0207ooo`T0ogl000<0Oooo0?mo003o
O`00103oO`020:0Pl080ogl00P1ooolF0?mo0080Oooo00@0ogl00:0Pl02P8?00ogl0101oool20?mo
000307ooo`3oO`00ogl00080Oooo0P3oO`001@1oool0ogl00:0Pl02P8?00ogl000@0Oooo00<0ogl0
0:0Pl02P8?001@3oO`000`1oool0ogl00?mo00060?mo000307ooo`2P8?00X23`00L0ogl000@0Oooo
0?mo003oO`00ogl00P1oool20?mo00<0Oooo0P3oO`0207ooo`80ogl0101oool20?mo00X0Oooo0P3o
O`0:07ooo`80X23`F01oool1o`00007ooooo00000ol00000oomo0?ooO`060?ooO`80ogl00`3oogl2
o`0000/0Oooo0P3oO`0807ooo`P0ogl00P1oool20?mo00D0Oooo1@3oO`0307ooo`@0ogl00P1oool2
0?mo0080Oooo0P3oO`0207ooo`D0ogl00`1oool00`3oO`00X23`0:0Pl0030?mo000307ooo`3oO`00
ogl000<0ogl000<0Oooo0?mo003oO`000P2P8?030?mo0080X23`0`1oool20?mo0080X23`0`1oool0
103oO`00X23`0:0Pl03oO`0207ooo`80X23`00@0ogl00:0Pl02P8?00X23`103oO`000`1oool0ogl0
0?mo000G0?mo00@0Oooo1P3oO`0707ooo`80ogl01`1oool20?mo00X0Oooo0P2P8?1H07ooo`7o0000
0Oooool00003o`00003oogl0oomo00d0oomo0_l0000C07ooo`80ogl000<0Oooo0?mo003oO`000`3o
O`0207ooo`80ogl0201oool20?mo00@0Oooo0`3oO`0207ooo`80ogl00P1oool20?mo0080Oooo0P3o
O`00101oool0ogl00?mo003oO`0207ooo`050?mo002P8?00X23`0?mo001oool00P3oO`0607ooo`L0
ogl00P2P8?0207ooo`<0ogl00P2P8?000`3oO`00Oooo07ooo`040?mo000607ooo`3oO`00X23`0:0P
l01oool0ogl00P2P8?040?mo00<0Oooo0P3oO`0207oooad0ogl01@1oool40?mo00P0Oooo0P3oO`0;
07ooo`80ogl0EP1oool1o`00007ooooo00000ol00000oomo0?ooO`0?0?ooO`;o0000301oool20?mo
0080Oooo0P3oO`0507ooo`H0ogl03@1oool60?mo00/0Oooo0`3oO`0407ooo`80ogl000<0Oooo0?mo
003oO`000`1oool20?mo0080Oooo4@3oO`0207ooo`80ogl000<0Oooo0?mo003oO`000P3oO`000`1o
ool0ogl00:0Pl0020:0Pl0@0ogl000D0Oooo0?mo003oO`00ogl007ooo`030?mo000307ooo`3oO`00
ogl000D0ogl00P2P8?040?mo0080X23`1P3oO`020:0Pl0<0ogl000D0Oooo0?mo003oO`00ogl007oo
o`030?mo0080Oooo1P3oO`000`1oool0ogl00?mo00020:0Pl0D0ogl00`1oool20:0Pl0030?mo001o
ool0Oooo05@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl04@3oogl00ol00000Oooo07ooo`09
07ooo`80ogl00P1oool20?mo00D0Oooo103oO`0?07ooo`80ogl000@0Oooo0?mo002P8?00X23`2@1o
ool40?mo00/0Oooo0P2P8?030?mo000307ooo`3oO`00ogl00080ogl00P2P8?040?mo0080X23`1@3o
O`000`1oool0X23`0:0Pl0040?mo0080X23`00<0Oooo0?mo002P8?000P2P8?040?mo000307ooo`3o
O`00ogl000T0ogl00P2P8?020?mo0080X23`103oO`020:0Pl0H0ogl00P2P8?030?mo000407ooo`2P
8?00X23`0:0Pl080ogl00P2P8?060?mo0080X23`00<0Oooo0?mo003oO`000P2P8?050?mo00<0Oooo
0P2P8?00101oool0X23`0:0Pl03oO`1C07ooo`7o00000Oooool00003o`00003oogl0oomo0180oomo
0_l0000[07ooo`80X23`2@1oool20?mo00d0Oooo0P2P8?000`1oool0ogl00?mo000507ooo`80X23`
0`1oool00`3oO`00X23`0:0Pl0040?mo0080Oooo0P2P8?020?mo000407ooo`3oO`00X23`0:0Pl0<0
Oooo0P2P8?0507ooo`/0ogl00P2P8?040?mo000307ooo`3oO`00ogl000d0ogl00P1oool30:0Pl080
ogl00P2P8?020?mo000407ooo`3oO`00ogl00?mo0080X23`00<0Oooo0?mo003oO`002P1oool20?mo
000407ooo`2P8?00X23`0?mo05<0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0503oogl2o`00
0080ogl01`1oool20?mo0140Oooo0`3oO`0307ooo`80ogl02`1oool20:0Pl0X0Oooo0P3oO`0407oo
o`80ogl000<0Oooo0?mo003oO`00101oool20?mo0080Oooo0P2P8?00101oool0ogl00?mo001oool4
0?mo00T0Oooo0P3oO`0207ooo`030?mo002P8?00X23`0080X23`1P1oool70?mo0080X23`00@0ogl0
0:0Pl02P8?00X23`0P3oO`020:0Pl080ogl00P2P8?00103oO`00Oooo0?mo003oO`020:0Pl0030?mo
001oool0Oooo00<0Oooo0`3oO`0207ooo`80ogl00P1oool20?mo000307ooo`2P8?00X23`0080ogl0
0`1oool40:0Pl00307ooo`3oO`00ogl000H0Oooo0P2P8?0207ooo`<0ogl0C@1oool1o`00007ooooo
00000ol00000oomo0?ooO`050?ooO`80ogl01P3oogl20:0Pl080oomo0P3oO`030?ooO`80ogl01`1o
ool20?mo00L0Oooo0P3oO`0807ooo`<0ogl00`1oool20?mo00<0Oooo0P2P8?0207ooo`80ogl00P1o
ool20:0Pl0X0Oooo0P3oO`0407ooo`80ogl000<0Oooo0?mo003oO`00101oool20?mo0080Oooo0P2P
8?00101oool0ogl00?mo001oool50?mo00P0Oooo0P3oO`0207ooo`030?mo002P8?00X23`0080X23`
0P3oO`0207ooo`L0ogl02@2P8?000`3oO`00X23`0:0Pl0020?mo00@0X23`0P3oO`020:0Pl0030?mo
001oool0ogl00080ogl000@0Oooo0:0Pl02P8?00ogl00P1oool20?mo000307ooo`3oO`00ogl00080
ogl03@2P8?050?mo000307ooo`2P8?00X23`0080X23`00<0Oooo0?mo003oO`000`3oO`000`1oool0
ogl00?mo000207ooo`@0ogl00`1oool30?mo03`0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
1@3oogl20?mo00H0oomo0P2P8?020?ooO`80ogl0103oogl2o`0000l0Oooo0P3oO`0C07ooo`80X23`
1P3oO`0<07ooo`80ogl03@1oool20?mo0080Oooo0P3oO`0707ooo`80ogl00`1oool30?mo00L0Oooo
3P3oO`000`1oool0X23`0:0Pl0020?mo0080X23`00<0ogl00:0Pl02P8?001`3oO`020:0Pl0X0ogl0
0P2P8?001P3oO`00Oooo0:0Pl02P8?00ogl007ooo`80ogl00`2P8?000`3oO`00X23`0:0Pl0050:0P
l00407ooo`3oO`00X23`0:0Pl0H0ogl01P2P8?001@3oO`00X23`0:0Pl03oO`00Oooo0080ogl00P1o
ool40?mo00<0Oooo103oO`000`1oool0ogl00?mo000207ooo`80ogl0=01oool1o`00007ooooo0000
0ol00000oomo0?ooO`0I0?ooO`04o`00001oool0ogl00?mo01@0Oooo0P3oO`0<07ooo`80ogl00P1o
ool20?mo00`0Oooo0P3oO`0=07ooo`<0ogl000<0Oooo0?mo003oO`00301oool30?mo0080Oooo0P3o
O`0307oooa<0ogl00`2P8?000`3oO`00Oooo0?mo00030?mo000307ooo`2P8?00X23`0080X23`0P3o
O`040:0Pl0@0ogl00P2P8?001@3oO`00X23`0:0Pl02P8?00ogl00080Oooo00<0ogl00:0Pl02P8?00
0P2P8?020?mo000307ooo`3oO`00ogl00080X23`00L0Oooo0?mo002P8?00X23`0?mo001oool0ogl0
0080X23`0`3oO`040:0Pl0030?mo002P8?00X23`00X0ogl000<0Oooo0?mo003oO`00103oO`001@1o
ool0ogl00?mo003oO`00Oooo00@0ogl02`1oool20?mo02D0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl04`3oogl20?mo0080oomo0P3oO`00103oogoo00000?mo003oO`0407ooo`80ogl01P1oool2
0?mo00H0Oooo00<0ogl00:0Pl02P8?003`1oool20?mo00L0Oooo0P3oO`0A07ooo`@0ogl0401oool2
0?mo000407ooo`2P8?00X23`0?mo00@0Oooo0P3oO`00101oool0ogl00?mo001oool30?mo00@0X23`
1P3oO`040:0Pl0D0Oooo102P8?0207ooo`D0X23`0P3oO`030:0Pl0030?mo002P8?00X23`0080X23`
0P1oool30?mo0080X23`0P3oO`00101oool0ogl00?mo003oO`020:0Pl080Oooo0P3oO`050:0Pl003
0?mo002P8?00X23`00<0X23`403oO`0307ooo`80ogl000<0Oooo0?mo003oO`000`1oool20?mo00/0
Oooo0P3oO`0U07ooo`7o00000Oooool00003o`00003oogl0oomo00T0oomo0P3oO`080?ooO`80ogl0
0P3oogl20?mo00<0X23`00<0ogl00:0Pl02P8?000P1oool20?mo00H0Oooo0P3oO`0707ooo`80X23`
3`1oool20?mo00L0Oooo0P3oO`0;07ooo`80ogl00`1oool20?mo0080X23`00<0ogl007ooo`1oool0
0P3oO`0407ooo`@0ogl01P1oool30:0Pl0D0Oooo0P3oO`0407ooo`80ogl01@2P8?0207ooo`<0ogl0
0`1oool20:0Pl080ogl0101oool20?mo000307ooo`3oO`00ogl000<0ogl00P2P8?0207ooo`80X23`
00<0ogl007ooo`1oool00`2P8?000`1oool0ogl00?mo00060?mo0080Oooo00<0ogl00:0Pl02P8?00
102P8?00101oool0X23`0:0Pl03oO`060:0Pl080Oooo0P3oO`001@1oool0ogl00?mo003oO`00Oooo
00<0ogl00P2P8?030?mo00@0Oooo0P3oO`020:0Pl0H0Oooo0P3oO`0407ooo`80ogl0:P1oool1o`00
007ooooo00000ol00000oomo0?ooO`090?ooO`80ogl0303oogl20?mo00<0X23`00<0ogl00:0Pl02P
8?00401oool20?mo0240Oooo0P3oO`0507ooo`80ogl00`1oool01@3oO`00X23`0:0Pl02P8?00ogl0
0080Oooo0P3oO`0307ooo`D0ogl01P1oool20:0Pl0030?mo001oool0Oooo00/0Oooo102P8?0307oo
o`D0ogl000<0Oooo0:0Pl02P8?000P2P8?000`3oO`00Oooo07ooo`0207ooo`80X23`1P3oO`0307oo
o`D0ogl00P2P8?000`3oO`00Oooo0?mo00080?mo0080Oooo1P2P8?000`3oO`00X23`0:0Pl0020?mo
00D0X23`00<0Oooo0:0Pl02P8?00103oO`0407ooo`030?mo002P8?00X23`00@0Oooo0P2P8?0307oo
o`80X23`0P1oool60?mo00@0Oooo0P3oO`0Z07ooo`7o00000Oooool00003o`00003oogl0oomo01l0
oomo00?o000007ooo`1oool03@1oool20?mo01H0Oooo0P3oO`0907ooo`80ogl02`1oool20:0Pl0T0
Oooo0P3oO`0:07ooo`80ogl02`1oool20?mo000407ooo`2P8?00X23`0:0Pl0<0Oooo0P3oO`000`1o
ool0ogl00?mo00050:0Pl0030?mo001oool0X23`00@0X23`101oool20:0Pl0<0Oooo1@3oO`000`1o
ool0ogl00?mo000207ooo`P0ogl000<0Oooo0?mo003oO`001P3oO`070:0Pl080ogl00`2P8?020?mo
00H0Oooo0P3oO`0507ooo`80X23`00<0ogl007ooo`1oool0101oool0103oO`00X23`0:0Pl03oO`03
07ooo`80X23`00<0Oooo0?mo003oO`00:P1oool1o`00007ooooo00000ol00000oomo0?ooO`0P0?oo
O`;o00009@1oool20?mo03X0Oooo0P3oO`000`1oool0X23`0:0Pl00907ooo`80X23`1@1oool40:0P
l0D0Oooo0P2P8?0307ooo`@0ogl00P1oool20?mo00P0Oooo0P3oO`000`1oool0ogl00?mo00020?mo
000407ooo`3oO`00ogl007ooo`80ogl01@2P8?020?mo0080X23`4@1oool20?mo00L0Oooo0P2P8?00
103oO`00Oooo07ooo`1oool20:0Pl00307ooo`3oO`00ogl002X0Oooo0Ol00001ooooo`0000?o0000
0?ooO`3oogl06`3oogl20?mo00D0oomo00?o000007ooo`1oool04@1oool20?mo0140Oooo0P3oO`0A
07ooo`80X23`00<0Oooo0:0Pl02P8?001`1oool20?mo0140Oooo0P3oO`0807ooo`80ogl02@1oool0
0`3oO`00X23`0:0Pl00:07ooo`80X23`0`1oool20:0Pl0@0Oooo0P2P8?020?mo00D0Oooo103oO`08
07ooo`@0X23`00@0Oooo0?mo002P8?00X23`1@1oool20?mo00<0Oooo0P3oO`1:07ooo`7o00000Ooo
ool00003o`00003oogl0oomo01/0oomo0P3oO`060?ooO`;o000000<0Oooo0?mo003oO`003P1oool2
0?mo0140Oooo0P3oO`0A07ooo`80X23`00<0Oooo0:0Pl02P8?001`1oool00`3oO`00X23`0:0Pl002
07ooo`80ogl0201oool20:0Pl080Oooo0P3oO`0707ooo`<0ogl02@1oool0103oO`00X23`0:0Pl01o
ool20:0Pl0<0Oooo0P3oO`0207ooo`L0X23`0P3oO`0207ooo`80X23`103oO`0307ooo`@0ogl000<0
Oooo0?mo003oO`000P3oO`000`1oool0ogl00?mo00040:0Pl00307ooo`2P8?00X23`0080X23`203o
O`00101oool0ogl00?mo003oO`0207ooo`80ogl03`1oool20:0Pl00307ooo`2P8?00X23`0340Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl03`3oogl20?mo00X0oomo0P3oO`080?ooO`03o`00003o
O`00ogl002h0Oooo0P2P8?0A07ooo`80X23`0P1oool20?mo00P0Oooo0P2P8?0307ooo`80ogl01P1o
ool20?mo00D0Oooo0P3oO`0307ooo`80X23`0P1oool20:0Pl0<0Oooo0P3oO`0207ooo`80ogl0102P
8?030?mo000407ooo`2P8?00X23`07ooo`@0ogl00`1oool20?mo00<0Oooo103oO`001@1oool0ogl0
0:0Pl02P8?00Oooo0080ogl000<0Oooo0:0Pl02P8?000`2P8?030?mo000507ooo`2P8?00X23`0?mo
001oool00`3oO`0207ooo`80ogl02P1oool20?mo00<0Oooo0P2P8?000`1oool0X23`0:0Pl00a07oo
o`7o00000Oooool00003o`00003oogl0oomo00l0oomo0P3oO`0E0?ooO`;o0000601oool20?mo01@0
Oooo0P2P8?000`1oool0X23`0:0Pl00607ooo`80X23`0P3oO`0407ooo`80X23`0P1oool20?mo00L0
Oooo0P2P8?0407ooo`80ogl01P1oool20:0Pl0D0Oooo0P3oO`0307ooo`80X23`0P1oool20?mo00@0
Oooo0P2P8?0407ooo`@0ogl00P1oool0103oO`00X23`0:0Pl01oool20?mo00<0Oooo103oO`0707oo
o`@0X23`00<0ogl00:0Pl02P8?000`1oool00`3oO`00X23`0:0Pl0020:0Pl0040?mo001oool0X23`
0:0Pl0D0ogl00P1oool60?mo00H0Oooo0P3oO`0607ooo`80ogl0<@1oool1o`00007ooooo00000ol0
0000oomo0?ooO`0X0?ooO`03o`00001oool0Oooo01D0Oooo0P3oO`0G07ooo`80X23`1P1oool20:0P
l080ogl0101oool20:0Pl080Oooo103oO`020:0Pl00307ooo`3oO`00ogl00080X23`1@1oool20:0P
l0<0Oooo1@2P8?0207ooo`80ogl03@1oool0103oO`00X23`0:0Pl02P8?0607ooo`80X23`00<0ogl0
07ooo`3oO`000P2P8?020?mo00@0Oooo0P3oO`020:0Pl0L0Oooo0P2P8?0207ooo`030?mo002P8?00
X23`00<0Oooo0`3oO`020:0Pl0040?mo001oool0X23`0:0Pl0D0ogl000<0Oooo0?mo003oO`001@3o
O`1107ooo`7o00000Oooool00003o`00003oogl0oomo0280oomo0P3oO`050?ooO`;o00000`1oool2
0?mo0280Oooo0P2P8?0607ooo`80X23`0`1oool20?mo00<0Oooo0P3oO`0807ooo`<0ogl00P2P8?00
101oool0ogl00?mo001oool20?mo00@0Oooo0P2P8?0307ooo`80X23`00D0Oooo0:0Pl02P8?00ogl0
07ooo`020?mo00<0Oooo0P2P8?0807ooo`050?mo002P8?00X23`0?mo001oool00`2P8?001P1oool0
X23`0:0Pl02P8?00ogl007ooo`80X23`00<0Oooo0?mo003oO`00101oool20?mo0080X23`201oool2
0:0Pl0H0Oooo0P2P8?000`1oool0ogl00?mo00020?mo000407ooo`2P8?00X23`07ooo`80ogl00`1o
ool50?mo00@0Oooo0P2P8?0207ooo`80ogl000<0Oooo0?mo003oO`00=P1oool1o`00007ooooo0000
0ol00000oomo0?ooO`0=0?ooO`80ogl04`3oogl20?mo00L0oomo0_l000000`1oool0ogl00?mo000R
07ooo`80X23`1P1oool20:0Pl0<0Oooo0P3oO`0307ooo`80ogl01@1oool20?mo00X0Oooo0P3oO`0;
07ooo`@0ogl01@1oool30:0Pl080Oooo0P2P8?0507ooo`80X23`0P1oool30:0Pl00307ooo`2P8?00
X23`00<0Oooo0P2P8?0;07ooo`80X23`1P1oool20:0Pl00307ooo`2P8?00X23`00<0Oooo0P2P8?03
07ooo`80ogl000<0Oooo0:0Pl02P8?001`1oool40?mo000407ooo`3oO`00ogl007ooo`80X23`00D0
ogl007ooo`3oO`00ogl007ooo`020?mo00H0Oooo0P3oO`0^07ooo`7o00000Oooool00003o`00003o
ogl0oomo00T0oomo0P2P8?020?ooO`80ogl07P3oogl00ol00000Oooo07ooo`0C07ooo`80X23`5`1o
ool20:0Pl0H0Oooo0P2P8?0507ooo`80ogl0201oool20?mo00L0Oooo0P3oO`0407ooo`80ogl00P1o
ool20:0Pl00307ooo`2P8?00X23`0080X23`0`1oool20:0Pl0T0Oooo0P2P8?040?mo00<0Oooo0P3o
O`000`1oool0X23`0:0Pl00807ooo`@0X23`1`1oool20:0Pl0X0Oooo0`2P8?0207ooo`80X23`1P1o
ool40?mo000407ooo`3oO`00ogl00?mo00@0Oooo0P3oO`0607ooo`80ogl0;P1oool1o`00007ooooo
00000ol00000oomo0?ooO`090?ooO`80X23`1P3oogl20?mo01/0oomo0_l0000C07ooo`80X23`3@1o
ool20?mo00P0Oooo0P2P8?0607ooo`80X23`3@1oool20:0Pl080ogl01@1oool40?mo00@0Oooo0P3o
O`001@1oool0ogl00:0Pl02P8?00Oooo00<0X23`00@0ogl007ooo`3oO`00ogl03@1oool40?mo00@0
Oooo00D0ogl00:0Pl02P8?00X23`0?mo000307ooo`80ogl0101oool20:0Pl080Oooo0P2P8?0607oo
o`80X23`00D0Oooo0:0Pl02P8?00X23`0?mo000207ooo`80X23`0`1oool20:0Pl080Oooo0P3oO`02
07ooo`80ogl00`1oool20?mo00<0Oooo103oO`0607ooo`80ogl0;P1oool1o`00007ooooo00000ol0
0000oomo0?ooO`0A0?ooO`80ogl07@3oogl2o`000200Oooo0P3oO`0O07ooo`80X23`1`1oool20?mo
00H0Oooo0P3oO`000`1oool0ogl00?mo000307ooo`80X23`00@0ogl007ooo`3oO`00ogl05@1oool0
0`3oO`00X23`0:0Pl0020?mo00<0Oooo0P3oO`0807ooo`80X23`1P1oool20:0Pl00507ooo`2P8?00
X23`0:0Pl03oO`002`1oool20?mo00`0Oooo0P3oO`0h07ooo`7o00000Oooool00003o`00003oogl0
oomo01X0oomo0P3oO`0F0?ooO`03o`00001oool0Oooo02<0Oooo102P8?0M07ooo`D0ogl0601oool4
0:0Pl2h0Oooo0P3oO`0907ooo`@0X23`201oool20?mo00T0Oooo0P3oO`0_07ooo`7o00000Oooool0
0003o`00003oogl0oomo01X0oomo0P3oO`0G0?ooO`;o00008`1oool40:0Pl100Oooo0P2P8?0507oo
o`80ogl0101oool50?mo00@0Oooo0P3oO`000`1oool0ogl00?mo000807ooo`030?mo002P8?00X23`
0080X23`0P1oool40:0Pl0l0Oooo0P3oO`0607ooo`80X23`0`1oool20?mo0100Oooo0P3oO`0307oo
o`80ogl0101oool40:0Pl0L0Oooo0`3oO`0907ooo`80ogl0;`1oool1o`00007ooooo00000ol00000
oomo0?ooO`0e0?ooO`03o`00001oool0Oooo01P0Oooo0P3oO`000`1oool0ogl00?mo000G07ooo`80
X23`0`1oool40?mo0080Oooo0P2P8?0907ooo`80ogl000@0Oooo0?mo003oO`00Oooo0P3oO`0307oo
o`80X23`00<0ogl00:0Pl02P8?000P2P8?0907ooo`80X23`0`1oool20?mo00D0Oooo0P3oO`0607oo
o`80X23`0`1oool20?mo01D0Oooo0P3oO`000`1oool0ogl00?mo000207ooo`040?mo002P8?00X23`
07ooo`80X23`101oool20?mo02<0Oooo0P3oO`0F07ooo`7o00000Oooool00003o`00003oogl0oomo
0280oomo0P2P8?070?ooO`80ogl02@3oogl2o`0001P0Oooo0P3oO`000`1oool0ogl00?mo000L07oo
o`80ogl0101oool20:0Pl0<0Oooo0P2P8?0:07ooo`80ogl00`1oool20:0Pl080ogl00P2P8?000`3o
O`00Oooo07ooo`0707ooo`80X23`0`1oool20?mo00h0Oooo0P3oO`0807ooo`80X23`4P1oool20?mo
0080Oooo103oO`040:0Pl0D0Oooo0P3oO`0F07ooo`@0ogl01P1oool20?mo01H0Oooo0Ol00001oooo
o`0000?o00000?ooO`3oogl08P3oogl20:0Pl0@0oomo0P3oO`000`3oogl0ogl00?mo000:0?ooO`80
ogl03P1oool20?mo00@0Oooo0P3oO`0N07ooo`80X23`0P1oool20?mo00T0Oooo0P2P8?0B07ooo`<0
X23`00<0ogl007ooo`1oool0401oool20:0Pl0X0Oooo0P3oO`0807ooo`80X23`5P1oool50?mo0003
07ooo`2P8?00X23`00D0Oooo0P3oO`0B07ooo`80ogl000<0Oooo0?mo003oO`000`3oO`0407ooo`<0
ogl05`1oool1o`00007ooooo00000ol00000oomo0?ooO`0C0?ooO`80ogl0103oogl20?mo00/0oomo
103oO`0=0?ooO`80ogl00_l0000<07ooo`80ogl0101oool20?mo0100Oooo0P2P8?0407ooo`80ogl0
1P1oool20:0Pl080Oooo0P3oO`0M07ooo`80X23`501oool20:0Pl0L0Oooo0P2P8?0507ooo`80X23`
0`1oool20?mo01X0Oooo0P3oO`0807ooo`80ogl04P1oool20?mo000307ooo`3oO`00ogl000L0Oooo
0`3oO`0G07ooo`7o00000Oooool00003o`00003oogl0oomo01<0oomo0P3oO`040?ooO`80ogl02P3o
ogl20:0Pl0<0ogl04@3oogl00ol00000Oooo07ooo`0H07ooo`80X23`1`1oool20:0Pl0@0Oooo0P3o
O`020:0Pl080Oooo0P2P8?0>07ooo`80X23`3P1oool20:0Pl0D0Oooo0P2P8?000`1oool0ogl00?mo
000H07ooo`80X23`1@1oool20:0Pl0<0Oooo0P3oO`1N07ooo`7o00000Oooool00003o`00003oogl0
oomo01D0oomo0P3oO`0>0?ooO`80X23`5@3oogl2o`0001P0Oooo0P2P8?0607ooo`80X23`1`1oool2
0:0Pl080Oooo0P2P8?0407ooo`80ogl0201oool20:0Pl0h0Oooo0P2P8?0507ooo`80X23`00<0Oooo
0?mo003oO`005P1oool20?mo00@0X23`9`1oool20?mo0080X23`0`1oool20?mo0380Oooo0P3oO`04
07ooo`7o00000Oooool00003o`00003oogl0oomo01D0oomo0P3oO`0W0?ooO`;o00007P1oool20:0P
l140Oooo0P3oO`0j07ooo`80ogl00P1oool20:0Pl2L0Oooo0P3oO`020:0Pl0<0Oooo0P3oO`0b07oo
o`80ogl0101oool1o`00007ooooo00000ol00000oomo0?ooO`050?ooO`80X23`>@3oogl00ol00000
Oooo07ooo`0707ooo`80X23`401oool20:0Pl0T0Oooo0P3oO`0;07ooo`80X23`5@1oool00`3oO`00
X23`0:0Pl00<07ooo`80X23`101oool20:0Pl240Oooo103oO`0407ooo`80ogl00P1oool20?mo02X0
Oooo0P3oO`0407ooo`80ogl0601oool1o`00007ooooo00000ol00000oomo0?ooO`050?ooO`80X23`
>P3oogl2o`0000L0Oooo0P2P8?0@07ooo`@0X23`1`1oool20?mo00@0Oooo0P2P8?0507ooo`80X23`
101oool20?mo00l0Oooo00@0ogl00:0Pl02P8?00Oooo0P3oO`0907ooo`80X23`0`1oool30:0Pl0H0
Oooo0P3oO`020:0Pl0X0Oooo0P3oO`000`1oool0ogl00?mo000807ooo`@0ogl0101oool20?mo0080
Oooo0P3oO`0Z07ooo`80ogl000@0Oooo0?mo003oO`00Oooo0P3oO`0H07ooo`7o00000Oooool00003
o`00003oogl0oomo00h0oomo0P3oO`0c0?ooO`;o00006@1oool20:0Pl0d0Oooo0P2P8?0;07ooo`03
0?mo002P8?00X23`0080X23`0`1oool20:0Pl0030?mo002P8?00X23`00P0Oooo0P3oO`0307ooo`80
ogl02@1oool20:0Pl0H0Oooo0`3oO`020:0Pl0X0Oooo0P3oO`000`1oool0ogl00?mo000@07ooo`80
ogl0601oool20?mo00h0Oooo0P3oO`0707ooo`80ogl01P1oool20?mo01<0Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl03P3oogl20?mo01@0oomo0P3oO`0<0?ooO`80ogl00P3oogl20?mo00d0oomo
00?o000007ooo`1oool0201oool20:0Pl080ogl01@1oool20?mo00H0Oooo0P2P8?0H07ooo`@0X23`
0`1oool20:0Pl0030?mo002P8?00X23`00d0Oooo0P3oO`0A07ooo`80ogl000<0Oooo0:0Pl02P8?00
5@1oool20:0Pl280Oooo0P3oO`0>07ooo`80ogl03`1oool20?mo01<0Oooo0Ol00001ooooo`0000?o
00000?ooO`3oogl0903oogl20?mo00`0oomo0P3oO`020?ooO`80ogl02@3oogl20?mo00<0oomo0_l0
000807ooo`80X23`0P3oO`0507ooo`80ogl01P1oool20:0Pl0/0Oooo0P2P8?0907ooo`80ogl01`1o
ool20:0Pl1X0Oooo0P2P8?0207ooo`80ogl01P1oool20:0Pl0T0Oooo0P3oO`0:07ooo`80X23`F01o
ool1o`00007ooooo00000ol00000oomo0?ooO`110?ooO`80ogl01@3oogl00ol00000Oooo07ooo`0M
07ooo`80X23`101oool20:0Pl0T0Oooo0P3oO`020:0Pl0/0Oooo0P3oO`0D07ooo`80X23`0P1oool2
0?mo0140Oooo0P3oO`0J07ooo`80X23`>P1oool20?mo00`0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl0B@3oogl2o`0000h0Oooo0P3oO`0=07ooo`80X23`4@1oool20:0Pl0/0Oooo0P3oO`0>07oo
o`80ogl0601oool20:0Pl1d0Oooo0P2P8?0j07ooo`80ogl01@1oool20?mo00D0Oooo0Ol00001oooo
o`0000Co00000?ooO`3oogl0oomo0P2P8?180?ooO`03o`00001oool0Oooo00/0Oooo0P3oO`0W07oo
o`80ogl0501oool20?mo00T0Oooo0P2P8?000`1oool0ogl00?mo000:07ooo`80X23`0P1oool20?mo
00D0Oooo0P3oO`1?07ooo`80ogl0101oool20?mo00D0Oooo0Ol00001ooooo`0000Co00000?ooO`3o
ogl0oomo0P2P8?190?ooO`;o0000=01oool20?mo01l0Oooo0P2P8?000`1oool0ogl00?mo000>07oo
o`80ogl01@1oool20?mo04l0Oooo0P3oO`0;07ooo`7o00000Oooool00003o`00003oogl0oomo04h0
oomo00?o000007ooo`1oool0701oool20:0Pl1l0Oooo0P3oO`2107ooo`80ogl0201oool1o`00007o
oooo00000ol00000oomo0?ooO`0a0?ooO`80X23`703oogl2o`0001@0Oooo0P2P8?0607ooo`80X23`
1P1oool20:0Pl140Oooo0P3oO`0407ooo`80ogl02@1oool20?mo0140Oooo0P2P8?000`1oool0X23`
0:0Pl01P07ooo`80ogl000<0Oooo0?mo003oO`001@1oool1o`00007ooooo00000ol00000oomo0?oo
O`0a0?ooO`80X23`7P3oogl00ol00000X23`0:0Pl00A07ooo`80X23`3P1oool30:0Pl100Oooo0P3o
O`0607ooo`80X23`101oool20:0Pl00307ooo`3oO`00ogl00140Oooo0P2P8?000`1oool0X23`0:0P
l01N07ooo`80ogl00`1oool20?mo00D0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0DP3oogl2
0:0Pl080Oooo0P2P8?0607ooo`80X23`5P1oool20:0Pl0d0Oooo0P2P8?0807ooo`<0X23`101oool2
0:0Pl080ogl000<0Oooo0?mo003oO`00601oool20?mo05P0Oooo0P3oO`0:07ooo`7o00000Oooool0
0003o`00003oogl0oomo0080X23`;03oogl20?mo02<0oomo0_l000000`1oool0X23`0:0Pl00307oo
o`80X23`00<0Oooo0:0Pl02P8?003P1oool20:0Pl0T0Oooo102P8?0807ooo`80X23`201oool20:0P
l0L0Oooo0P3oO`000`1oool0ogl00?mo000>07ooo`80X23`201oool20?mo00D0Oooo0P3oO`1H07oo
o`80ogl00`1oool1o`00007ooooo00000ol00000oomo0?ooO`020:0Pl1h0oomo0P2P8?0<0?ooO`80
ogl09@3oogl00ol00000Oooo07ooo`0307ooo`80X23`301oool40:0Pl00307ooo`2P8?00X23`00H0
Oooo0P2P8?000`1oool0X23`0:0Pl0030:0Pl180Oooo0P2P8?0207ooo`80X23`1@1oool20:0Pl0@0
Oooo0P2P8?0807ooo`80X23`301oool20?mo000307ooo`3oO`00ogl004`0Oooo0P3oO`0507ooo`80
ogl00`1oool20?mo00<0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?000P2P8?0N0?ooO`80X23`
=03oogl00ol00000Oooo07ooo`0@07ooo`@0X23`2@1oool20:0Pl00307ooo`2P8?00X23`00<0X23`
3P1oool20:0Pl080Oooo0P2P8?0207ooo`@0X23`0`1oool20:0Pl080ogl0102P8?0F07ooo`80ogl0
<@1oool20?mo01`0Oooo0P3oO`0507ooo`80ogl0201oool1o`00007ooooo00000ol00000X23`0:0P
l0020:0Pl2H0oomo0P3oO`0]0?ooO`03o`00001oool0Oooo00@0Oooo0P2P8?00101oool0X23`0:0P
l03oO`0@07ooo`80X23`0`1oool30:0Pl0d0Oooo0P2P8?00101oool0X23`0:0Pl02P8?0707ooo`80
X23`1@1oool20?mo0080X23`301oool20?mo00<0Oooo0P3oO`0h07ooo`80ogl09@1oool20?mo00H0
Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0:03oogl20?mo02h0oomo0_l0000407ooo`80X23`
00@0Oooo0:0Pl02P8?00ogl0401oool20:0Pl0<0Oooo0P3oO`0>07ooo`80X23`0P1oool20:0Pl1h0
Oooo0P3oO`0307ooo`80ogl0G`1oool20?mo00H0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
FP3oogl00ol00000Oooo07ooo`0L07ooo`<0X23`7@1oool20:0Pl0L0Oooo0P3oO`1a07ooo`80ogl0
101oool1o`00007ooooo00000ol00000oomo0?ooO`0o0?ooO`80ogl06@3oogl20:0Pl003o`00001o
ool0Oooo00D0Oooo0`2P8?0>07ooo`80X23`0P1oool30:0Pl1@0Oooo0P3oO`0707ooo`80X23`1`1o
ool20?mo0180Oooo0P2P8?1M07ooo`<0ogl00`1oool1o`00007ooooo00000ol00000oomo0?ooO`03
0?ooO`80X23`;`3oogl20:0Pl0T0oomo0P3oO`0I0?ooO`80X23`00<0oomoo`00001oool01@1oool3
0:0Pl0h0Oooo0P2P8?0I07ooo`80ogl01`1oool20:0Pl080ogl00`1oool20?mo00@0Oooo0P2P8?04
07ooo`80ogl0201oool20:0Pl480Oooo0P3oO`0J07ooo`@0ogl00@1oool1o`00007ooooo00000ol0
0000oomo0?ooO`020:0Pl0030?ooO`2P8?00X23`0200oomo0P2P8?0=0?ooO`80X23`803oogl20:0P
l0H0oomo0_l000020:0Pl1X0Oooo0P2P8?0L07ooo`<0ogl00`1oool40?mo0080Oooo0P2P8?0407oo
o`80ogl0201oool20:0Pl00307ooo`2P8?00X23`03l0Oooo0P3oO`0L07ooo`80ogl00@1oool1o`00
007ooooo00000ol00000X23`0:0Pl0020:0Pl2<0oomo0P2P8?080?ooO`80ogl0903oogl30:0Pl0P0
oomo0P2P8?000`1oool0X23`0:0Pl00G07ooo`80X23`6@1oool20?mo000307ooo`3oO`00ogl000H0
Oooo0P3oO`0B07ooo`80X23`00<0Oooo0:0Pl02P8?00G@1oool20?mo0040Oooo0Ol00001ooooo`00
00?o00000:0Pl02P8?006`3oogl20:0Pl180oomo0P3oO`0T0?ooO`80X23`2P3oogl2o`000080X23`
301oool20?mo00T0Oooo0P3oO`0D07ooo`80X23`0`1oool30?mo00X0Oooo0P2P8?0407ooo`80X23`
6P1oool20?mo04<0Oooo0P3oO`0;07ooo`80ogl00@1oool1o`00007ooooo00000ol00000X23`0:0P
l00K0?ooO`80X23`5`3oogl20?mo0280oomo1@2P8?060?ooO`80X23`301oool20?mo00<0Oooo0P3o
O`0?07ooo`80X23`1`1oool20?mo0080X23`101oool20?mo00L0Oooo0P3oO`000`1oool0X23`0:0P
l00407ooo`80X23`3@1oool20?mo00/0Oooo0P3oO`1307ooo`80ogl02@1oool50?mo007o00000Ooo
ool00003o`00002P8?00X23`01/0oomo0P2P8?020?mo01D0oomo0P3oO`0J0?ooO`80ogl0103oogl7
0:0Pl0P0oomo00?o000007ooo`1oool03P1oool20?mo00D0Oooo0P2P8?0807ooo`80X23`1`1oool2
0?mo00<0Oooo0P2P8?0:07ooo`<0ogl05@1oool20?mo02l0Oooo0P3oO`0Z07ooo`D0ogl00Ol00001
ooooo`0000?o00000?ooO`3oogl07@3oogl20?mo0340oomo0P3oO`040?ooO`80X23`3P3oogl2o`00
01D0Oooo0P2P8?0A07ooo`80ogl00`1oool20:0Pl0/0Oooo0P3oO`1607ooo`80ogl0;`1oool1o`00
007ooooo00000ol00000oomo0?ooO`0j0?ooO`80ogl09`3oogl20?mo00<0oomo0_l0000207ooo`80
ogl07@1oool20:0Pl00307ooo`2P8?00X23`00H0Oooo0P2P8?2307ooo`7o00000Oooool00003o`00
003oogl0oomo03X0oomo0P3oO`0O0?ooO`80X23`1P3oogl20?mo00D0oomo00Co000007ooo`3oO`00
ogl05P1oool20:0Pl0D0Oooo0P2P8?000`1oool0X23`0:0Pl00407ooo`@0X23`2`1oool30?mo02H0
Oooo0P2P8?1;07ooo`80ogl00Ol00001ooooo`0000?o00000?ooO`3oogl00P2P8?160?ooO`80X23`
4@3oogl20:0Pl0h0oomo0_l0000707ooo`80X23`3P1oool20:0Pl0h0Oooo0P2P8?0=07ooo`<0ogl0
5P1oool20?mo00d0Oooo0`2P8?1607ooo`80ogl00`1oool20?mo007o00000Oooool00003o`00002P
8?00X23`0080X23`AP3oogl20:0Pl1D0oomo0P2P8?0:0?ooO`80X23`00?o000007ooo`1oool0101o
ool30:0Pl4D0Oooo0P3oO`0807ooo`80X23`0P1oool00`3oO`00X23`0:0Pl01707ooo`L0ogl00Ol0
0001ooooo`0000?o00000:0Pl02P8?002P3oogl20:0Pl5<0oomo0P2P8?0:0?ooO`80X23`00<0oomo
o`00001oool01@1oool20:0Pl0P0Oooo0`2P8?0:07ooo`80X23`00@0Oooo0?mo003oO`00ogl0501o
ool20:0Pl1h0Oooo0P2P8?0207ooo`80ogl0BP1oool50?mo007o00000Oooool00003o`00003oogl0
oomo00X0oomo0P2P8?0W0?ooO`80X23`7@3oogl20:0Pl1@0oomo0P2P8?050?ooO`03o`00001oool0
Oooo00d0Oooo0`2P8?000`1oool0ogl00?mo000207ooo`80X23`0`1oool20:0Pl00407ooo`3oO`00
ogl00?mo0180Oooo0P3oO`020:0Pl0T0Oooo0P3oO`0E07ooo`80X23`D01oool10?mo007o00000Ooo
ool00003o`00003oogl0oomo00@0oomo0P2P8?0]0?ooO`80X23`3`3oogl20?mo00`0oomo0P2P8?06
0?ooO`80X23`303oogl20:0Pl0H0oomo00Co000007ooo`2P8?00X23`1P1oool20?mo00L0Oooo0P3o
O`0207ooo`80X23`6`1oool20?mo00/0Oooo0P3oO`0E07ooo`80X23`D@1oool1o`00007ooooo0000
0ol00000oomo0?ooO`040?ooO`80X23`;`3oogl00`3oO`00X23`0:0Pl00<0?ooO`80ogl0503oogl4
0:0Pl0X0oomo1@2P8?040?ooO`03o`00002P8?00X23`0080ogl000@0Oooo0:0Pl02P8?00Oooo0P3o
O`0<07ooo`80ogl0401oool20:0Pl7h0Oooo0@3oO`01o`00007ooooo00000ol00000oomo0?ooO`0e
0?ooO`030?mo002P8?00X23`02@0oomo0P2P8?0:0?ooO`D0X23`1@3oogl01Ol00000Oooo0?mo003o
O`00Oooo0080X23`3`1oool20?mo0100Oooo0P2P8?1n07ooo`40ogl00Ol00001ooooo`0000?o0000
0?ooO`3oogl0<`3oogl20?mo00030?ooO`3oO`00ogl001/0oomo0P2P8?090?ooO`80X23`103oogl3
0:0Pl0`0oomo00?o00000:0Pl02P8?000`1oool20:0Pl0L0Oooo0P3oO`0F07ooo`80X23`OP1oool1
0?mo007o00000Oooool00003o`00002P8?00X23`00X0oomo0P2P8?0L0?ooO`80X23`2@3oogl50?mo
01/0oomo0P2P8?050?ooO`80X23`0P3oogl20:0Pl0040?ooO`2P8?00X23`0?ooO`<0X23`00<0oomo
0:0Pl02P8?00203oogl40:0Pl003o`00001oool0Oooo00@0X23`00<0Oooo0:0Pl02P8?000P1oool2
0?mo01H0Oooo0P2P8?0507ooo`80X23`0P3oO`0;07ooo`80X23`1P1oool20:0Pl440Oooo0P3oO`0L
07ooo`80ogl00Ol00001ooooo`0000?o00000:0Pl02P8?002P3oogl20:0Pl100oomo0P2P8?0:0?oo
O`80X23`2P3oogl20?mo02<0oomo1@2P8?030?ooO`80X23`1@3oogl20:0Pl0H0oomo1`2P8?001?l0
0000Oooo07ooo`1oool20:0Pl00307ooo`2P8?00X23`0080Oooo0P2P8?0M07ooo`80X23`0P3oO`0;
07ooo`80X23`1P1oool20:0Pl440Oooo0P3oO`0B07ooo`80ogl0201oool20?mo007o00000Oooool0
0003o`00003oogl0oomo01`0oomo0P2P8?0R0?ooO`80X23`5`3oogl20:0Pl0030?ooO`2P8?00X23`
0180oomo0P2P8?000`3oogl0X23`0:0Pl0020:0Pl0030?ooOol0003o000000@0Oooo0P3oO`0207oo
o`80X23`401oool20:0Pl440Oooo0P2P8?0f07ooo`80ogl0201oool20?mo007o00000Oooool00003
o`00003oogl0oomo0400oomo0P2P8?0F0?ooO`80X23`0P3oogl20?mo0180oomo0P2P8?080?ooO`03
o`00002P8?00X23`0100Oooo0P3oO`0507ooo`80X23`2P1oool20?mo01l0Oooo0P3oO`0D07ooo`80
X23`@P1oool1o`00007ooooo00000ol00000oomo0?ooO`0K0?ooO`80X23`4@3oogl20:0Pl0@0oomo
0P2P8?0A0?ooO`80ogl0203oogl20:0Pl080ogl00`3oogl20:0Pl0H0oomo0P2P8?000`3oogl0X23`
0:0Pl0040?mo00`0oomo0P2P8?030?ooO`<0X23`1@1oool20?mo0080Oooo0P3oO`0507ooo`80ogl0
2`1oool20?mo00@0Oooo0P3oO`0=07ooo`80X23`401oool20?mo05D0Oooo0P3oO`0107ooo`7o0000
0Oooool00003o`00003oogl0oomo01/0oomo0P2P8?0A0?ooO`80X23`103oogl20:0Pl140oomo0P3o
O`040?ooO`80X23`0P3oogl20:0Pl080ogl00P3oogl20:0Pl080oomo0P2P8?030?ooO`80X23`00<0
oomo0:0Pl02P8?000`3oO`020:0Pl0L0oomo0`2P8?000`3oogl0X23`0:0Pl0030?ooO`80X23`00<0
oomoo`000?l000000`1oool0103oO`00X23`0:0Pl01oool20?mo0180Oooo0P3oO`0C07ooo`80X23`
401oool20?mo0140Oooo0P3oO`1207ooo`80ogl00@1oool1o`00007ooooo00000ol00000oomo0?oo
O`0K0?ooO`80X23`<03oogl20:0Pl0P0oomo1P2P8?070?ooO`80ogl00P3oogl20:0Pl0030?ooO`2P
8?00X23`00@0oomo0`2P8?0:0?ooO`80X23`0`1oool30:0Pl1@0Oooo0P3oO`0:07ooo`80ogl06@1o
ool20?mo0140Oooo0P3oO`1507ooo`7o00000Oooool00003o`00003oogl0oomo01/0oomo0P2P8?0l
0?ooO`<0X23`3`3oogl20:0Pl140oomo0P2P8?001?l00000Oooo07ooo`1oool20:0Pl200Oooo0P3o
O`1c07ooo`7o00000Oooool00003o`00002P8?00X23`03H0oomo0P2P8?070?ooO`80ogl0103oogl2
0:0Pl1P0oomo0P2P8?030?ooO`80X23`0P3oogl20:0Pl0030?mo003oogl0oomo00<0oomo0P2P8?03
0?ooO`@0X23`0`3oogl20:0Pl0<0oomo0_l0000j07ooo`80ogl0E`1oool20?mo00<0Oooo0Ol00001
ooooo`0000?o00000:0Pl02P8?00=P3oogl20:0Pl0H0oomo0`3oO`040?ooO`80X23`4P3oogl20:0P
l0040?mo002P8?00X23`0?ooO`80X23`0`3oogl20:0Pl0050?ooO`2P8?00X23`0:0Pl03oO`001@3o
ogl20:0Pl0<0oomo102P8?030?ooO`80X23`0P3oogl40:0Pl0/0Oooo0P2P8?0?07ooo`80ogl00P1o
ool20:0Pl1L0Oooo0P3oO`1G07ooo`80ogl00`1oool1o`00007ooooo00000ol00000oomo0?ooO`0n
0?ooO`80ogl000<0oomo0?mo003oO`002@3oogl20:0Pl0/0oomo0P2P8?000`3oO`00X23`0:0Pl004
0?ooO`80X23`00<0oomo0?mo003oO`000P2P8?040?ooO`80X23`00@0oomo0:0Pl02P8?00oomo0P2P
8?020?ooO`80X23`1`3oogl40:0Pl003o`00001oool0Oooo00P0Oooo0P2P8?0407ooo`80X23`2@1o
ool20?mo0080Oooo0P2P8?1e07ooo`7o00000Oooool00003o`00003oogl0oomo0080X23`>P3oogl2
0:0Pl0<0oomo0P3oO`020?ooO`80X23`1@3oogl20:0Pl1@0oomo0P2P8?000`3oogl0ogl00?mo0004
0?ooO`80ogl00P2P8?040?ooO`80X23`00@0oomo0:0Pl02P8?00oomo0P2P8?0:0?ooO`03o`00001o
ool0Oooo00D0Oooo0P2P8?0607ooo`@0X23`6P1oool20?mo0200Oooo0P2P8?1407ooo`7o00000Ooo
ool00003o`00003oogl0oomo0080X23`303oogl20:0Pl2`0oomo0P2P8?050?ooO`@0X23`6`3oogl2
0:0Pl0L0oomo0P3oO`040?ooO`80X23`0`3oogl20:0Pl0030?ooO`2P8?00X23`00@0oomo0P2P8?02
0?ooO`80ogl000<0oomoo`000?l000001@1oool20:0Pl0P0Oooo0P2P8?0207ooo`80ogl05P1oool2
0?mo00D0Oooo0P2P8?0I07ooo`80X23`?@1oool20?mo00D0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl03P3oogl20:0Pl1d0oomo0P2P8?0<0?ooO`80X23`00<0oomo0:0Pl02P8?000`3oogl20:0P
l0<0oomo0P2P8?030?ooO`80X23`00@0oomo0:0Pl02P8?00ogl02@3oogl20:0Pl0@0oomo0P2P8?07
0?ooO`80X23`103oogl40:0Pl0040?ooO`3oO`00ogl00?ooO`80ogl00P3oogl0103oO`00X23`0:0P
l02P8?020?ooO`80ogl00`3oogl00ol00000Oooo07ooo`0207ooo`80ogl00P2P8?0:07ooo`80X23`
6`1oool40:0Pl00307ooo`2P8?00X23`05D0Oooo0P3oO`0507ooo`7o00000Oooool00003o`00003o
ogl0oomo00<0oomo0P2P8?0X0?ooO`80X23`203oogl20:0Pl080oomo0P2P8?000`3oogl0X23`0:0P
l0080?ooO`80X23`0`3oogl20:0Pl0040?mo002P8?00X23`0?mo0080X23`1`3oogl40:0Pl080oomo
102P8?040?ooO`<0X23`0`3oogl30?mo0080X23`103oogl01@3oO`00X23`0:0Pl03oogl0ogl00080
X23`1@3oogl20?mo0080oomo00?o000007ooo`1oool00`1oool20:0Pl0P0Oooo0P3oO`020:0Pl1/0
Oooo0P2P8?0307ooo`80X23`401oool20:0Pl4X0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
0`3oogl20:0Pl0<0oomo0P2P8?060?ooO`80X23`9@3oogl20:0Pl0P0oomo0P3oO`050?ooO`80X23`
1@3oogl20?mo0080oomo0P2P8?000`3oogl0X23`0:0Pl0060?ooO`<0X23`00<0oomo0:0Pl02P8?00
0P2P8?040?ooO`80X23`103oogl30:0Pl0L0oomo102P8?020?mo00D0oomo0P3oO`030?ooO`03o`00
001oool0Oooo0080Oooo0P3oO`0807ooo`80ogl0101oool20:0Pl0/0Oooo0P3oO`0607ooo`80ogl0
1@1oool20?mo0180Oooo0P2P8?1807ooo`80ogl00Ol00001ooooo`0000?o00000?ooO`3oogl0203o
ogl20:0Pl0H0oomo0P2P8?0_0?ooO`80ogl01@3oogl20:0Pl0`0oomo0P2P8?070?ooO`80X23`00<0
oomo0:0Pl02P8?00303oogl30:0Pl0T0oomo0P2P8?0=0?ooO`03o`00001oool0Oooo0140Oooo0P2P
8?0;07ooo`80ogl01P1oool20?mo00D0Oooo0P3oO`1L07ooo`80ogl00Ol00001ooooo`0000?o0000
0?ooO`3oogl0=`3oogl20:0Pl0L0oomo0P2P8?0C0?ooO`80ogl01@3oogl20:0Pl0@0oomo0P2P8?03
0?ooO`<0X23`3@3oogl20:0Pl0/0oomo0P2P8?060?ooO`03o`00001oool0Oooo02`0Oooo0P3oO`0A
07ooo`80ogl0B`1oool1o`00007ooooo00000ol00000oomo0?ooO`0c0?ooO`80X23`0P3oogl20:0P
l0L0oomo0`2P8?0?0?ooO`80X23`00<0oomo0?mo003oO`000P3oogl20?mo00030?ooO`2P8?00X23`
00L0X23`0P3oogl30:0Pl0@0oomo0P3oO`000`3oogl0X23`0:0Pl0040?ooO`80X23`1P3oogl20:0P
l0<0oomo0P2P8?070?ooO`03o`00001oool0Oooo00d0Oooo0P2P8?0:07ooo`80X23`1`1oool20?mo
00L0Oooo0P3oO`0A07ooo`80ogl0B`1oool1o`00007ooooo00000ol00000oomo0?ooO`060?ooO`80
X23`:`3oogl20:0Pl0`0oomo0P2P8?0?0?ooO`80X23`1@3oogl20?mo00<0oomo1`2P8?020?ooO`<0
X23`103oogl20?mo00030?ooO`2P8?00X23`00L0oomo0P2P8?030?ooO`80X23`00<0ogl00?ooO`3o
ogl02P3oogl00ol00000Oooo07ooo`0<07ooo`80X23`2P1oool20:0Pl0L0Oooo0P3oO`0707ooo`80
ogl0G@1oool10?mo007o00000Oooool00004o`00003oogl0X23`0:0Pl0D0oomo0P2P8?0i0?ooO`80
ogl01@3oogl20:0Pl1@0oomo0P2P8?000`3oogl0X23`0:0Pl0020?ooO`@0ogl00P3oogl20:0Pl004
0?ooO`2P8?00X23`0?ooO`80X23`1`3oogl20:0Pl0@0oomo0P3oO`0:0?ooO`<0X23`0_l0000B07oo
o`80X23`201oool20?mo00`0Oooo0P3oO`1M07ooo`40ogl00Ol00001ooooo`0000Co00000?ooO`2P
8?00X23`:`3oogl20:0Pl1<0oomo0P3oO`050?ooO`80X23`0P3oogl40:0Pl0H0oomo0P2P8?070?oo
O`80X23`103oogl20:0Pl080ogl01`2P8?000`3oogl0X23`0:0Pl0020?ooO`80ogl00P2P8?070?oo
O`80ogl00`3oogl20:0Pl0030?ooO`2P8?00X23`0080oomo0`2P8?020?ooO`03o`00001oool0Oooo
00`0Oooo0P2P8?000`1oool0X23`0:0Pl00807ooo`80ogl0J`1oool10?mo007o00000Oooool00003
o`00003oogl0oomo02`0oomo0P2P8?0J0?ooO`80X23`0P3oogl40:0Pl0H0oomo0P2P8?020?ooO`80
X23`0`3oogl20:0Pl080oomo102P8?020?mo0080X23`00<0oomo0:0Pl02P8?001`3oogl20?mo0080
X23`00@0oomo0?mo003oO`00oomo0P3oO`00103oogl0X23`0:0Pl03oogl20?mo0080X23`00<0oomo
0:0Pl02P8?001@3oogl20?mo00030?ooOol0003o000000/0Oooo0`2P8?000`1oool0X23`0:0Pl01f
07ooo`7o00000Oooool00003o`00003oogl0oomo02D0oomo0P2P8?0A0?ooO`80X23`3P3oogl20:0P
l100oomo0P2P8?070?ooO`80X23`0P3oogl20?mo00D0oomo0P2P8?060?ooO`80X23`00D0ogl00?oo
O`3oO`00ogl00?ooO`020?mo00040?ooO`2P8?00X23`0?ooO`80ogl02P3oogl20?mo00<0oomo0P2P
8?0907ooo`80X23`0P1oool20:0Pl1D0Oooo0P2P8?0C07ooo`80X23`BP1oool1o`00007ooooo0000
0ol00000oomo0?ooO`0>0?ooO`80X23`5@3oogl20:0Pl0X0oomo0P2P8?050?ooO`80X23`2@3oogl3
0:0Pl0l0oomo0P3oO`030?ooO`80X23`00<0ogl00?ooO`3oogl0203oogl20?mo00<0oomo0P3oO`02
0:0Pl0H0oomo0P2P8?0:0?ooO`80X23`00<0ogl00:0Pl02P8?000`3oO`0:0?ooO`80X23`0`1oool2
0:0Pl1l0Oooo0P2P8?0C07ooo`80X23`BP1oool1o`00007ooooo00000ol00000oomo0?ooO`0>0?oo
O`80X23`5@3oogl20:0Pl0X0oomo0P2P8?0@0?ooO`<0X23`3`3oogl20?mo00@0oomo0P3oO`0:0?oo
O`80ogl00`3oogl20?mo01@0oomo0P2P8?000`3oO`00X23`0:0Pl0030?mo00`0oomo0_l000000`1o
ool0X23`0:0Pl02007ooo`7o00000Oooool00003o`00003oogl0oomo03l0oomo0P2P8?0<0?ooO`80
X23`4@3oogl20:0Pl180oomo0P2P8?040?ooO`80ogl01P3oogl30?mo00030?ooO`3oO`00ogl00080
ogl0103oogl20:0Pl0D0oomo0P3oO`000`3oogoo000007ooo`2107ooo`7o00000Oooool00003o`00
003oogl0oomo00P0oomo0P2P8?0e0?ooO`80X23`103oogl20:0Pl0H0oomo0P2P8?0@0?ooO`030?mo
002P8?00X23`00H0oomo0P2P8?000`3oogl0ogl00?mo00030?ooO`80ogl00P3oogl20:0Pl0@0oomo
0P3oO`060?ooO`P0ogl0103oogl20:0Pl0D0oomo0P3oO`020?ooO`;o0000101oool20?mo07X0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0203oogl20:0Pl1l0oomo0P2P8?0J0?ooO`80X23`1@3o
ogl40:0Pl0P0oomo103oO`030?ooO`80X23`1`3oogl20:0Pl0030?ooO`2P8?00X23`0080X23`00<0
oomo0?mo003oO`00303oogl20?mo00<0oomo1`3oO`0:0?ooO`80X23`1@3oogl01?l00000Oooo07oo
o`1oool20?mo00P0Oooo0P2P8?1`07ooo`7o00000Oooool00003o`00003oogl0oomo02T0oomo0P2P
8?0J0?ooO`80X23`0P3oogl20:0Pl0030?ooO`2P8?00X23`0080X23`0`3oogl20?mo00<0oomo103o
O`020?ooO`030?mo002P8?00X23`00<0oomo0P2P8?030?ooO`80ogl0102P8?050?ooO`80X23`203o
ogl20?mo00<0oomo00<0ogl00:0Pl02P8?000P2P8?000`3oO`00oomo0?ooO`090?ooO`80X23`1P3o
ogl00ol00000Oooo07ooo`0:07ooo`80X23`L01oool1o`00007ooooo00000ol00000oomo0?ooO`03
0?ooO`80X23`3P3oogl20:0Pl340oomo1@2P8?000`3oogl0X23`0:0Pl0040:0Pl0030?ooO`3oO`00
ogl000T0oomo0P3oO`020:0Pl080oomo0P2P8?030?ooO`80X23`00<0oomo0?mo003oO`001P3oogl2
0:0Pl0P0oomo0P2P8?040?ooO`@0X23`0P3oO`020?ooO`80ogl03`3oogl00ol00000Oooo07ooo`09
07ooo`80ogl05`1oool20?mo05L0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?000`3oogl20:0P
l0h0oomo102P8?0_0?ooO`@0X23`0`3oogl20:0Pl0030?ooO`2P8?00X23`00<0oomo0P3oO`090?oo
O`80X23`1`3oogl20:0Pl080oomo00<0ogl00:0Pl02P8?001`3oogl20:0Pl0D0oomo0P2P8?000`3o
O`00oomo0?mo00020:0Pl080ogl000<0oomo0?mo003oO`000P3oogl20?mo0100oomo00?o000007oo
o`1oool01@1oool20?mo01X0Oooo0P3oO`0=07ooo`80ogl0B01oool1o`00007ooooo00000ol00000
X23`0:0Pl00E0?ooO`80X23`9`3oogl20:0Pl0<0oomo1@2P8?040?ooO`80X23`1`3oogl20?mo0140
oomo0P2P8?030?ooO`030?mo002P8?00X23`00L0oomo0P2P8?020?ooO`80X23`00H0oomo0?mo003o
O`00ogl00?ooO`3oO`020:0Pl0030?mo002P8?00X23`0080ogl00P3oogl20?mo0080oomo0P3oO`0=
0?ooO`03o`00001oool0Oooo00@0Oooo0`3oO`0C07ooo`80X23`4`1oool20?mo04P0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl02@3oogl20:0Pl0H0oomo0P2P8?0R0?ooO`80X23`1`3oogl20:0P
l0<0oomo1@2P8?040?ooO`80X23`2@3oogl20?mo00030?ooO`2P8?00X23`00`0oomo0P2P8?030?oo
O`80X23`00@0ogl00?ooO`3oogl0oomo0P2P8?020?ooO`80X23`0P3oogl40:0Pl0040?mo003oogl0
oomo0?mo0080X23`00<0ogl00:0Pl02P8?000P3oO`020?ooO`80ogl00P3oogl20?mo00H0oomo0P2P
8?040?ooO`80X23`00?o000007ooo`1oool0101oool20?mo01<0Oooo0P2P8?0507ooo`80X23`0P1o
ool20:0Pl580Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl02@3oogl20:0Pl0H0oomo0P2P8?0R
0?ooO`80X23`5@3oogl20:0Pl0T0oomo0P3oO`000`3oogl0X23`0:0Pl00A0?ooO`80X23`103oogl2
0:0Pl080oomo0P2P8?040?ooO`80X23`00@0ogl00?ooO`3oogl0ogl00P2P8?0C0?ooO`80X23`103o
ogl20:0Pl0030?ooOol00000Oooo0200Oooo0P2P8?0207ooo`80X23`DP1oool1o`00007ooooo0000
0ol00000oomo0?ooO`1<0?ooO`@0X23`3P3oogl20?mo0080oomo0P2P8?030?ooO`80X23`0P3oogl2
0?mo00<0oomo0P2P8?000`3oogl0X23`0:0Pl0080?ooO`80ogl01P3oogl20?mo00H0oomo0P3oO`05
0?ooO`80X23`203oogl20:0Pl080oomo0_l0001g07ooo`7o00000Oooool00003o`00003oogl0oomo
02P0oomo0P2P8?0;0?ooO`80X23`00<0oomo0:0Pl02P8?004P3oogl40:0Pl0h0oomo0P3oO`020?oo
O`80X23`0`3oogl20:0Pl080oomo0P3oO`030?ooO`D0X23`103oogl20?mo0080oomo0P3oO`060?oo
O`030?mo002P8?00X23`00D0oomo103oO`030?ooO`80X23`203oogl20:0Pl080oomo0P3oO`000ol0
0000Oooo07ooo`0?07ooo`80X23`H`1oool1o`00007ooooo00000ol00000oomo0?ooO`050?ooO`80
X23`4@3oogl20:0Pl0h0oomo0P2P8?0;0?ooO`80X23`00<0oomo0:0Pl02P8?002P3oogl20:0Pl0T0
oomo0`2P8?080?ooO`80X23`1@3oogl20:0Pl0@0oomo0P2P8?00103oogl0X23`0:0Pl03oogl20:0P
l080oomo102P8?00103oogl0X23`0:0Pl03oogl20?mo0080X23`0P3oogl30?mo00030?ooO`2P8?00
X23`00D0X23`00<0ogl00?ooO`3oO`001P3oO`00103oogl0ogl00:0Pl02P8?0;0?ooO`80ogl000<0
oomoo`00001oool03`1oool20:0Pl0H0Oooo0P2P8?1K07ooo`7o00000Oooool00003o`00003oogl0
oomo00<0oomo102P8?070?ooO`80X23`203oogl20:0Pl1h0oomo0P2P8?0:0?ooO`80X23`203oogl6
0:0Pl0030?ooO`2P8?00X23`00<0oomo0P2P8?050?ooO`80X23`00@0ogl00?ooO`3oogl0oomo0P2P
8?00103oogl0X23`0:0Pl03oogl20:0Pl0<0oomo0`2P8?000`3oogl0X23`0:0Pl0020?ooO`050?mo
002P8?00X23`0?mo003oogl00P2P8?000`3oO`00oomo0:0Pl0060:0Pl0040?mo003oogl0ogl00?mo
00<0oomo0P3oO`020?ooO`80X23`3`3oogl00ol00000Oooo07ooo`0E07ooo`80X23`1`1oool20:0P
l580Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl00`3oogl20:0Pl0030?ooO`2P8?00X23`00H0
oomo0P2P8?0X0?ooO`80X23`2@3oogl20:0Pl0T0oomo1P2P8?00103oogl0X23`0:0Pl03oogl20:0P
l0P0oomo103oO`0@0?ooO`80ogl000<0oomo0:0Pl02P8?000P2P8?00103oO`00oomo0:0Pl02P8?07
0?ooO`80ogl02`3oogl20?mo0080oomo0P2P8?0<0?ooO`03o`00001oool0Oooo01@0Oooo0P2P8?05
07ooo`80ogl00P2P8?1B07ooo`7o00000Oooool00003o`00003oogl0oomo00D0oomo0`2P8?0A0?oo
O`80X23`803oogl20:0Pl0H0oomo102P8?070?ooO`D0X23`1@3oogl40:0Pl0L0oomo0`2P8?0;0?oo
O`80X23`0`3oogl20?mo00030?ooO`2P8?00X23`00D0X23`1P3oogl20:0Pl0L0oomo102P8?020?oo
O`80ogl00P3oogl20:0Pl0d0oomo00?o000007ooo`1oool04`1oool20:0Pl0D0Oooo0P3oO`0K07oo
o`80ogl0=`1oool1o`00007ooooo00000ol00000oomo0?ooO`050?ooO`80X23`1P3oogl20:0Pl0X0
oomo0P2P8?0@0?ooO`80X23`2@3oogl20:0Pl0<0oomo0P2P8?080?ooO`80X23`2P3oogl20:0Pl0H0
oomo0`2P8?050?ooO`80ogl00`2P8?080?ooO`D0X23`0P3oogl20:0Pl080ogl00P2P8?000`3oO`00
X23`0:0Pl0020:0Pl0H0oomo0`2P8?060?ooO`@0X23`303oogl20?mo00030?ooO`2P8?00X23`00D0
oomo00?o000007ooo`1oool07P1oool20:0Pl1H0Oooo0P3oO`0g07ooo`7o00000Oooool00003o`00
003oogl0oomo00d0oomo0P2P8?040?ooO`80X23`5P3oogl20:0Pl0T0oomo0P2P8?0G0?ooO`80X23`
0P3oogl20:0Pl0`0oomo0P3oO`070?ooO`80X23`0P3oogl50:0Pl080ogl00P2P8?020?mo0080X23`
303oogl20:0Pl0H0oomo102P8?0<0?ooO`80ogl000<0oomo0:0Pl02P8?001P3oogl00ol00000Oooo
07ooo`0507ooo`80ogl03@1oool20:0Pl0L0Oooo0P2P8?1?07ooo`7o00000Oooool00003o`00003o
ogl0oomo01<0oomo0P2P8?0j0?ooO`80X23`0P3oogl20:0Pl1D0oomo0P2P8?070?ooO`80ogl0703o
ogl20:0Pl1P0oomo00?o000007ooo`1oool0101oool20?mo00d0Oooo0P2P8?1H07ooo`7o00000Ooo
ool00003o`00003oogl0oomo00<0oomo0P2P8?0N0?ooO`80X23`403oogl20:0Pl1h0oomo102P8?0V
0?ooO`80X23`3P3oogl20:0Pl1/0oomo00?o000007ooo`1oool02@1oool20:0Pl0@0Oooo0P2P8?07
07ooo`80ogl00P1oool20?mo04h0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl00`3oogl20:0P
l1h0oomo0P2P8?0@0?ooO`80X23`6@3oogl40:0Pl0030?ooO`2P8?00X23`0080X23`303oogl20:0P
l0h0oomo0P2P8?020?mo00D0oomo00@0ogl00:0Pl02P8?00oomo0P2P8?020?mo0080X23`103oogl2
0:0Pl0030?mo002P8?00X23`00@0oomo0P2P8?040?ooO`80X23`403oogl00ol00000Oooo07ooo`08
07ooo`80X23`101oool20:0Pl0@0Oooo0P2P8?000`1oool0ogl00?mo000207ooo`80ogl0101oool2
0:0Pl4P0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0303oogl20:0Pl0<0oomo0P2P8?0>0?oo
O`80X23`;@3oogl40:0Pl0L0oomo0P3oO`080?ooO`80X23`3@3oogl00`3oO`00X23`0:0Pl0020?mo
00030?ooO`3oO`00ogl00080X23`0P3oO`020?ooO`H0X23`103oogl20:0Pl0030?mo002P8?00X23`
00@0oomo0P2P8?040?ooO`80X23`403oogl20:0Pl0H0Oooo0P3oO`0=07ooo`80X23`2`1oool20:0P
l4P0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl00`3oogl20:0Pl0L0oomo0P2P8?030?ooO`80
X23`3P3oogl20:0Pl1P0oomo0P2P8?0A0?ooO`80X23`1@3oogl40:0Pl080oomo0P3oO`0@0?ooO`80
ogl01@3oogl00`3oO`00X23`0:0Pl0030?ooO`80ogl00P2P8?00103oogl0X23`0:0Pl03oogl20?mo
0080X23`2@3oogl30:0Pl0<0oomo0P2P8?0?0?ooO`<0X23`103oogl20:0Pl004o`00003oO`00ogl0
07ooo`80X23`0P3oO`0507ooo`80X23`4`1oool20:0Pl4P0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl00`3oogl20:0Pl3H0oomo0P2P8?0A0?ooO`80X23`1@3oogl80:0Pl0<0oomo0`2P8?060?oo
O`80ogl00P3oogl20?mo00L0oomo0P2P8?00103oogl0X23`0:0Pl03oogl20:0Pl0040?ooO`2P8?00
X23`0?ooO`80ogl00P2P8?0:0?ooO`80X23`0P3oO`000`3oogl0X23`0:0Pl00:0?ooO`80X23`0`3o
ogl30:0Pl0H0oomo0P2P8?00103oO`00Oooo0:0Pl02P8?0707ooo`80X23`G@1oool1o`00007ooooo
00000ol00000oomo0?ooO`070?ooO`80X23`603oogl20:0Pl0T0oomo0P2P8?0K0?ooO`80X23`3@3o
ogl50:0Pl0<0oomo102P8?050?ooO`80ogl00`3oogl40:0Pl0040?mo003oogl0oomo0?ooO`80X23`
00@0oomo0:0Pl02P8?00ogl00`2P8?00103oogl0X23`0:0Pl03oogl30:0Pl0T0oomo0P2P8?030?mo
00H0oomo0P2P8?050?ooO`80X23`303oogl20:0Pl003o`00001oool0Oooo00T0Oooo0P2P8?1L07oo
o`7o00000Oooool00003o`00003oogl0oomo00L0oomo0`2P8?0B0?ooO`80X23`0`3oogl20:0Pl0T0
oomo0P2P8?0K0?ooO`80X23`3@3oogl30:0Pl0@0oomo1@2P8?0:0?ooO`@0X23`00@0ogl00?ooO`3o
ogl0oomo0P3oO`020?ooO`80X23`00@0ogl00:0Pl02P8?00oomo1@2P8?040?ooO`80X23`0`3oogl3
0:0Pl080ogl01`3oogl20:0Pl0<0oomo0P2P8?0@0?ooO`80X23`00<0Oooo0:0Pl02P8?001`1oool2
0:0Pl5`0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0203oogl20:0Pl180oomo0P2P8?0[0?oo
O`80X23`3P3oogl20:0Pl0@0oomo102P8?000`3oO`00X23`0:0Pl00?0?ooO`@0X23`00<0oomo0:0P
l02P8?000P3oogl20:0Pl080oomo0`2P8?00103oogl0X23`0:0Pl03oogl20:0Pl0<0oomo0`2P8?06
0?ooO`80X23`00<0oomo0:0Pl02P8?000`3oogl20:0Pl100oomo0P2P8?000ol00000X23`0:0Pl00G
07ooo`80X23`0P1oool20:0Pl080Oooo0P2P8?1407ooo`7o00000Oooool00003o`00003oogl0oomo
04T0oomo0P2P8?0H0?ooO`030?mo002P8?00X23`00l0oomo102P8?000`3oogl0X23`0:0Pl0020?oo
O`80X23`0P3oogl30:0Pl0030?ooO`2P8?00X23`00L0oomo0P2P8?060?ooO`80X23`00<0oomo0:0P
l02P8?00603oogl00ol00000Oooo07ooo`0F07ooo`80X23`0P1oool20:0Pl080Oooo0P2P8?1407oo
o`7o00000Oooool00003o`00003oogl0oomo00d0oomo0P2P8?1X0?ooO`80X23`2P3oogl20?mo0080
X23`00<0oomo0:0Pl02P8?002`3oogl20:0Pl0030?ooO`2P8?00X23`0100oomo0P2P8?090?ooO`04
o`00001oool0Oooo07ooo`80X23`2P1oool20:0Pl140Oooo0P3oO`1107ooo`7o00000Oooool00003
o`00003oogl0oomo00d0oomo0P2P8?1<0?ooO`80X23`1@3oogl20?mo01<0oomo0P2P8?0:0?ooO`80
ogl00P2P8?000`3oogl0X23`0:0Pl00;0?ooO`80X23`00<0oomo0:0Pl02P8?00103oogl20:0Pl0X0
oomo0P2P8?030?ooO`@0X23`0P3oogl20?mo0080Oooo0P2P8?0:07ooo`80X23`4@1oool20?mo0440
Oooo0Ol00001ooooo`0000Co00000?ooO`2P8?00X23`EP3oogl20:0Pl0040?ooO`2P8?00X23`0:0P
l0D0oomo0P3oO`060?ooO`80X23`1@3oogl40:0Pl080oomo0P3oO`090?ooO`<0X23`0P3oO`000`3o
ogl0X23`0:0Pl0020?ooO`<0X23`1P3oogl20:0Pl0030?ooO`2P8?00X23`00@0oomo102P8?090?oo
O`80X23`0P3oogl40:0Pl080oomo0P3oO`000ol00000Oooo07ooo`1Q07ooo`7o00000Oooool00004
o`00003oogl0X23`0:0Pl3d0oomo0P2P8?0G0?ooO`80X23`00<0oomo0:0Pl02P8?001`3oogl20:0P
l0D0oomo0P2P8?050?ooO`@0X23`0P3oogl20:0Pl0H0oomo0P3oO`00103oogl0X23`0:0Pl02P8?03
0?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?030?ooO`80X23`103oogl20:0Pl0H0oomo0P2P8?04
0?ooO`80X23`0`3oogl40:0Pl080oomo0P2P8?050?ooO`03o`00001oool0Oooo00@0Oooo0P2P8?05
07ooo`80X23`D`1oool1o`00007ooooo00000ol00000oomo0?ooO`0?0?ooO`80X23`9P3oogl20:0P
l0D0oomo0P2P8?0H0?ooO`80X23`2@3oogl40:0Pl0H0oomo0P3oO`030?ooO`80X23`00<0oomo0:0P
l02P8?000P2P8?060?ooO`80ogl00P3oogl20:0Pl0H0oomo0P2P8?050?ooO`80X23`0P3oogl40:0P
l0D0oomo0P2P8?050?ooO`80X23`103oogl30:0Pl0X0oomo00?o000007ooo`1oool00`1oool20:0P
l00307ooo`2P8?00X23`0080Oooo0P2P8?0307ooo`80ogl00P2P8?1<07ooo`7o00000Oooool00003
o`00003oogl0oomo00H0oomo0P2P8?070?ooO`80X23`8`3oogl20:0Pl0030?ooO`2P8?00X23`01l0
oomo102P8?070?ooO`050?mo002P8?00X23`0:0Pl03oogl00P3oO`030:0Pl080ogl00P3oogl0103o
O`00X23`0:0Pl03oogl20:0Pl0@0oomo0P2P8?000`3oogl0X23`0:0Pl0030?ooO`80X23`1`3oogl3
0:0Pl0030?ooO`2P8?00X23`00@0oomo102P8?000`3oogl0ogl00?mo00020?mo0080X23`2`3oogl2
0:0Pl0`0oomo00Co000007ooo`2P8?00X23`101oool40:0Pl0D0Oooo0P3oO`020:0Pl4`0Oooo0Ol0
0001ooooo`0000?o00000:0Pl02P8?001P3oogl20:0Pl2`0oomo0P2P8?0T0?ooO`80X23`1@3oogl5
0:0Pl080oomo0P3oO`050:0Pl080oomo0P3oO`060?ooO`@0X23`00<0oomo0:0Pl02P8?000P3oogl2
0:0Pl080oomo0P2P8?030?ooO`@0X23`00<0oomo0:0Pl02P8?002@3oogl20:0Pl080ogl03@3oogl2
0:0Pl0d0oomo00?o00000:0Pl02P8?001P1oool40:0Pl0H0Oooo0P3oO`1;07ooo`7o00000Oooool0
0003o`00002P8?00X23`00L0oomo0P2P8?0[0?ooO`80X23`9@3oogl20:0Pl0@0oomo102P8?080?oo
O`80X23`2P3oogl20:0Pl0L0oomo0P2P8?020?ooO`80X23`0`3oogl30:0Pl0@0oomo0P2P8?030?oo
O`80ogl00P3oogl40:0Pl0<0oomo0`2P8?030?ooO`80X23`0P3oogl20:0Pl0H0oomo0P3oO`060?oo
O`03o`00001oool0Oooo00L0Oooo0P2P8?0607ooo`80ogl000<0Oooo0?mo003oO`00B01oool1o`00
007ooooo00000ol00000oomo0?ooO`070?ooO`80X23`:`3oogl20:0Pl2D0oomo0P2P8?0e0?ooO`80
X23`0`3oogl20?mo00@0oomo0P2P8?030?ooO`<0X23`0`3oogl20:0Pl0X0oomo0P3oO`070?ooO`03
o`00001oool0Oooo0140Oooo0P3oO`1807ooo`7o00000Oooool00003o`00003oogl0oomo06d0oomo
0P2P8?020?ooO`80ogl000<0oomo0:0Pl02P8?000`2P8?000`3oogl0ogl00?mo00020:0Pl0X0oomo
0P2P8?000`3oogl0X23`0:0Pl0090?ooO`80X23`1P3oogl60:0Pl0l0oomo102P8?070?ooO`03o`00
001oool0Oooo01<0Oooo0P2P8?000`3oO`00Oooo07ooo`1207ooo`7o00000Oooool00003o`00003o
ogl0oomo00L0oomo0P2P8?150?ooO`80X23`6@3oogl20:0Pl0040?ooO`2P8?00X23`0:0Pl080oomo
0`3oO`050:0Pl0030?ooO`3oO`00ogl00080X23`0P3oogl20:0Pl080oomo0P3oO`020?ooO`80X23`
00@0oomo0:0Pl02P8?00X23`203oogl20:0Pl0030?ooO`2P8?00X23`00<0oomo1P2P8?080?ooO`80
X23`1@3oogl40:0Pl0L0oomo00?o000007ooo`1oool00P2P8?0<07ooo`80ogl00`1oool20:0Pl003
0?mo001oool0Oooo0480Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl01`3oogl20:0Pl1H0oomo
0P2P8?0M0?ooO`80X23`3P3oogl20:0Pl1P0oomo0`2P8?001@3oogl0X23`0:0Pl03oO`00oomo0080
X23`00@0ogl00:0Pl02P8?00oomo0P2P8?00103oO`00X23`0:0Pl03oogl30:0Pl0030?ooO`2P8?00
X23`0080oomo0P3oO`000`3oogl0X23`0:0Pl0030?ooO`80X23`2`3oogl20:0Pl0H0oomo0P2P8?06
0?ooO`80X23`00<0oomo0:0Pl02P8?001@3oogl20:0Pl0D0oomo102P8?000`3oogoo000007ooo`02
0:0Pl0L0Oooo0P2P8?0307ooo`80ogl0BP1oool1o`00007ooooo00000ol00000oomo0?ooO`0O0?oo
O`80X23`7@3oogl20:0Pl280oomo0P2P8?040?ooO`80X23`1P3oogl20:0Pl0030?ooO`2P8?00X23`
00<0X23`00@0oomo0:0Pl02P8?00oomo0`2P8?00103oogl0X23`0:0Pl03oogl20:0Pl080oomo0`2P
8?020?ooO`80X23`00<0oomo0:0Pl02P8?003P3oogl20:0Pl080ogl01@3oogl30:0Pl0@0oomo0P2P
8?020?ooO`D0X23`0P3oogl40:0Pl080oomo00?o00000?mo003oO`001`1oool20:0Pl00307ooo`2P
8?00X23`04`0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0;@3oogl20:0Pl2P0oomo0P2P8?09
0?ooO`80X23`2P3oogl20:0Pl0030?ooO`2P8?00X23`00D0X23`00<0oomo0:0Pl02P8?000`3oogl4
0:0Pl0030?ooO`2P8?00X23`00D0X23`1@3oogl20:0Pl0H0oomo102P8?040?ooO`80X23`0P3oO`05
0?ooO`<0X23`103oogl20:0Pl0<0oomo102P8?030?ooO`80X23`00@0oomo0:0Pl02P8?00oomo0P3o
O`0:07ooo`80X23`C01oool1o`00007ooooo00000ol00000oomo0?ooO`0]0?ooO`80X23`6`3oogl2
0:0Pl0/0oomo0P2P8?0@0?ooO`80X23`0`3oogl20:0Pl0040?ooO`2P8?00X23`0:0Pl080oomo0P2P
8?000`3oogl0X23`0:0Pl0030?ooO`80X23`103oogl60:0Pl0<0oomo0P2P8?060?ooO`X0X23`0`3o
ogl20:0Pl0<0oomo0P2P8?000`3oogl0ogl00?mo00020:0Pl0H0oomo0`3oO`030?ooO`<0X23`00D0
oomo0:0Pl02P8?00oomoo`0000020?mo01D0Oooo0P2P8?1007ooo`7o00000Oooool00003o`00003o
ogl0oomo0240oomo0P2P8?0W0?ooO`80X23`2P3oogl20:0Pl0L0oomo0P2P8?080?ooO`80X23`603o
ogl20?mo00<0oomo0P3oO`030?ooO`80X23`0P3oogl20:0Pl080oomo0`2P8?000`3oogl0X23`0:0P
l0040:0Pl0<0oomo0P2P8?030?ooO`80X23`00<0oomo0?mo003oO`000`2P8?050?ooO`<0ogl00`3o
ogl20:0Pl0H0oomo0P3oO`020:0Pl0@0Oooo0P2P8?0=07ooo`80X23`@01oool1o`00007ooooo0000
0ol00000oomo0?ooO`0Q0?ooO`80X23`<P3oogl30:0Pl0L0oomo0P2P8?0K0?ooO`80ogl000<0oomo
0?mo003oO`000P3oogl20:0Pl0<0oomo0P3oO`030?ooO`80X23`00<0oomo0?mo002P8?00102P8?00
0`3oogl0X23`0:0Pl0040:0Pl080oomo0P3oO`020?ooO`<0X23`0`3oogl20:0Pl0040?ooO`2P8?00
X23`0:0Pl080oomo102P8?020?mo0080oomo0P3oO`030?ooO`80X23`0P3oogl40:0Pl0@0Oooo0`2P
8?0207ooo`80X23`2`1oool20:0Pl3d0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0E@3oogl2
0:0Pl2D0oomo0P3oO`000`3oogl0ogl00?mo00020?ooO`80X23`203oogl20:0Pl0030?ooO`3oO`00
ogl000@0X23`00<0oomo0:0Pl02P8?000P2P8?040?ooO`80ogl00P3oogl30:0Pl0<0oomo0P2P8?00
0`3oogl0X23`0:0Pl0030?ooO`@0X23`103oogl20?mo00<0oomo0P2P8?020?ooO`80X23`00?o0000
07ooo`1oool0101oool20:0Pl080Oooo0P2P8?0;07ooo`80X23`?@1oool1o`00007ooooo00000ol0
0000oomo0?ooO`1P0?ooO`80X23`3`3oogl20:0Pl0P0oomo0`2P8?000`3oogl0ogl00?mo000E0?oo
O`030?mo002P8?00X23`00L0oomo0P2P8?060?ooO`@0X23`00<0oomo0:0Pl02P8?001P3oogl30:0P
l0T0oomo0P2P8?000`3oogoo000007ooo`0207ooo`80X23`D@1oool1o`00007ooooo00000ol00000
oomo0?ooO`1P0?ooO`80X23`2`3oogl20:0Pl080oomo0P2P8?040?ooO`80X23`0P3oogl30:0Pl004
0?ooO`3oO`00ogl00?ooO`80X23`303oogl20:0Pl0@0oomo00<0ogl00:0Pl02P8?00103oogl20:0P
l0040?ooO`2P8?00X23`0?ooO`80X23`0`3oogl40:0Pl0030?ooO`2P8?00X23`0080ogl0103oogl3
0:0Pl0T0oomo0P2P8?020?ooO`03o`00002P8?00X23`0080X23`2`1oool20:0Pl1L0Oooo0P2P8?00
0`3oO`00Oooo07ooo`0207ooo`80ogl0901oool1o`00007ooooo00000ol00000oomo0?ooO`1]0?oo
O`80X23`0P3oogl20:0Pl0@0oomo0P2P8?090?ooO`80X23`00<0oomo0:0Pl02P8?00203oogl50:0P
l0<0oomo0P2P8?040?ooO`80X23`103oogl20:0Pl0X0oomo0P3oO`0>0?ooO`80X23`1@3oogl20:0P
l080Oooo0P2P8?0507ooo`80X23`0P3oO`020:0Pl1L0Oooo0P2P8?000`3oO`00Oooo07ooo`0207oo
o`80ogl0901oool1o`00007ooooo00001?l00000oomo0:0Pl02P8?0A0?ooO`80X23`EP3oogl20:0P
l0030?ooO`2P8?00X23`0080oomo0P2P8?080?ooO`80X23`203oogl20:0Pl0P0oomo0P2P8?000`3o
ogl0X23`0:0Pl00<0?ooO`D0X23`1`3oogl20:0Pl0L0oomo0P2P8?000`3oogl0ogl00?mo00020?mo
00<0oomo102P8?040?ooO`03o`00001oool0Oooo0080X23`1@1oool20:0Pl080ogl0AP1oool1o`00
007ooooo00001?l00000X23`0:0Pl02P8?0A0?ooO`80X23`203oogl20:0Pl3L0oomo0P2P8?0@0?oo
O`80X23`00<0oomo0:0Pl02P8?000`2P8?000`3oogl0X23`0:0Pl0090?ooO`80X23`303oogl20:0P
l0030?ooO`3oO`00ogl00180oomo1@2P8?030?ooO`80X23`0P3oogl20:0Pl0030?ooO`2P8?00X23`
00@0oomo0P2P8?000`3oogl0ogl00?mo00040?mo00<0oomo102P8?020?ooO`03o`00001oool0Oooo
00@0Oooo0P2P8?0C07ooo`80ogl0=P1oool1o`00007ooooo00000ol00000X23`0:0Pl00J0?ooO`@0
X23`=`3oogl20:0Pl100oomo0`2P8?000`3oogl0X23`0:0Pl0030?ooO`80X23`1`3oogl20?mo0080
oomo0P3oO`000`3oogl0X23`0:0Pl0070?ooO`80X23`00<0oomo0:0Pl02P8?001P3oogl20:0Pl0D0
oomo0P2P8?0;0?ooO`80X23`0P3oogl50:0Pl0/0oomo0P3oO`050?ooO`<0X23`0P3oogl40:0Pl080
Oooo0P2P8?0C07ooo`80ogl0=P1oool1o`00007ooooo00000ol00000oomo0?ooO`0J0?ooO`80X23`
<@3oogl20:0Pl1T0oomo0P2P8?060?ooO`80X23`1`3oogl20?mo0080oomo0`3oO`020:0Pl0030?oo
O`3oO`00ogl00080X23`1@3oogl40:0Pl0@0oomo0`2P8?040?ooO`80X23`3`3oogl30:0Pl0<0oomo
0P2P8?0@0?ooO`<0X23`00<0oomo0:0Pl02P8?000P2P8?0f07ooo`80ogl05`1oool1o`00007ooooo
00000ol00000oomo0?ooO`0=0?ooO`80X23`903oogl20:0Pl1P0oomo0P2P8?0:0?ooO`80X23`3@3o
ogl20:0Pl0T0oomo0P2P8?020?ooO`80X23`1P3oogl20?mo00040?ooO`2P8?00X23`0?mo0080X23`
00<0oomo0?mo003oO`00103oogl20:0Pl0@0oomo0`2P8?000`3oO`00X23`0:0Pl0020:0Pl0030?mo
003oogl0oomo00@0oomo0P2P8?040?ooO`80X23`103oogl20:0Pl0030?ooO`2P8?00X23`0100oomo
0`2P8?020?ooO`03o`00001oool0Oooo00d0Oooo0P2P8?0W07ooo`80ogl05`1oool1o`00007ooooo
00000ol00000oomo0?ooO`0=0?ooO`80X23`903oogl20:0Pl2@0oomo0P2P8?0H0?ooO`80X23`0P3o
ogl20:0Pl0T0oomo0P2P8?040?ooO`80ogl0103oogl20:0Pl0@0oomo0P2P8?000`3oogl0ogl00:0P
l0030:0Pl0L0oomo0P2P8?040?ooO`80X23`103oogl20:0Pl1<0oomo0P2P8?040?ooO`03o`00001o
ool0Oooo00`0Oooo0P2P8?1007ooo`7o00000Oooool00003o`00003oogl0oomo07d0oomo0P3oO`0F
0?ooO`<0X23`0`3oogl20:0Pl0X0oomo0P2P8?040?ooO`80X23`00@0oomo0:0Pl02P8?00oomo0P2P
8?000`3oogl0X23`0:0Pl00?0?ooO`80X23`0P3oogl00ol00000Oooo07ooo`1=07ooo`7o00000Ooo
ool00003o`00003oogl0oomo0280oomo0P2P8?1G0?ooO`<0X23`00<0ogl00?ooO`3oogl0403oogl2
0:0Pl080oomo0`2P8?000`3oogl0X23`0:0Pl0020:0Pl080oomo0P2P8?020?mo00@0oomo102P8?02
0?ooO`80X23`00@0oomo0:0Pl02P8?00oomo1@2P8?070?ooO`80X23`1P3oogl60:0Pl080Oooo0P2P
8?0207ooo`80ogl0AP1oool1o`00007ooooo00000ol00000X23`0:0Pl00R0?ooO`80X23`4@3oogl2
0:0Pl3d0oomo0P2P8?050?ooO`<0X23`2@3oogl20?mo00H0oomo0P3oO`020:0Pl0H0oomo0`2P8?02
0?ooO`060?mo002P8?00X23`0:0Pl03oO`00oomo0P2P8?030?ooO`80X23`2@3oogl40:0Pl080ogl0
1@3oogl20:0Pl0L0oomo1@2P8?0207ooo`80X23`0P1oool20?mo04H0Oooo0Ol00001ooooo`0000?o
00000:0Pl02P8?00=@3oogl20:0Pl1L0oomo0P2P8?0T0?ooO`@0X23`3`3oogl20?mo00D0oomo0P2P
8?020?mo00P0oomo0P2P8?020?ooO`@0X23`0P3oogl20:0Pl0<0oomo102P8?090?ooO`80X23`0P3o
O`050?ooO`80X23`103oogl20:0Pl0@0oomo102P8?0A07ooo`80X23`>@1oool1o`00007ooooo0000
0ol00000oomo0?ooO`0J0?ooO`80X23`<P3oogl20:0Pl2H0oomo0`2P8?060?ooO`80X23`303oogl7
0:0Pl0050?ooO`3oO`00X23`0:0Pl03oogl00P2P8?020?ooO`H0X23`103oogl20:0Pl0040?ooO`2P
8?00X23`0:0Pl080oomo0P2P8?070?ooO`80X23`2@3oogl20?mo0080X23`1@3oogl50:0Pl0l0Oooo
0P2P8?0i07ooo`7o00000Oooool00003o`00003oogl0oomo01X0oomo0P2P8?1;0?ooO`80X23`3P3o
ogl20:0Pl0H0oomo0P2P8?0<0?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?001@3oogl0ogl00:0P
l02P8?00oomo0080X23`0P3oogl30:0Pl0030?mo002P8?00X23`0080X23`0P3oogl20:0Pl0030?oo
O`2P8?00X23`00<0oomo0P2P8?020?ooO`80ogl00`3oogl40:0Pl0<0oomo0P3oO`020?ooO`80X23`
203oogl40:0Pl0L0Oooo0P2P8?1107ooo`7o00000Oooool00003o`00003oogl0oomo06L0oomo0P2P
8?0W0?ooO`<0X23`1@3oogl20:0Pl0D0oomo0P3oO`050:0Pl0L0oomo0P2P8?030?ooO`<0ogl000<0
oomo0:0Pl02P8?000P3oogl20:0Pl0<0oomo0P3oO`050:0Pl080oomo0P2P8?030?ooO`<0X23`201o
ool20:0Pl440Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0R03oogl30:0Pl0H0oomo0`2P8?04
0?ooO`80X23`1`3oogl50:0Pl0@0oomo0P2P8?00103oogl0X23`0:0Pl03oogl40?mo00040?ooO`2P
8?00X23`0:0Pl080oomo0P2P8?050?ooO`80X23`00<0oomo0:0Pl02P8?000P3oogl20:0Pl0@0oomo
0P2P8?1;07ooo`7o00000Oooool00003o`00003oogl0oomo08P0oomo0`2P8?070?ooO`80X23`5P3o
ogl20:0Pl0@0oomo0P3oO`030?ooO`80X23`0`3oogl20:0Pl0`0oomo0P3oO`060?ooO`03o`00001o
ool0Oooo04P0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0Q03oogl20?mo00L0oomo0P2P8?05
0?ooO`80ogl000<0oomo0?mo003oO`003@3oogl20:0Pl080oomo0P2P8?00103oogl0ogl00?mo003o
ogl20:0Pl1h0oomo00?o000007ooo`1oool0B01oool1o`00007ooooo00000ol00000oomo0?ooO`1j
0?ooO`80X23`203oogl20?mo00L0oomo102P8?030?ooO`80ogl000@0oomo0?mo003oO`00oomo0P2P
8?00103oogl0X23`0:0Pl03oO`020:0Pl0@0oomo0P2P8?020?ooO`80X23`0`3oO`000`3oogl0X23`
0:0Pl0080?ooO`<0X23`503oogl00ol00000Oooo07ooo`0207ooo`80X23`4P1oool20:0Pl2l0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0H@3oogl20:0Pl0h0oomo0P2P8?070?ooO`@0X23`203o
ogl20?mo0080X23`103oogl0103oO`00X23`0:0Pl02P8?040?ooO`80X23`0P3oogl50:0Pl0030?mo
002P8?00X23`00T0oomo00@0ogl00:0Pl02P8?00oomo0P2P8?090?ooO`<0X23`4`3oogl30:0Pl0<0
Oooo0P2P8?0507ooo`80X23`0P1oool20:0Pl0L0Oooo0P2P8?0>07ooo`80X23`7`1oool1o`00007o
oooo00000ol00000X23`0:0Pl01Q0?ooO`<0X23`3@3oogl20:0Pl0T0oomo0P2P8?080?ooO`@0X23`
1P3oogl20:0Pl080ogl00P3oogl30:0Pl080oomo102P8?000`3oogl0ogl00?mo00050?ooO`@0X23`
00@0ogl00:0Pl02P8?00oomo0P2P8?0=0?ooO`80X23`2P3oogl20:0Pl0@0oomo0`2P8?0:07ooo`80
X23`0P1oool20:0Pl1L0Oooo0P2P8?0H07ooo`80ogl01@1oool1o`00007ooooo00000ol00000X23`
0:0Pl0030?ooO`80X23`FP3oogl20:0Pl0030?ooO`2P8?00X23`0280oomo0`2P8?020?mo00H0oomo
0P2P8?00103oO`00oomo0?ooO`3oogl20:0Pl080oomo0P3oO`020:0Pl0<0oomo102P8?000`3oogl0
X23`0:0Pl0020:0Pl0L0oomo0P2P8?070?ooO`D0X23`1`3oogl20:0Pl0030?ooO`2P8?00X23`00<0
oomo0P2P8?020?ooO`03o`00001oool0Oooo0080X23`?01oool20?mo00D0Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl00`3oogl20:0Pl5X0oomo0P2P8?0V0?ooO`@0X23`00<0oomo0:0Pl02P8?00
0`3oogl20:0Pl0P0oomo0P3oO`020?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?050?ooO`80X23`
00<0ogl00?ooO`3oogl00P3oogl20:0Pl0L0oomo102P8?080?ooO`80X23`1P3oogl40:0Pl003o`00
001oool0Oooo0080X23`1P1oool20?mo03/0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0O03o
ogl20:0Pl0X0oomo0`2P8?000`3oogl0X23`0:0Pl0020?ooO`H0X23`0`3oO`040?ooO`80ogl00P2P
8?000`3oogl0X23`0:0Pl0040:0Pl0<0oomo0P2P8?00103oO`00oomo0?ooO`3oogl20:0Pl0H0oomo
0P3oO`000`3oogl0X23`0:0Pl0070?ooO`80X23`0P3oO`050?ooO`L0X23`1`1oool20:0Pl080ogl0
>`1oool1o`00007ooooo00000ol00000oomo0?ooO`1l0?ooO`80X23`0P3oogl20:0Pl0H0oomo0P2P
8?030?ooO`80X23`00<0oomo0:0Pl02P8?00102P8?030?mo00@0oomo0P3oO`030?ooO`80X23`0P3o
ogl20:0Pl0D0oomo0P2P8?020?ooO`80X23`0P3oogl30:0Pl0040?ooO`3oO`00ogl00?ooO`80X23`
1`3oogl30:0Pl080ogl0103oogl40:0Pl0040?ooO`2P8?00X23`o`000080X23`101oool20:0Pl3d0
Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0P03oogl20:0Pl0/0oomo0P2P8?050?ooO`80X23`
0P3oO`0:0?ooO`80X23`2@3oogl20:0Pl0H0oomo0`2P8?040?ooO`80X23`203oogl20:0Pl080ogl0
1P3oogl20:0Pl0<0oomo00?o00000:0Pl02P8?00@`1oool1o`00007ooooo00000ol00000oomo0?oo
O`2;0?ooO`80ogl000<0oomo0?mo003oO`000P3oO`020?ooO`80ogl00P2P8?000`3oO`00oomo0?oo
O`0H0?ooO`80X23`1@3oogl20:0Pl0030?ooO`2P8?00X23`01L0oomo00?o000007ooo`2P8?000P2P
8?1007ooo`7o00000Oooool00003o`00003oogl0oomo0180oomo0P2P8?1b0?ooO`80X23`0`3oogl2
0?mo00@0X23`00@0ogl00?ooO`3oogl0ogl00`2P8?000`3oO`00oomo0?ooO`070?ooO`80ogl01`3o
ogl40:0Pl0@0oomo0P2P8?020?mo00<0oomo0P2P8?000`3oogl0X23`0:0Pl0050?ooO`80X23`1P3o
ogl20:0Pl0D0oomo0P2P8?000`3oogoo000007ooo`030:0Pl0@0Oooo102P8?0h07ooo`7o00000Ooo
ool00003o`00003oogl0oomo0180oomo0P2P8?1J0?ooO`80X23`503oogl40:0Pl0D0oomo102P8?00
103oO`00oomo0?ooO`3oogl20:0Pl0<0oomo0P3oO`030?ooO`80ogl000<0oomo0?mo003oO`001`3o
ogl40:0Pl0H0oomo0P3oO`040?ooO`80X23`0P3oogl20:0Pl0<0oomo0P2P8?050?ooO`030?mo002P
8?00X23`00D0oomo0P2P8?000`3oogoo000007ooo`020:0Pl0D0Oooo102P8?0h07ooo`7o00000Ooo
ool00003o`00003oogl0oomo00<0oomo0P2P8?0W0?ooO`80X23`;03oogl20:0Pl180oomo0P2P8?0D
0?ooO`@0X23`0`3oogl20:0Pl0<0oomo0P3oO`050?ooO`D0ogl00P3oogl30?mo0080X23`4P3oogl2
0?mo00<0oomo102P8?000`3oogl0X23`0:0Pl00:0?ooO`80ogl00`3oogl20:0Pl0D0oomo00?o0000
0:0Pl02P8?00101oool20:0Pl00307ooo`2P8?00X23`0080Oooo0P3oO`0d07ooo`7o00000Oooool0
0003o`00003oogl0oomo00<0oomo0P2P8?0W0?ooO`80X23`;03oogl20:0Pl2X0oomo0P2P8?030?oo
O`80X23`0`3oogl20?mo00D0oomo0P3oO`020:0Pl080oomo0`3oO`000`3oogl0X23`0:0Pl00G0?oo
O`@0X23`0`3oogl20:0Pl0@0oomo0P2P8?050?ooO`80ogl00P2P8?050?ooO`06o`00002P8?00X23`
0:0Pl03oO`00Oooo1P2P8?0207ooo`80ogl0=01oool1o`00007ooooo00000ol00000oomo0?ooO`06
0?ooO`80X23`R03oogl20:0Pl080oomo0P3oO`030?ooO`80X23`0P3oogl40?mo00/0oomo0P3oO`0<
0?ooO`80ogl000<0oomo0?mo003oO`000P3oogl20:0Pl0@0oomo0P2P8?050?ooO`80ogl0203oogl0
1?l00000X23`0:0Pl03oO`030:0Pl00307ooo`2P8?00X23`00D0X23`=01oool1o`00007ooooo0000
0ol00000X23`0:0Pl0060?ooO`80X23`B03oogl20:0Pl0`0oomo0P2P8?0[0?ooO`@0X23`00<0oomo
0:0Pl02P8?000P2P8?020?mo00T0oomo0P3oO`0;0?ooO`80ogl0303oogl20:0Pl0030?ooO`3oO`00
ogl001L0oomo0P3oO`001?l00000Oooo07ooo`1oool20:0Pl0<0Oooo1P2P8?0507ooo`80ogl0101o
ool20:0Pl2L0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?00;`3oogl20:0Pl1<0oomo0P2P8?0:
0?ooO`80X23`303oogl20:0Pl2L0oomo0P2P8?020?ooO`@0X23`0`3oogl20:0Pl0`0oomo0P2P8?08
0?ooO`80X23`0`3oogl20:0Pl0T0oomo0`2P8?020?mo01L0oomo0P3oO`000`3oogoo000007ooo`02
07ooo`80X23`0`1oool50:0Pl0D0Oooo0P3oO`0407ooo`80X23`9`1oool1o`00007ooooo00000ol0
0000oomo0?ooO`0_0?ooO`80X23`4`3oogl20:0Pl440oomo0P2P8?0G0?ooO`80X23`203oogl20:0P
l0<0oomo0P2P8?090?ooO`<0X23`703oogl01?l00000Oooo07ooo`1oool20:0Pl0<0Oooo1@2P8?0d
07ooo`7o00000Oooool00003o`00003oogl0oomo07@0oomo0P2P8?0E0?ooO`80X23`1@3oogl20:0P
l0/0oomo0P2P8?0B0?ooO`80ogl000<0oomo0:0Pl02P8?003@3oogl20:0Pl180oomo00?o000007oo
o`1oool00`1oool50:0Pl00307ooo`2P8?00X23`00D0Oooo0P2P8?0]07ooo`7o00000Oooool00003
o`00003oogl0oomo01l0oomo0P2P8?1C0?ooO`80X23`5@3oogl20:0Pl0030?ooO`2P8?00X23`0080
oomo0P2P8?030?ooO`80ogl00P3oogl20:0Pl080oomo0P2P8?050?ooO`80X23`1`3oogl30?mo0004
0?ooO`3oO`00ogl00?ooO`80X23`0`3oogl20:0Pl0030?ooO`2P8?00X23`0080oomo0P3oO`000`3o
ogl0X23`0:0Pl00?0?ooO`80X23`0P3oogl01Ol00000Oooo0:0Pl02P8?00Oooo00D0X23`00<0Oooo
0:0Pl02P8?001@1oool20:0Pl080ogl0:`1oool1o`00007ooooo00000ol00000X23`0:0Pl00O0?oo
O`80X23`G`3oogl20:0Pl0X0oomo102P8?070?ooO`80ogl00P3oogl20:0Pl0T0oomo0P2P8?040?oo
O`80X23`00@0oomo0?mo003oO`00ogl02@3oogl20:0Pl0030?ooO`2P8?00X23`0080oomo0P3oO`0B
0?ooO`80X23`00<0oomo0:0Pl02P8?000`2P8?0307ooo`<0X23`101oool20:0Pl0@0Oooo0P3oO`0[
07ooo`7o00000Oooool00003o`00002P8?00X23`0800oomo0P2P8?0:0?ooO`80X23`503oogl20?mo
00<0oomo0P2P8?000`3oogl0X23`0:0Pl0020:0Pl0@0oomo0P2P8?060?ooO`80ogl00P3oogl20:0P
l0<0oomo0P3oO`0B0?ooO`D0X23`1P1oool20:0Pl080Oooo102P8?0a07ooo`7o00000Oooool00003
o`00003oogl0oomo06/0oomo0P2P8?0T0?ooO`D0X23`2`3oogl20:0Pl0040?mo003oogl0oomo0?oo
O`80X23`00<0ogl00:0Pl02P8?001@3oogl30:0Pl0D0oomo00<0ogl00:0Pl02P8?000P3oO`050?oo
O`80ogl02@3oogl20:0Pl0L0oomo0P2P8?020?ooO`03o`00001oool0Oooo00@0Oooo0P2P8?001@1o
ool0X23`0:0Pl02P8?00Oooo0080X23`101oool20:0Pl100Oooo0P3oO`0H07ooo`7o00000Oooool0
0003o`00003oogl0oomo06/0oomo0P2P8?0T0?ooO`D0X23`00<0oomo0:0Pl02P8?00203oogl20:0P
l0@0oomo0P3oO`020:0Pl0H0oomo0P2P8?030?ooO`80X23`00@0oomo0?mo002P8?00X23`0P3oO`0=
0?ooO`80ogl000<0oomo0:0Pl02P8?001P3oogl20:0Pl0<0oomo00?o000007ooo`1oool0101oool2
0:0Pl00507ooo`2P8?00X23`0:0Pl01oool00P2P8?0407ooo`80X23`201oool20?mo00H0Oooo0P3o
O`0H07ooo`7o00000Oooool00003o`00003oogl0oomo06`0oomo0P2P8?080?ooO`80X23`7`3oogl2
0:0Pl0H0oomo0P2P8?060?ooO`80ogl00`2P8?050?ooO`80X23`0`3oogl20:0Pl0L0oomo0P2P8?07
0?ooO`80X23`00<0oomo0?mo003oO`002@3oogl20:0Pl0@0oomo00Co000007ooo`1oool0Oooo0P2P
8?00101oool0X23`0:0Pl01oool20:0Pl00407ooo`3oO`00ogl007ooo`80X23`2`1oool20?mo0200
Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?00K03oogl20:0Pl0P0oomo0P2P8?030?ooO`80X23`
403oogl20:0Pl0l0oomo0`2P8?030?mo00@0oomo0P3oO`020:0Pl0D0oomo0P2P8?050?ooO`80ogl0
0P2P8?030?ooO`80X23`0P3oogl20:0Pl0<0oomo0P2P8?0B0?ooO`04o`00001oool0Oooo07ooo`80
X23`00<0Oooo0:0Pl02P8?000`1oool20:0Pl00407ooo`2P8?00X23`0:0Pl080Oooo0P2P8?0Y07oo
o`7o00000Oooool00003o`00002P8?00X23`07/0oomo0P2P8?0@0?ooO`80X23`3`3oogl20:0Pl0@0
ogl0103oogl20?mo00h0oomo0P3oO`020:0Pl0L0oomo0P2P8?0G0?ooO`03o`00001oool0Oooo00T0
Oooo0P2P8?000`1oool0X23`0:0Pl00307ooo`80X23`:@1oool1o`00007ooooo00000ol00000oomo
0?ooO`2@0?ooO`80X23`4P3oogl20:0Pl080oomo0`2P8?040?ooO`@0X23`203oogl20:0Pl1L0oomo
0P2P8?060?ooO`04o`00001oool0Oooo07ooo`80X23`1P1oool30:0Pl300Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl0T03oogl20:0Pl0@0oomo0P2P8?000`3oogl0X23`0:0Pl0020:0Pl0L0oomo
0P2P8?020?ooO`<0X23`103oogl60:0Pl0H0oomo0P2P8?050?ooO`80X23`2P3oogl20:0Pl0040?oo
O`2P8?00X23`0?ooO`80X23`1`3oogl20:0Pl00407ooo`2P8?00X23`0:0Pl0D0Oooo0`2P8?000`1o
ool0X23`0:0Pl0040:0Pl2T0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0UP3oogl20:0Pl003
0?ooO`2P8?00X23`0080X23`103oogl20:0Pl100oomo0P2P8?000`3oogl0X23`0:0Pl00:0?ooO`80
X23`1P3oogl60:0Pl0030?ooO`2P8?00X23`0080oomo0P2P8?050?ooO`040?mo002P8?00X23`07oo
o`<0X23`1@1oool20?mo0080Oooo1`2P8?0=07ooo`80ogl06@1oool1o`00007ooooo00000ol00000
oomo0?ooO`2J0?ooO`80X23`1@3oogl20:0Pl080ogl00`3oogl40:0Pl0D0oomo0P2P8?030?ooO`80
X23`103oogl40:0Pl0X0oomo1`2P8?040?ooO`80X23`1@3oogl20?mo0080Oooo0P2P8?000`3oO`00
X23`0:0Pl00307ooo`80ogl01@1oool40:0Pl0d0Oooo0P3oO`0I07ooo`7o00000Oooool00003o`00
003oogl0oomo07h0oomo0P2P8?0J0?ooO`80X23`103oogl20:0Pl0030?ooO`3oO`00ogl000<0oomo
102P8?020?mo00<0oomo0P2P8?030?ooO`80X23`103oogl40:0Pl0l0oomo102P8?000`3oogl0ogl0
0?mo00070?ooO`04o`00001oool0Oooo07ooo`@0X23`1P1oool20?mo0080Oooo0P2P8?0Z07ooo`7o
00000Oooool00003o`00003oogl0oomo07h0oomo0P2P8?0F0?ooO`@0X23`1P3oogl20:0Pl0030?oo
O`3oO`00ogl000<0oomo0P2P8?00103oO`00X23`0:0Pl03oO`080?ooO`80X23`3P3oogl20:0Pl0T0
oomo0P2P8?000`3oogl0ogl00?mo00030?ooO`80X23`0`3oogl00ol00000Oooo07ooo`030:0Pl0<0
Oooo0P2P8?0207ooo`80ogl00P1oool30:0Pl2T0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
5P3oogl20:0Pl7h0oomo102P8?0:0?ooO`80ogl00`3oogl20?mo0080X23`00<0ogl00?ooO`3oogl0
0P2P8?0;0?ooO`80X23`1P3oogl30:0Pl0@0oomo0P3oO`000`3oogl0X23`0:0Pl0040?ooO`80X23`
0P3oogl20:0Pl0<0oomo00?o000007ooo`1oool00P2P8?00103oO`00Oooo07ooo`1oool20:0Pl004
07ooo`2P8?00X23`0:0Pl080Oooo0`2P8?0Y07ooo`7o00000Oooool00003o`00003oogl0oomo01H0
oomo0P2P8?1^0?ooO`80X23`5P3oogl20:0Pl0@0oomo0P3oO`040?ooO`060?mo002P8?00X23`0?mo
003oogl0ogl00P2P8?040?ooO`80X23`0`3oogl40:0Pl0H0oomo0P2P8?000`3oogl0ogl00?mo0002
0?ooO`80ogl000<0oomo0:0Pl02P8?00103oogl20:0Pl080oomo0P2P8?030?ooO`80ogl00P1oool2
0:0Pl0@0Oooo1@2P8?0307ooo`80ogl0:@1oool1o`00007ooooo00000ol00000oomo0?ooO`260?oo
O`80X23`5P3oogl20:0Pl0X0oomo103oO`000`3oogl0ogl00?mo00050?ooO`80X23`0`3oogl20:0P
l0030?mo003oogl0oomo00P0oomo0P3oO`0?0?ooO`80X23`0`3oogl20?mo0080Oooo0P2P8?0407oo
o`80X23`1P1oool20?mo02T0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0103oogl20:0Pl9L0
oomo0P2P8?080?ooO`80X23`0P3oO`020?ooO`80X23`103oogl50:0Pl1L0oomo0P2P8?030?ooO`80
X23`0P3oO`070?ooO`04o`00001oool0X23`0:0Pl0<0Oooo0P3oO`0:07ooo`80X23`9`1oool1o`00
007ooooo00000ol00000X23`0:0Pl0040?ooO`80X23`O03oogl20:0Pl1T0oomo0P2P8?080?ooO`80
X23`00@0ogl00:0Pl02P8?00oomo0P2P8?030?ooO`H0X23`0P3oogl20:0Pl0L0oomo0P3oO`020?oo
O`80X23`103oogl60:0Pl0030?ooO`2P8?00X23`00<0X23`1P3oogl01?l00000Oooo0:0Pl02P8?03
07ooo`80ogl00`1oool20:0Pl0D0Oooo0P2P8?0W07ooo`7o00000Oooool00003o`00002P8?00X23`
0880oomo0P2P8?0M0?ooO`80X23`1P3oogl30:0Pl080ogl0103oogl30:0Pl0@0oomo0`2P8?060?oo
O`80X23`00<0ogl00?ooO`3oogl00P2P8?040?ooO`80X23`0P3oogl20:0Pl0030?ooO`2P8?00X23`
00<0X23`1`3oogl00ol00000Oooo07ooo`0307ooo`80ogl00P1oool00`3oO`00X23`0:0Pl00307oo
o`80ogl00P1oool30:0Pl2@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0X@3oogl20:0Pl0H0
oomo0P2P8?000`3oogl0ogl00?mo00080?ooO`D0X23`103oogl50:0Pl080oomo0P2P8?060?ooO`80
X23`1@3oogl20?mo0080X23`1`3oogl00ol00000Oooo07ooo`0707ooo`80ogl00`1oool20:0Pl003
0?mo001oool0ogl000<0X23`901oool1o`00007ooooo00000ol00000oomo0?ooO`2M0?ooO`80X23`
3P3oogl20:0Pl0@0oomo0P3oO`000`3oogl0X23`0:0Pl0050:0Pl080oomo1P2P8?00103oogl0X23`
0:0Pl02P8?050?ooO`80X23`1@3oogl20?mo0080X23`0`3oogl20:0Pl080oomo00?o000007ooo`1o
ool00P1oool20:0Pl0@0Oooo0P3oO`0207ooo`80X23`0P1oool00`3oO`00X23`0:0Pl00U07ooo`7o
00000Oooool00003o`00003oogl0oomo0080X23`V`3oogl20:0Pl0/0oomo0P2P8?000`3oogl0X23`
0:0Pl0040?ooO`<0ogl00P2P8?000`3oogl0X23`0:0Pl0020:0Pl080ogl00P3oogl50:0Pl0030?oo
O`2P8?00X23`00D0oomo0P2P8?050?ooO`80ogl01@3oogl20:0Pl080ogl000<0oomoo`00001oool0
0P1oool30:0Pl0<0Oooo0P3oO`0707ooo`80X23`9@1oool1o`00007ooooo00000ol00000oomo0?oo
O`020:0Pl9l0oomo0P2P8?070?ooO`80X23`1P3oogl40?mo0080X23`00<0oomo0:0Pl02P8?001P2P
8?020?mo00030?ooO`2P8?00X23`0080X23`1P3oogl30:0Pl0/0oomo0P2P8?020?mo00050?ooOol0
0000ogl00?mo001oool00`2P8?0307ooo`80ogl0;P1oool1o`00007ooooo00000ol00000oomo0?oo
O`2A0?ooO`80X23`3P3oogl20:0Pl0l0oomo0P3oO`000`3oogl0ogl00?mo00050?ooO`D0X23`0P3o
O`050:0Pl0030?mo003oogl0oomo00@0oomo0P2P8?050?ooO`80ogl0103oogl20:0Pl0<0oomo00Co
00000?mo003oO`00Oooo1@2P8?0607ooo`80X23`:@1oool1o`00007ooooo00000ol00000oomo0?oo
O`2A0?ooO`80X23`:@3oogl50:0Pl080oomo102P8?020?mo00d0oomo0P3oO`090?ooO`03o`00001o
ool0Oooo0080Oooo00@0ogl00:0Pl02P8?00X23`1P1oool20:0Pl2T0Oooo0Ol00001ooooo`0000Co
00000?ooO`3oogl0oomo0P2P8?2C0?ooO`80X23`2`3oogl20:0Pl1@0oomo0P2P8?020?ooO`80ogl0
203oogl20:0Pl0050?ooO`3oO`00X23`0:0Pl03oogl00P2P8?00103oogl0X23`0:0Pl03oogl20?mo
00030?ooO`3oO`00ogl000P0oomo00?o000007ooo`1oool00P1oool20:0Pl0l0Oooo0P2P8?0R07oo
o`7o00000Oooool00004o`00003oogl0oomo0?ooO`80X23`Q03oogl20:0Pl080oomo0P2P8?090?oo
O`80X23`2`3oogl20:0Pl1@0oomo0P2P8?020?ooO`80ogl00`3oogl20:0Pl0<0oomo0P2P8?001@3o
ogl0ogl00:0Pl02P8?00oomo0080X23`00@0oomo0:0Pl02P8?00oomo0P2P8?00103oogl0ogl00:0P
l02P8?040?ooO`80X23`00<0oomoo`00001oool00`1oool20:0Pl0d0Oooo102P8?0R07ooo`7o0000
0Oooool00004o`00002P8?00X23`0:0Pl8H0oomo0`2P8?000`3oogl0X23`0:0Pl00R0?ooO`80X23`
0`3oogl20:0Pl0P0oomo0P3oO`020?ooO`80X23`0`3oogl30:0Pl080oomo0P3oO`020?ooO`80X23`
0P3oogl80:0Pl080oomo0P2P8?020?ooO`03o`00001oool0Oooo0100Oooo0P2P8?0T07ooo`7o0000
0Oooool00004o`00002P8?00X23`0:0Pl8L0oomo0P2P8?0U0?ooO`@0X23`00<0oomo0:0Pl02P8?00
103oogl20?mo0080X23`00@0ogl00:0Pl02P8?00oomo0P3oO`030?ooO`<0X23`0P3oogl20?mo0080
oomo0`2P8?030?ooO`H0X23`1P3oogl00ol00000Oooo07ooo`0f07ooo`7o00000Oooool00003o`00
003oogl0oomo08d0oomo0P2P8?0R0?ooO`80X23`1`3oogl20?mo0080X23`00@0oomo0:0Pl02P8?00
oomo0P3oO`020:0Pl0030?ooO`2P8?00X23`00<0oomo0P2P8?030?ooO`80X23`0`3oogl40:0Pl0L0
oomo0P2P8?0>07ooo`80ogl0:01oool1o`00007ooooo00000ol00000oomo0?ooO`1U0?ooO`80X23`
9P3oogl30:0Pl2/0oomo0`3oO`000`3oogl0ogl00?mo00020:0Pl0030?mo002P8?00X23`00D0oomo
00<0ogl00:0Pl02P8?000P3oogl20:0Pl0@0oomo0P2P8?090?ooO`80X23`3P1oool20?mo02P0Oooo
0Ol00001ooooo`0000?o00000?ooO`3oogl0I@3oogl20:0Pl2L0oomo0P2P8?0R0?ooO`80ogl000<0
oomo0:0Pl02P8?000`3oogl40?mo00030?ooO`3oO`00ogl000@0X23`0P3oogl20:0Pl080oomo0P3o
O`030?ooO`<0X23`3`3oogl00ol00000X23`0:0Pl00407ooo`80ogl0<01oool1o`00007ooooo0000
0ol00000oomo0?ooO`2b0?ooO`80ogl000<0oomo0:0Pl02P8?000`3oogl40?mo00030?ooO`3oO`00
ogl00080oomo0P2P8?020?ooO`80X23`00<0oomo0:0Pl02P8?001@3oogl40:0Pl0030?ooO`3oO`00
X23`00<0X23`1`3oogl00ol00000X23`0:0Pl00407ooo`80ogl05`1oool20?mo01L0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl0_`3oogl20?mo00T0oomo0P2P8?050?ooO`80ogl00P2P8?000`3o
ogl0ogl00:0Pl0030:0Pl0P0oomo00?o000007ooo`1oool0701oool20?mo01L0Oooo0Ol00001oooo
o`0000?o00000?ooO`3oogl0^P3oogl20:0Pl1<0oomo0P2P8?080?ooO`80ogl01@3oogl20:0Pl003
0?ooOol00000Oooo00H0Oooo0`3oO`0]07ooo`7o00000Oooool00003o`00003oogl0oomo09D0oomo
0P2P8?0S0?ooO`80X23`1`3oogl30?mo0080X23`0P3oogl20?mo00<0oomo0P2P8?080?ooO`80ogl0
0P3oogl20?mo00030?ooO`2P8?00X23`0080ogl00P1oool20?mo00<0Oooo0`3oO`0]07ooo`7o0000
0Oooool00003o`00003oogl0oomo09D0oomo0P2P8?0/0?ooO`030?mo002P8?00X23`00@0X23`0P3o
O`020?ooO`80X23`3@3oogl20?mo00<0oomo0P3oO`0207ooo`<0ogl0<P1oool1o`00007ooooo0000
0ol00000oomo0:0Pl0030:0Pl0030?ooO`2P8?00X23`0:l0oomo0P2P8?060?ooO`80X23`103oogl0
0`3oO`00X23`0:0Pl0020?mo0080X23`0P3oogl20?mo0080X23`4`3oogl01?l00000Oooo07ooo`1o
ool20?mo000407ooo`3oO`00X23`0:0Pl2h0Oooo0Ol00001ooooo`0000?o00000?ooO`2P8?000`2P
8?000`3oogl0X23`0:0Pl01l0?ooO`80X23`<@3oogl20:0Pl0<0oomo0P2P8?000`3oogl0X23`0:0P
l0040?ooO`80ogl000<0oomo0:0Pl02P8?000P3oogl50?mo00030?ooO`2P8?00X23`00P0oomo0P2P
8?050?ooO`80ogl000?o000007ooo`1oool00P1oool30?mo0080X23`4@1oool20?mo01/0Oooo0Ol0
0001ooooo`0000?o00000?ooO`3oogl0PP3oogl20:0Pl3H0oomo0P2P8?0:0?ooO`80X23`0P3oogl3
0?mo00<0oomo0P2P8?040?ooO`80X23`0P3oogl20:0Pl080oomo0P3oO`00103oogl0ogl00?mo0?l0
000407ooo`80ogl01P1oool50?mo00T0Oooo0P3oO`0;07ooo`80ogl03P1oool1o`00007ooooo0000
1?l00000oomo0:0Pl02P8?300?ooO`80ogl00`3oogl20?mo00<0oomo0P3oO`020:0Pl080ogl00`3o
ogl40:0Pl080oomo0P2P8?020?ooO`80ogl00`3oogl00ol00000Oooo07ooo`0:07ooo`D0ogl05P1o
ool20?mo00h0Oooo0Ol00001ooooo`0000Co00000?ooO`2P8?00X23``03oogl00`3oO`00X23`0:0P
l0020?ooO`80X23`1@3oogl20:0Pl080ogl00`3oogl20:0Pl0@0oomo0P2P8?030?ooO`80X23`0P3o
ogl00ol00000Oooo07ooo`0D07ooo`@0ogl07@1oool1o`00007ooooo00001?l00000oomo0:0Pl02P
8?310?ooO`80X23`0P3oogl20:0Pl0`0oomo0P3oO`090?ooO`80X23`0P3oogl00ol00000Oooo07oo
o`0D07ooo`@0ogl07@1oool1o`00007ooooo00000ol00000oomo0?ooO`1L0?ooO`80X23`F`3oogl4
0:0Pl0D0oomo0P3oO`000`3oogl0X23`0:0Pl0090?ooO`80X23`4@3oogl00ol00000Oooo07ooo`0=
07ooo`80ogl09P1oool1o`00007ooooo00000ol00000oomo0?ooO`1L0?ooO`80X23`B`3oogl20:0P
l0h0oomo102P8?050?ooO`80ogl000@0oomo0:0Pl02P8?00X23`0`3oogl20:0Pl080oomo00<0ogl0
0:0Pl02P8?001@3oogl20?mo00X0oomo00Co000007ooo`3oO`00ogl0101oool20?mo0080Oooo0P3o
O`0207ooo`80ogl05`1oool20?mo00d0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0YP3oogl2
0:0Pl0030?ooO`2P8?00X23`00H0oomo0P2P8?0C0?ooO`80X23`0`3oogl20:0Pl080oomo103oO`00
0`3oogl0X23`0:0Pl0030?mo00<0oomo103oO`020?ooO`80ogl000?o00000?mo003oO`000P3oO`02
07ooo`80ogl00P1oool20?mo01/0Oooo0P3oO`0=07ooo`7o00000Oooool00003o`00003oogl0oomo
0:H0oomo0P2P8?090?ooO`80X23`0`3oogl20:0Pl1D0oomo0P3oO`020?ooO`80ogl000<0oomo0:0P
l02P8?000P3oO`040?ooO`@0ogl00P3oogl20?mo0003o`00001oool0Oooo0080ogl00P2P8?0607oo
o`80ogl02@1oool20?mo01d0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0]P3oogl20:0Pl080
ogl02`3oogl20:0Pl0H0oomo1@3oO`020?ooO`80X23`0P3oO`050?ooO`80ogl01@3oogl00ol00000
Oooo07ooo`0207ooo`80X23`0P3oO`000`1oool0ogl00?mo00040?mo000307ooo`3oO`00ogl000D0
Oooo0P3oO`0M07ooo`7o00000Oooool00003o`00003oogl0oomo0:l0oomo0P2P8?020?ooO`80X23`
0`3oogl20?mo00/0oomo0P2P8?040?ooO`80X23`0P3oogl20:0Pl0030?mo003oogl0oomo00@0X23`
1@3oogl40?mo00<0oomo00?o000007ooo`1oool0101oool00`3oO`00X23`0:0Pl0030?mo000407oo
o`3oO`00ogl007ooo`80ogl0901oool1o`00007ooooo00000ol00000oomo0?ooO`2_0?ooO`<0X23`
00<0oomo0:0Pl02P8?005P3oogl20:0Pl080oomo0P2P8?030?ooO`040?mo002P8?00X23`0:0Pl0L0
oomo0P3oO`00103oogl0ogl00?mo0?l0000607ooo`040?mo002P8?00X23`07ooo`80ogl000<0Oooo
0?mo003oO`000P2P8?0U07ooo`7o00000Oooool00003o`00003oogl0oomo0;00oomo0P2P8?0<0?oo
O`80X23`1P3oogl20:0Pl080oomo00<0ogl00:0Pl02P8?000`3oO`040?ooO`<0X23`0P3oogl20?mo
00<0oomo1P3oO`000ol00000Oooo07ooo`0307ooo`80ogl00P2P8?00101oool0ogl00?mo001oool2
0?mo0080X23`0`1oool20?mo00P0Oooo0P2P8?0F07ooo`7o00000Oooool00003o`00003oogl0oomo
0;h0oomo0P2P8?060?ooO`80X23`0P3oogl00`3oO`00X23`0:0Pl0030?mo00@0oomo0P2P8?030?oo
O`80ogl00`3oogl40?mo0080oomo00?o000007ooo`1oool00`1oool20?mo0080X23`2`1oool20?mo
00P0Oooo0P2P8?0F07ooo`7o00000Oooool00004o`00003oogl0oomo0?ooO`80X23`Y`3oogl20:0P
l1P0oomo0P2P8?0>0?ooO`80ogl00`3oogl20?mo0080oomo0`3oO`030?ooO`80X23`0P3oO`0807oo
o`80ogl02P1oool20?mo01h0Oooo0Ol00001ooooo`0000Co00000?ooO`3oogl0oomo0P2P8?2W0?oo
O`80X23`4`3oogl40:0Pl0030?ooO`2P8?00X23`00@0oomo0P3oO`020:0Pl0D0oomo0`3oO`00103o
ogl0X23`0:0Pl03oO`020:0Pl080ogl00P2P8?020?mo00030?ooO`2P8?00X23`0080ogl000<0Oooo
0?mo003oO`001@1oool30?mo00D0Oooo1P3oO`0N07ooo`7o00000Oooool00003o`00003oogl0oomo
0;l0oomo102P8?020?mo00D0oomo0P3oO`020:0Pl0030?mo003oogl0oomo0080oomo0P3oO`020?oo
O`T0X23`0P3oO`030:0Pl080Oooo1@3oO`0407ooo`@0ogl00`1oool40?mo0200Oooo0Ol00001oooo
o`0000?o00000?ooO`3oogl0_`3oogl20:0Pl080oomo0P3oO`000`3oogl0X23`0:0Pl0050?ooO`80
X23`203oogl20?mo0080X23`00<0ogl00:0Pl02P8?000`2P8?001@3oO`00X23`0:0Pl03oO`00Oooo
00<0ogl000<0Oooo0?mo003oO`000P3oO`0207ooo`D0ogl09P1oool1o`00007ooooo00000ol00000
oomo0?ooO`2m0?ooO`80X23`103oogl50:0Pl0D0oomo0P2P8?0:0?ooO`80X23`00<0oomo0:0Pl02P
8?001@2P8?000`3oO`3o000007ooo`030?mo00<0Oooo2@3oO`0707ooo`80ogl07@1oool1o`00007o
oooo00000ol00000oomo0?ooO`2m0?ooO`80X23`103oogl30:0Pl0D0oomo0P2P8?0<0?ooO`<0X23`
00<0oomo0?mo003oO`00102P8?000`3oO`3o00000?mo00030?mo000307ooo`3oO`00ogl00080Oooo
103oO`000`1oool0ogl00?mo000207ooo`<0ogl00P1oool20?mo01d0Oooo0Ol00001ooooo`0000Co
00000?ooO`2P8?00X23`^`3oogl20:0Pl0H0oomo0P2P8?050?ooO`80X23`00<0oomo0:0Pl02P8?00
0`2P8?060?ooO`<0X23`00<0oomo0?mo003oO`000`2P8?0:0?mo0080Oooo0P3oO`000`1oool0ogl0
0?mo00020?mo0080Oooo0`3oO`0Q07ooo`7o00000Oooool00004o`00003oogl0X23`0:0Pl;/0oomo
0P2P8?060?ooO`80X23`00<0oomo0:0Pl02P8?000P3oogl80:0Pl0H0oomo0P2P8?001@3oogl0X23`
0:0Pl03oogl0ogl000@0X23`00<0ogl007ooo`3oO`001@3oO`0207ooo`D0ogl00P1oool20:0Pl080
ogl000<0Oooo0?mo003oO`001P1oool20?mo01L0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
a`3oogl20:0Pl0<0oomo102P8?090?ooO`80X23`00D0oomo0:0Pl02P8?00oomo0?mo00040:0Pl003
o`00001oool0Oooo0080ogl000<0Oooo0?mo003oO`000P1oool30?mo00@0Oooo0P2P8?020?mo0003
07ooo`3oO`00ogl000H0Oooo0P3oO`0G07ooo`7o00000Oooool00003o`00003oogl0oomo0<40oomo
0P2P8?080?ooO`80X23`0`3oogl20:0Pl080oomo0P2P8?080?ooO`80X23`103oogl00ol00000ogl0
0?mo00060?mo000307ooo`3oO`00ogl00080ogl00P1oool30?mo00<0Oooo0P3oO`0O07ooo`7o0000
0Oooool00003o`00003oogl0oomo08`0oomo0P2P8?0c0?ooO`80X23`1`3oogl30:0Pl0<0oomo0P2P
8?020?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?020?ooO`050?mo002P8?00X23`0:0Pl03oO`00
0P2P8?020?mo0080X23`3`3oO`0307ooo`80ogl07`1oool1o`00007ooooo00000ol00000oomo0?oo
O`2<0?ooO`80X23`=@3oogl20:0Pl0D0oomo202P8?050?ooO`@0X23`00<0ogl00?ooO`2P8?000`2P
8?000`3oO`00X23`0:0Pl0020?mo0080X23`3P3oO`0U07ooo`7o00000Oooool00003o`00003oogl0
oomo06<0oomo0P2P8?1A0?ooO`80X23`1P3oogl20:0Pl0<0oomo0P2P8?070?ooO`L0X23`103oogl2
0:0Pl0<0ogl000<0oomo0:0Pl02P8?000P2P8?020?mo00030?ooOol00000ogl000`0ogl000@0Oooo
0?mo003oO`00ogl00P1oool40?mo01l0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0H`3oogl2
0:0Pl540oomo0P2P8?060?ooO`80X23`203oogl20:0Pl0H0oomo0`2P8?030?ooO`<0X23`1`3oogl0
1P3oO`00X23`0:0Pl02P8?3o000007oooa40ogl000<0Oooo0?mo003oO`000P3oO`0O07ooo`7o0000
0Oooool00003o`00003oogl0oomo0<P0oomo0P2P8?070?ooO`@0X23`00@0ogl00:0Pl02P8?00X23`
1`3oogl01@3oO`00X23`0:0Pl02P8?3o00000080Oooo403oO`0T07ooo`7o00000Oooool00003o`00
003oogl0oomo0<L0oomo0`2P8?070?ooO`H0X23`00<0oomo0:0Pl02P8?002P3oogl00ol00000Oooo
07ooo`020?mo000307ooo`3oO`00ogl000/0ogl0101oool20?mo01h0Oooo0Ol00001ooooo`0000?o
00000?ooO`3oogl0?P3oogl20:0Pl8L0oomo0P2P8?070?ooO`L0X23`00<0oomo0:0Pl02P8?002P3o
ogl00ol00000Oooo07ooo`0307ooo`/0ogl00P1oool70?mo00<0Oooo0P3oO`0H07ooo`7o00000Ooo
ool00003o`00003oogl0oomo03h0oomo0P2P8?2@0?ooO`D0X23`0`3oogl20:0Pl0X0oomo00?o0000
07ooo`1oool0101oool30?mo0080Oooo1@3oO`0207ooo`L0ogl00`1oool20?mo01P0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl0eP3oogl60:0Pl0P0oomo00?o000007ooo`1oool01`1oool20?mo
0080X23`103oO`0207ooo`<0ogl00P1oool20?mo01`0Oooo0Ol00001ooooo`0000?o00000?ooO`3o
ogl0d03oogl20:0Pl0@0oomo2@2P8?050?ooO`03o`00001oool0Oooo00L0Oooo0P3oO`020:0Pl0@0
ogl000<0Oooo0?mo003oO`001P3oO`0L07ooo`7o00000Oooool00003o`00003oogl0oomo0<X0oomo
0P2P8?040?ooO`80X23`103oogl90:0Pl0D0oomo00?o000007ooo`1oool00P2P8?0807ooo`80X23`
1`3oO`000`1oool0ogl00?mo000N07ooo`7o00000Oooool00003o`00003oogl0oomo04<0oomo0P2P
8?250?ooO`80X23`103oogl20:0Pl0@0oomo1@2P8?090?ooO`03o`00001oool0Oooo0080X23`0P1o
ool20:0Pl0@0Oooo0P2P8?020?mo0080X23`203oO`0L07ooo`7o00000Oooool00003o`00003oogl0
oomo04<0oomo0P2P8?2;0?ooO`80X23`1@3oogl20:0Pl0H0oomo0P2P8?030?ooO`03o`00001oool0
Oooo00@0Oooo0P2P8?0707ooo`030?mo002P8?00X23`00<0Oooo0P3oO`000`1oool0ogl00?mo0006
07ooo`80ogl0501oool1o`00007ooooo00000ol00000oomo0?ooO`3C0?ooO`80X23`0P3oogl20:0P
l0H0oomo0P2P8?00103oogl0X23`0:0Pl?l0000607ooo`80X23`201oool20?mo00h0Oooo0P3oO`0D
07ooo`7o00000Oooool00003o`00003oogl0oomo0;40oomo0P2P8?0P0?ooO`80X23`2P3oogl20:0P
l0050?ooO`2P8?00X23`o`00001oool00P3oO`0607ooo`80X23`0P1oool20:0Pl0H0Oooo0P3oO`02
07ooo`80ogl06`1oool1o`00007ooooo00000ol00000oomo0?ooO`0d0?ooO`80X23`J@3oogl20:0P
l100oomo0P2P8?0/0?ooO`80X23`0`3oogl01?l00000Oooo0?mo003oO`0607ooo`80X23`0P1oool2
0:0Pl0@0Oooo0P2P8?020?mo000407ooo`2P8?00X23`0?mo01/0Oooo0Ol00001ooooo`0000?o0000
0?ooO`3oogl09P3oogl20:0Pl0`0oomo0P2P8?1E0?ooO`80X23`4P3oogl20:0Pl3h0oomo0P2P8?03
0?ooO`04o`00001oool0X23`0:0Pl0H0Oooo0P2P8?0807ooo`80X23`0`1oool20:0Pl0030?mo001o
ool0Oooo01T0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl09P3oogl20:0Pl6<0oomo0P2P8?1G
0?ooO`04o`00001oool0X23`0:0Pl0H0Oooo0P2P8?0[07ooo`7o00000Oooool00003o`00003oogl0
oomo0<P0oomo0P2P8?0J0?ooO`03o`00001oool0Oooo03@0Oooo0Ol00001ooooo`0000?o00000?oo
O`3oogl0b03oogl20:0Pl1X0oomo00?o000007ooo`1oool03@1oool20:0Pl0@0Oooo0P3oO`000`1o
ool0ogl00?mo000L07ooo`7o00000Oooool00003o`00003oogl0oomo0:/0oomo0P2P8?0g0?ooO`03
o`00001oool0Oooo00d0Oooo0P2P8?000`1oool0ogl00?mo00030?mo000307ooo`3oO`00ogl001`0
Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0F03oogl20:0Pl540oomo0P2P8?0g0?ooO`03o`00
001oool0Oooo0100Oooo103oO`001@1oool0X23`0:0Pl02P8?00Oooo0080X23`6@1oool1o`00007o
oooo00000ol00000X23`0:0Pl0060?ooO`80X23`D03oogl20:0Pl8X0oomo00?o000007ooo`1oool0
5@1oool30:0Pl00307ooo`2P8?00X23`01T0Oooo0Ol00001ooooo`0000?o00000:0Pl02P8?001P3o
ogl20:0Pl4h0oomo0P2P8?2<0?ooO`03o`00001oool0Oooo00T0Oooo0P3oO`0<07ooo`80X23`0P1o
ool20:0Pl0<0ogl0501oool1o`00007ooooo00000ol00000oomo0?ooO`1>0?ooO`80X23`1P3oogl2
0:0Pl8`0oomo00?o000007ooo`1oool02@1oool20?mo00`0Oooo0P2P8?00101oool0X23`0:0Pl02P
8?030?mo01@0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0CP3oogl20:0Pl0X0oomo0P2P8?28
0?ooO`04o`00001oool0Oooo07ooo`80X23`3@1oool20:0Pl0P0Oooo0P2P8?000`3oO`00Oooo07oo
o`0E07ooo`7o00000Oooool00003o`00003oogl0oomo05X0oomo0P2P8?280?ooO`04o`00001oool0
Oooo07ooo`80X23`3@1oool20:0Pl280Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0103oogl2
0:0Pl=h0oomo00?o000007ooo`1oool0=01oool1o`00007ooooo00000ol00000oomo0?ooO`040?oo
O`80X23`1P3oogl20:0Pl=H0oomo00?o000007ooo`1oool02`1oool20:0Pl0h0Oooo103oO`000`1o
ool0ogl00?mo000>07ooo`80ogl000<0Oooo0?mo0?l000000Oooool00003o`00003oogl0oomo00`0
oomo0P2P8?3F0?ooO`03o`00001oool0Oooo00/0Oooo0P2P8?0>07ooo`@0ogl00P2P8?000`3oO`00
Oooo0?mo00020?mo00X0Oooo0P3oO`000`1oool0ogl0o`000001ooooo`0000?o00000?ooO`3oogl0
1@3oogl20:0Pl=`0oomo00?o000007ooo`1oool0801oool30:0Pl00407ooo`3oO`00ogl00?mo00h0
Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl01@3oogl20:0Pl=`0oomo00?o000007ooo`1oool0
7`1oool40:0Pl00407ooo`2P8?00X23`0?mo00h0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0
h`3oogl00ol00000Oooo07ooo`0O07ooo`80X23`0`1oool20:0Pl0l0Oooo0Ol00001ooooo`0000?o
00000:0Pl02P8?000P2P8?3Q0?ooO`03o`00001oool0Oooo03D0Oooo0Ol00001ooooo`0000?o0000
0:0Pl02P8?000P2P8?2c0?ooO`80X23`;03oogl00ol00000Oooo07ooo`0e07ooo`7o00000Oooool0
0003o`00003oogl0oomo0;D0oomo0P2P8?0/0?ooO`03o`00001oool0Oooo03D0Oooo0Ol00001oooo
o`0000?o00000?ooO`3oogl00`3oogl20:0Pl9<0oomo0P2P8?190?ooO`03o`00001oool0Oooo02L0
Oooo0P2P8?0407ooo`80X23`1P1oool1o`00007ooooo00000ol00000oomo0?ooO`030?ooO`80X23`
T`3oogl20:0Pl4T0oomo00?o000007ooo`1oool09`1oool20:0Pl0@0Oooo0P2P8?0607ooo`7o0000
0Oooool00003o`00003oogl0oomo0=00oomo0P2P8?020?ooO`80X23`3@3oogl00ol00000Oooo07oo
o`0Z07ooo`80ogl01@1oool20?mo0080X23`0Ol00001ooooo`0000?o00000?ooO`3oogl0KP3oogl2
0:0Pl600oomo0P2P8?020?ooO`80X23`3@3oogl00ol00000Oooo07ooo`0Z07ooo`80ogl00`1oool2
0:0Pl0050?mo002P8?00X23`0:0Pl?l000000Oooool00003o`00003oogl0oomo06h0oomo0P2P8?1c
0?ooO`03o`00001oool0Oooo02l0Oooo0P2P8?001@1oool0X23`0:0Pl02P8?3o0000007ooooo003o
o`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, \
0.889355, 0.889355}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, 0.889355, \
0.889355}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1, pdf1, pdf2, {Red, Blue}];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2, pdf1, pdf2, {Red, Blue}];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1, obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45448 
%%ImageSize: 400 181.791 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0108209 0.238095 [
[ 0 0 0 0 ]
[ 1 .45448 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45448 L
0 .45448 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0108209 0.245293 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0028DC0C4FB9174EB8174EB8184EB7174FB71650B9184EB7199A71349B7336
9C75399A73399B753B4CBA1E4CBA1D4EBB1E50BC1F4FBA1E4EBB1E27DD1000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0027DB0C4CB6184DB718
4CB617986E2D936B2C946A2E946A2F966C30976B2E9E6F329C6D32986C3297703797723A
9B743D98733C99753F9975419974419C77439E7846A17A47A07A48A37D4CA07A4852C026
50BE2452BF2651BE2651BD2350BC2151BC1F27DD0F00FF0000FF0000FF0027DD0E28DD0E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004BB516729023976A2E966B30966E33956F3396703698713997703A976E3A
966E3A976F3B99703D9E7142A07242A47643A57540B07948B3794CB67C4FB57D51B67F54
B7845BB6845CBA835BBC855EB9855EB2855AB3895EB1895EB28B61B28961B0865DB1895F
AF885EAE865DAE865DAC855AA98254A8804EA37A49A47B4BA07B499E7A469C79419E7A42
9D78404EBD214EBC1F4CBB1D4CBA1C4BB91B4BB81B4EBA1D4EB81B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DB0C4AB51648B31548B617
49B71A936E33926D35956E39936D3A9672419877469C7B4AA07D4EA37E51A77F55AA7F58
AD7D58AE7A57B47957B87454BC6D4EC06847BE5E3EBC5538BA4E34B6432CB53F29AF402B
DF7F6ED67765A63B26A73620992E198C3019A75C41C38668A0664B87472E8D4A33935139
9A57429F5C46A6674DAA6D51AB7051AE7554B57E5DB58260B68661B3875EAC8358AA8358
A88458A48253A27F4F9E7B499B7B479979449A77419A753D9A73399A7136997134997235
4CB81B4BB81B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004DB6174CB5164BB51649B51546B4156A8F21906B2F936F35957038987740
9576429B7B4BA28052A37D53A57C54A87F58A77C57A97653A46D4C995B3F934E368B402C
7F2E1F7B22167C1C10871A0F9B1F14A81B11B2190DB7160BBB150BBE130CC2150EBE1712
C12521C42B24BD1B11BF150DBA160DAD150B9D170B88180C79140D720D0878100B7A100B
7A0E0B7A0F0C760E0977110976140873130670180A904436A868577A3C28A468539A644F
8D5740A26B4FB1785BAF7D5DAC815EAB855DA381569D7B509A774A9977459C76429C7640
9A743D9A733B9770357194274BB71A26DB0D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4CB717956B2F8F672C8E682C8D682C8F6B3190703795753F9879469A7849A07C50A27E52
A27E559F754F9A674695583C89452B7C311A74240F761C0B7615077810067B0C067F0C09
830B0A870A0B8606078A05079205089B0507B20F0DC21510CB1510CF130ED3130ED31411
D01410D0150FCE130BCD130BCD130BCC140DC71710B4110D9B08068B0405870709901819
8A1314850C0D85070A89080A8C0A0B8507077D0707A13F3EDA8786701C18C47370CA7E7C
64110C70120B84271E7A251976291A84412CA26E53C29C81AF9275A6896AA18461A3835D
9F7F569E7D4F9D7B489C7942987339946D316F922549B61849B6174DB81800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0024DA098F69248E6826
8D672A8B66318A67368E6D3B9574449575469D7A4F9F79519F76509867468B5236783920
6D2913671A086A1204710E02770B027908027F09038507048907068B08078702038C0507
8F050794060A920608900507900508910306940202A30706B70D0CCE1815D41511D61410
D8150FD7150FD71510D3110CD7160ED7160ED61510D51813CD1815BE15139C0706C14646
CF5F5E820A0B8D090A90070894090994090C8E070B85090D8612177F0B0E7F1012861B1B
7B0F0C7F0F0D8818169B312C710A056D0A046C180DC1887BDFBEB0D7C2B4CAB7A8BBA693
AF9981A48E6EA28962A38559A0804E9A77439C794397753D926E33926C2E6F911F25DA09
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0024D9086A8C1A88652586672A87672E
8B6836936F4499734D9B734F9A704E8C5C3D7D442A702D1A641B0A631004640A01690801
6B05007004017502017F0505830502880503880301910605950608930406920304940306
9803069D05099A04079905079403069204079003069505099D0507AE0C0EC01212CB1512
D51712D71510DC1612E01A13DD180FDD160EDD150EDD1710DD1810D5160FC41611A8110D
9B1615890B0B890907900B0AAF25259B0B0E98060A95060994070B9207078F0707911811
C05D4EB25A4C75160E942C28B34A46912625922828923D3AC4918CDDC6C0D7CBC4C7BDB3
D6CABEC7B9AAAA9A83B19C80AC9273A48A64A3865C9E7F549D7D4D9977429A743A926A2A
8D672244B00E24D90900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0024D9096B8E1C8C672789662D8A69378D6D3F967349
9A714C976647874B34732F1B651A095F0D016407006704006E0502720504730302750504
7603037900038003068202048803038C04038E04029203049804069A03049D05079F0608
A30608A7070AA6080BA206099F0609A0090C99050999080C99090D980508A3080AAD0A0B
C21411D61A16DF1A16E51C16E51B13E41913E01912E01C14E11B13DE170FD8160ED31912
BE1613CF4B48B9423F860706A419189F0C0DA007099F0406A107099F0707990906961D13
EE9B89D396819A4E416E09048819199C2C2DA0302F811D18904A43B38C86D9C6BFBEB4AE
D4CEC9DAD4CCBBB3A8D9CBC0CBBCADB2A38DBFAC91AE987DA58D6DA286609E7F549C7C4C
93723A8C6A2D89632345B10E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0023D80789621C8764278867338D6C3E936D459C734F976448874934
732B1A6915096E0D077209057406037505037603027B04057B02037C01037C0204790004
7D01068201068802079005088E02039304049606069A06089C0406A40809A9090BAA090C
A80608AC0809AD070AA9070AA9080CA5070BA4090D9E060B9E090CA00A0CA30C0DA30B0B
A60907BF1412D01815E11D17E61B14E41D15DE2B23ED524BD7261BDE1B11E0160EE31B14
D91C17E44440C533319907069A0405A1070AA6090BA7090AA80908A60707A0070699110C
C45C51CA75688C2F247B07037F03047C03057B0806841E17D7897E9F685EAF8880D0B9B3
CEC4BFBFBBB4C0BCB7D5D0CCD5CFCABFB7B0DBD1C7CABFB3C0B4A6C9B9A7A99782A69176
9A825F977C509575428E692F6B8E1C00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0022D806658A168764258B69348D6C40946D4B9060477E422C6D26146613086C0B05
7408067A05068207098406078203038203038103028302038A05068B0307860105830006
8804088A02059204079704069902049C04069F08099F0607A20405A90609A90509AC070B
AB0708B00909B20B0AB10A0AB0090CA60409A5070BA5070BA8090EAD0D10AB0E0FA9100D
A40D0AAA0D0BB50C0ACC1711DF2219DC251CD63B34FD8481DC3832E22015E71A11E91C14
E71B15E01A16DA1E1AC71512B10909A40606A3080BA3080AA5090AA90A0CA509079E0908
9B0F0F9412118C0C078B04028903047E0002760202740805872A247220196F2822BD8D88
D1BBB5D0C8C4CFCDCAD0CFCEC6C2C0ADA7A2C5BEB7C6C0B9BFBCB4D3CEC7CCC6C0D0C7BF
C2B6A8B0A08CA38D719C805B967948916F356C8F2100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043AE07
6589158564268868328F6B4092674585503872302165150D6A0A07730A077505047A0404
8004058504078B06088902038A03038A05048A04038B03039104059504089405088F0206
8F0205900103980206A0080A9F0406A20606A60809A60507AA0709AC070AAA0608AC0708
AF0809B20909B00707B30A0AB10A0BAA060AA9080CA90B0CAB0C0EAD0C0FAE0F0FAB100E
A80E0AA9100BAE100CB20E08BC1C14DA5045EE857DDF6965D03129E02316E31C11E41E14
E31E15E11E17DE1F17D8201BC91D1AAE120EA5141496070998090A9B08089D09089A0606
9F0B0BA00C0C9E0B099D09099505078601027C0103760102740403730705710B0B742324
D0A4A2E0D0CFCBC8C7CCCDCCCFCDCCB3ADA8BBB4ACB0A9A1ACA69EBDB9B4B5B3AFC6C5C1
CECAC8D2CAC7D2C6BEC2B5A5A9987F9A8360997B5070963123D90D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0023D6015E80027451087F5C1C
8665308C673D875939763C25631E0E641107690A067307097904097C04077D0204800404
8103028502028A03048C03038D05038D05048E03039203059402049A0607980405980607
9302039804059E0607A30709A6080AA70709A9070AA90607AA0607AB0708AE0A0AAD0807
B20A0AB40A0AB20B09B30D0BAF0909AF0B0BA90908A70908A80C0DAA0D0EAA0E0EA90E0B
AB100CAE120EAF130FAB120DA11A12EC978BFFCFC4FEBCB3C0453BCC2C23CB271FC22820
B4241CA51E189C1D17981F198D1B17821C177919167614137F16158A1615870B0A8E0B0B
950E0EC339389B0A09A0090A9E08099203058602027E01017A0001770001770101780C0C
853838DFB9B8CFC3C1CECDCBD6D6D4BEBCB6D9D3CDD5CEC9B8B1ABC2BDB8C5C1BEC4C3BF
C5C5C2BBB8B7D0CDCACFCCC8CFCAC3C8BEB0B3A28D9B846494784D68912C20D70A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0021D5027B51057A571581622B896639
8255346D311A611709660E066B09047009067405067B05087F03097E01058104057E0102
8203038804058B03048B04018B03008F04029405049202029905069C04069D06079E0709
9802049B0405A00706A50707AA090AAD0A0BAA0708AA0808AB0808AB0706AE0A09AD0807
B30A0BB30A0AB10A09B10B0AAE0908AE0B09AD0C09AE0E0DAC0E0DAB0F0FAA100FAB110D
AE120EAF130FAE1510AC1813A2221CBE6C67E0BDB7B7999071342C6E1B1561120C4E0C04
490D06400A05390904360B04300A032B0A042909042B07033309063E0A09500E0D661214
7714158E1819930D109908099C07089D09099205048D05048601018F0A098D0807890909
841516B86D6CD5B0ACCABEBACECBC6B6B3ADCAC7C0D7D2CDBFBAB6D8D5D1D4D4D2D2D2D1
CECDCCACAAA7CBCAC6CACAC8C9C9C8CDCCC9D2CEC7CBC1B4B1A38D9984658D714945B41D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00607E047E5411825D2683603378502D632E16
5A1304640B046B08057006057407057505067804067902047E0206810206840406840304
8401038A02048D04059006069106069507069806079402039602039C0406A20709A2070A
A107089F0604A00604A70805AB0907AC0A08AB0908AE0B0AAA0806AD0B09AD0B09AF0A0A
B10A0AB40B0CB30B0BB50D0CB30E0CAF0B09B00E0BB1100DAE100DAB100EAA120EAB130E
AC1511AD1916A81F1A97221C7E221E5B24233E29262B231A2D1B123D241B513B3269564B
7D695C8E7A6E9C887C9D8A8097887D8E83768074686B5E534E403830211B220C08230502
3306064F0D0E7113148A1213940B0B9E0D0C9C0B0A990808960705AA1B179E110B99100D
971E1D943837A56E6BD5BCB6DCD4CEBDB8B2BFBAB3C0B9B3B9B2ABC4BEB8C7C4C0CECFCC
D2D2D2CFCFCECECECDCACACAC7C8C9CED0D0CCCDCBCCCCC8CBCAC3C3BDB2A39380978060
8A6C3F21D80C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0020D5007D55087F581B876032805635612F19531205590803
6505056F05077203067103047103037303047603057800047F0307820206840205890405
8802038D04069004078F03069102059403069703069702049904069C04069D0305A00407
A40609A30707A40706A90909AC0909AB0909AA070AAE0A0DAD090AAE0A08AE0A09AF0A09
B20A0AB50C0BB60D0DB30D0BB20D0BAD0D0AAD0E0CAB0F0BAA0F0AA70F0CA5130FA51915
A0231D87201B6B1C174E1410411916452C275F4E47928377B2A294D0BEB1E1CFC5EBDAD1
EDDED4EBDED3EBDFD4E8DCD2EBE1D6E8E0D3E7DCD0E7DACDDFD0C4D2C1B5B8A59B816F65
45342D210B072B0603480C087214128A0F0C930A089506059C0A099F0E0B9F110E910F0C
B75350F7B4B4AB7B7CC3A3A2EADBD7CEC8C3D5CECBD9D1CEBDB5AFCBC4BDB5B1AAB4B2AB
D2D2CDBDBCBBCECECFCECFD1CECFD3CBCFD2CACED0CCCECFC8CACAC8C7C7C9C5BFBFB7A8
9F90758F764D41B11A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0021D5017C54097D5A207F582F67371D511707500A03570301630405
6A03057005077103067003066E02027102037603067901067F0308820408850405890405
8903048A02038C02049002079101059605089704069704059605059804059D0506A20507
A30406A70709A80708AC080AAD080AAB0709AB0B0DA8080AAC0B0AAB0B08AD0B0AAF090A
B40C0CB30B0AB40C0AB10C09AE0C09AF100EAC0F0DA90F0DA6110FA0151298211C7C1E18
57160E3C140A442A20715C53B29F96D8C5BCE0CFC4E6D6C9E6D6CAEADCD4EEE2DDEEE5E2
EFE7E5ECE6E3E9E6E2EAE7E5E6E4E2EAE6E3E8E3DFEDE7E2EBE5DDE9DFD8E6D7CFE2D1C6
D8C8BCB2A499594C43200E092F06055A0E0D7E110F920C0D99090B980708930707860908
B45A5DFDCBCEDAB1B482585ADABBB9C6B5AFCEC4BEDFD7D2C3BEB9DBD6D2D3D0CAC2BEB7
D9D4CFB6B2AFC6C4C1C8C8C7C0C1C3CED2D4CED3D6CDD0D3CCCDD0CACBCDBDBEBEC6C6C2
C7C2B8B4A894917A5A668D2D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0022D402845410875A2373431E551C094909014B0702500402570101640404
6A03047005077104077003066E01046F00037301067803067B0205820408850406890606
8903038C05048E0405940608940306970508970506920203930404980605A00706A50808
AA070AA80707A90A08AE0C0AAB0A07A60908A4090AA30808A40A07A60C08A80908AF0A0D
B00B0BAF0B09B20D0BAF0B08AF100CA70B08A50D0BA01312991E1C76171455150F3E170D
5A4235988778CDBFAEE0D2C3EADCD0EEE3DCEDE5E0F0E9E6F1EAE7ECE6E5EDE7E7EAE7E8
E8E7E8E7E7E6E5E5E6E4E4E5E6E6E8E7E6E7EAE8E9E8E6E7E6E3E3E5E2E0E9E3E2E8E1DC
E4DDD4E1D8CDD4C6BCA597904938332504034D0B0B7A1010900B0E96070B95080B941416
811A1FB061689C5458651D1D8E5450DAB9B3C9B7B0BDB1AAB4ABA3C7BFBAD1CCC6C9C5BE
DCD9D4D5D4D2D3D2CFCFCECDB7B7B7D4D5D8C9CDD0D0D4D7CFD0D3CDCDD0C5C5C9CACBCD
B8B8B7CAC8C2B1A698A58D746991361FD50B18CC0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0047AA04915516914A1E7F2B0F6D0F026606025B01015401004F0000570100610102
6902036E03066F02047205077202077301087701067A03057B0203820408830104870505
8A04048D04049005048F0201960606970606990707970606950404990505A30807A70706
A90808A50707A20703A90C09A509079E0608970305980305A00B0A9F0707A10608A8090D
AB080CAD0C0BAB0C08A90C08A50D08A2120D97191478171252100B43191262473BA59283
D5C2B3DDCCBFE4D7CCE9DFD6E8E0DAE6E2DFE6E3E4E6E2E5E7E4E5E2E1E3E4E3E5E3E4E4
E3E4E1E5E6E3E6E6E5E6E5E7E4E2E5E5E3E6E7E5E8E8E6E9E5E4E6E3E3E3E0E0DEE2E1DE
E5E3E0E5E2DDE1DBD5E1D7D1C8BCB46E5F57290D0952120F831A188D0C0C8D0B0CD66769
AB41457E0F14810F117E1311772823EAC2BEE2D2D0D8CCC8AFA39CB6ABA2B4AAA1B5ACA4
C4C1BABCBCB8CFD0CDD8D8D8D3D3D5D8D8DAC8C9CBD2D6D8D2D4D6CCCCCFCBCBD0CECFD3
BCBFC0BFC2C0A6A29DBBB0A5A18E798E715067401318CC0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF009153168B39128418038F0D03940906950909900A0B7F0505740203710202710100
7001017204047002036F02037302057702087B03097D0205800306860509850407840405
8906078B04059106059305039707069605059B09099A07079C0606A10707A70809A70708
A20406A00507A20707A50906A409089701049805099B090B9A07089F0809A40A0DA5080C
A90A0FA70C0CA40B07A5100B9B150D8219105910083F1409634A3DAD9C8DD4C2B3E2D1C5
E9DAD1EBDFDAE9E3DEE8E4E0E7E4E0E5E4E2E5E3E4E7E4E5E5E3E3E5E2E2E6E4E4E5E5E3
E6E7E3E5E6E3E8E8E6E5E5E6E5E5E7E7E6E8E8E8EAE8E8EAE6E6E7E4E5E4E1E2E0E1E2E0
DFE0E0DCDDDEDADBDBDFDDDADFD9D4CFC4BB8A7A7034150F85413E790F0F860C0E9A2428
982427880A0D8E0908880A087B1C1AE5B4B3E4D4D5E0D9D6C1BAB3DCD2CAD3C9C2B8AFA8
C0B9B3AEA9A3BAB7B3D7D7D6D6D7D9D4D5D7D4D6D6D5D6D6D2D2D4CECFD2C8CACDCACED1
CBCFD2CACCCEB3B2B097948FA89F97AC9B88896D4F67401517CC0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D505
8F4F157F2C0B7F0F019007029C0704A30706A60807A60909A007089A06049E0A089C0A08
970A098A05048102037701017400037701077D04097F030881040785050989060A840204
8804068A03059106079607079A08099503039907079A05069D0607A00507A50709A40709
A107099E0508A00608A20808A3090A9A04079704079906079B06089B06089F080AA0080A
9E090B9C0B0B9B0F0C9A1E196F150E430F03503526A39281D8CBBAE0D6C8E7DFD5E8E2DC
E8E3E0E4E1DDE7E6E2E4E3E0E6E4E3E7E5E6EAE8E7EAE7E6E8E7E5E7E5E5E7E5E6E9E7E8
E7E7E5E5E4E3E8E6E7E5E4E6E5E6E8E4E4E6E7E7E9E4E6E6E5E7E6E3E4E3E1E1E1E3E3E3
E3E3E3DFE0E1E1E3E3E1E2E2DFDEDDE2DDD7D1C6BC88766D34100B5C110F7E0F1188080C
8D080D8F04099C0A0B9C0A0B83090B97494ECFABAED6C6C3B8AEA6C7BCB2DACFC7C5BCB5
E2D9D5C4BDB8C6C3BED7D7D6D4D8D9D2D6D7BEC1C1D4D5D6D4D4D8CFD2D5CACCD0CBCFD2
C3C7CAC8CACECACACEBFBDBF9A95929D9388A999848A6E50673F1417CC0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D506924F1A
7E280A7A0B008A03019A0504A20706A80807AC0908AD0909AB0808A40602AE130CB4180F
B00E09B30F0BAB0D0B9B06068F05058101027D00028104077F0306800306850406880304
8904058904058C04048F03049808099604059B08079C06059E0404A00507A10507A00607
A00709A1080BA007099D04069B04069601049904079B05099D080C9A080B9E0B0D9A090A
940A099013107E1813550E07471F13867363C6B9A6DFD4C4E7E1D7E7E3DEE6E5E2E3E4E1
E2E3E0E4E5E0E2E2DEE4E3E0E4E2E3E5E4E4E5E5E4E5E6E2E7E6E4E4E2E3E6E2E6E7E4E8
E5E4E5E5E4E5E6E4E6E7E5E7E3E3E4E4E4E6E5E5E6E4E5E4E4E5E4E3E2E3E3E1E2E2E1E3
E2E2E4E2E2E4E0E0E0E3E3E3E2E2E4E3E1E1E5E0DBD1C7BF705C543D0B086A0F10820B0D
890408900105A70C0EB110129F0C107D0A11661C209A6F6BC2AB9FBAA89CBCADA1BAACA1
CCC2B8C2BEB5CACAC3D7D9D6D4D9D8D3D8D8B6B8BACFCED0D2D3D5D0D1D4D1D2D6D0D1D6
C5C8CCC1C3C7C7C8CDCCCBD0B1AEAFA39F95938C7C9F8F79977B5D633A0F18CC0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B7810792507
760800870200970504A20707A90808AD080AAE0909AE0D0AAE110CBC221AC83026C4281E
B71009BC0C09BE0D0CBC0D0DB70E0DAB0C0BA10A09910305870105830205830304860504
8504058704068B05068E04049205069706079C07079F0605A10404A30607A308089D0405
9D04069C06079C06079B06079D07099D06089E06089C05079D080A9B0B0B970A0A930C0C
8F171769110B410C035B3E30BFAD9DE0D3C5E4DBD0E9E4DDE7E6E2E6E6E5E5E5E3E5E5E4
E2E2E1E3E3E1E2E2DFE4E3E0E1E1DFE0E0DEE3E3E1E4E4E2E2E1DFE5E1E4E6E2E6E5E3E6
E6E4E6E5E2E4E7E3E7E4E1E4E2E1E3E2E2E2E2E3E3E3E4E3E4E4E4E1E1E1E2E2E2E1E0E1
E2E2E4E2E2E3E4E4E3E6E5E3E4E3E3E2E2E2E2DFDEDFD9D4C7BDB45538334D0B09780C0E
8606098B03049F0B0AAE0F13A60E1183020571080B6A1D1ABB8E84DBC6BCD5C9BFB6A89D
BEAFA3B2A89DB6AFA6C4C2BBC5C5C1D5D6D4D1D2D4D5D6D8D1D1D3CDCED0D4D5D8D4D5D9
D0D1D5D0D0D5C1BFC5C6C5CBADADAFC0C1B98F8E819089799F8D797F5D3F349C0700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006C7C0D762703710A00
7C02008F01029D0406A40608AA090BAC0809AF0B0BB61915C12920B71E13B0140AC6251D
BD140DBE0E09BF0C08C20C09C40C0AC40E0DBC0E0BB40D0BA809099A05058B0102870304
8102048504058B06078801028E04039506059E0708A10607A20706A10604A10706A00607
A107099F06099E07089901039F0507A2070AA50A0BA00909990808950B098C0D0A7D1210
580C0946190D886D59C3B19FDCCFC2E6DED7E4E0DCE1E0DDE2E3DFE2E3E0E2E2E0E2E2E1
E2E1E1E1E0DEE3E2E0E3E2E0E1E0DEE3E1E1E3E2E1E4E2E2E1DFDEE1E0DFE1DFE2E1DFE2
E3E1E3E2E0E1E4E1E2E4E1E3E0DFE1E0E0E1E0E0E2DFDFE2E1E0E3DEDEE0E1E1E2E1E1E1
E0E0E0E0E1E1E5E4E4E2E0E1E4E2E3E3E2E4DFDEE1D9D7D7E2DDD8A897904315106B1310
8919179019188605059106088F0408860508871414771A189B615BDDC7C1D9D1CDBCB3AD
DFD3CBC8BBB3BBB0A7B8B0A6ABA79ED2D0CBC1C2C1D2D4D4D2D6D7D1D5D7D4D6DAD3D4D8
D0D3D6D0D1D4D1D0D4D0D0D4ACAEADA2A39E9897909F9C91918477886754369D1000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0023D103792A046E0B00770401
860201980405A20509A5070CA10609A10507AD0D0DB81A16AD1209B1170BB3160ABA1910
C11811BD0D08C10C09C20B08C50C0AC40C09C40D09C50E0CC20E0BBE0F0DAD09089B0303
8D01018601038705058804028B05049105039704059D0406A10607A108069E06049F0607
A00608A40A0CA3090AA2070AA20609A40909A40A0B9C08089308078A0D0C700F0C480B02
522D1EA18772CFBDA7E0D5C6E3DED8DFDBD9DEDDDDE0E0DEE2E1DFE1E1DFE2E3E0E1E3E0
E0E1DFE1E0DEE3E3E0E4E3E0E3E2E0E2E0E0E4E2E3E6E2E4E1DDDDE0DCDBE1DCDCE1DDDE
E3E0DEE1DEDCE4E0DEE5E0E0E5E0E1E5E1E2E4E0E0E4E0E1E4E1E3E4E0E3E1DFE1E2E0E2
E0DFE0E1E1E1E1E0E1DFDDDFDEDCDFE1E0E3DCDDDFD7D8D9DCDCDAD7CECA7B5D5752120B
933A35DB78757C0B0B830508830206820507A13030B05858AD7373E0C4C5DBD0CFBBB1AD
CABFB9C6BCB3CAC0B7DAD1C8AEA9A0CFCDC7ADACA7C3C0BDCDCDCCCECFD1D2D4D8D2D6D9
CCD0D3CACBCFCECED2CDCFD1C5C8C9B1B3B08F918A999990AFA79D8D72675D2A141DCC06
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0025D3047E30046E0E007103007B0101
8B01019B0305A30509A3080B9903049A0202A90C0CB71B17B41B14C32E23BC261AC02217
BD160EBC0D09C00B08C30C09C30B09C40C0AC50C0AC50B09C70C0AC80D0BC60E0CC00F0D
B30D0A9E05048D01018803038903028F040599080A9B04079E06069D06039E0705A30A0A
A50B0CA30708A50708A90B0BA5090AA20B0B9E0A0B9405078C0F0E70110E440A03674837
B19C85D2C0ABE0D3C5E1DCD3DBDAD6DBDAD8DAD9D8DDDCDAE2E1DFE1E0DEE1E2DFDFE1DE
E0E2DFE2E3E1E1E1E0E3E2E0E2E1DFE1E0DEE2E0DEE3DFDDE3DBD8E5DBD8E5D9D6E3D3D1
DFCDCAD7BFBECFB1B1CBA8A9D1ACACCCA7A6CBA8A5D2B0AFDCBEBEE1CCCAE4D7D5E6DEDC
E3DFDFDFDEDDDDDDDEDFDEE0DFDEE1DEDEE0D8D9DAD5D6D6DBD9DADFD9D8B9A8A351211A
681612801A197F0A0B870809860608830507800A0E76121663131A763E44D5B6B7CCBBB6
B3A59DB0A499B8AEA3CDC4BAB3AFA4CFCEC6C8C7C2CCC8C5BFBDBBC1C2C1CFD2D4D1D4D8
D2D5D9D3D5D9C6C6C9BFC2C3C5CACBC7CCCDA2A7A394968C9E9A909E8C82623829526514
3DA00D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF006467047011006F0301740000820103
930204A00206A50609A8090AA60809A60807AF1210B9211BBB241DBE261EB51B11C12119
B8110CBB0D0ABE0B08BF0B07C10B07C30B08C60D0AC50A07CA0E0CCA0E0CC90C0ACA100D
C9100DBD0E0AAF0A079F05059402029203039706079803059C06079C06079F0608A2070A
9F05069F0606A40808A60A0B9C07089306069109088F12116E0F0C450D067B5E4CC0AF9B
DBCEBEE1D8CCDDD8D2DBD8D3DBD9D4DADBD6DADAD8DDDCDBE1DFDFE3E2E0E2E1DFE0E0DF
DFDFDFE1E0E1E1E0DFE2E1DFE3E0DDE2DFDCE5DCDAE3D3CFDEC4BFD0ADA8BB8D87A66C68
9956558C3F3F832C2F85262A8B27298D28288B28278F2E309036379A504DA36A66BD9490
DDC5C0E0D4D1DFDBDADEDDDDDEDEE0DFDFE1D9D9DBD5D5D7D7D7D9DBD9DADACECA89625B
66130F7C0B0B8406088B07078904058502058505097E050A74060B6C1116A36767D9BDB8
DBCFC6C9C0B6B4ABA0B1A89CABA396BEBAAFC1BFBACCCCCBCCCBCCCCCDCEC9CACDCBCCD1
D2D5D9D3D7DAD2D3D6CFD0D3BABEC1B5BABDB5BAB9BABBB78F8D8694897F77564B582615
9E6E512D960200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00499F037C1B007103007301007601017E0101
970509A20408A60206A80408AB0708AB0908AF120FAD140EB1140EB1110BB1100ABD1A13
B60E08B90B08BE0C09C00C08C10907C40C0AC40C0AC90E0CC80E0AC60D06C90E09CB0E0B
CC0D0BCC0F0BCA100CC7110EBA0D0BA003029401029303049A08089E0909A10709A2070A
9C03049F0603A309089F090A90040587060783100F6A110D4C160C8D715DC1B09CDBCFBF
DED8CEE0DED8DFDFDADBD9D4DEDBD6DAD9D4D9D9D5DDDEDBE0E1DFE1E2E0E0E0E0E1E0E1
E1DFE0E3E1E1E5E1E0E7DFDDE8DAD7DCC3C1CAA3A0AA706D9648479033318E242492201F
9118189416179511149910149D0F129F0F0F9F0F109D0F119C1214961515891715822320
873C3AB5817EDCBDB9E5D6D4E1DBDBDEDDDFDCDCDED7D8DAD6D7D9D6D8D9DED8D5BB9C94
692018780B088606058A050488030491101186080B7F04077902058415167924229A6C66
D8C6BFD5CFC9D0CCC6D4CDC5B4ACA2B9B0A8B7B3AECCCDCCCCCECDCED0D0CECED2CFCFD3
D0D3D6CED3D6CFD3D6D0D4D7CDD1D3B7BABC9DA0A1B3B6B4B1B2AC8C857C7A5D53481C0E
AE8674704D2A17CD0100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008A2902810C007F02027C01027801027A0000
9203069F0305A40204AB0708AD0909AC0907B11411B11713A80E08B41914C22620BA1813
B40B08B90A08BF0C08C00C08C20B08C60C0BC80C0BC90B0BC80E09C70E05C90E07CC0F0C
CB0C0BCB0D0BCD0D0BCF0E0DCD1110C0110DA506049601019805069C06089F0608A10708
A20807A20806A40C0B940406880608811211600E0A4E1D11967C6BD0C1B0DED6C9DAD6CF
DBD9D4DDDDD8D8D9D4D9D9D4DEDCD8E1DDDADBD9D5DADAD7DBDBD9DFE0DEDFDFDFE1DFDF
E4E0DFE7DEDBE7D3D1D0ACA8B7817C9147438D2E2B9221209A1A1B9D14169F13149F1012
9E0E0EA10F0F9F0B0CA20B0DA40B0DA50C0BA40B0AA60C0CA10B0A9D0A0A970B0A930F0F
850E0E7F18189F4F4CD19E99E9D4D0E1DBDBDADADBD9D9D9D8DADAD6D8D9D9D6D5D2BCB7
763C31710F088408048B06048805049C1D1E8F14167D04087C04078813149733326E2824
C4A19CC3B7B3CFCAC7D0CBC8BAB4ADD5CFC9D1CECBD1D2D0C4C6C4BEBEBDD2D2D3CFD0D3
D0D1D5CED1D5C7CACCC0C4C6CFD4D5D2D5D7B1B2B5989899ACADA89E9A948A746C482018
98746BA68A7740670700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00489801881800890901840000840101850304870203
9301039D0103A30203AA0707AC0808AA0806A70A07B51B18BA231FB61F1AAD110CAD0906
B20906BA0B09BF0C09BF0B07C20B09C40A08C70B0AC70B0AC60A09C80C09C90D0ACB0F0C
C90C0BC90A0ACE0E0CCF0E0BCF0E0BCC110CC20F0CB40A08A70405A00204A20607A00605
A20806A10907980708890205810E105F0C0A501F14A18A75C8BCABDCD6CDDCDBD6DEDEDC
DBDAD8DBDAD6D9DAD5D8D9D4DBDCD8DFDCDADDDBD7DDDDDADEDEDBE2E1DEE6E1DFE7DBD9
E2C9C8C29796A4605F9437359927249B1B199D1314A31212A41010A20D0EA40F11A30E10
A30C0DA50B0CA70C0DA4080CA50A0DA50B0AA40A07A10705A008079F09099D0A0B990B0B
91090A8C0A0C8A12109F3E37D49B96E8D3D2DEDADBDADADBDADADBDBDBDBDAD8D8DECECA
96645A6E120880070488050589040584040682050A8004087E0708790A0ACC6A68691C18
A87A76DBC6C2CAC2BEA9A29AA7A095C2BDB1C8C6BFCECECAD0D0CFC8C8C9CDCDD1C5C4C9
CFD0D3D0D0D3CDCED2C9CBCEBCC1C4C5CACDC0C5C8BDC0C0939490989691A2938C472820
7A5C57CDB9B164492C00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0027D2028D26018F10028C05018701018701028C0204910101
9A0104A00204A50306A90509A80507A60606A40506AF1213AE1211AA0B0AAC0706B10A07
B50A07BA0A09BB0906BE0B09BE0A07C30B0BC50B0BC70D0BC80C0AC90D0BC80B0BCC0F0D
CB0E0CCB0D09CE0E0ACF0E0AD1100BD1100BCF0F0BCC0F0CCC1110C10E0DB10707A40504
A108089907078C04037F0A0B5E0B0A54251BA68E7DCDC0B1E2DBD2DCDBD8DADCD9DBDCDB
DAD9D8D8D7D5D9D9D5DAD8D5DDDBD9DEDAD9DED9D8DDDAD9E2DFDCE6DBD9E5CBC8C3908E
9A4D4C952F2D9E2120AA1B1BAD1615AD1414A90F10AB1110A90E0CAB110FA80F10A60D0F
A90E0EAB0D0FA90C0FA3080BA20609A40809A50A08A10705A009099B06079A08099A0A0B
96090B8F0608940A0C8F110EA04641DAAEABE3D7D5D9D8D8D8D8D9D8D8D8D8D7D7DED2D0
B78D847921177F07048707078604068603068403088003067E0506760607AB4949A65553
7C423FDBBEBAD5C9C3D0C8BFAEA499AFA599AAA498B7B3ABCFCECAC9C8CAD0CFD3CCCED2
C9CDD0C6C9CDCCCED2CCD0D3C4C8CCC2C8CCA3ACADBCC4C2B1B7B492938E8F837C563D32
634943D5C6C589776828980600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00489B018D1C02930C078E05038600018701038E0104980305
A10408A40207A50206A70407A60507A50406A70306AA0609A9050BAB070AAD0707B40B0A
B60909BA0A09BC0B0BBB0B0BBB0A08BF0A09C30B0AC40B09C80D08CA0E0BCB0E0DCA0C0C
CB0E0BCE100ACE0E09CE0E09D10F0CD2100CD41210D2100DD6110FD41210CF1512B80A09
A20504940706840B09640B084D190E9D836ED3C3B4DDD6CEDCD8D5DCDBD9DCDBD9DAD9D7
DAD9D8DCDADADBDAD8DCDAD9E0DCDDDFDADAE1DAD8E1D5D4DEC7C6BA8B8AA456559E3030
A51F1EA91814B11815B51615B81416B51214B21312AD110DAC110DAA100DA60D0CA60D0C
A80D0EAA0E0FA60A0BA30909A70B0BA90B0BA80A0CA308089D06059D09089A0909990809
97090B9206099107098D0A0B7F1412B3736CDDC5BFDBD7D5D7D6D7D5D6D5D6D5D6DCD3D2
C8A29C8E352C890D07840302830303850405850606830A0A7E0809770307790B0F771315
7323219B6A63BDA69DD5CBC1B9B0A7CFC8BDBEBAAFB0ABA3C5C0BCB0ACABD0CFD0CCCFCF
CBD0D1CCCFD3C9CCD0BEC3C6C9CED1CCD1D4B4BABB9BA0A0ABB0AFAAADA9958C855F463C
523732D0C4C5B0A7A252361400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00685E01911304990D0A8D02038601018900029302079E0609
A10507A10206A30406A50608A50506A40303A70405A80508A60306A60205AB0607B10808
B60909BA0A0BBC0A0ABD0B0BBF0B0CBE090AC20B0BC20A08C60C09CA0E0CCA0C0CCB0D0D
C90C0ACC0D0ACF0F0CCF0F0AD2110CD2100DD2110ED3120DD20F0BD7110ED71310D01411
BB100D9A0E0D6E0C0950180E9A7C69CFBFABDDD4CBDDDAD6D9D8D6DDDAD9DDD9D7DED9D8
DDD8D8DBD8D7DDDADADEDADBDFDADBE1D9D9DDCBC8BD98949E5A59973031A51F20B01818
B41514B41412B41310B81513B71412B41311AE0F0CAE110EAB110FA8120FA40F0DA30E0D
A30C0BA40B0AA50C0CA20909A50A0AA8090AAA0B0BA50907A40B0A9E09089C0908970706
9306058F05078B0406890406810A0B832E28CCA39ADED3CDD6D5D4D7D6D7D7D5D6DBD4D4
D2B0AC9B40399C160F9105018806038407047B0904C1605CA54846750A0D77040978050B
700B0D641913AC8175AD998DABA096C2BAB1CCC5BEC0BAB4CFCBC7B7B5B1CDCDC9B7B7B5
CFD0D0D0D1D4CCCFD2C8CCCFBFC1C5C2C6C8CBD0D0C0C6C78F9695969A97A9A49E6B574E
442B25BAAEAFC0BCBB5B493000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00881F00921105970D0B8701028100018A01039605089D0608
9900049C02069E0306A40808A20405A30505A40306A7040AA60308A90508AD0808B00707
B6090AB80A0ABB0A09BE0B0ABE0A0BBF0A0BC30B09C30C09C40C0AC60C0AC80C0BC90C0B
CA0D0CCC0F0CCD0F0AD0100AD2110CD0100BD0100BD1100BD2100CD5110CD8130DD6140F
C81A168F120E541009997969D0BEAFDFD5CCDCD8D3D6D6D4D8D7D5DDDBD8DFDBDADFDAD9
DDD8D6DAD6D4DED9D8E3DDDDE4D6D6D8BBBAA6736D802E28921F1DA51717AE1413B71515
BA1617B41112B41112B21111B21211AF1210AD1210AA120FA50F0FA10F0E9D0F0D9D100E
9A0C0A9C0D0C9C0C0D9E0B0DA3090BA90C0CA70909A70A0BA50A0AA007089D08079B0808
9305068C01038C02058C0507850606780F0AB27469D9C3BAD9D6D2D5D5D6D4D4D6D7D3D3
D4B8B4A04941A51A11AC190FAE2E21A53125871F17B55F5BBB6B696D0B0D780508780407
720608650D0A885047D8BCB5B1A199A99C94ADA098B4ABA3C9C8C0C4C6C0CDCFCCC5C5C5
CDCCCFC3C3C8CACDD1CCD0D3C9CBCEC3C5C8B2B7BAC2CACCA8AFAE9297968C8C8A958682
3D231F817270BFBCBB7164522D9D0800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00489D03841B0092130A8806057D00008001018A0204950609940204
9500019701039B01059E04079E0305A10507A30509A6050BA40307A60506AB0707B00809
B50A0AB80B0ABB0C0ABC0A09BD0A0AC00B0AC20C09C30D09C20C08C60D0BC50C0AC70B0B
CA0D0DCB0F0DCC0F0BCF0F09D1100AD1100BD2120BD0110AD4120DD4100BD6140DCE1711
A916116A120B997162C7B6A8E0D5D0DAD4D3D6D4D4D7D6D6D9D7D7DAD7D4DDD9D6DFDBD9
DCD9D8DCD7D6E4D9D9DCC8C7AE848391494489231D941811A0120DAA1210AE1210B31211
B51313B21111B01212AF1311AB1412A71411A215119E1B17931A178719157C18147D1D19
7B1B187915157B1215841013940F119C0B0BA00A099D07079F0807A10A099E0908970404
9302038F02048F01038D01028802027F0905903E33D2ADA1E0D7D2D5D6D6D5D6D9D9D5D7
DBBEBBAA564CA1190DCF3B2FAD26188B1306A2362D8B272375121274070A7904067A0506
7B1113AA565359201BCDB1AED3C6C4D1C6C3C2B6B1A99E97ABA299A8A59DCACBC7CACCCC
CACBCFC5C8CBC7CCCFC1C8CBCDD0D5CED0D5B8BCC09AA0A2A2A9A7ABB1AE8D8E8C8A7A78
442421654F4BB7B1AF8C8074289A0900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF005E65037113027B0D077502017601017E01028702038D02058F0003
9200019502039701039C04079D0307A004089F0305A20406A40507A40506A90606AF0809
B40A0BB70A0ABD0C0BBC0A08BE0C0ABE0B0AC00B09C20C09C40D0AC60D0BC50C0AC40A0A
C80C0CC90C0BCB0E0ACE100BD00F0AD1100BD1100AD3120CD5120FD6130FD01510B51712
720C07996A5FCCB8ADE3D8D3DFD8DADCD8DBD9D7DADAD7DADDD9DBDDD9D8D9D6D5DCD9D7
DCD8D6E3D7D6D5B7B6A56B6B862B29941B1AA11513A6110DAA120DAB110DAE120EB01210
AC0F0FA80E10A91414A518169E1F1C8A1E1B771E1A5D1512480F0A3A0C072D0903270903
280A052908062F07083E090B5F11127C0F109410129506079F0B0B9E0A08990503960403
9201019201019202029001028D0303840401802016C49285DECFC9D8D7D6D5D7D9DAD7D7
DEC2BFAD5B51A51E11D84034AF190F990905860603A8342E7C09077C06077D0304891312
841A16A0494360211CBB9A98D7CBCBD2CDD0CFCBCEC1BAB9CBC2BEA59F9BC5C3C1C7CBCB
C7CBCDC5CACDC5CCCFC2CACDC3CACEC2C6CBC5C8CDBFC2C58E9290969C97B0B1AE857573
462622624944ADA4A39F968D3B670C00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF007230054F08007024227823226D05057902038301048B02058E0102
9002029101029401049A02079E0208A10309A30408A20506A50807A40506A80507AC0709
B1080AB5090ABB0A0BBE0C0BBD0B09BE0B0AC10C0AC30D0BC20A0BC40B0AC70E0CC40B09
C80D0BCB0F0BCA0D09CE100AD0100BCE0E09D2120DD2100DD2110ED31612C21A16810D08
884E46D5BDB5DFD5D1DED6D7DAD4D8D9D7DAD9D7DAD7D5D8DBD9DBDDDBDCDFDBDBE4DBDC
E2D3D2BA94919149478B201E9A1614A51112A90E10A90E0CAA0F0DA90F0EA9100FA9120F
A613119D1414941E1E7B1C1A57130E3A0D072E10092F1A12402E2455453A66584C6C6053
6D60555A4D423F312826160F2005013B0504731111920F129E0C0D9D0A089B0706980404
9501029502029201019001018E0100870201790E07BE8074D7C0B9DBD6D6D6D7D7DBD8D7
E0C5C3AC5B53A61D11D03629B92016AB120B950703A62822840D0A800B0B830D0C931E1B
831310801B17782C28D0A4A3DBCACCD1CED2C7C8CCC3C3C5CBCAC7BAB8B4CCCCCBBDC1C3
C0C7C8B7BEBFC7CCCFC5CACDC1C6C9BBC0C3B9BABEC8C7CCAFB1B2959794939491ABA09E
4A302C573E3BA49B9BABA49E4E341100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00652A03360803936B6C713A3C5A06076F01037E01058B0207900306
8F00039101039602049D04079E0308A0040B9E0308A10508A40506A70609A90509AC070A
B0090AB5090BB8090ABB0A0AC00C0CC20D0CC30C0BC30A0BC3090AC50C0BC60D0AC90F0A
C90E09CA0E08CE0E0AD00F0BD1100CD1110CD1110BD2110BCE110DC5191593120F732E28
C7ACA4DED3CFDBD5D4D8D6D5DBD8D9DCD8D9DAD7D9D7D6D8D8D8D9DCD9DAE0D8D8DCC8C7
A5777684312E901B1A9A0F0EA40E0FA90E0FA70C0DAA1010A60D0CA30C0CA41210A11A16
92201A7018144A0E0936120A422A1F6F60529B8E80B8A99BCAB8A8D4C2B3D7C7B8D3C4B5
D5C5B6D0BEADC5B2A1AC9A8A78665A361A154809087F1211950C0B9B0909A00A0C990306
9601039301029001009002018C01008802017D0A05B36B5FD1B4ABDED6D4D5D5D5DBD7D7
D2B6B1AB564BA91B11BB1D14DC473AB8281AA61E12AE3227820E0AAB4040BC53538C1D1A
79070480110E8425256F2D2FBF9B9FDACBCFC7C3C4A4A09DA8A49EB9B8B3CACBCAC7CDCD
C8D0D0B9C1C1C7CFD1C5CDD1C5CDD0C4CCCEB6BABDBEC0C4B1B3B7B2B7B68B8E8D96918F
523F3A5E4B46A9A1A2B3AEAB4F361900FF0000FF0000FF0000FF0000FF00
00FF0000FF0048AA0A5120004D322DA6979951373A3F04066202047D02068F0508910207
9000059501049D03069F04079B01049D02069D0306A00507A10307A40407A80609AD080A
B0090AB50B0AB80B0ABB0B09BD0A09C00B0AC30D0CC2090AC30A09C20907C30A06C70D08
C90E09CB0F0BCD0F0BD00F0CD00F0BD2110CD3120DD2120EC91511A61814691911BA998E
E3D6CEE3DEDCDBD9D8D5D5D3D9D7D6DCD7D8DBD8D9D9D7D8DAD8DADED6D6D5BFBC9E6A67
842B28911815A11310AA1010A90E0FA70D0EA50D0DA5100DA2100F9D1313951E1B731913
4A0F063E1B10604A3C9A8979CBBAABDACABBDDCFC3DFD0C6DED0C8E5DAD3E8E0D9E5DED7
E6DED6E5DBD1E4D8CCDACCBECDBAADB8A195592D266A120E8B0C0B9B090A9D07099B0609
9A070A9302058D01028E02038C02018701007D0702AC5E51D0B1A3DED7D1D6D5D6D0CAC8
C29E959D3E30AF180EB91109BA1A0FD23D30CF44379E1B128206058412159A2B2F9A2826
8F1B14800D08952826691110612023AE898AE1D2D1B9B3AFCAC5C0AAA7A1A9A8A4ADAEAC
CACECECAD0D3C6CFD2C4CED0C6D0D2C1CACCC2CBCDC4CCCF96A0A29DA7A7A7AEAD858380
52453F544641C7C2C4B7B4B450381E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0043A809482402887B72A0A0A23F393C1F00014C03037806088C04098E0107
9001069601069E03089F05099C04089C04089D04079F0506A20607A40508A8060AAA0508
AF0808B40A08B90C09BB0B09BD0B0ABD0A09C00C0BC00A08C50C0AC70D0AC70D0AC70C0A
CA0F0ACC100BCD0E0BCF0D0AD2110CD2110CD1120CCA120DB117136E0E06946C5FDACCC1
E5E0DCE3E2E2D9D9D8D7D6D6D7D5D6D7D6D7D8D7D6DCD8D6E4D7D5D8B7B595565284211E
9316139F110EA8100FAA0E0EA80D0EA50D0FA81112A10F0F931412781613500E083C150A
685042AC9A8BD4C4B4DDCEC2E4D9CFE5DCD5E6DFDAE6DFDCE2DBD9E2DFDCE1DFDCE0DFDC
E3DFDDE2DEDCDFDCD9DFDCD7E4DBD6E3D3CBC4A297772B248C14109C0B0B9C06089B070A
9604089003068B00028B02028B02028502017A0702AC5F50CDAC9BD8D0C9CDCCCAD2C9C5
BE93889A3020AC0F05BC0D08BC0C07BC0F0AB7100CAE110E91020384010586070C890B0E
98211E8718137E1D18A2504D6A2221713B38CBAEAAC2B8B5D8D4D1C1BDBACBC9C7AEADAB
C2C4C3B7BEBFC5CED1C7D0D2C5CDD0BCC5C7B9C3C4BEC8C9ABB5B6919B9B8E9897A2A5A3
5F5551433834C7C5C8BEBBBD533F2400FF0000FF0000FF0000FF0000FF00
00FF0000FF003DA507654726918C85999EA03B3B3E0F00002E000062080A80070A890207
8E020693010698020898040A9603099501079802079D0408A00608A10608A70609AC0609
B0090AB50B0AB80B0ABA0A0ABC0A09BE0B08BE0B09BD0807C30D0AC60D0AC70C09C70D08
C80D08CB0E0BCD0D0CD00F0ED2100FD0100ECB110DBE1613840F0B7A4239CCB8AEE3DCD6
E2E0DFDEDEDED8D7D7D9D6D7D6D5D6D8D7D6D9D4D2DFCEC9D6A79FB25A5298211A960F0C
9C0D0C9F0B0BA40B0DA40A0CA20B0D9C080BA11417941C1B64110D3D0E075A4035AE9C8D
D2C2B3DDD0C4E2D9CEE3DDD7E5E2DEE3E1DEE3E2DFE2E0E0E0DFDEE0E0DEE0E0DDDFE0DC
DFDFDDE0DFDEE0E0E0DEDFDDDDDDDDE1DBDAE3CCC6AA71677F140E970B099D08089B0607
9907089404079105068F04058C02048906057F0C04B06351CDAB9AD7CEC5CDCBC9D4C8C5
B7867A962617AB0C03B80804C10C09C20B0AC00B0CB90B0EA7080A8F0104860206820307
800507770A098B3936F7BEBEA672715B2523BF9B97AE9E98B5ADA7B5B0ACD1CFCDCDCDCD
CFD1D3B4BBBCBDC6C8C2CBCFC6CCD0C7CFD2B6C0C1B1B9BBB0B8B9ACB6B5828C8B939A9A
7873713B302EBFBBBFBEBDBE53412900FF0000FF0000FF0000FF0000FF00
00FF0000FF0038A107987F6685848581898D393C3D0B02011B00003D02036205067A0406
8801048E02068E02078A02068E03089201069802079A02079C0307A00508A7070BAB070A
AF080BB30A0BB80B0CBA0B0BBA0908BD0A08BF0B0BC10C0CC20C0AC50C0AC80D09C90D0A
CA0D0BCA0D0BCB0E0DCF0F0ED0100ECF120EC314109D15106B2018BA9C94E1D6D2E1DEDD
E0DFE1DFE0E2D9DADBDAD9DAD8D6D7D9D3D3DFCAC5CB948CB44D41B9291EBE1C15AD0D09
A009049F0A09A00B0CA00D0E9C0E1095121581171757120F4B251D9D887CCFC0B1D9CEC3
E0D8D0E3DFD8E0DED9E0E0DEDFDFDFE0E0E0E0E0E0E1E1E1E0E0E0E0E0DEE0E0DEDFDFDD
DEDEDDE0E0E1DDDEDFDBDFDED9DCDBDBDBDBE5DBD7D2ADA47D281F920F0C9C09099A0607
9A05079A07089707079507079004058E0706840F06BA6C5BC5A492D8CEC4CECAC6D5C6C1
9C675D8A190EA80A05B20302BE0A09C30B0EC0080DBC070CB40A0D9C0506890203850407
8204088D191D731A1DCF9096A46E72784746E7CAC6C0B4B0C7BEBAB1A9A4B2AEA9B5B5B3
CDD0D1CBD2D5C9D3D5BDC6C9C1C8CBC3CACDC6CED1C2CACD9EA8A9A2AFAFA6B3B47B8685
82817E3B322FB5B1B4BDBBBE55432E00FF0000FF0000FF0000FF0000FF00
00FF0000FF00875B22BCAB99757B80828F94383F410501011401012703023A0001590202
7903058903078501037D00018501059002069301039801059C03089E0307A5050AA90509
AE060AB2090CB60A0BB90C0DBA0B0ABE0D0BC00C0BC10C0BC20B09C50C09C90C0AC90B09
CB0D0BCD100ECC0F0DCE0F0ECF100ECA120FB51815710E0BA67B74DCCEC8E2DEDCE0DEE0
E2E1E4DFDFE1DEDFE0E1E2E1DFDADADCC6C2C78980AD3D33BB2218C61810C91410C4140F
B5100CA40B089B0B0B930C0B8E17166E1311460E09694D42BAAA9CD9CDC0E1D9D0E3DFD9
DEDEDADEDDDADEDEDCDFDFDEE0E1E0DFE0DFE1E1E1E2E2E3E3E3E3E0E0E0E0E0DFE0E0DF
DEDEDEDFDFDFDCDEDDDADDDCDDDFDEDCDCDDE2DBDBDCC1BA843D328E140E9C090A990306
9D060B9B05079C0709980709950508920807881208BF7462C9AA9ADBD2CAD2CBC7CFBEB6
8550467407019F0807AE0405B70506C00B0CC0090CBF0A0DB90E10B216188F0305840104
84050999202382151A77141D70181F783539DFBCBECFC4C4D5D0CEC2C0BBC5C4BFB1B0AD
BEBFC0B8BBC0C8D0D3C7D1D3C5CED1B6BEC1C4CDCFC6D1D3B8C3C5919EA095A3A5949E9E
787874352C29A5A1A1BEBCBD58453000FF0000FF0000FF0000FF0000FF00
00FF0000FF00936B39C9BFB48592967C8C902C3737060202160202280406280001340101
5A04047A05078401058702078A03098E02089101069301059801069E0208A30308A90509
AC060AAF0A0BB10B0AB40D0CB70B0BBD0C0CC10C0CC30C0BC30B0AC70C0AC90D0ACA0D0B
CB0E0BCB0F0CCD100ECE100ECE110FC3141390120D854740D2BDB7E5E0DDE1E1E1E2E1E4
E4E3E6E1E1E3DFE0E1E3E1E0E9D5D3CD8F89B03B32BF1F18C91610CA130FCA110ECB1410
C61510B5130F9A0C098513115F110A43180B826B5BC7B9A8DED5C7E1DBD3E1DEDAE1E1DE
DDDDDADCDEDADDDFDCDFE1DFDEE0DEDEE0DDDFE0E0E2E2E4E1E2E3E1E2E2E0E1E1E0E1E1
DFDFDEDDDDDDDCDDDEDDDFDEDCDEDDDBDBDADDD7D6D1B7B0833C328D130C9E0A0AA1080A
A00609A006079C05069A0607960507940A078A180AC9856FC8AE9DDED8D0D5D1CCC6B2AB
733A307108038D0202A60507B30607BE0A0AC10B0ABC0709B90D0FDC3B3DA10A0D8F0104
86020583040784070A82060B7B080D6F0F137333369B7B7ABFB1AFB9B5B2D0D0CDCACAC9
CDCDCEB3B2B7BEC0C5C9D0D3C8D1D3C1C9CCBCC5C8B4BFC2C6D1D5B8C3C78290938F9B9D
8E92903A3230968F92C0BDBE5C483500FF0000FF0000FF0000FF0000FF00
00FF0000FF00A47F50CDC7BF8D9DA36B7C7E2B34330601001C03042E0508290104220101
3100015C04067C04078701058D02078D00068F01079302089500069E020AA4040AA9060B
AB080CAF0D11B61918AA0909B60C0DBC0B0CC00B0BC30D0CC40D0BC50D0BC70B09CA0D0B
CA0E0CCB0E0DCC0F0DCC100DC8130FAD1813761F16BE9E95E0D7D2E1DEDDDFDFE0E0E2E4
E0E0E3DFDCE0E2DDDFEAD5D5D79997B8423BC01E16CA1410CA100DC80F0CCB120ECC130E
CB150FC11B159F1D185C0E084A24169D8976D3C5B5E3D9CCE6E1D9E1E0DAE0DFDBE2E1DE
DEDEDCDCDCDAE0E0DDDFE0DDDEE0DDDCDEDBDCDEDDDFE0E1E1E2E3E0E1DFE0E1DFDEE0E0
DEDFDEDEDEDDDEDEDFDDDDDFDEDEDEDBDBDADBD5D1C7A8A181332793130BA10B07A40909
A10506A00405A107079C05069602049006048C1F11CB8E78CCB7A7DCD7D1DCD5D4BFA7A3
713028760906850201960404B10B0BBE0B0BC30C0BBD0808BB0A0BB5090BB10B0DA30609
9102048A04068D08098D080A8404077B070971121170312ECDAFACC3B9B7B6B4B1BBBBB9
CFD1D1D2D2D5CFD1D5C0C7CACBD3D6C9D0D3C5CCD1C0CAD0ADB8BEBDC8CDA9B7BA7E8D90
949C9D4D4A49878487BFBEC15E4C3B00FF0000FF0000FF0000FF0000FF00
00FF0000FF00AB895AC3C0B95D6E746F80843039390A02012405083205092F0406220203
1800003301026305077D03078802048C02048D01058F01069301089D050BA3060CA6070C
A4080DA30C10A51113A2080AB30D0DBB0D0DBD0B0BC20D0CC30B0AC50D0BC70D0BC90C0B
CC0F0ECC0F0DCA0E0BC9100BBC160F88160CA06A5EDDCCC3E2DCDAE2E0E2DEDFE1E0E1E3
E0E1E2E2DDDDE5D0D1D89C9CBB4642C5221BD11812D2130FD41612CE120CD2160ECF1610
C51811AB1C15660D055B3222AD9A86D1C5B4E3DBD2E2DFD9E0E0DBE0E1DCDFE0DBDEDFDA
DEDFDDDEDEDEDFDDDFDFDFDFDEE0DEDBDEDADEDFDDE0DFDEE5E2E2E4E1E1E2E1DFE1E1DE
DFDFDDE0E0DFDEDEDEDEDEDFDEDFDFDCDCDADDD4CFAF877C80231998120AA20B07A20707
A40708A60709A307089D0405980406910A07942E1FCA947FD0BDB0D8D1D0DBD3D4B39592
6E241E7C0A078503018B0101A20706B90C0CBD0A09BB0708BC0A0DB6060AB6070BB10B0B
9D04058E04058A05068D070A8806088107077E15108D423CCEA9A5DBCECFBFBBBAAFAEAB
B6B8B5BFC3C2CED4D6CDD5D7D1D9DBC8CFD4C8D0D6C8D0D8BBC5CCB0BBBF9DABAD96A5A5
7C85854343427A7779C3C1C2604E3D00FF0000FF0000FF0000FF0000FF00
00FF0000FF00AF905FB1B3AA596C707285862F38380A01022405052E03052B02051C0102
0F00011300003501026104067A02038401028700038B00058E00069703099F050AA3060E
9D050D990F14A41D219B070AAE0E10B00D0CB30D0CBB0C0DC20C0CC50D0BC60D0AC70D0A
C60C09C90F0CC80D0BC7130FA71A11803227CDB1A7E4DCD7E2DFDFDFDFE0DDDDDFDDDEDF
D8D4D3E1CCCAD09793B74843C1221CCC150FD1140FD2130FD71612D4150DD51B11C7170E
AD1C15660902673A2EBBA795D6C9BADED6CEDFDCD8DDDCDADFDFDDDDDEDCDEDFDBDEE0DC
DEE0DFDEDEDFE0DDDEE0DEDDE4E1E0E2DBD9DFD1CEDCC5C4DDBEBFE1C3C4E3D2CEE1DED9
DEE1DEE0E2E0DFE0E0DDDEDEDEDFDEE0DEDCD4C1BE8A4E49831611990B0AA20909A5090A
A70809A50507A306069D06079706098B0A059E4233C29683D4C6BADAD3D2D8CDCE997471
6C18118309068904058D0304970203B00C0BB90B0ABA0909BA090BB8080BB60709B50A0A
AC0C0D9001038703069614198B0B0F7F0707841D18CA81799E7672D1C0BFD2CFCEC8C8C8
BABCBAAFB3B2BDC4C5CED6D9CFD9DBCDD6DAC6CFD4BEC8CEC6CFD6BEC8CD869394909FA0
8F97994D4B4D6A6569C2BFC165534300FF0000FF0000FF0000FF0000FF00
00FF0000FF00A7875688887C5266666E81812E37370A00012203042B02042702031A0202
0A01000401001400003D01026704077A02038101038802078C010691010699040A9E040A
9F080DAE2226B62E31A41114A60E10B42525AB1D1CA40908B90C0DC40E0EC40C0AC50C0A
C60D07C71008C8110BBC171084170DAA7D72E1D4CEE3DFDEE1E0E2DDDDDFD8D9DBDDDBDC
D8C9C4C69087B04339B91F17C7160FCC130DCF130FCE110DD0130ED31711D01C14B31C14
710F06724235BDA798DCCFC3E3DBD4DDD9D8DADAD8DCDDDBDCDDDADCDEDBDBDDDADDDEDC
DDDDDCDFDCDBE2D9D9E1CFCDD9B9B6BC8B87A765629544419A3E3C9C4945B5877EDACEC6
DDDED9DEE0E0DEDFE1DAD9DBE0DEDDE1D6D4B58D8B7B26268A0D0E9A090AA3090AA80B0C
A70909A50807A006049B0706910505860C05B05D4CBC9986D7CCC2D5CFCDD5C6C58B5B55
75150F8908068D03068D02048F0001A10507B30B0BB80807BA0A09B90A0AB60707B7090A
B10B0C9803048701028D0D11870D107F0A0A7C100E943B386E2F2AAE8E89BDB4B2CDCDCE
CDD2D2CBD0D1C5C9CCBEC6C8C6CFD2CFD8DDCBD5DBC8D3D9B0BBC0BDC8CDABB7BB808E91
959EA168696C565357BCB9BB67554700FF0000FF0000FF0000FF0000FF00
00FF0000FF0081A745757362425451798B8A3137360F02022503032A0102230001150201
0600000000000800002400014C03026A03047901048001028400038A01059201079B0309
A4080EAC1217AB1317A40B0EA91415CF4143B1292B950304B30E0EC20D0EC40C0BC50D0A
C60F09C71008C2130BAA1E1581362CD0B8B2E4DFDDDEDDDFE1E1E3DBDCDFDBDBDDDDD3D0
CDA29AAB473DB72218C41610C6100CC9100BCB110CCC110CCD130FCA1511B61B16760E07
744034BEA799DACEC4E1DBD6DEDDDBDCDDDCDADCDBDBDCDBDDDDDCDBDDDBDCDCDAE0DEDA
DFD8D5DBC8C6CDA7A5A96764993E3B9929249F211DA41D19A4211D8D271E6C372AD2C2B7
E0DEDADCDCDCDCDCDEDDDADBE0D5D4C7A8A4843C3889161593090B9D080BA2080BA50909
A30806A106079E0707990707910806861208BA725DBFA291D9D2CAD8D3D0CAB5B37D413C
7A100B8B06059206078E03058A0001900102A60708B40A08B60806B70909B6070AB7070A
B40809A607088C01037F080AC25E60902C2D7F0F10830E0F71110E99625CBCA9A6BBBAB9
D3D6D9C8CDD1CBD2D5CAD2D5C9D2D6C7D0D7CAD4DDCBD5DDBDC6CDB8C2C7A7B2B8A0ABB1
828C8F62676A464648B4B3B366574815CC0300FF0000FF0000FF0000FF00
00FF0000FF0058C8335E5B474456538597963338371404032503042601031D02020D0100
0200000000010600001901013300015302037005077A02047D00038401059103089C050A
A4060BAB090EA80A0F9A0408A10B0EAC1317A10F12920002AF0C0DBE0C0DC20C0AC40D0A
C60E0BC7110CB9170E8D2115AB7E76E0D5D2DCDADDDDDCDFE0E0E2DEDEE1DBD4D3D0AEA9
A85249AF231BBD130FC10D0CC50F0CC50C09C60E0BC70F0DC81311BA1A1780110B743C31
BAA293DDD2C6E0DCD5DCDBDADCDCDBDCDCDBD9D9DBDEDDE0DFDEDEDEDCDAE3DDDAE4D0CF
CDA7A59A5A578F322F9D2522A71C19AE1814AE1613A91A1796211D60190E8C6D5ED2C8BE
DCDAD6DCDBDAD9D8D7DED4D2D2B5B19E5C548C201999100D9D090AA2090CA2080BA20808
A006069F06089C0709960507920B07912515C38770C4AE9EDAD5CFD9D3D0B99F9A702822
820E0B9008099105079004068E02058C0002960102AE0A0BB60709B8080AB40607B40706
B30806AF0A099B07087D0505BD6164A94D517C080C991114891011752A2AD7BABACDC9CA
CCCDD1B7BABDB7BEBECCD4D7CED6DBCCD5DDCCD6DFC6CFD9CBD4DDC6D0D78E9A9F93A1A4
929DA0626769363739B3B1B1695A4929980500FF0000FF0000FF0000FF00
00FF0000FF0051C0284A442D6373707689893138361504032302021F0101120101070100
0100000100000900001B02032B01023C00005902037103067801038000048C0306970206
A40509AA070CA60B108C03058D0A0D920D0F8906088A0101AD0D0EC00F0EC40E0BC20C08
C30D09C4140EAB2014843A2AD2BCB0E0DEDBDEDEE1DCDEE2DFE1E4E2DEDFDBBFBDB1655E
A8261CBA140FC2100FC20D0CC40E0CC50D0BC50D0BC7110EBE16148F130F6F2D25C1A699
DDD0C5E0DBD3DBDAD7DBDCDCDDDEDEDCDBDDDDDBDEE0DDDFE2DCDCE0D3D0CBABA89D5F5E
953939962220A11A18AA1714B01614AE1513A418148B1C1659150A735144C8B9AEE0D8D2
DBD8D7DBD9D9DBD4D1CEB6AF9E635A8C261E99130D9E0B09A00709A2070AA40A0CA10709
9E06089B06079506078F04058B0905963524C18E79CEBDB0D7D3CED9D1CF9F7B76701C15
860A098D04068D02058C02058D02068E0308910104A20508B3070ABA090BB50707B40707
B60809B30808AB0A0C90030681090D820E1485050A970C10931014741819B38B89D1C9CA
C4C4C8C8CACDB0B5B7BAC0C3BFC7CBCED7DFCAD3DCC8D1DCC0CAD4C3D0D8B5C3CA87979C
8797997E8587373639ADA7A769554529970400FF0000FF0000FF0000FF00
00FF0000FF004AB81E5B503754615E6B7B7C3739381A06062104041801010C0000030000
0000000100000A00001D01032801023000014300005F03047103037C010387010599060B
A5060BAB080CA30C107C0304802223C66E6F801718900909B3100EC1100CC30D0AC20C09
C40F0BBA170EA13222A07162DFD6CEDDDFDEDCE0E3DDE1E4E0E0E3E7D6D6C78985AF342C
BA1810C00F0DC20D10C50F11C50F0DC50E0CC40D0BBE110D9F161067150DAF8D80D6CABF
E2DFD8DCDCD8DBDBDAD9D9D9D9D9D9DAD9D9DCDADADFDAD7D6C1BDB1807C903F3B952523
A21D1CA61616AA1313AB1310AB1612A31F1B7E1C15480F05705444CCBCAEDDD4CCE0DAD8
DEDADBE1D7D6CDB6AF965F5484221B9611109F0C0DA10B0CA2090CA1080BA2090BA00708
9B05069604058F04068C0605880F07A6503EB78F7BD1C5BAD3D0CCD6C8C58E5F5973160F
890A098D03068A01038701028A02058A02078A0004930104AC080DB7090CB50709B5060A
B30508B20507AF0808A509098F0304870407870508870507880D0F812221CF9E9CB3A3A2
B8B5B6D1D2D5C0C3C8C6CBCFBAC0C4BFC6CEC4CBD4C8D0D9BEC7D1BBC6CFB6C3CCA3B4BB
7D8D917E8588383638A09794644D3A2B960400FF0000FF0000FF0000FF00
00FF0000FF0049B61B6D6047525E5B879395413D3E1E07071D0302110000090101040101
0101010100000A01011C02042401012A00013100004201015E0203750203860105950208
A2040AA7060BA3090C890C0C852B2CA85B5C8E2423A61111B90D0DC10C0AC30C09C50E0A
C20F0BB421179A4638CAAEA4E1DFDCDCDFE1DDE1E4E0E1E5E5DADCD6A7A6B04640B81E16
BF100BC10D0DC20E0FC61010CA1310C60F0BC20F0AAF1710751207946555CDBCADD8D7CC
D9DBD6D9DAD8DBDBDADCDCDAD9D8D6DDDAD7D9D5D0BBAFA793655D8C302A971B16A41816
AA1615AD1415AA1416A31918911F1A66170E42160A816A5AC4B8A8DED7CBE2DDD8DDDAD9
E3D8D7D2B4B0985B5384211A9412109D0C0FA0090DA1090CA30A0DA0090B9D0608A1080A
9C07089707089107078C0704841005B16651B69682D7CEC5D4CFCCCBB6B1753B3478110C
8806058E04068D01038B01038A0104870004860003890102980305B00B0CB40709B30609
B4070AB30607B20806AD0C099603038802038606078307087E0A0A731112975A5AD6BAB9
B2A9A8B3B3B3B7B9BBCCD0D3CCD1D5C5CBCEC7CDD3C7CED6C6CFD8C1CBD493A1A8A1B3B7
97A7AB6E7779383736948A83654C352D970400FF0000FF0000FF0000FF00
00FF0000FF0049B51974684D828D8D96A4AA46484B1D0B0C1802030F00000D0302060201
0100010101010901011A01032501012A01012D010132000047000169020584020795040A
A0050AA7060CA8080CA41214B73F3FBE4E4DAE2724B61110BF0B0CC10A09C40D0AC50E0A
C0140DB93C2F995F50DFD0C7DFDEDDDEDFE2DBDCDFE2DCDED9B8B8AF5954AF221CBD140F
BF0F0CC00D0DC41010C81110CB120FC8120DC0161193150D874536C5AC9BDDD4CAD7D6D1
D9D9D7DAD9DADCDADDDBD9DADEDCDAD9D4CFC6BEB5796A5D4D1D11922C24A01612A81514
A71414A919199D1E1F781A194C120A4E2F209E8C7CCFC3B4E3DACFE2DDD8E1DCDAE1D5D3
CAA7A59B554F90241F97110F9A0A0A9F0A0CA00A0CA10B0E9E070C9C06099E090A9C0708
9C07099A08099508068F0B05881C0DBF7D68BEA595D5D0C9D5CFCCB499937029227C0B08
8903058F03078E02058F02078D03068802038501028802048C0001A5090AB1090BB3090A
B00607B40909B30906AC08059A03028B020285060582070680090A7C0D106C191BC29797
CABEBDCFCECFB1B1B3ACB0B2BEC3C6D0D5D9CDD3D7C8D0D7C6CFD6BCC7CDB1BEC491A0A5
94A4A88C94963130308E847D6A50392E990400FF0000FF0000FF0000FF00
00FF0000FF0048B51B887C677C8A9092A6B0464E5515090A1602030F00000C0101070101
0100000101010900001B01012901012E00022F00023001013B00015C03067C030992050A
9E050AA8080DAB080DA90B0EA40F12A91415B21110BD0F0EC10C0BC40D0CC60E0BC40E0A
B51810BE5B4EB08B7EE0DAD4DDDFDED8DCDED8D8DBDAC7C8B57470A02520B71311BF120F
BE110EC11310C31110C6100FC8100EC5130EAF1A127D2015C8A192E0D2C8DCD9D3D9D9D6
D7D7D6DBDADBDEDDDEDBDBDADADAD8DFDCD7DFD8CFC7BAAD805F516D1C11A82823A21513
9B1C198D24215E16123D150D6A5446C0B0A2DACDC2E4DDD6E1DEDADFDBD9E1D2D2C29898
92423F941F1AA11511A20E0DA40C0EA1090DA40B0FA0080C9E080B9F090A9E08079A0406
9C06089D080A9707068E0B05932F1EBE8975CCB7ABD4CFCBD5CDCA9A766F6A19117E0806
8802048A01048D02078D02068B0204880203870102880203870001980607A80609AC0607
AE0606AF0606AF0606AF0708A304059101018505047E0705831211851A1C6F15168E5554
C2B0AED3D3D4C0C5C6C5CACBB2B6BAC8CBD1C9CFD5CCD4DBC2CCD3B4BFC8C6D0D8ADBBC2
8493988E989A4745478D837E70573F2F990400FF0000FF0000FF0000FF00
00FF0000FF004AB61E887F6D8B9AA3A7BAC8444E570A04061001020D00000C0000080102
0100000100010B00012103023003033402023301023000003700014900016902068A060C
9B050CA4060BAB070DAC080DAB070BB00A0CB80C0DBB0C0CBE0C0DC10B0DC40C0CC1110D
AE241BDA9284D1BDB3DDDCD8DBDEDED8DCDDDDD8DAC59C9B9D3933AB1711B61311AF1715
9C130F9D1411B01413C01213C81413BC18138E190D9E6355DAC6BADED8D2DCDCD7D9DAD6
D8D9D7DAD9DBDDD9D9DFDAD8E0DDD9DCD8D5E0DBD6E4DAD4D9C5BA815046852E278C2722
651710421309543A2DA39485D4C7B9DFD4CBE5DEDAE1DCDADFD9D8D8C9C7AC807E8F3937
961D1A9F110DA9110DA80D0DA60C0EA2070CA30A0E9E080A9F0A0A9F0807A108099E0608
9D07099C06089606058E0E06A84D39BC917CD6C9BED2CFCACEC2BD82544C6E110A800402
8602028902048901058A02068901048A02048801028A04058401018801019C0507A70506
A80302B4110FAC0808AE0609AE08089F07058B0705790706963637DE8D90661718955955
BBA19DB5B2B0AFB3B3CFD5D6CDD2D6C0C6CBBFC6CEC9D1DBCBD5DEC8D2DCB0BCC5B6C5CC
A4B3B979848857585B877F7C79614D2F980600FF0000FF0000FF0000FF00
00FF0000FF004DBA248F867683929AB2C4D13E49500905050C01000A00000B0101050001
0100000101010D01012201013001023602013301013100003A01034101035400037C060D
97060FA3060BAA070BB00B0FAE080BB1080CB7090CB90A0CBC0B0CC30C0FC40C0CBB140E
B23D30E1AE9FDDD2C9DDDFDDDADEDFDFDFE0DEC9C9AD6461A3231AAB18118D110E5B0605
3C01003E0000760B0BB01412BC140FB1281B833322D0AFA2DFD5CDD8D7D3D6D6D4D5D5D3
DCD5D4E1CCCCDFBBBBD6ABA8DEBBB6E5D2CCE1DBD6E0DBD7DFD4D0C4ACA4542E2540180B
482C1D968675D1C5B5DDD3C7E6E1D8E4E1DDE6E2E1EDE1DFDCC1BE9C6765862D2A921B19
9D1411A4120EA30C0AA20A09A50C0EA2090BA40A0CA10909A20A08A00706A20709A1060A
9F080A9A06099607068B1008BE705EC09E8FDCD2CBD5D1CEC4B1AC73382F770F08840502
8601028802038C04068C03068A01048802048701038701028602038301018D0102A3070A
A90607C72727B31112AE0708AF0908A6100DAC3232730D0E751B1DC26F737320217C3A36
B99994CAC1C0A5A6A7A8ADAFBBC2C5C7D0D4BCC5CDC4CDD7C9D2DDC8D2DDC4D2DB9FAFB7
98A7AE929CA242474A827C7C8670622D980800FF0000FF0000FF0000FF00
00FF0000FF004CBA2499918099ABB0B1C7D13B494F0605060A00000B0100080101040102
0100000300000F01012201012F00013701013802023300003D02044302034A0001690308
8F090EA0070BA8070BAA070BAB0609B1080BB60A0CB7090BBF0E0EC10D0CC3100CB5180F
C76355DAB5A8E2DDD7DEE3E1DCE1E1E3DEDECCA2A09E3934A01C167A0C0A400101290D07
35251C40241D60120CA11811AD180CB74E3BA27460D8C9BFDBD7D3D8D8D9D9D6D7DFD1D0
D6B0AEC57B78B54C49B23D37B04A44CF938CE4CFC9E3DEDAE2DAD7D7CCC59182756B5D4A
BCB09CDCD3C3E2DED3E3E1DBE2E1E0DFE0E0DDDCD9C9B5B39364618338367F24227D1A17
821A188B1B18901513960F109E0F0FA00C0BA10A09A10807A30907A208089F0508A00509
9D05089704069709088E1B11C48171C6AEA2DCD4D0D5CFCEB49995722A237C0B07880405
8802038701028701028903048601028702058601048400038501038403028500019C0709
AA090BAD080AAE0809B00508AF080AA10F11F3888C8121266D090D841E20801D1B6D1816
8E5D5AE0D1D0BCBCBDBEC2C3A6ADADC1CCCEB7C2C7CAD4DBC7D2DAB8C5CEC7D4DEB1C2CD
7F909996A3AA50585C7172728F7F722A980900FF0000FF0000FF0000FF00
00FF0000FF004EBD268A83728FA1A69EB6BD354449030506080102080101060101030100
0000000300000F00012302023302023801013601003601003E0103420203480102600206
82080C9C0A0FA6090DA9070CA90609AF090AB30A0AB60A0ABC0D0CBE0C09BE0F0AAD1A0F
D47F73D8BDB5E3E1DFDEE2E3DEE0E3E2D0D1AE68679D27247D100D44070556382F917F6E
A1927FB29684B06F5F9C2A1AA32816D2846EC9AB9ADCD5CED7D6D4D7D7D6DED1D1D3A5A3
B45752B92F29C3241DC0211AB12A24923F38C0A29AE1D9D2E2DEDADFD9D2CAC0B4CFC5B4
DCD4C6E3DED7E5E4E2E3E4E3DEE0E0CAD2D0888F8D4B44413D221F37130F320E0A2D0B06
300B08340A08430C0C5E0F108215169310109A0A099E0808A10708A20808A10707A00709
A0080B990607970D099A3123C78F7DCEBBAFDAD3D0D6CECB9D7A75731D188308088B0405
8901028600018501018601038500038701058702068500048601038503048300018E0102
A30608AB0405AD0404B00506AF0708A60B0FAD282E8712177A090B8919189B2B2A771110
6B2321C0A0A0BAB4B6D1D4D7B9C0C2BFC9CBB8C2C8CAD5DCCDD8E1C3D0D9ADBAC5BCC9D5
A9B8C173838A6671755F6464958A7D2A990B00FF0000FF0000FF0000FF00
00FF0000FF004DBC24857F6D93A4A9AABFC82C383F050406070002040001020001010000
0100000101010B00002402023501023C01013B01013A01014001034300024A01035B0206
6E00058E070E9D050CA6070DA60408AD070AB00909B50A09BA0A0AC00E0DBE130EAB251B
DE998DDDC9C3E3E1E1DFE0E3E3DFE1D0ACAB9B3F3A8F1C16560904795849AE9D8EC9BEB0
D4CABEDBCDC2DAB1A2A3523E9C412BCF9681D9C5B6DBD5D0D8D7D5DBD8D4C9AFA9A35650
AA2B25B1211AA91F18941F1A6E181343130A6F5B50D0C7BDE2DED8E2E1DCD8D6CEDEDAD2
E3DED9E3E0E0E1E1E1D0D4D29EA8A34C5B561B2A251A1E192F2820433B304D4539484035
3D352C2F281F1C110A2007033B08096710128D13149B0B0C9D0709A1090B9F0606A10707
9E05079A0707931008A84A36C0927DD7C9BCD9D2D0D4C8C68A5E587516118909068D0506
890202880202850101830102840103870103860104860205860203840101830101870001
9C0607AA0708AD0707AE0608A90204AC070BA8080D9C090D8908098E17178C1716851817
6D1D1CBB9392A59A9AB2B4B6BAC1C3CDD5D9C8D2D9BCC6CFCCD6E0C3CDD7C1CAD5A9B3BE
A6B5BE88989F525E605054549B90842B9B0D00FF0000FF0000FF0000FF00
00FF0000FF0047B61D989481809599A3B7C12730370904060A0101040001020101000001
0000010100000C01002601023701024102034202034001024202034400034C0004570106
6501077A020995080EA3070CAB080DAE080CB0090AB50909BD0C0CC10C0CBB120EAC2F25
E3A8A0E4D5D2E2E1E2E0E0E2E5D9D9B9827F942B2280180B824A39BAA696D5CDC2D4D2CC
D3D4D0D6D2CFE3CCC3A56B59AA6650C9A08EDDD0C6DAD7D2D9D8D5D4CEC78E756D652A22
75221C6A19144C0E08330902270E054A3C2E9A8F7FCDC5B8E1DED7DFDFDBE1E1DDDEDEDA
DCDDDAD6D8D6B5BBB8666F69313A31464D41727366A1998BBEB0A2CCBDAECBBCADC9BAAA
C4B6A6B9AA9DA4988A6E64582A19132D04036610118F10129C0A0D9F080BA3090AA20705
A108079B09068E1306B5664DBE9B85DACFC5D7D1D1CFBFBD7C474179120E8A06068F0407
8A01038B0305860003830002830103830103820004820004820202800101830103850001
930304A70909AC0707AE0807AD0505AD0607AC060AA80A0E9306099F212196211F841B18
803634E3C0C1BAB1B2B0B1B4A4A8ABC0C9CCC3CED5C3CFD5C9D4DAB6C1CAC8D3DEB7C3CE
7A8A9292A2A8616B6E434546A1948A2A990D00FF0000FF0000FF0000FF00
00FF0000FF004BB920908A778B9EA37E9199242B30080305090102030000000000000000
0000000400001501012F04043A02033C01023D01013D01014001014600025403095D030B
6401096D000687050AA0090DAA080CAE080CB00609B80A0BBC0A0AC30E0CBB130FB13B32
E1AEA6E5D9D7E4E3E4E2E1E2DECCCB9B5C568B261A8E3928C29A89DCCEC4D5D1CCD3D5D2
D3D6D5D4D2CFDBC3BC945B4CB67965D3B1A2E0D6CFDAD8D6DBD8D6C4BDB5544A3F1F1007
1E0C032312082D21155C5344A09586C3B8A7CEC6B6DDD7CCDFDFD8DCDDDAE0E0DDD7D8D2
BBC0B87A8176585E51878B7DB7B7A9CAC4B6D2C9BCD9CDC2DCD0C6E0D5CDDED4CDDED6CE
DED5CEDBCFC8D2C5BBC3B6A9AC9E93553F383F08067F1517970B10A10B0FA30A0BA30A07
A109089A0B088E1D0FC2816ABEA793D9D2CCD5D0CFC9B5B27D3D398212108E05078F0207
8E0307900509890105840003820002820204820104810102810100820102850305860104
8C01029D0608A90609AA0406AB0506AD0606AF0809AC090C9E080A8A0506860E0E7A0E0D
701D20CA9EA3CCBFC2D1D1D3B5B9BCBDC6C9ABB7BBC6D2D7C7D3D9C3D1D8ADBDC6BECED6
A3B4BB6D7D837C888B3E4343A2968D2C9C1000FF0000FF0000FF0000FF00
00FF0000FF0054C12A7E756569797D75868B242B2C060303050101020101010001000000
0000000600001A02022E03033502033300023401013601013B01014602045301065F0309
66030A68020676010594080CA80A0EAF070AB20708B7080ABD0B0BC00D0AB8150EB9493D
E0B2A9E4DCDAE2E3E5E1E1E3CCC1BE6D473D5D2215B38576E1CDC2DED8D4DBDAD9D9D9D9
D8D8D7DED3D3D6AAA7934539D28B78E1BEB0E4DBD5DCDCDBDEDBDACEC4C0948A81726A5E
736C5C8D8272AEA290BEB3A3CDC3B7DAD4CADFDCD3DEDED7DBDCD8DEDEDDDEDBD7ADA89E
706F5E959581C9C8B4D3CFC0E1DED2DDD9D0DFDAD4DFDBD8DEDBD8DFDCDADCD9D8DCDAD8
DCDADADCD9D8DEDAD9E0D7D4D6C9C2B8A79F623E38600C0C8E0D109D090CA009099F0807
9C0808960F089D3928C2927CC4B7A8D8D4D1D5CFCEBBA29F702823860E0E95080B900207
8F02069103068E04068A0305840103820003840205830103830204820103850104870308
850005940509A7090CAB0606AD0505AF0607AD0405AD080AA7090D94040789070A80090C
79111472282BA68183C3BABABABEBFCCD3D7BBC4C9B8C3C8C0CCD2C7D4DDB5C5CEACBDC6
AEBEC586939A6471733E4443A2978D2C9C1000FF0000FF0000FF0000FF00
00FF0000FF0054C0286B604C515E6088989B222B2B020302010100020101010001000000
0000000500001400012801023202033201012E00002D00003200014001024E0206560307
5B02066104096E0308850308A1090CB0090BB6090ABB0A0CBE0A0BC00D0AB7150EB94E42
DCB3A9E4DFDDE0E3E5E2E4E6B9BAB62F2A1F493B30CCC1B8E0DBD8DEDEDFDEDEE1DCDBDD
DCD7D6DDC0BFBD6E6CA02F26C96C5DD5AC9FDCD3CDD7D7D6DAD8D9D9D2CFC9BEB6C5B7AE
C9BBAFD0C2B6D7CCC2DCD5CEE1DCDADCDBD9D9DAD5DADBD5DBDCD8DFDEDAD8D2CACFC6B6
D0C8B3DCD5C4E3E0D4E1E1DAE0E0DBDCDCD8DCDBD9DDDCDBDDDBDCDEDDDEDBDADBDBD9DB
DDDCDFDBDBDDDAD9DBDCD8D9DBD6D4D9D0CBB8A098703029841410990E0D9A09089A0807
9B0909911007AC5541C69F8BD3C8BDD5D2D0D9D3D1B496916E201A860D0B93090B95070A
9304089102068F02058B0305850102860105890408840104830003870205870206860409
8100048701039E070AAC080AAE0507AF0508AF0609AA0406AA090BA20A0D8C0709870F12
800D0F7813158C4D4EC2ADACA7A7A8C4CACEC3CCD1C1CAD0BDC8CFBECBD4C4D2DCB7C7CF
7F91989AABB26A777B404545A2968C2D9D1100FF0000FF0000FF0000FF00
00FF0000FF004EB91F5A4F3673827F95A8A9202D2C010202010101010101010101000000
0000000400001201002301012D01022F01012E00002F00013601023D0101420001480102
4D01035400026702077A010698080CAE0A0DB70A0BBB0A0AC00D0BBF0C08B91611B74940
DBB0A8E3DDDCD4D7DADCDFE1C4C5C26D6E6489867DCFCDC9D6D8D6D6D9DBD6D6D8DBD4D4
D6BCB8BB7873A62F29B11F15B43B2ED8988BE4CDC8DBD6D5D9D7D8DCD6D6DED7D6DBD3D3
DDD6D4DFD9D4DFD9D6DBD5D5DCDADAD1D0CCC5C3B9CFCDC5DDDBD8E1DEDBD2CCC6DCD5CB
E4DED4E7E3DCE5E7E1E2E3E0DDDDDCDBDBD9DCDCDADCDCDBDCDCDCDCDCDBDBDADADCD8D9
DDDADCDCDADDDAD8DBDBD9DBD4D3D2D7D3D0DCCFC9AB7D757A1B15910F0B970A08990708
9B0B0B91180DBE735EBFA08ED9CFC6D4D2CED7D1CCA8877D721F178509078F0607930507
98070B9200059101068B0104870102890205870104820001870102880202870204840207
800105810003940406A80809AB0406AD0407AE0508AD0608AD0A0BA30A0B8C080AD05F60
801211801617863D3CE0C3C4B3B0B1A8AFB0A9B3B6C3CDD3BFCBD1BDCAD3BAC8D3C3D1DB
A9BAC174878D8A9AA03B4445A59B922E9E1200FF0000FF0000FF0000FF00
00FF0000FF004AB61A564B2E6E7E79849A9B192727000403010101000000010101010102
0101020300001101012002012701012D01023301013801023E02023D01013E0001460104
4C0002530001660206750306890306A80B0FB70C0DBA0A0BBD0A09C30E0DBB110FAC302B
E4A9A3DACCCBCACCCECDCFD1DBDAD8C3BFB9BBB7B2D2D1CFD2D3D3D2D2D2DBCFCFD4ADAC
B16460A62B27B51814BD140FB31813C0514AD99A96E3C8C6E0D5D3DCD6D5DDD6D7DDD5D8
E2D7D9E0D0D0E1C8C9D1B2B4B39B9B80756BB4AE9FDCD5CDDFDBD8DEDDDBDDDAD8E3E1DD
E4E3E1E4E5E4E4E6E5E3E4E4DFE0E0DADBDBDCDCDCDDDDDEDCDCDDDDDDDCDDDBDBDBD8D9
DCD9DADBD9DBDBDADCDBDADCD8D8D8D8D8D7DCD6D3D2B4AC8A3E378D130F990A0B9B070A
9D0F0C922114C38370C0A898DBD1CBD7D3D1D6CFCA9D776E7118108A0B07900505940507
9605099403099203088B0104860001840102840203830102850203840102840204860408
8102068001038C0202A40A0AAB0707AB0505AC0406AF070BAC070BA60A0C960A0D971E20
871313871615772321BF9998B6B0B0C8CFD1A8B3B5B7C3C6B9C6CBC3D0D8B7C6D0AFC0CA
B4C4CD7F9298718285474E50A2978F30A01400FF0000FF0000FF0000FF00
00FF0000FF0049B5175145274A5B55788E8E182626000303000000000000010101000000
0000000300001202011F02012201002801013202023B01014102033E01013F0000470103
4F01035800036A04077A050A8202059A080CB00D0FB90C0CBD0A0AC30C09C1100EAE1A18
D67C7ADEBCBBD2CBCCD3D3D4DADBDAD5D5D2D0CFCCD1CECED4CED0D9C4C5C5908FAC4C4B
AA2220B91513BE0E0CC51110C11111B51917B73E3BD17E7BE0A9A6E5BCBBE0BBBBDEB3B4
D9A3A3CC8685B964659D4B4C612D287F6A5CD0C8B8E1DCD3DEDBD8DFDEDCE0DFDEE2E2E2
E4E5E5E5E7E7E4E5E7E3E3E5DFE0E0DBDDDCDADCDBDBDCDDDDDDDEDEDDDCDBDBDADBDBDB
DADADAD9D9DAD9D9DBD8D8D9D9D9DAD7D8DAD7D5D4D8C3BE965750881713990B0D9C0A0C
9A100C9F382BC69280CBBAADDAD3D1D7D2D3DACECC9A6F687417118A090593050697070A
9404089001058F02058B0104860001830103860404830201820201830203840204850305
850307830206870002990506A50503AA0505AB060AAD080DAA060AAA090DA40A0E910409
970E13951515821F1A8C5752A39494C1C6C9C2CCCFBDC8CBB5C0C6BDCAD2C5D3DCB5C5CE
8899A39CAFB66E7E7F464C4CA1938A33A11500FF0000FF0000FF0000FF00
00FF0000FF0046B1135E50304B5A54758888151E1E000101000000010001020101010100
0000000400011202012003011F03021B00012601013803043D01023D00004201014A0002
5501046201067203097A03088103088D0409A70C0FB60B0CBF0C0BC00C09C10C0BBB1310
B5312DDD8F8FE7C7C8E7DDDDE0DCDCD6D1D1D6CECDD5C3C2C7A0A0B26969A63332B11C1A
BC1310C00E0DC00C0BC5110DC7100EC71513BD1715B5211EB73835BB4847B64545B53F3E
B33432B22927A927257B1D186A3B2FC1AEA1DFD7CEE0DBD8DCDAD8DFDFDDDEDEDEE3E3E4
E6E6E8E5E5E7E6E6E8E5E5E7DFDFE1DCDDDDDBDCDDDBDCDEDBDCDCDDDDDDDBDBDBDADADB
DAD9DBD9D7DBDBD9DBD8D7D7D8D7D9D8D7DAD9D6D8DACAC79C645D8718149A0D0E9E0E0F
911008AA523DBF9682D4C8BED9D4D4D8D3D5D9C9C998696476160F8F0C0A920607960609
9303079003068E02058E0206890204850001880303860202830102830203830102860505
8301038201048300028F0203A30708AA0806AC0809AA0509AC070CAD080CAB0C109C0609
98080C99121191241F9C5C57B7A2A0A3A5A7A7B2B4C5D1D5C3D0D7B6C3CCBECDD7BCCDD6
A1B2BB75878E92A0A24348489E918833A31700FF0000FF0000FF0000FF00
00FF0000FF0042AD0E6252326975707B8E8E141F1F000102000001010001020101010100
0000000400011202011E02011B00001700001F0000350306380203390000460101510004
5D01076E050A7503077B0307800509870409980508B20C0DBC0C0BC00C0BC20C0AC10D09
BD1612B42C2AD17575E4AAABD5A9A9CCA09EC18A87AD615EA23836A71F1CB31312BA0E0B
BF0D0AC20E0BC10D0BC40F0CC7110DC6100CC8130FC61410C41613C51918C21718C01717
C31B19B41D1A8617125F2317B39A8BD8CEC3E1DCD8DEDADAE1E0DFE2E2E1E3E3E4E3E3E6
E5E5E8E6E6E8E5E5E7E5E5E7E3E3E4DFDEDEDCDCDBDCDBDADEDADADFDAD8E0DBDADCD9D8
DBDAD9DAD7D8DBD7D7DBD7D6DAD8D7D9D7D8D8D5D5D7C8C69B645E861A149B0E0D970A08
8C1308BB7059BFA08DD7D0C8D4D3D3D4D3D4DBCDC995645D7A16118C0808930509930409
8F02088D03088A01058902038B0405870101870102880304870102850002830002830102
8501048502058300058800029D0608AB0809AD0808AC0709AE080CAF090DAE0A0EA40B0F
9105078E0E0C80100F772E2DCDB2B2CDCBCDA0A9AAB0BDBFB9C7CCC0CED7B8C8D2B3C4CE
B8C8D27D8E967D8B9053585B998F874B711C00FF0000FF0000FF0000FF00
00FF0000FF0043AF0F64583463706A7C8F8F131E1D010202000000020201040301010000
0101010300001200012302022A02032B03032D00013A03073900023F0001510203600307
6904096F060A7404087804087E040885050A910304AC0D0CB90E0ABE0C08C10C09C40E0B
C7110EC21310BB1E1BB02A29A8302EAB3430A72823A61915AE110EB80D0CC00E0DC00C0B
C50F0BC40E0BC30F0BC4100CC6100DC40F0BC6130EC6100DC70F0DC50F0CC61311C21413
B5191889181453150DA3887AD6C9BEE0D8D4DFDBDBDDDBDCE2E1E2E4E5E4E3E4E5E3E4E6
E3E4E6E5E6E8E5E5E7E7E6E8E7E3E3E5DCDBE5D5D4E0C5C4D6B2B3CDA5A6C6A1A1CFB2B2
DCCCC9DED8D6DBDAD8D7D6D4D7D5D5D9D7D8D8D5D5D3C1BF93585285160F9B0F0D980D0A
8B1A0DC0806AC0A999D7D3CCD2D3D4D2D2D3D7CAC69A6B617B170F900A09940507950508
8F03068B0206890007880104890202880202880204890205860003850004850205820104
850104860105840205840102940606A80A0AAB0605AD0708AC060AAF080CB00B10B31A1E
A51E208509098210116E1B1CC29FA1D1CED0B5BEBFBFCBCCB1BDC3C1CFD8C0CED9BDCBD6
9DADB69DADB5717F86565A5F968B8567422400FF0000FF0000FF0000FF00
00FF0000FF0043AF0F5D522F41514B809494121C1A010201010100020200020101000000
0100000600001400012702043201043401013D01024803064901035402056505096C0509
6904076F0E0F6F0C0F73070C7F070C8505098B03059C0605B50E0BBF0D09C30D0AC50E0A
C70E0AC8100BC9140FC1110FB80F0BB5100BB30C08B60B0ABC0D0DC20F0DC30F0CC10D0A
C30D0BC6100DC40E0BC50F0DC40F0DC30F0DC30F0DC5100EC91210C4110DC0130DB41815
85131150140D8C7467CABEB4DDD5D1DCD9DADBD9DBDDDCDDE3E3E3E3E4E5E4E5E7E5E6E8
E4E5E7E6E4E6E9E1E4ECDDDFEDD0CFDCA9A8CD8381B75A589E3838922C2C8D2C2C8F3C3B
BB8883D5C3BDDBD8D5D6D6D6D5D5D7D6D5D7D9D3D4C7ACAB823B358C1511970B0B960F0C
8E2518C48C77C6B4A4D8D5D0D0D2D2D2D2D3D5CAC89D716A75170F900C0A940307960309
93040A8B02068B0208890208880205870103880105870104880105870104850204850204
880307870308800003800203890101A40B0BAE090BAC0609AB0509AF090DAE090EAD1114
A81C1E850608800B0C6F1414A37575BFB7B89FA9A9C8D3D5C4D1D8BCCBD5C1D2DCC1D1DB
A8B8C17D8F968C9BA14D515692858169422700FF0000FF0000FF0000FF00
00FF0000FF0041AD0D4F42212E3E38798C8E131C1D010201010000020101020201000000
0101000802001701012A02023501023C00024802035102055802056103066C060A6B0307
882124BB55579C383B6602047605098404098A0305940303AD0A0ABD0C0AC40D0AC60E09
C50C06C9100BC8100DBF0908B80604B50805B70B0AB80A0BBA0A0BBC0C09BD0C0ABA0706
BE0A08C20E0BC20C0AC20C0BC10D0EC20E0FC10E0DC51110C71111C1100FB4161088140D
51120A907468C6B8AFDDD4D0DBD9D7D9D9DADEDEDFDDDDDEE1E1E3E3E2E7E4E4E7E6E5E6
EAE2E3EDD9D9F2C6CAE8A1A4D26F6DBF413DBA2925BD231FB11A18A31413A015159A1F1C
AA5A53CDAFA6DAD6D1D5D8D7D2D5D5D6D5D6DACFD0AF86837E251E94130F990B0A940F0B
943425C1927FCCBEB3D2D1CFCECFD1D2D1D3D8CCCCA077717319118D0A08940407950409
9104088D03078B02098B02098B0309860003880105880205880205870105860104880205
8702068201057F01048004068501029D0708AC080BB0080DAA0509AD070BB10B0FAE0B0F
A60E108E070A820C0D81282483544EBCB3B08D9595B7C3C7BAC8D0C1D2DABBCCD4B6C7D0
BDCED87B8D9579888F64696E8A7F7C6B452C00FF0000FF0000FF0000FF00
00FF0000FF0042AC0C4A3C1749564E7C8D8F141B1E020203010000030100030201000000
0201000800001901012D01023D02054501054B02045101035A0205640507640307640002
840F149312168E101373040770010484060B8C0408930406A40608B90C0CC30D0AC60E09
C80F09C9100CC9100DC60E0BC00C0ABB0B0CB50809B50809B70909B80A09B90B0AB70707
BB0A08BD0B08BF0B0AC30D0EBF0B0CC10E0EC00E0DC41110C41113B91414911511551209
8C7061C1B4A8DED4CFDCD8D7D9DADAD8DAD9DADADADFDEDEE4E2E3E7E4E6EFE7EAF1DCDF
F4C7C9E69698D45F61CE3A3CD52C2BD1211BCD1B14CA1A15C01815AC0F0FA61212991B17
752B20AC9387D9D5CFD6D6D7D4D6D6D8D5D5D1BDBC8E534E881B189A11109D0E0E91100A
9A4231B99380D3C8BFD0CFCFCFCFD1CDCCD0D8CDCFA27E79721D15890D098E0404930407
8F02058B01058C0408890107880106870104870103860002860105860106850205870304
860304830105820206830407860104970507AB090DB0070CAE080CAE080CAF090CAF0A0B
AB0D0E9309097D100DA9645BA98C82A9A7A0939C999FABAC9CA9AFBACAD1C1D2DABDCED7
9EB0BB9EAFB96F7E866D73788377756A462D00FF0000FF0000FF0000FF00
00FF0000FF0041AA0A4637124E5B5284969712191C040203060201060201030101010000
0500001100002201023301034302064800044B00054D00035701045F05095B01036D0406
8E0B0E9B080A9A0B0D8107086D0002840A0D8D06099205089A0206B10A0BC00D0BC30C09
C50E09C50E08C9110DC7100CC20D0BBC0A09B80808B60808B70909BB0D0CB70908B80A0A
BA0A09BF0E0BBC0908BF0C0CC10D0DBF0D0CC10F0FC00E0FBC1213A017175B0B06856658
C0B5A7DCD5CEDDD9D8DBDADBD8DADAD9DCDBDBDDDCE0E0E0E5E1E0EEDFE0F3CCD0E2999D
CD5C5DCD3738D52524DF2321E2231FD91E17D01A13CE1915CA1C18B81512A61614871E19
59261AB5A79BD8D7D1D6D7D7D3D5D5D7D0CFB08E8B7F2D2A9216159C0F0F990C0A8F110B
A75345B89787D7CEC6D1D0CFCECED0CDCCCFD6CFCFAC908B712720850E0B8C03028E0103
9002058D02048C04078A01078A01068B0307870104840001840104830106820004840203
8703048803058703068602068802078E0104A5080CAF080CB1080BB1080BB1090CB00A0C
AC0B0C980B0B7A0E0CAD716AA491889092898A958F9BA7A5B3C0C4B6C3CBAFBFC8BDCDD6
AABBC386989F86959C575A607F736E6F4A3100FF0000FF0000FF0000FF00
00FF0000FF0040A90A3C2D0A59665D899A9C12191C020201040100050101050202040100
0C00001D01023002053B01044301034B01054B01054700024C010452030853000177080B
940A0C9D0709970A0A7905056600017D08098905078F0206970406A30304B80C0BBC0B08
C00C08C30E09C40E0BC40E0BC4100BC00E0ABC0C09B70808B60808BA0D09B90A08BC0A0C
BF0C0CC30D0CC30D0CC20C0BC4100FC20E0EC3100FBE1210AA1916670B067B5448C0B3A6
D7D3CADBD8D6DAD9DBDADADCD9DADADADCDCDEDFDEE3DBDAE9CCCCE6A5A7CD6266C63538
D32727D81E1BD81915D91915D61915D31915CF1713CF1915CA1A16B81916941D1953130A
836C5FCAC4BAD7D7D3D6D8D6D3D2D2C5B1AF894B48871A1897110F990E0B950B08881008
AA5D4FB89A8DD8D1CBD0D0CFD1D1D3D2D2D4D6D2D2B8A6A1632A247B11108C06088E0104
9203068E03058A01048C03088B03068801048501038201028101027E0003810105840206
8501058802068801078A040A8A040A8A00049D050AAD070CB0070BB0070AB50C0FB20B0E
AF0D0D9F0B0C820B0B99534EA78D8497968C7D878083918DAFBCBEC7D4DCB4C3CCAFBEC6
C5D3DB84959C85959A6B7175786C696E4A3200FF0000FF0000FF0000FF00
00FF0000FF003DA8094B3D1C5C6963809294121B1C0202010400000601010700010A0000
1600022701033A03054302064601044701044603044101034300024703054D00027B0C12
90080E950A0D84080A6401035E00007705078805078D02059202059A0103AD0808BA0C0A
BD0B07BF0B08C10B0AC40D0BC30E0BC00D0ABB0A08B70907B90B0BBB0C0BBB0908C10C0C
C50E0FC30D0DC20D0BC10D0BC20D0CBF0B0ABC0D0BB015147C110C703D34BAAA9ED7D2CB
D8D8D6D8D9D9DBDBDDDBDBDDD8D7D9E2DFDFE3D5D4DFB4B3D17979C43D3DD12A29DA2321
E0221EDB1B16D5150FD41611D21512D01614CF1714CB1814C11A189D1A17570C046C5042
B8B0A3D8D3CDD7D6D4D5D5D4CABCBC9E6E6E82232191100F9B0F0D9A0C0B950C09840F05
B26B5BB9A093D8D2CDD2D2D2D0D1D3CFD0D2D3D4D3C2BAB65934306A131286090D91060A
9102058F03058C03058700038500028501028301038101037E00037D01037E0104810105
8402068702088A03098B040A890408880106960309AB0A0FAC070BAF080BB20A0CB60E0E
B10B0CA90C0F910A0D7E1F1D9D6D67A3938CA0A19C848F8D8A989AC6D5DAC4D3DBB8C5CE
B0BDC6A8B9C076868C788185736A6874503B00FF0000FF0000FF0000FF00
00FF0000FF0039A5055145235A6A647D909210191A0101010400000801010E0000140000
1F01012D00023E01044903074801054102033800013800003F010143050842000364090E
78090F76070A6203064E00025C02047B06098905078E0407920306950102A50604B90E0C
BD0B09BF0B0AC10B09C30D0AC10B08BD0A07BA0806BB0908BB0A09C10E0EC10D0EC10E0E
BF0C0DBD090BBD0A0BBD0B0BBF0D0DBF0F0CB7141190151068271EB09A8DD6CEC7D9D6D4
DAD9DADADADDDBD9DDD9D7DAE0DADCE2CAC9D29494C05251C32A28D2201CD81C16D91A15
D91B14D41810D0160ECF140FD01614CF1816CA1815BF1E199A1D17560C04644639B7B0A0
D6D1C7DBD7D4D9D7D8D0C7C59971707F2A2A8D1212970D0C990A0A9D0C0E990C0C89140C
B47363BEA99CD6D3CFD1D1D2D0D1D3D1D2D3D1D2D0CFCCC974605B490C0A7B0F108D0609
9004088B01068901058A02068702048301018200008102047D00037D0002800103820103
8502048503058702058A05088703058702038F0206A4090EA8050AAF080CB3090BB40A0B
B20B0CAD0C0E9F0C0F820D0E6E1A1B693939A29490A5ACA994A1A3ADBCC0C1D0D6C7D5DD
B4C2CC97A8B08C9FA4606B6F6D666574513D00FF0000FF0000FF0000FF00
00FF0000FF003BA60745391951625C80929312191A0302010700000F01011A0202200201
2601013000023C01024602054902064601043D01023D00014701054102053200033F0308
4B02054F020644000246000263040982070C8D05078F0304940405970303A00403B20B0A
BA0A0ABD0A0AC00B09C30C0BC20C0AC10C0ABF0A09C20D0CC30D0BC10E0CBC0A0AB9090A
BB0B0DBC0B0DBD0C0DBB0A0BBE0D0DBB1110A3151267110CA17E73D0C6BDDAD6D5D8D7D8
D9D9DBDAD9DCDCD8DBE3DADCDBBFC0C37C7DB73D3CC82522D41D18D71914D71712D61611
D61911D2170ED11711CF1511D01815C81816B91E1C8C1A154B0C046A5044C0B7ABD6D3C9
DCDBD7D8D8D7CFCDCD9E8A886F3230841A19910D0E990C0E9B0B0D9F0D109B0E0F8B1911
B9796CC3B0A6D4D2CFD1D0D2CECFD1D1D2D4D0D1D1D3D3D098908C2F0C09641010840A0C
8D06088A02048801038801058701048401018201018001037D01037F0205810103820103
8402058503058302048803068B04078903048A01029D070BAC090EB1090CB3090BB40B0B
B30C0DB00C0EA50D108C080D75080C5C1111896865999B98B1BCBEC1CED5C1CED6BBC9D3
C7D6E1899BA3798C91677376635E5E74544100FF0000FF0000FF0000FF00
00FF0000FF003EA80A3D32146F7F7B8092950F16160601001000011C0102230102250000
2A00013400034102054801054C01054C01054A01034E01065204074A050A2D00012A0507
350B0C4C191A3E03044F010473080C87060B90070A9002069706089C06079F0405AC080A
B6090ABB0908C00B0AC20A0AC10909C30D0CC10B0BC10B0BC00C0ABA0908B60709B90B0C
B80A0BBA0A0CBD0A0CBF0C0EBD0C0EB4151380120C835148CFBFB7DAD6D1D9DBDADADCDD
DADADCDCDBDCE3DEDFCEBBBD9D6B6C983938B42927C91E1BD71B17DB1B16D41610D2150F
D1150ED21610D31814CE1512CB1C19B21D1C7E1713410D06756158BCB2AAD9D5CFE0DFDD
DDDDDCCFD3D1959B993E383535110F5A1112790F108F0D0F980B0E9B0B0F980E0E8C1D15
BA7D6FC3B0A6D5D2D0D0D0D0CCCECECFD2D3D1D1D4D2D1D3B7B4B242312F3B0606730F12
8405078A04048803028601028602038602028301008101017F01027E01037F01047E0103
80000482010580000485040889050A890408880002970508AA090CB20B0CB2090BB30A0D
B20A0DB00A0DAB0D1093070A7C070964110E916B67908D8BAEB8BBC9D6DDC7D5DEB6C7D0
B5C6CFA8B9C0718388727E825D595975594500FF0000FF0000FF0000FF00
00FF0000FF0037A407554E326375737B8D901114141102012002022B02032D0103290101
2B00013400034102044A02044E02064F01055101045501045A020553040736020326090A
AD9392B38D8C591A1A6C0D0E7D06078604068D04089204099502059B05069D0304A40304
B10808BA0A09C00B0CC30C0EC40D0CBF0B09BD0A08BB0A06B70904B50806B50809B7090A
BA0A0CBA0A0CBD0A0DC10D11BB1111AF2C24742E22B49B90DBD3CDD8D7D5D7DADADFE2E3
DFDFE0DEDEDDBFBFBF6961613D222145100F5F0808A71C1BCE1B19D71813D91914D81915
D41814D41514D51918CC1D1DAA1C1B6E120F3F130C7F6F64C6BEB4DCD5D0E1DDDCE0DEDF
D7D6D5A8ADA838413B1119110E0C051703003E05057A1213900B0E9B0E11970F0F8C2118
BC8273C9B7ADD4D1CFD0D1D2CECFD2D0D0D4D1D0D5D0D0D2CACCC87C7A741C06044C0C0B
750A0B8506078702018903038A04058803048401018201008101007E01017E01027D0103
7E0104820205810004830206850208860309850004910305A70A0BB00A0AB10909B2090D
B10A0DB00A0BAE0E0F990E0D962926601714A98784AFADAEABB6BBB9C8D2BDCED7C3D3DB
AFBFC7A3B3BB96A5AC5D686D4B484674563F00FF0000FF0000FF0000FF00
00FF0000FF0034A3095E5B43627677808F951410121D03022E02033702043504052B0101
2C01023100023C00014501034C01054E01055001055201025801045A04065B18193C1616
6B5251855E5D863D3C780F0E8105068803058E05089405099703069904059E0505A00304
AE090AB80A0BBE0B0BC10C0BC30E0CBE0C09BA0B07B70A04B80B06B40807B70909B90A0A
BB0A0ABF0C0CC10D0EBE0F0FAD150FB451448F6556D3C6BDDBD7D3DBDADADADBDDDCDDDF
E1E3E4C3C9C8545C5B1A211D2827203B2F2839120E7B1412C21E1CD81B16DA1914DC1B17
DA1B19D21817C71D1DA21B1A5E0C094520178D7F73C9C2B6DBD7CEDEDDD8E0DFDED9D9D7
C5C5C1B8BAB19A9B909190847F7C6E474035220705590D0E8A1114990C10990E108E2119
BA8374CBB9B1D6D1D0D0D1D2CFD0D4CFCFD4CFD0D5CDD1D2D0D2D1B0B2AD3C3A321C0300
4E09097407098503058801028802038501018201018101017F01017E01017D01047D0004
7E010482020484020485020488040787040A840107890204A10A0CAE0B0CB20B0BB30A0E
B10A0DB20D0DAF110F9A1210CA6764793734835E5CBBB3B4AFBABFB9C7D0B5C4CDC1CFD7
C6D3DC99A9B386949D778087423C3870513900FF0000FF0000FF0000FF00
00FF0000FF003DAD1353503A51646789979D1D1517270605320102360104310103280001
2C01033300023F01024902054C01044E01055002065101045400035D0207610D128E4A4E
975D5E8741407314157E0A0C8204068A04069006089202069804079B05069E05079E0305
A40407B50B0CBF0D0DC20C0CC30D0CBF0B0ABD0B09BB0C08B80A08B90A0ABC0C0DBC0B0A
BC0C0BBB0A0BBE0D0EBA120FA8251ACA8172BEA396DCD4CFD8D6D6DBDBDDDEDFE1DDE0E0
C2C9C75C68622F38327D7E77B5AFA5BCB2A6BB9F93A3544CB82721D41D18DB1A17D81A17
D11D1BBB1D1D8C1715500B07503229A3988DCDC5BBDCD7D0E0DFDADEDEDCD9D9D7D3D3D1
D1D1CCCECFC8D0CEC6CAC8BDC1BAAFB1A79C806C6349100E801315950B10980C0E8D1F18
BD8477CBBBB3D3CFCFD2D2D4CDD0D2CBCFD1CFD3D6CFD3D6CED1D4CED0CD898B831A1611
1C01014F0A0A7307098505088401038000018101027E00018001027E00027C00037C0003
87070B941214850304850307830106850308820106810002960708AA090CAF090AB1090C
B30A0EB00A0CB00F109F1010AA3D3C8E3B3989504FA99596989EA3C1CED6C2CFD8BDCAD4
BDCAD6B2C2CF7A8A93818A8F4B45426B4C3500FF0000FF0000FF0000FF00
00FF0000FF0043B21B56524180919596A0A62A1D202C06073302013501032D0002250001
2D02053701044403044C04064A02034701024B01044F00055301045C020663020A690811
6D0B11720A0F79060A7D02068504078A05078E04059605089903079C05089D04079E0508
9F0305B10B0CBD0D0EC30D0DC30C0DC10B0BBD0A0ABA0B08B80A08B80B0ABB0D0EB80A09
B90B0BB80A0BB60A0AB31410B44236C79181D0BDB3D9D4D1D6D6D7DADADCDEDCDCC9C5C2
666962515950A6AA9FCAC6BFD9D3CDDED5D0E0CFC9E2ACA5B8423CC9211CD31A18CA1E1D
AB1E1E6D0F0F3C0C06655245B1A89BD3CDC6E3DFDBE0E0DFDEDFDFE1E3E2DFDFDFE1E1E0
DEDEDDD9DAD8D6D8D5D2D5CFD4D4CED8D2CCC5B7B092655E7A1E1B8F0E0F970E0E8F1F18
BE8378C9BBB1D2D2D0D0D0D3CCCFD2CED3D5CED3D5D0D4D6CFD3D6D1D2D3C3C2BD686761
110B081C01004F070978060A8101038000028001037E00017F00017F02027F0104800205
840507890D0E7901027A01047C010781050C7D04087A02038A0305A4090CAC0809B00B0B
B20B0DB20B0CAF0B0DA70C0F910D0E7D0F106F2222BB9B9B9FA1A2B3C0C3B6C3CBC4D1DB
ADBBC7A4B5BF9DACB66E787F4B45436E4F3900FF0000FF0000FF0000FF00
00FF0000FF003DAE197D7C6F97A9B0A4AEB62F1F243407093B02033701012F0101270101
2C00013801024603074903064301033E00014201034901054F01045B020666020A6E040B
73040A77040A7C020980030788060B8C05099105089504079904099C04089C03069D0406
9F0506A90708BA0B0DC00C0DC20D0DBD090ABC0B0CB80A09B50807B40707B7090AB6090A
B40808B70A0BB60B0CA9140EBB584BBA8F81DBCDC7D6D4D4D5D5D7D7D5D6D2C6C58C7671
614F45ADA79CD5D4CCDDDCD9DDDDDCE0E0DFE5E0DEEBCDCBC26965B62421B9211F901A19
510B08371B15887F74C5C1B4DCD8CFE2E1DDE0E2E2DDE1E2DCE0E0DDE1E1DCDFE1E0E2E4
DDDEE2DADBDED6D8D8D4D8D5D1D5D3D1D3D1D8D1CEC3A5A17F3832881411940E0C8C1C16
B4786FC9B8B2D3D0D1D0CED4CDCFD3CDD1D4CDD1D3CFD2D4CFD2D6CDD1D4D2D2D1B4B3AE
514C481502013C01027004078102048100018101027F00027D00017B01017D010384070A
9C24249A2B296E01027302067202066E03066A0203700202840306A20B0EAF0D0EB00B0B
AE0808B20C0DB10C0DAC0C0D9C0C0C870A0C751618A87D7DB9B5B4BBC4C7ABB6BEBECAD3
BFCBD4A1B2B995A5AD838D9548434273544000FF0000FF0000FF0000FF00
00FF0000FF0040B31F878A808296A0A8B4BF2F1E243706093E01023C02013401022C0101
2F02033802043F02043E01033B01033901023C00033F00024700025702066402086C0108
74030A7601097B010885050B88040A8803088B02069002069603079902079B02059E0507
9F0607A30405B60C0CBC0B0BBE0B0CBE0B0BB9090AB40A0AB10808B3080AB4080BB40809
B30707B30607B50A0BA5160FC46D5EBA998BDAD1CDD4D2D4D4D2D5D6D3D29F948F5A4239
A58E82D6CAC2DCD9D6D8D8DAD7D8D9D7D9D9DCDADBDFC5C7A65D5D9428266E1311360803
483A30A29F94C6C4BDD9D7D2DEDEDCDDE0E0DCE0E1DDE1E3D9DEDFD8DEDEDAE0E0DCE1E1
D8DCDDD9DCDDD5D8D9D3D7D7D1D5D7D3D7D8D6D5D5D6C6C49B646080181593130F87180F
B3766BC6B5B0D2CFD1D0CFD5D0D2D6CED2D5CFD1D5CFD0D3CFD1D5CDD0D5CDD0D2CED1CE
A9A39F5F413C5B1310790A098104038101018201028201047F01047C00027D00037E0205
8712139122207102027102046802035B0000892D2EB04B4D800D0E980A0CAC0D0DB10C0B
B10B0BB10B0CB10B0DAC0D0EA017169421217517197C4647A99EA1C1C8CDBEC8D0A9B3BC
C5D0D9B9C6D07889928C98A05B57587D5E4C00FF0000FF0000FF0000FF00
00FF0000FF0093703D75786EA2B4BFACB6C22E1C233807094103033E01013802032B0101
2600012B01023301023701013601023301013702023B01024300025401076101066C0107
76030A7B020980030B82020B85030A8301078402059006089704079803049B04059F0608
A10709A10305AE0708B90C0CBC0C0CB80A0AAF0A0B9F06079B0506A8080BB0070BB40709
B10405B20607B10908A1140CC26F5DBDA192D9D3CED3D1D4D2D0D4C8C6C3605E55595244
C8BDB3DBD3D0D5D3D4D6D6D8D7D7D7D7D7D8D6D2D3B8A1A3703D3E4C14123415106E655B
B0AFA4C9CAC2D8D8D6DBDBDBD8DADADADEDEDBDFE1DBDBDDDADBDED9DDDEDADEDFDADDDF
D8D9DBDADADDD6D7D9D6D8DAD5D8DAD3D7D8D3D6D6D7D0CEA47A787B1C1991130E85140C
AF7065C7B3AED4D2D4CED0D4CDD1D4CCD0D3CED2D5D0D3D6CDD1D4CED2D5CDD1D3CDD0D0
CFCCCAB7A29B8A524875150F7E06038403038301038402058201057E00037D01047C0104
7C02057A02057701037301026901045B00017814189E282E9A1C218A0205A50C0DAF0B0B
B30D0BB20C0BB10C0BA90F0DA62928EC92936A1A1D733B3DAA9799B0B4B9B8C4CABAC6CE
B4C1CAB5C3CEA5B3BE6B77805C5B5E80675800FF0000FF0000FF0000FF00
00FF0000FF00926F408D9089AFC3D1A6B3BF2C1D223809093E01004202033A0304270102
1A00002100013203043802023402022C00002E00003A00024700035401056001046C0105
7A050A7D03087F01088001088102088103078302058C03069304079502059601039C0607
9E0607A10507AA0708B60B0BB80B0CB4090B9F02048700017F0000930305AB090BB10708
B10708B00505B30A09A3140BBD6757BD9F91DBD5CFD3D3D4D3D2D4BFBEBA68695D8A8879
D5CFC7D5D2D1D5D5D7D4D5D6D7D7D8D2D4D5B0B5B25A5954291C17392B23979186BEBCB0
D3D4CCD9DAD7D9DAD9D7D9DAD7DBDCD9DEDED8DCDDD8DADCD9DBDCD9DDDEDADEDED6D9D9
D9DADBD9D9DAD8D8DAD9D9DCD5D9DBD2D8D9D2D8D7D1CCCBA077767B1D1A9513118F1713
AB635BC9B2ACD7D5D5D1D4D7CDD2D5CED2D3D0D3D4CFD3D5CDD2D5CBD1D3CBD1D2CBD0D3
CBCDCED2CBC8B9979091443C7C0B078403038401028702048501048000048003067F0206
7D01047A01037801037401026C02035D01006D0307920B119D0A109404089B0709B11010
B20D0BB10C0AB5100EAE100E9C1516CE6368741B2069292BC5ABAEBEC0C59DA9AEC0CED5
C4D1DAA3B3BE99AAB685919B4A4A4D80675900FF0000FF0000FF0000FF00
00FF0000FF008D6A3B90938F778D9A9CAAB52E21233408073D0101400302350201210101
1400001F01023302043801023101022A00013000004001034D01055601036001026C0103
7502067A000581040A82040A8303088603088904088D04068E0203920305940204960304
9B05079C0305A20407AE090BB40B0BB10809A80709A10B0C900404940203A90708B10808
B00707B10606B10705A9100AB34940C4958ADDD1CBD4D1D2D5D3D4CBC9C5B0ACA2B4AFA5
D5D2CDD5D5D4D5D6D6D5D7D6CCD0D0A5AFAD4B5C541423184C5145A3A194C6C3B8D9D9D1
D9DBD8D7DADCD7DCDBD6DBDAD6DCDCD7DDDCD7DCDBD6D9DAD7D9DAD6DBDAD6DBDAD8DADB
D9DADBDADADBD9DADCD7D8DBD4D8DBD1D7D8D3D6D6CEC2C1935F5E811818940E0E901412
A0524AC5ABA4D6D5D3CFD3D6CDD2D5CCD0D3D0D5D6CDD3D4CCD1D4CCD1D2CDD3D3CBCFD0
CAC8C9AD98988B55517C201C810909870306870205880206870104840205810205800205
7E02047C02047801037701036F02035E000068010291090DA1070DA00A0F8F0103A40D0E
B00D0EB30C0CB10B0BB00C0FA80E139A1017820E14651719C0A0A4C8C9CFB5BFC5ADB8C0
C6D3DDB1C1CE788A9893A1AD5555587F655700FF0000FF0000FF0000FF00
00FF0000FF008D6636797C738BA3ABA8B5BE2F20223408063C02023A02032D01011C0000
1400001E00013303043A02033300013301013E03034802044F01045801036202036B0103
7603087C02087F02068102068503088602078902058E0506910506910305950407960105
9D0609990306990204A60609AE090AB00908AE0808AB0607A60505A30203AC0606B10707
B20808B30809B60A0BB10C0AA11B16C4756DD6B6B0DAD1D0D4D2D3D6D3D4D6D3CFD4D1CD
D4D3D1D7D4D4D6D0D0C3BEBE8C929131423C1A2B1E6F7768B2B3A7CFCEC6DADAD5D9DBD9
D6DBDBD4DADAD7DDDCD8DCDCD8DBDCD9DDDED8DCDDD8DADCD8D9DBD6DADBD6DADAD8DBDB
D8D9DBD9D8DCD8D8DDD4D6DAD2D8D9D1D7D7D7D5D6B79E9C7E34328B1313950C0C941513
903B34BE9E97D4D1CFCED2D4D0D4D7CED2D5D0D4D7CED2D5CFD2D4CED0D2CDD0D1CDC9CB
A98E917E3F3F791716840A0C8A060B8803088502058502038703058201037F01027C0101
7C01037C01047A01057901037002045F01016701028B05099E0409A0090D8C0204930709
AD1113B10B0CB40D0EB00B0EAC0A0EA20C10870A0D7826279C7D7FBFC1C7BBC5CCBEC9D1
BAC8D2B5C6D4A5B7C571818C66696B81685A2F960800FF0000FF0000FF00
00FF0000FF008963305154497F949CA9B5BF32212536080A3800013301012901011E0101
1B00002401003401043D02053B01033A00024102034901045201045A02046303056B0105
7603087C01078204078304058504088301058702048B0204910506910306950306990406
9D07099803069702059F0306AA090AAD0807AE0606AE0505AE0506AF0607B00708B00607
B20608B6080BB30508B4080AAE0E0DAA2C29C27772D8B5B3DCCECDDAD2D3D9D2D3D9D0D0
D8C9CAD0B5B6B38E907055552B27232B342A878E80BCBBB1D6D5D0DBDBD9D9DADADBDCDD
D7DBDCD4D8DAD7DBDCDADBDDD8D9DADBDDDCDBDDDDDADBDCDBDADDD9D8DBD6D8D8D5D7D8
D8D9DBD9D9DCD7D6DCD5D6DAD2D6D8D2D4D5CDBFC0905E5E7F1D1D9412129A0E10930F0D
86261FB78D86D6CDCBCFD0D2CED2D5CDD1D5CCD1D4CDD2D5CED1D5D0D1D4D2D1D1B29C9D
7E403F7D1615870A098904068702058401058000047F00018001017E00027D01027C0102
7B01017901037800027801037003045D01006803038B05079E0406A40A0E93070A860305
A20F13AE0B0EB40E10B00A0BAD0B0DA20C0E860C0DA55A5AC1A8A8A9AEB097A5ABC1CFD7
C2D1DBA5B6C3A2B4C0809199525659826C602B940700FF0000FF0000FF00
00FF0000FF007B5623787B71A3B8C3A7B3BF311F253507093602032E02022401011E0101
1F01012700013602053C03043802033501023A00014602035102045901046100046D0207
7904087F030783030784030687060A8402078804068B03058E03059103059805089B0507
990305940204950205990205A40609AA0507AF0608AF0608AF0507B20608B20507B00306
B10408B6080DB40509B40608B5080BAF0D10A82222B85655C47F80D09B9ECC9B9EC0898C
B16C6F974B4D6E302F3815114B42389A9A8DC4C3B9D6D7D0D8DAD8D7DADCD7DBDDD9DBDD
D8DADCD5D9DBD8DBDDDBDBDED9D8DADCD9DCDED7DCDDCCD1D5B9BDC1A4A7A49599ABAAAC
D0D1D3D6D7DAD6D6DBD7D8DAD3D7D8CDC9CAA7898A7C2F308A15159910109B0D0F970E0D
851B14B07971D3C3BFD1D1D2CCD1D2CDD2D5CDD3D5CED4D4CED4D4CACFCFCBC5C58C6462
751B19880B0B8B05078904078603058101038201058001027E00017D00027D01037B0002
7A01027B00037A01037801047003055D01016501028D080A9F0608A6090D980A0E7A0000
960A10AC0B12B20B10AF0A0DAF0C0FA40B0D8F0E117F2B2EB08F92BFBEC2A3B0B5AEBFC7
C3D4DEBACBD575879193A3AA565B5C826D612C960900FF0000FF0000FF00
00FF0000FF00744F1E94978F97ABBAA6B1C02E1E2432080B2F02032400001C0101190000
1E01002701013002033001022B01012700012E00003F00024E01035B02056301056D0106
7602067D030685060A8604098604098604098702058C04058F0306930208960207990307
9501059201049201049501059D0205A80509AE0508AD0306AE0507AE0505B10507B30507
B20508B3060AB4070BB4060AB7080DB6080CB20B0DAE1616A71F20A82A2DA62C30A5292C
9C2728751C1A3E10095E4D42AAA398CBC7BFD9D6D4D9D9D9D8D9DBD7D9DBD9D9DCDADBDD
DBDBDDD7D8DAD8D8DADFDADDE0D2D7DFC2C8D5A2A9B56D759E4E53783A3E3D2325848281
C7CBC9D6D8DAD5D6DBD7D8DCCFD3D5A3A19F654544721E208C1014990C119A090D9C0D10
8C1311A55D59CDB4B2D1D0CFCBCFD0CFD3D5CED3D5D0D4D5CFD3D4CFD1D3BCAEAE703737
7D14138D090A8B04078803068402038401028401038201008102017F01017E01027D0101
7D02027C00017A00027600027003055C01015F010184060A9F090DA60D12940B0F760101
900B0FAB0C12B10A0DB10B0EAE0B0EA70A0E970B0F780E12652C30B3A7ABB6C0C7B8C6D0
BDCBD8C1CFDBA2B1BB7383896E7273816C5E309A0A00FF0000FF0000FF00
00FF0000FF00825B2C86878092A6B3A9B4C22E1D2333080B2A01011F0100190000190000
1E01002601012C01022901012000001D00002A01013E02014E01035B02056301056D0106
7602077A01058205088404088504078703078B03088E0106920307920206930105940206
9001068F0104930207940106990104A40407A90406AB0306AE0607AF0707AF0607B00507
B10408B3060AB40709B5080AB80C0EB80A0CB80A0CB60B0DB50C0FB61113B41316A61818
7B15133F0C0767584CADA99CCDCAC2D7D6D4D8D9DBD8D9DBD7D9DAD8DADADADCDBDADCDC
DBDBDDDBD9DBDDD1D4DEBEC3CA8F95B96067A8383F9F32357724244012126C5F5AB6B8B2
D2D7D4D3D7D9D6D8DCD2D1D5B9BBBC5153501F0E0B5110118110139A11149A0A0D9D0C12
940F14923835C09E99D4D1CFCFD2D3CFD3D5CFD2D4D1D2D4D3D4D6D2D1D4A38E8E6D2726
800B098B03058B03078701048701038500018500018500018301017E01007E01037D0103
7D01027C00017B01037600017103045C010251000068010489090E90091081060C6E0204
820709A60D10B10C0EB20C0FAF0A0EAA0A0F9E0B10810A0E661C1E9E8688939A9FC0CDD7
C5D2DDB4C2CDADBCC67B8991575A5E816C5F309A0C00FF0000FF0000FF00
00FF0000FF008A673B71736EA8B9C7AAB2BF321D243308092B00012200011F01011C0101
1F01012400002A01022801012101011D00002A00003E01034C01045602046000036C0107
7703097C03067F02058404088706098905088C0307900206930407920403920204930306
9004078C0104910207930209960107A10409AA080BAE0709AF0508B00609B00508B3060A
B10608B20608B30608B30709B40B0BB80D0DB70B0CB90C0FBB0E12B81014AA161779100E
420D086A5A4EAFAC9FD0D0C6D7D9D4D4D7D7D6D7DAD9DADCD5D9D9D5D9D9D8DCDCDADBDB
DDD7D7DEC5C9CA9398B45A60AE363DAD2B329324275D141236130C6C6159B6B5ADD2D3CE
D6DAD9D4D9DBD1D3D5B8B7B8B1B0AE93938E4D453F360B0878181592100F990C0D9B0B0E
980D128A2120B4847FD5CECACFD4D4CDD4D4D0D4D5D3D4D7D3D4D8D1CED09D81816D1B1B
8407098D03068D02058C03068802048501018501018600018702048300048100047E0103
7C01017C01027A01027801027301026304044800004C00016505096E050A68050A5F0104
79060BA00E11AE0B0EB00C0FAD090CAA0A0FA10C1285080C671618C1A3A59DA0A5B8C5CD
C6D4DEB5C3CF7F8F9A99A6AF5A5D61806B60309A0E00FF0000FF0000FF00
00FF0000FF0086653D888B88B8C9D7AAB0BE331E263307092C01022500012201021D0000
1F01012400012900012B01012701002600013102023D01034901055201065B01046C0307
7502077D05088003078406098605098A04088E05078F02049002058E02038F02058F0306
8E04068E02069203089203089202089301049E0307A70407AD0509B1070AB1070AB1060A
B4070AB4070AB3060AB5080BB4090AB90E0EBA0E0EB90D0FB60D11AD15178112133E0906
6B5B4EB1ACA1D2D0C9D6D6D3D5D8D6D4D8D8D5D8D9D6D9DAD4D9DAD6DADBDAD9D9D8CACB
CDA2A5B66569AB363BAC282D9F24287116183C0A0739261E837F75BDBEB3D3D5CED8DAD7
D4D8D8D5DADCD2D4D6D4D3D4D3D0CFCCC8C5B3ACA67C5B556E1A188F11129A0D119A0A0F
990B0F8B1413A25E5ACBB8B5D0D2D1CCD2D3D0D4D7D1D5D8D2D4D8D5D0D39675766C1918
8308098C03058F05058D04058801028701028500018401018501018601038403047F0204
7D01027C01027A01027801027701026C05064A00004001014F0709530507500408510105
6D0409980B12AB0E13AD0E10A8080AA90A0FA20B128B080F6C1317AE898EC9C7CFBEC8D2
C2CEDBC1CDDB9EACB977848C787C7F7D6C632C990D00FF0000FF0000FF00
00FF0000FF007E5E358B8F8C9AACB9A5ADB92E1C212C06072B00012701012201011E0000
1F01002601012E01033001012E01012B01013402013F01024800045100055A0104660003
7302067802057D01058103078504098803078C04059104069002068E03058D03048F0408
8D02058B00048D02068F04078B01048B0001930103A40608AD070BB2090DB1070AB00407
B00305B20406B40709B4070ABA0E0FBB0F0EB80B0CBA0F11B112169115174A0805695348
AEA99CD3CFC8D7D5D5D5D7D8D6DADBD6DADBD4D8D9D7DBDCD9DBDCD8D3D4D7B9BCBE7C7F
AB4345AC2B2EA123277A191C480C0D2B100C544D44A9A89DC4C4BBD5D7D1D8DAD7D8DCDA
D4D8D9D6D8DAD6D6D9D9D9DBD6D6D8D5D5D6D7D2CFBFA7A3803D3A881517980E139A0B10
9A0A0E92110F88312CBB9994D6D4CFCED2D2CFD4D6CFD5D6D0D4D6D1CED09779786C1B1B
82090C8903058A02038B03048A02058802038601028500018401018201017F02017D0102
7D02027B01017901027901027A020375090A510202480D0C6D3434592221400708440203
630305930D12A60C10AE0F10A9080BA7060CA2080F900C11842B2F8F6C71B3B3BCC9D4DF
C5D2E0B7C4D2B7C4D07B88926B6F757B6B642B9A0E00FF0000FF0000FF00
00FF0000FF007B5A31909392A6B8C6A4ACB82B1A1F2B04062C00012901002500001F0000
2001002400002D01023402023302022D00003301013F01024C01055602075C0105640103
7302067A02067B02068103098002078502078B03078F03088E00058E02059005098E0309
8A00048B03058C04068D03058F04079002049A0305A7080AA90509B0080CAF0509B20609
B10406B30608B5090BB80C0DB70D0DB90D0BBA0D0EB30F129A13175A0A0963473EABA498
D5D1CAD6D5D3D4D5D8D4D7DAD3D8DAD4D8DBD5D8DAD9D9DADCCED0CDA0A3B1595EAA3035
A62829831C1C510F0F290B0838302A8E8F85BEC0B4D2D1CAD9D9D4D9DBDAD9DCDBD7DAD9
D7D8D8D6D7D6D6D7D8D5D8DAD5D9DCD5D7D9D7D5D6D5C9C8A06F707F1A1C930D1296070B
9B0A0E960D0E831815A26E67D0C7BECDD3CFCBD3D4CCD3D4CFD3D4D1CED09F8282661817
7E070A8903068A03048903048701028600018501018501018301017F02017C00017B0002
7A0002780001790102760102770102790D0B711C1B5A2323D9B3B3D1B1B28B64663B0203
650407900A0DA20A0CAA0C0EA7070CA5080BA2090F930E138F393DC3A5A8A0A2AABDC7D3
C3CFDDC5D2DF909FAAA1ADB7626367806D632E9B0E00FF0000FF0000FF00
00FF0000FF008568408E9493BFD0E09DA4B32C181E2F03073201032E01022A0102230101
1E00002100012B01013402033702043002023201013D01024D01055A0206620205680204
7304077A03097A01077E010983040B8301068A02088E02099003089004079206098E0207
8A00048C04078901048D03078F01069200069B0307A30709A6080BAD090FB1070BB20608
AF0506B00607B40A0BB50B0BB50C0BB80E0EB70F0FA514146B0B0B5D3531A89C94D1CEC7
D5D5D3D4D6D7D4D5D7D8D9DDD5D7DBD5D7DAD8D4D6D6BEC1C18589A74347A52B2E902124
5F13122F0B082D231D6D6E64B3B5ABC6C7BFD6D8D2DBDBD9D8DADBD6D9DAD7DADBD5D8D9
D8DADBD3D6D5D3D7D7D2D8D9D1D7D9D1D8D8D3D7D7D5D1D2A38080781D1E92101397090D
9B0B0F970B0E880F10873C36BDA39CD5D5D2CDD3D4CED2D5D0D2D6D5D2D5A98B8C6A1F1F
7C07088903068A02058901038802038702038500018501028202027D00027C01037D0103
7B01037901037801037401017201006E0301943A365314115A2F318D696E8051574A0106
73050A93080EA0090EA0060BA0060BA3090EA2090F950C11791D21CBA5A9CDC9D0BDC6D0
BECBD5C9D7E19EAFB77F8E96787B80806D63309D1100FF0000FF0000FF00
00FF0000FF0080643CA8ABACBFD0E0959BA82A151C2F05082F00013001022E0203260202
1E01012000002901013001013202032E00003300004101035002055A01046403066B0307
6D03077102087802097E010980030A8101068B020891040A9205098E03048E0406890104
8801048902068902058D02078F01069301059802059602048F01019D0608AD090DB20609
B20608B3090BB3090BB40B0CB50D0DB40D0DAE141482121257211EA59590D0CCC8D6D6D4
D5D7D8D4D7D8D6D7D9D9D8DCD9D6DBDBCFD2D2B0B2A75F639D36399327276D1919390B09
26191159594FA3A59CC1C3B9D4D4CEDCDBD9DADBDBD9DADCD7DADCD6DADBD7DBDCD6DADC
D5D8D9D3D9D8D3D9DAD3D8DAD3DADAD0D9D9CFD7DACBCDCEA38383781D1E9512149A0B10
9A090F96080B8E080A801916AA7471D4C7C6CFD0D1CDD1D3CED0D4D8D4D7AF9696732C2A
7F0C0D8A04078C04088802048601018500018501018500018100017D01027D01037C0002
7C01017A0101790102760002720100710301791714A253506928275615145F101173090E
89060D99060E9E070E9B050C9B040C9E070EA10910990B127B0F15935961B8AAB5CAD0DB
C6D3DEBACAD6BCCDD87B8B9472777E7B6B66319E1500FF0000FF0000FF00
00FF0000FF007D623BB5B9BBC0D0DE989EA82613172803042B01013102022C0001220101
1E00002401012A01012C01022C01013000003B01014A02045301055C0206620204670204
6801046D00057702077E02088102078502058E05099306098D01048A0205870103890305
8902068A02068C03078D01079002069303049905079F080A960405970003A90509B1070A
B10507B3090BB70D0FB50C0DB60F0FB0110F99161458100C8F7870C8C5BFD2D4D1D5D7D8
D6D6D8D8D7D9D8D7DADAD8DADFCFD3C5979CA15257943135751F21471110240F0B47463F
94988DC1C3B9D0D0C9D9DBD5D8DADADBDDDFD9DBDED7DBDCD5D9DAD7DBDDD6DBDDD4DADA
D3D9D8D2D7D6D4D8DAD4D8DBD4D9DBD3D9DAD2D7DACBC2C593626481191B970E119B090F
9A090E9A090E96080A8D0F0F8B3937BD9D9CD6D1D1CED1D1CED2D3D4D2D4BAA5A5753532
7B0C0B8802028A02048802038600018400018200008401018502028202058002057D0103
790102770101780201770202730101720101700303771516953D3C923A378C28267C0609
8C04099B080D9C060C9A050C99040C9A040B9E070E9D0B11890F146C1E26A48C95BDC3CD
C8D5E1C2D3E093A5B098A7B2686C737868652F9C1400FF0000FF0000FF00
00FF0000FF0081663FB6BABAC5D3DF7B7B85250D122603042601012E03042B0102210100
1E00002701012B01022900002800003100014202044C02035100045800055F0103680507
6C02057101047902068003088503078702038B02068C02078B0206890204860102870103
8A02058D03078E02078E0107910407930305990205A00407A60509A80408AE060AAF0508
AF0508B3090CB50B0FB70D11B30C0FA413136F0E0B734A44BEB4ADD6D5D2D2D5D4D4D6D7
D7D7D9D8D6DADAD5D9D5C2C6BA8C8F92464A7D292D551719290D0A2F2B247A7F76B5BAB0
C4C7BFD9D9D4DBDBD7D8DCD9D7DCDCD8DDDEDADEE1D7DBDDD7DBDCD6DADCD5D9DCD4D7DA
D5D9D9D4D8D8D6D9DBD5D6DAD6D9DBD5D9D9D5D6D7B9A2A480393C8D1618980B0F99090D
9D0C0F9A090B99070A940B0B811413A46A68CCBBB9D1D2D0CBD0D0D0D1D2C5B6B77C4645
77100E8904048C03038700018701028702048100028101038101038101037F01047C0103
7A01037A01027901027601017401017301017301027202067003086D0407700506760003
8A050998070C9C070D99060D95020A98030C9E07109F0B118E0C106E161BC5A5ACBEC1CC
B6C3D1C9D9E697A8B387959F7D81887C6C68309D1500FF0000FF0000FF00
00FF0000FF008D714DB1B2B2ACAEBB402E372D0A0D2601012200002902022601011F0100
2000002A02022D03022901002B00003701014703054D01035000035802065E0002660103
6C01057503067902067E01078101068703088B050A8B040A8A0307890306840102870203
8903048902038C03058E03069205089303079804079E0407A70409AF0608B00709AF0609
B1080BB2090CB50B0EB40B0EB113149C24215E201AA8958ED8D2CED6D6D5D3D6D5D4D7D6
D6D8D8DAD5D8D0BBBFA5757B7D3A3E5F2121340F0C2518145D5E58A6ABA3C2C6BED3D6CF
DBDCD9DADCDBDADDDCD8DEDDD5DBDBD7DCDCD9DDDED8D9DCDADBDDD8DADCD7D9DDD7D9DB
D6D9DAD4D9D8D6DADAD2D5D7D6D9DBD4D7D9C7BFC39163687E1C239411159B0C109D0B0F
9C0C0E9C0B0E9A080C9509088B0D0D873131B28D8DD5D0CFCFD3D3D0D2D3D1C9C8846160
6914148205078A02038A02038B03058802048300057F00047D00037E01047D01047C0103
7A01037A01037A01037901037702047400027501027400027402056F01046E0104740003
86040995070A99070A96030996030A96030C97040D9B0911930D1375141AB99097CFCED7
C1CBD7BBC8D4C4D2DF828F9A8589917D6F6B33A11800FF0000FF0000FF00
00FF0000FF009D7E5CB3AAAC6D5C663811163103042901022300002601012402011F0100
2101012901012E02022B01003000003F02044A02044F01035501065F0409640205680206
6F03087402077902097F020A7F0109810007830107850207850206860406830102850102
8701028902038C01048E01059102089202079603069D0407A60509AD0608B0070AAD0708
AE0708B1080BB40B0DB20E0FA31814A0484084645BCBC4BFD7D4D5D4D4D6D4D7D7D5D7D7
D8D5D7C4AEB292676C67313640161821100B40403790948AB6B8AFD0D0CBD9DAD5DBDDDA
DBDCDCD9DADCDADCDDD8DDDCD7DDDDD8DDDDDADDDED7D9DAD6DADDD2D8DCC2CACCC1C7C8
D2D6D7D7DCDCD5D9DAD4D7D9D4D6D9CECBCEAB8C91792D318A1419980E139D0C119F0B10
9C0A0E99080D99080D97090B910A0C801113985656C1ACA9D4D4D4D0D4D5D1D2D3918182
4C1011790C108704078802038601028701038402047E01017C00017C00037C00037A0103
7801027600007901027801037501017600027601027401027200046F01046F0104740104
8504099405099904089B060C96040B96040B98060D990710910A117511178F6367C5C1C7
CCD5DFC1CDDCA7B4C29EAAB671747C7E6D6B37A41C00FF0000FF0000FF00
00FF0000FF00A37F5C9276735122283E04073201032501012100012201001F01011D0101
2001012801012D02012F00013701013F01024801025302035B0205630206630105650104
6D02077201087802097A01087A01077C0106810309810309820206840305840101870103
8700048A01069104098E00068F01079101069602069D0306A8060BAE070BAE0608AF090B
AD0608B30A0DB60E0EAF12109E2B22BB8377B4A49DD4D2D1D5D5D7D4D5D7D4D7D8D3D4D6
B5AEAF71585A4C2B2C26111029262174796FAFB5AAC3C6BED7D8D2DADAD8D8D9D8D8DCDC
D7DBDCD8DCDDD7DCDDD8DDDED9DDDEDADCDFDBDBE0D6D7DBC0C8CC97A7AA627271ACB6B4
D1D4D3D7D8DBD4D8DBD4D7DAD0CECFAE9697844143821618900D119A0D119B090E9F0B11
9E0B119B0B1097080B98090C9107098A0B0E7F1F1FA77674D1C4C3D3D3D6D0D4D7AAA6A9
442022650E1083070B8803058903048802048100027D00017C00027C00027E02047D0103
7B0002790102790103780103750001730001760101740103730104730105720002740003
84020794040999050A99060D94030991030A94060D95080E910C12791718AF8386BBB7BD
B6C1CBCAD7E69BA9B78C9AA380838C8270703AA62100FF0000FF0000FF00
00FF0000FF009F714A6231285312134203032D01011F00001E00011E00001E01011D0101
2001012901012F01013502023B02023C00004700015402025E01046202056001045E0003
6401046B01067002077201057300047702057B01067F0206800306840307870407890405
8701048D03089002089203099102079202069703079C0205A7060AAC060AB0060AB2090D
B0070CAE060AB10B0CA61310AC4D43BA9589CBC3BED2D3D1D1D5D7D1D5D8D0D7DAADB4B7
50555522201C1D1A155457509DA19AB7BAB3D2D4D0D7D9D8D7D9D8D8DBDBD7DADBD9DCDE
D8DCDDD7DBDCD8DCDDD9DBDDDADCE0DDD7DCD6C7CDAEA1A85D60652435357D8C87C1C8C3
D7D9D9D6D9DCD3D7D9D3D2D2AB94958143438A2222911011960C0E99090D9C090F9D0A11
99080E98090D95080A9307099106098F080B870F11853434B69293D7D0D3D1D0D3C0C0C0
5947454608077408098503058902038401027F01017E01037C00017E01027F01047E0003
7F01047D0103790202760102750102750001770203740002730102740102740102760102
86030895050B97040A96040B92020B90040B90050A940A0E8F0F117F1E1E98686AD2CAD0
B9C2CBBFCBDAC1D0DE808E978B8E968472733CA82300FF0000FF0000FF00
00FF0000FF006C8426511205560A094201032900011E00001F01011F01011C01011C0201
2300012D01023502033702013701013D01024902045302035901025E01055D01055C0003
6000056300056801056D00057001057502077A01057D0205810508800206820204840304
8902068D01079103089303079202089202089603099B0307A7090BAD080CB1080CB0070B
AF070CAD070BAC0B0A98100AB46459B49990D7D2CED5D6D4D2D5D7D1D6D9B6C1C2566767
0C1D1A2E39307C8378ABADA5CDCDC8D8D8D6D9DADCD7DBDED7DBDDD8DCDDD6DAD9D8DCDB
D7DCDBD7DCDCDCDCDDDFD9DADBC9CCC9A5AB90676D4F36391E1F1D74807BBDC5BED6D9D6
D7DADBD5D9DBD3D0D0B89D9F874646831C1C901113980D119A090D99060A9E080D9F090F
9B080E97060A96070A94070A92070A8F070A8C090D7C0F118E4C4CC1AAAAD2D0D1CDCFCF
7C77742D0704630B0B7E03048701048301028001027E01027C00027E02037D01027F0102
8202047F02057500016F0101720102760103770103720102710002730003740104760004
81010690030B97040C95020B94050C91040A92060B930B1092161ABC5B5F713A40D2C4CC
CAD2DDBAC7D6AFBDCC9FACB86D717A7C6C6C3CAA2400FF0000FF0000FF00
00FF0000FF0057690D4B07005205054101022900011D00011C01011D01011A00011B0001
2400013001023502023401023401013D00014801045003065200035701055D01065E0105
6202066400076801086A02066E02067301047901047C00037F0105830307820103830103
8801028B01048D00058F01069102088F02088F040A940509A2060AAC080AB0090BB1080B
B0080BAE080AAB0C0A95140CB76F64B9A39AD8D6D2D3D4D4D1D4D5CED3D47C898823322C
58645A969C90BEC0B6D3D3CED7D7D6D6D8D9D5D9DAD7DADCD7DADCD6DADCD8DCDDD5DAD9
D7DBDAD9D7DADCCBCFD0A9AEAB6E758141474A1D212F1F1C83867FBAC2BBD4D9D5D8DBDB
D6D9DCD8D2D4C2A1A39E50539724259713139B11129D0D129E0B109C090CA30B10A1080D
A00A0F9C080D9B0A0F99090E93040A8D02078B040886090A771615996664CDBFBFD0D0CF
A9A8A6321E1D4908097407098101038401048501068201058101057F01037E01037E0104
8101058002067702036E0001700203770205780206740103720004720005730107740007
7E010990040C98040D96030B94040A93040A92050B92070D8C0B11871D2474363BD9C9D0
B7BFCBCBD9E69FAEBB919EA97C80887B6E6D3DAC2700FF0000FF0000FF00
00FF0000FF0075320D4B03004B02033C00012A00011F01011C00022001021D00011C0000
2400012E02022F01012C01013201003F02024702044801054600024D01035900075E0107
6101066502076802076901056B01047101027801057E0105820106860207870206880202
8C06058801048B01059105098F02098701067B00027E01049A080CAB0A0BAD0707B20B0B
B20A0AB30B0BAD0C0A95110BB76D64BBA39DD7D4D2D5D6D7D3D4D7BFC4C279827B868D83
ADB0A6CDCEC6D6D8D3D6D7D6D5D7D6D5D6D7D6D8DAD6DADCD6DADDD6DADDD7DBDED8DBDC
D6CDCFD0AEB2B7787D99474B762A2E4312123B29268C8B85BFC1BBD6D8D4DADBDADADADB
D6CDCFC69FA1A64E51A92327B0181BA10D0F9D0D109B0B109C0B0F9C0A0DA00A0F9F080D
9F090E9B060C99060D97040B96050C90030990060B8D070A820B0A782020A97E7ED5C9C9
C8C6C7615857280202640D107B0507810205840205840204820103810103810205830307
8002067E00047D0104760103730103770003760103740004750106760106770107740005
7D010690050C97030C99030C95030B93040A8F030892070D8E060D810B10732A2CD1BBC0
AEB4BFC5D2DDBCCAD5838E9986899281747454782D00FF0000FF0000FF00
00FF0000FF006C28084A03004902043A0101280100210001200001220102220201200101
2300012D01022D01022900003302013E02024101023F00004200014D01055501065B0107
5E02076301086400046901046C01057001047802067E0107800105840106890307880202
8A04038701018A01038F02059103088C03088504097E000298080BAA0B0CAF0B09AF0909
B0070AB1080BAF0A0BA1120DAA4E46B99590D8D3D1D3D5D7CFD4D6C3C7C5A4A6A0C1C3BD
D2D4CED2D6D1D3D8D6D3D7D8D4D7D8D6D7D8D5D8DBD6DADDD7DBDED5D7DAD8D3D7D4BDC2
C08990A54C54923238681B1D310A06473C359D9C96C9C9C5D8DAD6D8D9D8DBD8DBD8C7CA
C39295A84749AE2223B81517B51214A60D109D0B0F9E0D129C0A0E9C080CA10A10A1080E
9F080DA0090F9B060E98050E98070F95060B94080B8E04078A0506850E11873438BF9799
DACFCE98959326131345070972090E7F0307820205830204840203840204840106840307
8003067D01047D01057C02067A0105790104760104750105770107790107790108770006
7F01068F050B95030B96030B94030A9002088F040990050B8D030A850A0E6A181ABDA1A4
C6CBD2B5C1CCBCC9D5A1ACB76F737C8072736D463500FF0000FF0000FF00
00FF0000FF005E23043C01004403033700002901002201012001011E0000200101200102
2401012901022901032500003402024302024501024701024C0203520305540105560003
5A00045F01066400056A02056C01037203047802057C01047E0004830105860104870102
8701018901028E030690010793020896030996060B9304099C070AA7090BAC0809B00B0C
B1090CB0070AB00909AB0F0C99251FAE7871C5BBB8D1D6D6CDD4D4D0D5D4D0D3D1D2D4D2
D4D8D5D4D8D7D3D8D8D5DADBD4D8D9D5D7D8D6D8D9D8D9DCDAD6DAD5C2C7C898A0A7535B
9A2B308D23265912132B0F0A5F5950A5A79CD0D2CBDADCD9D9DAD9DED8DBDCC1C6BF7E83
A7373CB41F21BD1515BD1114B51013A80D0F9F0A0F9D0B109E0C119F0A109F070DA1080D
A1080BA0070C9E070E9F090F97050C95050C93070B90040892070C8F090D840F138E4043
CBAAAACDC3C358494832030461060A7A04078203078403068302038202038505068B0B0D
7F02057B0103790004790005790105770002760103740105740004770004780004780005
80010593070C99070C9604099103098D03088C03098D040A8D050985070C670F13A8878A
C0C3C9CCD6E0AAB6C29BA7B282868F796B6C6A443200FF0000FF0000FF00
00FF0000FF00622F073802004003023802002A01012301012001011E00001C00001E0100
2100012902012601012500003A02034D0204520203530203530304500002520003560103
5A01035F01056500046A01056C00027102027601027B01047E0104830204870205850103
8801038A01038F020595030995020A9502089A050B9A03089F0609A6080AAC0A0CAD090A
AF090AB00909B00A09AE0F0D9A1C17A7645DA79790C3C3C0D3D4D5D0D4D5D2D6D7D2D6D7
D3D7D7D6D9D9D4D8DAD4D9DCD4D8DAD6D7D9D9D6D9DBCDD0CCA5A9B86A70AC363DB12428
A421215B0A08361B15828077BEBFB6D4D5CED9DBD6DBDCDADDD4D5D5B1B6BD6D72AC2D31
BB1B1EC01416C01113BE1114B61013A80D0FA20E119F0C119B090D9F0B109F090FA0090D
9F080D9C060A9F090E9B070C98060C96090C94090C92060B94060C94060C8F070D811116
8E4A4EDBBCBFA38D8E4B1A1B5C03057B05098203078002057F01047F0103840304850304
8102047D01037A0103790205770103740001760203750103740003770205770003790103
82010693060C9803099704099100088C02098A020A8A020989010884050B670C10A27D7F
9D9EA4CAD4DEBBC7D47E8B978C909A7C707169433200FF0000FF0000FF00
00FF0000FF006735093704003C02023602022800002001001F01012001011F01011D0100
2100002A02032901012C00014101034F01045201035001024D01034C01024F0002540103
5B02056001036601036C01066E01067201047500027A00027D0002810101850102880103
8901018D02049204079705099402089401099702089A02079E0407A50809AB090AAE0A0B
AD0909AF0A09AE0808AC0F0D991E18BE7F76B09F98D0CECAD6D7D8D2D5D6D3D7D7D7D9DA
D8D9DBD8D8DCD8D9DDD7DADDD8D8DCDAD0D6D3B3BABE7C83AA4147B1262BBC2020B32421
A8453E683C35A29D92C3C5BED8D9D5DADBD9DDDADADDCCCECD9CA1AE4E55B4292FC11A1D
C71518C41215BF1113BC1114B31014A40D119C0E119A0F10960C0F960C11960C11950B10
970C1195090C960A0D96080C96090C920709950A0C95090B96070C98070C96070C8D090F
7C141AA06064DBB5B6744342600A0A7804077F02067E01047D01037E0104810206800104
8001057E01067B02057901037701037300017300017701037700037901057A01067C0106
82010692040D9A040D99040D92020A8D020A8902098A01088A020984070C660A0DA1787A
B0ADB2B5BFC7C5D0DDA5B0BD6D71798274756D473700FF0000FF0000FF00
00FF0000FF005E2B033302003702023301022500011B00001B01001F01012002021C0101
1E00012700002F01013701034301044C01064F02054901014902024901024E0202510001
5800026201036701056D01076D02056E00027501037C01047D00028201018501018C0304
8D02049003069405089706079503089503099803099C0508A00709A70909AE0C0CAE0A0B
AB0708AE0A0BAD0909AB100E961F1ABC827BC0B2ADD7D4D4D5D5D7D1D5D6D0D6D6D4D9DA
D7D9DCD7D8DAD8D9DBDBD5DAD3BEC4BE8991AA4E55AB292DB91D1FC21A1BB81C1AC75953
DBA79FC1B4ACCFD0C9D8DAD7DADBDADED5D9D9BAC0C48188AD3D44B82328C2171CC71519
C31315BF1415B81516AD1516A2181A8B14187A13176F1317650F136010145B0C0F610F11
6911137211137B12158713178C0F138D0B0F8F090C91050A98080C9A070B9A080E92050C
8B080F7E161CA86365B87E7E6412117A080A8003067F03057E01038102058002057B0103
7901027A01057A01047901037701037401017401017801037901037B01057D01087D0109
8001068F030A98040B97030A93030B8E01098B01088D02078C03078304096D0A0E815153
BAB3B7C6CFD8ABB7C49FAAB66B6F76786E6D69483800FF0000FF0000FF00
00FF0000FF00622A063403003401022D01012200011C02011901011D01011E00001E0000
2101002B00013801043E01044000024902064A01044801034602034600024F0103560101
5901015E00026201026802046B01046F01027901048102068301058502038702038A0105
8E01078E00069202079705089704079705089604079B0608A10709A90A0BAD0A0BAE0A0B
AD090AAF0B0CAC0809AA0F0E951F1BBD847EBFB1AFD8D6D9D5D5DAD4D7DAD3D7DAD6D8DC
D8D8DCDAD6DAD9C8CCC7A0A6B1676DA63339B52023BD1717C31515C31516B21C1BCD7670
CCB2ABD5D5CEDBDCD9DBDAD9DDCFD2D4A6ADBA616AB32E36BC1C22C0161AC01618BC1719
AF1817A01A1C8A191C6D13154F0B0D3605092303051C0406130304120406120404130302
1903022002032901043C060A4E090E6812167A0E1288090E970B129C0A1097050B97090F
94080E8D0B127B1115A85454872C2B7A08098105078103067F01048102058002057A0002
7601017700027701027601027500027300017300017400037700057B01067C02087A0108
7E01058D04099A060C9802099401098F01078C01068F030A8D030A830308730A0E7E4649
ACA1A6C1C8D2BDC9D77985918389917B747565493B00FF0000FF0000FF00
00FF0000FF00682D063703003201022A01011F01001A00001901011A00011D01011F0000
2801013502033E02044001054100034601024601024501024701024B0102500102560101
5B02035E02045F00036601046C01057201057B0006820207860207880204870203870205
8C020991010A9302099706099806089705089806079905069F0708AA0A0BAE0B0CAE090B
AF090BB40E10AF0A0BAE1212951F1DBE8683C2B4B4D8D7DAD6D7DAD3D6D8D6D7DBD8D5DA
DED2D8D4B5BCBB7C84A74246AC2428BA1A1CC21616C71515C61414C51515B01B1BCD7976
C7AFAADDDAD7DFD7D7DDC1C5C7878EAF4249B62329C0191FC0181CB3191C9F1A1D801618
5B0B0D3E06082706061808060C08070B0F0D1219171F28252C34323137363439352F322D
2328221318120A0B080906060E05051C0303370608641015820F14940C1096090C8E0507
92070B8F050988060B821113AA3A3C7E07098203078202057F01048001057F01047A0103
750101750001740001730201720101740203730103730003740003760005760006760106
7B00058D060B9805099B030996030A9002088B01068C040987020880010871080D7A3F42
B5A7ABA4ABB3C3D0DB9CA7B36E737D7A75785E493E00FF0000FF0000FF00
00FF0000FF00652D053603003202022801012002011E02011C01011C0001200102240100
2D01013D03044001034202024101014602014601014601014A01024F0102520102550003
5600015C01046101056701056C01057401077C0107800007820006850104880304880104
8E010992010B93010B95030B9A070B9906099904089F080DA3080CA90A0CAE090CB10A0C
B30A0DB30A0DB10A0DAD1011982521BE8884BFB3B1D7D7D8D6D7DAD4D7DAD6D5D9D7C6CD
C2979FA6545BA72C30B61E20BD1715C31615C71616CA1616C71314C71617B01D1DC97676
D3B6B6E4CFD2D8ABB0B66268AF3137B82124BA1B1FAD1B1F8D1719650E103C0607220506
11050611100F262C26454E466A746B838E85838D85919992A1A6A19FA49FA5AAA3A2A59E
8E928981857B7C827761695F383E371216100905031D0102480A0D761216890C0F8E080B
91060B92060B91070E8A050B8C0A108604098402068202058405087F01057D0103790103
7300017502027301016F01006E0102720104720003730003730102720102740205780208
7D00058E050B9A060B9C050A9503098E02098B01088B030985010780010974080F6E3133
B4A6A7A1ABAFADBAC39FAAB4787C847B747855443F00FF0000FF0000FF00
00FF0000FF00622A053602003101022401011A01001A01011B02021C01001F0000240100
2D01003D02034402044300024301024201014201014400014B01024F0101530203560104
5500015D01016301036801046E00047601037D01048001068101058302058A04088B0106
8D010692020A93010B96030C9904099E080C9D060BA0060DA3060BAB080DB00A0DB10A0C
B30A0DB2090CB40B0EAC1011982723BF8B86C2B8B4D6D7D8D8D8DCDBD3D7CFB4BCA3717A
853640901E22B51E1EC01716C01312C21314C61515C91616C71314C61516B31B1CD57677
DFA7A9CC888CAC4249AF262BB11D20A21D1F7B14164F080A2B03051608051A1A163A3F3C
656C699197939AA09AAEB2ACB5B9B2BEC4BDC3C7C0C9CBC5CDD0CDCACFCCCFD4D0D0D3CF
C9CBC6C2C4BDBABFB6B0B6ACA5A8A1898D865258511819151001023203066C1215840A0E
8E080D90080C8F04098C04098903088602058101027F01037E01048004077D0104780102
7501017301017301017202006E0100710102700002710102710101720202720104760106
7B00058C050B99050B9A040A94020A8D01088D040A8A02078400067F010674060B642125
9E8C8FA7ADB1B3BFC778858E898F977A767955464200FF0000FF0000FF00
00FF0000FF006429043701003201022400011900001601001701001C0101200102210101
2800013801034702054400014401024200014101024401024701014C0102520002580103
5B01016403036601016B00027201047802047E02058103068B0C0F7F02048503068A0105
8C000590000794030A98050A9A05099B06089F050AA2070DA4070CAD0B0DAF090BB00A0C
B00A0CB10A0CB70E12AF11149A2525C5908DC7BABADAD6D8D9C9CEB690988C5159682730
4B0A116F1417AB2122BF1716C41414C61415C61315C61414C51312C81517BC1A1BDB595C
CF5F62AA2F33AD2429A01E22761214430707200404150E0C31353169736B97A299ABB2AC
B5BAB8C2C6C4CFD1CED7D9D7D8DAD8D8DAD8D5D8D6D2D5D6D1D5D6CED2D3D3D7D7D2D6D5
D1D6D2D0D5D0CFD6D0D1D8D4D2D5D4C2C3C0A3A6A07F847E464845110706320507681014
81090E8A05088C04078B04078803078503068000047E00037F01047E01047C0204780102
760102750102730101720101720201720102730103720003710101720202720003760005
7C01078C060C96050B96030A93030B8C00088801078602078202067D0106780B11783237
AC95998F9197A8B2BAA5AFBA6168707B7A7C54464200FF0000FF0000FF00
00FF0000FF006328033702003403022501011900001801011601011A0000200102240101
2800003901034A02064A02044501024400014301014401024500024800035300035C0103
6402046902046901026C00037100047401047400027B030593151B8004077D0102870105
8F020891010895030997040A9A070B9C05089F0508A2070BA4070BAA090BB10D0EB10C0E
B20D0DAF0A0BB30D0FAD0F129A2425CA908FCAB4B4CEB2B79F6D74793B434F1A202A090C
442D2DBA8686A83837BB1A1BC51416C61314C61316C51214C61414C41213C5161ABF1E23
AF1F239B1D217513174407082107051E19164B4F4C909691ACB3ACB6BFB7C4CCC5CFD4D2
D7D9DBD7D9DBD7D8D9D6D8DAD4D8DAD5D9DBD3D7DAD1D5D9CFD2D6D1D4D8D2D6DAD0D5D6
D1D7D6D2D8D6CFD6D4CFD7D7D1D6D9D0D2D5D1D3D3C2C4C39498965A5D5918100D330506
6F111484080B8906088904078401068402078001057F01037E01027D0103790102750001
740001740102740101740202700203700103730203750204730103720002740003770205
7C01058C060B95050B9401099202088D010A8902098301068101067D010674080E863E45
B1979C94969C869098ABB5BE676E757B7A7C56484400FF0000FF0000FF00
00FF0000FF006326033A02003502022501001A00001901011801001A01011F0101270201
2E00013D01034C02064901044501024502034501024801034901024900015102045B0204
6302056901056B01056D02057101047202056D01027203057F080B740304740102860306
8E010793020A96030A9A050C9B050B9F070BA1090BA1080BA2080AAA0B0FAF0C0FB00B0D
B10B0DB30B0EB40C10B011139F2324D78C8EB781868B4F5760262C330E1024151465625E
B5ADAAD3B0AEA04141B51C1DC21315C51417C51216C51216C41215C21417BC1619AB191D
86191D4A080B220506251F1D555B549BA29BB5BAB4C4C7C3D3D6D3D5DBD8D6DCD9D6DBDC
D6DADDD5D9DBD6D9DDD6DADDD6DADDD2D6DAD2D6DBCCD3D7CDD2D6CFD3D7D1D7D9CFD7D9
D0D5D8D3D6D8D4D6D8D1D5D7D0D4D7D0D4D7CDD1D4CDD1D5CBD0D1AAAFAC6769641D0D0B
46070A770C1085080A8503078201078101068001057E01037B0102790102780102740000
7200007301017401037001036101015B0202660204700103720002730004740006770107
7B000489030895040A97020C93020B8E010A89010983000681000582030878060B64181C
A98D8F999AA08B949B7A838A858C917C7C7C594B4500FF0000FF0000FF00
00FF0000FF006224033D01003801012A01011E01001C01021B00021900011C0000240100
2F00014202054E03074801024100014301024601024A02024B02034700014B0103510001
5B01026902066C02056B01037001057202076601026002026405065E01026E0102850206
9002089301079603099B050C9B050A98040895050898060A9D080AA6080CB00C10B10B0F
B20C0EB40C10B60C11B30E12AA1B1DC8575B88313654171B25090A3D38348E8F89C1C1BD
DCD7D5D5B7B69F4645B31F1FC41618C31316C31316C31216C11719B51A1D93161B5B090D
2B03032014135C5B599FA19DB7BBB5CACDC7D8DAD6DBDCDBD8DAD9D8DCDDD5DADCD5DADD
D4D9DCD4D9DCD5DADDD5DADDD5D8DBD4D8DCD4D8DCCFD5D8CED4D8D0D4D8D1D4D8D2D6D9
D2D8D9D4D8DAD4D7DBD1D5D8CFD5D8CCD3D5CED3D6CDD1D4C9D1D3CCD2D0B1B4AF5E5956
270505630F117E080C80030880020A7E01087D01057B0003780002770002760002740001
7501027601057702057303056202025302015600016B0407720305720104720106740108
7B00068903099202099101088F010A8E010D8901098401088200078201087B050A5C0A0A
916F6F8484888F999E788388656D707F807F5C4D4800FF0000FF0000FF00
00FF0000FF006224024103003D02012D02012000001F02011E01012003031E0101230201
2C01013C01024C04074902044201024001024302034901034B01024B00024E0103500003
5C01056601046A01046800016C00027303066703045905056E1C1C5F01027A04078B0409
8F010692010696040997040898050A9303078D00049104089D0A0CA5090DB00D11B00B0F
B30C10B40C12B60D14B71015AF13179F1D1E721D1C2F0F0B635F59A8AAA4D0D1CDD7D7D7
DBD8D8D0B7B49D4946AF1D1DC31518C41318C01216BC161BA71B1E7310143703041C0B08
43443F9FA39FB9BBB8CECFCCD9DBD7DEE0DDDEE0DEDCDDDED9DADBD8DCDED6DADDD6DBDE
D3DBDDD1D9DBD4DCDED3D8DCD4D8DAD4D8DAD5D9DCD2D6D8D1D6D9D0D4D8D1D4D8D2D5D8
D5D9DBD4D8DAD1D8D9CFD6D6CFD5D5CFD7D6CED4D4CED4D5CAD0D3CBD1D3CDD1D1A7A9A7
473737470B0C760B0E8103088002087E01077B00047B00037A0103780002780103780102
780102770003770004750104710303660405570000640204720206740105720007750107
7B000589020895040B9501079302098F020B8A010987020882000683020A7A040A5E0C0D
997878858487737D81808A8E60686A828383594A4500FF0000FF0000FF00
00FF0000FF006121044302003E02012B01011D00001D01002001001F01001D0100220101
2600013000024103064201023D01023600013900014702034A00014F0202530304580104
6002066501046701026800016C000275030576080A8828289F403F7A0C0C8705098A0004
8E010592020793020793010695020898060A96060A97060A9C090CA3080CAD0D11AE0B0F
AD090CAF090FB10A10B30F13A7191AAE4C4894645D897E76B8B8B2D4D4D2D8D9DAD7D8DA
D8D8DAD1BAB8994643AD1C1BBF1216BF1518B11A1B8C1519500608230504342F2B878C85
969D98C8CCC9DDDEDDDBDDDDDADEDEDCE0E1DEE1E3DEDFE2DADBDEDADEE0D6DBDED4D9DC
D4D9DCD5D9DCD7DCDFD3DBDDD3DADBD5DADBD6DADCD1D5D7D2D6D9D1D5D8D3D7DAD5D8DB
D4D6DAD2D6D9D2D6D9D1D5D8D1D6D8D0D6D5D0D5D5D0D4D6CCD0D3CCD0D3CACFD0C9CECF
8F8A8A3C12116E10107D04078003078204087E01057C01047B01047800037901047C0205
7A01037901027701017501027300036E0306600001650104720106760006750006760006
7C010488030796050B9701079500089001088A0208890306840105810006780307610E10
A380828F8D8F7A80855C6268787A7F8A87895A4B4600FF0000FF0000FF00
00FF0000FF00621F044504003E03022C01001F01011E01012101012102011C01001D0100
2100002C00003701023900013903023100013700024902055002034D00015001025B0307
6001056301036601026902036C01027301037402048414158614148206088801058E0107
9001079101089302089303089402089905099A050998060A98070C9D0B0EA50C0FAB0B10
B10D11B00A0EB30D11B111159C2022C88A85B4A49DCACAC6D6D8D8D8DADBD7D8DCD7DBDE
D8D8D9CEB8B6994642B1211EBA1819A61B1E6F1110340502241713656662A9AFAABEC3C0
CFD4D2DBDEDDDDDFDFDEE0E3DDE2E5DBE0E3DDE1E4DDE1E4D9DDE0D9DDE0D7DBDED5DADD
D5D9DDD6D9DDD4D9DCD5DADDD5DADDD5D9DDD3D8DBD0D5D8D0D5D8D2D7DAD1D6D9D4D7DB
D3D6DAD0D6D9D0D7DACDD5D7CFD4D7D1D6D9CED5D5CDD4D5CACFD2CBD0D3CCD0D2CBCFD0
C2C2C07659546413127905078103078002067E00047D00047D00047C01037A01037A0105
7A01047801037801037601037502067001046C00046F01077802097B0209770106740003
7A000387020692020893000695040A8F03088901068702078702078502077902075F060A
8B6166867C818E8F945D60665F60658C898B56474200FF0000FF0000FF00
00FF0000FF00611D014502013D01022E01012101011D01001F01011F01021A00011B0001
2100002E02023702033901013602022E00003501024602055303055401025300015B0106
5E00046100026601026B01036F01037400057901047C02057F01048601068B03088E0205
91020693020794030794020895030A9A050C9C060A9D080C9506098A0001920406A60D0F
AD0B0DB30E10B30B10B11116982224C5918EC3BCB8D5D9D9D5D9DCD5DADDD6DADDD8DADE
D9D9DBD1BBBB9D4D4CA42322941A1B590C0C2509033E3D33959B92B5BAB6CED3D1D7DCDB
D9DDDFDADDDFE0E2E2DFE2E2DCE0E3DADFE3D9DDE1DCDFE2D9DCDED6DADCD6DADDD4D9DB
D3D9DCD3D9DCD2D7DAD5DADDD5D9DCD4D7DAD4D9DCCFD6D8CDD5D7CED6D8D3D9DCD5D7DC
D2D5DAD1D7D9CED7D8CBD4D6CBD3D5D4D9DCCFD5D8C9D1D3C9D1D4C9CFD2CACFD2CACFD1
CED0CF9F8C886823227D0C108102088001057E00047D00057F01067F01057A0004760105
7200047501047800057700067501067501057802087801077B01087D01097A0108780106
7A010388040993040A9401079101078F03098901088701088600078602087B0207620509
8B5B6084797F6F71767C7F84515257908E9053443F00FF0000FF0000FF00
00FF0000FF005F19004902024302023501022700012100012001011E01021A01021B0101
2200002D01023602023900013802023101013101013D01015000025B03075C01075F0207
6201056502046800036E02047101037702057B02067D01048001048701068901068C0104
9104079203069403079402089602089D080E9B06099C07099D080A99080A930304A70D10
AF0C0EB50D11B60D11B01113982423BF8C8AC2B9B6D5D8D8D3D7DAD5D8DCD4D8DCD9DBDF
DBDBDECCBBBD864C4E7020203F0706281611696C64B5BCB3C4C9C2D7D8D8D8DCDED6DBDD
D8DDE0D9DCDFE1E2E5DFE0E3DDE2E5DADFE2DADFE1DCDDDFDBDEDFD8DCDDD8DDDDD4DDDC
D2DADBD1D9DCD3D9DCD4D8DBD4D7DAD5D7DBD7D8DCD2D5D9D0D4D7CFD1D4D0CDD3D0CBD4
CFCCD2D3D2D7D1D5D8CFD4D5CED2D6D1D3D8D0D5D6CAD2D3C9D0D2CCD1D4C8CED1C9D0D2
C9CECFBCB2B2723C3D760F138004097F02067D00047D01057D00057D0105790105710103
6700016D01037702087801077701057A02077A01087901057900057B01077D02097A0305
79000288030994040A9402099203098E02098901088400078402088303077B030764050A
8C5C619D939862656A64696E494E528D8F914F413C00FF0000FF0000FF00
00FF0000FF005B12004B02014601013901012E00012901012401001E00011900001B0101
2101012A01013301013700013902032F01012B00003502014904065603085C03085F0206
6001036401026A02036E01046F01027401047601047901027E01038701058901048B0105
8D020690030793030898060C9803089803079803069B06089F090AA0080AA60B0EAC0B0E
B30D10B40B0FB40D10AD1112972622BF8C87C4BAB7D7D8D9D6D7DBD8D8DCD9D9DCDBD9DE
D5D0D6AEA4A84634341F0E0B322E27939890B3B8B2D1D5D1D9DCDCD9DBDEDCDEE1D9DDDF
DADFE2DDE0E3E3E4E8DDE0E3DDE2E3DBE3E2D7DCDCDCE0E0DBDFE0D8DCDED7DCDED7DCDD
D5DADBD4D7DCD7D8DED4D1D7CFC6CCC8BAC0C0A9B1B2949CAB858EA57B84A06F7A9F6C79
9A6974A87E89B0939CC0B2B8D0CDD0D4D6D9D0D4D7CBD3D6C8D0D2CAD1D3CBD1D4CAD1D3
C9CFD0C8C2C4845B5D6B10147F060B7E01077E02077F01077F01077C0104790103750205
6B01036A00027401047802057501047701067901067900057900057B02087A01077B0207
7D01058B030A98050D9300069202088D0208880107840006830107800206790106640408
84525489808284898C55595D3F43478C8D90483A3400FF0000FF0000FF00
00FF0000FF005B12004E02014902023D00013401012D01012901012201011B00011B0101
2201012E01013802013C01023802032800001F01002300003202044201045301055D0105
6001016601016C02037002036F00017102017301017801027D02038301028700028B0205
8C01058F040791040797050B9703089903089B04099E060AA0070AA2070AA9090CAF0B0C
B10B0DB40D11B10A0DAF1415992723C6948EC3BCB7D8DADAD6D7DBD9D7DCDDD4D9C7B5BC
89757C3931351218154F5951A2AAA2C0C5C1D6D8D7DCDFE0D9DDE0DADEE1DCE0E2DCE0E2
DDDFE3E1E2E7E0E3E7DDE1E4DDE3E4DDE2E2DBDFE0DBDFDFDBDFE0D8DADFDBDBDEDEDADD
DBCED4D1BAC3C49CA9B27D889B5C668A434B83353D7F2B357A243078232E7A212C7A1925
821926821C2780252E843E45A1757AC7B6B9D1D0D4CCD1D5C9D1D4C9D1D3C8D0D2CAD1D3
CBCFD1CFCBCE9774786813187F080E8101088101088200088100057F02047C00027B0103
7902047702057901057901057700047701057A02067A01067A01067C01087F040A7E0308
8201078F030B97030A9401079101068E03098801078400058101057E0105770106630508
8451527D7474727879707377393A3F8F8E913F312D1F8D0800FF0000FF00
00FF0000FF005A12005208064B02024201013800003101002D02022501011D00001B0100
2000002F01023D02023F020239030430060861353A340A0C2500003200034F03075D0104
6201026900026E01047001027201037301037401047800027E01038301038601038A0104
8C010591050895050A9301079603089A05099C070A9C0608A0090BA4080CAE0C10AF0A0E
B00A0FB20A0FB50D11AF1416982825C0908BC1BBB8D6D8D9DAD6DBD4C7CCB1939A734D55
361F221D1C1A6C7570ABB4AFCBD0CDDCDDDFDFE2E5DADEE1DADFE2DDE1E4DFE3E6DFE0E4
DFDFE4DEE0E4DCE0E3DADEE0E0E4E5E0E5E5E0E3E5DDDFE3E1DFE3DED2D9DCBFC7D29FA8
B9717DA44A579B313D94262F892128791E2368171D58131B4A10193A070D3F04085D050A
840E15910D12910E128D141A801B21904F53B99FA3D0D0D4CAD1D4C9D1D3C9D1D3CBD2D4
CBD0D3CFCFD29D8184681B1D7F0A108102098202098301078301068002067E01057E0106
7F01088103097F01067C00047900047700047800027A01047D01077F010880040A80040A
82020891060D97050B94020692020890030A8B02088501048001037D0004770203630405
834F4F9C90915F6365676A6D3E3F438A888B392A261D8C0600FF0000FF00
00FF0057B51754130075342F4904024904033E01023202012A02012201011A0000190101
1E00002E01023C02033D02053302044513175011164505073503042D00014803075A0206
6301046801046D02056E01046F00027201037601027A01027F0104840003870103890003
8D02078F02089403099705089705089A070A9B05089F0709A0060AA6080EAB080EB20A11
B40B11B60D12B40C11AE1314952626C49694C4BABADED3D6D3B6BCA16F776C383F321316
2B28248C958EBEC7C3D4D9D8DFE3E4E1E5E7DEE2E5DADEE1D7DCDFDDE2E5E2E3E7E0DFE5
DDDDE2DBDFE2DCE0E3DBDEE1E0E2E6E2E3E7E7E1E6E4D1D9DBB4BEC5828EAE4E59A8313C
A4242D9C2229861B2162101242080A2902041B030513060A0C080D0E06082A0B0B5C1817
801C1C8A1514911213920B0F900D12861A1E95595CBBACAECACFD2CAD2D4C9D2D4CAD3D4
C9D1D3CDD0D29D8587681D207D090E8205088203058402058001047F0204800206810107
8201088000087D01067C01067B02087A01067800037B01057E020880010881060B790107
7D03078A070B94060A95030793010792020A8E02098802088301057B0104730105620307
7944469385877F81845355582E2E2F878384382521208E0700FF0000FF00
00FF0055B31561250A7D433C4305034603033A01012D00002700012101011A0001190101
2000012E01013A02023903042A00013001024703044C03053B04042600003A0104560207
6201046601046800026901026C01027202017601027B01037F02028401028700028A0102
8C01058E01079302089705089705089502059B0608A00609A2070BAA0B10AD090FB20A0F
B2090EB50B0FB60C0FAE0E12992728CD9697CEB0B5C5959C9B525A712C32360F124A423F
B0B5B0D0D5D2DFE3E3E0E4E5DDE2E3DBE1E3DEE3E6DADFE2D8DDE0DBDFE3E0E3E6DFDFE3
DCDDE2D9DDE0DDDFE2E2E0E4E4DCE1E4CCD3DAA8B3C4727FAF3F4CAC2933A920299A1E24
7512184706082701021404020C0A07121814262E293A443F4C5552565A556C5E57835E56
9F6761B56764A035358B0A0D90090D8B0E137E292CA58687C7C7C7CDD3D4CAD3D5C9D3D4
CAD3D4CDD0D294797C691B1F800B0F82040686070785040483030685060A820307810207
8002087D01077D02077A01067901057800047900057A01057D02067D01057B04096E0205
6E00037F030792080C97050A95020895040A8E02088801078200077C0007740107610408
7642437C6D6E7D7D816F70752F2C2F807779331C18208C0700FF0000FF00
00FF0052B110682D0D5F27213E02014203033A02013001022C01032702032001011E0000
2501013101023B02023702032600012D01014302034702033302031C0000310204530206
5F01036301036401026500016900006E00017301017801037D0102810100860201890102
8C040690060893020798040A95020896040A9804079E080A9E0608A5060AAD090DB30C10
B40A0EB80D0FB80B0DB41113A62526E99394CE80859B3E46752125380B0A59514EC0C2BF
D7D8D8E3E4E6E3E5E7E0E4E6DCE1E4D9DEE1DEE3E6DADFE2D9DEE1DCE0E3E0E1E5DBDCDF
DADCDEDCDDE0DFD8DEE1C9D2DCA9B4C36976B63846BB2632B61D28A01C246B0C113C0307
1E0305110C0C242C27545F567B877F96A29AA5AEA7B1BAB3BCC3BDC2C8C3C7C9C4D1C7C2
BB9897964D4F86181C8E0A0F92090E8E0B107A18199A6F6EB2AFADCCD3D4CAD3D5C9D3D4
C9D2D4CECED08563666B151880080B8403068403048705078604098302078002067E0206
7D01077E01097C01087901067802057702047901057C02067D02067E0307770508630000
720607921216A2171C95040B99030B9702098E00068902078401077F0207750004610306
7D494A97888A63636666666B403B3E7E71722E150E218C0500FF0000FF00
00FF0051B10E753B1448120B3B00004204043801012F01012C0102280101230101240001
2900013403023B02013602032401012700014103044503042D02021500002D0103500307
5B01036002036102036301036700016C01017201027600027A01027E0101830102860102
8802038C030792030894020894020797040A9503079B080B9C0407A7090DAF0A0FB50B0F
BA0D0FBD0F10BF0F13C01215BB1E20D2494AA72D307B1D1F390A086B615CC2C6C2D9DDDC
E0E3E4E2E7E8E3E7E8E2E6E8DCE0E3DBDFE2DADFE2DBDFE2DADEE1DCDEE2DFE1E5DCDDE1
DCDADDDBCBD1D1A3ACBB6670B53843BE242DC51D23B81D228A11194703071D0403211D1B
5157538C9691A9B5AEBBC6BEC8D2CCD1D7D4D4D8D7D3D7D6D2D7D6D0D6D6CCCCD0AB9399
8D4C5285191F8F0B1194070C91050B8D090C7D18179C706EA29F9ECCD4D5CAD2D4CBD3D5
CCD2D5C1BCBE81555870111484080B8705098605088403068402078504098002067E0106
7F01087F02097E030A7D030B7802067600037A01067F02098001078203097C080C650000
820D0E990D10AD1C20A412199C050D9A040A9201078A01078501077E0106760106640508
7B45479E8F917071735454552F27278272712C120A208C0500FF0000FF00
00FF0053B3117A401B3F06023D00014404053901003001012B0002260000230101240101
2B01023201013B01033803052100011E00003A05073E0506230202140000340305520306
5900025900015A00016101036701026B01017101027401017801027C0103800102840003
8801058C010791020793010794020694020595040899060A9E070BA5080CAE0A0EB40B0E
BC0F10BF1012BE0E11C11013C31618B31B1C8318183808066D6661C4C9C5D7DDDBE0E5E5
E2E6E7E3E7E8E4E8E9E1E5E7DCE1E4D9DFE2DADEE0DBDFE1D9DDDFDFE0E3E1DFE4DCD1D7
D0ACB4B76F79AC3942BB222BC71B21C71A1EAF1C1E730E0E330101291C1C6B6D6BA8AEAB
C1C8C4CFD5D2D4DAD9D7DDDDD4DADBD4D9DAD4D8DBD2D7D9D1D6D9CCCACFAB949C7C3B45
84171F910B1293050D95050E93060D8F0A0F7D1C1D6D4745A3A4A1CED6D4CFD6D6CED6D7
CED4D7B5AAAD6C3538750F1283050986040A8302078304088100058304098002087E0309
7B02087403076D020674060B7A050B7C010680020884030B85020986040B7E090D640000
830C0EA11012A50E1295060B94040A9A050C96020A8C01088401067D0106760107670609
7B43448071728181826A696926201E7A6F6C281208228F0700FF0000FF00
00FF0057B6156325073E03004101004603043D01023001012C0102290101250100230000
2A00013402023801013804052102021500002704062602041300001400003C0306590507
5C02045600015800016001036701036C01027201027501037801027C0103800102830103
8701048D010791010896040B97040A96050995040898060B9D080CA2080BAB090EB20A0D
BB1011BB0E0FBA0B0FBE1013B918198815153A07056B6560BBC3BEDAE1DFDFE6E6DFE8E7
E2E7E7E4E8EAE3E8E9DEE3E5DCE0E3D7DDE0D8DEE1DADEE2DDDEE1E7E0E5E1C5CDC48891
AE4750B1252DBF191FC61418C7191DAA1B1E600809290A0854524BA1A7A1C8CDCBD6DADA
DBE0E0D8DEDED5DBDED3DBDDD3DADCD4D8DBD4D8DBD3D7D9CFCFD2A89096824149841920
900A1196070F94030D91030B91050B8B0D11621213462F2DAAB0ACC8D2D0CBD4D3CBD4D4
CBD0D39C88896923247F0D1187050A8402098203088103088001078002087F020A7E0109
7C01096E01045C00015C000171050A7E040A83010885020886030987050A7C0408660101
700406930F139C101287040586040792050B9403098D01068501047F01057801066A0709
7F45459180816E6E6E6A6A692F2B276F6562240E06218F0600FF0000FF00
00FF0055B4155515004101004201014502023C00013201012C0102290101270100240101
2600003102023601013502042302030C00000C01010D00000A00001C0001410104580103
5B01015500005400005D01016702026D01027301027601017A01037E0102800101850102
8901048D01078F030894050C95040A94040993040995080D98080EA0090EA70A0EAD090D
B80D10BB0D0FBA0E10B516198813143C05046C625EBDC3BFD8DEDCE0E4E5E2E6E9E1E5E8
E0E4E7E2E5E8E5E6EAE1E2E6DEE1E4DDE2E5DDE1E4E0E0E4E8D8DEE5B6BFBD656FB12E36
B91B21C1161AC31216C0161AA3191C570709321916848781BBC5BCD2DAD4D9DEDBDBDFE0
D9DEE1D5DDDFD4DCDED2D9DBD2D9DBD2D7DAD2D6DAD4D3D7B6A1A683444A861A1F930D12
95060E94030C95060C9104088F0A0C751012340505615C5ABBC4C1CAD1D1CCD1D3CFD2D3
B8B2B37D525472151981070D83020A82010B7F00097D01067F0208800309810208810108
8001087D030A76050A6602056601037E070D8402088A040B86010785020882050974080B
5B00016B070B7F0E127606087A03078D040A9303098E02068801068201067B01076A0407
804646AD9F9F787A7B5859582E2B27695D5B290F09218D0500FF0000FF00
00FF004FAD115010003E02013E01004303033C01013302022B0102250000230000240000
2700002E01013500013502022503030900000200001009081806063002054E0306590105
5901035400005400005D01016701016F01017501037801037A01037C0001800101850101
8901048D02078D02078F030A94050C95050C8F040B86010685010598080EA40A0EAB090E
B50D10BB1013B010158C12173F0303605351BBBFBDD7DCDADFE3E4DEE2E5DFE4E7E1E5E7
E2E6E7E1E4E5E2E3E6E3E4E8DFE1E5DEE0E3E3DDE2DEC0C8D58F9ABB4651C3282EC9191F
C81317C61417BB1214A4181A5A0708472E2A9D9F98CAD2CBD9DFDCDAE0DDD9DEDDDBDFE1
D9DDE0D6DCDFD5DBDED4D9DCD3D8DBD3D7DAD4D5D9C1B0B58B5158851B21930D1296090C
91050992060B91050A8E080C7D1013430607382A29919693CDD3D2C9CFD0CDD0D3CECACF
96797E681F237A0A0F82060C7E01097F020B7C010A7B01097C02077F0306800206830308
82020684020981020A76040A6900017A04078604098903088902088A030889060A800D10
5F0708550A0D5106095202036F05098D050B9505098E02078801078501078002076F0509
8345498A7B7B8587896C6B6C312A2A675959290F08218D0500FF0000FF00
00FF004BA90F4C0B003D01003C01003F02023901022E0101280102230102240101290101
2D01013301023600013802022A03020E0000322C2B96898A442326430509540106580205
5601025501015901015F02026701016F01017501037902037C01037C0001810202860202
8600018A01058C02068901068B010790010990030A88020889030897070DA50A0FAB090E
B00C0FB1141794171B470405645451B6B9B8D5D9D9DDE1E2DCE0E3DBE0E3DDE2E5DEE3E6
DEE3E5DFE4E3E1E5E5DEE2E4DDDCE1DCCFD7D0A1ACB95B65B92D36CE2229D51A1FCF1316
CC1318C41417AF1A1B670B0B583936ADADA8CFD6D2DAE0DED8DEDDD9DFDED9DFDFD8DEDF
D7DCDFD7DCDFD3D8DBD3D7DAD5D9DCD6DADCCEC8CB9D72778423289711159A0A0E920709
8801048E070D8A070D7D0E13460608231210797D79BCC1BFCCD0D2CBCFD3CECFD4AE9DA5
7940487410157E050A7F030A7E020A7C01087A01087A01087C01097E02087F0206800208
8101078302078403097E02097601047E040787050A850206880309860107860208891217
983B3CB371714811134200026E050B91060E9503098C020786010687010881000872060B
86484989777868686A7774763A30315F5152280E08208C0400FF0000FF00
00FF004AA80F4C0B003E02013D01013C02033301022A00012400012000012301002C0201
3001013501013800013B01023403041C00004536374E373D3C0E154C0309560104550001
5100005501015B01026202036801026E01037401047902047B01037D0101810102840101
8601038700048901058901058B02068F010892010992030897060C9C070CA3080CA8080E
A50D118F13164B0506503E3BAFB2AFD5D8D9D9DCDED7DDDED9DEE1DCE1E3DDE2E4DDE2E5
DCE2E3DEE3E3E0E5E5DFDEE2D8C4CDBE838FAF3F4CC2272ED11E21D81A1BD91819D51618
CA1115BB1518871516532624B5B2AED2D7D6DADEDFDBDFE1D9DEDFD9DEE0D7DDDED7DDDE
D7DCDFD5DADDD4D9DCD4D9DCD4D9DBD8D7DAB3979C7E2E3393131AA00D129B080D900508
89030886080D740E134104071C0C0A636A63AEB5B1CED0D0CDCFD2CDCED3BBB2B77D545B
711B217E090F81030980030A7E02097E02087F030B7E010A7D010A7E020A7F010883020B
81010782040880020681020981030980020683050884030884030A83010986030A85090E
9D383AA65B5A5B17175B0406850A1096050B95020788000383000583010781010872070C
87494CAC9A9C73737657545642383B524446260D071E8A0300FF0000FF00
00FF0046A20A4B0A003D00003C01023501012D0001280001240000200100220100290101
2F00013601013B01013D01013E02033706093C171E481F2742060C500206570103570203
5101025001025702025F03036502036A01047201067701047A01037C0002800002830101
8401028601048801048B01058D01058F010694030A96040B9601069A0307A3090CA30B0E
8D0F134F06093F2A29A3A6A2CFD4D5D8DADCD8DADDD4D9DCD6DBDED9DEE1DBE0E3DDE2E5
DBDFE2DBDFE2E3DEE4D7B9C2B26975AC2F3BC01D26D11A20D91A1DD71717D91717D31516
C31416A31A1C5C1617A19190D6D8D7DADEDFDADCE0DBDCE0D7DCDFD7DBDED4D9DCD9DEE1
D7DBDED6DBDCD5D9DCD6D9DDD6D8DDCDBEC69457608A171F9E0A129D040C9B080D8F070B
840C10670D10320204190D0A596059A2ABA6D1D4D4CED0D3CCCFD2C2BEC293737870252B
7E0F1586070E83030A82030A7F01087F01087E01097E01097F020A7F020A7F0109810108
8301088101077F01087F02087E010781020983030985030887030988030989030A8A040B
8D1215A8393BB344479315199C0B109F060C9501078B010486010484010583030874060C
7D3C409D8A8D8C8C8F5856584F4748453938250D051E8A0200FF0000FF00
00FF0046A20A4B0A003E02003900003201012C01022A01012801012301002501012A0001
3201023A01023D02023F01024401044402064A0E1345080C460104500003580003580204
5100024D01024A01024B02025102025C02046902067301047902047B01037F0103830202
8200008501018700028A01038B00038D010490010596040B99050A9D0608A20C0D941013
5B070A301311888783CACECCDCDEE1D8DCDED7DBDDD7DBDED8DCDFD8DDE0D9DEE1DBDFE1
DCDDE1DCD3D9D5AEBAB85F6DB02731C01820CA141AD6161BDB191CD81617D91818CF1616
BA1D1D7716168D6B6BCCCAC8DFE0E1DCDDE0D8DBDDD9DDDFD6DADDD5D9DCD7DBDED9D9DE
DBDADFD6D2D7CFC4CAC8B6BEC0A1ABB77D888A222C9E1019A40811A10710970C11810F13
54080A220001171311626964A2ACA8CBD1D0D1D2D5D0D1D7C6C3C993797F7330367B1018
86070E86030A85040C82020A80020A7F020A7E01097E01097E01097F020A7E0108800108
8301088201078001077F02078002077F01078202088402088402078A060C89020A91050C
9C0C10A21014A61216A70F12A5080BA2070C97010791030887010587020684030873070A
8A494B9581846A686D6A66685B5153312626260E051D880200FF0000FF00
00FF0042A0084D09004402023D01013201012C01022B02032801012401002500002B0101
3300003D01014001024201024702044602024601034702024900005301025B0204560103
4C0203450203581C1D7A3E41813F42550D0E5300016803047402037800017F0203830203
8401018401018601028801038900028D01058F000592010798040A9F090C970F11690B0C
2F0A09736F6ABBBEB8D9DAD9DBDCDED9DADDD8D9DDD8D9DCD5DADCD6DBDED6DBDED7DADD
D6CAD0C4979FA44550B5252EC5191DCE161AD21618D9191CDB1A1CDA1718D61818C81E1D
B53D3A743E3BC4B9B7DCDEDDDDE0E1DDDEE0DADDDED7DBDDD8DCDFD7D9DED9D7DCD5C5CD
C9A5B0B7818B9A535F903C478C2934961E289D1118A50C13A40C14940D15710B103E0406
160201272826717977A1A9A6CFD5D5CFD3D6D0D3D7C9C4CC967A8474313A7A131A84070F
89040B89030A8902098603098001077D00067F01078001087D01067D02067E02077E0107
8202098301098101087F010880020780020680020682040982040B84020A88010894070C
A0090EA70A0EA8070BAE0D10A8090CA1060A970207910207880104860105820206700508
8C4E50A18D8F6B666A474043695F60251818270D051D880100FF0000FF00
00FF0044A0094F09004903044002033201012900002701012401012300002801012E0201
3501023D02024001024201024201024100014301014702024900005302035603044C0202
420000752F31954B51813038882F3771151A5401025801026C03057702027D0103820003
8401028301018300008500018900038D01068F010794020A97030A96080F7B0F14370403
5C544FA7ADA8CFD4D1D8DAD9DADBDDD7D8DBD6D7DBD6D8DCD3D8DBD5DBDCD7D8DCD1C2C9
B37F889D3942AF2027BE1719C91718CE1515D41718D61618D71618D61517D01A1AB92A27
DB8E89AD9694D5D3D2DBDDDFDCE0E2DBDFE1DBDEE1D8DBDCD9D9DCD3C7CEC39CA7A9616E
A138479F232D9B151D9B0F189D0C15A00B12A10C11990E1483111751060A240102110A09
444C47858F89B0B7B3CFD3D3CED2D4D0D3D7C9C4CA967780732B377A0F1884070D89070C
88050A88040A8803088905098302067F01058002058002067E02057B01057E02077F0108
8001078002067E02057C01047F03077E02057E010580020883040D82010988010894060B
A2090EA8080DAE0B10AE0A10AB0A0FA1050C98030A9000068A0106850106810207700508
7C3E3F9F8A8C908B8E40373B756A6D1B0F0F240C051B870200FF0000FF00
00FF00429F084E09004502023C01013201012A00012801012401012500002A00012D0002
3201013901013F00004202033F00013D00004101024602034901014D01024A0203420101
4701035E080E65030B6F020B7702097803086904075100015A02047103037C0103810204
8101018201008300008601028800028C000590010694020797080F860F154705064E3D38
959992CCD0CDD1D5D5D5D7D9D5D7DBD6D8DCD6D7DBD4D7DAD3D8DBD8D7DBD2BBC2AC6C77
9C2D36AC1920B91418BC1113C31314CA1413CE1213D11315D51416D51718CC2022C14E4E
E5B6B6C9C2C2DADBDDDBDDE0D9DEE1D8DDE1D9DCE0DBD5DBCDB2BAAF6D79A03442AC1F2C
B2141EB11016A2060CA00A109D0D15930E1681111858080D2C0103110403252B296D7B74
93A19AC1C8C3D3D7D6CFD4D6D0D3D6C2BAC196717B7529347E121C86071089070D860509
8403078603088804098502078300058301058402068201068103087E02077E020780030A
80020981020A80040A7900057C02077E02077F0106830208840309820208860106930408
A40B0FA9080EAD0A10AD0A10AB0810A3060E9902089302088A0106840006810206720609
854748927D7F7D767942373A776B6D1306052008031A860200FF0000FF00
00FF00419F074D09004703034001023601012F01022B00012900012B01012C00012D0102
3000003801013F00014301024302023F01013E0001410101470102480203410101480102
5902046902067200067800067F01058102067404075301024D00016B04047B0102800102
8002028101018400018600028701038801048C02049104088C0F1457080C391E1C8D8C86
CBCCCAD4D4D6D4D4D7D2D5D7D5D9DCD5D6DBD8D8DCD6D6DADAD5DACCB0B8A75E699F2631
B01821B71318BA1115BB0F12BF1113C10F10C91112CF1314D41416D01516BD2022D88082
D1B7B9D4D3D5DBDCDEDEDFE2DCE0E4D9DBE1DACFD7C197A1A24C56A5212DB2141FB91019
B60F17AB0D149E0F168D1118710E134C070B280103120304161919576361909F9CB0BDBA
CFD7D5D3D7D8D2D6D9D4D5DABBADB38759637C273183111A87060F8A060E88060D830208
8402088603088702078603088401078502068302067F01057E00067D01067D02087D0109
80020A80010A7E02087D02087D01087F02078403088603088503088702098A020797080B
A3090DA9080EAD0910AD0910AB080FA5060D9D030A96030A8A0107840005810206710508
945556A691916A616236292B6B5E5E0F0101250B0818840100FF0000FF00
00FF003F9C054C09004501014001013600013101012E01012D01012F01012F01012E0101
3101023901023E02023E01014001023E00013C00004000014402034101023F0000520004
6702057402067C030981020B87030A8603087D070C5B03044900006704087B02047F0102
7F00018201018501028701038701038601028C03048B0A0C680B0E310909706B66C0C1BE
D3D3D5D4D3D8D4D4D9D2D3D7D5D6DAD7D7DCDAD8DDDAD1D7C8A8AFA3555DA12229AF151B
B71217B91117B80F16B80E14BC0F12BC0D0FC51112CD1315CF1114CC1518B42729E7A2A5
CCBFC1DEE0E1DCDDDEDCDFE0D8DCDEDAD4DBAF8892933B46A4222BAD171EAA121BA5141C
98171C7C101659090D3702051D01020D05041518184F5957899692A6B3B2C5CFD0D1D7DB
D3D9DCD4DBDFC7CCD3A499A3794D5577262D82181E810E15810C11830A1184070F84040C
86040B8902098A03098803088402078303088002067E01087F02097D01067901057D0106
8002088001087E01077C01067D02077E01078002078102067F01068202098903089B0A0C
A4090DA90811A8070EA9090EAA090FA6060D9F050C98040C8C01088501067F010573070D
7D3D41A79293898183382C2D63575613040324080619850100FF0000FF00
00FF003F9B054D06004601013E01013500003202022F01012E00002F02012E02012C0202
2C00003501013C01003E01013E01013D01013C00013E02013E02033901014501025C0305
6B02067201057901057F010683010783020779040A5602044100006204087B03087E0103
8101018401018500018702038801038F04078F050A7A0B0E3E0404584A45ABABA7D2D3D3
D2D2D6D4D5D9D2D3D8D4D5D8D6D7DAD8D7DCDED5DAC7A4AB9C4A52A32229AF1318B81217
B91015B90F16B80E15B80D14BB0E11BD0E11C41013C91015CE1116CB181AB42D2FECB1B1
D1C8CADEE0E2DDDEE2DADFE0D7DDDEB7B5B95A3A4169222A74181E6D11165C0B11470609
3201031F01010E03020A0B0B1B2421505C5A899592A2ADA9BDC5C4D1D8D9D2D8DCD2D9DE
CDD7DFB1BFC7808C95433A463C18213D0B0E3C07093B05083E05074A070B5E0B106F0A10
7B060D86050C8B040B8701088402078202087E01078002097F02097D01077E03077D0103
8002068202087E01097C02097F030A8002088101078103087E01077F01088A040A9C0A0B
A40A0DA8080EA8080FA9090EAA090EA8080E9E020A97030A8D01078501067F020672060A
7535377A656788818342353753444511040320040329490200FF0000FF00
00FF003F9B054C06004803013D01013001012C00002F01012E01002B0201260000240000
2700003502023E03033F03023C01003B01003C01013C01013602013300004C0306610204
6900046F01067400057901057D01067E030A6F04084B02023B00006004087B0307810105
8401038602018701028A02048D02048F0307860A0E55060740262292918BCCCFCCCED2D4
D0D4D6D4D7D8D4D5D8D4D5D8D4D4D7DBD3D8C6A1A79F4951A31F25B21318B61115B91014
BB1013BD0F14BA0C12BB0E12BB0C10BE0E11C20F13C71016CE1418C9181AB02D2DE5ACAC
D2CACBDCE0E2DCE0E2DADFDFD3DADB8991950E0E1314070B1704081203050E0406090506
0A0B0A191F1D434E4B6F7D7A8F9C9AA5B0B0BEC7C5D3DAD9D3D7DAD6DDE1CFD9E0B8C6D0
8B9EA941565F0E1F26040C1307070B0603070806090604050602020C03021600012B0103
560A0F75091083040A88040B8401077F01067E02077F02087E01097E01097F0207800207
8101068403088003077A01057C02077F010784020885030A7F010880010A87010999070C
A60B0FA9090EA8070DA9070DAA080DA8080D9D03079602088F02078601057F01066F060A
95595B8E7B7B63595A4435373B2E2F1306061B0201390C0300FF0000FF00
00FF003D99044C06004803043700002A0100290001300202310202290101230001230102
2A01013602033A01013B01003A00003A00003B00003A02022F0201300001520407660104
6E01067200067501067801077601087003085901043E00013D00006304067A0204810102
8400028701038902068A01048D01048B07096F0D0E370B09736D65C1C5C1CED2D3CBD0D2
CED3D5D1D7D7D0D3D5D6D5DAD9D1D5C09DA299444AA72025B31315B50F12B60E12B81213
B61112B81215B80F14BC1114BD0F13C00F14C11014C41014CB1217C41216AA2023DB989B
CEC2C4DDE0E2DBDFE1DDE1E2D6DDDE9BA5A73D494B2C35372A3132333F3C48555065716C
85908E96A29FA5B2B0B3BEBBC7D0CED3D9DAD3D7DCD4D9DECFD8DDB9C8D093A6B3556B75
122A30061A1D1424242D3A3A424E4F4C5859566564556363424F4C2E3835131715070302
1B000150090F74080E82020B84020A8201097F01068003077F02077E01077E01077F0108
8201088503087A01037302037300057B010781010783010880000780010787010897070B
A3090CA9090EA9080FA9070EA8060EA7070D9D03079502059002068901068102076A050B
895155A391946A5E5E4F3E3F2318180A0101190000380C0300FF0000FF00
00FF003B98044B05004604053500002B00012D01013001012E02022501001F0000250203
2B01023400013A00013B01003A01003900013B00013A02022B01013001025404086D0207
7501077901087B020979030A7102096103064D01033D00004901006D03057C0202800002
8301028701048801058E04098E030883080C540808462F289C9D94CDD1CECDD1D3CED2D5
CED3D6CDD4D6D0D3D7D9D5DAD0B5BA9851579E2328B21417B60E0FB50F11B41115AE1619
A4171BA11A1EA51B1FAD171ABA151AC11217C41218C30F13C81217C20F14B0191EC77075
CEB4B8DCDEE1D9DFE0DCE1E1D9E1DFBCC6C6A8B3B1A8B3AFA1ADA898A7A08B99929DAAA3
AAB5B2BEC8C9CDD5D7D5DADCD3D8DAD3D8DDD2D7E0CBD7DEA9BAC1758A94263E48041C22
273D3C5F737082928D83928E8997948D99978B9A978896958C989686918C747E763F4741
090403280002660A117E050D81020A8201098103088103078204087F01067E01077E0007
8401088503087C02056F00007502067F040A8100068301088202098303098B03089B090D
A3090CA80A0EA8090EAA0B11A5050EA3030B9F030B9501079101068B010680010668050A
7945488370737D6E70554244160B0B0B02021A00003D0D0500FF0000FF00
00FF003A97034B07004403033401012C01022E01023001012D02012100001D0000240102
2D00013A01023F02023D02013901013901013D01023802042500012800014D03086A030A
75030A79030C76040B6E030A6102095303074901054700015F02057703067D0001810204
8201038401038802058E04098C040A790C0F3F090770655EC3C5BFCFD1D1CFD3D5CFD2D6
CFD4D7CED3D6D4D3D7D5C3C9AD7279992C2FAD181AB61114B31013A7151994171B770E13
600A0D560A0D5A0A0D6D0B1093161CB1161CBF1219C00C13C30F14C20F14B8151CA8333C
D69FA7DED2D7DADDDFD9DEDEDADFDFD4DCDBC6CDCBC4CBC8BBC5BFB9C5BEBAC5BFCAD4CF
D1DAD8D3DBDCD3D8DCD3D9DECFD9DDC8D2DAB0BFC87F919B495E6421393E384F545F7374
81918E95A39DA4B0AAB1BCB9BAC5C3C1CACAC6D0D0C3CECEBEC8C8B1BBB79CA79E828D83
4B4F4B1B0606530A1078070F80010981010886040A8402088403088001057F01077F0007
83010886030981040878010479020683050C84020985030A8201098300078C02079A0609
A2080BA4090CA2060BA60910A4050DA2040C9F040C9702099201088D030980010668070B
8854566F5E605F4C51533D410F03040B02021A00003D0B0400FF0000FF00
00FF003A97044B07003F02022F00012900012B00012E01022B01022200001F0100250101
3100014102034401023C01013700003700003C01013A03052401012000003F0308560208
63040B64020B5D020A5402094A010745040846000460040978050A820307800205800105
8201058602068902068C0208870C11590A0B4D322FA6A5A1CED1D0CFD1D4D0D2D6CFD3D6
CFD3D6D3D4D7D1C4C8AD787D962B30A81819AE1114A513188D141B5D0A0F3704081D0304
1104050E03070F03061702043501047D1016AF1319BD0C13C10E13C00E12BC0F13B31A21
B0424CD7A0A8DECCD1DDDCDFDCDFE1DBE1E1DAE0DFD9DEDED8DDDDD7E0DED5DDDBD5DBDB
D7DDDFD2DADFCBD6DFB5C4CE92A4AF657B84324A52273E4555686B81929398A6A7ABB6B6
C4CCCBCED7D3CED7D5D0D7D8D2D9DACFD5D7CED5D8CDD5D7CED7D8D0D9D6CDD7D2C4CEC8
9BA29E564E4B420B0E740B1283050D8201098501098A040B860208830206830207840209
8502078502078403088001067F01088101098101088102097F010685010693050A9F0A0C
A3080BA4080DA2060EA3070EA70B11A2070E9D030A99030A9201088C02087E0205650707
98686889777A453036462F330A00000901011D00003C090300FF0000FF00
00FF003896034405003601012A00012801002901012A0202260001250101240000270001
3301014102034402033C00003900003A00013F01023D03062601031A00012B01053A0105
4201064502084001063D02083700053C000256020878070E86060B880409860308850208
8602088802078B0105890408750E113C0E0D847D79C5CAC9C9CED0CCD0D3CFD2D5CED2D5
D1D2D5D2C8CDA3767C933037A1171DA5141891161A610B10300204150404151816394441
5E6B696F7B7A646F6D48504F211718440508A0191FBA1015C00D13C00D12BF0E11BE1316
B0161FAF3945C8808BD7AFB8DCC4CCDFD2D8DFD8DDDFD9E0DED6DEDDD4DBDCCED7D7C4CF
C5B6C2A5A6B3778895415765172F3A21383D617576889799A4ADAFC2CACBD1D7DAD4D9DB
D3D8D9CED7D6CED7D6D1D5D8CFD5D8CFD5D9D0D5D9D0D6D9CED6D6CDD6D5CCD5D6CDD4D5
D1D6D6ABA7A662383A7011167F050C800108840209860208860107850106870308840107
8300058302048604088402088101087F01087E01087E01087E00058A040A99080EA0070C
A3070DA2050CA50810A4080FA4090FA1070C9C040A9801099102088901077C020564090A
9061619884873F2B2E2D191B0600000701002103023F0B0300FF0000FF00
00FF0064730E3E05002E00012301002301012703032002011D00012301012801012A0101
3300003F02024101013E00003F01004101004501014303062600011300001D0206290307
29020430090B32090B2F030637010453050B76081284030E8902098B03098C04098B0308
8D04098E03068E0306830B0B52090958423FB1B3B0CACFD0CAD0D3CBD0D3CED2D5CDCFD3
D5CED4A17C82812C31971A1F96161C720F153B03061602021B1B195A635E95A19CACB8B3
B0BCB8B3BEBAAEB8B4ACB5B3A3A3A26E45468F1F1FB41315BB0B11C00D14BF0D12BD0D0F
BB0E14B9171FAB1F2AAD3C48B85D69C87D87C78892CF929FC78595C27A8BAD6273954F62
693B4C2B202F08172112282F52676981928FA8B3B1C8CFCFD3D7D9D4D9DBD5D9DCD3D6DA
D2D6D9CFD8D8D0D8D9D0D6D8D0D6D9CED5D7D0D6D9CFD4D7D0D5D7CCD3D5CBD3D5CED5D8
CFD3D6D0D1D2967C7E651A1E76070D7D02087F0207830307870308890308890308850207
8403078203068101057E010681030A81030A7D02087B00087C000688020899080E9E060B
A2060DA3070DA2060BA4090EA3090DA1070C9B030A97040C8E0109860107790205640D0E
96696A735D5F321D1F1808080400000800001F01013E0A0400FF0000FF00
00FF008E4E1A3D07002A01011D00001D01011D03021100001201012002012902022B0001
3502023E03024101014300014701014801014A00024B02063902051A0001140103220C0C
6D5A59A89596917A7C2C05065F1C1E79141982060F8A020C8C020A8C03098D05088D0407
91050995060A90090B7914133D100C888580CBD1CECCD2D3CAD0D2CCD0D3D0D3D6D5D2D8
B69BA280383C8B1C1F89191C58090D240103181214565F5D9AA6A1B9C3BBC6CCC8D5DAD9
D8DEDCD9DEDDD9DFDED7DEDDD2D4D2C1A9A79B4642AC1B1ABD0E13BD0B12BF0E12BE0E10
C00F12C21015C01218BB161EB41921B21F28AD1F2AAB1F2DAE212FAB213094202E631520
28050D110F143E4D4F7D8E8E9DABA9C5CFCCD1D8D7D2D7DAD2D7DBD2D8DBD2D7DAD0D5D8
CED5D7CFD9D9CED5D7CFD4D7D0D5D8CED4D7D2D6D9D0D5D8CFD5D8CCD4D6CAD2D4CED5D8
CDD4D7CFD4D7B2A7AA673234700B117C030A7E02067F020589050A8D050C8B0409860308
8101067F01067F02097C01077E02077E02077C02087A02087E020688020898070D9C070C
9F070CA1070BA10609A60C0FA4090C9F05099A040B93020A8A0007830106770306661415
A982827562632612140E02020300000A0000230100400A0400FF0000FF00
00FF008F4F1D3C06002801011B00001900011501020A00000D00001C01012601002B0000
3400003D01014301014701014A01014C01014F01025501074F060B31030717010349383B
C4B5BAAFA1A96B525A69353B782025800B1286050E8B040C8C040A8A03078C04068F0607
96080C96080C8C1011631714533D36B6BBB6C9D0CFCBD2D3CAD2D4CBCFD2D3D2D7C4B2B7
81464C7C1C20751518400506180302353635818B8AA7B1AFCAD4D0D7DFDBDADEDEE0E0E3
DDDCE1DBDADFD9DDE1DADFE0D7DBDCDBD3D0B57E7A9E2120BB1115C00D12C10F13C00F13
C10D13C20E13C51016C51117C51318C41217C11217BF1219B9141BA0171F5A080D210203
292929717F7C94A19EBBC6C4D1D9D9D3D7D8D3D8D8D2D7DAD2D9DDD2D8DCD2D7DBD0D6D9
CCD5D7CDD6D8CDD3D6CFD4D7D0D5D9CFD3D6D1D5D8CFD6D9CDD6D8CED7D8CCD5D7CED7D9
CED6D8CED6D8BCB8B96F43456F0E147D030B7D01067E010686030A89040B89040B820207
7E02057E010780030B7E020A7D01087E03087B03087C04077D01048B030899070D9C070C
9A040A9B040AA1090CA30A0CA2080C9C040997030A9101088A02088200057B0509651214
9B72758A76791F0C0E0B01020400000F010127020241090300FF0000FF00
00FF008D4C1B3C05002801011B00001A02021603020D00001101001E02012702012C0001
3601013E02014101014401024902034C00015200025A020658040A5C1F23301115231017
3F2C3760424F7A475271202A75091280030C87030D89030B8A03098B03098B0307910609
95060B90080B871F1E491A158B857DC9CECBC9D0D1C9D1D3CAD1D3CED1D4CCC0C68C5D64
711F245F10113003031D12115D6260929A97B9C1BFD1D8D8D8DFDFDCDFE1DCD6DBD6BEC7
C4A0ACBDA0ACC2BBC2D7DADED8DDDEDBDBDBC29C9D952929B81517C20F12BF0B0FBF0C11
C30F15C30F16C10C13C71217C61115C61215C01113B715179514175206091C0605434A46
8F9D9AAFBAB7CCD6D4D0D9D8D0D8D8D4D8DAD4D9DAD4D9DBD1D7DACFD6D9D2D6DAD1D6D9
CED7D7CCD5D7CDD4D7CFD5D7CFD4D6CED2D5CFD4D6CFD8DACAD4D5CCD5D7CDD5D9CED7DA
CCD4D6CFD7D9C1BDBF74474A6E0D137F050B7E01087F020981030980010882020A7E0107
7E02097D02097E02097D02097A01067A01067B02077C02068000058F040A99050C9C060C
9C060D9B050C9E070CA0090BA40A0D9D050A98050C93030B8901078200067A0409701C1E
8D63675D474D18080B0701010301000F0001290202450A0400FF0000FF00
00FF008D4B1A3D06002701011D01011A00011501000D00001301011D01012401012B0102
3201013A01013D02013D01014100014900015200025B01065A02065911157A494F74535A
79525B70374166141D7107107B030B8102098501098801088802088B040A8E060B92060B
95070B8D0F117C2F2A543E37B7B9B4CDD3D2C8D0D2C7CFD1CCD1D3D1CCCF987378742D31
5A1315260101261F1E777D7CA7AEAEC9CFCFD4D9DBD5D8DCD8D3D9D2B9C3BC858FA24B58
97334077313C8A767ECDD0D3DADFE1DCDBDCCCA7AA9A3032B9181AC61316C31013C30F14
C30D13C81218C51014C91317C40F12C41215B915188F131646030323110F696F6B99A6A1
C0CBC6D6DDDBD3DBDAD0D8D9D1D9DAD2D8DAD4D9DBD2D9DAD1D8DACFD6D9D0D6D9D1D8D9
CDD6D5CAD4D4CDD5D8CDD4D7CCD2D5CCD2D6CBD3D6CDD7D8CBD5D7CBD4D6D2D8DBCED6D8
CED6D7D1D6D9B6ABB06A343A77101685070D8102087F02097E01087E01087F020A7F030B
7C020A7B02097900067801067802077801067B03087F040A85020991050C97040A980308
9B050B9D060C9D070C9C0507A2080B9D050B97020A91030B89000982010779050A7D2E30
B690933E2B310E02050300000100000D00002A020145080100FF0000FF00
00FF008B49193B0400270101200001230101280C0B1400001701011A01011D0000250001
3000013901013A01003800003F00014B01035401045B01045B0003590307570B1259131C
590F186009106B040B7402087D030983020A87020A8802098A040A8A040A8E050B91050A
92080D831615632D26877E78CCD1CFCAD0D2C9D1D4CAD1D4D0D1D4B49CA072383C5E1D1E
28040336332F7E8482B2B7B6D0D4D6D2D5D9D7D6DCCEBCC7B483919E4451A32632AE1D26
9F1E24550D107F7071D0D4D5DBDEE1E1D9DDC08E929E282BBB1516C21113C00E11C41015
C71015C91116C91216C61014C61317B91517921517430303322421868A86B0B9B4CED7D4
D4DAD9D7DCDDD4D8DBD2D8DBD2D9DBD1D8DAD3D9DBD1D9DBD1D9DBCFD7DACED7D9D0D9DB
D0D7D9C9CDD2C1BEC6B8B1BAB1AAB4BAB9C1CDD2D7CBD5D7CDD6D8D0D4D8D1D5D9D2D7DA
D1D7DAD1D3D8A590966520287B091187050D8202087E01087D02097D01087F010981020A
7E01087A01087701077501077400077401077602087402057C03088B060B9102089A060A
9B05099A03079D060B9D0509A3090F9B020B96030B8E0208870007820006750409732A2C
AD8C8E3224270901030100000101010E01012C030145080300FF0000FF00
00FF008B491B3C0600250001210000461E1E431C1D1E01011A0101170000190000220001
2F01023B03033A01023800014000014B00035302055501025802035801035A01065C0107
6001096601076E010873010878010780010985010A8601098602098602098B050A8D0408
89090B862E2A55332EB4B1AFCFD4D4CCD2D4CDD2D5CFD2D4C8BDC0784F54561D22280605
3A3632878E8CBCC2C1D4D6D8D7D8DBD7CFD6C4A4AEA35B69A02D39AF1B25B41219AA171C
700E104C2927B3B2AEDADDDEDCDCDFDFCDD2A95E65AC2126BE1416C51517C11114C21015
C71116C81115CA1316C31014B91317901215420203382C2A959D9ABAC2BFD4DCD9D5DCDC
D4DADCD5DCDED3D9DCD4DADDD2D9DBD2D9DBD2D9DBD2D9DCD0D9DCD3D9E0CDCED6B9B3BB
A28F998A6A75805261753D4D723C4C7B5562948992C8CFD4CBD2D6D0D4D8D4D8DCD2D6DA
D1D5D9C7C2C8835D666C141D80050E85030A8103087F02087C00077D02087F0108810209
7F01077C02087702097301077200067402087401066F01046E000182050A8E0409940307
9A05099B04099D040B9D040B9F060E9A030C9202098D030987010782010774060A793334
83646526181C0801030201010100000C000026010040070100FF0000FF00
00FF008447173A06002600002302036F4C4D3916171F01011B0202160101170100210201
2C00003602023700013900014301024A01034C00024E00024F00015000015500035B0004
6100056601056B00067001077400077C010A81010A83030B84010889040A8A04098C0509
810D0E7F3E3A73635EC8CCCBCFD4D6CBD3D4CDD3D4D3CFD0967C7F562A2E2A080B3E3834
898F8AC2C7C6D1D5D6D6D5D9D2C3CBB1838D983E48A42129B5161DBB1319AB15197A1113
3E0E0F938A89CACDCDDCDEE0DEDADDD2ADB3A23B44B81920C21215C30F14C41115C51116
C61115C81317C91318BB10149A14174903043F302F9FA6A3C0CAC8D4DDDAD7DFDED2D9DA
D4DBDDD4DBDDD1D8DBD2D9DBD4DADCD1D9DAD3DADDD4D8DECAC9D1A697A5926D7E814A56
752A36771C287B16227D121F791522601F2A503D44A3AAAECED7DAD0D7DAD1D6DAD2D6DA
D1D3D7A4929A6C2F39760D1783050C8504098303097E01077D02087C01077D02077F0309
7F02097A02087301067101067201077301067601057904087702058001058E040A920207
98050A9A050A9D040C9D050C9A030A98050B8F010889010787010780000671070A925250
886D6D160A0C0300010000000100000D00002501003E060100FF0000FF00
00FF008547193905002902033F2122705759422D2D1702021601011401011700001F0001
2B01023502023700013C00014401034902044B01034C01034C01025000025701055E0005
6401056901056D010772010977010A7C010A7E01087D01077F02088403088A05098B0A0C
811E1E724643999793CBD4D3CDD5D7CCD4D5CFD4D4B9AFB06040432C0E10393130868B87
C2C9C5D1D6D7D4D4D7D0BDC6A66C79952D39A71A21B51217B60F14A9151A781014370809
817575BFC0C1DBDDDFDCDDE0DECCD2B46E76A92229C2151AC10C10C71217C61015C91317
C40E13C50F13C41318A814195B0608402A299DA09EC6CCCBD7DCDCD7DCDDD8DEDDD7DDDE
D5DADDD5DBDED2D8DBD4DADDD3D9DCD5D8DCCFCAD0AE9AA49065727D38477C1F2D841822
830E17880C14870B12810C146F11193B0B102E2A2C9BA7A7CCD7D7D0D6D9D0D5D9D1D6DA
BAB4BA7A515B7118227F09127F020A81010A83030B81020A7E02097C01067B02067A0107
7A01077601067000047101067302087100057600057D01068202068601068E030991030A
92020996030A9703099A030A9B050B95040A8E020988000789010983020870090B955758
8F73760F06080200010000000200000E00002801013E050100FF0000FF00
00FF008145173605003F1B195A3E3F6D575B4130320F00001000001401021700011D0001
2A01013502023A01013D00014201024801034A00034B01034D01035300045D0106620106
6600046A000570020875010978010A7C010A7E02087B01057E020781010788050A860C0F
8B39396D514DB9BCB9C8D1D2CCD5D7CED3D5D0D0D17A6A6C361E202E25237E8481BBC3C1
D1D5D7D2D1D6C8B5BB9B5E69922331A4121EB20F14B21014A113176E0D112C0303645E5C
B5BBB9D6DADADCDFE1E1D9DEC999A3A2333CBB191EC71215C71013C61013C91114CC1318
C91015CA1519B7171B770D11411B1B9F9D9BC8CDCDDBDDDFDADCDEDADEE0D7DDDCD6DCDD
D6DCDFD5DBDED1D9DCD2DADECECFD5BAA7B29C6C79853945821C278A131B8F0E168E0A11
8B0911880A127D0A12650D13320406150D0E5C6867B7C3C2D0D9D8CED3D7CDD2D7C4C2C8
886C756C212B7A0A1381060D7F020A80030B80020A8002098002097C0105780105780107
7701067200037001047001056F00056E00047400057D01068501058902048A02068B0206
8F020792030995030998040A96030993020A8E01098C01088900088002056F0E0D9A6162
6044470D02050200010101010300011201002E03023F040100FF0000FF00
00FF007A411535070146221F5B3B3D482C31210A0E1501031401011702021701011C0101
2700013301043901013D02014101014501024900024C0102520104590105600206620004
6600046A010570020872030975020A7C040C7D01077C01057F020783010987050D7C0C11
975655887975CAD0CECBD3D5CCD4D6CFD3D7AAA6AA3D32321D1714767A76BDC4C2CED3D4
D5D5DAC4B0B993555E90232AA01017AC0D14AF10169E151B650A0D2803045A5854ABB3B0
CFD8D6D9DDDFDFDCE0D1B1BAA54A55B01C24C51418C50D0FC81012C91113CB1014CB1115
CC1416C6191A971718480E0E938986C1C9C7D3DBDAD9DDDFD7DBDED6DBDDD5DBDDD7DEDF
D5DDDED5DDDFCFDAE0AFB8C28F81907E435584212F8D131C981017970D12970E11910B0F
870A10790E15560B1025020211100C49595598A7A4CED7D7D2D8DAD0D6D9C9CBD08C797F
682830780E1782060C8003087C01067D01077D01097E000880020A7E02087B0107790107
7802077200047002056F01046E00036E00037400047C01048301048601038501028A0307
8E020790020994040A97050B96030A93010992010A8E02098B01087F0307721819BD8B8C
462F310A01030100000100000501001801012F000240040200FF0000FF00
00FF007B411443150747221C3718182104081801021501011400001801011900011B0100
2500003100023B03023C01013F00004500014D02025001015500025C0105610207630104
6701056A020867050C5B03095D020874080D7E050880020681020684030884060C771416
A27572A29C97D0D4D4CED3D5CCD4D6C8D0D363696A1116125F6760AFB7B1CFD4D4D4D3D8
C6B1B98A4C55912229A31417A90F12A7131791151A56080920040352524FA7B1AFCDD7D5
D5DCDEDDDDE1D7BFC7B1646EA8202AC1161BC91417CA1215CB1115CA0E13CE1117CD1216
CA1517B520215E0A09856E6BBEC2BED5DEDCD5DEDDD5DDDED5DCDED6DCDED9DDE0D8DCDF
D8DEDFCAD4D6A2B1B75D68752D1B2A671C2A8C141F960C139D0E139C0E12950E10880F12
73131842070A1702011217134F605B8EA09BCAD6D4D0D8D9CDD4D7C9CCD19F8E95743C42
78141A83080E84020984040A8104097D02087C00087C00087E01097E01087D01087B0008
7901087301066E01046D00027002047100037601037C0103800103820103810003850104
8900048E010793030A94020A97040B93000892010A8D01098901087F040A741D22B98B90
30191E0A02030100000101000901011D010133010341040200FF0000FF00
00FF008048124C1F08421F182104031801011501021300011601011C02021C01011F0102
2401013101023901013D00014201024901025202025601015A02035D0105610006650105
6902066502065400054200023E00005F040779040981030783040782010580070B7B2626
9E7F7AB7B6B3CED2D2CED3D4CED5D7AAB5B7243432405148A0ABA2CDD4CFD1D4D5C8B8BF
91575F8E21289D1013A20E109911157911153D03041A08075E635DA7B1AECBD5D4D2DBDB
D6D7DCD9C3CBB5707AA82932BC181EC41417C31114C41014C81016C80E13CA0E13CA1116
BE1A1C8E23225F3A38CCCBC7D6DBDAD6DCDCD6DDDED6DEDFD7DDDED7DCDDD9DBDED8DCDF
D4DBDCD0DADAABB9BA7E8E9227232B3C0B127F181F930E139A0F139411157E12165A0C10
2C02040E05041D2B245E716A9BA9A3CAD5D1CCD6D6CCD4D7C4C7CE96848D753E4578161E
870B1286040B84030C8103097E02077E02087D00077E010980020981030980020A7D010A
7B020B7301076C00036C00027101047301037A02057E0004820105820104810004850105
8702048B00049202089402099502099402099001088D01098901087E040A78232792656B
240E140901030201020201010C00002200003501013F020000FF0000FF00
00FF00824D135127112A07031C01001601011301021301011801001B01001A01011C0100
2301013102033B02023F01024301014901015301035A01045C01055F0106630106670105
6801056301046002085A060B4F01035F03067A040B840309860208860308820E0F873E3C
99827FC7C9C6CAD0D1CCD2D4C8D2D46B7B7D2234328C9C93C9D4CCCFD3D3CEC4C997666E
89242C981218960C0F8510125E0C0F280203201917717A75A9B4AFCAD3D1D4DBDCDADADE
D3BDC6B16E78A32A33B9181FC21318C01114BC0E10BE0E11C20D11C50D11C80F12C31417
B02D2F5A1F1EA09896D1D5D4D9DCDDD7DCDED6DCDFD4DADCD5DBDCD6DBDCD7DBDFD8DCE0
D6DDE0D4DDDDD4DFDEC1CECC808B89291C1C5011177F191E82161A651013360304160303
0E110D3D4E47758780AAB7B0CED6D2CED7D6CCD5D8B9BCC389737F6F344074121B83080F
88030B88030B82020A7F01077E02077D01077F010880020980010882040A81030B7E010A
7A010A7301086C00036901016D01037401047A01047F01048402068201077E0206810206
8501058C020791020894020996030A9201089100088F01098901077C050A8A3A3E997378
1404090500010100000100000E00002C03033E04033F030111C20100FF00
00FF0089591E4A240E2303011D01021801021601021601001A01011A0102160101170100
2301013101023901013D01014100014A01015502025A01045C01065E0105630105660104
6901056C02076F030970040A6A02066E02067F040B8602088B050B8A060B7E0E0F91544F
9B8B87CDCFCFCACFD2CAD2D5B1BEC03143446D7B7AC1CBC7CFD5D4D3CDD19D767E802931
8E171C8610176A0F143903051604033034328E9A98B3BEBBCFD7D5D4DADADAD7DDCEB3BE
AA626DA1272EB4151ABB0F13BF0E14BC0C11BA0D0EBE0F11BF0C10C61113C51213B21819
AC5050684F4FC1C5C5D9DEDFD7DBDDD6DBDED5DADDD7DBDDD7D6DAD1C7CDCEBFC8D1C4D0
D8D2DBD9DBDFD6DDDDD5DFDDC4CECB7A7F7D200C0F43151B3005081602020A0B09273530
6B7F7694A59DC0CCC6CFD7D6D0D6D8CED4D9B4B0B77F626C6A29346F0D167A060D83050C
84020987040A8503098002087F01077F02097F010A7E01097D01087C01077F020A7D010A
7900097501076E01046800016A00017201027800017E00038302077D0106760002780002
8202048802068B000691010795040B96050C9302099202098B02087A060A8A4245907375
0B02030301010101010300001301003003033E02023E020122860200FF00
00FF00885A21320C002001001B01001500011500011901011C0101170001120000140100
2200013403033C02023C00014200014D01015702035C01055C00055E00056501066A0206
6B01086C000673010976010979020A7C03088102088703098B050B87040A7B0F109C6562
9C928FCED2D2CBCFD2CCD5D7869696485856A8B1AFD0D5D6D0D2D6AF989F77363E7A1D23
6811143C02051D01040F0D0C49555190A09CB8C4C2D2D8D9D5D8DADAD4DAC8A7B3A15260
A0212AB5161ABD1013BC0F12BB0E11BB0E11BB0E10BC0D0FBF0E10C21010BE1516A92B2C
D29A98ABA3A3D5DADAD6DBDDD4DADDD6DBDEDBDADED4C4CAB98F989C5A65954755994F60
AF7888C2A7B2DAD7DCD6DCDDD6DCDBBDC3C3494E52090A0F090C0E222E2B62746E83958D
ABBCB4CBD7D3CFD8D9D2D7DBCCCDD3A3939C7F515B6E202A750F157604087B04087B0206
83050A84030884030882030881020A7F02097C00077C01077B01067A00067E02097E020B
7A020A7501077202066D01046E01037502027C02047E01047F01067D0106770103790103
82010687020588010590020895040A96040B9402099302098C030877080A945354503537
0900010100010101010400011601012F02023B01023C020021850100FF00
00FF007F4F1A3007002201011B01011601011500011A01011E02021A0202130101130000
1F01003301013C01014001024701025001025800035D02055E01056201066600066A0007
6F020A71000A7701097C010B7F030C7F010981010886040B88030B87050A7A1012A26F6D
A49E9BCED3D3CBD0D3C3CCCE798685899592CBD2D1CCD2D3BFBFC4644C535220253A080C
1C02020B0605232A296B767398A49FBFCBC7D4DCDCD7D9DCD8CDD3C196A19D4352A41F2A
B41318BD1212BD1011BC1013B80C0FBD0F12BB0D10BE0F11BF0F10C11010B51717BE5B5A
CEAFADC4C4C4DADEDEDADDDDD9DCDEDCDADFCBB3BBA05E6A9329359C1A23A218229D1926
8D2433824857B2A4B0D1D6DDD4DADDD5DBDD9EA8AB4150506575728A9A96A7B6AFC7D4CD
D2DCD9D2D9DBD2D5DBBEB5C091727D75333E7818217F0C137E070C7A0207790207780105
7E020784060A8002068002077F020881030A7D01077F03087E01077F02087E01087C020A
7700077501067101046E00027201027901037D01037D01037F01057E00047E02057E0003
82000588030889010690020996040B940109940209910208880407781314A56C6C351A1D
0900010201010301010700011801003202023F03033D010020840100FF00
00FF007942173205002201001B0001170001150002170001180101140000120000140101
1D01003302024002034300014800015001025601035B02045C01046301076801076A0007
6D000972010B79020A7E010A81020B84010C84020A85020984020888060B7D1114A06A6C
ACA5A4CCD2D3CACFD2B6BFC1899494B9C1C1CED4D5C7D1D3757D811A171B1208090A0707
1B24224B585475827FA9B3B1CCD4D2D4D9D9DAD9DED4C1CAAF7B8696323EA41822B21016
B70F11B80F0FB40B0DBA0E12B80C11BB0D12BB0C10C00F12BF0E10C01213AE1E1ED28685
CBB9B8D5D7D8DADCDCDBDBDEDBDBDFCABEC58B57628E2633A019249F141B97161C86161C
6A141F3D101F3A3541A2ABB6D3DDE2D7DEE0C5CFCF96A3A1A8B5B1C5D1CDD0DAD9D0DAD9
D3D9DBC8C3CAAA929E85505F721E2C7D111B830B1483090F7D040A810B12770208780006
7D03078105098003087D01067E02077E02097D02087E02087F010780010880020A7F030B
7B02097601077100037100027802047B01037E02047D01037D0103800205800104810104
8101048501058800068D010993020A94020A9201088E000785050A7E2123A16D6F2A1013
0901020100000602020D00021F00013602024002023E020021840100FF00
00FF007037123003002200011B01011602021501021501011702011502011000000F0000
1900012F02034002034501034A01024E00015300015600025B00056301086801096A0107
6C01067201087A030B7F020A82030C86030E86020C86040B86040A8A080E7D0F15A76F73
ABA2A3C9D0D1C7CFD1B0B8BA9BA3A3CED4D4D0D5D9A2ACB226353805121127332F596662
7A878299A5A1C1CACAD0D6D8D2D5D9D7CFD6CBABB6A5606D982733A8161EB10F12B70E10
B70E10B50D0FB30C0EB60D11B40A0EB80C11BB0E11BE0F12BD0E10BC1113A21C1EDA9A9C
C4B9BCDADCDFD9D9DDD9D9DED5D7DC8981885026306B202969121A5C0D13400408270104
1603070A090E121F257E8F95BECBCED4DDDFD3DCDCCFD9D7D3DCDAD2DADBD2D9DECACBD2
AEA2AB86636E753745711F2D7215207011196A1016660D14660D14680D1469080E71060B
78030A7C020880040A7D02087A00067800057701057A01057D01067F02087F02097F020B
7C010A7701097501067701057D01067E00047F02047C00037D00037E0104810104820004
8301048602048801068E020A91010A9202099102088D01087F060B8130327D5456180608
0400000101010402030C00012402033B02013F01003C010020840100FF00
00FF006B320E2F03001F00001900001601011500011601001901011701011201000C0000
1400002B00013E02034301024901015001025601025901035B0005620107670106690105
6B00067302097801097D020A7F020A80000984010A86030A86040A89070D7F0F16A06266
A99C9DCBCFD1C6CFD1BAC3C4BBC3C4CDD2D6C3C9CD727E804453516C797384908A9FA9A4
BFC6C4CDD4D3D0D3D7D1CFD4C6B3BBAD7C8799404D9D1F2AAC131AB30F13B71010B60D0E
B60D10B60E11B40D0FB30B0DB40B0EB70E11B80E11B60D0FB70C0EB90F13A31F22DB9FA3
C9C2C5D8DEE1D7DBDED8DBDEC3CBCD555F61100F1316090D1304070F05060C0B0B161F20
394A49687A798B9D9D9DACADBFCBCBD3DCDDD4DDDED3DDDED2DBDFC3CFD6A4ACB576707A
593D494F212C46101A3C08112C02082200041B00021901011D0102210002310306460409
60070E70040B7902087C01097A01077602057501057701057A01077C01087D01087E0209
7A01097901097700077B01077E01067F02057D01037C01037D0104800206820206830106
8501068801068801078A01088E01089002088E0207890106770709A763627456570D0203
0300010000010300000E00002701014104044201013E010021830100FF00
00FF00662E0C2D02001F0100190001180101180101190101180101160201150303100102
1500002B01013D01024301024A02015302035801035C01045E0005610005670106690106
6B01077201087802097D020A7F020A7F020A83020B86030A89060B8C070D840E148F464C
A68F92CDCFD1C8D0D2C7D0D2CBD2D4CCD3D59EA7A88E9A979AA6A0AFB9B4C8D0CDCDD3D4
CED3D5D4D3D8CDBDC6B18993974C5794242FA41721AE1015B00B0FB40D0FB50E10B70F13
B50E11B30D0FB20D0EB40E0FB50D10B40E11B30E10B60E11BA1012B91115A21B21D29095
C6BCC0D6DDDFD5DDDED5DCDCC8D3D27789872F43422839383746455666657D908E91A4A1
9FB0AFADBCBBBECCCACFD9D8D2DBDBD3DCDDD2DBDDCFD8DDA5B3BB70838E33434E181C23
160D1313050B0E040909050804060903080A030C0C020C0A030908020306060204100002
28020353090E6C050B77020A7800087701067701067A02097A02097901077901067D0209
7A01087A02097C010A7E01097E00047E01047C01037B00037B00037D00037E0104830107
8701078800078801078A02088D02088D02078C0207880408730A0BAF7373654E4F0A0103
0401030202010A010120050731020442030442010140010123840200FF00
00FF00632C0B390D082302011901011701011801011901011601001400011201010F0101
1700012D02033E02034501024A00015101025801045B0103610105620105660004690106
6C01086F01087601087D030A7F020A80020A8201098704098C050B8B040A880A137F222A
AA8185BFB9BECCD0D4C9D0D2CCD1D4CBD1D2B8C1BFC3CDCACDD6D4CCD5D5CED4D6CFD0D5
CABFC6B18D999754618E2B359A1820A70F16AF0D13B20D11B30D11B40D13AF0A0EB10B0F
B00B0FAE0A0CB20F0FB20E0EB30E12AE090EB20D12B81114B91013BA1216AA181FC06B72
C3AAB0DADCDFD5DBDDD6DDDED4DDDBBECAC7B7C5C3A8B7B4A4B3B0A0AEABA8B6B5BBC7C6
CBD5D5D2DBDCD4DDDED1DDDED2DDDFD2DCDDD3DCDEC3CDD14F5F67071B24011116011011
0715151422212938363D4F4D52646260706E66767265766F5D6D674F605C2E3D3B0F181A
06030622010455080E6E020879020A7901087801077902097901097802077901067B0208
7B02087D01087E01067F02067E01047C00027D01027E01047C00037C00037D0104810106
8601078801088800078901068B02078C02078902078305087210129A6465392123070001
0100010200000900001D010338010449040742000240010023830100FF00
00FF005F290850251B2002001500011300011501021801011602011201010F01010E0000
1800012A00013A01014501014C01025101025600025B0103600104620103650104690005
6F02087101077402087902097E030B7F010981000988040B8A040A89030889060D801217
904F52A59496CACDD0C5CBCECFD3D6CDD2D4CDD4D6CCD3D6CED4D9D0CFD5C3B6BDAD8B95
9455628727359117219B0F16A60C12AD0C10B00B10B10C10B20D12B30D12AF0A0FB10C11
B00C10AF0B0EB30F0FB30F11B20D11B10C11B30D13B60E14B90E15B90E15B3131AA12A33
CA8F9AD9C8D1D7D9DDD4DBDED6DEDFD7DEDFD4DBDCD0D8D7D1DBD8D3DDD9D4DDDCD4DCDE
D2DBDDD1DBDECDDADEB9CBD1A6B8BBCAD7D8D4DEDFBECBCC57696A1D3031354848506361
6B7F7B7A8D8883959192A3A198A8A7A2B0AEA7B5B0AAB7B1A4B2AD91A49D7D908B667673
3D484A0E090C31040865080D760208790208790107760007760108750107780208790106
7B01068002078402068301058103067D00028001028102047D00037C01037D0104800106
8200068701088901088901058A02068A01078902087F0409842B2DA26E71280F12070001
0000010300000D00002200014002034F020647000242010024830100FF00
00FF00612E05552E1F1D02001201011000011401021801031501011001010B00000D0101
1800012C01013D01024801034E01045200045800045B02035F01026200036500046A0105
6E00067302087602087A02097E020A80030B81010985020A87030889040A8B080D851015
843C3C9B8886B7BCBDC7CED0C9D0D3CBCDD3CAC3CBC3B2BCBA9DA8A677829049548D2A34
9318229B0E18A00B11A1070CAA0B10AC090FAF0A10AF0A0FAF0A0EB00B0EAF0A0EB50F14
B20D11B40E10B20C0EB10C0FB20D10B30E12B40C12B60C14B80D14B90E13B81017AC1520
A43544C98D9CDBC7D2DADBE3D7DCE2D8DDE2D6DCDFD5DCDED6DEDFD4DDDED2DBDFCDDAE1
BDCDD5AABCC57D929D4F66708DA3A6CCDBDBD3DEE0AEBDBE8A9C9B81939296A6A59FAFAC
B2C1BEC5D2CFCDD7D6CED8D8CFD8DAD1DBDCCED8D8CED7D6CED8D8CCD7D6CBD6D4B7C5C3
8795954D55551E0606580B107203097A0309780205740004740107740107750007790106
7D01058301068802068702068301058001048301048602067F01047D01047D00057F0209
8101078501078701078801068801058A01088702087704089042458F64691F090D060000
0100010500001A02033604064F060853040448010143020024840100FF00
00FF006234055D3B2A1B03001201010F01001101011400021201020C00000B00000D0000
1B00003103034003034801045002065400065800055901015D01016501056801056B0105
6E00067301077703097B030A80040C81020A84020C85010A89040C8B050C89060D7E1014
905553938883C1CAC8C8D1D1C6CBCE93838D8F5D6A9044518E2E39901E2698151C9F0E15
A60C13A60911A3060EA6080FAC0A10AF0A0FAF0A10AF0A10B00B10B00B10B00A0FB50E12
B60E11B60E11B40B0EB50C0FB60F10B70E11B50C11B70B12B90F14B80E10B90F14B61119
AA16229E2B3AB26778CAA0B0D0B8C6DAC8D4DACAD5D6C7D0D1C6CEC1C1C9A2AEB97C919D
4E6570203843061F28263F45A1B3B5D3DCDED5DCDEBDC6C8BAC6C7C7D2D2D2DCDBD2DBDA
D1DADBD3DBDCD1D8DAD1D8DAD1D8DBCFD7DBCED7D9CFD8DACDD5D7CED5D7CED4D8CBD4D6
C9D4D4A3AEAB5245434D0E1070080D760208750206720004720004720105730104790205
8002068703098801068702048301048201058501078903098201057E01057E01077D0108
7F00068300048700068901078900078901088202066F080A93535655343A140407070001
0201010801001C01023601034B02044E020245000141010023830100FF00
00FF00693B084D2B1A1902001101010D00000D00000D00000D01010B00000C0100100101
1E01013101023C00014500024D01045200035800025A01025D0102630105680105690104
6C01057202087402087802097F030C81030B82020B86030B8A040C8A040B86070D731215
9F7473999796CAD4D4C8D2D2BFC1C46949507A212B971620A11118A71014A60C0EA70B0E
A90A10A9060FAA0911A8080FAD0A11AF0B0FAE090EB00B11B00A11B10B12AD080EB20B11
B30D10B40E11B40D0FB60D0FB70C0FB80D10BB0E12BB0E12BD1013BB1113B91215B51015
AF0C14AA121E9E1A29972A3C9E4355A45365A45A6B9251617B4E5C4F404D17212F051923
01151D1F35395C727391A4A3BECACAD8DDE0DADCE0D6DADDD4D9DBD4DCDBD5DDDCD2D9DA
D4DBDDD3DBDDD0D9DBD0D8DAD0D7DBD0D8DBCFD8DAD1DADCCDD5D8CFD5D8CED3D7CDD3D7
C8D2D4C8D3D3928D8B4F2020670A0E720108750108740106730105710004720004790105
86060C8902098902078802058402067F00048101068502088401068201057E00057D0106
8101078300058700068901078B02098802087D0407721718C08F913520220D0305060101
0501020800001A00003601024B02044C010243000140010023840200FF00
00FF006E3E0D3311021701000E00010B00010B00000E01010F02010E01010C01010E0000
1D00003001023D01024401024A01025202025801025B02035C0003600105650106690105
6C010570010774020977020A7D040C7E01097F010881010788060C8604097F070B742224
9F8181AAAEAEC9D3D4C7D0D2BAC0C1593E4171171B9E1217A5090EA60A0DA70B0DA6080B
AA090EAB070FAE0A12AA060DAC080EB20D13AE080FB10C12B00B10B20D11AF0A0FB00A11
B00A0FB20D10B50D10B60D0FBB0E12BC0D12BB0D11BD1013BD1013B80F11B51014B00D12
B00D13AE0D14AB0E17A60F1AA1142097192586212E5D1623300915110A130512162B3C3E
7181819EADACB7C5C1CED9D8D3DBDDD6DBDED7DBDED7DCDED6DBDDD4DBDCD5DCDDD5DCDD
D4DBDED2DADCD2DBDCD3DADDD3DADDD2DADCD0DADCCFD8DBCDD6D9CDD6D9CFD6D9CCD4D7
C7D1D4C9D3D5C1C4C56347475A0D116F02097604097301067201067100067500077D0107
88040A8A02088801068502058301067D01057803057B04088204098301077E01057C0104
8001058602078701058A02078800068702077B0509732122BF97972214150B0506030001
0401010F01022402033C01025004044F030344000142020123850100FF00
00FF006131082504001400000E00000E00001201011301011101010F00010E0201100101
1B00013001034002034401034801024D00015201015801025B00035F00046501066A0206
6D010670000676020A79020B7A020B7F040B7F020A82040C8203088204087D0B0F7E3837
9C8886BBC1C1C6D1D2C9D3D4BCC6C65E55564F0E11941419A50B10A80C10A70B0EA4070A
A9090EAB070FAD0911AC080FAC060EB10A11B00A10B00B10AE090DAF0A0CB20D0FB20C11
B30D12B70F14B80E13B80B10BE0E14BE0D15BE0E14BE0F14BD1115B71014B20E13AF0C12
B10E14AD0E12AA1013A2101692141A6E10153C05091A03080E0D12354241788886A6B4B2
C0CBC9D1DAD8D8DFDED6DBDDD5DBDED5DADED5DADCD6DBDDD4DADDD6DDDFD4DBDED5DCDF
D6DCDFD3D9DCD6DEE0D3DBDDD4DCDED2DBDCD2DBDDD1DADCD0D9DBCFD9DAD0D9DBCDD6D8
CAD3D8C8D2D5CCD3D67E6C6F5410166C030A740409730106740209730107780106820107
8B040A8B02078802068401048501067F02076C000262000174030880030A7E00057D0004
8101048502058400048600068802078301067506087F3434805A5B110404040103010001
0300001101022A03044404054F03044901014100003E010021840100FF00
00FF005826052604001600011100001C0604270D0C1802031102010C00010D01010D0000
1900013102033E01014200014801024C01014F00005801045C01056000046500056A0206
6C010671010875010A79020C7B01097E010980030B82040C83040C85070D790E118C504F
988C89C5CCCDC5D0D1C7D2D2C1CECD7277782E060982161CA10D13AA0D11A70A0EA90B0F
AA0A0EAA080EAD0A10AE0910AF080FB00A10AF090FAE080EB10B0FB30C0FB50D11B40D11
B81115B80E14B80D12BA0C12BE0D14BD0D15BA0B11BC0C12BE1016B80F15AF0D12AE0E13
AA0D11A6121499171A7711164405081D02030D0B0D343F417D8C8CABB9B8C4CFCFD5DDDD
D6DEDFD4DCDDD5DCDDD5DBDDD4DBDED2D8DCD4D9DDD4D9DCD4DBDDD4DCDED5DEE0D4DADD
D7DCDFD6DBDED5DBDED5DDE0D2DBDCD3DBDDD3DBDDD2DBDDD0DADBCFD9DACDD7D8CAD4D6
CBD3D7C9D1D5CBD1D47E6E715613196E070D71010676040A7301077400057D0206860209
8A030A8901078801078701068802068502077903076803056701037B0208810207810105
840106860106850106830005840106800407710B0B9E5A597148491F090A060001010100
0501010F01012500014302045002044901023F00013D010020820000FF00
00FF005724012A0601190000190101492C2B4C32321201000C00000800000901000D0100
1C01003201023E01014300014A02034D01015000015901055C00046100046701056C0208
6D01077001077302077A040B81070D7F030882050C83050C86070E85070E750D1294605E
9A9391CCD4D4C6CFD1C8D3D3C5D2D18F9C9A221314600F169A1118A80B10A8080DA6080E
A7070DA9080DAC090EAF090FB00910AF090EAF090EB20B11B2080CB40A0DB60C0FB60C11
B50B10B80F14B60C11BD1116BE0E14BC0C13BC0C12C01016BB0D14B60D13AA0A0FA30C11
9A141683161A530A0D2402040F0808313B39798887AAB8B9C6D2D2D4DDDED5DBDDD6DCDE
D6DFE0D3DCDED2DBDDD5DCDED6DCDED5DADDD4D9DCD2D7DCD3D9DDD2DADCD4DCDED6DCDF
D3D8DCD4D9DDD3DADDD3DCDFD0D9DCD1DBDCD0DBDDD0DADCD0D9DBD1DADCCFD8DACDD7D9
CED7D9CBD2D5C9CBCF735E625811176F050A7201067503097301067500047E0106850106
8802088801078A03098902088B02088B03088503077B040774000387080D8A0209860006
8701078701068500058400058402077E0508711313A66A6B6D4548321B1D060001020100
0702020E00002901024703055102024C01014201023D01011F820100FF00
00FF00602D012D09002101013C1C1A6046465343430B01010B01010901010700000D0100
1D00003502014202024601024A01034F01035301035901035D01046301056800056B0108
6A01086801056D030677060A7F070B81060A81030A83040B83030A81040B700E129C6D6C
A09A99CDD4D6C8D0D2C8D2D3C9D5D4A9B7B540403F34040785141AA30E12A5080DA6080E
A8080EAB090EAF0A0FB00A0FAF090DB10A0DB1090DB60C10B80C10B60A0EB80B0EBA0E11
B60D11B60D12B60C10BB0F13BD0E12C00F15C00E14C01016B90F14AE0B11A20E148D1519
610E11310407120607272E2D727F7CA9B6B3C5D0D0D2DBDCD6DEE0D7DFE1D6DDDFD6DEDF
D3DCDED2DBDCD3DCDED5DDDFD4DADDD8DCDFD7DBDED3D8DDD2D8DED0D8DCD5DCE0D5DCE1
D4DAE0D3D6DFD4D4DDCFCFD7C9C7D0C4C2CBC6CAD4CED7DFD0D9DFD1DADCD1DADCD0D9DB
CED6D9CCD3D6BAB6BA5F3A40620E157303087501067502077500067A0107800005850106
8802088802088801078A02098E050B8B02088902088A04098803078A03098E030A8C0109
8B01078A01058B02078C040A8702087A0609812E2F865557583B3F120506030001010000
0700011700003402044D04045403024D02024001023800001D810000FF00
00FF00633003330C0136120F5B3B397B65654E43430A01010B01010A01010800000C0000
1C00003502014302024601024A01034F01045602045B01045D01046201046801056B0108
69020961010467020575050A7C060B82080D83050C83030986050B83070E6F11159C7173
A5A0A2CCD1D3CBD2D4C7D0D2C9D2D4C2CDCD6B74741604055F1014930F14A4090EA90A0F
AB080FAD0A10AD080DAD070BB10B0EB20A0DB3090CB70D0FB70B0FB90C10BB0D11BB0D11
B90D11B90E12B80C0FBC0F12BB0E10BF0F13C31017BD0E14B00D129E13187710153F0407
1904031B1D1A5B69649AA8A5C2CECAD7DFDED7DEE0D7DDE0D5DCDED5DDDFD4DCDED2DBDC
D6DEE0D6DEE0D5DCDED4DCDED5DCDED3DADCD3D9DCD2D8DCD4D9E0D5D8E0D2D0DAC8BFCB
B7A7B5A78E9F936F828F6274905E7080576871647488929DC0CED5CDD9DCD0DADCD0DADC
CED7D9CBD1D48B7A805D1F267009107804087701057702067A0108800209860207870105
8A03098A03098A03098902088902088901078B03068E05079106098D02088F010A93020C
91030892040893040990030A8A050A780C0FB77374775154180204080101010101010000
0A01021F02043703044A01025202024A00003E01013600001A800000FF00
00FF00612D07340C054F2D286243447B63673D2F320A01010901000700000A0101100100
1E01003503024101014601034A01034F01045502065902075C01076100056800066D0208
6C02086C03096D020777050B7D050C82050C83050B85050A85050981060D6F12189B7277
A4A0A3CCD2D5CAD0D4C7D0D3C5D0D2CBD6D896A2A32424242D02047C14199F0E14AB0B11
AE0A11AD090FAC070DAF0A0FAE080BB1090CB2080CB60B0EB70B0EB80A0EBB0C11BB0C11
B80A0FBA0C10B90B0FBC0E11BC0D0FBD0D11BE0F17B3121898151A5E090D260101130E0E
4B555192A09BBECAC5D3DBD9D8DEDFD8DDE0D7DEE1D8E0E1D7DEE0D7DDDFD7DDE0D5DDDF
D4DCDED6DEDFD4DCDED6DEE0D6DDDFD2DADDD5D8DCD0CDD3C4B7C2B89CAB9D7081905363
7F32447F28397B1D2F7C192A761E2E5219261B0B1637444BA4B5B8CEDBDCCED9DACFD8DA
D1D8DDAAA3A962363E6A101879050C7902077701067A010881040C86060B8500068A0208
8B02098801078600068802088A03098B03088C03069004088F030793040B92010995030B
9302089603099C070E9D0A11920C10801D1ED2989A5B373C1F070A0A0202010000010000
0701021A01013601014C01015101014B01014000013800001C820100FF00
00FF00521F02431E14583A35654749331A201204050B01010701010600010A0101100101
1C01003301014302024701024A00024F01025400045700065D02086201076901066E0107
70010874020B75020B78040D82081184060D84050B85060B85070B80070C6C0F159D7176
A8A3A6CBD2D5C9D1D4C7D1D3C7D2D4C9D5D6B2C1BF57625F1003034D0A0E92141AA70C11
AD0910AB060EB30E15B61017AF090EB40A0FB60A0FB5080CBA0D0FB80B0EB90B10BA0B10
BA0B0FBB0D10BC0F12BD0E13BC0C11B90F14AA151D83131A4303051A05042E3231768482
AEBCBACED7D7D9DFDFDCDEE1DADDE0D8DCE0D8DFE1D9DFE1D7DCDFD6DBDED7DCDFD5DCDE
D5DCDED4DCDDD3DBDDD5DCDED7D8DDCDC3CBBCA1ABA0707D8F4A5B872D3F891E2D8F1824
8F121D8C0F1A800F196C111A43090F1A04091D23266D7D7CBBCAC9CEDBDAD0DADBCFD8DC
B9B8C07A5962681A21790A117D040A7801067A01077E02098203088301068802078C040A
8901088701068903098801088D040B8E04098C03088F060B92060C95050D95030B930209
96030A9D070EA0070FA10B11921014A44D4FA37073462227160104090101070201070100
0900001B00003F03045905065802024E02024201013A01013D080300FF00
00FF00562600552F225C3C3943292B1201030B00010902020501010301010802030D0100
1C01003503034302034802024C01015101025401045400045A01056101066701066A0005
70020874010A74010A77030B7F070F80050E80040B7F030A81040B7C03096E0E159E7075
A6A0A3CDD3D6C6CFD1C8D2D4C8D2D4C7D3D4CAD7D592A19D2227261E0103691216970F14
A8090FAD0810AE0810AF0910AE080DB3090DB6090DB90B0FBB0E10B6090BBB0E12BB0D12
BA0B0FBC0D10BD0E11BC0F13B00E159C171D5C080D2701021913145C66659BA9A7C0CDCB
D6E0E2D8DEE1D9DDE1DCDFE2D9DDE0D7DCDFD8DDE0DADFE2D8DDE0D6DCDFD7DDE0D8DEE1
D5DBDED7DDE0D5DBDDD0CED3AD919B995C698D34418C1D2A931522960F19970B13980D14
900E157D1319580F152703050F09092A38356C7E7BA9B8B6CFDAD9CDD7D9CFDADEB0BDC3
6F6B7557262F700D157E060C7B01067A03077F030985050A8603088803088C050A8C0409
8801078902088C040B8D040B90050D8D030A8600058300048902098F020A930209950209
98040C9D0610A20911A10F148A171BCE878A8F62654624271500020F02030F03030E0101
1903042C01024801025B02035B02034E01024201013A01003D080300FF00
2FDF0E5B2B025730224324211903030A00000500010301010100000100000500000A0000
1B01013302034100014701014B00015001015200025100015700025E00046600066A0107
6E010872020975020A77020A7B040C7F07107A02097A01087F030B7C030C680810926267
A49B9FCFD4D7C8D1D3C8D2D4C8D3D5C8D3D5CAD6D5B8C5C26874720C0B0B2D03047C161A
A00E13AD0B11AD090FAF090FB10B0EB1080BB6090CB6090CB80C0DB70B0CBA0C10BC0D12
BB0D10B90C0FB80F14AB141B86131B4504081A0506323735808F8DAFBDBCD2DBDCD9E0E2
D6DDDFDAE0E3D9DEE1DADFE2D8DCDFD8DDE0DADFE2D9DEE2D9DFE2D7DFE1D7DDE0D7DDE0
D8DCDFD9DCDFD8D3D9AB8A937E303B911B279C121CA00D159F0C139B0B0E960D11871016
6810143503061504061119164F615B7D908BB1BEBCD1DADBD0D8DACDD8DDA6B7BE566A71
1518222D0912610D1479070E7A01077B030781040789050A8802088A02089006098E0508
8902078A02098D020A8D020A8E040A8A02088400057E01048200048D020797040A9A070C
9502089B06109D081097101595383AD8A2A5966D724D282D270407270609150001110101
1F00013C01025501026002035B01024D00014000013700003C060100FF00
2EDF0E5C2C03502A1D2A0D0B1502011C0E0D0801010401010101010400000902010B0100
1800003202044403044902024A00014F00015200025501035A01046201076700086B0109
6F030B71010975010979020B7B030C7C040C7B04097B02087D01097A02096C080F864E51
9E9194D0D3D7C8D1D3C8D2D3C9D4D6C8D2D4CAD3D4CBD5D4A2ADAA353F3E0D030345080A
8A1116A40A0EAF0C11B00A0EB10A0DB30A0DB60A0EB70B0EB70A0DB90C0FBB0D11BA0B10
B80C10B41013A0151A6E0D133002031C1312606A68A0AFADC5D1D0D6DEDFD9DEE1DADFE3
D9DEE2D8DDE0D9DEE1DBE0E3D8DDE0D8DFE1D5DCDED8DEE1D7DEE1D2DADDD0D9DBD5DCDE
D7DBDEDCDADEBFA4AD843844961C259F0E13A40D11A30C129C0D118F1215721014450609
1A02020C0E0C273734687D768FA19AC0CDCAD0D9DAD0D7DBCCD4D9A1AEB6768A93475D62
0F1E220B040739070C6808107601087D03088102068602078D050B91070A8D03058D0308
8B03098A02098D01098D020890050A8901078300057E000382000391050898040899050A
97040A9D0A109C0C128A1316BD7576A57A7F815A612D090E3A0C10471317220002190204
2901034E05066604056B03055F01024F00013F00003700003D070200FF00
5ABC185F2E043510041E02001A04032917160B00010601000301000701010B01010B0100
1600003101024101024802024C01014E00015200025601045C0105600008660108690007
6E020971010A74020B79040C7A040C7B040A7D060A7F030A82040D80030B770B117C3A3E
9F8B8ECACCD0CBD1D4C9D1D4C9D2D5CBD4D6CAD2D5CCD3D5C6D0CD8C9794191E1D180203
5F0C12960D13AD0C10B10B0FB0080CB30A0DB30A0CB60A0DB70A0DB90C0FBA0E11B70C10
B1111697161A580B0C2203022D2D2A84918FBAC7C7D1DADCD6DEE0D6DDDFD8DDE0D7DEE0
D6DDE0D6DDE0D8DFE2D6DDE0D7DFE2D5DEDFD4DDDFD5DFE2C0C9CDB0BABED0D9DBD4DDDF
D6DBDECBBBC3995A658E1B25A01016A10C0E9D0C0F9510157A10154F080C2301030E0808
1C2824576C667E938CA9BAB5CAD6D3CCD6D6CED8D9CED8DCC2CDD2AAB8BD97A8AE869798
697A783B4444180203580E1472030A81030B87030A8601068903078E0609890205890106
8902088600068902068E02069003098D02098902088500058A020695040998040998060B
99060C9B080E971014882527E3ACAF8C696F78555B1E0104280307390E11230102210303
3102025101036C04067103046601025501024601023C00003E070200FF00
58BB175B2B03431B102D0E0B1801011502021002020800000500000400000601000A0100
1B01013603044100014700014F01035102015400015702045A01055F0208630107680106
6B01066F020A6F010A73020B76040B7602097C040980040B82040C83040D7A070F712227
A5878ABFBFC2CDD2D6CCD1D6CBD3D7CBD4D6CCD4D7CED4D7CED5D6B6C0BD636E6B0B0A0C
290104781116A00C12AD0A0EAE080DAE080CB1090DB3090CB60B0EB70C10B51013A51014
830E16420305190A094B544E9EACA8CAD5D5D9E1E3D9E0E3D7DEE1D5DDDFD7DEE0D8E0E2
D7DFE2D7DFE1D7DEE1D7DFE2D4DEE2D1DDE1BFCFD3A4B5BA9EADB0C5CFD1D4DDDED8DDE1
D0C8CF9D6D7788222D9D121BA00B119A1013871317600D112E0305110607151C1D4E5F5C
758A8497A8A3C0D0CCCBD7D5CED8D8CED7D9CCD6D8CDD7DACBD6D9CCD7DACCD7D9CAD6D7
BAC7C58B9795443B3D470D11740A1083030B8803098601068701068701058902078B040A
8802088501068802048C03068F03088F04088F040990030A92040B93040994050A94060C
96060C980A0F8B1214AC5E5FCCA0A38B686E66474C664E521802061A02062C1315230203
3503055205056702037103046601025902024B02043F01013C050100FF00
59BB184C1D01532B2230100D1600001200001101010C02000802010601000501000A0000
1B01013602034602044D01025202025602025500005501025700025C0103630104670105
68010568010767030B66040D67030971040A79030A7F030B81040C81040C7F060E6D0F15
9E7176ABA5AACBD1D4CCD2D6CAD3D6C8D2D4CCD4D7CDD3D7CFD6D7CCD5D3A4AEAC3F4748
0D03063E05098A151AA70E12AD0B0FAE090EB00A0DB50D10B60E11AF0D129E1217710E14
3301071E1618677171ADBBBAD2DDDBD9E0E1DBE1E4D7DFE1D5DDDFD6DEE0D6DEE0D6DEE0
D6DEE0D8DEE1D7DEE1D4DDE3BFCDD694A8B2627A8292A7ACB6C5C6D5DFE0D7DCDFD4CFD5
A77F89852A3697131B9E0F159311167310153E05081602011015134454517C8C8997A7A1
B9C8C4CAD6D4CCD8D7CDD8D8CDD7D9CCD5D7CDD7D9CDD6D8CCD5D7CCD5D7CCD6D8CAD4D6
C9D3D5C7D0D1959193592B30700D1487070F8A060B8602078602078501068902098A0209
8901078702068B04078F07098C02058F040991030993040A9001089001078F03098F0308
91050A8C080C7E191CD59D9D8763659573793F262C39272E13030919060C1F060A29060A
3502034F02016902027003036401015701014900013E00003E050100FF00
55B8164D20025A362A593A361901001402021001010A0000070101060000060100080000
1600003302034903064F02035202025501025601025901045D01055F0103630004670106
6701056102055002044200024200025B050A73060D7A020A80040B80040B81040B7C0E15
914F559E8D92CBD1D5CAD3D5CBD5D8CDD6D9CBD2D5CDD3D6CDD3D6CFD7D7C7D0D18B9696
1E24251502025B0D11961316AB0E12AF0B0FB10C0FB10B10AC0C139A141A620A11270306
2A292B849192B1BEBFD2DCDED9DFE1D8DDE0D9DEE1D8DEE1D6DDDFD8E0E2D5DEE0D7E0E1
D7DFE1DBDEE3D0CFD6ACB0B95D6D791B343E698086B3C3C6D3DEDFD7DDDFD9D5DBB7949D
893542951A2498131A88161A55080C2301010E0B0A303E3B70847F99ACA8B9C7C4CCD8D5
CED9D9CFD9D9CFD9DACED8D9CCD6D8CCD5D8CDD6D8CDD6D8CDD5D9CDD5D9CED6DACBD5D7
CBD4D7CAD2D5C5C6C878595D67111783070F8601088402068302048200038501068B0309
8C040A8D060A8A04078902048C01078E020A93040B9303099103088D01078C01078E0307
910609870E0F984A4BDDB5B76A4B4EAB8F9326131817080E13020918050C1E0309280105
3A00025C06066F05066F02046502025601004A010140010143070400FF00
53B71461360F5B382B4222201B00011602021001010B0101060100060100060000060000
1601013403044702054C00025001025301025601045B03065F0204620003650105680108
6802095B00034D010141010336010242010366050C77010A7F050B7F0308830509870B11
7F262BA17F84BCBDC1CAD3D6C9D2D5CBD3D5CCD2D5CED3D6CCD3D5CCD3D6CED5D8BAC5C5
74807D0D0E0C250203711015A01017AA0A0FAA0A0FA80F1590121952050A1F0405393C3B
99A6A4C3CECED4DCDDD8DEE0DADFE2D9DFE2D6DCDED9DEE0D8DFE1D6DFE1D5DEDFD7DFE1
D8D4DBC5B1BD8F7484443A46101D23607578ABBBBCD2DDDED7DDE0D9D7DDBB9CA5893B48
931D2892161E7314183804061505051F28256C7E7A8C9F9CABBDBAC9D6D5CEDAD9CED9D9
CFD8D9D0D9DBCCD5D7CCD6D7CED8DACDD7D9CBD4D6CDD6D8CDD5D8C9D1D7C9D3D6CAD4D6
CED6D9C8D0D3D0D4D7968386661D23830C138A040A890509850306830105850006860006
8A02088B040786010388010590040A93040996050A9302088F01088C01078C01078F0309
91090D811917D19A98BEA2A4786164BCA9AC190A0F1D0A101503061200031E01062D0103
4B05096305076B01026E03046301025400014A010141010045090400FF00
52B5125B2C06421E132103011A00011501010F00010A01010801010A0201080101070101
1400003302024802054C01045000025201025200015700015D0103620104640106680109
67000865010766030965070E5404094C000369060C78030A7E0308810307850207910B11
8211179A5D63A99C9FCCD2D5CBD3D6CAD1D3CAD2D4CCD4D6CBD3D6CED5D8CDD5D8CCD7D6
A8B7B2525E590A05043E06098A1319A30C12A2111684101847040A1A0707515A589BA9A7
CAD5D4D8DDDFD8DCDFD8DDDFD9DEE1D7DDE0D8DFE0D8DEE0D5DCDFD9DEE2DADAE1D8C6D1
AD808F8245574F23311D14196A7876A9B8B6D0DBDAD6DCDDDBD9DFBDA4AE8C43508E1E29
881920590C102402021513104B5955849793A3B5B1C4D1D0D0DADBD1DADBD1DADCD1D9DB
D2D8DBCFD6D8CFD8DACDD6D8CCD7D8CBD6D7CBD6D6CCD5D8CCD4D8CCD5D8C8D3D5C9D4D6
CBD4D7CAD3D6CFD5D8A7989D6C2931830D158E050C8B03088803088703078702068A0408
8C050A8B05088802048C020593040A94020896040A93010A91010A8F01098F030990050B
880E10954644E9C6C68A74788571748F828615080D1F0B101C06081B0105290407390104
5403076B04087202057102046502025601014A010241010041060100FF00
4FB411572B062505001B01011901021401020E01010900000700000A0100070000080000
1600003402034702054B00035202075501045701025901035E0204610105640106670108
6A00096E010A70010A6F02096B030A64000771050B7801087E02088102068A030796090E
8E0B1282272EA78087C0BEC3C9D1D4CBD3D5CCD4D8CAD4D7CBD5D6CCD5D7CDD5D9CAD3D5
C5D1CE909F9B1C2220240001740F1498151A7F12173F04081C101155615FADBBBACFDADA
D7DEDFD7DCDED7DCDFD8DDE0D9DEE1D9DEE0D7DDDFD7DEE2D8DDE2D9D0DBBC9AAA9A5668
8833435E1B27271015606866B1BFBBCFDAD7D7DDDFD9D8DDCBB4BD88475388222E821B22
48070A1A05062B312D7A8A859AACA8BCCAC9CFDADAD1DADBD2DADCD1D9DCD0D8DAD2D9DB
D0D5D8CFD6D9CCD4D7CDD5D8CDD6D8CCD7D8CBD6D8CBD4D8CAD3D7CAD4D5C9D3D6C9D1D6
CCD5D8C6CFD2CCD3D6A6979D6C2732820C158C050C8802078B050A8B050A8803078B050A
8F070C90060B91060A92040997050C95020992010792010A92020B92010A9001098D090C
7A1613C79190DEC6CA634E53A490925E505419090F2A141A1B020723040A2D0306430609
5603076B02077702067501046702035300014700013F000041070200FF00
51B4144E23051B01001500011601021301020F02010A01010902010902010802010A0100
1900013402044401044901035202065802065B01055C01055C01035E00035F0103660106
6B010871010C73010C71010972010876030B79030A7C02087D01078101078F060B97060D
970A1188121A96525AA9989FCCD0D5CBD3D7CAD3D7C9D2D6CAD4D6CCD5D8CAD1D4CFD4D7
CCD4D5BEC9C76669683B1115781C217215193503041E1514697471ACB9B6D2DCDCD6DEDF
D7DDDFD7DCDFD5DADDD8DEE1D7DDE0DBE0E3D7DCE0DAD8E0CEB9C6A26D7E883143862231
60151C220808656B69A4B2B0D1DCDCD6DDDFDCDCE1D0B9C2955764842530721821380309
170A09535C5A93A3A1ACBBB9C9D6D6D0DADBD0DBDBD0DBDCCED8D9D1DADCCED7D9D1D9DC
CED5D8D1D8DBCFD7DACED6D9CFD8DACDD6D8CCD6D8CBD5D7CAD5D6C9D3D5CAD3D7CAD2D7
C8D1D6C6D0D3CED3D8967D876B1E298309138A050B8802068902088B030A8903098D050B
8E040A8D040891060B94050C94020A94030A9002088F030891030A94040C93050D891011
8A3E3CE4C2C49E89917A6469BDACB06A5A5D1B06095C44491E030926050B2B01053B0104
5200036A010278010476010265010252000148010340000140050100FF00
55B61B4013001B0100120000140001190404130304080000060000060100050000080100
1A01013803054601034900025001035801055C0005600108610207600104600103630105
6A000770020B74020C77020B78020B7B020C7C010A7D00097E010880000690060B9C090F
9D080D940A13842029AD8289C3BEC2CBD3D6C8D3D5C7D1D3C9D3D5CCD5D7CCD2D5CFD4D8
CED5D6CBD5D4A4A4A3553334571B1E2E0506201A186F7A76B5C2BDD2DADAD5DCDED5DBDE
D7DCE0D5DDDFD4DBDDD6DDDFD9DFE1D9DBE2DACDD7B58D9C984B5B9124328F202B5B1016
260C0A5F67619FAFACCED9D9D7DEE0D9DADFCDB6C09C5C69882C3867171F2C0407251F21
75807FA3B1B0C0CCCDD3DCDED3DCDED2DBDCD0DADACFDBDBCFDBDAD0DBDBCED8DAD0D9DB
D0D8DCD0D8DCCED6D9CED6DACED6DACDD6DBCCD7DCC9D6D8C9D3D4CAD4D6C7D1D4C9D3D7
C9D2D7C6CFD4C4C2CA7E555F7314218707128C060C8A02088F050B8C020A8801088A0209
8C030A8A01078F050A94060C93030B8F02098D03088A03078C02078E03098B060A7A1212
BC8687D7C1C75D484F99858AC6BBC15E5258332022260D1124060C29040B310206470409
6105097704067F03047802036401015300024A010344010142040100FF00
4CAF16370B001F01001801001E01023B1A1C3118190C0100090201060100050100080000
1C00013C04064902034C01034F01035701065C0107610209640109620106620105640005
6901076F010974010978020A79020A78010A7800087B00097F020A84010792040B9C070D
A30A109D070F8E10199B4F57B1999DCCCFD3C9D3D5C9D3D5C9D4D5CAD4D5CBD4D6CED5D7
CED4D7CAD4D5BFC7C7656363120A0B1E201F7E8C89B9C6C3D1DBD8D4DBDCD4D9DCD6DBDF
D4DCDED3DCDDD7DDE0D9DCE0DDD8DFD2B7C4A76878942F3E9C1E2A941D245C0F13210B0A
66706BA1B3AECCDBD8D6DEDFDADADED2BEC7975A68882E3A65172027050936383795A1A2
B3BEC0CDD8D8D3DCDED4DBDDD2DADCD2DBDCD0DADBCFDADBCFDBDACED9D9CFD8D9D0D8DB
D0D8DDCFD8DECFD6DDCACCD6C6C1CDB1AEBCA6AEBAABBABFC6D2D4CAD4D5CAD4D6C9D4D6
C9D3D7CACED6A08D976F2C367D0D1587050D89040B8C040A8B01098C0109890108890208
8B02098B03098C02089004099003098E02098C0207880205880305880307830B0D7E302E
D9B8BABDADB549363CBBACB097919937333AB8AFB321101321060B2A04093B080C490206
6502067E04068202037902036601025501014A010146010145050100FF00
46AB143308002100002001013D1717784F533010121200000C01010801000601000C0000
1B00003903054802034A01034D01025401045A00065E0107620007620007640108670107
6A010771040A77050B7703097501087600087A03097A03087E010689010994040D9C070E
9E080E9D060E9A0B14881C24AC797FBFB6BBCDD2D7CBD6D8C9D5D5C8D5D5C9D6D6CAD4D5
CDD6D9BFCCD274878C132829112524718682B5C5C2CFD9D8D1D8D9D1D9DAD3DBDDD4DBDD
D4DCDED7DDE0DBDCE0D9CBD5BC909F9A44559C212EA41823931A20540A0C220D0B616D6A
9DB0ABCDDCD8D5DFDEDCDDE1D4BFC99B616C802A3460171E28080B51545499A8A8BECBCC
D3DDDED4DCDED2DBDDD3DCDED3DCDDD1DADCD0D9DAD1DADCD0DADBCED8DAD0D8DCD1D7DF
D0D0DBBCB5C1A5909F8560727E51656343573C3A495B6A73B2C0C2CDD6D8CCD5D7CAD4D7
CDD6DCB3AEBA7A4D5975141D89091088040A8702078802098901088B01098E040B8B0309
8C040A8902078B03088E04098D02078E01078D01068C040888020688090A751310B2807E
D5C4C89181896C595FD7CCD18480881C151EA3999F2D21251C070B2203072F0206460207
6A050A7F03068202037701026601025501004A000146010143030100FF00
44A912320700240001512A2D663B3F7C50563614171601010E01010A01000A01010E0101
1B00013402034201024601024B01025300035B01055E010560000563010766010A69000A
6B010871050A72020873010875010976010879030A7801068101088F050D98060E98040A
9A050B9C050C9E0810930F17954249B09399CBCBD0CAD2D4C9D5D5C8D5D5C8D6D6C7D5D6
C0CFD5738891142C32112A28627873B1C3BFCEDAD9D1D9DBD2D8DBD2D8DAD2DBDDD3DCDE
D6DCDFD9D8DED3BCC8A46B7A902B3AA11925AA151E93171B51070B230F0E6E7973A6B9B4
CFDDDAD6E0DFD9DDE0D2BDC89A5C6B842C375B131924090A5D605FA3B1B1C4D1D1D5E0E0
D3DDDED3DDDED3DDDED4DCDED4DDDED3DCDDCED6D8D1D9DBD0D9DBD0D8DCCFCDD8B8A6B4
A37B8E85495D74283B6E1E2F5B19282F0D19101118506163AEBDBECCD5D6CAD3D4C7D2D7
B7C3CE6F6A7858212D7D101889050A8A040A8A040A8B020B8C030D8C020B8B01098C0309
8A03088A03088902078C03078E03088F03088E02088C02078A0307830B0C7B2D2AD8B9B8
CFC1C6564046826B70BFB6BB948D9525111B4D343B1D090E1906091B0205290205420102
6B05088303078302047600016400015401014A000143010140030000FF00
46AB143208003510105D32385D2E3682565E38181C1201010B01000801000801000D0101
1B01013603054302034600014A00025401055C020560020562020563010767010B69000A
6A00066E030771020874020A74010975010975010878000881000A8E030D97060F98050B
9B060C9E060BA0070D9C0A1288161FA36970B9AEB2CDD2D5CCD5D6C9D5D5C7D4D4BFD1D4
7F959C152D3411282A5F7670ABBCB7CED9D7CDD7D8CFD8DACFD8DAD2D8DBD5DDDFD4DADD
D9D3DAC0A0AD984E5F911F2FA21420A7131B92181C4D0609220F0E6F7875A4B3AFCEDAD7
D5DFDED8DCDFCEBBC5985968882B3968192228090C666B69A8B7B6CCD9D9D4DEDFD4DEDF
D5DEDFD3DDDED1DADCD4DCDED3DCDCD1DBDBD2DBDDD1D9DCD0D0D7C0AFB9A27786843B4D
7E1D2F801929701521490A121F0207171516495956899A97C9D4D3CAD3D3CBD6D8B7C6CD
677A86171E2829060D670D1285090E8902088B02098D030C8C030D8A010B8A030A890208
8A04098701078901088A01068C02088D03088D04098B0208870408791011AC7372D6C3C5
A9989E4B30349984869B9499756A73412832492D331A04091704071B0305250001460204
7005098604088502057902036401015100004A02024301013F030100FF00
45AA12380A005C3334673D4254262F6D434C22070A0E01010A02000501000701000B0000
1B00003802044702044901044B00035301045801035A00025F0104630107650109670109
6A00066F020773050B7103097201087401097601077B01078602098E020A96040C99050B
9B050B9D050AA0070CA0090F9810178A2E35AA898DC7C8CAC8D2D4C7D4D5C8D7DA8EA2A8
21383F0C21255D716FAEBFB9C9D6D2CFD8D8CED9D9CDD8D9D0DADCD1DADCD5D9DDD1C7CF
AC7E8D8D3444971927A2101CA5141D8A151B460507231414707B789EADABCEDAD7D4DDDB
D9DCDFD1BDC6995A678D2B396F1A222E0A0D676A6AA8B7B6CDDADAD5E0E0D4DDDFD4DCDE
D6DEE0D4DDDFD1D9DBD0D7DAD4DBDDD5DADED4D4DBC0B3BFA98290853F4D84202E8A1824
7D131E5F0E16300307120707212C2A5B6E6C859795C4D1CFC9D3D3CBD4D5B9C5C97D8F97
677A81323F4513090C46080B7B0B108703088D03098C020B8A020C8B030D89020A8B040A
8903078A03098A020A8901088B02098B02098A0209890208850B0E7D292AD6B3B4CFC4C9
7563686F5759A79B9CB4B2B7615A6127161F19060D1B060B1B04062004062E0103520206
74040981010683020379020266010251000049000146010142020000FF00
41A60E431406774E4E6E464D48202727040A1400010E02010A01010600000901000E0101
2000013B03054902054C01044D01045101025601025C02055C02055E0208600107660107
6B01086E01076E02076E01077001077402087701077A000489030995050C950107970208
9C060C9C060C9F080DA2090E9E0A108E151B9A595CB2A4A6CAD4D5C7D5D8A2B3BC354C54
0A20245A6F6EAEBEBBCAD5D3CCD5D5CDD6D8CFD9DACFD9DAD0DADCD5D7DDC9B6BF9B6270
8B26359D1722A6131AA2141B84151B3D0306241718747E7EA2B0B0CFDADAD5DDDFDBDBDF
C4ADB8914E5E8E25347F1D24360808686865ADBBB9CDDBDBD5DEE0D4DDDFD5DEE1D3DADD
D4DBDED2DBDDD0D8DAD4DADED6D6E0D0C3D0B08C9C8D4B5D8524338B192488171F6C1017
3E050A18020311141341535072878393A5A1C2CECCCBD5D5C9D3D4C9D4D5BCCACBADBEC0
9BABAE8493955D5E5F43151776101588050A90060C8C02098B040C88020A8A030B880107
8901068C03088D030B8B01098B010989020988010887060A760F10AA7270D4C3C4B9B0B5
3926299A8788928F91BBBEC3443F4621131C19050B24080D3D1E212804073D06095E060B
7403078102068302047A01016801025300014A010248010247040100FF00
3FA50A562912754E4C49262A28070A1D00021200010A00010801010700010901000E0000
2000003901034702034A01034A01034E01025401015801035500035500035D0007640006
6901076D01076D02077003087403097502097500067C01058E050A99070C9B050A9C040A
9D070E9D080E9C060B9F050BA30A0E9D0F14892329A4787EC0BEC3B2C1C8465963071D25
4B6262A2B3B2C9D5D5CBD4D5CCD5D8CED6D9CED7D9CED5D9D7D5DCBA9DAB8C48588E202D
A0141EA511179A12197B1519370305271D1D828B8BA9B6B6CFDADBD4DBDEDADADFC6ADB9
934E5F8F22318E1E284A090C635956B0BBB8CEDBDAD3DDDED4DDDFD6DEE0D5DDDFD4DBDD
D3DBDDD3DBDED2D7DBD5D2D9BAA1B2996075862B3D8C1A2989162171141B46090C1E0104
0C090A2A36366A7D79869994ADBEB8C8D5D1C8D3D3CBD5D6C9D4D4C9D5D5C7D4D4C5D2D3
C8D5D6C7D3D4A8ABAC6F4C4F6E131988080E8F050B8E040A8B030A8A02098A0309880007
8901088B01088D02088E020A8C02098902098601077E0809752625D4B3B1C9C1C38E8287
462E31B8A8A88A8B8C93959A463E441B0B101E050A3713198C686C2A07093B03075E0408
7703078301068501067D02056A01025500014A000144000045040112C201
41A70A64361978524F2F10111E01011D01011602010E01010801020500010701000C0100
1F00003A03044401024601024500014A000151010156020356020359010562020A680108
6900066A01066B01066E000572010875020875000580020692060C9B050B9F050C9D050D
9B040C9D080E9C050B9F070BA2090E9F0A0F9011188D3E47AB949C6C767D071A213D5154
94A6A6C5D3D2C9D4D5CAD4D6CBD5D8CDD7DAD0D6DCD0C6D2B28B9A893848921B29A0121C
A30F179811196E0F152D02042A2425879191B5C0C0D2DBDCD4DCDEDBD8DEC3A5B0974B5C
951F2F981C25641217493232AFB7B6CFD9DAD7DDE0D5DCDFD4DDDFD6DEE0D5DCDED3DCDD
D5DDE0D7D8DED0C1CCA77D8B873C4D851E3088162577131E4E09102201030E070A1E2A2B
5D6F6F7F9290A1B1ADC4D1CCC9D5D2C8D4D4C8D4D5C8D5D6C4D1D2C6D1D4C6D2D3C8D4D5
C7D2D4C7D2D4CBD0D2A28F92672128810B138B060A8B04098801078C040A8B03088B0209
8901098C030A8E030A8D020891080E8A040987050A750E0EA56E6ECDBFBFC8C2C755424A
6F5659D0C5C495989894989A8D898B2B1E201B060A290B124121292C0A0E3A03065D0308
7B050A8703098702087D02066900015601004B0201430001450402238501
47AC0F6F41233F19162001021D00011F02021B03020F01010700010400010702020A0100
1C00013903044301034301034201024501014D00025503055904075B0106630207670106
6901066901056800046B010470010774020978010588050A97080D9E060E9E050E9B050E
98040B9C060C9D090C9B070C9B060B9C080E970C147F18217F555E171C213347478A9C9C
C3D0D0C6D1D2C7D1D4CAD4D6CAD5D7CDD9DDC7C8D2967282862D3E991724A31018A41016
941119690E152901042C2A2D869494B0BDBCD0D9DAD5DADEDAD7DEC2A1AE92414F9B1E2B
A419228820264018199C9F9EC6D2D2D7E0E0D8DEE0D5DCDFD5DDE0D5DEE0D4DCDED6DCDF
D9D6DEC0A5B4925367842637871C297716204E08102601050E0505131A18516160809494
93A5A6BECCCBCCD6D5CCD5D5CBD5D6CCD6D7C8D2D4C6D3D5C4D0D3C6D1D5C7D2D5C5D1D2
C7D2D4C7D1D4C8D1D3BDB6B9653238740D1387070B8806098603068A0407890306880106
8802088B03098E0509910807950E0F860206800B0D732524CDAEAFC3BFC4A59EA5341D24
816C6EC6C3C499A1A3AEB5B875757A30282C18080C1A030A1D030A2300053C02055D0408
7301068304098501077E03056A0102550001480001420100420101248401
4AAE125B2E132502001F01011F01021B0102160201110101090000040001020101060100
1801013603044807094E0D113F01034906084B000457060B731E2363080D640205660004
6801056700036700026800036D01087501097E01078F070C97060D99040B99030B95020A
97050B9A060C97040B97050B99060B9B080F950E1670111929040A2C333380918EC4D1CF
C6D0D1C7D1D3C7D1D4CAD3D6CCD8DCB2C2CA6A6D785929358A1B25A21016A4111693131B
610B132302063E3C3F939FA1B4C3C3D1DCDDD5DBDEDDD5DDC09BAA8E3A489E1D27A9171D
9F282B65282A7D7674BFCBCAD4DEDFD9DFE1D8DDDFD4DBDED3DBDED6DDE0D7DADFDACFD7
B7909F883D518622337D1A265A0F162A0306100506151C1C4656558698959BABAAB8C6C8
CAD6D7CED7D8CDD5D6CCD4D7CCD4D8CCD3D8C9D1D6CAD2D7C8D1D6C7D1D5C8D2D6C8D3D4
C5D0D2C7D1D4C9D3D6C4C0C5693B42710D1384060A8604088301048401038803078A0409
8903088A03058E06039C15118A05048104066F0D0D9F6C6ACCC0C2C0BFC575666D3E2125
8C7B7B9093948A9496868B9016141C180C131C060E1A030919000525010541020762050A
7201058204088502067F02036E0101590101490001410100410101268604
4BB0154318042101001F01011C02011000010B00001003020E0202050101010001040000
1801013604054504064905094701044E02065101055601075B0208610206650004680106
6801046A02056800046800046E020977020A84020A93070E97050C95020A97040B96050C
96050C95040B9302099402089603099408107E0F173F050A261D1C7D8B87BDCBC8C9D3D3
C6D0D2C7D1D3C8D3D6C9D5DBAEBEC84C606C111B27644149831F249E16198F14195A0B11
2104073F424395A0A1B7C2C4D2DDDED5DBDFDAD2DAB98E9D9339499F1A25AE151AA61D1F
B360617B6464B3BBB8D4DEDFD7DDE0D8DEE1D9DEE1D7DEE0D3DBDCDBDDE1D7C5D0AC798A
8734477C20315E121D310408130606141B194B5B598194919CADABB6C5C4CBD6D7CDD6D9
CFD7DACED6D8CED5D8CDD4D8CBD3D8CCD4DAC9D2D6CAD2D6C7D1D4C8D1D6C9D3D5C9D3D4
C7D2D4C7D2D4C9D3D6BDB6BD6B3840790F1789060D8602098603098703098702098C060C
8A0407890401A31D17900C078303037B080A712424CFB2B2C0BEC1BAB6BC3E272F6E5256
A89D9EA5ABAE8F969A6E6B7213070E28131A270A1121020823050A2701073F010765050D
7C040B8504088401048203057402025F01014D0000430000420201258503
40A60E3109002000001F01011C02020F01010800000C00000C0000040000020101070000
1A01013502044300034A02044F01035501045601045B01065F0106640205660106660005
6701046902056901056901056B010674000883020992050C93020995030A98060D96060C
93040A93030A93030A95050A94060D850B1251080C1C0B0B6F7A77B4C2BECBD5D4CBD4D4
CAD3D4C8D3D4C8D4D9A7BAC2435A650F273057666BA597997633367D1E22500B0D1B0608
454C4C9BAAA9BBC6C6D4DDDFD6DCE0D6CBD4AE808F923140A31A25B01217AF15199D2A2B
CF9C9CB3AFAFCDD7D6D9E0E1D9DEE1DADFE2D9DFE2D7DFE1D8DADFD2C0CB9E6B7D7D3143
64192838071019060B1317184254527F93919EB1AEB0C0BDCAD6D4CFD7D8D0D8DBCED5D9
D0D6DBD0D6DAD0D6D9CDD7D9C9D4D6CAD4D8C9D2D6C9D3D4C8D2D4C6D0D4C8D3D5C7D3D4
C5D2D2C5D2D3CAD4D7AA9FA663242F7D0B158B050D88030A85020987030C85010B860208
88030397150C9E1C138403037F0306710E0FA57371C9BFC0BFC0C58E848C32171FA08B90
B1AFB3B9C2C6A3A8AC80777C250F1524080E2D0B1229070E27080D2802073B00035D0106
7B030A8402088400058301057701036100004E0000450101460401278503
3AA20B2C07001F01012002011E01011701011201011303030D0201050101040001090000
1F01033C04064602034901034E01015301025400025C02066101076202075E0208600208
64010567010566000466000469000472000588060C90030993040A95050A930309910208
9104099104089304099203098A070D6C0E142403044A504FA4B2B1C9D4D3CBD5D5CBD4D5
CBD6D7C6D5D6A2B6BC415C6419343A697F81ACBAB9C4C3C362474A3610151A0B0E5A6666
90A2A1C3D0D1D3DCDEDADDE2D1C1CCA56E7E973040A51823B21218B40F13AD1A1DAA4C4E
CDB0B1BFC3C4D8E2E2D8DFE0D8DDE0D9DFE2D7DFE1D7DFE3C7C5CC8C6F7C622F3E3D101A
1A060C1012154957578A9C9C99ACACB2C4C3C9D8D6CFDCDAD1DADBD0D7DAD0D6DAD0D7DB
D1D8DCCED5D9CDD6D9CDD8D9C7D4D5C8D4D7C9D3D6CAD4D6CAD4D6C8D2D5C7D2D3C6D3D4
C3D0D1C6D2D3C5CBCF846A726B1A268207138B040F8A030A86010785020986030A860507
901107A82B1D8506038103067A080B702725CCB5B2BEC2C3C0C1C659474F44282EB9ABAF
7E848995A2A5979EA26D66692613171F060C32111827040B2301062A0103460407640207
7E050B860209870107820004790203650101510000470000460200248401
349C072B05002001012001011F02011B0102150002100000090000050000050101080000
1E01023C03044401024500024B01025202035300025C01065E01075501064A01044C0105
5C02076401056600056701056A010575000688040A8D02068F020692040893050A900209
8D01068F03089103088E050A790C123B04072F2B2A919F9EC5D1D1C8D2D3C8D2D3C8D3D5
C9D7DAA7BBC13C5860213F44778F91B4C4C3CDD8D8C1C9CB5D626611191C6B797A9FB1B1
C2D0D1D4DBDDDBDADFD2C0CA9D6271942534A81520B8161CB91317B91318AB1E23BA6A6E
C7B3B7CDD4D6D9E2E2D7E0E0D7E0E1D8E0E3D5E0E4C5D3DB777E892F27311C1116121516
3344427D9190A0B2B2B8C6C6C8D5D6CFDCDCD0DCDCD0DADBD3DADDD2D8DBD1D7DBD1D7DB
D1D8DBCFD7DBCED7D9CED8DACBD6D8C7D5D7C6D4D8C5D2D7C5D1D6C7D2D4C9D3D5C9D3D5
C7D2D4C7D0D4A89FA9723D4975101B84050E89030C8D050E8B030A870309820205820701
AF35248A10068003047E050A6C0D0DA47672C6C1BEBCC4C6ABA5AB351B206E5256C8C1C2
828E8F7F8E908A92944B494B180B0E1D080E22060D24030A2E070D37020854060B6E0509
7A01058502078502058201027B01036B00025900004E0101470101258602
3299042D05002201011F00011C00011800021401020D0101070101050000050101080000
1D01013B03044502034601014B01015201025601035C02075B02084E00054201033F0000
5000036101066801066900056C00067901098802088D01058F02059103079002098E0109
8D010890030A91040B880D12580B0F210F0E778181BECBCBC6D0D1C7D1D2C9D4D4C7D5D5
AABFC24E6A6F2341457A9393BCCCCBD0DADACED7D9C4D1D3788B8D7D9192A7B8B9C6D4D4
D3DEDFDAD9DED6BDC6A05C699A2331B11721B91016BD1015BD1115BF151AA91C21CE8287
C9B9BECFD5D8D9E1E3D8E2E2D9E2E1D9E3E5CCDCE3778F9A0D252F0A1E22344846849A97
AABFBDB6C9C8C8D6D6D1DCDDD2DDDED3DEDED3DDDED3DCDED2DADDD0D9DBD0D8DAD1D8DB
D1D7DBCFD7DACED7D9CFD9DCC7D5DAB1C4CC8DA2AD8195A18A9CA4C8D5DACAD4D6CAD4D6
C8D2D5C2C3CB86636F711C29810A1286070D88040B8A040B8B030A880408840702A32A1A
951C0D81050280040777070B722A29CDB4B2BFC3C3BEC1C67D6C743614189E8686C2C1C0
919E9FAAB8B89BA5A66C6D6E22161A1C0A0F270F162303092D040B3A03094D0103680205
7700038101048403048302037C01046E01025E0100520101490101248502
3197042F04002402012101011C01011501011100010E00010A0101060100040000070100
1A01013702034301034801024E01025301035801035C01045F01085901085503084E0105
5401046101056801066901056D00057F020B8E040B92020891020791020892020A92010A
92010A95040C920A107510162C0404595B59AAB8B7C5D0D0C7D1D2C7D1D3C6D3D4B4C6C7
90A7A94E6A6B829A99C0D0CDCDD8D6CED7D7CED7D8C7D4D69AABADABBDBFCCD9D9D4DCDE
DCDAE0E3C4CFA85866A82532BD1820C9151ACD161ACB1318C91316C91619BB2428CF7F83
D5C4C7D7DCDEDCE2E3DCE4E3DDE4E5D9E2E5A7B9C01E39402C464B869D9DBDD2CEC7D8D6
CFDEDDD3E0E0D5E0E0D7E0E1D6E0E1D6E0E1D6E0E1D3DCDED0D9DAD0DBDBCFD9DAD1DADC
CFD7DAD0D7DDCFD3DCBFC3CE969FAD5064731E3947556E7997ACB1C7D7D7CAD5D5CAD5D7
C9CFD69C8893722C39810F1987050B85030887030989030A8A03098A08049A1F10A82F1E
8307028305067E0608690D0CAE807DC8C0C0BCC2C5BEBAC1472A32431E21887876B8BEBE
7E8D8EA1B0B1A3AEB1868A8D38323715080E39262D260B112E080E3301054C02046A0507
7A02067F02058001047E01047801036D01025F01015201014A0200258301
3095022F04002502002201011D01021601011301021101020A0100050100040201080201
1801003403024100014901034E01035301035701035C01046101066402086203085D0205
5D01056501056A02066A010570000684020B92030C93010992010992010995030A95020A
96030A950408890D124F090B35282695A09FC7D3D3C6D1D2C7D1D3C8D2D5BDCACE92A3A7
8BA2A395AAAABFD0CECBD7D5CED8D8D0D9DAD1DBDCC8D5D8A7B5B8C6D2D4D7DDDFE1D8E0
E2B9C8B85C6DB92836CD1B23D6171ADE1C1DE11D1CE42122DF1E1DE42524D93535E38788
F1DDDEE4E6E8E3E9EAE5EAEBE2E7E8E4EAECA8B4B7859697CFDEDEDBE9E8D8E4E4DFE8E8
DEE6E6DEE6E6DDE5E5DEE5E5DDE4E5DCE3E4DEE5E6D9DEE1D8DEE0D6DEDFD2DBDDD0DADD
D6D8DFCCC0CDA891A46F5C702F2F41051624425B638BA0A4C4D3D3C9D5D5CAD4D6CCD3DA
AD9FAC783D4D7D131F8C09118C040A89030889040A8903098A0908921709B43F26891005
8003047D0206770C0D7A3532D0B8B6BFC1C1BFC2C6988A923A161B704E4E9D9694B1BDBD
7285858D9E9FA9B7BA2E363C0F0F1410080E1A0B111C050B2303083703085402066C0106
7A01067F02067E00057901037400026A01025E01015301014A0100248101
3096032D04002301011E00001A00001701011501011101010A0101050200020201050001
1902003503034000014601024A01035102045400035B01055F0106620105620105600106
6200056801066A00066C000576000587040991020994020894020897030A9B060C9B060D
9B060D93080B7714153009097B7D7BBFCCCAC6D2D2C6D1D2C8D2D4CBCED39490989CA1A6
9DADAEC0CFCFD1DCDCCED8D8CFD9DAD1DADBD4DFE0CCD9DABAC7C7D2DADBE6DBE1EAB8C4
C35768CD2E3CE3282EEF282AF02726F42D28F42E27FA3831F83A31F83D33EF4943EB8380
FFEAEBF8F7F8EDF0F1EFF2F2EDF0F0F8FAFBF9FDFDFAFEFEF2F5F7E4EAEDE2E9EBE8EDEE
E7EBECE6EAEBE6EBEBE5EAEBE1E7E7E3E9E9E1E7E7E0E5E6DCE1E3D9DDE1DADAE1E0D3DE
CEABBBA2697D6C364A32172712151F566B6F98AEB1C3D1D3CFD9DACED7DACED4DBBDB0BE
8C5467821829920C1790030B8F030B8B02088C050A890505890F01BD492D921C09820602
7F0205780407681211B38A87C7C2C3BEC4C6C3C3C5644D523B1719A8908EBDBEBDB4C2C3
8DA09F96A8A7B6C1C42B3035110C11170B0E17060A1904091E010436040858060D72060E
7A01087E01067F02067801037201026800025C01015200014C0101268202
5A75102D06002101011E02011D02011C02021601020F01010D0201060200010100040000
1800003403034001024401034A01035101045301035A00055E02065F01065F0004600104
6602076D020870020876040A7F030A8E050C93030997040999040A9C060AA1080CA40A10
9F080D9111135A1312554746AFB7B7C8D3D3C8D3D3C9D4D5CED1D5BBA3AD6C404CAF959E
B7BABCD1DADBD3DCDDD0DADBD3DDDED5DFE0D6E0E1D8E2E3D9DFE1ECE4E7F7C5CECB5966
DD3841F23235FA3232FE3734FE3C36FD4037FD4439FF4C41FE5043FE5645FC6457F0837F
FED5D8FFFAFCFDFEFDFEFFFDFEFFFEFDFDFDFEFEFEFDFDFEF7F8FBEEF2F4F2F5F7F1F2F4
F1F4F4EEF1F2EAEEEFEBEEEFE9EDEEE8EDEDE3E8E9E3E8E8E1E3E6EBE3EBF7D7E5D995A9
A44F64772C3E3B111F201C22728385ACC2C3C3D5D7CFD8DDD1D8DCD2D5DCC7B6C49E6375
8C1F329A0C1A9E071298030C96030C91030A9107098A0A01B44021A32E12870B01860404
810409750D0E824541CFBFBEBDC2C6BFC6CBB5ABB13F1E224F2B2BBBADAD929A9BAEBFC0
8EA1A19CADAEB3BCC028272D24181C5B4A4C1804091C050A2C0D1138080C470004600107
6F01047A01057C01047701036F00016601015C00015100004C0000278402
86531F2B04002001001E01001C00011A00021301010D0000090101050100030100080000
1B01013402024001014401024900015101025601035A01045D01065E0106600106650106
6F040B70010873010877010986040D94050E98050C9A050A9F070AA2080CA4080DA5090E
9F0C108C2021431817909191C7D1D2CAD3D5CCD6D7CDD3D5D5C3C895505C872D3CC4919A
CAC3C6D6DADDD4DCDED6DFE1D6DFE1D8E2E3D9E3E5E6EAEEFDF2F6FDCED6E36D7AE83D48
FA393EFF393BFF3B38FE3F3AFF463FFF4940FF4F47FF544AFE574AFF6151FB6A5DF2817C
F7C1C2FFF9F9FFFFFEFEFEFDFEFEFEFEFEFEFBFCFBFCFCFDFAFBFDF4F6F8F2F3F5F5F6F8
F0F2F4F2F4F6EDEFF1F0F2F4ECEEF0ECF0F0E6E8EAEFE8EEFDEBF8FAC9DBD2758CAD4358
7222313410184A474AAFBCBEC7D7DBCCDBDFD4E0E3D4DAE0D9D7E1D2B8C6AE687A9A2334
A9131FAA0911AA0910A6080F9F040C990509920B03AF3717BB45238C0D018E07048D0608
830A0D6D1818C4A09FC5C3C6BCC5CCC1C2CA806A7340161B7F5E5DB9B4B36F7C7EA2B5B7
7488897E90919BA1A529242A17090D2210151403071904083B1E22411519430206580103
6B01017401027700027601036E01026301025A01025302024E0101278302
8650202D04002101011E02011B01011801021201010A01010401000302000402000A0100
1E02013904034002024401014A02035001025701035B01035D0106600107640208680108
6F030A73010A74010A7B010B8B040E95040C9601089A03099F050AA1050BA70A0FA70C10
9C1115913C3E5A4545B7BFBFCDD7D8CBD5D6D0D8D9D9CED2BC858D972E3A892730C4999F
D9D4D8D8DDDFDBE0E3DCE1E5DAE0E3DAE1E6DAE0E5F0E9EFF4C1CCDA5F6DEC3B47F83037
FC3136FC3235FB3432FD3D39FC403BF9413BF9453FF7453EF94A40F64F41F55E51EB7C76
FFD8D7FFFCFAFEFEFDFDFEFDFDFDFDFAFBFAF4F5F4FAFAFBF3F3F5F1F2F5F0F1F5F1F2F6
ECEFF2E7EAEDEFF1F5EEEFF3ECECEFF1EDF0FCEAF4FBC9DBDF7E98C64D6AA0334A5A1320
31181C767B7BCFDDDEDDE9EED4E0E6D5DEE4D5DAE1DAD4E2E4C2D4B76477AB2535BC1821
BE1216B90D11B50B11AF090EA90A0CA00D04A9290AC9522995150292060497060A90080B
7A0F0E9D645FD4C6C6C4C9CFC2C7CFC6BDC7522D38491A1FB39999BFC1C2A0ADB0ABBCBE
7C8E9079878A83878A1D191D11060A1004070F01031500021C00012A02033D00015F0305
6F02047501047801047502036A01015D00015200014E00004D0201288402
8551212B04001E00001A00001A0001170101110101090100010000010000030100080000
1D01003803014201004601014A00015000025700035D02076102096201076501066B0008
72020C76020C78010C82020E91040F9B060E9E060D9F040CA4070FA4060CAA0A0FAA0D11
961618955254877D7EC9D1D2CCD5D6CED6D7D6D4D6DAB7BD9B465189262F46080DA49598
D8DEDFD3DADCD9DEE2D9DDE1DBE0E5D9DFE4DCDFE4F4E1E9CE727FDE3743F52B31FD2D30
FB2B2DFB2F2DF9312EFB3935FB403BFD4B46FF514CFD4E48FE524AFB5449F86457F5938B
FFE7E4FFFDFDFDFEFDFDFEFDFDFEFDFDFEFEFCFCFCFBFBFCF7F8F9F4F5F7F3F4F7F1F3F5
EDF1F3E9EBEEEDEDF1F1EFF4FCF2FAFFDDEAEE94A7DD586ED3425B891A2E4C1420504245
B1B9BADAE7E8D6E0E3D6DFE2D6DEE3D9DBE4E2D2E2CF9EB3AF4D65B52438C61824CA151A
C71317C20F15BE0E16B80E11AF1106B52C09DD6031A62105A00D089E05099A070C8D0E10
873630D7B9B3CAC9CCC3CAD0C9CAD199828C491620552629BFAEB0BCC3C7A5B3B7B1BFC3
A8B6B89DA9AB969A9E1E1B200D03070D02060E01041C04062804053501034B0003650205
7403057600027901047301026700005901005000014D00004F0201288201
7F4E202803001E01001C01011C01011A02031302020A0101030001010101010000070000
1D01013A02024700024D01024F01025300025901045E01056201076501056A01066F0107
76020A79030C7C010A8B040E9C0710A2050DA6060DA9060EAB070EAE090DB10A0DAE0E12
9B2325B37D7EB5ACADD2D6D9D1D5D7D7D9DBE0D4D7B68890722B33420A1016060A8E9497
CED8D8D2DBDDD4DCDED7DDE0D7DEE0D6DDE0DCDEE2FBDEE6CE5D68EA3339FC2D2DFF2F2E
FF312FFF352FFF3A34FF3D36FF413CFE4642FF4D4AFF4F4AFD4C47FF554FFE6862F8928F
FFE5E5FFFCFCFEFEFEFDFDFEFDFDFFFCFDFFFBFCFDF8F9FBF6F7F9F7F9FAF1F2F4F1F5F6
EDF0F1F0EEF2FEF3FDFFE4F3FBB4C7E97083E8505DE54C569C29324E1B22948F93E7F1F2
EDF8F9D6DFE3D8E0E4DBE0E5E0DDE4EED5E3CA869AAC384DBE2234CA1723CB1218C91216
C10D12BF0D14BB0C11B41009B62607E3612EB62D08AC1306AC090AA9090E9D0D12811A19
CA9995D2CAC7C7CCCFC6CAD1CDC2CB683E4851151A79504FA7A0A1ACB8BD77888E9BABB0
B1C0C3B2BFC19DA4A70E0E11160D111003081002051701032602023F0508550307680306
7602077800047800037101026701015D01015401015001014F0201288201
77461B2804001D00011C01011C01001A01021100010A0000080100050000020000080000
2102013F03044E01025401045602055700035C010361010566020669010670020878040A
7F060D870B128A060D9B0911A60910AC080EAD050DB0060CB2090DB70C0EB70A0DB41114
AD3A3DE8B8BBD0C5C7D6D7D8D1D4D5DAD7DADDCFD0674D4F2A10151E1418707779C7D2D4
D5DFE1D2DBDED3DCDFD7DFE1D8E0E2D8DFE1DFDCE0F6C8D1C0434EE72C31F22526F62828
F62726F92D29F72B27F82D2AF82F2BFB3632FB3837FD3B3BF93838FA3C3DF8494BE8666A
FED1D4FFFBFCF3F4F4EDF0F2F1F4F6EBEEF2EBEEF2EBEDF1E9ECEEE6E9EBE7E9ECE9E7EB
F6E7EEFDDCEAF0A7BEDE6782E64B62E23845D13B3EEC8A88A27372C0B8BBDFE8EBDDE6EA
D8DEE3D7DEE4D9DCE4E0D6E2E7C1D1C36F82B33042C21E2CCB1720D0171CCC1318C91317
C21114BD0F13B21008B32405E4642EBB350BAD1304B50E0DB1080DAB0D11931718B97471
DDCAC8C9CCCDC6CDD2CDCBD3A2859156192465282BC8AAA9C0C1C0B0BFC0778B8D849799
B1C0C4B0BDC17A81850C0B0F10070A13060A1404071402031D02023203044500025F0306
7102077801067600037002026700006001015902025001004D0201258200
7443192603001C00011B00011C01001A02011201010F01010E02010B02010702010A0000
2501024402045301045701045701045B01046001056501066800066E020879060D850C13
90131A95141A960D13A40C12AD0A0FB20A0DB5090EB7090FB70A0DBE0E11C10F12BA161A
B6484DE4B8BED3CACED3D5D7D0D4D6D9D6D9C5C0C02D2F2D262F2F8E9A9BC4D0D0D0DADE
C7D1D6CFD8DED2DCDED4DEDFD5DDDFD5DBDEE1D9DFD498A2B7303AD41D23DC191EDF181D
E31C1DE21B1CE31C1DE52021E31D1EE82021EC2326EB2326EC2425EB2426EC2D33D53F46
EEAFB5FAF1F5E7EAEDE3E7EAE2E6E9E4E7EBE3E7EBE3E7EBE1E6E9E2E3E8ECE0E9FAD8E4
E097A7C9576DCB344CD42538DC2430D1292EDE7173F6D0D0D4D2D4D1DADDD1DADFD6DDE1
D5DADFD3D5DDD7C8D5C996AAA34157AC2032BB1622C3141DC21117C10E14BF0C12C01015
B80D0FB0110AAC2204E26A30BB4010A71702AE0C0AB1090FAB090F9A1013A74F4EE4C2C3
CCCACDC3CBD0C9CCD3C5B6C061303D5B171EA67676D3C7C7C2C9CBBBC8CAABBCBEB4C3C6
A1AFB29EABAF6D7478120D121C0D101504061402041501021B00002F03046A2A2F540002
6A01057400047301026F01016701016202035801014D0001490101238000
6F401A2303001900001E01012302011E02011401000F01010B01000801000702000E0101
2501024402045401045901045900025E01046501056B010771020978040C7E060E8B0F15
94151A900D1293080DA60B12AF090FB1080BB6090DB90A0FBB0B0FC00D12C20E13BC191E
B4484DE7BEC2D2CCCFD3D5DACFD5D8C6CCCF656F6F3E4D4B98A9A9B3C2C2C9D4D5CAD3D9
BAC5CBCED8DCCFD9DAD1DCDDD2DCDDD2D8DBDECFD5AB616BAE2129C5151BC91217CC1317
CB1215CB1215C91115C81318CC141ACE1217D21418D51618D8191ADA181CDD1E24C52C34
E2959EEEE0E6E1E5E9E0E3E7E1E5E8DFE4E6DEE2E6E2E6E9E5E0E6E9CDD9D998A9BA4E61
C23143C8212ED01C28CC161DCA171BB92025CD777DCEBEC3CAD3D8D3DDE1D0D9DBD6DBE0
CBC8CFBCA1ADA3607397293DA71629B3101FB40C16B50D14B30B13B00811B20A12B00A0F
A80C08A21B01D36327BD4E179A1601A00906A7070BA6070D9D0E128D2929E0B2B3D2C9CD
C6CDD2C4CBD1CFC9D18B667353131B6F3435CAB1B0999C9FC1CDD2ACBAC0A7B5BDBBCAD0
95A4A8AAB9BC868C8F392F35523A3F280C101B02051E01052D05083403054905095E040A
6E02077301047101026C01016701016001015700004E0101470000238100
6D3E1A2202001A00002101012602022002021301000B01000601000400000601000D0000
2400024604065601045E01066100036501046C020770020878060C7A050C820A11890D12
88080E8C070E94060DA50912AE0810B2080CB40A0DB80A0EBA0B0FBF0D13BE0D11B8181A
AB4044D8B2B5C9C6C8D0D4D6CDD6D8B0BDBE8999999FB0B0AEBDBDC5D1D2C8D3D6C2CED4
AAB6BBCFD9DBCED8D9CFD9DACED8D9D2D7D9C5ABB28D323CAE1A21BD1316BD1013BB0E11
BF0F15BF0F16BB0E14BC1016BE1115C11014C91518CB1517CE1519D2161CD2181EBC252C
DE9198E2D5D9DFE5E8DEE2E5E3E7E9E0E4E6E4DFE4F1DAE4EEB7C7C05F72BB2F41CE2331
D01A21CE151BCB151ACA1519C51418B11B21BE6B74CABCC2D0DADED4DDE0D4D5DCC9BDC7
AD828F953D4E9E1E2EA8121FAC0C18A60512A80811A6070EA5060DA5060FA2040AA20A0A
981201C2571CCB6624931D01960B069A04099E060C9B0A0F861616BF8683D7C9CAC8CCD2
C5CCD2C9CAD0B29AA4571C275A171BB78F8EBEB7B8949EA1BFCBD08E9BA38D9BA59DABB3
84949AA3B1B795969D2C1C243D20284B29303310162A050A2E0308340102470103600106
6F02067100037000026C01026600015F01015801014F00024A0102470401
6936132704001D01002000002302011D02021401010F01010B00000A01010900000D0000
2601034803075A01046301056702056C020572040975060C97282D9724287E060A7F0308
82020A87010B93030DA80914B10911B2080DB3090DB60D10B5090EBB0D12B70C0EB11516
9B2F34C9A3A7C0C3C4CBD5D6CAD5D5ABB9BAA8B7B8BCC9CAC7D2D4C7D2D7C1D0D7A2B3BA
ADBCC0CCD7D8CCD6D7CFD8DAD1D9DBD1D0D5A3757F92202BB1121ABC1115BB1013BD1114
BE1115BE0E14C01218C01316C51414CB1515CE1414D71A1CD8181CD7171CD81B1FC93134
E79DA1F2E5E9E2E7EAE2E7E8E6E5E8F2E4E9FCCED8DD8191C94154D72D3CDF232CE62225
E11E1EDB1B1DD21517D41919D31B1BB91D21CF7C81D1C2C6DADEE4D8D0D9C8A6B5B26D7D
9A2B3BA91925AF0F18AE0A12A9070FA3040EA1060DA1070CA1060BA0050C9D0609950E02
AF440ED67A2F9328048D0C0291050791040991040A8A0F118E4241DDC5C4C8CCCEC4CDD2
C5C9D0CCC1CB7245515F171F7F4648DAC5C5C5C9CBBFCACCC0CBCF95A4A9A3B2B7AABABE
83949A8C979F3A3741341F2A3F222B32151C47272D3513172701033601044F0205680205
7100067301047001026C01026600015F02015701005001004A0102480501
6A36132A04001F01001E01001E01011700021301011402021402011303020E0101100000
2501024B04075F01066800046B0105710307720207851018A62E36991B2283060B7C0106
81030B88020C91020BA80C15B10C13B30B12B10A0FAE080DAE080DB20B11AF0A0DAB0F12
8E1B21BD8C93B7B7BBC8D4D5C5D2D3C3D2D2C6D3D4C8D2D3CCD1D7BBBFCB84909D7D8E97
B7C6C9C9D4D5CCD6D7CED7D9D5D9DDCEBCC290454EA71A23BC1016C31014C51014CA1417
D0181BCF1618CF1619D41A1CDC1F1EE62422EB2624EA2322ED2725EF2928F0322FDA4644
F3B7B8FDF8FBEFF1F3EFEFF0FBEEF2F7C2CADC7078E0484EEC393CF33232F4312DF8342E
F22C25EE2821E7221BE9241DE3211ECD2D2EE39394E8D2D7E1CAD5DEA1B3B3495CB62636
BC1621C1121BB90C14B50911B20A12A8060DA10409A10709A1080A9E0509950B03A33406
D9812BA8490C8910018E06058F04098C040A87050B791619C59698D0CACCC1CBCCC2CCD1
C7C8D1B49DA85416216319209F7577D3CFD0BCC7CABECDCFBAC9CBB6C6CABBCACE9CAEB0
8F9FA28C93991B111B462D3A482E3A1C0B13907F835A3D432F03083F0004600409730308
7702057400037101026C01026601015F02015702004F0100480101470502
6433122702001F00001F01011D01011600011400011701011A0102150100110101140101
2600014B04076404076900046E020672020774010781050F8E081192091284050C760007
81070F8C0B1491070FA40C15AA0A13AC0A13A90911A5050BA4060BA4060AAA0A0FA4080E
941019A45761B69FA6CCCFD3C8D3D5C6D1D4C8CFD5C8C3CDB7A1AE785E6E24212F808D95
C6D4D7CCD7D7CED8D9D0D9DBD9D5DBCFA1A99C2C34BD171DCE1517D71819DE1A1AE01C1D
E31E1FE92322EB2524ED2B28F5352FF7352EF7332DF6352DFB3E34FA4437F95041E76A5F
FFD5D3FFFCFCFCFDFEFFFAFCF1D7DBDF9BA0E67775F2665AF85A4CFC5647FB513FFD4E3C
F94231FC4130FB3C2BF9392AF2342CDF3E3DF9A9AFFFD3DFEB94A5C93E50D52635DE1C25
DD181ED5161ACF1519C40D14C00D14B90C13AF090EAA080BA60707A10E059A2402D37B23
C66E1C8B1B01910A069004088F030A8A040B800D13884143DBC5C6C7CBCDC1CBCEC2CCCF
CDC8D0724E5859131D6324269E8585C5CBCE92A1A5B4C4C7A7B9BC95A8ACB3C6CA92A5A8
ACBBBDB6B8BC3C2D342C0F1A1D0311271C27968F98513B423D0B125204096A0309760207
7B02067701037000016A01016401025E01015601004D0001470001430401
6232112804002001012101012101011C00001A00001D01012002031A0101160101170102
2300014603075F02056801036D020672020773010874010881090E80090E74060C6B0107
7A081084080F8B040C9E0A15A40C14A40B13A209129F050DA0060C9B0106A4080FA4070F
9D0914911B26AA616DC4A1AEC6B5BFC0AFBBBB99A7A86F808A3B4C63243234222CAAB3B7
CCD9DBCBD7D7D0D9DBD4D8DCE3D0D7B76771BC272ED61D1FE21F1CEB221EF12621FA302C
F42926FE3530F8312BFD3E36FF483DFF493DFE4A3FFD4D41FE5545FF644FFF715DFB9285
FFE0DFFFF7FEFFF8FFFFF4FFFFEFF9FFE1E8FFBFBDFFA396FF8776FF7865FF7460FF6551
FE5743FF5744FC5742F55443F45048EF5051FA7B86EB6A79E34250F1343CF5292DF62529
F02224E81D1FE31D1DDA1719D11216CD1318C20F11BC0F11B10F09A62000CF6D18D98424
9B3204950E039A070998040A92040A89080C751618C49898CFC9C9C4CCCEC2CCCEC4C9CD
C2B2BA521F29570F18845655C1B9B5C5CFD1A4B2B6BAC8CB96A8AB86999C899EA0849B9D
9FAFB1C5C8CD5B4D55270A161D010F1F0D1B4F45513D2C34885A605403096D040B780107
7E01067C01047200016A01016200015F0102590201500101480102450400
5F30112904002201012301002603022402012201012100012401022101021A0101170001
1F00003B02045A04076601046A01037002066D0107630003761F21B364656F1F2360030A
71040B790209840208990A139D0A1499091294060F9907119B060B9E060AA1060CA3060D
A4070FA40D189C1929A0374CA64E629D44559F3343A21F309A1D29580F16645659C5CDCF
CFD9DAD1DBDED2DBDDDADADEEBC2CAB6444ED12328EB2524F22723FC2E29FA2D26FF322B
FC2E29FE342EFE3731FD3A33FE4038FF4940FE5047FF584EFC5346FC594AFE6458F67774
FFB5BFFEC8D9F6B3C6F5ADC1F3A4B7F193A3F28187F3716DF86A61FC6459F6564AFC5347
F95144F0594BF57A6FF99A94F79190E76166E94751F43E48FC393DFF3333FD2D2DFB292A
FA292AFA2A29EE2120EA201FE11C1DDB1B1DD11417C91714B51F04D06314E89125BB540B
A11902A70B09A5050BA5080F9C090D850F0F8C4846DAC8C5C9CECFC3CDCFC6CFD1CCCBD0
9E7F88530F1B57121A9A7B7CB8BABABBC7C9BAC7CCB8C5CAAEBDC19AADAE9CB0B1829699
8C9CA182858F2D1F2A240A13290B152106131C071348303AA06F775B040D7101077F0208
8402078102067601016B01016602026201035A01024F0102460102490702
5E2E102902002301012201002601012801002801012801022A02032601021E00011A0102
1C00003100015103066202046901026F04076A01056305086B23267B424668272D610710
6D010876010586040995050F9B081489020C7F010791091098060BA1070CA2060CA4070D
AC0B11B00A12B10E18AF121FAD1521B1161FBB141DBD141BA31B22420408A39EA0CFD8DA
CFD8DAD2DBDDD6DDDFE5DBE1DF9FA8C3363EE32728EF2423F42524F62524F92925FD2B26
FD2A26F92A26FC302CF72E28FC372FF83730F43933F7423BF8453DF74940F24A42EC5251
E36269E2737EE07680E27B84E0747DE36B70EA6563EC5F55F25C4FF04F42F34C40F44C40
EC5248F38078F9ABA8E8A1A5ECA5AAFFACB0E76166EA353CF93132FA2C2BFC2B2AF92729
F32223F0211FEA1D1DE21819DE181ADB191AD41B18C6230BCD550DEB9222DA7919B02A02
B7140CB60C0FB40A11B10B12A30F1285201ECEA5A1D0CDCCC5CFD0C4CFD0C7CDD0D1C7CC
6C3D4660121B6221278F7B7E8A9396B8C7CB99A9AEB2C1C8ADBBC1AEBEC4B2C3C987989E
A9B4BD36323E2A151F3B1D2245242935131C2907122F040F500A157209127D0207810105
8300057F02047A01037102026B02026501035D01034C0102420000450501
5C2C0F2A02002400002400002A01012E02022D02022A00012901012702012001011D0001
1F01012A00014702056104086A02066D050867010566080C86373D914F567C323B64050D
7002097901078E080F9F0D15A00D1691071083020690050B9F080EA6080EA9080FAD0A12
B40C12B70E11BC0F12BF1013C31112C71211CD1414CC1C1C991C1D431618C6C6C8D1D8DA
D3D9DCD2D7DBD8D7DDE8C9D4B75662CD2A2FE52321EE231EF1201FF01C1DF72321F82723
FB2A27FA2B27FD342EFC372EFD3B2FFD3F35FD433AFB483EFC5047FC574DFA5F54F96F67
F98582F99EA0FCB8BAFEC9CDFFCBD2FEB9BBFEA29AFD9080FF8773FC715DFE6A59FC6556
F88378FFC1BCF2B9BAE7A5ABE5A0A6F7AFB6FCA3ABDA3E45FB393CFB2E2DF82727F52326
F42222ED1F1CEB1F1EE01718DD1719D51713C21B05C74A07E38918E0871DB33802B71707
BD0E11BB0B14BA0C14B60F149E1819B16564E1CDCCCAD0D1C6D2D3C4CFCECDCED1B89FA7
5B1A236312189C696A988F908D9A9CB2C4C6728387AFBEC489989F899BA29FB1B884949B
B5BEC7322C35341A22411D23431F253D151D3C081251091464040F79030B830007850106
8301057D00037A02037401046D01046700025F01024F0002450102450501
612E122F03002A01012B00013101013402022F0101290101280101270101220101200102
2403032801023C020558040961020661010460010561010762070D670D1464060C6A0108
74020980030D9E111BB11922AD131AA50E14A10B10A1080CAB0B10AF0B11B00910B70D15
BA0C13C21214C61311CC1513D11813D41814DF241FCF2623851A1A5F3F42CECFD2D5DADD
D2D7DBD1D6DADED4DBD69DA9B93842D72426E92421F02520FA2A26FA2824FC2724FF2E2A
FE302CFE322EFF3631FF3C35FF3D36FE3F37FF453CFF5047FF5349FE574EFE5E56FE6A66
FA7073F8838BF794A3F7A0B3FAA6BCF796A7F98289FB7675FA6B63FD6257FC5B50F25951
F58D8AF5B8BCF2C1C8F1C0C6EDB1B8DB939EFCA8B5DE545DF1393DF83132F92D31F7292E
F6272AF12624EB2321E82021E01E1BD1210CC94106EB8E1FE29019BD4C06B21904BD0E0E
BE0C13BA0913B80B12AD14169B3231E7BAB9D5CECFC8D0D2C8D3D3C7CFCFD6CDD17E4E57
68151E661C1FCEADAEC1C2C4B6C3C5BAC9CBA4B3B5B9C8CA8B9BA07A8E947A8F947B8D93
8D999F2E2C331E0A1328070F502D35350B15571B236C151F7709137E020B89020A8B0209
8601068000037B01037501047001036C0203650203560202460101430401
622C113303012E01012F01013502023702022F0101280001270001280001270101240102
2303041F00012E01034903085100035300005900025F01036601066A00076F0108740209
7B030C8D0813A81721B41921B01117AF0F13AD0B0FAF090EB1090FB30910B80B13BC0D14
C11014C71214C91110CF1512D01310D21513D31917BC202159070A857578D6DADDD4D8DB
D4DADED4D7DCE8D1D6B56169C12C34D82225E01D1FE92121F22826F22322F72523F62521
F72523F72423F82825FA2C28FA2C2AF32726F8302FF93433F32E2AF83632F53433F43539
F13640EF3947EE3E51EB3F56EA3F58E93B51EA3748EA323EEA2F36ED3134E92E2EDC3235
E0696FE7A3ABECB6C1E9B4C0F4B7C2BA747FF6A3AFB93A45CB2027D71D21D71A1EDC1B23
DB181FD61419D31516D41817CD1C10C23303E8861BE19519C8670FB22403C21611C41114
C21016BC0D13B512159B201DD2928DE0CFCECED0D2CBD2D5C9D2D4CDCDD2BA9AA36D212A
6F11188B4E50CCBDC1A2ABB2BCC9D0BDCBD0C0CDD0BECACDAFBEC1ABBCC09EB1B57E9195
88979D282B32230B1345161E3A0F192C060F4C1A214F050C7009127E010B8A020B90030C
90030B8B03088201037901037201026E0102690102590202460000430401
6630133504012E00002D00003401023602023101012B00022A01022E0203300406240102
1A01021501012000013D02054B00035000015801016001026800057102087601097D030B
880710990F18AB161DB11217AF0C11AF0B10AE080DB30B0FB70B11B60810B80812BD0B14
C00C12C71013C81011CD1312D01414CF1315CC1B1F9E1B2040090DB0ACB1D4DCDFD1D7DB
CFD5DBD6CFD6B987909A2C35B41C22BC1317C51317CB1216D21417D61215DE1515E21516
E91A1BED1B1DED1C1DF12120ED1E1FE81A1DE41719EA1D1FE91C1DF02322F02524ED2427
EB2127EB232CE6202AE31D2AE51F2DE6202EE01B27DE1A24E62028E41F24E21F24D42128
C13B43F6AEB6CE96A0BC7F8D9C5E6BEFB4BDEA9DA69D202AB5151CBE1418BE1217BC0C14
C10E15BD090FBF0E11B60D09AB1C01D67316D99411D3851AA12C01AC130BB30B0EB60D11
B30B11B41114A31918AB5753E6CBC6D2D3D3CCD3D7C8D0D5C8CED2D4C5CD854A5677161F
721A1CA77E7F99989E8A979FAEBCC4ADBBC3B0BDC4BFCCD2A6B5BABAC9CFB1C1C795A7AC
ACBABF221D25370B15651D274507112D040C2D070D3600035E060D7A050B830106890108
8E020993070C8E06098203047600016F00016B02025D03024C0102480602
6935143707003202012F01013100013401013601013101012C00012E02032F05071D0102
1000010D01011A00003C05074D02045101015901016400026C00057602097D020B83060E
8A0811970B13A91015B00D11B00A0FAD060CAF070DB1070CB5090FB6070FBA0913BB0812
C00C12C50F14C71013CB1315CA1214C61215AE151B62090E412B2EB6BCC2CCD7DACBD4D9
D1D3D9C1A3AD8B374399171FA51015A90C12B30F14B70D10BE0D11C60D11D21214DF1A1B
D81214E31A1FE1181DE1191CD81113E1191CDF1617E41A1BE51A1AE61B1BE61D1DE11B1B
DC191AE32023E52224E11D21E52027E31E27E11E25DF1C22E01C20E82225E62125DC1F24
C7262EDC6D76F8B2BED794A2DC9AA8F6AEBBB24853A81821B8171CB61115B30F13B20B11
B90F15B80D11B50F0DAA1A04C45B10D69314D29517A44B079210019C04079E040A9C0307
9F070B9D0F11831E1BD7AAA9D3CDCDC8D1D2C7D0D4C6CED3CCCBD2B5959E6B1C27751319
965452DAC6C4B0B6B89AA6ACBECAD09DABAFA8B6BCB1C0C68B9CA2A1B2BA9AABB39AAAB1
A9B4BA20131B42111A58131C420812340912390E173900065E050D7102077801047F0104
8502068901068802048301037A00027400016C01015C01014F01014A0401
6D39163806013503013604033502023700014005063903032B0000280101260303160101
0B00000700001500003802044E01035601015F010167010271030777030A7902097D020A
8001098F040CA3090EAF090CB0070BAF060CB2090DB1080CB3090FB60910B70910BA0B12
BB0B10BC0B10BB0B0FBA0B0FB80B0FAE0E137A0B0F2901026C6E70BAC8CAC8D5D7CCD3D8
CDBFC893535F8D18229F0F14A61114A90E13AF0D13B10A0FBA0E10C00C10CE1215D71719
D21013D51116D41014D41113D71314E31C1CE11818E61C1CE4191AE71C1CE8201DE8231F
E5231FE92824E72623E92828EB2A2BE52327EB292CF02D2FEC2829F22B2CEE2828E82425
E0252ACF2934D74E5EE97587E67285C14050BB242FC0181DBF1316BB1114B81113B20B0E
B80E13B30B0DA81005AE3A06DA8F19D2990FC57C188A1A00940605960209960109950309
920308871012935250DCCBCBCBCFD2C6D1D3C5D0D4C6CDD3CEC6CC72444C69131C651217
B08888D0CECEB8C3C6B7C4C7C3CCD1BAC7C9BBC9CBACBBBF96A6AC97A7AE8E9FA68A9BA2
8892973831352B0F1328030A26030C24010B42111D4C061271121B740208760102760001
7900027E00058102058002047D02047A01036E01015C01014E00004B0301
733D183905003802003902023A04043600004106073803042800012100001E0203110001
0900010A01021900004005075501045F02026502026A01036E01036F0003740104770106
7C0105890106A2080DAE080CB0090DB1090FB0090DB0090DAD080CAE080CAE070CAF070C
B1080EB30A11B0080EAE090FA90910920F15460206271C1E93A0A1C7D4D6C9D3D5D5D0D7
A5768288222EA0131AAB1014AB0D12B00F14B50E14B90D12C21014CA1216CF1316D71618
D71416DC1515E41C1BE31D1AE9221FED2423ED221FF32923F02723F53029F6352CF53B2F
F03D2FF3473BF04B44ED4D4AEB4E4DF0534FEB4742F0453FF1433DF7453EF6413CF43C38
F03432F03738E5353BE33842E33843E3323ADC2529D81F20D01819CB161AC9171AC31215
BE0E10B31008AB2801D78017D49B0CD39516A341069811059E070A9901099A040C96030A
8C040A741417CAA3A3CFCDCEC4CFD1C3CED0C3CED1C7CBD1BCAAB2551B24630E1765252B
98858AA5B1B78B9DA2AEBCC0C1CED0C0CED0C1CFD1BFCDCFBDCACEBCC8CD92A1A59AAAAE
919FA1949899453B3E200B101D020B23010C400D1A60192566060F79040B7A0205740001
7300027500047601047701037802037B0304720203610101540100500500
7A43183E0A003C05013902013603023502023C08092F03032001011B0102190101110100
0A00000D00012000004B0A0D5C02046201026601026B02036C01036F0203730104760105
7A00048800059E060BAB0A0EB20F13AF0D12B00E13AB0A0EA7070AA60709A40408A7050A
AC0810AE0910AC080EA7070D9E0E146A0A101F01024F5658B4C2C3CAD4D6CFCED4BA98A5
862D3B9C151FAC1116AF0D11B20C11BB1115C11115C91419D01619D7171ADC181AE41D1E
EB2122F22825F32922F83028F7322AFA3731F83731F73832FE443BFB493DFC5447FE6455
FE7564F98679F99E99FAAEAFFBB2B6FCAEADFB9C96FD8E85FD7D74FF726AFF6D64FF6B62
FE5B54FE514DFF5854FE5050FC4849FC4546F93C3CF73637F23032E8262AE42427DD1E1F
D51D16BF2504DB7216DF9E13D89F0FCB79159C1E01A60B08A7040BA2030CA0040B980107
88090F8D4446DEC9CACACFD1C4CFD1C4CFD0C5CED0CFCDD4967A825510195B0910724549
8A888B83969A6F868A8FA1A3A8B9BC95A5ABBBCBD1AABAC0CBD8DFBAC6CDA8B7BCBFCED2
909EA2949A9F41363C250A1027060D29020B34000A4400076001087B050C7D0106780104
7301026F01036C01036902046A04037405067403056500015B0301540802
86501D3F0B003E07023A04033102012C02012901021F0201120000110001180203170201
1000001401022200004707095F04076402036201026402036601036C0106720106760106
7B02058A050BA10C11AB0E12AF1314A90F13A00A0DA20C0FA2090AA20709A5080CA3040B
A8060EAC0910A8060DA1090E840F14360103161315899798C6D3D5CFD3D7CFB8C28B404E
961623AE1219B81216BD1314C01213CC181AD41A1ADB1B1BE21D1FE92121F42A27F92C29
FC302BFE3631FE3A33FF3B32FF453BFF4A41FF4A45FF4B48FF524CFF5A53FF645BFF736A
FF817AFE9797FFB3BBFFC4D4FFC5D9FEB6C5FDA1A8FC8A8CFD7777FE6C6BFF6864FD625E
FF5D5BFF5452FF5355FF5153FF4B4FFB4449FE4247FA3B3FFC3F45F9343AF42B31F22D2C
E43218DB590EECA01EE0A912E7A021B54204B91C09BD0F0EBB0D12B2060EAE060CA70C0F
861214C99596D3CBCDC7CFD1C5D0D1C4CFD0C7CDD0D3CAD16C3D485F0C175B0F15997A7C
A6ADACB9CCCE879A9DAABCBDA7B6B98E9EA4B2C3C9809198B8C9D099A8B19CABB5B0BEC9
6169766966732B1621411C252B040A2F00064D0C1452030965040878050B7C0308780005
7200036C01026501025801015302026304057006086501025A02004F0500
5F77113F0C003F06013B04012D01012300001E01011501010800000A00001802021D0103
1701011600012000004007096511135D01015B01017A2022862A2E69050A6F0208720006
7701068502099C090FA70C11A80E12A30D1398060B9C0A0EA20C10A1050AA4060DA6060D
A6060CAB090FA90B10960C115706081302024D5758B7C4C5CBD2D6D9CAD3AA69769A202C
B3141AC11417CA1719CC1716D51C1BE12422E82624E7211FF02525F72928FE2E2AFC2C27
FC3029FF3932FC352EF9332CFF3F39FB3C37F93531F93532F83A37F83F3BF7443EFA4C48
F44A4AF04C51EE5360EF5B70EB566DE6495EF24F5CF34852F54249F63D42F83D41F83B3F
F03136F12E33F23135F13136F03038E7262FE6232EE52731E42A34E6242EE11E24E0291E
D13E06ED8F1CDCA40DE3AB19D77816BE2D04CE1E13CE1716C91315C61216C01014AC1315
A24241E6C5C5CCCECEC9D4D4C4D0D0C6D1D2CBCFD3C5AFB65F1C276A0D175F1A21968388
A1ADB2BCCDD3A0B2B6BCCACCBBC7CABAC6CBB5C3C896A4AAB4C3CB8B9CA5899AA396A2AF
2F30401E0E1E2A0B194E263032040D3D030952050A5E04086B0B0F942E34730309770106
7200026B01026102024F01016E25267723246405056303035A0301550B01
40A209480F00460A014006032E01002201001D01011701011001010E00001A0202210202
1D01011901011B01012B00014F090C590203650608963238A23B44831B226B01066D0106
76020884020A9C0911A70C13A70C12A70F14A50F15A10A10A3090FA4060CA7060DA7050B
AA080CAB080BA70D12870F153801023F3838A4ADADC8D0D1DAD0D5CE96A2A9323FC01D24
CC1A19D51E1CD81E1EDA1E1FDC1E1EE01F1FE72423E41D1EED2224F01F20F62220F6231E
F72721FD312BFD322BF82D27FC322DF92E27F62C23FC352DFC3932F9362FF9372FFD3F36
F4362FF83934F6393BF63C40F94046F63B3EF6383CF73739F73335F62C2EF72C2EF2282A
F1272AF2282AE82122E31F21E11D23DB1821DB1A23D71921D41921D3191FCA1813C02A03
E7811BE1A20FDAA80BE49B1EB83D02C21D0AC91514C50F12C20C11BF0C10B810149B1A1B
DA9797DACBCCCDD3D5C8D3D4C6D1D2C6D0D3D3CFD6A47A856A131D6F0E15763B418C858D
7C8D9991A6B082969EB0C2C7ACBBC2B3C1C7B2C0C7B5C2C8B6C4CB92A3A9A1B2B89BA6AC
39343D2D151F330C173307133A08124B080F5B060A650408721317B6565D70030A750105
7100026700015C01024901014E03068531325C02025E0403590401570E01
57B7195618004E0E034108022C01002301002001012202012303031D01011F0000280101
2400011B00001800011F00003902025502036C04077C060D80060F7B050D6D00056A0105
72000686050C9A0911A50C12AB1015AA0E14AB0F16A80B12A60810A6040BAB070DAC070C
B1090DB20B0EA9101576060A4C1316B7A6A8CFD0CFD8D2D5E1B8C0B84E58C4242DCD191B
D21918D51B1AD71B1CD6191CD6191BD51719DC1A1CDD1618E4171AEF1C1DF72320F7241F
F92720FA2922FC3029F6312CF6322FF73029FA3428F9382DFB3D32F93D2FF94030F54131
F94B3AF54C3DF14C42F14E48F3534CF7554EF54E46F84C44FB483FF73D35FD4039FA3C36
F83934F93935F33330F0302EED2A2BEB2829E52425E12022DD1C1FD71E18BE1E02D96714
E9A319DCAB0CE2A517C8620BB82303BD100ABE0C0FBC0A10BD0B12B90D12A41215A54C4A
E8C8C6D2D0D2CDD2D5C9D1D4C9D2D6CCD0D6D6C4CF75344178121B6D1316B18A8C91959C
8A9DA68397A17E949B81969D7E929895A7AEAABAC197A7AEB3C4CC8C9EA5B2C3C8A6B0B6
8D858B5B3D446B404935091430020C400309630A1076080E7C080F840F1580060D7A0104
71010268010259020249000054020463090A5901015902005C0A01591101
00FF006B2C074C0F013E08022B01012500012500012701012A01012C0101310101370202
2F01012101011A01021B00012E01004F01026C02057C010780000780030A7400066E0005
72000685030A9E0B12A70D12A90E13AA0E13AA0C13A8080EA9060CAC060CAE060CB50B10
B90E12B60C11A70C117F060C8D464BDDC3C5DAD3D3E0C3C8B55F69B92630C9171DC91114
CA1113D11417D11317D4161AD41518D81619E11A1CE41818F1201EF82520F92822FA2B23
FC2D25FD2F27F42E26FC4944FF615FF53F38FE483AFE4F3EFA503FF8533FF85F4AF96F5A
F7806BF58F7DF59990F49E9AF5A09BF79F96F59088F78378FE7668FA6253FF5E50FD574B
FC5548FE5348FF4F47FF4843FB3F3CF83936F63531F42E2BF22C26E63217DB550DF19D22
E1AB12DEAA12DF8A18BA3100C61A0BC6110FC30E10C10C11BF0C12B91519992423DDAAA6
D7CECDCCD2D4CAD1D3CAD0D3CACFD4D5D1D8B38C997017257C0F16853B3DDBC9CB9BA8AD
B8C9D0B2C2C897AAAEB5C8CB8EA1A3A0B1B4A0B1B783949BA8B9C27D8F998FA1AB98A3AE
8E89953F2532613B463B162131101735050D56050C7A091087020992080E8A03087D0003
7401036601025402034A00015A04065E0304530000570702601306434F01
00FF006576114A11013A08012D01012901022801012B01023200003E04024905044D0708
3C04042400011601011400002200004A03056C03087A01067E0106800207770106700106
7701078B060CA10C12AA0D12AA0C11A6070FAA0A12A9070DAF0A0EB3090EB3070DB80A0F
BD0D14B70C12A20408921418B87074DBC1C5DFC5CABA727DAE2733C61620CC1117CB1012
CD1112D51416D91518DD191ADE1719E61A1DED1E1EF2211DFD2C23FC2F23FD3528FE392B
FF3B2FFB352BFB3E37FF514CFF5754F84B44FF5247FF6254FF6E5DFF7765FF8776FF9F90
FFBDB4FFD7D6FFE7ECFFECF6FFECF6FFE7EDFFDADDFFBBBBFF9591FF7C74FF6B5EFF6F61
FF6F60FF675BFF5C53FF514BFE4744FE4643FF4440FC3934FB3D2DE74812FA9327E7AC1C
E2B419E8A71DD15C08D1290ADB1C16D91819D01315D11418CC1318B41A1CC26969E7CDCC
D0D2D3CBD1D4C9D1D3C8D0D2CACDD1D8C7CF7A3C477C101C780F16A46D71B1ADB492A1AA
BCCDD5B0C0C6B4C3C8BDCCCEB7C5C6B9C8C8B5C3C5AAB8BBAFBEC47D8E977B8E9783919E
3C3C4B1B09193A202E200A1477656D4E2B324E060E75060D8C060C96060B900509820104
7902056602034B01004600015703045602034B0000500903561404298900
00FF0028D80A551F013908003001002E02022E0101350101430403540807580607540507
4004042100001101000D01011900004202056B03077A0105820207840308790304710104
7901078C050AA20A0EA9080EA9070CA9060EA9060DAB070CAE080CB1080BB10508B4060A
B6060CB4070CA7070A951D20D99DA0E6C6CCCB8C96AF313CC71B23D21519D51617D91818
DC1A19DE1A1AE41D1BE81E1BEB1F1DF32321FC2A25FE2E25FF3428FF392AFF3D2CFF3E2F
FF4135F8342CFF413BFD4842FD4A43FE4741F53C37FC4D47F9564DF75A53F8615DF56A68
F5797FF28693F293A5F69EB5F59BB2F391A3EF838EF37781F7696FFD6063FA5351FD5651
FC574EFC514BFE4F4BFE4643FD413FFB3D3BFE3D3CFB3830EF411EF07721F2AC28E4B61C
E1B21BE5901ECC3D04E02717E21D1DE11D20DA181BDB1B1FCF1D21B23031EFB4B7D7CED1
CED2D5CCD3D5CAD2D4C7CFD1D1CED3BE98A0791E2A88121B83282CB694989EA3AB92A2AB
91A3AD91A2ACA3B3BCB5C2CAABB7BBBEC9CCBDCACBBECACDB8C6CA93A3A8AABAC087919A
403B4626131F1C061012020C7A6E7750323B48050C750A1188040A91040B8A0208800104
7B04076403044600004903045505074B0101450000520F055013022A8C00
00FF0000FF00824B173C0D00310301300202350202410302570B085E070460090956090A
3801011D01000D00000A00011400003E01046A04077E01068602078704097903056D0002
7802078F050BA0060BA9060BAB070CAC070DAA050CA8040AA80209AA0308B00408B30407
B8060AB9080BAF1013B2484AF8BFC2E5A6AFB23E47CA252ADC2122DF1F1EE01F1EDE1C1B
E01D1DDF1919E21B1BE71E1DED2220F1221DF82720FD2B22FD3024FD3425FD3625FB3325
F92E26EF241FFB3732FD3F39FE423BFB3A35E92624FC3E3AFD4642FD4A47FB4B49F84A4A
F84D50F75158F75661F75A67F65864F35258FB5959FB5253F9484AFD4448F93B3EFB3E3E
FD403FFD3D39FB3735FD3635FD3533FC3332F52B28F0301EDD490BF79F2ADFAC16DDB216
E0A71CC45E0CBE2206D01914D21417D7171BD11317D0171BBC1F1FC26464E9CCCED2D3D7
CAD3D5CAD3D4C8D1D3CACFD2DACCD28F515C8717238A171DAB6768CCBEC0A7B2B8A7B6BC
A0B1B79EB0B6A3B2BA93A1AA9CA9AFBBC7CAA0AEB0BFCBCEACBABEA8B7BBB5C3C69DA4A9
61565D33161F300E18220612301624300A1646030967030883080E87030A800206770002
7406075F090A5213134606064802044400004903015411065115002C9000
00FF0000FF004CB1154415003607013404013600004905035F0B07660C096009094C0607
2E00011B01020D01010601010E00003702036A050A820209880207850408740204680002
7200058B03089E0509A7050AA60207A90408A80308A70208AB030BAE040CB3050AB9080B
C20D10C00E0FAD1619DE7B82F3A7AFB94952BE1F26CE1919D21717D51919D31718D21417
D41519D11117D41319DA161BE0191BE91B19F6231DFB261DFD2C21FE3022FE3223FE2E24
FA2925E01513E92424F83536F63433E92928D61817F83937FB3C34FB3C34FC3F38FE433D
FD413CFB3E3BF93E3BFA423FFF4945FD443EFE473FFF463EFA3832FC3230F92C2BFE3433
FB332DFA2F27FD302BFD2F2BFB2E28FD3129F12B1CD93207EA7D1AE4A617D8AD0DD0A409
DC971FAA3300BC1C0FBD0E0FC41015C61015C30E13BC1316A02122DDA2A1D8CED1C9D1D4
C7D2D3C7D2D3C6D0D2CBCDD1CEB4BC79273389121C811D21C69A9DCCCDD1ABBAC0C3D1D7
BECDD0BECDCEC8D4D7A6B3B5B1BEC0AFBCBD9FAAACC0CACEA2ADB2A6B5B9A4B2B6AAAFB4
473A4128070E350D162B060F2E04103A010B51010867020776010681040B7C03076F0001
660608611E1F9F6F713605063E01014F0403530602530F02561B0000FF00
00FF0000FF005BBF204A19003D0A023E0501440300560805660D0A650A095809083F0405
2500011500010A00000300010900002A01035F050A7B030A8102067D04066B0102600000
6D02038301059A0408A40207A80308A80207AB0409AE0409B1070CB4060DB7070DBC0A0E
C00B0FC01014B01D23F58790B9404AB61D25C31316C61013C71114C61014C81317CA1519
C81218C81117C91017D11319D81316EA1D1BF6231FFE2B23FF2C22FD2D20FB2B1FFC2A21
F62520E71E1CD7191AD92528D32326CC1A1DCE1518EE2E2CF9342DFB342AFD392EFB3930
FD3B31FC392FFB382EFD3C33FE3E35FA3830FB3930FA372EFA2F26FA2822FB2925FC312B
FD3229FF3228FD2E26FD2C25FD2D25FB2F21ED3415DC570EF5AD2AD9AC0ECFA805D09D0B
C57113A52003B61511B70D11BA0E15B70A12B30A10AD181C9A3C3CE6C8C7CBCED0C7D1D3
C6D2D3C3D1D1C4CFD0CECFD2A9828B741621820E167F3033B9A4A9A1B0B797ACB4C3D5DD
C1D1D6D1E0E3D9E5E8CED7DBC4CFD1C1CBCEC3CBCFC5CDD0B3BEC1B0BEC0A5B1B49A9CA0
2B191F29090E623D422F060D35010756060E710A1177090E79060B7D030A7702076A0002
5F080A561B208F64683603034E04036509085B0501540E005A1F0000FF00
00FF0000FF002EE00F521E003F0701470401550A065B0A06650E0B5E0907510A09320101
2000001700010E00000901000801001C00014701056602056F01036D03036101015B0000
6901017F00039B0509A8050BA80307AC040AAE040AB1070BB3070AB6080CBA0B0EBB0A0E
BB0A0EB80D13C32B33C1333BB0161EBB1015C00E12C00E11C00E12BD0B11BF0E15BE0E15
BD0D14C10F16C40D13CF1015E31B1DEC1D1BF82622FB2923FA2920FE2E23FD2B23FC2A24
FA2B25F4322ECF2B2BE66566E36267BD1D21D31A1DF42F2FFB332DFC352BFC372BFC3A2D
FD3A2DFA3629FB362AFA362AFA362CFB372EFB362DFD392DFD3429FC2E25FB2E26FC332A
FC3328FB3125FC2F25F7271EF8291CF62E17DC3704F69629F6C42BDEBA13D1AA06D69C15
AD4304A91201B40C0CAD040AAF060EAA050DA0060C8D1216B37372D7CCCCC5CED1C2CED2
C0CED0BFCFD0C2CECFD6CFD4824F5777111C770D148D5257A39CA28EA2A987A0A8A8BDC6
B0C3CCC8DAE0D0E0E7CCDAE1D2DEE3C4CFD4D3DCE1D4DDE3D0DBDFC5D4D8B5C1C4ADACAF
5F474D3A11187E525937070D48050C6B0A137F0B1290191F8712177C040A730105670102
59030568232845060A5003046F0B097308065D03005812035D220000FF00
00FF0000FF0000FF005C27054307014F0904580C075609045A0C09580D0A4306052C0000
2100011D02021402020E01010C02011200003201025202065E02055D01025901015C0102
6A01047F0004990307AA050AAE060AAE060AAF070BAE070AB20B0CB3080BB60A0CB5070A
B5090DB0080DB41318AC0A12B10A11B80B10BA0C10BD0F12BB0C11BB0B10BE0D13BD0B10
C00B10C70D10D31315E11A1AEF221FF3221CF82820F82820FC2D26FA2D25F92F27F9322A
F5312BE73B37F78384EF9FA3D87C82C43F42E23E3CEA3D36EB3F35E73D33E74135E54436
E44435E13F32E54538E54537E8483BE24236E14134E64838E64837E44233E23F33E8453B
E33E32E33C2EE83D30E6392BEB3A29E63E21E46625FBB745EFC938E6C62CE8C12BE5A02B
B43802C31C0FCA1918BA0E10B40F14A8090F96070C7E181BD5AEADCDCDCDC1CDD0BFCED2
C0CFD3C6D4D6CAD3D5CBBFC5672B33760F186E0F1591666BB1B3B798ACB090A6ABBFD2DA
B4C5CEBED1D9B6C9D1B9CAD1D3E1E8BFCBD2D9E6EFCAD9E1D1E2EAC8D8E1C0CCD2A8A3AA
5C3C4558212B47050E4B050B54050B60010776060C7F040B8001087E0106720004640101
5701036716195D0709710B097F0C097407045D06015513005F270000FF00
00FF0000FF0000FF00733C13460A00520D07530D06490602470604420404330101280000
2401011F00001700001100000E01011001012401024002044C01045002035402045B0105
6B01068101069B050AA7040AAC060BAE090CB00B0DAE0A0BAE0A0BAF080AB1090CB1080B
B2090CB0080BB0090CB1090FB50A0FB6080BBC0C0DBD0D0DC41112C30E0FC60F11CE1414
DB1E1BDF1D19E8241FEB2A23EB2D24EB3226EB372AE4382CE33C32E03E34DF453ADE4B40
D74A41CB5650CA8284DCB6BDD9ABB0B56D6CB95D54BE5B4EBC5C4FB85E52B35F52B76859
B26455B36556B26656B26656AF6555AE6454AB6252AE6654AD6553A95F50A95E4EA95B4D
AC5B4DAB5848AF5947AF5342B75542AD5236AF6C3DB69146B0983DB6A23DBA9D39BB8234
AA441BBD3726BD2D24B328219A1511971513901C1B843939E2CBCCC8CDD1C2D0D3BFCED2
C0CED1C4D0D3C7CDD0B9A4AB5D171F770C146B121A927275B5BDC19CB1B7B3C6CECFDFE7
BFCFD7D4E3EBC6D5DDC5D4DBCEDAE1C5D0D9D2E0EAB2C3CFBACED9BACDD8C6D1DBA39CA9
7A566253101B63060F7611166201056D070C81090E90091091060B8B0408760102620000
5400005600016A06077806057C07047106025C09005617014A600100FF00
00FF0000FF0000FF005E73104C0F004F0D064407023A03013400003101012A0001280000
2800012502012002001902011001010F00001A00003002034F1A18642C2B4A0508590106
6D0107830207980509A4050BA7050BAE0C0FAE0A0CB3100FB00C0CAD0809B10A0CB2080A
B40909B50A0BB70B0CBB0C0EC11010C71312CC1814D01D17D01F19D0241ECC2520C8281F
CD3227D0382DD14134C94435C64E3DC55947C36150BC6557BC6F60BB7666B8786AB77E70
B38277AC8880A18D8C9B94969C97979A8E8A9A887E9D897D9B897E998A8093887D8F867A
9085798D82768E85788C8377867F72898376878275898376888376878378857F72898174
857D70867D6F877B6C8B7C6B8C7B6787766284775F80785D7D79587B7B527B764B85704D
916A5196614F955948925547874C3D8447397B42377E5B56AEA6A7AEB4BABFC9CFC2CFD3
C4D1D6C4D1D5CCCFD4A4858B68141B7B0B117B282E9C8688A0AFB4A1B8C2B4C8D4C5D7E2
B6C8D3D3E3ECCAD8E0D1DEE7D4DDE6D7E1EAD8E4EEB3C3CEC0D3DDC8D9E2C7D1DD888291
401D2C50061182141B93171B740203880F13A2181DA10B11A1080D9505087E00016D0102
5C00015C01016A02057302037606036F0B045D0D015A1B0132960000FF00
00FF0000FF0000FF0042A60A521800490D033A04022F01002D02012B01012D01032D0202
2C02022C01012902002101011600001200001A01002903047F5859D3ACAE5A1F235C0309
73040A7F0004940508A4080CA90A0EB01414B31613B91B17B81613B91313BD1212BF110F
C31310C21310C31613C41B19C31F1AC32820C02E24BA3428B1392CB0443AB35449B15F52
AD6759B27466B88575B68E7DB39685A89282AC9B8CA3968BA49A8FA39B8FA6A094A2A095
A1A49A9AA19A99A29E96A2A093A19E8F9B968D98908E98908D99928996908C989587928D
88938D8A948E87938D828E8985938B8391898290888290897D8C867F8E8A7A8A867B8B83
7A8B81798A827D8D857A8B8078897D75847977847B748179758379758477758274778071
787D707C7D707A796A797668777365746F607972647472697174716B72726B76766D7A7B
778486859194989C9F8469697B3531862C29935859D2C9CDB7C7D0ACC1CEAEC1CFA8BDCA
ADC2CEBED2DDB3C7D3C6D8E4CBDAE5D1DFE8D7E3ECD2E0EAD0E0E9D5E2EBD1D8E2655865
4F232F51070E7C1A1B801918882524840E11A10F12AF0E11AB0A0D9D06088E05077C0204
6B01016400016801026D02017107046C0E045F12015F1E0037990000FF00
00FF0000FF0000FF002CDD0D6028034810023503012B00002701012801012F0102310102
2E02022D00013002012A02011F01001A01011F00023F181B50292D70494D5E2025660A0E
7202077F0104930608AA0D10B51618C32727C02320C32521C0201CBF1E1BC3201CC3221C
BD241BB1261CA5261DA6352CA14036A152469B5F53996E619E80749782779B8C80A1988B
9B978CA1A196A0A4989EA69AA0AA9FADB9AFB1BBB2A8B0AAB3B9B3BCC1BBB4B9B3B4BBB4
A7B1ABB2BEB9A4B1AEA5B4B2A4B3B2A2AFAAA4B0A9A7B1ACA4B0AB9BA8A79DA8A89AA4A4
9DA6A59FA9A8A0ACA998A6A39AA8A597A5A096A49F8E9C9994A3A08B9B99889998859694
899D97879B9480938D7F928E7E928D7B8E89798D8975888571868273898271877F71877E
6F837A6F81797082796E7E756C7C746879716B7B736E7B746D79736C7972687870687974
68777463737065716B706B627C63567A5A4F74635E83868B98A6B0A0B1BCB3C4D1B8CBD8
B1C6D3B7CDDAADC6D1ADC4CFAEC2CEBBCED9C8D9E3C6D7E1CCDCE8CBDAE5D3DBE4827179
6331395E1C20551112723A38EFB5B87E1F249E1015AE0C0EB00D0EA70A0D99070A840103
7801026C01006801016801016C09026A13046219016828013C9D0100FF00
00FF0000FF0000FF0000FF00566D094915003303002F03032C0202270000300101350102
3200012F00003201013101012901022000022301023C0F11936064A0696D984E526C080A
7702068605099D0B0EB81617C52021C8292BC42D2DC4332FBB3531AD312CA4352D9C3A30
97483C92574A93675C8E70668B786E887F7784887E818F8580928A7F928B899B948FA098
91A0999FADA6A1AFA7ABB9B2AFBFB7BCCAC3BDC8C1C0CAC4C9D2CCC8CFC9C6CCC8C7CECB
C0C9C5C4CECBC5D0CFC9D3D4C9D2D3CBD3D3D2D9D8D8DDDDD8DEDED6DCDEDADEE2DBDFE3
DDE1E5DDE2E5DDE4E5DEE5E6DCE2E5D9E0E2D7DEE1D6DDE0D7DEE1CFD8DBC9D3D7C5D0D3
C5D2D1BECAC9B3C0BDADBAB7A8B4B09FACA998A7A595A6A591A3A18597947D918D798E8A
778D87748B836E857E6D837D69807C687F7B6C827F687D79697E776C8078627671647774
64787562787063776C67776A6A74686A73676570686370705E6D7161717564757A708289
8697A1ABBDC7B0C4CFC4DAE4B4C9D4BFD4DFB8CDD7B8CED7B8CDD9ADC2CFB7C9D4B2B4BE
967C84643038531C24876469E3BEC6712028991118AA0D10AD0E0FA80C0DA00A0B8F0405
8202037702026D02016801006709016417035E1C0075360242A40200FF00
00FF0000FF0000FF0000FF004EB314501D003806003604023A0503390201430605430304
3A01013400013801013C0202320202220000230101370205681B208D323881171C7E060A
83050B8D080EA9171AB71F1EB62625AC2F2EA33A3A9E484593514C8A5B5285665C816F65
7E766B7B7D7379807878837D788881768981788D87768E8A7B94917B95928299978A9E9C
94A6A69AAAA9A3B3B2ABBBBAB2C1C1B5C5C4C1CFCFC6D3D5CFDBDED3DDE1D9E2E6DBE2E6
E1E7ECE3EAF1E2EAF2DAE2EADFE4ECE3E6EFDBDEE6D9DCE4D5D7E1D3D2DFCDCCD8CECDD9
CECED9CDCFD8CECFD8CECFD9C8C9D6C8C9D6C6C5D2C8C7D4CAC9D5CBCBD6C9CAD5CACCD6
CDCFD6D1D2D8D4D5D9D9DADCDDDEDFDADDDFDBDFE3D8DEE2D7DDDFD3DBDBCED6D7C9D2D2
C1CCCCB3C3BFA4B6B29BACAB93A5A4889A98809491758B86758B836E847E697F7B657C7A
657D7A607A755E7972617971647A7262776E60746E6074725E73705D736E5E726E5E716E
5B6D6E61707463747B73868E899CA6ACC0CBBBD1DDC5DBE7B1C8D5A5BCC9A7BFCDA6BAC7
8D8A9736101E420D1A653846C18D9D6A101B941017B31D21B21719A90D0DA20A09950405
8B03067F0203760200700401690B0161180166280081440400FF0000FF00
00FF0000FF0000FF0000FF0000FF00723D12400A003E0502430500500803590906570706
4801013E01013F00014402033A02032D02032D02043E00036D0C138A1016901013890B0E
820D1185161A891E208B2A27893D3886534D7F605B7D6F6974736A737970717D7573827B
73837D758780768881778A85748984748A85768C887B908E7B908F7E94947F9695899E9E
95A8A994A5A8A0B0B3A4B2B8A7B2BAA7B4B9A2AFB4A3AEB4929DA48E989F87919582888E
898C93777B8473788370767F70747C73737D72717B706F796F6E776F6D77706F74747176
76737775737776727679757A75747970707574727877757B79777C7D7A7F7D797D7D797C
7E7B7D807C7E817C7E837F7D84807F8080818181848280838784868A87888D8B8D98959A
9C9CA0A1A4A6A1A8AAA8AFB2AEB4B4B8BEBDB7BCBBBDC3C0B4BDB7A7B5AF9CAEAA91A3A0
829695728988688281657F7C67807D627C77627C77607A765E78725F78715F78705E746E
5C726C6075705E73705E73715A6E6F5F7479657A837D929E9CB0BEB5CAD7B6CCDD93A3B5
474152320E1D3C0814440918893D4E770F1A8E0D11A31014A90E10A80C0CA60E0D9B090A
8D04058203028208067704006F0E01651D0071380241A50300FF0000FF00
00FF0000FF0000FF0000FF0000FF005F7712420E004007014C080262100A6C0F09680B08
5804034B01014C02024E0404430304350102370408430206690C10800F107E10106B100D
5F191566322F714C4977605C75696472716B6E78706F7E776E807972837D758581758581
7889837789837A8C857687827687847A8B887F8F8C818E8D83908F83919081918E81908D
7A8887757E8071787A6B6F72696D6F6B6E6C696D696B6D696E6E6A6D6F686E716871736A
73736C70706B73756F71746D73766D72716875746B74756C74756C74756C727065737063
7574667472667772677470677374697374667070637575687A7B707C7D727A786E7F7D73
807F747E7F7571736977786F76786F787A727D7F7883827D93928DAEAEABCDCDCEE5E2E7
E8E7EDE4E5ECD0D4D8AEB1B491908E86817C867F77877F7789847B8988808F9188999B93
9DA19DA5ACAAA1ADAC9FAEAC95A5A2899C977A928D718A8668827C657F78607B745C7873
5E79735E78725C76705E766F5C756D59716D5A71725D7176596C745F737D6F83908D98A6
2519243A131C3B080F42030D610A14801018C34648980E0DA51111A20E0DA10F0D940806
8904028305038307047C070173120268230075400422D40200FF0000FF00
00FF0000FF0000FF0000FF0000FF00389E06461400430A015109026C130C71100971110B
640A065A04035E07075E0A095007053F04033805073805064A0D0B55120E58241D64453D
685A5264655D646E6764736D6878746E7C7870817971847C7789867788867A8B89788985
7C8D867E8C877E8B867F89857E86827D837F777B7572766E696D64696C6365685E676B5E
6B6D62737369716F64757266807D6F807E6C7D7A677C7766777362777663727460757763
72746274746476766674736077766174715F737260747564737564747464767463747360
7577637576647A77677B78687C7B69787A657879647C7C69797B6A74796971776874796A
72776874786A777B6D7C7E72898D81989C92A6A8A0A3A5A0A5A8A6A2A7A9A6A9AEADABB4
B3B2BD9A9EA68B91957F8484787C747A7B6D7674647B77647C78667F7C6A847F6D857D6E
847B6F857D73817C73827D7687847C8A8D83989E959BA49C98A59D95A59D879A93788F8B
6F878367817D617B77607B755C77715A747058716F5F77765D72735B707253686B515E61
4B4949422E2D3A19195B292D5C0A1382111899181C921110AD312F991B1AB12A29930907
8B0604880906820400830D05711302652201566E0300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0045AB104B17004A0D015A0F056D130B73120C71110C
670D09610A066009075E0807570A094408082F0807260F0B3E2D26564C435A58505B6459
5C6C635D7069637772697D7A708380738581758882798C86788B8878898777868375837C
717E75717A716E726967696165645C6A655A6D67596D6958726F5E74725F7A78627B7A64
78745F7D77647C76637C76637A74617D77627C776277735F76745F777762737660727561
74776575776678796579786374715D75735E71705D737361757666757565777664767763
7578647779677C7C6C7B7B6C7B7B6A7A7E69767A66767767737668777C6E797F707E8274
8687788D8E7F9191828A8C7E8184777F817982837D898B878E919094989AA4A6AAA6A6AB
ABA9AE9395958186827A8079747B6E737A69757967787B6675776376786376745F797360
7C75637A73617D76647C7363837768857C6B867C6C867D6D837C6C8380708E8C81959790
99A09997A39E8697947B908C6B837E647E7B5F7876637B7B6079785D7673566D6B566967
56635E575D564F4C465946463E0C106B11148B14158B1314D6727397262A991516990E0C
920C08910C0897130E840E056910005B1C0033970100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0057BA1C561F004D0E005F12076B110971110B6D100A
660D085A0905550905540D094C100C3F18123C2E28484B444D595050615852645B596B63
5E716A6678736A7E7A6D827F72878472878470838070807C6C7A74657167626C5E5F6656
646755686856706E5C7774627975617D77637E77627D76627F796578765E76765C777860
7876607A75617B75627C75637C75627A746079735F7875607A776274745D74765F767862
77786377756077766075735F76735F74725E75736075736072725F767562767560787863
777965787968767A6B7075676E7566717B6A747B6C777A6C7C7D6F8382738988788E8C7B
8C8A7782807080806F868876858A7A8085788083797A7F76747972747973747872787A75
7A7A767A797178796C787A6A75766373746173756173766273766272735E706E5A6D6A56
706F5A72705A706E57716B55706954746D587E766281776482776280745E877864857663
867B6A827C6E86857B90948B90978F8F9B9581918F7387866B8381657E7B5D777558716F
566C6B596C6950615B545D59544C49542B27671614801619AC3A4195171F9D12149D100D
920A049C160D95120884110568130256190030950000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00672F044E10005C11056B130A6F140B691109
64100B520904440A033B1106442A1D4E43384D51494D5C544D6159546A615A6F6763746E
6A7A746A7C776B7F7A697F78687B7563746D5D6B61606A5F61695A686F5971745B7B7A60
7B775E78735A79745C7A765E7C775F7A755D7C76607B745F79735D807D647F7E657A7861
7776607A76617B75627A746179725E79725E7D77637A746176735E78766077775E76755D
75735A74705978755E75745D76745F76715E77725E7A76637A77637A79647A7964787B66
7074637075656B73646D7666737B6C70796A72786A787B6D7C7C6B7D7C6A817F6E84826F
84847183837278796876796772766472766771756871766973776C757A6D7B7D717F7F74
82807586817388846E8E89708980688D826B8C826B88816B7A765F77735E76735E716E59
6F6C566D69516762496A654D726E55726F57706C58827D697B77617A745D776F567E7359
7E725881765E837963817765827967817A6C8482778E928A88958E83948F6E8583617B7A
5C75755A7272556D6C536A6851635F54585162484364242478161B9113189D12109A100B
900A0399130996160983190D590B0052160000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00884F195216005A11036B160B6E160B68130A
5F120B4E1209422113473D2A4B4F3C4E5649515C534F5F5851665E536A615C726A647870
66797165766F6170665B695C60695B666C5A6B705A73775F74785F75785D76775C7A775D
77715979725D7B765F79755D7B765E7E775F7C765F78735D79765E7A765D7B765E7D7962
7A786076755B7A77617975617973607B756279725F7B75607C7A6377755D77745C77755C
76755B75745C78775F74725C7775607B76617A76627B786578776470715D6A6F5B6D7363
6D7366757C6D6E77676F776671766676796A777A6C76796A7A7D6C767966797B69797A69
7677667576657477647076617074617274667374687475677575667D7D6C83816E837D6B
8079657F786280785D847A5D88795E85745B84745B887A5F887C62857A617E755F756E58
706951736A52746B546E674F746D5577715A746F5C73705D7B796577766075725C79755D
7872597B74597D765D7D755E7C735A7C72597E745B7C745F807A6885827482867D7D8C87
778885687B7A5D7576577172526B69536963555E585A4F4B6034306C18138B181493140F
8B08039511099820137115084E0B004E150100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004AAC0F5A1C005C14026D180C6E170D61140A
551A0F5331234B433146513B4858444E5B4C4F5E5356665D5B6E645E72686073685D6F60
59685A5E6757686F5A6D715B78765F7A775C7A785A79765A77775C77775D77775E79765F
7A755F7C78617D796179755E7D755F7D735B827B62817B6379765D79765C79755C78745D
75735B76765C77765D7A76617D78647C776378745D77765B78775C7C785E7C775E78755D
76745C74745C75755E77755F75735E76745E7576617174626B6F5E6D72616A73616B7464
6A70637076666E7463727766727463787868787A6B777A6A767768757564737663737764
7276647376646F75626D74616F73627171627472647672617B76637A75617A755F756B54
746C51766F52787254756E51796E537D71577B70577D7157796C50776A4D7E70567B7056
766C536F674D71694F726B536D664F78705A77735F73715D7B796475725C74725B797661
716D5778735A7A735D7B745E736D546F6C4F7571537771557D725782725A8175617D7768
7D7C717C81797886826D82805F777559726F576C68566761545751664C45611F197D1813
8D140F971B12891D105C0D034509004B160100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00773A0A6019016A180B691C115B2115
5433244E453349503B4B5B45495A484F5E50586559606F63607064606E615D6756646A55
6F715874755B76755B79775D7773587B775B7975597773597A775E7C79607C7A617F7B64
7F7B627D7A607B775F7D786082796181765E80765F7B735B78735A7A765B7B775C757259
75735A75745C7A775F7F79627C76617E79637C7A5F79785D7B7861817B667D77617C7660
7A745F78745F78766176746073725F7274616D73626D75646C7665666F5E656D5C697060
7176687278676C74617077667378687679697376647376647375667577687176656F7564
6A7261686F5E6D73626D73617275637577657475617875617A745F78715B776E56746A4F
756A4D736B4E716C4E736D5177705579725A78745C746F56756F526F67457267457F7557
776E53726B506E684B736D526E684F78735B78755F7C7A6378755D726F5679755E7B7863
78745C7B755D77705A7A735D737055737357757457767457756E52786D50796B507B6D52
7B6D567E7361787769787F7776847F677C785B7370566E6A53696557615C5A4943581E19
7D1F188B1F147116094D0B01420E0049160100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0048A80A66220065200A602A17644633
4E442F4C4D374A543D4C5A4452624E5865565D695B5C67575F6758656B576F7059747056
76725676735978755D7A765E736F5778755D7D795F7D785E7E785F827D647E795F7D795D
7D785C807A607F7A607C775E7B755C7C765D8177617F76607C755C7B765B7E795E7E795F
7A755C78735B79725C7A745C79735C7B755F79765D78775E7E7B678882717E77657B7560
7E78657975627877647476657275656D73656B7567667161606B5A6872626F77676F7668
6D7466727D6C727D6C75806F757E6E767D70757F6F75806F737E6D707B6A6D75656A7263
656E5E6A74646E78676C75646C73636C726170736273735F79735F756D56736B4F786F50
73694A6E6648736C4F736A4E736D5275705973725B7271597772566A65437069457A7253
7B7358756E526F694C6F6A4E7672587D7A637C7A63837F6878745A7371587A76627C7762
7B755D777156756E567A725A76735878775C757258736F56746F53746F526E674A655D3E
6C6143675D406B644B756F5C777565747A6E69786F61756F596F6C5467665D6564594944
521D13702315540F02420E013E0F0121890000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0081420B622F0C6D513750462D
4A4A314F543B535B4458634D5D69555C68565B63515A5E4B69695671705A717054726F52
74715874725B75745D77755D73715976735B7C775D7E785D7D775D7E785F817B607E795C
7D775A7B755A7A745A79755B78755C7B765D7E775F7F78607E775F7E795E7D775C7C765B
7C775C7E775F7E775E7C755C7C765D7A755C7A775D78755D7874617973647A7363787562
797764797865757766797C6C747A6C6F786C6A756A6A77686E7C6C6E7B6D707D6F737F73
78857A7E8E818695888A988C88968D859189829086839286818F837B897C6D796C6B7669
6370636573656674676774676672666973676D73656E726072705C716D556E694D716B4E
726B4C726B4E746C4F776E5276705672715970705A706D586F6A4E6B6645777151777155
7B745B78735A7571587A775E817E677C7A65817F6A7B79636F6E5675755D7877607C7860
7B75597E775B7A725678715678735977745B736F57757058736E55716C52726E53716C51
6D684A615C3F5D573C5E573E6F6750746F597374626D75676370685B6967546363555D58
4B3B2E441A0B400E003A0C003B0E0021890000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048AE0E6F4D1F564A2A4B472C
4E5237575D4260654E6468535E634E5B624C535745595B4A6969566F6D57737056747157
7D7A617B7A647D7B637C785E7C795D7F7B5F7D775B7C73597D775D7D785F7D785E7D785C
7B75597B745B7A745A7E7A5F817C63807A617E775D7E775D7C755B7B765A7B76597C765A
7C775C7A755B7C765D7D785E79745A79755A7A775C7B765F7976627A7969797968797A69
7A7C697D7E6E797C6E777C6F71796D6C786C6D7A6F6F7F73677A6E63786E6B7E756F817A
778C86768D87738C86778D8B748888758B897389867389847589847689846C7E78697C74
687B72697B71707F766C7A7268766E69766C6975686A74646E736170735D706E56706E52
736E51736E51767055746F556F6F576D70597070596D684E726A4D7771527672547A7559
79745D797861777760797864807D69817E6A79776373715C76755F7878607A775E7A755B
7A74597B75587B745877725978755D79755D77725A76705974705877735A757157736E54
6F6A4E625F425C5B415757415959424F4E3765644D73705B717060666A605A665F516057
55594D3827183411013B100240110100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052BD1B68501E4E4521524F2F
5D5F4163694C66684E605E4855563F585C44555B47585E4E676B596F6E59726E55757156
78765B7A785F7C785F7B775B7B76597975587D75597C735976705778755B78745A78735A
7B755C7E78607B765D7C765C867E647D745A7C74597C755A7972567D775A7A75587A745A
7C765C7D765C7B765B78765B78755B7A775D7A7760787661797A67797C6A7A7D6C797D6C
787C6C7076686A726866706765736B697B74647872566C674F6864415C583C5753334F4A
2A484322413E203F3B1F3B381D37351C39371B3B361E3D381F3E3A274442324E4C3E5A59
526B695D736F687A786779786578766779746373696874676971626A6E5D71725D75745D
73725875745C6F70586B6E576C6F596C6D556C684E7670537B72537B73547B75577A7459
7E79627B7964807F6B817F6C807D6A79776371715C7476607A78627A765D7873587A755A
7A74597B765A7A755C78745F797560706B53736D52736E53726D54777158757158746F57
75705869674E595B45565B474C55413F4C3A3742304A4E3B6F6A5475705A666A57566455
5461524B49382E15033A1100314E0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00688B1953421058522966623D
6A694863654654563A4D4C355B5B435F6248575D4856604F636B596D6F5B717056716F52
73725577765A7C795F7B775D7D795D7C785B7A74587B745A7B765C7B765D7B765F7E785F
7E785D7F795E7C775D7F785E7F785C7D73587C74587C75597871547D76597B755A79745A
7D785F7B755C79755C76755D7776607678617A7B677678677076637379666B7161666F60
646E615A685E485C544F665F67807B4B67632C484424403D25423E2946413E5A544D6A61
5A776D6A867B6D877C7A90867D928872897E698378617B714C685D2F4D421F3E341C3A34
1835311129271228281F38392E4747435B58566C685D6C64636C61676C5E6C6E5E70705E
6B6A565E5F4A686B5570725B7372597C765B7D74577C73567A72537C74557C755979735A
7A755E82806B7D7D697D7D6975756171705B74745D79785F7A745C7B725A797358787358
7771577B745C7A735D7D77627A745E767057716B4E736D50756F54767056767058746E57
6F6C57676853545A454F594640513F294032243B3028392B444934666449726F54616750
586451585E492E1D08391401228A0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00714E0D5C4C1C6761366C6941
66664250533541462E4448304E51385D61475B614B535F4D616D5C696F5A6D7054707053
74735575745876745B79765C7A785B7A785B7F7A5F7B755B7B755A7771577872597B7559
7F785B7C77597A76587D775A7B74587C73577C73577C75587E76597C75577C775A7C795F
7A786071715B737460757763757A67727A656F75636B7262656D5D5966564F5D4F485A4F
3C5149324A4226433B1F3F372948413F5D55425D554F675D62776F778A82889B938DA29B
AABDB8BED0CBCFDCD9DCE7E4E8F0EEEDF4F2EBF3F2E6F0EFD7E4E0B7CABE9AAEA283968B
798A8173847B51665D2B443E14302D1A36341A32312A3E3A47564E5C6458696D5F717161
74715F76725C7E7B61807D6080795D7E75587E74587A72567A76587A765A79755B817D65
807D677A796476786172745D73755F73725E7A78607D795E7D755A7D72587C7459767056
7A745A7A735B7F755F7F76617F775F787157777055797358787258777257726F55726F5A
6C6D5A606653525C4B445442304838213E30203C2F233B2D2C3E2C424B32646447706C4F
65644B615F4A3D2C183D190100FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0029DE0B6545076F5D2D6E653B67643D
5A5C3C4C5239424B35414B34454E3849523C58624E525F4D5B695865705C686E576D6E55
76755A78775D76735A79765A817E617A775B7C775C7C76597D785A7E785C80795E7B7357
7972537873527973527D765680785A80775A80755A7D74577B76587A785A7A785C777960
767A647177656D73646C7163656D5E5E6B5A5C6B5B58675B4C5F53374F44304B4128433B
223C362640382D493E395449475F535A6C6069786C727D6F797F7385897D81867B6C746D
727A77767C7C8A8D9196959D9B99A296949E9C9AA4A4A1AAAFADAFADADA6A5A699969587
9A988BADB1A3929D9173847B546D69A0B7B896AAAA283C37172A1F3441325B5E4B746E58
7D72597D74577C74547971527A73547C74577B755A7A765D77755E7B79637D7C687A7A65
7878636E705A70725974745D75745F7A75607B765D7C755A7F75597F74597D73587C755A
7C755B7B725A7E735D7E755E7D755D7B755D7A745B79735A7572577070556F71586A6F5B
6B736258635546554931473B2441342342332541312A4432324A373A4D38575F456C6649
74684C685B424E3921401B0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0049B40C70541378673572673E6B6947
585F46505B4547533F414F3C414F3D4755424957454A5949526050616D5C666D59696B56
6E715775765C77745B7D785E837F647B765C7771567E76597E785A827C5E827C5F7D7659
7D76577872507973507B72517E74577E75587C75597B765B77765C767B63767C666D7662
606E5A57655757645A59645B526258485F52334E422744392542391D3C341F3D332E4A3D
415748506253596858616C59666B5868675469655069634A6A6146675E40685E40675E42
6660476B66547B766C7C787183817A8282798280778179727D736880725D8473578C785C
907C62978A73938E7C93988A626F6665726F99A5A2667368596757333D2A505037726748
7B6B4B7D704F7C74527B75577B755A7C775E7C79627B7A657C7C6778786478786572725F
70715C7071597A775C7D785F7C765F79725C7872587C74597F735980755B7C7258797258
7A73597C745C7F78617D76617B755E7B755F736F58737058717057686C54626954666E5F
5C695D4154482E453B29433B28453A2F4A3C304839354C3B3E56463F5847596A5666664C
7467487865436248264E280000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0042AC077C60217465346F694272765A
5E6C545364504C5E4A4759464757464757454A5B4A4B5B4C5563555A6757646D5C656B58
6A6F576E725972735C79765F7A775F7E79617973587972547C77577C77587D78597F785A
817A5C7D78597B75547972537A72567671547D7B627B7D677579666D76645D6B5B526455
4B6052435A5040564F384E4827413B1B383213322A1D3B30314D413E564A4A5F4D566650
626D55676B526A684D70684A7466447967437D6A457E6B4583704887754A89764A8C784C
86754D7A7151817E6AA2A293C7C8BAC8CABBACAE9F90907E807A668A7B5D917B5492784F
92764D8E7452937F619F91787E755F777361A5A2926B6B5567684E6B6D53615F43797153
867A5C857B5F837C607E7B5E7A79617D7B667D7D68787B6576786374735F76735D78745F
79765E7C795E7E795C7E785D807A607F755F7D745B7B73597A705880755E7B725C7A735D
7A735B86806A7A776377746075705B78735F72705C6E6F5A696D59686F5D656E60586357
425248314A3E2A483D2A473C314C3F344E40364D3F3E57473B554741594C576B5B646953
6B634078673C705726309E0200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0044AE0A806427726535706D4C767E67
6575615B6D595769574F614F4D5F4D4E604F4F5F50515F535764595B675C636F63687162
636C5967705A6C715B70725C76755F7A765F7B775B7E785A7A75567D78597D77587E7658
7D775A7C775B7F7A5E7F7A5E88846887846A7F7E67797D676F7764606E5D4C61543B544A
2D4A4325433C203E361E3930183428253E33395144495C4D556554606A56696D546C6D4D
716C497467417A673C836B3E866E3E856F3E7F6C4278684275654277674285754D8D7B53
897B5676715382816D969486B5B2A8C0BEB6AEAFA49999898D88728277588F7E59927C56
957D57937C56917A56937C5A907D5A7F6F4C7C6A4977674173643D7A6F4A786F527F745C
8C846E88836C87846C84826A7E7D677C7B66797A6374755E76765E7B775F7A765B7E795D
7D775B7D785B7D785B7F7A5E7E785E80775F7D765B7E785E7C755D7D765E7D765F7C7661
7C78637A77637B766477736076735E736F5B6D6E5B676D5B646E5D657162525F52445446
3C4E40324C3D3250403350403A56473C564740594A44605047615452695D5E6F6366705C
6561407567377B63273EAC0800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0046B20D7F652870643776765877806E
6B786C6674675F6F625A6A5D586A5A5768585B6B5D5B675E5D6961636F6779857C717C72
6D7668677360636E59656C556D7058706F55726F53736F50746E4D77714F7972507C7252
7F785B837E65837F66837F67827D657F7A617B7A607579606C765F5A6B573C5446173329
0C2C231B3A2F284335384F3E46584453624C5F6951646A4F6C6C4F736C4B7B6E487E7041
83713D886F388A6D358E713A8D76416C5D314D4623534E30625C3F6E66496C6344746D4D
7B76577E7C6387846F908A778F87778C86778C88788B897487846C8A836A837B62736C55
6A664F756F5584785A84735184724C83714A927C54856E408168357F6737816C47837358
877F68827E687C7D66797B6375765E7978617C795F7B795C807C5F817D5F7D795B7E7A5C
7D785A807A5D7F7A5D7F7B5E7E795C817C60847F64827D637F79607C765B7A745B7A7560
76745F75745F736E5B6B66536B6954686B55646B58606B5B556555495B4B425443465747
4053443F56463D5846415D4C4964554C64584861554A65594D675C586E655A6C63657060
6161437165358368254AB60E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0047B20C8064286F6238707156757E6E
737E746F7B7168786C66776A63746862736763716768746B66736B6A776F78857D7F8C83
94A0958493846C7C6958634E5960475F62466565466965436C67416D673F726842746845
746B4B746E5176715879765D7C79607F7B617A795E767B5F70785E5B664F364934283D2C
384E3C485A4553624A5E674B696B4D6F6D4B756D467B6F468372458C764798804E98814A
93783E8F72359273399277408A77476359345E5B3C5755375752345B56395E5B3F5A5D43
5C634D5F66546B705F767A687074636D7062686F605A64554B5548475245374439293B2F
1C33261B2D1D3D442D7C755784744F87744C8C764E927B4E896F3A8368328C7347816F4D
81785F7A7862797A647A7A617D7B617E7A5F807C5F817B5C837D5D807C5C7C785B7F7B5F
7C77597E785A7E775B7E785C7B75587D775A7972577E795F7D775E7870567A735A726D54
6B685067644D65634D63624C5B5F4857614B5461504C5C4E485C4C485C4A485A484C5D4C
4D5E504B61524862524A65564D675A536A6151695F4F685E536C63586E665A6A61687263
64624373622F93712A2BDF0B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA148365276E60356F6E52787F6E
7681757683787483786F80766D7E746E7F756D7C736F7E736E7D72707F7476857B79897F
8D9D937D8E837D8F8172817166725D606A4F6066496365466867446C68426E6742726947
736C4E77735779785E7A7C6380816983836B81836A7E836973775D5B5E435B61435C6245
6468486C6A49716A4A736B457B704982744B8B794F8E794D8E7646907745947945997E4A
9C7F49997B4392733A9276418E7A4D7A6E496E66467371527370536A684D5D604648553B
3547332F40333643393D493F3B473E2E3C3421362E142F260E291F0C271E0C281E0F2E21
1F403135513F4E5D467372548C7D5890794F8E7549866D3F8F784588713E9A865A857856
7F775D7F7A637D7961817B5F857F61837E5F837E60868062847D5F837E617F7B5F837E63
858063827D5D86806182795D7D75587A7053776E51746C4F74694E70664B6B6648696547
6361456060485A5D4758614A4E5E484C5F4D485B4D475B4E4E6252526453536452536453
55665953685B526A5D526B5F516B60566C655C7069596E675C716A596D665E6D6368705D
6B64417E662D4DB91600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008A67247361316B6747777C68
77827379857A7F8B827C8B8276877E7A8B8376877F798980819185849386798A7E7C8C84
7D8D847A8B817B8D8278897E7584766D7B6A707B6A6D77626E765E6D72576D6E53706F56
77785F767961777C65797E697A7D6B7B7D6B7F8270838671706F5470684373673B7A6A3E
7F6E4283704784724C8174507A724F7E755781785B887E5E83795583784F85774B877547
887244887040886F3A89713C917A4C8A7851827553776F5277735A7D7A6486897489927E
8A9B8D869790B1BDBBC8D2D1B5BFC196A2A25C6F6C3C5249425345485845566955556955
596C56616E55676B4E7B72508B784E947C4D8E7443886F408E794C9181578A7D59867C5D
837D61857F65847D63857E61878161878262858060857E60827A5E817B5E888266817C61
7A7558787253787253716A4C71694C71684A6F65487066496E65496762466363475E6246
58624757624C53614E4C604E435B4B465E514D64584F665953675A5C6D5F637364607064
60716860726A5C726A5B73695B736C5C726C5E716B6477705D6F6A5C6F66606C5F6C6E56
7264398E6C2C2CE00D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075951E7B612973684284846C
7B84727E897C7F8A82838F887D8D867D8F877E918B82958E8B9C938D9E9380908780918B
788B827B8E84788C827A8D8376867C7381776F7B70758175768276798577778170707765
707764727A657079647277647577667577687679697E7F6B746D4D7A6939866D358C6F38
947643876E4277694679745771755D6D7260717666727866747964757A6073775B78785B
7E7B5C837C5B867B5585784E87774E8977518E7C5794836093816297856A978972A8A08E
B0ADA2B4B5B2C2C4C6C7C9D0BBBEC4A3A8A88A8F887F8173857D677F7559726D50706E4F
736F4E78714B7F72488774488D76488E77498D784C8F7E558D815C8981628880658B8368
878166868065878167817B60837E60827E5E7E78587E7456797053777053787155736D50
726C4E716A4B706B4C6C684A6D684B6B674968644968634C615F495C61495E685156644F
4F64504F64554D64564D65584F675B536B5E556D615C72685E726667786C68786F65756E
65757161736F5C716D5D746F5C75705E766F61776D667A7163756E6070656068556E6547
7E642F4DB91500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008E6A24796534847D5F
90968484908487938B83918B80918D80948F859995879B988A9E9A82968F819490829592
7F928C83958E7D9189798D8677898275837979847B7C877F79857F76837C758379758274
7B897874816E74806C757C69767B697579677679677878627B7150846E3D917339927237
9777418A714371613D605E426B705B757D6D7980737B82747B8273798070757F70737E6D
76816F7E8773858B7490937996957B928F73887E5F887C59927D5B9A815EA28766A48C6E
A18C719988719285728F85778A8073877C6B8A7E6688765A87704B90764B90784B917B4D
8C77488674438C7A4A917F5195855D948762928867928B6C8B866A8D886F8F89718D866F
8881698A8369827C637C765E7A75597872557A7353787051797253767052757153726E4F
747051716E4E6C6C4E686A4F66664E6A6A53686B56636A5A5F695B576455556656526657
506659556C60576E63586F655C74695D7469637A6E667D726B8076687B71687A73677A74
677B76657975617974637D785E79735F786E657C71677C7066766C6A756667664A766235
6B8F2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DB098466277D6D46
8F8E798993878C9A928797927F938E829894869B98879B998B9F9C849995839795839694
8395938C9D9884979285999581949081928B83918C86928E82918C7A8B837B8D827A8C80
78897C7D8C7D7D8A7B7F8C7D7B85777A80727A7F6F7A7D6A7F7B607F704A856E3D8E723A
93753C957844866F4372654166614463624B6564526F6D5D7878677D7F6F818778818B7C
8390808794858E9B8A919E8D95A09096A191979F8D9C9F8BA1A18BA39E859B9174887959
907B559882559A83569B835C9D85609A805A9B80599A8054987D4C947741947842957D48
A08C5AA29468A298709B9370999373969376918E73928E75918D75918E768E8A738D8670
867E67817A617F78617D776079735A777355757151757150767252767154727154737356
75745872735971745F7275656F72656D7366646E625B69605768615E70695B6E66586E64
586E6360766B62766C677C72697F756C8178687D74687E746A7F77687E766A8079667C76
687E786B817A617A73617C75607B73657C736A7E736E7F746D7669686A52706337917030
2CE00F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050BA1782642E
8173558A8B7D8E98908F9D99899C97849B94839A968A9F9D91A6A4899E9C859A987E9391
869A96869A958C9F9B889B99889C998AA09B899D9B889999889B997F958D80958A82968B
8193898595898090857F9085849088838C84889084878F7F83887682826B837D5A837649
8A7744927A478F77478A74477E6B437A67437563437160417162456F654C706D596D7261
707A6B7481727583747685777B897D7A877E6D7D7461736B5769604B5B4F4C5647585943
706541937E4D967C48997D4A987B4A977B4B947B4A957C4C9F8858B29D6DBCA87AB9A77D
ADA07AA29B7A9B97789593748F90728E8F7593927993917C93927E90917D8F8F7B878470
7F7B667D79647A776174735D76775F74775E73775A77785D7A7A6180806983826C898771
8A887480806F7D7E727779717377707178706F797167746E64747165777361766F61786F
637A706E837873877C71847C7588817689837286806E837D6D847C6E877E6E877F708881
6D857E6982796A847B6B847C6A80776F8175707D6F6C73656B6A5370613A9071332BE10F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FBA19
8567358071558A897A929A93879692889C97869C97889D9A889F9D90A6A48AA09E7E9592
869B97879C978DA19E899C9B899E9C839A968A9F9D8EA1A28EA3A2889E9A859B93849892
839690899A9387988F86968F8998928994908A948E8B978B899588919B8D8D96848E937B
9290738D86638B7E588B7A518C774E937A51957850A08155A9885BA3865E8D7757877B62
8A8671999B88B7BBAEDDE1DCEDF1F5EBF1F7CBD6D991A29E62756C5A695B5A614F6A684E
7F724A8C78448F7740907943947D4CA49163C2B289D1C49DD7CAA5D3C8A6CAC0A1C0B79B
B3AB90A39E829795789394778E937590957A91937D959784959888969D8E8E9686898F7E
868C79888C7B8A917F818B78848F7D8893828A9483899081878B7A8B8C7B989381AEA291
A79A8A958D7E8A867B89887E7F8178787E76778179707C74717F787080796A7E756A8077
6F867B778D82788D85748882798C897588877185837288836E87806B857D6E88806F8880
6E867F6C857C70867E70847B6171676C75676C6E5A6D674B7462369674362CE11000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
26DB0D8B6834816E4D837C6B84878087928F90A09D8FA39F8CA29F8EA4A28BA09E849997
90A4A28EA2A090A4A38A9D9C889C9A8DA2A08DA2A293A6A790A4A3899E9A8BA19E899D9C
8C9E9C91A19C91A19B8F9F9A8C9C9788979384948E89988F96A29996A39B8F9C9695A29A
9AA49A99A192989C899B9A84959077968A6E928363927E59967E559F845B9E845C97815A
917F5A8B7E5D887D68867E78857E8479767D65686651584B5158425D5E43646041766F47
8275488E8050A19366C2B58DE7DEBDFAF4DBF8F4DFF2EEDBECE8D4E2DECDD9D6C6CCCABA
C3C1B0BEBEA9B6B8A1AEB19BA5AD969FA89298A08E9CA4949BA5979BA79A9AAA9B99A89B
98A5999CA99FA0AFA596A69E93A49B93A59C92A0998F9A9195998F9B9A8EA89E91B9A597
B7A293A697879890809391828C8E8183877D7F88807C88807F8D847F8D85788A82768A82
798E867C928A7F968F79918C758D8A7A908E738986778D89748B85728A8472888171857E
72847E7586806E7F756B786B646D5C696B547267427F673174992700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CE00F6F9127846A407C6E567C7B6D8C958D8F9F9A94A6A493A6A48DA1A08B9F9D
96AAA892A6A495A9A894A9A794A8A794A7A68EA2A290A4A490A4A495A8A794A8A78FA2A2
90A1A19EABAB95A3A096A6A294A6A192A4A08DA09B93A49D9DACA691A09D93A3A197A6A4
97A6A3A1AEAB9FABA79DABA395A198A4ACA1A8AFA1A9AE9CA5A793A09D869F997E9D9376
9E93739D9374948E73928F7B918F809494848E917C91947B95987BA09F81B0AD8EBDBA99
CBC9A9E3E0C4F6F2DDFCFAEBFEFCF3FDFCF6FDFDF9FCFCF8FAFAF5F6F6F1F0F2ECECEDE7
EAEBE3E3E5DBDFE1D6DCE1D6D6DDD1CED9CDCCD7CCCBD6CBC2CFC7C0CEC7BACAC4AFBFBB
ABBCB9ABB9B8A4B3B198A8A899AAA993A6A393A5A09CA8A19DA29AA2A198A9A195AB9D90
B5A596A79888A0978694928397988D8E928A8A948D83908B7D8C8682928B7B9088748D85
7A918D7C948F7D969177918C78918E788F8D728886778C88798E88768B856E817A6C7C73
6A786F6D796F6974666B715B6D6A4C74653893743429DF0E00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0054BE1F936F39816D477E78608286788B958F99A8A597A8A697A8A7
9AABAA96AAA895A9A79BAFAE99ADAC9AAEAD94A8A698ACAB9DB0AF9AADAD98AAAA9CAEAE
98A8A8A0AFAF9AAAAA93A5A398ABA799AAA69BADAAA7B9B6A6B6B495A6A499ABA98EA19F
94A7A49DADAD9EAEAE99ACAB97ABA997A9A7A0B2AFA0B1ADB1BFBAABB7B1B8C0BBBBC0B8
C1C5BBCBD0C4BEC8BACED9CAD9E2D3DEE5D7D9E2D2DBE3D3E7EDDEEBEEE1F5F7EBFCFEF3
FEFFF5FEFFF8FEFEFAFEFEFEFEFEFEFDFDFDFEFEFEFDFEFEFDFDFDFDFDFDFEFEFEFEFEFD
FEFEFDFEFEFCFFFFFDFDFEFBEFF3F1E4EAE9DCE5E1D6E2DECFDBDAC7D4D4C0CCCDBBC9CA
AFBEBFB3BEC0ABB7B8A1AEAFA0B0B09BADAB9CAFAA9CA9A29DA49F9FA29BA6A69DABA79D
ACA69AB0AB9CA9A697A4A398A3A69F979F9A919E9A8A9B97849793819690879D97829A95
819895819995849D997C95917D94917C918F7A8F8D768C867388816F81786C7B716C786C
6B77686B72606C6B506F643B866F3850BF1F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004EBB1D91713C85724B837B658C908397A09B9BA8A5
A0AFAEA1B1B09CAFAE9BAFAE9BB0AF9BB0AE97ACAA9DB1AFA1B3B39FB1B29CAFAF9FB2B2
97AAAA9BAEAD9DB0B09FB1B192A4A399AAA89BADABA4B6B4A8BAB79FB2AFA3B6B3A0B3B0
9BAFAD92A6A599ADAE9CB0B198ACAC9CAFAEA1B3B4AFC1C2A1B1B1B4C2C3C0CBCDBAC4C6
C0CCCDC5D3D1BCCECCCDDFDCD0DEDDD3DDDDDBE5E5E2EBEBE4ECECEAF1F0EEF2F1FAFCFC
FFFFFEFEFEFDFEFEFEFDFDFDFEFEFEFDFDFDFDFDFDFDFDFDFEFEFEFDFDFDFDFDFDFEFDFD
FEFDFEFDFDFDFDFDFDFEFEFEFCFDFDF0F2F3E9EDEFDEE7E7D4E0E1CFDBDCCAD6D7C1CCCE
B7C3C5C2CFCFB7C4C3A9B8B6A5B5B4A7BAB7ADBEB8B4C1BAABB5B0A1ABA7AFB7B2B3B7B0
ADB0A8AAAEA4A6A89DABADA5A6ABA69CA5A39BA9A891A29F8DA29E889D998CA19D8A9F9B
839794859998849A97819995819794809493778A886D817A6B7D726A786C6C75666C725D
6B694D71643E886F3A4CBD1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0052BD1E9A7A4086724C867D648B8B7C
9EA49DA0ABA99FAEAEA2B3B2A2B4B1A0B2B09FB2B1A4B8B6A2B4B49EB0B0A3B5B5A0B3B4
9CB0B0A2B6B7A0B5B5A0B3B49FB1B0A3B5B3ABBBBAA9B9B8A4B4B3A3B5B3B2C3C2A2B5B4
ADC0BEA0B3B2A1B5B59DB1B1A2B6B4A5B8B7A3B5B5A0B3B3A3B6B6AFC0BFB8C4C6BCC8C9
C8D6D7C3D2D1C3D4D4C6D8D7CFDFDFC9D7D8D4E0E2DDE7E9DFE8EAEDF4F6ECF1F1FAFCFC
FDFDFDFCFCFCFEFEFEFEFEFEFDFDFDFDFEFDFEFEFEFDFDFDFDFDFDFDFDFDFDFDFDFDFDFD
FDFDFDFDFDFDFEFDFDFEFDFDFEFEFEFFFFFFF3F3F5E6EBEDDCE5E5D9E4E4D3DFDECEDADA
CCD9D9C0CFCFB9CAC8BACBC9B5C5C3BBCCC9BECCC9C7D2CEBDCAC6B2C0BDB6C4BEBBC8BF
B0BBB4B7C1BAB4BCB4B2B7B2B1BAB6A1ADAC9BAAAA98A9A891A4A18EA2A0889D9A8BA09C
8A9E9A899B98879B988298947E9490708380677773657369677462686B566C644777643A
92753D51BF2100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002AE011769D348F7549
8C7A5B8E867394958AA7ADA8AAB2B0AAB5B3A6B5B4A9B9B9A8B9B9A4B6B6ABBCBDA8BABB
A0B3B3A2B6B6A3B8B8A6B9BBAABCBDACBDBEACBDBDB0C1C1A8B9B9ABBBBBAEBFBFADBEBF
ABBCBCB2C2C4A9BCBCA9BDBBB0C2C0B1C2C2B0C3C2ADC1BFACC0BEB5C7C5BBCAC9BAC9C9
C3D1D1C8D7D5C8D8D6C3D4D2CCDBDAD7E4E5D6E2E3D8E3E4D7E1E3DDE7E8E3E8EBE7EBED
F1F3F5EFF1F1F7F9F9FDFDFDFEFEFEFDFEFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFD
FDFDFDFDFDFDFDFDFDFEFDFDFDFDFDFEFEFEFEFEFFF9FAFBE9EDEDE9F1F0E2ECEBD7E3E2
D6E4E4CCDDDCD0E1E0CEDDDCCAD8D7C8D5D4D1DBDBD0DBDAC6D3D2BDCCCBBECECBBBC9C4
B8C5C0B6C3BDB5C0BCB2BDBAADB7B6A3B0AF9FAFAE99A9A798A8A694A7A492A6A38EA49F
8EA29E889A9782918F7687846C7C75677367676C596766486D643D816C3C739C325AC525
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
56C126759C3791784F8E7E61988F7BA4A395A8ABA5A8B0B0A2AEAFAFBEBEB1C1C1AFC0C0
ACBFBEAEC2C0ADC1C0A9BDBEABBEBFADBFC1ACBFBFAABDBD9FB2B29FB2B2A3B6B5A7BABB
ADBDBFB3C2C5A6B8B9B1C5C2B1C4C2B4C4C4B7C8C8B6C9C8C3D5D3C5D4D3C4D2D2C1CFCF
C5D3D2C7D6D3D3E0DED4E1E0CFDCDBD8E5E5DAE5E5DAE3E4D7E1E2DDE7E8E2ECECE1E7E8
E6EAEBECF0F0ECF0EFFAFDFBFEFEFEFEFEFEFEFEFEFDFEFDFDFDFDFDFDFDFDFDFDFDFDFD
FDFDFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFDFDFDFEFEFEFFFCFEFDF9FCFCF3F9F9E1EAEB
E1ECECDDEAEAE0EDEDDEE9EAD2DDDEDBE6E7D6E0E1D0DADCC8D3D5C6D3D4C3D0D1C1CDCE
BCC8C7B8C3C2B7C3C1B0BBBAAEB8B8A3AEAFA3B1B09FAEAB9AA9A691A29F8A9D99879A95
7F8E8A76807C6E736C696D5C68654D6D623F846D3D6F9A2F55C42400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057C42879A038967B4C917D5D9A8C79A29C90AEB0A9B4BAB8B2BCBD
B2C1C0B4C5C3B1C4C3AEC1C1AFC1C2B1C4C5ADC1C1AFC3C3AABDBDACC0BFA2B6B5A5B9B9
A3B7B7AABABCABBDBDB3C7C5B7CAC8B7C9C8BBCDCCC0D3D1C7D6D6C9D6D6CBD8D8CEDBDB
C8D6D6CCD9D8DDE9E8D2DEDED8E5E5E0EDEDDDE6E7DAE1E3DFE8EADDE8E9E1ECECE8F0EF
EAEFEEE7ECEBF8FCFBFDFEFDFEFEFEFDFEFEFEFFFEFDFEFDFEFEFEFEFEFEFDFDFDFDFEFD
FDFEFDFDFDFDFDFDFDFEFEFEFEFDFDFEFDFDFEFEFEFDFDFDFEFEFEFDFFFEFAFEFEEEF5F5
F1FAFAE4EEEFDCE8E9DBE5E7D7E1E4D6E0E2D2DCDECFDADCCCD7DAC8D3D6C8D3D7C4D0D4
BCC9CBB7C2C3B4BEBFB0B9BBABB5B6A3ADAEA0AAAA97A19F8F9A967F8D857380756F7567
6A68556F644A7665408A7241729D3457C52700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002DE21550BE27A380549A7E5D95826DA19487
A7A398AFB3ACB4BBB7B1BBBAACBABAB3C3C5B5C7C8BACBCCB5C6C7B8C8C9B2C5C5B3C6C6
B1C5C3B3C4C4B5C6C6BBCECFBACDCCBED1CFBCCFCDB9CBCAC5D4D3C8D6D6C9D6D6D3DEDE
D3DEDED1DCDDD1DCDDD2DDDED2DFDFD6E2E3D7E1E2DBE3E4D9E2E3DBE5E5DFEAEAE3EDEC
E8EFEEEAF0F0EEF3F4F5F8F8F5F7F7F5F7F6F6F8F7FAFBFAFCFCFCFEFEFEFEFEFEFDFDFD
FDFDFDFDFDFDFEFEFEFDFDFDFDFDFDFEFEFDFDFDFDFDFDFDFEFEFEFCFDFDF5FAFAF0F6F6
EBF2F3E3ECEDDAE8E8D7E6E6DAE8E9D1DDDFCAD6DACBD6DAC7D2D6C4CFD4BCC7CDB4C0C4
A9B6B8AEB8BAABB0B3A5A9AC9DA1A096999686867E7A75686F68546B6447746943897547
709B3551C1272EE41500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005DC82F51BF2C
79A0449C805F9681669A8C759D9886A7A79BBABEB6BFC3BFBEC4C2BBC5C5B4C0C2B6C3C4
B8C5C6B7C4C5BBCACAC0D0D0BFD0CFC9D8D6C6D6D5C6D6D5C9D8D8C9D8D8C9D7D7D3DFE0
D8E3E3DAE5E5D6E0E2D7E1E2D8E3E3D5E1E1DBE6E5E0EAE9DCE6E4E1E9E8E0E8E8E2ECEB
E6EFEEE9F1F0ECF1F1F2F6F6F4F6F7F3F6F5F7FAF9FAFBFBFDFDFDFEFEFEFDFDFDFDFDFD
FEFEFEFDFDFEFDFDFEFEFEFEFDFEFDFEFEFEFEFFFFFEFEFEF9FAFAF1F5F6ECF1F3E9F0F3
E8EEF1D9E1E3D4E1E2CBDBDBC7D6D7C2D0D3B3C2C6B6C1C7B5BFC4AAB3B6ADB4B4A4AAA6
999D9793938B827D737E7465776A53786647836A4295754446B61F53C2272EE51600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0035E81A64CE325CC92F4FC02AA88859A0835D9A81619A896E9C927AAAA291B4ACA0
BFBAB3C3C3BCC8CCC6CED4CED0D6D2CBD3D2C5D1D1CAD6D7C5D3D4C3D2D3C4D3D5CFDDDE
D0DDDED7E5E4DAE5E5E4EEEEE5EFEEE0EAE9E0EBEAE5EFEDE5EDEAE6EBEAEAF1F0E5EDEC
EFF7F5F5FAF9F9FCFCF8FAFBFAFBFCFBFCFBFBFCFBFCFDFCFDFDFDFEFEFEFEFEFEFEFEFE
FEFEFEFEFDFEFEFEFFFEFFFFFEFFFFFBFCFDF9FAFCF2F4F7F0F3F7EDF2F7DFE7ECD9E1E8
D5DAE2D1D7DDC6CFD2BAC4C5B6BFBFB3B9B8A6A9A49A9B9392908689827382745F7E6D51
836E4A8B72489D7D4D47B82253C1272EE41500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0069D13362CD305BC92E53C22C4CBD2B
A9885EA487629F89689F8B70AB9985B0A293B6AFA3BEBCB0C7C5BEC9CBC6D1D6D2D8DDDA
D8DFDCDBE2E0E0E5E5E1E4E5E8EAECE6EBECE6EDEEEDF1F3EBEDEFEDEFF2ECF0F3EBEFF2
F0F4F7EEF2F5F6F9FCFAFBFDFBFDFDFAFDFDFAFBFCFCFDFEFCFEFFFEFEFFFEFEFFFDFDFF
FDFEFFFBFCFEF5F6F9F4F4F6EDEDEFE4E5E7DDDDDED7D6D7CCCACCC3C1C2B0B0AFA8A8A4
9C9992958F858C83768C816D8B7B648C775A937B56987C52A283534BBC2755C22A5DC82C
32E71800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0034E81A65D13560CC345BC73355C43281A748AD8B62A78A64A48B6AA58F72
A59076A7937EAB9785AF9C8CB5A496B5A79BBDB0A6C6B7ADCBBBB3CABEB7C9C0BACEC6BF
D1C9C3D3CBC5D4CCC5D5CDC6D0CBC4CEC7C2CDC6C2CAC4BFC4BDB8C1B9B3C3B9B3C1B6AF
B8AEA6ACA29AA59A8DA395859E8E7B9A8A7596856D98836A977F639B82619F845EA2845A
A787584DBF2C54C42F5AC82F61CC3100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0034E81968D134
68D13669D13965CF3864CE3960CB375DCA3791B351C69B6C8DAF50C0976CBF986EBD976C
B89467B79568B79667B59568B29368B6966CB7956CB69569B99669BB9768BC97678AAF4F
57C83656C73459C8335ECC3461CE3563CF3564D03365CF3333E71900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0108209 0.488926 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0108209 0.732558 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C834
59C9355AC9365CC9365CC9355ECD3B61D14389B25CBB9C81BD9F86BC9C80B29274B59678
51C337AD9173BCA285BCA48CBAA590B19B88B29D8A857668796F639486738A7A62887760
9B886D5AD1457FAF5953CA3E56C93D55C63A55C5382AE11B00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008CB65EB89A7CBA9D81
BEA588C7B095BDA38BC2A78FDCC7B5D8C9B9CCBEAEC9BAA9CEBEACBAA793AC9580C3AE9B
D2C3B5C0B5A8CBC1B6D6CEC8B6B3B2868484B0AAA842464C1D2E39626C6FA7A8A48F9190
9B9F9DC9CCC8B0B6B1BDC1BBC7C4BACAC1B5C4B7A9C1B0A2BCA797B59E8EB39A8784B163
59CD4256C93D51C33600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE318
59C6315BC734B69169B8946CBA9A72B89E7BD2BB9DCCB69CB6A28AD4C4AED2C4B0BAA996
BCAB97D7CBBCDDD1C5CBBDB1CFC2B7CFC7BCC5BDB1AEA393BDAE9ECCBFB2C3B6AAC6BBB1
D5D0CBC2C2BEB3B1ACBCB9B5A1A2A26E6E719E9A98B1B3B399A8AF90A4AEBBC9CEA9BAC4
3450655B7B915B7B8C627E8BBCCED2C8CFCFC9CCCACCCBC9CECBC8CEC9C7CEC9C6CEC9C4
CFCAC2CEC5BCC5B8AEBCAFA3B3A393AC978555CA4300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002CE31959C7325BCA3489B14FB8986BBD9C72
C09D76C19E7AC5A484CBAB8FC4A78DC0A88FD4C3ACCFBEA9B9A790B8A68FC2B5A2CAC0AE
BFB5A5D3CABED8D2C9C8BEB3BAAE9EC6BDAFCEC9BCC7C0B4CAC2B8D6D1CAD6D1CABBB3AC
C2BDB6B3B2ADB0AEA8ABA89FCAC8C1D3D3D1C0C1C1BCC0C1AAB9C2334D66536D838FA1B2
203A5412345182A2B6748E9CB0C6D0C1D0D5C7D0D3CBD1D4CAD0D2CDCFD3CCCFD1CCCED1
CCD0D1CACECFCCCECECCCDCCCACAC8CEC9C8C7BFBBC4B9B3BAABA0AF9A8859CE4550C236
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002DE3195BCA35B8946FBB9874BC9B76C09E7AC3A480C4A682C4A682
C7A885C5A987C6AB8DD1B7A0CFB7A0C9B198C7B099C8B29DC8B09DBEA894CEBEACD3CABC
BEB6A9A69D92AEA69DC6BDB5CAC1B7CBC3B9D8D5CDD6D6CEC1BEB5C0BCB3C8C2BBC2BAB3
BCB5ADD6D4CED6D6D0C7C7BFC0C1B9CBCFCD8690938891949BA3A94B5C6F455C6F9FB1BA
A9BCC785A0B29CBAC8B6D3DF648495ABC6D2C0CFD3C8D2D4C9D1D4CCD1D5CAD0D4CDD3D7
C6CED1C9CED1CBD0D3C9D0D3C9D0D3C7CCCFC9CBCEC9CBCEC7CAC9C7C7C3CAC6BFCBC1B8
C3AFA4A88E7E94755E47B52922D81100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC935
5ECC3ABA9670BC9974BC9D76BEA07BC0A07FC4A284C7A78AC7A98DC8AB8FC9AD90C9B090
CBB293CCB393CCB296CDB39ACEB69ECEB8A0CEB9A2D5C1AEE0CCBBC8B4A1C4AF9CBCAC9D
A79F90BEB7A9CDC5BCC7C2BDCDC8C3C6BCB5CBC4BCCDCCC4C3C1B9BFBCB4D7D5CEDADAD4
C6C6C1CBCCC7CDCFCABEBEB8B3B2A9B7B5AE979B9C9DA1A3B8BCB9CAD2D7B7C8D498AFBD
B8D1E14E6F8C254E6F799FB9284C667090A7BFD2DAC7D2D5C6CFD3C8D1D3C7D1D2CBD4D7
C7D1D2C9D0D2CCD1D4C8D0D3C7D1D3C8D0D3C8CED3BFC8CEBDC8CBC4CDCFC5CCCCC6C9C8
C7C5C4C7BEBCBDB1ACB1A1969D857489674F42B02100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BCA3486AE4FB79A72BDA37E
BEA281BD9F81BEA283C0A686C2A889C7AB8ECCAE92CCAF95CAAF98CEB49ECEB7A0CBB69E
CBB79FCEBAA0D0BAA2D3BAA3D5BFA9DAC8B3CFBEA8D2C0ABCEBCA7CBB4A0D0B7A4B9A99A
CEC7BBD9D4CACDC7BDCAC5BFAAA69FC7BFB5C7C0B6D8D7CEDBDAD5CECDC8CECDC7D9D7D3
CCCAC4C0BCB5C5C1BAC2BEB8C4C0B8C3BFB9D5D8D4CFD6D6B7BFC0C8D0D7687F9623476D
6D8EAE3F5F82143A6261839DA8C2D38EA8B8BDD3DDC6D5D9C6D2D6C7D1D3C8D2D4C6D0D2
C6D0D1C6CED0C8D0D4C8CFD5C4CDD2C2CCCEC6CED4C4CDD5C0CBD0C5CDD2C4CCCEC6CECE
C4CACBC5C7C9C0C2C4C1C1C0C4BFBAB9AAA29D877686694D3DAD1D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002CE41BB09268B3986EB99E77B79C77B79F7BBAA381
C0A887C1A888C4AB8BC6AD8FCAB398C8B196CEB89FCFBBA5CCBAA5D3C0ACD2C1ACD0BFAA
C9B8A5D0BFACD3C2AFD7C3B0D7C4B0D8C6B0D7C5ACD7C3AAD6C2AADDC7B3D7C1AEC3B2A3
B2A99FCDC7BEC7C0B6ABA69CBCB9B0DAD6CECAC7BFD3D2CBDADAD3CECBC4C2BBB2CCC5BE
D3CEC8C7C2BBD2CFC8DBD8D3D6D4D0CCCAC6CACBC8B7BFC2768489A9B3B88F9EAE46607F
7D94ADBDCEE0A5BBCE9BB6C9BAD3E295B2C36E8FA1BED6DFC8D6D9CCD6D8CCD4D9C9D1D4
C8D0D3C8CFD4CBD2D8C9D0D6C7CED4C5CCD2C4CDD3C4CDD6C4CED6C4CDD2C0CACDC3CCD0
C2CBCEC5CBCFC1C8CAC3C7CABEC1C4C1C3C3C1BEBBB7ACA4988471628D381ED50D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CE3185AC8335ACA36B0946CB59B76BAA17DBCA583BAA281BBA381BCA582BDA886
BEAA8AC2AD8FC8B295CDB89ECCB8A1CAB9A3CABAA6B7AA9AADA295A69A8BCABDABD4C3B0
D4C1ADD6C4B0DBC9B5DBC9B5DAC8B4DBC9B2DCC8B0DCC6AEDAC6AFDDCBB7D7C6B1D5C4AF
BCAF9EB9AFA4C1B8B1B8B2A9D7D4CCD8D7D1C4C1BAB9B5ABC7C3B9CFCBC2C7C2BAD2CCC6
DAD6D2D8D7D3C4C1BCD3CDC8D2CDC8C5C0BABBB6B0BFC0BEA4ACADB2B8BBCBD2D6C5D3E1
A2B6C7AABDCAA3BACC2B4E6E3A607F6185A01C435D9DBCCDC4D8DBCED9DACCD6D7CAD5D7
CAD3D8CAD3DACDD5DBC9D2D5C9D3D5CCD3D8C8CFD6C8CFD7C7CED6C6CDD5C2CBD0C0C9CF
C1CBCFC4CED0C4CDD0C0C8CCC1C7CCC2C6CABCC2C5C0C1C3C5C0BCAB9B90856D583BAB1E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058C833
85AE4FB7996FBB9C75B89C78B99F7DB9A380B7A380B8A384B7A383BDA987C1AD8AC1AD8C
C3AF91C8B298CDB79FCDB8A3CEBBA9D0BFAFC2B6A6B9AFA3D4C9C1A89E94C1B4A4DAC9B6
DECAB8DDC8B5DFCAB6DCC8B6DDCBB7DFCEB9E0CFB8E0CCB5E0CCB4DAC9B2D9C9B1D8C8B0
D2C5B0DED3C5E2D7CED0C6BCCBC2B6CAC4BAA6A49D9B9B95A6A8A0D8DAD2D8D7D1C4BEB8
CFCAC5CFCAC6BCB5AFC6BCB4CFC8C0D7D4CDC9C5BFCDCDC8D5D7D4C8CBCCADB1B4A4B1BD
2745603D5D788CA6BB2A4869183C5FA1C0D68AA7BA96B4C4C3DAE1CBD9DACCD7D9CAD4D6
C5CFD1C2CDD0C5D0D2C9D4D6C9D4D6CBD4D9C9D2D7C9D2D9C7CFD6C7D0D5C1CACFBFC8CD
BCC7CBC2CDD2C3CED4C1CAD1BFC8CDBFC7CCBDC5CBBDC1C9BDBFC5BDBCBFAEA9A68A796C
5E883600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE51A83AE4FB0956E
B89C78BC9F7DBFA282BDA283B9A083B6A084B5A082B7A284C0AB8CC1AD8CC9B393CAB697
C9B79CCDBBA1D3C0A7D1BDA6CFBCA9D0C1B1D6CEC1D9D5CFDCD7D3B3AAA0CCBDABD7C4AE
DDC8B3DECAB7DECCB8D9C7B5D9CAB8DCCEBDE0D0BDDFCDB7DECCB3DCCBB3DECEBADBCFBB
D4C8B3D4C5B4D4C5B6CFC1B2CBBFB0D6CDC3C2BFBBCBCBC88C9089CACDC5D2D1CAC0B8B1
C3BAB1D5D0C6D6D4CAC9C7BDCECDC4D8D9D2D4D6CFBBBBB4C2C4BF868B8E949A99ACB1B4
5D6F80536C80B0C4CFB3C7D58BA8BDA2C0D1B4D0E253768DA0C1D0C4D7DECAD4D6CAD3D6
C9D3D5C8D4D4C7D3D4C8D2D4C6D0D2C8D1D7C7CED6C6CFD7C5CED5C3CCD3C2C9CFC1C8D0
BCC5CCBDC6CDC2CBD2C2CBD0C3CCD3C3CAD3BEC7D0BBC2CBBBC1C8BEC4C9B8BEC3A7A6AB
7B736D55863700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002CE41958C934B0956CB09970B6A079
BAA17FBBA182BBA082BDA385BDA489B9A48CBAA58CBEA88BC8B192CAB294CCB498CDB89F
CEBBA3D1BFA7D4C0A8D3BCA5D1BDA6CDC1AFDEDBD0DCDDDADFDCDBD6CBC3D5C4B2D8C3AC
DBC6B0D9C7B1D7C9B4D7CDBFDDD6CDDFD9D0DCD2C5DECFBBDDCBB3DFCAB4DBC9B5D9C9B5
D8C8B4D8C6B1D8C8B6E1D4C5D3C8BAD3C7BCD4C9C4B1ABA6ABA79FC3BDB3D7D4CCD6D2CC
C7C1BAD8D6CDDADBD3D3D3CBC2BDB6CBC4BEC7C2BBB4AFA5BAB7B0B8BAB9B6B8B7BCBBB9
D2D8DCBDCED89CAEB6B1C4D046647E264C6C7CA0B9224764537A91C0D8E2CBD7DACCD4D7
CBD5D6CAD6D7C8D5D5CCD5D8CCD4D8CAD1D9C9D0DAC4CCD3C2CBD1BEC7CEBEC7CDBDC6CB
BBC4C8C1CACEC0C9CEC5CED3C7D0D5C5CED5C2CCD3BBC4CBB8C3C8BCC6CABFC7CFABB1BC
3F4652404042467D341AD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C73484AE51B3986FB1976FB59B74B59F78BAA482
B89E81BAA083BBA286BDA389C3AB92C3AD96C1AB92C5B095CAB599C9B499CAB49ACEB9A1
D2BFA8D2BEA9D1BCA7D1BBA6D4BEA9D4C5B1DDD8CAE0DED7DED8D1D5C7BAD7C5B2D8C3AC
D9C4AEC9BBA7B3AB9DBCBAB4CCCECCDADCDAE0DDD6DACFC0DCCCB7E0CBB5DDCAB5DBC9B4
DACAB3D7C7AED6C6B2DCD0C1D3C7BACEC0B2CFC1B6D6CCC2D3CBC3C7BFB8DCD9D1DBDAD4
CAC9C0C2BFB4CBC8BEC7C3BAC3BAB3C5BCB5DAD5D1D6D4CFC2C0BCD4D5D1D1D6D2A7ABA6
B3BABB5F74842C495F8CA3B6445F7B1033577D9FB69EBBCC7492A5B8D0DCC8D7D9CDD7D9
CCD6D8CBD6D8CBD6D8CDD5DACBD2D8CCD3DBC9D2D9C8CFD6C7CED3C1CACEBCC5C9B9C0C6
B6C0C2B7C2C6B9C4C6BFC9CDC4CFD3C6CFD7BFC9D2BFC8D0BBC6CCBAC4CDBFC8D1BDC6D0
7C8894717F8A62676B66594A1DD61000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0056C835AE936EB19672B39873B39974B49C77B69E7BB9A282B9A285
B79E87BAA28BBEA891C3AD97C3AC96C7B09CCAB59DCCB89ECCB79EC8B399CBB69CCDBBA1
CDBBA2CEBBA3D0BEA6D0BEA6D4C0A8D5C2ACD2C4B2D4C7B9D7C6B6D3BEA8D8C2AAD9C3AD
CCBBA9AEA391CDC6B9DAD8D3BFC1C2CED0D1DEDCD6D9D0C4DCCCBBDFCBB8DFCAB7DCC9B4
DAC8B2D8C6B0D5C3AFD2C1B0D2C2B1D0C1B1CEC2B4E0D7CFDFD8D2C6BEB6CAC1B6CECABF
C3BFB4BEB6ABD5CEC4DFDBD3D7D5CFC4C0BCD9D5D4DAD9D5BBB7B4B9B4B0B1B3AF767B7A
A8AAAC919BA853697E98ABBABFD1DE92AAC0849FB5B5CDDD86A3B56C8C9FC1D9E1C9D6D9
CBD5D7CBD5D7CAD3D8CDD6DBCDD6DBD0D7DCCCD5DACDD4DCCCD3DAC7CED4C2C9CFBEC7CC
BCC6C8BAC4C6B8C1C4AFB6BCB6BFC2BDC6CDBBC6CCBDC6CDC0CBD0BFC9D1BFCAD3BCC7D0
A6B4C08798A88B9CA69CA2A390827100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002AE31980AD4FAE9471B19776B39977B29B75B19C77B19B79B79E80BBA287B9A28A
B9A38DBEA893C5B09CC8B59FC6B39DCAB69FC9B49BC8B398C8B399C8B199CCB49CCAB59C
CCB89FCBB79ECBBAA0CDBDA2D2BEA6D2BCA7D4C1ABD3C0AAD7C1A7D3BDA0D8C1A5D8C4AD
B4A694BBB2A2D2CABEDDD8D1CCCCC8C4C3BDD9D2C8DCCDBDDECCB8DDC8B3DECAB4DEC9B4
D9C6AED9C6AED8C3AED1C0ACDDCDBDDDD0C1C9BCADCFC3B7CCC2B7C5B9ABBFB2A3D3CEC1
DBD8CFD3CCC5D1CBC5DBD8D3D7D8D3C1BCB7C1B8B3CAC4BFC1B9B5B6ADAAD4D1CFC5C7C5
B6B7B3CED0D0C9D4DBA0B2BBA9BCC57A93A8183B5C4F718D5778921A3E5DA6C5D9C7D7DD
C9D4D6CCD5DACCD3DBCCD5DCCDD6DACDD4DACCD5DCCCD3DCCDD6DDC7D0D5C6D0D2C4CDD2
BEC8CDC0C7CDBDC4C7B6BDC0B2BABDB3BCC1B4BEC1B8C3C5B5C0C3BFC9D1B7C5CEBCC9D3
B3C2D03A4B62334A603A515E6E76775B904400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C733
53C733A89067AD956FB09775B39978B59C7BB29C7BB19D7EB39F81BEA78BBDA68CC0A991
C3AE98C9B39CC9B39CC9B29CC8B19AC6B097C4AE93C7AF93C6B195C6B196C9B198CCB39B
CBB59DCCB99FCCBB9ECEBD9FD3BEA5D2BDA5D2BEA5D4C0A6D7C1A5D8C0A2D5BC9EDAC1A8
C2AE9AAB9D8CD2C7B9CAC2B6ACA598CBC1B2DBCCBADDCCB7DECBB4DECBB3DBC7B0DBC8B0
D8C7ADD6C3AAD4C1A9D1C2ABD3C2B0D4C2B2D0BCACCAB9A9D0C4B5DAD0C5C5BCB1CFCBBF
D9D9D1D7D5CFBDB7B0C2BDB6C7C6BEC9C3BFBEB4ADD5D0CBD8D6D3C3C1BEC9C8C5D4D5D2
B6B7B2A8A9A48F9BA130495E506D808099AB23406033536FB4CEE2728EA58FAEC1C2D7E1
C7D4DAC9D4DACBD4DBCDD6DDCFD8DFCED6DECDD6DDCBD3DCC9D2DAC2CDD2CAD4D8C8D0D5
C2CBD0C0C7CDC2CACEC2CACEBDC5CABBC2CBB6BEC4B6BFC4B6BFC6B9C3CCBDC7D1B0B9C6
B8C1D0738193667B8E4D647653657085858261914400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007BAA4BA79169
A7916AAC956FAF9773B09876B39A7AB49C7DB49E81B39E83BBA68DC0AA91C5AE95C6AF98
C4AF99C4B098C4AF96C6AF97C6AD95C5AB92C5AC92C5AE94C5B197C6B299CAB49ACCB49A
CCB59BCCB89DCEBA9FCFBBA1D0BBA2D3BDA5D1BBA3D3BDA5D4BEA2D6BEA1DABEA1DCBEA5
D9BFA8BCA995AC9C8DAFA090C8B8A5D9C8B2DCCAB4DDCBB5DBC9B3DAC8B2D8C5B0DAC6AF
D9C5ACD6C2A8D5C2AACFBDA6D0BDA7D2BFABD4C1AFC9B8A7D0C6B8DAD5CACCC6BBBBB3A5
C4BFB2C8C4B9C1BDB2BDB9AFD2D0CADCDAD6CEC9C5C4C0BBD1D1CCBFBCB8ABA5A0B9B5B2
8B8C899B9D98BABDC16372855D7485B7C8D2B0C2CF8FA8B9A0B8C8AAC2D6577992ABCADC
C1D4DBC8D2D8CCD3D9CCD5DACFD8DFCED8DECBD6DCCCD6DFCCD6DDC9D2D9C8D1D7C7CED7
C3CAD2C1C8D0C4CBD3C8D1D9C3CDD5C3C9D4BBC4CCBBC6CCBCC8CEBDC7D0C1CAD3B0B9C2
AEB6BF9FAAB592A3B198ACBB889BA59CA6AAA9A1993EB02500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A48B64A78F69A7916C
AB9370AE9574B09778B49B7CB49D7DB5A082B8A287BBA38BBFA38EC6AD97C8B29AC4AF98
C1AD95BFAE94BEAB8FC1AB90C4AB90C4AB8FC2AC92C2AD95C5B19AC9B59DCEB89ECDB59A
CEB69ACDB89ECCB9A0CDBAA2CDB9A2CFBAA2D3BEA6D3BFA6D5C0A7D6BFA5D8BFA4D7BCA1
DAC0A4D8C3A8D8C3ACD9C4AED8C3ACDCC7B1DCC7B2DFCAB4DDC9B1DAC7AFDAC7B0D9C3AC
D9C3AAD8C3A9D5C0A9D3BEA6D3BEA7D3BEABE0CFBCCDBCACC8B8A9C8BCAFC3B8ABC2B4A7
C4B9ADDDD8CFD9D5CEC4BEB8CAC4C0D5D1CDC9C2BEB4A9A1B8B0A7C2B9B6B6ADABC8C2BE
CECECBC1C2C0BDBCBDCED3DAB4C1CB95A1A9A0B1BD334F692B4E6E7F9EBC16395E648AA5
BFD7E1C9D4DACBD5D8CCD3D9CFD8DFCDD6DFCCD6DFCDD6DFCDD6DDCDD4DCCDD6DDC7CDD8
C7CED7C1CAD1C8D1D8C9D1DBC8D2DBC6CFD9C3CCD5C5CFD6C0CDD3B8C5CDBEC8D1B2BEC4
B0BAC0A0A6B1414D5E44596D5268756C7C8091979395847500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0028E11979A64CA68F6CA7916FA99171
AB9273AE9678B19B7EB29C7FBBA287C2A88CCAA98FC89C87C79782CDA48AC4A88EBEAA90
BBAA91BBAA8FBBA78AC1A98DC3AA8CC3AA8DC5AF95C5B199C7B29CC8B39DC8B399C9B196
CAB59ACCB9A1C5B6A0BEB39FBCB39FC3B8A4CBBEA8D1BFA8D2BEA6D6C0A5D7BEA5D9BFA5
D9C0A4D9C3A7D7C3A9D8C4ABDBC6AEDBC7AFDBC7AFDCC9B1DBC9B1DBC9B1D8C5ADD9C4AC
D9C2A9D9C1A9D6BDA6D4BCA6D3BAA4D0B9A4D0BAA7CDB9A6C9B5A4C9BAAADCD3C8D6CCC2
C1B5AAD4CCC0D2CDC3C4BDB2B7AFA4C2BAB0CEC6BFC1B8B0C2BCB4DAD6D2D4D2D0B9B7B3
CECFC9C4C5C0A1A09CACADAF566573364D5F96ACBA3C557214355997B5D086A2BB608096
BDD6E1C6D3D9CCD4D7CDD4DACFD6DCCED7DECBD6DCCBD4DDCED7E0CED7E0CBD4DDC4CDD6
C6CFD4C4CDD2C5CED4C6CFD8BFC9D1B7C3CCB4BEC8C5CFD6C5D0D6BEC9CFBDC8CEB6C1C7
B4BCC2B1B4BE565D6E5565794C606F6577817F8B8E9088843DB02800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A18866A18A689F8A68A18C6CA59173AA967B
B09D83B5A48AB3A28ABCA690C3A38EC69984D79482B65B4B9D3423BB644CCC987AC2A586
BBA688BCA68BBEA58CC1A78DC4AA8DC4AB8EC4AB91C4AD95C6B099C6B099C5B096C7B297
C2B29BA49B89817D707170656C6D656C6F678C8E81BCB4A2D1C1A8D6BFA7D8C0A8DAC2A9
D8BFA4D9C3A4D7C3A6D8C4A9D8C5ABDBC6ADDBC5AEDCC8B1DBC8B0DAC8B0D9C6AED9C4AC
D9C2AAD9C0A8D7BDA6D3BBA3D2BBA3D1BBA4CFB9A3D5C1ADCFBCACC8B8A8D5CABCD0C7BB
BDAFA1C1B2A2C8BDAECEC6B9C2BCB0C7C2B9DAD7D2D6D5D0B8B5B0CBC6C1CAC6C1ABA8A0
AFADA4ABABA88C8E8CB6B6B899A2AD586C7C9BAAB6BDCCD796AFBE8DA7BAA9C1D068879C
89AABBC3D5DECDD5D9CDD4DACFD6DCCED6DDCAD5DBC9D4DACBD6DDCBD5DFC9D4DDC5D0D6
C7D2D6C7D0D7C4CDD4C6CFD6C2CBD2B5BDC6A9B1B9B4BBC3C2CDD6BFCAD3C4CED8B8C1C9
B8C0C8BBC1C8909BA481939F8297A28DA0A9A1AFB6ACADB095837A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CC22F9885619A88679D8B6BA39173A59377AC9B82AE9E85
B2A38AB3A48DB6A68FBDA491C99A89A14E3DA52E1FB32418B42012A12912C98365C5A182
BDA386C2A78FC2A78EC4A98EC3A98BC4AA8CC4A98EC5AB91CDB49BC7AF95C5AE95BEAE97
8F87757272628A87789A94869A93887D7D7560645E74756BBEB5A1D3BEA6D7BFA7D7BFA8
D6BFA6DAC2A7D8C1A5D8C4A7D8C5A8DBC7ADDBC7AFDBC5AFDCC7AFDDC9B1D8C4ACD9C5AD
D8C3AAD6C0A7D9C1A7D5BDA3D5BFA7D3BEA6D0BBA4D3BFABD0BDABC8B6A2C4B59FC4B7A4
C7B8A8C1B3A3D6CFC3DBD8CFD8D6D0BFBCB5CBC9BFCBC8C0B3ACA5B0A79ECCC4BDC8C4BF
B3B1ABD4D4D3CACBCDB0B0AFC4C7C8C2CAD097A0A7A0AAB26B82932245646A8BA9345573
315473B8D3E2C9D7DBCCD3D8D1D8DECED6DFCDD7DDC9D4DACAD5DBCCD6DFC9D3DCC8D4DA
C9D4DAC3CCD5C6CFD8C6CFD8C7D0D8BFC5CFAEB5BDAEB7BEC0CCD4C0CED5C2CED6BFC8D1
C0CBD4BCC8D18494A1374C5B415966667E8685979EA4ACB3B0A9A840B42B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CC2309989649C8E6BA19274A19278A6967EAC9E85AB9D86B1A28A
B0A188B4A48BB6A28ABF9C87B6715EA83A27B12715B52110B22410B64B30D09475C4A285
C0A589C3A88CC2A78BC1A78AC3A98AC4A98BC6AB8DC6AB8DC8AD91C5AA91C1AC96968A7A
6D6D5F919283A39F8CA69F8AA9A18F9F9A8D7679725B615A92907FCEC0A5D4BFA4D5BFA4
D8C1A6DAC1A7DAC1A3D8C0A2DAC4A8DBC7AED8C7ADDCC8AFDCC8AFDBC8B0D8C6ADD6C5AB
D6C3AAD5C0A8D5BFA7D5BEA6D2BCA4CFBAA2CFB7A2CFB8A3CAB5A1CAB6A2C4B49DD2C5B3
E1D4C9C1B5AAC1B9ADCAC5BBC6C4BDB8B4AAB7B3A7D2CFC5D3CDC8B7B1ABD5D2C9D5D4CF
BCBAB6BCBAB6C2C1BEA8A7A1A0A19A939A9E3546566C7F8E849AAE17375A41607FA0BAD0
526F83A7C1CCC4D5DAC9D5D9CED5DBCED6DECCD5DDCBD4DBCBD4DACDD6DDC8D2DBCAD3DC
C9D2DBC4CDD7C4CED6C3CDD6C5CFD7C6CDD6BAC2C7ABB3B8C2CDD2C0CDD5C1CBD3C1CBD5
C2CFD8BECCD797A7B72F43583E56694A64726F858E96A3AA98989A62954D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0024DF179787649C8E6C9D8F72A1927BA49680A69A85A79B85AC9E87B1A18A
B2A189B6A48BB39B81BE91769C432DAE3720C54D33DA6B509D381DCB8164CB9F82C1A488
BFA589C0A789C1A88AC1A887C2A987C3A888C7AA89C7AA8AC5A88AC2A78BB3A48F676557
77796C9E9C89A6A08BA59E8CAAA291A8A0927F80775D675F737868CABEA6D3BCA0D6BCA2
D6BCA4DAC0A7DBC2A4DBC3A4DAC4A8D9C5ACDBC6AEDCC7AFDCC7B1D9C6AFD9C6AED7C3AA
D8C4AAD5C1A7D5C1A8D5C0A9D3BCA5D1B8A2D0B7A1CEB7A2CBB7A3D6C3B1C4B29FC5B4A3
CCBDAEC2B2A3BDAD9EB6AB9ECBC6BCD1CCC7BCBAB2D3D2CCD7D7D2C1BCB8B6AFA7C1BBB4
B2ACA4A59E95C0BCB58F8F8B9EA09CC7CCCE64717F647280C0CAD2ACB3BF8F959DBABBBC
B1B4B6909A9FC7D2D5CAD3D6CDD6D8CED6DBCBD5DAC8D4DBC8D3DBCAD3DCCAD3DCC9D2DB
C7D0D9C7CDD8C7CDD7C3CBD4C4CBD1C0C5C2C6CBC2C4CBC8C0CACEBECCD3BDCAD3C2CFD8
C2CFD8BECAD7AEBCCB7B8B9A7689976277827E939C9DACB4B6BBC0978C861BD40F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
22DD146699408C7D5B9586659B8D709B8E75A2967EA3977FA79C85A89B83A99980AE9D83
AC9A7FAF9D80B49D80BD9277A7583E982E14AB4A2BD58B69AF7554C79A7BC0A084BFA48A
BFA388BFA286BFA385BFA385C2A587C2A484C3A485C3A585C5A888C0A68B9588755C5D52
7A7F70989983A09C84A29E8A9E998B939084797C775A645E727769C6BBA3D1BCA1D6C0A5
D6BDA5D7BEA7DAC2A7DAC2A4D8C1A5D9C2A8DBC5ADDAC5ADDAC6AED9C5ADD8C4ABD6C3AA
D8C5ABD5C1A8D6C2AAD4BFAAD2BDA8D1BCA4CFBAA2CDB8A2C7B5A0CBB7A3C9B39EC5B09B
C2B09ECCBCAAC3B4A4BBAFA2D0CABFD6D5CFC4C2BCB6B1AAC1BBB3B7ADA7B1A49DC3B8B1
D2CCC6BFBAB5D1CDC8CFCBC9C2BCB9BAADAAC4AFB1B39697B38C8BC39392BB8782BA827C
B98481A67A7CBE9B9FC8AEB1CCC0C2CECDD1CFD3D8C9D1D7CAD4D9C7D0D6C7D0D7C9D2D9
CBD4DBC5CED7C7CED8C7CED7C9CDCDB1AE95ADA87DCBCAAEBFC6C0C2C9D1C2CBD5C1CDD9
B9C7D2C2CEDCBCC8D56A76864D5E6D63758076878F859299A1AAADBEBBBA43B83300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0021DC15
8473548777588B7C608D80659589709D917AA29680A39880A99E85A99C81A99A7EAB9A7C
AB9A7CAE9D7FB39F7FB99B7DC59779BA7F60B37C5AC59D7BBE9D7EBEA083BBA084BCA286
BFA386BE9F80C1A382BFA081BEA080C1A483BE9F7EC0A280C2A482BFA4868A7E6A595D52
6A7367838774898977898A7C82857B767C75646E6C57625D818272CBBFA7D0BFA3D2BEA3
D4BFA5D5BEA6D9C1A7D9C1A4DAC2A6DBC5AADBC6ADDAC7ADDAC7ABD8C3A8DAC5ADD8C4AC
D8C2ABD7C2ABD7C2ABD6C0ADD3BEA9CEBBA2D0BDA4CDB9A1C8B49DCAB59FC7B39BC7B29C
C3B29EDACEBDCCC0AFB9AC9DBCB1A2BFB7ACB7B0A5B0A69BC7C1B6D7D1CDC9C2BFC8C0BD
D7CFCDD1C5C2B8A19DC19B95B6817BAB635FA347479F33329F2423A42021A41C1CA31919
A2191C9E1C219B232A9F363DAB585EB78084C4A7AACFC5C8CFD1D3CAD2D6C5D0D5C9D2DB
CBD5DEC7D0D7C5CFD5C3CCD2C7CCCABAB89AA69D5DB3AB6ECBCBB2C6CACCC4CDD6BCC9D5
B2C1CCBBC9D4B7C3D06A76892A3C4E495F6D62748079888F7F898B9C9D9E88726700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00817154
837359887A60847B618B826A9990779F957CA2987FA39980A69C82A59A80A7997CAE9C7D
B19E7EB29F80B39F7FB59E7FB89E80BA9C7FBCA081BAA081B89E80B89F82B89F80B99D7D
BB9D7DBEA07EBEA07CBEA17EBEA17FBEA07CBE9E78C0A078C0A278BDA17B8E7C6455544B
5A635E676E686D736D6A726D67706B5D6A6654625F5B645AA7A38FCDBEA3D0BFA1D2C1A3
D2BFA3D4BFA4D7C2A7D8C2A5DCC4A9DCC5ABDAC6ADD7C5ABDCC9B0DAC5ACDBC6ADDAC7AE
D8C3ACD6C0A9D5BFA8D3BDA8D4BEA9D0BCA5CCBAA2CCB9A2CBB79FC9B59DC6B59CC4B29A
C2AE99C1B09DBFAF9BBDAC99BCAB98BDB4A4D6D0C6C7C0B9C4C0B7D4D5CED0CCC6B5A49D
C3A19CBC8480AD5B56A53733A1221DA31512A80E0FAC0C0EB20B0CB70C10B50B0DB70A10
B30A0EB30A10AE0910AD0C14A70F159D181D9A3337AA666BC8A4AAD4CBCECBD0D4CAD3DB
CAD5DCC9D4DAC5D0D5C5CED5C6CFD0CACCBCB6AE7CADA25CC7C190C9CBBCC1C9CDBAC5CF
B7C5CEB5C2CBBFCBD88C98A86573816577825C70787B8C9399A8ABA5ABAF96898300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001FDA145D913E7B6C53
7C6F5780765F847C668A846D958E779A927CA09882A19A80A49B82A89E85A99B82AC9B81
AD9C80AE9D81B09E80B29F81B4A080BAA384BAA183B89F80B59D7DB69E7CB49C77B49C77
B59C78BDA17FBA9C7ABB9C79BE9F7BBF9E79C09F76BE9D72BE9E6FBE9D70A58C6D5C5548
525855535E5D56636055615E515C59505B57545C52898776C4B7A0D0BCA2D2BFA1D2C0A3
D3BFA4D5BFA7D3BFA6D7C2A8D9C3A8D8C2A7DAC4ABD9C5ACDAC7AEDAC6AED6C4AED7C5AF
D8C4AED9C3ADD5BFA8D3BFA8D2BEA9CEBCA5CEBBA3CCB8A2CCB7A0CAB59EC7B59CC1B197
C1AE96BDAA95CAB8A6D2C1B0C2B1A1C3B7A8D6CFC5D3C8C1B2A49AC0ABA2C6A098B6726B
AB4740A42421AA1715AF0F10AF0A0CB2090AB4090AB4070BB6080AB7080AB70709BA080C
B7070AB3040AB3060AB5070AB2070AAD080DA90E149A111A972E37B2757AD1BBBFCECFD5
C8D1DAC7D1D9C4CFD5C6D1D7C4CFD2C4CDCBC2C3B0B1A87AA69A62BCBA95C0C6BCBEC7CC
B8C1C9B6C3CBB7C5CFA7B4C26978885C6E786D7F847F8C92929DA2A3A8ADACA6A21BD40F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00786951726953736C57
8C85748F8877857E6C8B8471958D7A9C9480A39984A49983A79C86A69A83A79A80AA9980
AB9A81B1A087AF9E82B2A184B3A184BCA88BBAA185B79E80B49B7BB39A77B19A73B29C75
B49D77B79C79BA9C78BA9A73BA9972BF9D76BF9D74BD9A6FBC9B69C0A06DBCA07589775C
5955464E564A555E536064597471647E76678E806CBDA990CBB599CFB99ED3BDA3D3BDA4
D3BDA5D4BCA4D3BDA5D5BFA6DAC3A9D8C4A8D8C4AADAC5ADDCC6AEDAC7AFD7C5ADD9C7AF
D6C3ABD6C1A9D6C2AAD4C1A9D0BEA6CDBDA3CDBCA2CBB9A0C9B49CC8B39CC8B49CC3AF97
C7B099C2AB97CCB9A8D4C4B4C8B7A8BCA899BCA899C1A497C69889BC7468AC433CA61E1B
AE1210B30D0BB50B0BB6090BB40608B5060BB30608B30607B40808B50808B50707B60608
B40406B60609B00406B30608B40608B00609AF060BAB070DA30B1295191DA25357C9ACB0
CDCDD3C6D0D9C5D0D9C5D0D6C3CED2C3CDD0C5CBC9C7C6B4A9A173A29D66C2C3A5C2C9C6
BEC6CCB5C0C9B7C3CDB3C1D03F5067293C505E727F82949C849096848B8E9894903DB229
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001CD81270684F6D6C5885877A
BDBDB6A7A59D868172918D7897917D9B9480A29A85A49B87A79D88A49880A89A80AA9B7F
AB9B80AFA084AF9F84B1A187B19F83B9A387B39B7DB59C7DB29978B59B76B49B73B49C74
B39C73B79E76BA9E73B99B6FBA9A6FBE9E75BB9870BD986CBD9968BF9D6CBF9E6EBA9C70
9E86637F70528D8165A08F74A99278B69D81C5A98AC8AC8ACCB293D0B99CD2BDA2D4BEA6
D3BDA4D4BFA4D3BEA3D5BFA7D8C2AADAC5ABD7C1A8DCC4ADD9C4AED9C7B2D4C4AFD4C5AF
D6C4AED4C2AAD5C3AAD2BFA6D2BEA6D0BCA4CEBAA1CCB89FCAB69EC8B49BC9B59CC7B39A
C5B098C9B29CC6AE9BC3AC99C2AB98C2A492C89C8AC68073B24B41A9231CB01410B30D0C
B90D0BB80B0BB6080AB5060BB6070CB5060BB40709B70A0BB30907B50B08B50907B50709
B6080AB4050AB00506AE0405B10707B10707AE0606AF060AAC060BA7090E951116954248
C5A6ACCDCBD2C8D0D6C4CFD5C1CCCFBFC8C4C4CBBFCBCCB3C4BF86A19949B7B278C7CAB7
C3CACCB7BFC6BAC4CDBBC6D35161733445575D7180697F8990A2A99FA9AE92918D3EB42D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF001BD711508939726F5C939788B5BFB7
C1C7C6B0B3AF86867A91907C94927D9B9782A09A87A29C88A19A84A49B81A89C82A99B80
A99B7EAC9E81AD9E83B2A186B19D7FB1997AB19779B09677B19774B49B74B19771B39A74
B39971B59870B49669BA9A69B79766BC9A6BC09A6EBE986BBD9968BE9C69BD9D6BBE9E6E
BE9D6FBE9F72BDA076BFA47CC3A67FC8A682C8A781C9AC83C9AF87CCB593D3BEA0D2BEA2
D1BDA2D3BEA5D4BEA7D5BEA6D7BFA8DAC2AAD8C1A8D7C4ACC9BCA8B1A8979F9789A29A8D
AEA89AC3BBA9CDC2ABD1C2A8CFBEA5D0BEA5CFBBA1CDB9A0CAB69DC9B69EC8B59DC7B39B
C6B19AC8B09CC7AC98C5A793CDA795CE9383BA5D51AA2924B31715BA0E0FBB0B0DBA090B
BB0A0AB8090AB9090BB50508B40608B50709B50909B60A0AB60909B70A09B80A0AB80A0B
B7090BB5060BB20509B20509AE0305AF0506B00607AD0305AC0408A9060CA3080D950F15
933E42C7A8ABCBCBCEC4CDD1C5CDCBAEAF9AAEA977B8AD62AFA339A79920A59C39C8C795
C5CBBDBEC7C9BCC5CDB7C0CA7A89926675816B7C857B8C948E9FA59CA9AEA8ABAB6A9C52
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004E863367604A6B685796998FB9C3BFBFCBCB
C2CCCDB8BCBB8A8B838D8D7B9795819D99869F9A87A19C89A09A83A39C82A49C82A89E83
A49679A99A7BAA997DAB9B7EAF9B7CB0997AAE9776A9916CAD946DB39872B59B76B09571
B3956FB7976DB9986AB69563B99863B99662BB9565BD9767BF9A68BE9C6AC1A070BF9F70
C09E6FC49F71C3A175C2A378C3A37AC6A57CC7A67EC9AB83C7AB84C8AE8CCFB698D2BCA0
D1BFA2CEBEA2D2BFA6D6BDA7D7BFA9DAC4ADD5C2AFB8AE9C8A8776908D7DA7A0939D958B
7C786F7C7C72B8B4A4CEC2ABCDBEA5CEBEA5CDBCA3CEBAA2CBB79ECAB59DC9B39DC7B29D
C7B19CCAAE9BCFA797D49E92CD7E73B03D35AF1B16BB1211BD0C0EBF0B0EBC0809BD090C
BA070ABB070CBB080BB70509B40608B30608B20707B40708B40408B6050AB7070AB7070A
B30507B10308B1070CB0040AB10509B20509AE0407AE0508AB0507AA0509A70409A4090C
931114984749D3BABACACECFC6CFCCC1C2AFB1A770AA9A3DA9991AA9980AA49511ABA33E
BDBE82C3CAAFBEC7BFB6C2C48A9AA63F55674D6877748E9891A4AA8893998C8E908A786D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00518633665F4B68655790918BBAC2C28FA0A4A9BBC1
C2CED2C4C8CB8B8D868D8E7F9696849C9A889D9A899E9C88A09B85A29C85A59C86AA9D86
A7977BAA9979AC9979B29E7FAF9B7CAD9978B19B79AE9975AE9874B19877B49B7AB29775
B49570BA9970B59467B89364B7925EB9945FBD9661BE9866C39F6EC5A172C3A073C19E71
C19F71C19F71C2A177C3A47DC6A780C7A780C8A881CCAD87CAAC87CCAF8DCDB394CEB69A
D0BDA0D0BFA2D4BFA6D6BDA7D9C0AAD6C0ACC3B3A57E796D999789B8B1A0C0B4A3C3B4A7
AFA49B74736D76776EC5BEACCFC0A9CFBFA6CFBFA5CDBBA1CDB89FCEB59FCCB39DCBB29C
CCAF9AD4A696D2837ABD5149B12923B71512BD0D0DC20B0FC0090DBE0A0DBD0B0BBA070A
BA070ABD080DBA070BB60609B40608B20608AF0507B3070BB1060AB20609B2070BB2080A
AE0909AB080AAC0A0EAB090EA9060AAE080DAE0708AD0508AB0608A80307A80307A80607
A1070B880D12A66668D1C6C7C5CFCEC3CDC7C3C5AFBAB481A89938A19009A69602A79A0C
A79F25B2AE55B7B985C3C9B4A9B3B13547513C56644F6975798F98A0AFB6A0A5A8897A72
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF001BD711665D476764548A8C85B4BABCB2BFC45A7178637D82
C1CFD3C8CCD09092908C8E829494859695869A98889D99869C9683A19A85A59B87A99B86
A6967DA89879AB9A7BAE9B7BA79472AB9975AA9775AE9C77AF9B77B19B79AF9676B09573
B49671B39369B69566B59260B99460B9935DBD9660BC9965BE9D69C3A172C5A377C5A277
C5A175C19E74C1A177C5A67EC5A880C7AA83C9AA86CCAE8AC9AB87CFB18FCBB091CDB596
CCB89AD2BEA2D3BEA6D5BFA7D8C1AAD6BFAF9C8F8475736BA4A299BCB7A8BEB5A5C2B8A9
B1AAA083847F5F6660AEAD9FCCBFABD1C0A7D0BDA4CFBBA3CEBAA3CDB7A1CFB6A1D1B29F
D8A595CF766CB7342CBD1F18C11510C30F0DC20D0BC1090BBF090BBC090BBA0909BA0A0A
B80809BA070AB70609B40607B30709B1070BAD080AAA090DA70C0DA00E0F9D13159D1C1F
9A242798282D95293092242B921B2097141B9D0E12A20C0FA5080BA70609A70405A90506
A604099B080F831C21BF9697C8CACAC1CECFC4CBCBC6C7B6ACA363A19018A99704AD9C04
AF9F08AC9F14A59A2CC0B96EB9B8886A70586C7A7568787C7180848F9DA09DA4A6A29793
1BD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004C873464645285887FA9AEAFBDC5CD909FA75C7076798C91
C6D1D7CBD2D68F95928B8F848F92849596889B97889F98869D96839F9683A29482A49582
A3947BA5977AA7987AA59476A79474B09B7BAE9978AC9771AE9970B09A72AD9671B49B78
B39671AF9167B59466B59361B7945FB7945EBB9460BF9965BE9B68C1A070C2A175C2A176
C19E74C09E74C4A379C5A57CC3A37AC5A57CC8A782CFAF8FCEB190CBAF8ECDB293D4BB9E
CEB99ED1BBA3D2BEA6D4C0A7D5C0A9D4C0AF897E7575736F93948FA9A89EAEAB9EAAA69A
9B9C94767E795B6760A2A496CDC1ADD0BEA7D0BEA7D1BFA8D2BEA9CEB6A2D5B2A1DDA094
C9635BB62621C21814C7130EC7110CC70F0CC50D0BC30B0BC00B0ABC0907BA0B09BA0A0A
B90909BC090CB60708B40A0AAF0F0DA40F0D9A16149B292B983E44924E58885665734E64
664E675C4A655A4B655F4F666E5568835B6B8D4F5A8C30398E141A9E0A10A5080BA9060B
A6040AA1040A920E128D3F42CFBDBDC5CBCFC2CBD2C2C9C5BEB990A69732A7930DA8970A
AE9E08AE9E04AA9A06B09F19A99C2977712B5F68536A7B7D889A9E8C979A848688968A84
3AAB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF001AD81262604C7D8378A1AAA9AEB8BCBCC6CEA3B0B7B1BEC4B9C4CA
C9D1D9CBD3D79EA4A28B8E859393849591839B93879D94859E95849E9582A0927FA39481
A39680A3947AA4957AA5957AA79478AF997AAE9676AB936EAD976DAD996FAA956EB39A77
B69B78B2936DB39366B2915FB3935DB5935DBA9561BD9765BF9C6BBE9D6EC09E72C3A076
C4A076C5A47BC5A67EC3A47DC4A47AC6A57BC9A881CBAC8ACBB190CBB190CBB293D1B89C
D3BAA2CFB8A0D6C0A8D2BEA5D6C1AAD8C2B08E83796F6F6E7D807F8A8F888C9189838B83
757E7B5F6F6A5C6960B0AF9FCFC2AED1BFACD1BEACD3C0ADD5BDAADAB4A3DF9C92C1504B
BA1F1DC61513C9120FC60D0AC60D0ACA110EC9100DC50C0EC20B0DBD0A0CB9090BB9090B
B80A0BB80D0DAE0D0DA31516A030329E4C5386566260496237335522295219234F1B2652
212E55303D633B496B3A4B6C32456838496C323C5B5A4D658856668D2F3A96121AA1090E
A5060AA305099E0A0D821316B88A8CC6C5C7C2CCD2C3CDCCC1C3A8A3974898891F645806
9E9312AC9E08AFA003AE9E04A696098D831E3D3F1E394A4D657B8494A2A8A5A8AA9A8F8D
3AAC2400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00655F47676C5E99A5A0ACB9BCB2BEC4BBC8CFBDCBD2C1CFD7C4D1D7
C8D1D7CCD2D5A7ADAB8A8C838E8E809995869A94869C95879D95859F95839E927FA0937E
A39781A3957DA3947BA5957BA7957AAC9478AA9172AB9570A8956BA9966BAC966EB09872
AC916DB0916CB19165B09360B1945FB3955FB89562BD9966BB9967C0A071C5A67AC7A67E
C7A57FC3A37DC3A681C6AA84C4A780C6A680C9AA85CBAE8CC9B18FCDB595CBB495D1B99D
D2B9A0CFB79ED3BDA4D4BFA7D6C0AAD7C1AFB4A4996A676362696867716F69737063706A
5E6D675B685F7F8678C4BEACD1C3AED4C3AFD6C3AFD7C1AEDFBBABDF9B8FBD4843BD1E1E
C91314CC1011CB0F0FCA0E0ECA0E0DCB0F0ECC100FC60C0DC30C0BBD0A0BBA0A0AB50C0A
AE0F0EA61D1EA53F42985B69674E6835355A16264E182C552F42665A6A89697289848595
9898A3969BA8A4AEBC94A6BA3451718CAFD16B8EA89EB3C98787998B6C7C954856921921
9F0A10A10409A0060A910D108D4346C6B8BCBFCACFC2CECFC5C9B3A59A5592832855490B
71680B988F0FACA20DAD9E06A797069D8F177B75346970636F7B807E898E98A1A3A7A6A4
47BE3800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0033AD225E60518D9790A9B6B7B3C1C8B7C5CDBAC9D1BECED6BDCED5BBCCD2
C5D3D8C9D2D5B3B8B88488818B8C809391849894889A94889F968AA095879E917FA2937E
A2937CA2927BA4967DA09177A39076AA9176AA8F72AD9573A8926CAA946BAE976FAC936D
AC9168AD9062B19160B2935FB39562B39462B69665BA9966BF9E6DC4A477C8AA82C8AA85
C5A583C6A785C3A684C4A886C7AB88C8AA88CBAD8DCBB092C9B091CAB495CAB699CEB99E
D2BCA2D0B8A0D2BCA4D5C1A9D5C2ABD6C2ADD5C1B0A6988C6C69616C6F69767B727D8276
7F827689887ABEB7A6D0C3B0D2C2AFD4C1B0D5BEAEDAB5A9E29C93C14A44C01E1CCE1517
D11114CD0F11CF1113CC0E0FCC0E10CE1012CC0C0FC80C0EC30C0CBD0E0CB2120FA81F1D
A9444898606F584A66232D56142855273C624D607776808C8C9196AEB1B4B5B9BCA9ABAD
CCCFD56471817A8D9E90A4BC0B284F2F547C7BA2BAA5C3D0C7D6DFC6C6D0B99EA79D565D
901A209E0A10A1060A99080D7F1B2093717BBFC5CFC3CCD2C3C6ADA49C4F8B7B1B6C5B13
7F731B4D4801959219A39B0DA19403A3940C978E2B8E92668A968C97A2A3869091888987
689B4E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00488234787E75A9B3B4B0BCC4B1BFC8B9C7D0BDCDD6BFD1DBAEC2C9B3C6CD
C3D4D9C6D1D6B8C1C28388848B8D82919185939185969286A0988DA09689A09586A19382
A2927FA4947DA3937BA29278A49277AB9378AB9174AF9576AC9472AB936EAD956DAB926A
AB9165AD9061B1915FB1915EB49562B49565B79767BC9C6ABD9D6DC1A175C6A67DC3A47E
C5A683C5A687C6A98AC6AA8BC7AD8CCBB090CBB094CAB196CCB498CAB498CDB89DCCB69C
D0BAA0CEB79DD2BEA4D3C2A9D5C2ABD7C2ADD9C4AED9C7B3C0B3A2B3AA9AB5AF9FB9B3A3
BFB6A5CEC2B0D3C4B3D6C6B6D7C6B6D5C1B2DDBAADE09B92BB453FC72422CF1716D01313
CF1111CF1111CF1110CD100ECB0F0ECD0F10CE0E13C90E0FBD100FAD1A19AB42449D6471
57486622305D162F5C32476A69738A8E919AB0B2B1C5C5C2ABACAACED1D2B3BBC28C959D
C6CED6556477384C61A9B9CB62758C4D678090ABBCB7CCD6C5D5DDCAD2DBD3D1D6C1A6AA
954A4F91151C9C070B9B070A820B117A444EAAABB6C2CBCEBDBD9DA49A3F958313826C0C
90801A4D46016261087471089B940FA19407A2961778721A696F3E8C9782ACB8B1A3A6A0
82756200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006F6D5EA3ACAAB2BEC3B5C1C9B6C4CBB8C6CEBBCBD5A7BBC480979FB3C8CF
BDD0D6C1CFD4C0C9CC868C898B8D848E90849392869491869D978C9A9285A197899F9383
9E917F9F927CA2967DA3967BA5967CA49278A99477AA9272AD9572AC946FAB926BAB9269
AB9065AC8E61AF8F5FB49463B29260B59462B69664B99968BE9D6EC0A074C0A279C2A680
C3A886C4A78BC5AA8EC5AA8DCAB092CBB394CBB295CAB197CCB49BCEB8A0CBB79DCCB79C
D4BFA3D0BBA0D0BCA2D4C0A7D6C1ABD7C4AED7C4AEDDC9B3D7C6B1D8C8B5D9C8B7D7C7B7
D7C6B6D8C7B6D7C8B6D7C8B8D6C2B4D9BAADE3A297BF4B44C2221DCD1614CF1311D01311
CF1211CE1111CC0F0ECC0F0DCC0F0DC90C0DC71212B81717B4383AAB6573675573253662
143261334D756D7C90A0A5A7CBC9C5B9B4B1C4C1BED1D0CFC6C2C5B8B1B3C9C3C7A29C9F
ACA4A2B3AEAFA5A8ACA1A7ACBAC7D25972886B89A1A4C0D2BAD0DCC7D4DDC9D1D8D1CED3
B89399882D34940E13990509900A0E7E3039897D87C2CCCDB6B895A5993CAA9715A58E07
A48F13645703554F0B4849086E6E0C968F0E9F93089B8F0C9C972887863B989B76A9AB9E
9D908400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF003AB62A92978EBAC7CBB2C2CAB5C4CDB3C3CCB4C5D09EB2BD7D949D81989EA0B5BC
82959CC2D0D8C5CED3868B8C8A8C859191869594879D998D9D988C9B93879B93859B9281
A09583A29584A09480A39881A59881A3937BA69377AC9576AF9577B09575AB906BAE936C
AB8E66AE8E63B09062B39464B59463B59363BA9568BD9B6DBD9C6FC0A076C5A882C2A988
C4AA8CC4AA8EC7AD92C6AC91CAB196CAB498C9B599CBB69BCBB89DCBB99ECCB89DCDB89D
D2BEA3D0BCA3D2BDA4D4BFA7D6C1ABD6C2ADD5C2ABDAC6ADD8C6AFD8C6B3D9C9B8D6C8B8
D7CAB8D5C6B4D4C5B2D4C2B2DABDB0E4AA9FC3564EBF221CCD1812D0140FCF100CCF110E
CF1210CE100FCC0F0FCD1010C80E0DC21515B72629B557647F5A743138651430612B4971
677B92AFB6BCB3B2AEB0ACA1D7D1C8D3C8C4B3A09EC9AAAABF9595B27D7DAD7473AC7270
B17B74C0938EC8ADAC8A8083B8BFCA2239590F2F58799AB4ABC3D1C7D5DDC9D3D9CDD3D8
CFC1C7A36B7185171F99090F970B0E81212969505CBFCAD0C1C5B5AEA467A9972AA8930C
A8930A928006867A135049046563116965069B910CA09305A6980BA7991C998F37908A5F
9588731CD40D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0069A454B6BDBDBBCAD4AFC2CCB7C8D3B4C6D19CB1BC76909A79939B8BA2A88CA1A6
A7B7BDC7D2DAC8D0D88F9396888B8690908798978B9F9B8F9B968A9891849D95869E9584
A29886A59A88A39885A29782A0937EA1927AA59479AA9576AB9273AE9471AD906AAE9069
B09268AE8F62B09062B29263B49364B69467B8966ABB996FBD9C73C6A681C8AA89C1A78A
C5AA90C4AA90C5AC90C8B093C7AF94CAB39BC8B298CAB499CDBA9CC9B89AC9B698CDB89B
D3BEA2D2BDA3D4BEA7D4BEA7D6C1ABD6C1ABD8C4ACDAC6AEDAC7B0D7C7B1D5C7B4D4C6B3
D5C6B2D6C5B1D3C2AED6BFADE5B5A9CE6C63BD2720CF1A15D51511D4170ED3150ED1110F
CE110FCE1210C8100EC31311BA1A19B74146AC7084554D791B3367213E6B5C6F8A92979F
A2A09BC3BDB4C4B8ADAC998EBA9B92BD8B87B16663A84344A52D319F1E219B17179B1417
9D1A1A9920219D3B3DAB686ABC9DA07A7988364762748CA1B6CBD4C8D5DCC8D1D8CAD2DA
D3D2D7BF9FA4852E38930C1499080D83171F603F4DA9B7C2BBC7C8C6C6B3ADA667A39327
A6930BA18E04A7971283760A5C55064A46019891139B90059D9104A69A0AA39618B0A351
A3936B3AAA1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A09E8DBFCBD0B4C4D1B2C3D2B1C2D1A2B4C2768E9B738F9A7C99A36A868D92A9AD
BECED4C7D2DBCAD2DA969CA0888B878F908696958999978A9F9A8E9C95889D9486A09787
9F9584A19886A39986A0947FA0937C9F9078A39379A89479AB9376AA9070A98E69AE9269
AD8F64AF9063B09063B39265B59368B8956BB49369BF9F76BD9F78C0A27DC2A585BFA387
C3A98EC1A98DC5AD90C4AE90C9B498C7B297CAB499C9B298CAB59ACAB69BCBB79DCDB9A0
D3BEA5D4BEA6D5BDA7D7BEA8D6BFA9D6C0ABD6C0ABD7C2ACDBC6B0D8C6B0D7C5AFD8C5AE
D6C4ADD8C6B0D8C2AEE2BBACDB8A83BB312DCB1C15D41911D41710D21510D31410CF110F
CA100FC61311B81917B12E2FB85C678262802C3B6E1B3C733E5B828791A0A6A19FAD9E94
B19D8FB59A8DBF948AB6716AAB4A46A22826A51515B31214B20B0FB0090EAC0708AB060A
AB0709AA080CA50B0F9813159B3E3BCA9E9FA5A3B15A7288B1CBDBC1D1DAC7D1D8C8D1DA
CBD1D9CFC2C995565F89121C97080F851017693C47919CA9B4C6CFBAC3C4BABCA7AAA25F
A3941FAC9B0BAE9F06A798099185106E6404988E10817707837B079E9508A49809A2941D
B6A55849BB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4A298BAC6CDB0BFCDB0C1D1A6B9C9798F9E6E89954A69724361686A8489A6BAC1
BFCFD6C5D0D8C8D1D89EA5A9878A86918F869593879795899A978B9992869C92869D9183
A19484A19584A29683A29480A1917C9F8F77A29179A59278A99274A99070AB906CAD8E66
AD8D61B08F64B19067B09168B6956CB5946AB3946ABB9E76BA9D77BEA07BC0A180C3A487
C6A98EC6AC91C5AB90C3AB8FC3AE93C8B398CAB39ACCB49CCDB79FCBB59DCBB69ECDB9A1
D1BCA5D3BEA6D2BCA5D2BCA4D8BFAAD8C1ACD5C0ABD7C3ABD8C4ABD6C3ABD7C5AED6C5AE
D8C7B0DAC8B2E0C3B0E8AA9DB8423BC6201CD11811D41811D4160FD51511D31310CC130F
C2140FB3211FB95860A5738859527A1B396F264B7C7086A2A4A7AAB3A99EB7A395BC9E8F
C39386BE746BAB413DA71F1EAD1112B30C0EB7090BB9080BB70609B4060AAF0405B00607
B10708AF0506B2070BAC080B9E0D109A353B956F811725465B7C97BDD4E2C5D1DAC7D0D9
C8D0D9D1CCD5AB7F88841E28950B13870B13753B48717786B4C9D3B7C5CCBDC4C3C2C0A5
A59D4DA79917AD9D04AA9B04A596089B8E06A0920B7D700C5F59008C880DA1970BA29509
A2911B50C11500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0093938BB7C4CDB0BDCDAABCCC849BA8718C984C6B742142466F8B8EA3B9BEB9CBD3
BACCD5B7C9D0C6D3D7A8B1B3868B8790918994948A95958B9592899A948A9890859A9183
9F95859C9382A39786A19482A29582A0917BA29278A79377AA9374A88F6FA88D69AB8F65
AD9063AF8F65B2926CAE906AB3966EB0956AB4986DBDA07ABC9E7CBA9C7BC1A283C6A78A
C7A98EC6AA92C8AD95C4AB93C4AE96C9B49BCDB79FCCB7A0CBB79FC9B59CCEBBA2CDBCA1
CEBDA2D0BDA4D1BDA4D4C1A7D6C3ABD4C1ABD4C1A8D7C3AAD5C1A9D9C6AEDAC9B2DACAB3
D8C8B2DBC6B3E9BEADCB6C61BF2821CF1914D21511D41711D5170FD5160FD1150EC41811
B62D29BB6D756B5B7D243769173B703D5D8590A0AEB2B0AEBAAE9FBAA893C3A290C98D80
B04F47A82220B11414B50B0DB6080ABA080BBC080BBA060BB70509B40608AE0304B00305
B00607B10406B00607B10507AE080B980A13AA57625C5067415A73B1C8D5C4D1D8C8D1DA
C8D2DBCFD1D9BEA5AC802D36900E16890A117C3A475F6372B0C6D2B5C4CDC1CDD1C5CBC6
BBB98AA5982DAC9D0DA89803A59602A09102A3920880730D5F5804615F078784119E960A
9F8F0A4CBE0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
73A0458B8C84B5C2CAB2C3D195AAB8728B985C798321404857767B4D696FA7BEC690A7B0
7B949B9EB4B9C6D5D9AFB9BB858D8A8F938C92938A96948B98948C9A968C9994889A9485
9C95839E9684A39586A39383A39381A0917BA6967CA9957AA89274AA9373A78F6AA88F68
AA8F65AD8E65AF8F68AF916AB1976FB3966FB99B76BA9D7ABB9E7DBB9E7FBFA284C4A789
C7AB8FC9AE93C6AC92C4AC93C5AF97C8B39ACBB79FCBB69FCEB7A1CDB69ECEB8A0D1BDA4
CFBEA4D0BFA6D1BFA7D2C0A8D3C0AAD6C2ACD6C2AAD8C4ACD9C6AFD9C7B0DCCAB3DBCAB6
D8C7B4DFC0B1E1998FB8362ECD201AD51A13D41610D6170FD5170ED0160DC61C14BC3C38
B474814C4C70183A6C244877617997A4A9ADBAB1A7C1B0A3C2AA9ACAA190C57C6FAC3A34
AF1917B70E0EBD0D0DB8080AB7060BBA070BBB070BB90409B70508B50609B00307B10408
B3060AB20509B10408B20509AE0508A6090D972B32A2839572869F9BB6C6C3D4DCC5D2DA
C4D2D9CAD3DAC3B6BC86414A8D111A8C0A118038454F5161B0C8D5B4C4CCC0CFD5C4CECF
BEC1A4AFA956A99B20A8970BA89805A29200A4940593850C5B53034848054B4D01908C13
9F910B92740A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AA8F688B8E87B3C3CAAABFCD7890A064808D28465154727B4B69705A767E87A0A8516A70
92AAAFBDCFD4C5D1D5B9C2C4838A898C908A94958C98978D97958999968A9C978A9B9385
9B94849D95869F93849D907EA2937DA4947CA3937AA5947AA49174A69271A48F6AA9926B
A88E65AE9065B2916AAE9069B2956EB79975BB9E7CB69C7BB79C7DBBA083BDA285C3A88A
C3AB8CC2AA8EC7AF95C5AD95C1A990C5AF96C9B39CCAB49DCBB49BD0B69DCEB69ECDB6A0
D0BCA8D0BEA8CFBDA7D3C1ABD6C3AFD6C2ADD6C3ADD4C2ACD8C7B0D7C6AED8C7B1D9C7B4
DCC3B3EBB6ABC35852C3251FD31D15D61A13D51811D2150DD0180FC41E15C24848AD778A
3B4570183E724A698E8E9EAEB1B0B0BFB0A4C5B1A1CAAEA1D09E93BF655DAB2924B11411
B70C0BBC0B0BBC0A0AB9080AB60709B60609B6050ABC070CB9070BB6070BAF0509B0060A
AE0609B3070BB10407B20507AE0406AA070A93181F7949680F1F4D2D4E73B6D0E0C2D3DB
C4D3DACAD3DCC6BDC592566089121D8B0912843A483F3F52AEC8D6B8CAD3BECCD4C3D0D6
C5CBC1BABA92C3BB6CAD9C29A7950AA79603A29301998B048F8514564E02514E07646204
979011947E1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AD926C919290A9B8C68FA5B66A8798304F5D45646E4C6B75506F76567177A4B8BFA3B5BD
9CB3BB889FA6C5D3D8C0C9CC878E8E8C8F8D90918C93928B98958D98948A9A95899A9486
9993839E96869C927F9F927CA0917AA4967CA2947AA4957BA69578A69372A6916EAA916D
AE916BAE9167B1946BAD9069B39772B69A77BCA281B79D7EBAA081BEA388C5AA90C0A789
C4AB8EC3AA90C6B095C7B095C3AB90C6AE92C6AE95C7B199C9B49BCEB69CCEB69DD0B9A3
D0BAA4D2BEA6D0BEA6D2C1A8D4C3ABD7C5AFD6C4AFD7C6B2D6C5AFD6C6AFD7C6B0D8C3B0
E2BDAEDE8D84B93028CF2017D61A13D51612D11411CF1711C41F17C14D4CA97B92344273
193F735D7998A8AEB4BBB3AAC1B1A3C4AE9DCBAD9ED6A095C05E57AD1E1BB6100FBB0B0D
BA0A0CBB080BBC090CBA090CB50608B5080AB40709B4090CAF0A0EA90D119E0E109E0E11
A40B0FAC070CAF0509B00609AF0508AB060A96141C804C681525531B3F65A3C2D4C0D2DB
C4D2DAC9D2DCCDC4CF97606C8715208C0A11863A4736374CA9C5D5B8CAD5BCCAD5C1CFD9
BECCD0C8D0C9C8C6A3B0A652A99A1BA39305A292019E90039D9208978D0F776C0C5F5700
8C840F98851400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A588608F8E8CA1B0BD8097A74C6A783655604D6B744E6C7457747986A0A791A6AEA2B6BF
778F976A8288C2D1D9C5CDD48B91938E939090928D95958F9B97929C9590978F87979285
9A97879B96849D95829E927FA0927CA3947DA1947BA2957BA59579A59272A79070AD9172
AF9472B19772AF936DAF936DB49774B79C79B59C7AB8A081B9A485B8A487BDA98CC0A98D
C5AD92C5AD95C5AD94C5AC92C7AD94C6AD94C9B198C6AF98C7B39ACAB69CCEB89FCFB9A1
CEBAA2D2BDA8D1BEA7D0BFA6D5C4AAD3C1A9D3C1ACD5C3B0D6C5B0D5C5ACD6C4ACDFC3AF
EAB5A5C0554AC4261BD51E14D51812D31614D11713C31B15BF49499E72893245761C457A
6B87A5AEB3B7BFB5A9C5B4A2C5B09EC9AB9AD1988DBD574FB4201CBF1212BD0B0BBC090C
BB080CBC080BBA070BB8090CB40A0AAE0B0CA40E0FA11E20A0363D9D4C568F505C92515C
9E3B429C0F14AD070CAE0309AE0407A9080B9820266F475F47618585ADCC8DADC1BED4DE
C4D3DAC8D1DBC7C3CC98637086141F8E0C14883A49332F47A8C2D5BACBD8BAC8D3BDCBD4
BECFD6C3D0D5BCC0AFABA267B1A43CA39415A59509A192039D91029D8E049F900E796D07
847A0A8F7E1042B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A07F5593918D97A6B1849CAA31505C4B6C74496A6D4D6B6E88A5AA546E7591A8B1899FA8
ACC4CB81969DC0D1D7C6D0D58C9596878E8B8F928D95958F99958E9D968F9990899A9286
9C95869C96859C95839B92809D927EA2967EA2957CA3957BA19176A69376A89276AC9377
AF9577B19979B29878B29876B29976B69F7AB7A17DBDA686BDA588BAA68BB7A289C5B095
C5AE93BFA98EC4AE93C5AC92C9AF94C9B094CBB39ACBB49DCDB79FCCB69DCBB39BCDB6A0
D0BBA7CEBCA7D1BFA8D2C0A7D1C0A7D2C0AAD3C0ADD4C1AFD6C4AFD6C4ABD9C4ACE1C0AD
E09789B73127CF1F15DB1D12D4170DD21712C61B16BC4140A7778D304373214D7F728EAA
B2B4B7C0B4A8C4B3A2C4B19ECAAF9CD39D90B8544EB31E1BC31413C40E10BE0A0CBB080C
BA0A0DBA080BB80B0CAE0D0DA214149D2E329E525E8359705245662F315A1D2752242347
81526696242CA9090FAE030AAF080A9D090AA040474A3653415F89416A9422476BB1CFE1
C2D4DBC7D3DBC8C4CE98637084121D8C0B14893B4B302C45A7C1D5B8CDD8B1C0C9BECCD4
C3D2D9C0CDD5BBC2C1B9B89EA7A269B0A652A094259E910D9C8D039E8C02A69608A19309
9B8D0D86720641B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
977141A299908F99A47C909E4C66714C6B7048686B7D9C9F506E728DA7AEADC6CE69868F
74909997B0B6C2D3DAC3D0D6959FA1878F8B90938D96978F98968E98948A969084999183
9791819A95859A94849990809D9582A19784A398839C9178A1957AA3947AA8957CAD987D
B0977AB29979B2997AB29A7AB79F7FB69D7DBCA584BBA685BBA688BBA88BBDA88EC4AE95
C5AD93C3AC92C5B095C4AE92CAB296CAB297C8B299C9B39BCBB59DC9B39BCAB39CCDB59F
CFB9A3CFBAA5D0BBA5CFBBA3D2BDA7D2BFA9D3C1ABD3C1AAD8C5ADD6C2A9DAC4ADE8BDAC
C7675CC52921D61C17DA1B14D51911C91B13BA3532B47B8B3847751A477B7795B2B7BBBB
C2B6A8C6B5A6C6B2A4CBAFA1D6A899BB5D54AE201CC31514C91211C30C0DC00C0FBA070A
B80909B60D0BAB1714A8393B9E5C696B536E313761152B5D193260435980606E8C7B7186
A36874981D24AA080CB0050BA9070A98181A985A6A2023453F5C816280A11737589BB8D0
BED2DDC8D4DCC8C1CD985E6D85101C8C0A13893E502A27439FBBD0B1C6D2B8CAD1B7C8CF
C0D2D8BAC9D2C1CDD4C2CBCABFC4B9BDBEA4A8A56E9B9234988B129E8F07A19203A39301
A7990F8B790621D90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
9A713CB5AA9C848E9597A9B5556D774E6A6F6F8B8F5C787C77939B9CB8C35F7C857D9AA0
809CA2607C81A3BABFC0D0D49DA8A9868E8B8D908A95958E92928A908F86969287958E80
9993839A94849D97879B94829E9784A29988A49B89A09681A69982A4957CAB987FAD987E
B19A7AAE9773AD9774AE9979B6A081BBA384BBA283BCA687B8A586B9A78ABDAB90C3AF95
C0AA8FC8AF95C7AF96C3AE91C7B295C6B195C4B096C7B39AC9B49CC9B29CCBB59ECCB69F
CDB8A1CDB9A5CDBBA5CFBDA5D0BFA6D2C0A9CFC0A9D0C0A9D7C5ADD6C3ACDBC1AEE9AFA0
B84039CC221ED31813D71B14D21F16BD2C25C276824C50771B477B6083A5B6BDC3C6BCB2
C7B5A7C8B5A5CDB1A2DAABA0C5766DAB2520BD1513C5100FC70F0FC20B0EBD090CBC0A0D
B50909B3201CB6555679576D2D3660122D5F203D6A5369888691A1C2C3CDCDC1C7B28486
A13D3EA20F11AD080AAB080B9A1013A24D594F3D5D122C556C8CAAB4CCDC9FB8CBA1BED2
BDD5DFC9D4DDC4BAC795596486121A890A12863E50292A459FBFD1B0C8D2BAC9D2BDCCD5
BFD0D8BFCDD6C2CFD7BFCBD3B8C3C9B7BFC2B7BEB2A7A9818A8838928A1D9E9213A3940A
A3950E7F6E0245B90C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4EBB24B5A7957E868BA0B2BB526B7264818669848970899091ADB54D6D76617F87A1BDC3
758F968AA3A88EA2A6C4D1D6A9B3B6848E8B8E938C97969192908B9290899692888E897D
9592839390819995869B95859C96859F9886A19885A29783A59882A89880AB977FAD957C
B29B7BB09978B19B7BB29D81B49E82BAA285B9A084BAA487B8A585BCA889BEA98DC4AF94
C5AD93C6AC92C3AA8FC2AD90C4AF94C5B095C5B096C7B199C8B29BCAB59ECAB69DCBB99F
C8B79ECCBAA2CEBCA4CBBAA1CFBEA5D1C0AAD0C1ADD2C2ADD4C3ABD1C0A8DDC0ABDB8F82
BA2E25D21F19D51812D51C15C2231BCA656A7663841A3F734E739AADB8C1C7BEB5CEBDAF
C9B6A7C8B4A3D4AEA1D18A82AA3531B91716C3100FC71012C60E0EC10A0CBE0B0EBA090C
B60A0BB82B2AAF5C653C2A4A2839615668858E96A3C6C5C7B3A6A3BC9F9EB983819E3C3B
A01214AB080CAA090B9B1213A04B54634B670D21513D649084AAC795B4C67EA1B53A617B
B4D6E5C7D3DEC1B6BF905259861116860B1083414F282E45A2C2D2B1C6D1B9C6D0C1CEDA
BCCCD6BFCDD6BECCD5BACAD2B1BFC8B3BDC7B4BEC4B1BBB7869178999F6FA2A1569C9328
988D0F85790864960E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB91FAD9B847D8487A5B6BF5B727A7B979D5B757C99B4BD4C6A725C7B8188A4AA8EA8B0
98B1BC879EA79CAFB6C4D0D6B2BBBF808B88868D868B8C888D8D8990908996948A8C8A7D
9390829893849892829893829C98859E99869F9885A49B86A89A84AA9982AF9A82B09980
B19C7FB29E7FB4A185B39F85B6A286BAA186BCA48AB8A489B8A487B7A486BFAB8FC6AF97
C4AC93C3AB91C2AC90C3AE92C4AE91C7AF95C5AE96C6B199C6B29AC7B49BC9B99DC9BA9D
CABA9FCBB9A1CFBDA5CEBCA4CEBBA4D0BDA8D1BFABD4C2ACD8C5ADD6C1AAE4BCAAC96B5F
C32721D31B14D71B14CD1E16C24342A67A92273F70385D8AA9B3C4C8BBB5CEBAACD0BBAC
CCB9A7C8B2A0D69F92A7463FB01F1DC21312C8100EC60E0EC31011BC0F11B41012B50D11
B70C0FAE0E10A82B2EA5626A9A8689A29C96AA9F94B59F95BC938CB66D699E2E2DA31211
A80907A60B0A9815179D4B565D48631325560B2A5C7595B82C4B6A1F3E5D6B8DA71E425D
A1C0D4C6D2DFBBAEB9884650891319840B118545562A324AA4C3D5B2C6D1AEBCC5BECBD6
B8C8D2B9CAD4BBCCD4B8C6CFAFBCC4B5BFC9B3BEC8B1BEC67C8F93778A8394A487A1A767
9B962F978E158D7C1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B718AB9374818784A8B8BF7C919B60788290ABB6607C854F6C7288A2A6A1BBC3718E99
5976807D959CBCCCD3C3CDD3B6BEC27B8381828783868883888A828D8A83929185939486
9493849895859894849B9587A19A8B9F9887A09986A49B88A89C87AA9A83AC9A81AF9B81
B19D82B3A086B29E84B39E83B7A086B8A088B8A28ABBA68AB8A084BAA588BDA78CC0AA92
BFA991C0AC91C1AC91C1AD92C0AB91C4AD96C4AE97C4AF98C6B39BC8B69DC8B79DC9B89E
CDBAA2CDB8A2CFBBA5D0BEA5CFBEA5D1BEA6D5C1AAD3C0A8D7C5AED6C0ABE8B8A6BA4C42
C9241DD71D14D31E14C02924CC7D8A4C4F772849799399B4D6B7B8DDADA3DBAC9FD9B3A6
CEB4A3D0AE9FC87970A42723BE1A1AC91112C50E0EBE100FB01D1CB23B3EAF494FA53239
A4181AAF1010AE1111A32925C88578B89785B79584BA8075A84A44A01E1BA9100EAA0B08
A20D0B97222493505C4C3E611027561837673C54748593A291A0AE667B8F9BB2C19FB9C9
AAC4D4C5D2E0B8A8B4833C468B1119850C157F45572C3752A9C7D9BBCBD8BAC7D0BDC9D5
BCCAD5BAC8D5BBCCD6BCCAD5B3C0C9B3BFCBB2BFCAAFBDCB5C707F293C41637364778361
8C934E9592289B8D1A40B20500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A68A62858B82A6B7BE8498A27E95A274909B48666F779197A6BDC55B757E7F99A0
9BB2B9BACED6BCCED5C3CED3BCC5C77B81808184808687808A8A808C8A7E8D8C7F959486
9291839693849B97889E97899E97899F9A88A29C89A59D8AA79C8BA99B89AC9A88B29D88
B09C84B29E85B39E84B49E82BCA38AB69F87B9A289BCA58AB7A286B9A489BDA98DBEAA90
C1AC94C1AC93BFAB90C0AC90C3AB93C7AD98C9AF9AC6B199C5B29AC7B59DC8B69ECAB8A1
CBB9A2CDBBA4CEBBA4D0BCA4D3BFA7D3BFA7D6C1ABD6C3ADD7C5B0D8C0ACECB2A3B43B2F
CF231AD41B11CB2118C54D50916C863945728980A2C0818CB84F4FB83C3AB6433ED38379
D9AC9FDCACA0B5524EB1201FC41615CA1110C31412B62B2AB2636D654C6946436270576C
AC646AA12426AF1011A9100FAF3830D37C71B65C54A22B27A51413AD0E0DAA0D0B99110E
97343885566B3030570D295A23456D92ACC4C1CFDBA5B0B6BEC9D1AEC2D07893A6A1C2D7
7093A6C1D4E3AE9CA780323A8C0E15820C157847572A3B54A6C4D6B7C8D4BCC9D4BECAD5
BECCD7C0CEDBBFCFD9BACBD5B3C1CAAFBEC9AABBC5ADBECC94A6B662737D88948F8F998C
8F977696944A9B8D2448BB0D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4885B93978D9BADB2879BA593ACB845656E6E8C9396B2BA58737E536F7692ACB2
A2BCC3A2BDC77C939BBCCBD0C3C9CD8084867E817D80817A86867E8D8C828C897D969186
9994889995889895869E988AA0998B9F9A89A39D8CA59F8EABA092AE9F93B4A193B39F8C
B5A088B6A089B59E86BAA28ABCA38DB9A18AB8A288B9A489B8A288BBA58CBDA88DC3AE93
C4B098C4B098BFAA92C2AC94C4AC95C7AD98C9B09BC7B29CC5B39CC7B59EC8B49EC9B49F
CEB9A4CCB9A2CEBCA5D1BFA9D1BFA9D0BEA9D2C0ACD5C3AFD4C3AFD7BDAAE7A899B13127
CF1F18D21C14BD231FD17882684E69A285A4B2596BB6282EC51E1FCA1C1AC11E1AAD322E
E19F99E0A8A4A9403EB51D1CC61412C81312BB1D1CC06069514062183165324D74707484
B18F90BF6664A21614B00C0AAE0E0DB11C1CAB1313AE0E10AC0B0CA3100F9A2426924852
59415D17235010325D557B9AACC6D6ADBCC3C4D0D896A7B193A6B1667E940B2B4C4B708E
41667DBBCFE1A8909D7F2833900E15800E1574495B31465EAFCEDDB5C8D5BBCBD8C0CCD9
C0CCD8C1CEDBC0CED9C0CED9BDC9D5B1C1CBACBEC8AABFCCA1BACA8FA8BB8DA3AFA1B3B6
B1BEB5A6A881978D404CC11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A584539E9D9193A0A7ACBFCB66808C5A798190AEB663828B4F6E7669848B7E989F
66838A59767D99AFB6B9C8CEC0C9CC838A8C797C7980817B83837E8B8B838F8D83928E82
9B97889D988C9A96899F9B8CA39C8CA69E8FB0A699B0A597B1A497B3A399B5A496B9A796
B6A590B7A38EB7A18AB69F87B9A38CBAA48CB49F87B8A58BB6A38AB8A58CBCA88FBBA88F
C3B199C3B098C1AB93C5AD95C2AB94C3AC96C6AD98C7B09BC6B19CC7B19EC9B49FCAB6A0
CCB6A0CDB9A1CDBAA3D1BEAAD1BEABD2C0ADD0BEAAD5C3AFD5C2AEDABEABE4A495B43329
CD1D15D31F18C03435BA73829D738AB55E70B9252DCD191DD01718CE1614C71A15AD2E2C
AF757BB890989F4244B2211FBF1313C30F11B3191ABB6270443354535B7CA19CA8BBA09D
C9978ED37871A71F1AB30B0CB7090BB80A0DB40D0CA90F0DA02221A04C537A526A31315A
0F245717335E4C6880A7BCC5C0CED19EA7AB9FAAB0495D6A5F748296A9B8486479628096
A3BECDBFCAD6A285907C1F29930E1582121B6A41533E536CB2D0E0BACBD7BBCCD8BECCD9
BFCCD8BFCAD6BECAD6BECAD7C0CFDCB2C2CFAEC2CCACC0CD738DA22F4F6A305067587480
8094979AA29499966F96845400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A47E47A7A1918C999E97ADB75C77818BA7B172909B496A7167888D47666A688488
6C858A97AFB68EA4ACB0C0C6BEC9CD899395757C797D7F7983827D8A89838A8A80929084
9C988C9F9A8F9F9B90A59F93ACA697ACA596B2A79AB3A89BB1A698B5A89AB5A597B2A291
AE9E8CB19F8BB39F8AB29E87B8A48BB7A388B8A489BCA88EBAA68CB7A489BBA88DBBA78F
C0AB95C1AC94BFA891C2AA93C3AD95C2AE96C7B099C9B19BC5AF98C7B29BC9B49ECBB6A2
D0BBA8D0BBA6D1BDA8D0BFA8CEBEA8D1C1ADD0BFADD6C5B1D5C2ADD9BFA9E6A999B0362A
CD2118D11F18CA4443B66874CF8391B12F36CC1D1FD31616D21615CD1613BC1C17B65158
69516B69637EA7656FA42629B91819C41113BC1215BB353EB55C69BB757DC07572B75A53
AD3C34AC201CB10F0EB80B0DB9090CB40C0BAC1F199B3936774751453E5E18295B132B5E
3A4D7079808F97989593938DB8BBB9B5B9B8A9B0B0C0CDD2ABBCC3ABBBC4B5CDDB89A6BA
9FBCCDBBC6D49D7C867C1A21910C118618205F3A4E4A5F79B5D0E1B7CAD2BBC9D2BBCBD8
BDCDD8C0CDD7C0CDD9C0CFDABFCFDCB7C9D7AEC2CDAFC1CE758B9C45617645637668818E
85969B828B888A8C80887E6C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00789B31A59B8684929694A8B2778F9A8DA9B649677360828847696C5D7D7E7D989B
A0B7BD8FA8B14760698CA0A5BECACE97A0A3757C787B7C7782827A84847C89887F8E8C81
969287A09992A39C94AAA199AAA298ADA59BAFA599B3A79BB2A69AB4A89AB5A698B1A190
B2A08EB39F8DB39E8AB59F89B8A28AB9A48BB7A38BBAA58DB7A289B9A48ABDA88FBCA690
BCA690BDA891C0A892C2A993C2AB94C5AF97C4AE96C6B099C6B09AC8B39CC7B59DC9B8A1
CCBBA4CDBBA4CDBBA5D0BEA9CEBDAAD0BFACCFBEAAD5C4AED3C1A9D7C2AAE7B6A4B1453A
C9251FD41F1BC72C2AF68084E1686BC22423D31C18D31815CE1714C11C16B43C3C9D6F84
2A3C655B708DC6A5AAAB5753A72824BA1817BE1212BC1215B4171BB21C1EAD1918B01816
B01411B41410B40F0DB80D0EB60A0BAB100DB54E4E5430421C2043192852414D737A748B
9B858BAB8B85B59288AF928BCEBFBCD6CFCFB7B8B8C2CBCFA5B6C17B919F8FAABD193A5A
3053737C8B9E96707B7C141B8F0A10841B2658384F526984B2D0E0B8CBD5BCCAD3BACBD8
BCCED9BDCED6BCCDD5BCCDD7BFD2DCB5C8D6ADC0CEB1C3D1A1B6C46B869799B5C294ACB6
A4B6BBAEB9BCA5ACAB8F8B862A9F1900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004CB81CA99A807E898AA1B5BE92A9B457737E5D7B845271765D7C8169888C425F66
839EA72D4951718B928A9CA0BAC5C9A2A9AD7176767B7B7780807A81817888877D8E8B80
938F859D9991A29D97A6A098ACA59DABA299AEA498B1A598AEA495ACA392AEA491B0A491
B1A28EB09F8BB39E8BB29D87B4A088B9A58CB7A38AB7A389BAA58ABDA58CBFA78FC2AC94
BDA992BFAA94C1A993C3AA93C2AB94C2AC95C5B099C5B098C5AF97C8B39BC9B69EC9B8A0
C8B8A0CABAA0CABAA1CDBDA4CCBCA4D0BFA9D4C1ABD2BFA7D0C0A7D2C2ACE1C0ADD18476
B93028CF231CCF211CCE2928D02A2BCF1D1AD21D17CC1F18BF261FBC4E4FAB7D92364673
1F4777889FB3C3B7B1D6AEA1C27C70AA3930AE1F1AB71A17BA1918B51614B11816A71715
A5201FA92D2BC03D3AAB1211B40D0DA51110A95057381C3643355386637AB07582A45056
9C3839982D2D9A2D2D9C363B9E4E54B37E82B6999AA19A9B65727C344C5B8CA2B44A637E
33516EABB4C68D5E667F1117900A10841E2951374D5F7892B6D2E1BACCD5BDCBD5B6C7D4
BBCED8B9CCD4B7C9D4BACCD8BDCFDBB7C9D7B3C6D2B8C9D6AFC3D32D495F47677B5D7889
7A919B90A1A89EABAEA9ACAC57443600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004AB417B29D81808788AABCC57E95A057737B5B788059767D71909637575C88A2A9
778E97445E6444595CA6B3B6BAC4C5A8B1B37175767A7C797F807A83837B89877D8D8B7F
928F839D998EA19D94A5A199ADA8A2A8A198ACA397B2A798AEA292A99F8EAEA492B3A795
B3A590B1A28EAE9D8AB09C85B5A188BAA48CB7A189B8A38BBCA78FBDA58EC3A993C4AC96
BEA892C0AA95C2AA94C3AC94C2AA93C2AB97C5AF9AC5AD97C8AF99CAB39CCAB49DC8B59D
C9B79FC9B8A0CCBCA2CEBEA4CEBEA4D0C0A7D4C1A9D3C0A7D1C0A7D2C3AED9C4B2E8BCAC
D27C6FBA382CC62820CA251FC6221DC2231CBC2E25BD4E4ABC7880887693304B7A1D4A7C
6888A6B2BABDC2B9ABC9B6A6CEB1A1D2A090C17B6FB25954AD4F4FAB4F54A5565CA2646E
9165767B5668BD78809D1D1FAF0C0FA30C0BD06367AC5C68A44653A02731A3161DA91015
A80A0EA8090EA8090FA60A129E0C14911319923437A67272C6BABDACB8C19CADB7B8CDDB
A1B6CA989AA9875057871317910A0E85212C4A344969829AB7D1DFBECEDABECCD6B4C6D3
B4CAD6B7CBD7B7CAD7B7CAD8BACCDAB9C9D6BBCAD7B9C8D6B0C2D45068824F6C854F6B80
6B839182949D7F8C92878C8E5C4E4300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB517B69E81888C8EA7B9C4627985657F88556F777F9CA23C5A5E79969B7F989E
768D94667D82A7B7BBB4BFC2BAC3C7B0B8BD767B7E7C7D7B80807B82807A87837B8D8980
938D859D968EA19C93A4A097ADA9A0A9A59BA6A294ABA494AEA394ACA092B1A497B3A494
B8A797B2A08FB09D89B49F88B5A189BBA68EB7A189BCA78EBAA78EBAA590BEA790C0A892
BDA68FC1A892C0A791C2AA93C3AD95C0AB94C2AE96C3AF97C4AF99C6B29DCAB7A1CDB9A4
CBB6A1CBB9A2CCBAA2CDBDA4CCBDA5CFBFA8D4C3ABD7C3ABD4C2ADD4C3B2D6C4B5DBC5B4
E6C2AFE4A696D2796CC66159C2635EC37779B58893817891415981224C7C3C668F8098B0
B8BCC1C2BAB3C4B8ABC6B9A9C7B8AAC7B2A4C4ACA1917B7C685A6A524F6A3D45632D3A5D
25375D383E5CA470809B1C22B10C0FB00B0DB61E21AA181EAC1118AE090FB2080FB2060C
B0060BAF050BAF030BAC020AA8040AA6070C9D0B0F8E1C22AA7176C8BEC87C8E9C8DA6B7
40586E5A5B6D7D404989101692090F85212F432F476D89A1B8D2DEBDCFD8BACBD5BACDD8
B9CDD8B7C9D7B8CAD6B9CDD8BCCEDABDCCD8BBCCD8B8CAD8B6C9DAA1B7CEA0BBCF9FB7C7
A0B5C0A8BBC3A3B1B8979DA25E524B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0028DB0BB094748D8E8FA4B5C07A919D58737D7D98A14B656D6A8588769093738E91
97B0B48BA3A99DB1B6B4C2C8BBC6CCB5BDC47A7F847879787E7E7986847D89867E8F8C82
948F849C978E9F9B929F9B94A6A39BA6A499A9A599ACA598AEA498AFA395B3A696B5A594
B7A694B4A290B5A28DB39F87B5A189BAA68FB6A18AB9A48CBDA991B9A58DBDA58EC0A891
C0A790C2AB93BDA78FBFA991BFA991C1AC94C2AE97C6B29DC4B29CC4B39BC8B89FC8B89E
CBB9A2CAB7A1CDBBA5CFBDA8D1BFABCFBEA8D3C2ABD6C4AED6C4B1D4C1B1D7C5B6D5C6B6
D7C8B7DCC5B6E1C3B8B59B9A80768258607C354F753257804C71957D96AEAEB8BFC0BCB8
C5BCB2C8BCB0C4B8AAC4B8AAC2B6A6C3B5A5BFB2A2BDB2A8AEA9A692939B838994828793
8E8D99A78F97A55758A11414B50B0CB40809B3070AB3070CB20709B2060AB30409B4040A
B4060AB4070AAE0406B10409AC0407AD0509AB070AA10A0F891A20A47381292F435B7486
607486635C6F803B468B0E1691070F892534402D45708EA4B8D2DEBBCED6BBCCD6B1C3CF
B8CBD6BCCFDCBCCED9BCCED8BCCED8BACCD8B6C9D4B7CAD9B1C8DD5B79944F728B6D8A9E
738A97869AA292A4AAA4AFB377706C27981000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A4835D93918FA1AFBB738A9769858F628087668187728B8E68838669858A
5E7C805C7A7D8CA6AAB1C4C9B6C5CCBAC4CB7E8589787B7A7C7D7885857E87877E8F8E82
959185A19B90A49C93A59E95A6A19AA6A298A8A499A9A396AEA698ACA191B3A796B5A595
B7A595B5A191B6A08EB39C86B79F89B9A38CB5A088B9A38CBBA58EBAA48DBDA68FC0A791
BCA58FBEA992C0AB92BFA991C2AC94C2AD96C3AF98C6B29DC7B39EC7B59EC9B8A1C8B7A0
C9B8A2CCBAA6CEBDAACEBDABD0BEABD1BFAAD3C1ACD2C0ACD5C3B0D7C5B4D9C8B7D5C6B8
D5C8BBD7C9BCD8C8BED0C4BEBAB4B6A7A9B4A7AEBBB1B8C2C0C0C3C5C0BDC9BFB6CABFB2
C9BCAFC8BAADC7BAACC5B8AAC6B8AAC7B9ACC0B5A6C1B6A6BEB6A6B8ADA1B4AB9EB4A99C
BCA499C188829D2D2AAD100FB50909B50709B40708B30608B4070BB30409B20308B6050B
B30507B40709B20809AF0506B00406AE0609AC0406A8050997090E933C44A5919E90A1B0
B8C8D1A797A27E313A8F0D1493080E8624353F2E497896AEB5CFDCBBCED6BCCDD7BCCCD9
B8CAD6BACCD8BDCFDBBDCFDBBDCFDCBBCDDBB8CAD6B8CBD8B5CBDF3A587543657F607F91
5B727E788B937B8A917E878D6F696924961000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A17C4F9A958E9AA7B28399A774919C62808985A1A75D797E617E85537076
56757767848686A2A6627C81A8BCC1BBC8CB858D8E7B7D7C7E7F7A81817A88877E8F8D82
9693879D988FA39C94A39C94A6A098A8A49BA7A499A8A498ACA59AACA497B3A797B4A395
B7A496B9A392B59E88B89F89B89F89BCA58FB6A089BBA28CBFA690B8A18AB8A28ABCA68F
BDA790BEAA92C2AD95BFAA92BFAC94BFAD96C3B099C5B09DC5B09CC7B39EC8B6A0C9B7A2
CDBBA7CDBBA9CCBBA9CFBDAAD0BEA9CFBDA7D0BEA9D3C2AED4C3B0D8C7B6D8C7B8D5C6B9
D3C5B8D5C7B9D4C7BAD4C8BBD0C5B9CDC4B9CCC3BACCC2B8CEC2B6CDBFB3CABEB1C8BCAF
C6B9ABC5B9ABC3BAACBDB5A7BEB7A8C1B8ACC0B7ABBCB4A5BAB1A1BAAE9EB6AB9ABBA496
C39187A74642A61614B30B0CB70A0CB5080AB2080AB10708B40709B6080AB50709B7060C
B40608B30608AF0507B00409B10507AD0305AE0509AB030AA2050C84121D946B7E8E9CB5
8796A7A8959D7E2B30940E1395080F8725353F2F487A9AB1B6CEDDBDCDD9BACCD6BBCDD9
BACCD6BDCDDABCCCD9BACCDAB6C9D7BACBD9BBCBDAB9CAD8B8CADB758CA18BA7BAA1BDC9
9CB2BC9EB0B8A5B4BA9EA8AE7B777A38671D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009C7440A69E91909CA5A6BAC766818D96B2BC6F8B945D7A814E6B71537477
62828488A5A85B777B55707597ABAFBCC9CE8F959A797C7B7E7E7A83827C8989828F8F86
9A978EA09B93A29D95A29C96A9A39FAAA5A0A6A297A9A298AFA89DACA499B2A699B2A393
B7A696B4A390B29F8BB39F8AB3A08BB4A28BB7A38CB9A38DBBA58EBBA58DBCA78EBCA68F
BCA690BFA994C2AC96BFAB93BEAB94BEAB95C2AE98C6B09BC7B19CC8B29DCBB6A1CCB7A3
CDB8A7CEB9ABCEBBABD1BFACCEBCA8CFBDA8D2C1ACD4C3B0D3C1AFD5C4B2D5C5B5D6C9B9
D5C8B8D5C8B8D3C8B8CFC7B5CFC6B8D0C5B9CFC3B7CDC2B6C9BFB3CAC2B4C9C0B2C8BEB2
C8BEB2C4BBADC2BBACB6B3A3BAB7A8BCB6AABCB4AAB8B0A4B5AE9EB6AB9DBBA699C4948D
AC4F4EA41A1CB00C0DB70A0CB50909B20809B20809B20809B40709B50709B30709B20409
B30A0CAD0A0CA9090BAB090DAF0A0EAE060BAC0408AA0207A5040A8C0A148B4E681B224B
2C43629B8A947A2228940A1195070E8723314333497899ADB5CFDEBCCDD9B4C6D0BBCDD7
BCCED8BDCDDABACBD6BDCFDBBBCDD9BACAD7B4C6D4B4C7D6B9CCDB7F94A9668196728F9F
7F99A383969D95A6A99DAAAD95999D48392E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A27740BAAEA188939C99AFBC87A2AD8BA6B177919B4D67704E6B70557578
4566686C888C94AFB3778F939EB0B4BECACD98A0A4767A7C7B7D7981827D8686818E8F87
9C9C949F9D969F9C959F9B96A39F9AA9A39DACA59CA9A297AEA79BAEA599AFA595B2A595
B6A696B3A090B2A08CB4A38FB5A38FB4A08BB8A38CB7A28AB6A28AB8A58DBCA990BAA68D
BAA68EBBA790C0AA96BDA994BDAB96BEAC96C1AD98C3AE99C7B29DC8B4A0CBB8A5CDBAA9
CCB9A8CDBBABD0BFAFD0BFACCDBDA6CFC0A9D1C1ACD4C3AFD4C3AFD3C3B1D4C5B6D5C8BB
D4C8BAD3C7B8D0C7B6CFC8B7D1C8BBD0C4BBCCC2B8C9C2B4C8C2B1C9C2B2C5BDAFC6BCB1
C5BBB2C2B9AFC2BBAFBFBAAEBDB8ACBAB4A8B8B2A4B5ADA0B7AD9FBBA89EC49690A94D4D
A61B1EB20E12B60A0EB6090BB70A0BB20809B20809B5080AB5090DB30A0DA90A0CA00B0E
9A1416962224983033992B3395151D9F090FA90509A90307A303078E060E8E4C62242D53
56738F9C8B977A2029960A1196050C861E2C4E384E7391A8B6D0E0BDCED9AABCC4B2C4CE
BCD0D9B4C6D4B8CBD9B8CAD5BACBD5BBCDD7BCCED9B5C8D8B2C4DA8298B32845604D6980
637C8A74868F7F8F957A878B7C83854A3F3700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004EBB24BDB09F7E8C92A6BBC99BB2C087A1AD617C864F6A73516C732A464B
223C405A747A627F856D888CB3C4C8BCC6CBA2A8AD76797B7B7C797E7D798887828E8E88
96988E999B909B9C919F9D94A49E97ABA49DADA59CAFA69DACA399ACA298AFA498B0A397
B4A396B4A092B39E8DB4A18CB6A18DB8A18EB7A28DB7A38CB4A28BB6A48EBAA68FBBA68E
BDA890BAA790BCA894BCA994BDAD96BEAD99BEAC98C1AF9AC6B59DC7B7A0C8B7A4CBB9A9
CAB7A8CCBBAACEBFACD0C1AECDBDA9CDBEAACFC1AED3C4B2D2C2B0D2C5B4D2C7B8D1C8B8
D2C9B8D1C8B8D1C8B9D0C8B8CDC5B8CCC2B9CCC3B9CAC3B6C7C3B1C5C0AFC6BEB2C8BEB7
C5BBB5C4BBB4C3BBB2C1B9AFBCB5ABB9B2A7B6B1A3BCB2A4BAA79CC79A95A74D4EA31B1D
B41112B70A0DB9090FB7090DB30709B10808B00807B10B0BA90C0C9E121498292E9A4B56
855769634E684F47655548617E4F5E932C35A10C12A80409A203078E0A12905265293457
9FBCD69E8B987A1E2595081197040C841724593B526F8BA2B4CFDFBFCFDAB9C7D2B7C9D4
BBCEDAB3C5D3B1C3D1B6C6D3B8CAD6B9CBD7BACEDAB9CADAB6C7DC92A7C26A829D8DA4BA
94A9B6A3B5BEA3B4BAA0ADB18A8F9352474227980E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004FB81EB8A690818B8FA8BCCA8EA6B47B97A45976814D69722441461C3639
7C9395849CA0658286547276758C8FBCC9CDABB2B5767A7A797B777C7D7883837E93928C
95968E989A9097988EA1A095A5A197AAA39BAAA29AAFA59DB0A69CAEA197AEA197B0A39A
B8A89CB2A092B5A190B6A18DB7A28DB5A08DB5A08CB7A28BB8A48BB9A48DBAA48DBCA68F
BEA991BCA68EBDA993BEAC95BCAC93BEAD96C2AF9AC1B09CC3B8A3C9C0AFCBC2B3C8BBAE
CCBCAECDBDABCDBEA9CDBEA8CCBDA6CEC1AACEC1ADD0C3B1D0C3B2CFC4B3CFC6B5D2C9B8
D0C6B6D3C8BBD1C7BBCFC6B8CEC4B9CCC3B9CDC4BBC9C1B8C7C1B4C7C1B4C7C0B6C7BFB8
C8BEB8C3B8B2C0B7B0BDB4ADBBB4ABB9B3A8B9B1A5BAACA2C59F99AE595BA21C1EB31013
B80C0EBA0B0EB80A0CB6080AB4090AAD0809A60E0C9D19189D393E915364634A682F335B
172D5B122C5E1B3661495F7C686677A3636C941219A3040B9C0306880D1184516415254A
304D6C867383781C2295080F99050D820E1B643F55647D95B2CFDEBACDD7BDCCD8BCCAD7
B6C7D4B9CCD9B8CBD9B7C9D8B5C7D5B7C9D7A5B7C5B6C8D7B9CADC889CB46D879E758FA1
7D95A181969F8CA0A698A8AE9BA4AA5A5352279A1300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0051B81AB29A7E878C8FADBECD8FA7B56F8D995878832F4D5518323672888D
6B828790A9B06580857B9699657B7EB8C8CBB1BABE777D7E7B7C797E7E7982827D878780
9192899B9D939B9C91A1A197A3A197A7A49AACA49CB1A7A0B3A89FB3A79DB1A59BB0A399
B6A79BB3A394B1A08FB5A38EB2A089B1A089B3A088B7A28BB8A28AB9A38BBAA48DBAA590
BBA78FBCA990BEAA92BEAB93BEAC94BFAE97BFAF9CB3A999C0BEB2D5D8D1DADCD9D0CFC9
C7BEB1CCBBAACFBEAACDBEA8CBBFA6CBC0AACDC0AECEC1B1CDC1B1CCC2B1CDC5B3CEC5B4
D1C6B6D0C4B6CFC4B6CDC3B6CCC3B7CCC4BAC6BEB6C9C0B9C8BFB6C8BFB6C9C0B8C7BEB7
C5BCB5BEB7B0BCB7AEBFB9AFBBB5ABB8AFA6BBAFA5C6A8A0B26866A12024B31115B90D0F
BB0C0EB8090EB70A0EB40A0DAC0E0F9A15169B3C3F956272554A6B20305F0F295A1B3963
445F7E7184988E9AA49FA6A9A99D9E9F6061901115A4060B9B06098E272A66465A172C4E
849CB38C7682761A2394081098040C7F08116F40525B6C83B2CFDDB9CED6BBCDD4BCCAD3
B9CAD2B9CCD6BACCD8B9CBD9B9CBD9B5C5D5A0B2C0B0C3D1B5C8D960799241637E34576C
557481748A9573868E76858D747F88575457269B1600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0050B615AD9170898C8DA9BBC87E98A56F8D994C6A75102C325C757A677F86
3E5A615A777D76909693ABB0768B90BAC7CDB9C1C77A8283797D7A7E7E7983827D86887E
9092859B9C90A1A096A4A099A9A49EABA59FAFA7A1B0A59FB0A49EB1A59CACA298AEA197
B1A397B0A394B5A494B3A090B09E8AB2A089B29E88B7A38BB49F87BAA38ABCA48DBBA68E
B8A68DBDAB92BBA791BFAB96BEAC97BDAD9BA69F8F9E9E91B3B8B2ACB4B5CED4D7D5D8D5
C4BDB2C7B9A8CCBCA9CDBDA8CABEA7CBBFAACCC0AECDC1B0CCC0B0CCC2B1CBC2B1CFC5B5
D0C4B7CFC5B7CEC6B6CCC5B5C9C1B5CAC1B9C8BEB8C8BEB7C8BFB8C7BEB7C9BFB8C6BDB6
C0B9B1BDB8AFBDB9AEB8B6AABCB9ACBDB4A9C2ADA4C28581A02B2CB31419B90D10B90B0D
B80A0CB80B0FB00C0EA512139E2F339B5E6C5A4E6D1F336110306325456F586E86848F98
9499999EA19AA19F96A69C95B89390983F419C1013A6060A95080A9A494F3A2F4C183556
98ACBC9D828B78192194071098040D8707117B3C4A535A6EB2D0DEBCD0DBBACBD4BACAD4
BBCBD5B9CBD6B9CDD7B9CBD7B8CAD6B4C6D4B3C5D3B0C4CFB2C6D588A0B54D6E836E8EA1
8CAAB596AFB98FA2AAA8B5BF75818E41444C4E3A2B00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AF8F68888785A1B1BE8198A669869423414B4A656C60777F3F575E
112A2F657F8544606758747A9DB2B9B5C4CBBBC6CB7E8789787F7D7F827C8A8D868A8D84
8E91869C9D929D9B94A4A09AA9A39DAAA39CAEA6A0AEA49FB0A59EB1A69DADA399ABA196
AEA196B0A193B2A191B29F8FB4A18DB5A08AB4A088B4A087B8A38ABAA48CBAA48DBAA68E
BBA78EBEAA91BEAA91BEAB94BDAC99B3A697938F82B8BAB0D8DDD8BFC6C7BFC4C4D0D0C9
C1B9ABC9BBAACBBCA9CDBEAACBBCA7CCBFA9CBC0ABCCC1AECEC3B2CDC1B0CEC4B2CEC4B4
D0C4B7CDC3B7CCC4B7CDC6B8C9C3B6CBC2B8C8BFB7CEC6BFCAC3BAC7C0B6C6BEB6C3BBB4
BEB9AFC0B9B1B9B2AABAB5ABBAB5AABBADA5C9A09AA44343AE191BBC1113BA0C0EBA0C0E
B60B0FAF10119E1B1DA14B547C5B752D35621030641F416D59738D8B98A0969B969D9D93
9C9A8CA4A295A8A296B19A93AE6E6C911A1EA4090DA2080A8C161984556810204822466B
7E94A299808473181D91080F99020B8F070F7D2D394D485DABC8DAB7CDDABACCD6B7C9D5
B9CAD6BACBD9BACBDAB8C8D7BAC8D5B9C7D6B5C6D3B3C5D3B2C5D3A1B5C7728C9E7D99A7
87A2AC8EA6AD90A3AA98A7B17E8F9D222E3950443800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A9865C9E9B9795A4B08EA6B546636F3E5C645C777F3B545C0F282D
627B7E8BA4A87D979C63818638565CA5BAC0BBC8CD8590937C84838386828C8E898E9089
8F92889FA0969B9A94A4A09BA6A19AABA39BAEA59FACA19CADA29BB0A69DAEA399AD9F95
AEA094B0A091B19F8FB4A191B4A08DB6A18BB4A088B4A088B7A38AB9A58CB8A48CBAA68E
BCAA92BBAA91BBAA90BCAB93BCAB97A89B8B9A9486B5B3A7C9C8C1B5B7B2B0B0A8C7BFB2
C5B9A6C9BBA5CABCA8CDBEACCDBDACCCBDAACBBFACCDC1B0CEC1B2CFC2B3CCC1B1CDC4B5
CDC3B8CDC3B8CEC4B9CEC6BBCAC4B8C9C3B7C9C3B7CCC5BBC8C2B9C5C0B5C6BFB4C5BDB3
C0BCB2C0BBB5BCB7B1C0B9B2C1B8B1C1A8A3BD7977A42222B81313BD0E10BB0C11B70F11
AA120FA52E2AAC666B5946601C2B5B1634664661858192A098A19E9C9E94A09F939E9C8F
A09F8EA5A193A89C91B085809233349F1014A4070B980C0F9845513F31540C2C5C325C82
4964778B7981731D21910A0F9B040D95050E7D1A275A4558A3BECEB7CFDBBCCDD9B8C8D5
B8C8D5BBC8D7BDCADBBCC9D8BCCAD7B8C8D7B5C7D3B2C6D1B3C8D6879FB0456479577688
66838E7B94997B8F947C8A926374811C2B36504A4000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AD8554AEA79E8F9EA77E94A23853607B97A23F5C650D272E597277
718B916C8890819AA0728A90768D929BAEB3BBC9CF8D9B9F7D86878C8F8C8F908D939490
999B939D9E969F9F97A3A29AA3A098A7A39AA9A39CABA29CADA49CAFA69CB0A298B1A096
B3A295B09E8FB09E8EB19E8FB39F8DB49F8BB19D86B19D85B4A087B9A68EB4A28BB7A590
BAA893BAA890BBA88FBCA991C0AE99B8A8978B8273A4A095A6A398979588BCB7A7CBBEAC
CCBBA7CBBBA7CABBA9CDBDADCDBCADCAB9A8CCBCABCDC0AFCEC1B1CBBEB1CDC1B4CDC3B7
CCC2B8CCC2B8CDC2B8CEC3BACCC3B8CBC2B8CBC2B9C9C1B8CAC3B9C5C0B5C6BFB4C8BFB6
C2BDB3BEBBB2B9B7B0BCB8B1C1B9B1D0ACA9A44749B11B1DBE1112BC0C10B60D0FA91310
B13F36CF837E98677070536C6256737D7E9391959B9A9D97A3A598A0A193A09E919D9E90
A4A293ABA297B5958E9E4F4E941416A5090D9E0A0D952A33754F6B112050254871A9CAE0
ABC0CB9C8E946F1F23920B1199030995020B810B167041538F9EAFB6CDDABBCCD9BCCAD7
B7C7D4B8C8D5B9C9D8B7C7D6BACAD9B8C8D7B3C5D3B2C5D3B5CAD87C94A86E8BA2557288
6D8A9788A2AAA0B4BA9EAEB58697A11E2D3858554D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AB7E4BB5AAA08B97A0899CAB758D9C67838F143138466064698389
4C69712B4950607E8394AFB4698186A7B9BDBBC8CE9AA5AA7F888A8B8F8F919290939390
91928D9C9C979E9E96A4A49AA6A59DA6A19BAAA49FADA49EAEA39CADA299AFA097B09F94
B29F92B09F90B09E8EB19E8EB39F8DB59F8CB39D87B4A088B2A089B4A58EB6A68FB7A790
B8A892B8A793BAA993BFAC97C5B19DC1AE9BB7A798A19688A9A291BCB5A2C8BBAACAB9A8
CEBEABCDBEADCDBDAECCBCADCDBEAEC9BCAACBBDABCCC0AFCAC0ADCBC0B0CAC1B3CAC2B6
CCC4BACCC3B9CEC3BBCDC3BCCEC3BBCBC1B8CAC0B8CABFBAC6BEB7C5BEB5C5BDB3C6BDB4
C0BAB1BCB9AFBBBAAFBEBAB1C2B4AECD9F9F9B2D32B5151ABF1013B90E11AD1412B53B34
DD8079BA60609B353C96283494353EA97070AD988FA29E92A19F92A5A298A2A095A3A193
A9A093B3968EA86562931B1DA30C0EA30A0A991F219156692626530E2A5C5F7E9995ADB6
A7B9BF9E959B73292F8C0B1298030898020A8B060F7529377B7585BBCEDCBACBD9BACAD7
B6C6D5B5C7D5B8CAD8B6C8D6B4C6D2B7C7D4B6C8D4B3C6D4B2C6D68AA0B2849FB0748E9D
768E98778E96869BA090A3A88C9EA61F303A5A5B56269A0F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0053BE28A69A8B828F96AEC1D0879FAF3E5B67314C54667F854A636A
0F29304A65685D797C456266819A9F94A8ADBCC8CDA8B1B67F878A8C91918D8F8D949590
9796929B98959F9D98A4A29DA5A19AA69F97A9A199ACA39CAEA49DACA299AEA299B1A496
B0A091B3A193B09D8FB19F8DB3A08CB29D89B39E88B39F87B19F88B4A48DB7A78EBBA991
BCA894BBA794BDAC98BFAE9AC1B09DC4B29CC6B3A1C2B1A1C7B7A5C7B9A6CABBA8C9B7A5
CCBBA8CBBCA9CCBEAECABEAECABEAFC7BAABCABEADCAC1ADCBC3B0C9C0AFCAC0B3CAC2B6
CBC3B8C9C1B8CAC0B9CDC3BDCCC1BACABFB6CAC0B8CAC2BAC4BDB5C7C0B8C1BAB2C3BCB4
C5BFB8BEBBB0BCB9AEC0B9B2C2B4AEC592929C272BB81519BC1011B41310AE2B24DF7871
AA3D3B9E191BA81114AC0D11A31216902A2AB18B849D9C939EA097A7A59CA39E95A79D93
B1938DA96162982023A30C10A7080AA11010BE595C6E425928284E43507095A2AD959EA3
8B989F716A747C3841890B129702079A020A92030B780D1B7C5261B4BCC9BBCCD6BBCCD6
B7C8D5B6C8D4B8CAD8B7CAD8B7CAD5B6C7D2B8CAD6B2C5D3B2C7D68CA4B64561755D7787
69828A687C835E7274697B7D687A811A2C395B605F279D1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0052BD23AA9B86808D92A7BDCA617D8B2C4B54627C82486166122B2F
455E627C949992ABAF9AB3B76D878D556D72BECCD3B7C0C781878D87898C8B8A8B939190
9998959B9A969C9B97A3A09AA8A39DA9A39CABA39BAEA59CACA199AFA29AAD9F98AFA196
A99B8EB3A496AF9F8FB09F8CB2A18DB5A38FB4A18BB29E86B6A28AB7A48CB8A68FBAA691
BAA491BFAA97BAA895C2B2A0C1B19FC5B4A1C4B2A0C3B1A0C4B3A2CAB9A9C8B8A6CBB9A7
CBB9A7CEBDABCDBDADCEC0B3CABDB1C7BBACC5BCABC5BEAACAC3B0C8C1B0CBC4B5C7C1B3
CCC6B8C7C1B4C8C2B7CBC4BAC9C1B8CAC4BBC9C4BAC9C4BDC6C1BBC4BFB9C2BEB7C0BCB5
BEBAB2BEBAB0BEB8AFBEB7AFC2B3ADC9989899282CB81519BB0F10AD140FD96058BC4A48
A21718AE0D11B10A0DB20B0DA90E119021257F5D67606D7693A09CA1A099AC9F97B6928E
A559589B2023A70C10A9050AA70408A20A0FA82A2F9D3A47924A5A9B6A75BFA4A8B8B1B3
B9BFC4958E9681444C890E159802089A02079502098C0914782834B7A4B0C2CBD5BFCDD8
BACBD5B7C6D3BBCBD8B8CAD8B3C7D4B6C8D4B7C9D5B3C5D3B0C5D3A4BCCE2C496066879B
6F8E99738C9579909580959A82969E1C303D5B64653A6C1E00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB81A9F8B6E7A8183ABBFCA3E59637591995C757C183035364F53
6E8A9058757C809CA38DA6AC6E868C687D82C1CED5C2CAD4858991898A8D8D8B8C908F8D
9697939797929B9994A09B96A6A19DA9A29FA9A19CADA39BACA299AFA49BAEA097B1A399
A99B8EAC9F90AF9E8FAF9D8BB19F8BB19F89B5A189B59E86B79F88B6A289BAA68DBDA791
BFA996BEA897BDA999BBA99BBCAB9CC1B0A0C6B4A4C3B0A1C8B5A6C6B3A3CAB7A5C9B8A4
CBBAA8CCBDAACDC1B0CBBFB0C9BCB0C7BCADC5BEACC2BBAAC8C0AFC7BFB0C6BFB0C5C1B2
C9C3B5C9C0B5C9C0B7C8C0B7C4BFB5CAC3BAC9C3BAC3BFB6C6C1B8C3BFB6C1BDB5C1BFB7
BFBCB3C1BDB4BDB8B0BCB5ADC1B3ADD0A8A79A373AB1171BBA1011AC110EE6605CAC2424
AE1013B40B0FB40E10AC0E109D131796435150436422395A8D9BA3A79B96B08681A14A48
9B1A1AA90D10AA0709AB0509A90307A90509A4060BA0080D9A0B129010188C2C30AF797C
A69798A89FA2834E52830F1797030B97010798020996050F800D17935A64CEC4CFC0CAD5
B9C8D5B8C7D4B2C3CDBACCD8B3C7D2B3C7D2B5C9D4B6C8D6B2C7D5ACC4D5637F937695AB
7493A7688397597687637F8F6A859515313E52626252453000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB616A78F6C888D8BA8B8C270878F7F99A3304B552D454C728991
526F792B4D5564848A607B807E9599A3B6BAC2CFD5C7D0D88A8F958B8D908D8C8D8C8A8A
92918E9696929A9995A29C99A49B9BA99F9FAAA19EAFA79FADA59CACA398AB9F96AB9F93
A99C8FAC9D8FAE9C8DB09D8CB09E8AB09E89B4A088BBA28CB99F89B8A38CB6A48DBAA793
BAA895BAA997BDAA99BDAA9ABEAD9CBDAC9AC4B2A1C5B2A3C5B2A2CCB9A8C9B8A6CBBCA9
C9B9A9C9BCABCBC0B0C8BFAFCCC0B2CABFB0C5BCADC4BAADC6BCAFC6BEAFC7C0B2C3C0B3
C7C3B8C9C1B7CAC1B8CAC2B8C7BFB6C8C0B7C9C3BAC6C2B9C4C1B8C5C1B8C0BEB4BEBDB3
BEBCB3BDBEB3BDBBB1BEB7AFC0B5B0CAB0ADAD6464A42025B51115B71112B9181AB41116
B50D11B30C0FAA0E109817189A434E785B7C19285A2C4069A297A3AF74759631329E1315
A90C0DAC0709AC0809A80307A90307AA030AA70105A60105A60308A6060B9C0B0D871A1E
AB7877A29090A174757D121996050E9A02099C030B98020C8C040D76151FAD818BCAC7D0
BBC9D5B6C8D2B3C5CFBBCDD9B7C9D5B7C9D5B7CBD7B5C9D8B2C9DE7C98B33957791D385E
0A224A051B4302173D0416380C223F09243854686A554D3C00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0050B814AA926A9B9F9BA0AFB99CB0BC516C7726424B68838B58737F
264751406267617F8249636695ADB098AEB3C3D3DAC9D2DB8D939A898D908E8E8F929291
9897959797949A99959D9996A49E9BA7A19EA7A19EABA6A1ABA49CAA9F96A99C94AA9D92
AC9D90AA9A8BAF9E8EB19F8DB19F8BB09F8AB3A18BB6A089B69E88BAA28BB9A48FB8A694
B7A996B9AB98BBAB9ABEAB9BBDAA99BFAC9AC0AE9DC6B3A4C8B5A6C8B6A5C9B8A6C8B7A6
C7B7A8C9BAADC9BBAEC9BDAFC9BFB0CCC2B4C6BCB0C5BCB1C2BAAFC4BCB2C9C2B7C3BFB4
C7C5B8C6C3B7C7C1B6C8C1B9C8C0B6C9C2B7C8C2B9C6C1B8C4BFB6C5C1B8BEBCB3C1C1B8
C1C1BAC1C1BAC2C0B9BDB8B2BEB8B1BEB2ADC6A09EA24C4FA12022B01819B11415B21418
AB1217A0151996262C9E5B696B5A7A1F2F5E2F3B6A8268859E505B9A1F23A81214AB070A
AF0808AF0808AA0607A80307A70208A70206A80309A60107A90408AE060DA9060C920A0F
93454A998087A6858B7A1D2691070F98020999020998020B92020B870813751E2AB5939E
C2C6CFB5C6CFB0C4CFB1C5D2B7C9D7B2C6D5AFC8D8A7C1DC6380A81A396B011B5000144D
001146000F3F010E3B000D37000F34021833475C6554544813CC0600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98D619B9B9696A5AF869DAB24414C728E97607C83325058
3E60652B4D4F7F9B9C98AEB3627A81516970B4C6CDC8D2DA91999F8A90938E9191909290
9798959B9C989D9C999D9C97A09F99A5A09BA39C99ABA5A0A8A199A9A097A89E94A99E93
A8998EAB9B8EAD9C8DB09F8CB2A08CAE9D89AF9D89B09D86B6A189B9A38CB6A18BB6A490
B9A994BBAA96BBA998BBA897BEAC98C0AE9AC1AF9EC1AF9FC5B4A4C7B6A5C8B7A6C6B7A6
C6B8A9C7B9ADCABCB0CABEAFC9BFAFCBC3B3C9C2B2C4BCAFC4BDB2C5BDB4C3BCB3C3BEB4
C3BFB4C5C1B6C5C0B5C7C0B6C4BEB2C6BFB5C7BFB6C7BFB9C5BEB7C5C1B8BFBEB5BFBFB9
BEBEB9BFBEBAC0BDB9BEB9B5BEB9B3BAB3ADBEAFAAC7A4A2B174709F48469A353897343A
98454D995E6E7C64813A406D1C2F6151537B936580932E3B9F1319AE0E11AE0909AB0507
AD0709AD0709A90506A80305A60105A70105A70206A60207A70208A90108A8040997060C
8D323E50384A998B997830398B0A1396010998030995010992010A8F020B830814762330
B0949EBEC7CEB5C7D0B8CAD7B7CADBB1C8DE7E9CBD24447502205B011A5900155100104A
010E44010E40010D3A000B36010E340112321B2F40535A5222980D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98552A5A19991A0AA7F94A14C66717390993A595F3B5D60
3154556C8C916D8B93718B919BB0B78B9EA6B0BFC7C8D3D89CA6A8878E918C92928F9392
9596949898949A9B959C9D989E9E989F9B97A39D99A8A19BAAA198A79F94A59C91A69A8E
A99A8CAB9A8CB09D8FB19D8CAE9A89AC9A87AE9C87AF9C85B49F87B39F86B4A08AB5A38E
BBA893BDA893C0AB98BBA793BDAB96BDAA98C0AC9CC1AF9FC1B0A0C6B6A5C5B6A3C3B7A4
C4B9A8C3B8AAC5B9ACC8BDAFC7BEB0CAC1B3C9C1B4C2BBB0C1BAB0C3BCB2C3BCB2C2BBB1
C4BDB2C7BFB5C4BCB4C6BDB5C7BEB5C8C1B9C7C1BAC4BFB8C2BFB7C3C1B7C1C1B9BFBFB9
BFC0BAC0C0BBBDBBB6C0BDB6BEBBB2BCB8AFBCB5AEBBAFAABEAEA8B09C9C7C6B756A6377
4F56732A3D66183367293A6D75648A924D62951E28AB1418AF0B0DB1070AAE070BAB0508
AB060AAC070BA90408A90409A9040AA80309A80409A80307A80307A80306A5030698070C
9237443D2A426E718485525C830F1797040B96010593000793000A94010C8D020D7F0A16
6E2F36B5B1B5B4C8D1B0C7D9A6BFDC58759F0B2A60011C5C00175A01145901135501114E
010F46010D41010D3E010C38010C33000E3005172E515A59219A1000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A87E42B2A99A89959C98ABB67F96A44F6B7736565C305155
6E8B9044606727434A5F7B828EA6AC7B8F96B6C7CEC5D1D8A7B1B6868E918E9395919595
9395939798949899949A9C979E9F9AA19E9BA49E9BA69D97A89E95A99F96A3988DA5978B
B1A093AA978AAD998BAF9A89B19C8AAD9B88AB9A83B09D85B29E85B5A189B6A48DB6A58F
B8A791B8A68FB9A792BAA693BEAC98BCAB97BCAA98BEAC9BBFAE9DC2B2A2C3B4A4BEB2A0
C0B8A5C3BBA8C2B9A8C2BBABC6BFAFC6BFB0C7BFB3C4BCB2C1BAAFC0BBAFC0BCB0C1BDB0
C6C0B2C8C0B6C7BFB7C7BFB7C6C0B6C0BEB3C4C2B8C4C2B8C1C1B7C0C0B7C1C0BABEBEB7
BDBEB6BFBFB7BBBAB3BFBCB5BCBBB1C0B9B2BAB3AEBCB5B1B4B2ABAFAFAC999EA3707F8E
5A6E855669877476949470889035469E1620AB0D12B20B10B2080CB1070EAF070DAC060A
AB060CAB060CA60409A60309A5050AA5060BA30508A50308A50207A80307A1030690060B
9648572E2647515E789B7B8677141C93070E98040995010894020993000A90020C850510
6E1F2A918898ABC4DA9AB7D73B5A8A04215D01195B01165B01185D02175B01135400104B
010E43000D40010D3D000C38000B31000D2E02132C38434A46362100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BD24BCAD9C7E878EB5C8D56983913858633B5C61607D82
486166172E327B9497718A8E687F86B3C5CCB2C1C8C1CED5B2BDC3848D908990928D9291
9496959796949A99959C99969E9D9A9F9C99A49F9AA69F98A59D93A39B90A59A8FA5988D
A7978DA7958AA89587A89683AD9B87AE9D89AA9A84AD9C84AF9C84B5A289B5A48BB4A48B
B7A78EB7A78EBAA992B9A894BCAA96BBAA96BDAA96BEAB96BCAC97BEAF9CC0B3A1BCB2A0
BCB3A0C3B8A4C3B7A5C1B8A8C1BBABC3BDADC5BEB0C9C1B6C2BBAFC1BBAEC0BCAFC0BCB0
C2BCB1C6BDB4C7BEB8C7BFBAC6C1B9C1BFB6C0C1B6C1C1B7C0C0B6C1C2B7BEBFB6BFC0B8
BEBFB7BEBFB7BBBCB4BABAB2BBB8B1BCB7B2B8B4B0BBB7B3B2B3ABAFB0AAADAFABAAADAD
A8A7ABB29EA7A86B76932531A8141CB30D13B5090FB50811B4060FB1060EB1090EAC070B
AA060CA7080D9D0A0E93090E900F15901317950C119D050BA30307A50306A00508890C15
8D546D161F484D6382A696A176252B900D1597030A96000A94010B93010B90010A86050E
7A2A3D322A4E6688B62B5085011E5E01185C00145802165B02185C01185A011551001248
01124004153C0C1F4307173C01103201122F04152F22313D4C423400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0056BF26B7A38F6F787CB1C5D04B677338596258777C516D72
152E32758D917B939AAAC1CBAFC4D0BBCFDBA9BAC4C4D0DABBC4CE838A91868E908C9392
9598979696959896949D99979F9D999C9B97A29F99A19B93A29A91A2988EA1958BA4948B
A49288A69289AA968AAB9687AD9A88AB9A85AE9D87B29E88B39F87B09F88AF9F89B3A28C
B6A48EB4A38CB6A68EB7A791B9A894BBA994BDAB95B9A78FBBAA93BEAE99BAAF9AB9B09C
BBB19DC0B4A0C2B6A3C0B7A6C0BAA9C2BDADC7C1B4C8C0B5C5BEB3BEBAAEC0BCB0C1BEB2
C3BEB3C6C0B6C4BFB6C4BFBAC4C0BCC4C3BCC3C2BAC2BFB7C2BFB6C2C1B7BEBFB4BFC1B7
BDC0B7BEC0B9BCBDB7B8B9B3B7B6B1B9B6B1B9B6B1B6B5B0B6B6ADADAEA6AFAEA8B0A8A3
BB9F9FA760659A212AAA1117B40D11B5090DB3080EB4070DB4070DB2070DAF0A0EA60A0D
9B0D12951B239539428E4D5D805466845663A04A52920B11A5060AA6040A98080C92333F
492E500D25547193B49DA3B2824D5483101795040C97010C94010B92010A8D000781050C
7B2F45201644041D5C011C6200176100145A001357011458011758011C570E2B5C1D375D
3951695066764F6275162842061C332139490920300F202E4D463E24960900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0053BA1DAA9175717474ACBFC8516C7745626B627F84173034
688185738D945C778299B2BF7A94A1748E988A9DA6C3D1DAC0C9D3888E958B9092919594
9195949496959795919C99949E9C979D9D98A19F9A9F9A92A39B90A49990A3968DA4948C
A5938BA99790A9978CAC988AAE9B8AAD9A88B09C89B49F8BB49F8BB29E89AF9C86B19F89
B3A18BB3A28BB5A58DB6A690B9A793B9A893B8A791B8A790B8A792BBAC97B8AA95AC9E8A
B5A592BDAF9CBAAD9BBEB5A5B9B3A3BEBAA9C3BEB1C7C0B5C5BEB5BDB9AEBCBAAEBFBDB0
BFBBAFC1BEB2C3C0B6C2BEB7C4C1BCC3C2BCC0C0B8C0BEB6C1BEB6BFBFB8C0C1BABDBFB8
BCC1BABBBDB8BCBEB8B7B8B2B8B9B1B9B6AFB8B8B0B8B8B0B4B4ACB1B0A6B5AEA7C0A3A1
A961649C2028AE1018B40B12B50B0EB4090FB3080EB3070DB0090BAA0A0F9D121595272E
934B5B7C57744B456C232D5D1926544D405F934A57920C14A10209A1040997171B9D5869
201C412A4A775D8CAE6D8CA389727E77181F91070E97020A9301099202098D02087E040E
7631491C144502165700155E01165B01175800165306235B1634653457815A80A07A9AAF
8BA4B093A8B35C7285061932213B4C4B64684053590E1D2A48494821960D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DC0C9F815D8C8B87A7B7BF5D75825E7A841A363B5D787B
6C878C5470794B65719EB5C1405A63859BA2C2D2D9C4D1D9C7D1D78B9298868B8D888C8D
848888878B898E8E899A98919B99929D9B979F9C979E98919E968CA1968D9F9188A4958E
A4938BA4948AA6968AA99789AA9788AE9988B09B88B19E88AF9D88AF9D88B09E87AD9C83
B2A089AF9D88B2A08CB3A18CB1A08CB3A28EB5A48EB4A58CB0A18AB1A28CB1A38EB3A38F
AE9D89AEA08BB0A492ABA190B2AB99BBB5A5BEB9ACBEB7ACC3BBB2BEB7AEBEBBAFBEBDB1
C0BDB1C0BEB2C0C0B5C4C2BAC3C2BBC2C3BEC5C5BFC2C2BBC0BFBABFC0BAC1C4BDBDC0B8
BCBFB7BEC0BABCBFB8BABDB6BABBB6BAB7B2B9B8B2B5B4AFB5B6AFB5B1ABC2ABA7AC6869
A02529AF1116B40C11B6090FB5080CB6090DB4080CAF0B109C0D0F982A309757656C5675
2E3567122964102C65253A6957517581495F8B19259E0710A4030AA1040AA41A21A34857
6C48616A6F8895AFC37792A49C97A1773139880C1395030B9401089100098A010B79071A
4E163B12114B02145901135B001559011A57092759375B8186A8C497B8D32A4C6781A1B7
7491A07794A62D4762011530506A75586F6D54646422303844484A21981100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009E7D53A5A39DA1B0BA839BA836535C48656A718D92
4D6A7146646C95B0B993AAB494ABB4A3B6BFC6D5DDC7D2DBCCD5DC8D969B7C8487787D7E
75797780827E8C8B8795928C98948D9E9A95A39C97A19790A1978E9F958CA0948A9D8F86
A19289A6958DA7968BA99889AB9988AA9885AB9A83AC9B84AB9983AC9B84AE9E85AE9D85
B19E86B5A08AB4A18BB19F87B2A088B19F88AD9D84AF9F85AF9E84AB9A81AB9A83AB9B84
AD9E87AB9E87ABA08AB1A794AFA794B0A897B4AD9EB6AEA2C2BAAFC4BFB3BDBBAFBDBBAF
C1BEB3BFBEB4BFC0B9BDBEB9C0C2BDC3C4C0C5C6C2C1C2BDBEBFBABDBFBBBEC2BBBCBFB6
BDBFB7C0BFBABDBFBBBABCB8BABCB9B5B4B2B9B8B4B4B5B0B5B5B0BEB0ACB8818299282D
AF1318B70B10B80B0EB40A0CB3070CB2090EA80D119E1F259E4F5C7156732C39690C2866
11326D36507C6F769393768B883B4B8C13209F0814A4040CA9060BA40108A1040B940914
87202BA06B75A19BA3B0BFC9A3A9B38B646E7A141D92070F95020A90000A860511600B29
240A3E0A155901145C01145A021D592748777A9BB9A1BCD1AFC7D98299AD5770846E8797
5D788833516B021E3D0F2B424660644F635C52635F3B494D3E4346219A1500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A38055A7A49E9CAAB5879FAC314D587591994B6870
3B595F88A6AB4A68716E8A95748E9995A9B3C4D3DEC0CBD5C8D0DA939BA27C8487767A7C
737674848480928F8C9C9593A098959F9793A49D969F978F9E968E9F978D9F94889E9085
A29086A49287A9978BA89687A99887A89884A99983A89780AE9B83AC9B82AA9A80AE9D84
AE9C84AF9D85B09E86AF9C83B19D84AB9A80A9987EAA987CAB977CA9977DAA9981AB9C85
AA9B83AC9E86AB9D88ACA18DAAA28DAAA290ACA596B5AFA1BBB4A7C1B9AFBDB9AFBFBBB3
C3BEB8BEBCB7A2A5A39197969FA4A4BCC0C0BFC1C0BEC1BFB0B5B29FA6A4A8AEAAB8BDB8
BCBFBABCBDBABABCBABCBDBEBBBCBDB8B8B6B4B6B1B3B4B1B5AFACC39F9F993D42A8181E
B50D13B80A10B80B0FB60A0EAD0A0EA010159B323B92607842436D122E680F346C3A5782
747C989B85949A5E698E272F970F17A0050DA40309A7030AA40308A70409A8040AA4040B
970911821E25B08C9599A6BA5A75908B8497732C35880C1392020A8D020B73081B3B0A35
0F1051041661001A5E0928614A6C949DBCD7ABC5D7ABBFCEB2C5D48297A799B2C094ACBD
4F6782071F450D284745637359727255666052605A414F5139424525A11D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A68254A6A09996A3AD748896758F9C5F7C853A575E
7D9AA04C6A72607E8675909A758D97A5B6BFC6D3DDC3CDD8C9D0DBA0A4AE7C8186727679
7B7E7E8B8C8A9392919793919D96939C958E9E998F9A958B9B968D9C948C9D9188A29087
A18E83A49186A69487A39283A69584A89784A99884A99884AA9782AB9981AA9B81AB9C82
AA9980A8957CAC987EAD997EAF9C81AF9F84AC9C81A9987DAB997FAB9980AA9B81AC9E85
A7997FAA9980AB9C85AB9F8AA9A18DA8A18EABA491AEA898B2AD9EB3ACA1BDB7ADBEBAB1
C1BEB8A9AAA5949994B2B8B5888E8DA9AEAEC2C4C5A2A5A4959A97A2A7A3A1A8A3848E8B
A3ADA9B6BDB9BABDBABEBFBDB7B7B5B7B8B4B5B6B1B2B1AEBEABABAF6C709B1D24B21016
B60B11B80B11B5090FB00C119B14199A445173577525366C0E327126477A6B79979C8B9C
9D687190333995161CA10B11A4040BA40309A40309A30208A40309A50409A50207A50309
9F030B830A138F5A676E768F1A39586C788C8B626B7A141A8B040B8605105A09261F0C45
07175F021B6213366F678EB4A6C6DCB0C7D8B1C5D4B3C5D4ABC0D23D5B7391B5D34C6B8F
14305B011B452A486173939D6B828360726E5260584856553440412CAB2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A47C4BA19A8F929EA5AABCC9849CA93C59646C8991
55727B5C7A84738F99788F97ABBDC6C4D0DAC6D1DCC5CFDAC7CFD9AAB2BA696E75727579
8385878F908F92918F96918F9D95939B96919A959093918A96938A9C948C9F91899F8F86
A18F85A18E82A18F81A69385A99686A89683A99782A79581AB9985A8967FA9977FAB9A7F
AB987CA79277B09B80B19C81AD9B80A9987CA9997AA89877AD9C80AA9A80A99A80A99B81
A8997FAB9A80AC9E85ADA28BABA08DA89D8BACA28EABA28EAEA897A9A394B5AFA3B9B6AB
C2BFB7AAAAA5888C87AEB5AF8A908DAFB2B0BABBBB8C8D8BBDBEB9BEC0BABCC0BAADB3B0
808988B5BDB9B9BAB5B9B8B3B9B8B3B6B5B1B6B5B0B9AEABC7A0A298373CAE181DB60B11
B60C10B50D10B00D129C181CA055625F5174162F6810336E475D878E849D98697491383F
8F151D9B0B11A3070EA8050DA7040AA50109A4030BA30208A10109A20108A60308A70409
A00309860610874C603C425B86A1B596A9B69B8D95762E34840D137E0919470E33121353
03165F011C5B4B749FA3C8E1AFC9D7B7CBD9B2C6D5B4C5D6AEC2D54F6D8A466C94163565
001C480D2C4C41606E5C757A53686852645E5362574D5B562D3A3A544E4500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0051BE29A397898A959EA8BDCB607B865B788257747E
58767F6C8992728D96A7BBC5BED0D8C1D0DBC3CFDAC5CFD9B2BDC6909BA26F767C737579
88878992909092908D938E8D9B959499949297928F8B8884908D859A92889C8F869F8E86
9E8B829F8C7FA29183A49383A89685A99782A5937DA4937DA4927CA7947DA7937BA8947A
AB987BA89579AF9C82AF9B82AA987EA49278AA967BA69273AA9779AA997EA7977EAA9C85
A4977FA69A81A9A089ACA28FAEA191AA9D8DA89B8AADA392ADA696AAA395A8A496AEAB9F
BEBDB3BCBBB39C9F97939B92A4ABA3BFC2BDB5B5B3959795C0C1BDBEBFBABCBEB8B4BAB7
7F8985B2BAB5B7BAB5B9B8B4B9B6B3B3B3AFB4B4AEBFB0AEB98285971F26B51117B90C12
B50C11AF0F13A01D23A35A6A554E72163168203C71717296997184943E4A91181FA00E15
A4070DA7040CA7020AA50309A30207A40309A6050BA40309A30208A60209A8050AA70309
A00509850A1488556D1A28499CC0DA6488A177889C8E6B757317226E0D26310B3A0B1454
0915531F2F633D6085A4C9DFAFC8D6B4C8D6B6C9D8B6C8DAAAC0D77694B60A2B59001E50
1C41645476877A949A6E82855D6E6F53635E5262584858562C3A3E56544E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004EB91FA59781869096A9BECA5E798473919A486771
65838B5C777F98AEB6BDCED8BDCED9C1D0DCC5D2DEABB6C3838D967B858980868A838687
88898890918D8E8E8A95919096918F98918F98928D827C758F88809D938A9D8F879D8B85
9E8A82A08D80A18E80A59384A69483A7937FA7927DA4907AA49078A8917AA9927BA8937B
A8957DAB9881A7947BAB987EA69579A39176A69277A79275A89375A9957AAA9A81AB9D85
A79C85A69B87AA9F8DACA190ACA291AEA393A69C8BA99F90A9A3999B9A8F9091869A9D94
B9BBB2BCBCB2BEBFB4C1C2B8BFC1B8C5C4BDBEBEB98B8C8BB3B6B6BCBFBDBEC2BD9FA5A2
909693BABEB9BABBB7B8B7B5B5B4B2B2B2AFB3B3AFC0B0AEAC6D70A11E22B71114B90C10
B40E11A1161AAA596659486C2334674A5182896A8B954758951C28A30F18AC0A11AE0A0C
AB0508AD080DAA060CAA070CA6050AA60409A60409A6030AA7040BA8040BA7030AA8060D
9E090C881E276E4F6E1026507CA1C11D4164385473AEA9B97137465E1637270C42121253
2813454D34583A4763A8C8DCAEC9D6B2C9D7B5CCDCADC6DE6E8DB0143464011F511F466D
5D859C88A7B28FA6AB7D8F926D7D7D5D6D6950625B394D4C253A3B61685F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004FB91CA29074899497B0C5D187A0AD54737E5E7D86
65818893A9AFACBDC6B4C3D0B9C9D7B9C9D898A6B677818C7780867B8386808689868A8D
88888A8F8F8F908F8D918F8C9992909A908E9E94918F867F8C847A938A819D908A9A8B85
9B8A819E8C7FA39081A49283A1917FA2907BA6937CA7937AAA957DAA937BAD947DAB9680
AB9681A7927BA28D73A49075A49276A8987CAC9B81A39073A79275A59174A6957CA99980
A69982AB9F8BB0A493ACA192ABA293AAA392A49E8D9C988A7C7D747D8179787E77626C66
848D88BAC0B8BCBEB5C1C1BAC5C3BBC5C2B9C1C1BBB0B2AF8E9293919899929D99949D98
B2B5B2BAB9B6BBBAB6BBBAB6B7B8B3B4B3B1B3B3AEBFB1ADAE6C71A21D23B81114B90E0F
AD1112B4474C87596B5C4E6F8769888F465D94212FA3121AAD0D13AD070EAF080DAD0709
AB0508AA0409AB050BA8030AA6060AA1060A9F0C0CA10C0FA4070DA60309A70309A20309
91080D9343543A345C1A3B667698AF7490A2849FAFC2CEDC927A8B4E2247200F47190F4C
46123C60233F3C344F9CB9D1A9C8DAAEC8E093B2D53F618F07285F011F550A27514F7089
59798668828B63767C5E6F71606F6D5464604D605C1F3439294147606E67209B1300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0027D90BA68D7093999DB4C8D86F8A9961828C5E7B81
96ADB3B6C6D1B3C1CFAFBECCABBBC98796A46B7681737A82787C807A80837F848787898D
858689888A898D8E8B92908C948F8C98908E97918B979289918D829892869B9287998B84
9A89819E8C82A39084A59284A59081A48E7CA58F79A7927AA6937BA9957DA8937BA9947C
A6947CA39278A39173AA9679AC9B7FA5957BA8987EA59376A69174A89276A59278AA9982
A89982A89C84A59A84A59B87A99F8CA69D88A39C89807F727B7D768D91898F958E737E7C
566663A3AFA8B7BBB3BFC0BBC5C5C0BEBEB6C3C4BDC0C1BCC0C2C0B8BAB8B9BCB8BEC1BC
BBBBB8BAB9B7B8B8B6B9B9B7B8B8B6B6B6B5B8B9B4BEB3B1B780829C2127B61217B80D0F
AA1111D5686AB66C75A14E5E9523319F111CA70A11B20B0FB1070BAF050BAB0509AC070B
AA050AA9040BA8070EA2080D970C0E8C1816A5423CBE504E980D12A3030BA8040B9F060B
8A1721825473102254537EAA9FC5DA9ABACA7DA0B2AECCDDB2B6C6614E6D1F164B170E49
43123C5213304535547F9BBF8CAFD44F709E10306703235C092C5D2A4B70728EA469828D
849BA1778B90697C7D6476755B716D4E6464344A52061A2D172C3D606F7025A21C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A58666939597B2C4D46B849667839088A2A9
B0C2CAB8C7D4B3C3D3A1AFBF7A808F706C786E677075737A7D7D837E8084818689858889
8888898987888E8D8A92908C928F8A938F88948F88959188969087978E84998F859A8A81
9B897F9B897FA08D82A18D80A18B7CA48979A58C79A6917BAA967EA8947BA7967BA69579
A493769F8D6FA49070A38E6EA39071A18F73A28F74A69074A79070A89270AB9676A89679
A5967CA4987DA59B7FA99D84A89C84A89D86A69F8B6B6A5F6D746E7E88827A8480627170
4D605C9BA8A0B9BDB5BFBFB8C3C2BCBFBEB9C0C0BBC0C1BBC0C0BBC2C1BDC0C0BBC1C2BD
BBBBB8B9B9B5BABBB6B8BAB5B6B9B4B7B9B6B7B8B3B8B4B0CAA5A4963339B0181DB80F11
B41012B31D21A81B22A8141CAC0E15AC070EAF090CB3090CB4090EB0070CAC070AAB060B
A6050AA0050C960B138D1A2292434A8B585DA7717396353B980B12A6050CA3070C900E14
99506238305F0627605E8FBE5585A97DA9C5234E689BBFD5BFD1E09393A92F2D5511144B
1D12472512412122541630690C2C68001D5A022157254770779AB891B1C99AB5C789A1AD
A5BCC48DA2A9889BA17A929567838B304C5C061F3701122F01142D3C4C5629AA2700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A2825D939493B0C0CE8096A578919CAAC1C8
B1C6CEB4C5D4A5B4C67072826D55635F303963383D8370747C7B7F7E83867F8585838786
8789898C8C8A8F8F8C92918C8F8F88939188918E86918D85968F86978D84988C839A8B82
9B897F9D897E9C897E9E8C7FA28B7CA18878A78D7DA7917FA28D78A7907AA59077A58F73
A69071A49070A28F6EA38E6AA8936EA18E6BA3906FA79373A79170AA9370A89371A69475
A6977BA79A7FA5987FA99C82A79D83A49C83A49E8A75756A525C57586A665566644D5C5B
616F69A9B1A7B9BDB2C0C1B6C4C3B9C5C2BBC5C4BEC5C6C0C0C0BBC5C4C0BFBFBCC0C0BE
BFBEBCBEBDBABABBB6B9BAB5B5B7B2B5B6B1B4B7B0B3B2ADC3AFACB670729F1C20B71213
B90E10B80C11B50D11B40C11B2080CB3090DB2080BB2070DB3090EB1080DAC080CA4090C
960B0F8D1E248D445075516845364F6A4D60873D4990141DA0090FA1070C921013974755
5A49710C25602147796991B2274C6B5B7F9A638396A9C5D4BFD2DEBCC4D1736D8828214D
18134914114D0B124F041A5505265B21426E6685A6A1BFD769879F82A4BD46677E7A96A7
6C87946A818F677F8F3C576D14314F031A3F011238010E330111331A2C3E4C4D4400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A38256A5A49FA9B8C397A9B596ABB5AEC4CD
B0C6D2A5B6C4717584674C5A67232D6A0D13671619865E607F797C7D82847D8485818788
888B8B8D8D8C908F8D91908C918F8A928E87918D87938F87968E86938980998B83998881
9A877F9C89809B887D9D8A7D9E8A7A9E8A78A38D7AA58F7CA7917DA68F79A28B73A38A6F
A68D72A58F71A18E6DA08F6EA39170A28D6DA28E70A39070A4906FA89272A99675A8977B
A69780A99D86A59A84A39A82A29A83A29A84A49D88989684666C625B666066716B68716A
8A9085A1A497B3B4AAC0C0BAC2C1BAC4C0BCC6C3BFC4C3BFC1BFBDC4C0BFBFBEBCBDBCB8
BDBCB8BDBCB8BCBCB7BABBB6B7B9B4B7B8B2B3B4ADB4B4AFBEB0ADC08386A02529B51315
B90E0FB7090EB70C0FB50B0CB3090BB5080EB3080EB2070DB10A0DAA0A0D9D0E12911F24
8F475372566E36365A2F33596C57727D3647860F199A070E9E0A0D901116934652625173
0F26600E346A688BA8859EAC9CB5C2ABC5D588A3B1BED4DFC0D1DBC7D2DCAFACBC694D68
4A1A3F42113D341542262B557797B5A3C2D6AFC8D8ADC6D649657A67859B486577708796
5E7481657A8E213959041A4501144301104102113B010E360110350A1A35494C4F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009B7848AEABA59CACB9BCCEDDB1C2D1B0C3D2
A8BCC978818E614D575C1D266B0C1474080E6F0E12824B4E84787A7E81847E8285848689
8687888B8B8B8A8A898E8E8B918F8B918D88918C868B877F928A83988D89978984988680
9B857EA0877E9E887E9F897DA38C7D9F8877A18A78A68F7CAB937EA38C759D876E9F896D
A38B6FA79075A89479A28F73A39173A38F73A190729E8F6EA1916FA4936FA39372A79A7F
A19580A89E8AA59C88A39885A69D88A19A83A19C86A19E8A9697879395889193869A9B8E
A3A194A3A295AFB0A7BCBDB7C1BFBBC2BFBCC5C5C1C0C0BFBFBEBEC1BFBFBEBDBABCBCB6
B9BAB5BCBDB8B8B8B5B9B9B7B7B9B4B4B7B0B4B7B0B5B6B1BCAEACA46367A11E24B50F13
B6090BB7090DB40709B6090CB70A0FB3070DB40B13AC0B0FA31113951F25954955755773
383D631D2C5948477078526E7C2737890F1A95071094090E8C1B21904F6051476B102B61
0D356B587A9DB9D2E3ACBFCDA3B9CB6384A0698EABB3CEDFBFD2DDC1CFDAC6CCD8A493A1
6B34466C142A640E26512D4A7D8EA4AECAD9B1C7D5AEC4D19CB5C58EA7BC92ABC198B0C1
7C94A2829BB1041A44021347000E42010F41010D39010D35011034031430444A5200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009C7640A9A39992A2ADC0D3E2AFC1D2ABBBCB
848D9A6A626D59323857121570202587363A6310167E454988787B7D7E807C80817F8283
848788888B8C8D8F8D8E8E8A92908C918C87938C868F89828C857D978D89968885988582
9E85819D847EA0877FA0887DA38B7C9E88779F8B77A28D79A5907AA390779D8C6FA79479
A69277A28D73A18D71A18C70A18C6FA08E70A798799D8F70A19171A29271A39375A3967E
A69C89A5A08C9F9A86A19985A59C87A09A849F9A86A19C8A9D9A899E9B8C9F9D90A19F92
A2A093A2A195AEAFA6B6B7B1C1C1BBC2C1BDC2C3BFC1C2C0C2C1BFC0BFBDBCBBB9C2C1BD
BDBDB8B8BAB6B6B8B5BDBFBCB7B9B4B2B7B1B2B7B1B1B4B0BBB1AEAE73769B1C22B30F13
B70B0DB6080AB6080AB70A0FB2090FAD0B10A00F13921B209446537F5E7A39406E143068
2C41716C5B7F7E3C54841725930E1892070F8C0D1284252E81546B3638630B2760194073
8CAECF94A9BC9BB0C27E96AD8AA0B8324F701A3F60ACCBDFBCD0DDBECEDCC3D1DBC4C4CF
997C896D25336F0F2161263C5C5F74ACC8DAB0C8D7ABC1D29FBBD2335175203D6A48678A
7494A95E7991081E47011244001044010F40010F39010E32031633051A333B465010CD0C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053C12BACA5958E9EA5BED0DFB3C2D39198A8
6C5E695D3C416D4446562B2C734E5186585F59181F6F383C8673747C7C7F7A7E7E7C8080
828889878B8B8B8D8B93928F91908C928F8C928E8A928A84948B85968C87968985998883
97847E9D88809F8981A38D83A08B7CA08E7BA08E7AA18C77A9937DA08C749B896EA28E71
A18C6F9F8A6DA18B6DA18B6B9F8B6BA08E6FA49576A19273A49476A29275A39379A4977F
A59E889E9A83A09B84A19A84A29A86A09A88A19B88A09B889D9A879E9D8A9F9C8DA29E91
A29F93A6A69BACADA4B2B3ACBFBFBAC0BFBDC1C0BDC0C0BBC3C2BEC1BFBEBAB8B5BCBBB7
C0BFBDBDBDBBB6B8B4B4B6B3B1B6B1AFB5B1AEB3AFB4B8B4B7AFADB68284991F26B10F14
B70C0FB80B0EB50B0EAE0A10A00B13931A22994752835F7A3E4270132E6E0D33732D4D7F
7C759272283C8C101D960912930A1186131B843B48654C6A1D2B5D072863193F6F6283A1
92A8B896A4AE8696A46C80918FA1B0899DAF91ADC0B4D0DFBED2E0C2D3E0BFD0D9C4CEDB
BFBDC8906D79671E2C601C314A4055A0BCD0ACC7D792A9BF617C9B0D2958011B56031F4F
44647E536F830E2346011241010F4302113E0115360F283D324E592D47532D3D4624A220
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004FBD24B0A5919099A1BFCEDEA6B0C1786D7A
6332395813146E3A396B52536A5C61775A62581D26672C31846C6E7677797A80807B8081
8083858789888C8E8A8E8F8A90908D92918F95918E938B88968C88968C87988E86998D84
95877E97857E9D8A83A28E859E8B7E9D8A7A9E8A75A18974A78D78A188709E876BA08B6D
9E8B6BA08D6EA08C6D9D89689D8A699F8D6CA09272A29478A99A80A7977DA29279A69983
A29A849F9883A19984A099839F9984A09A879F99889F9A889D9A889C9C8A9E9C8CA19F92
9C9C90A1A298ABACA4BBBDB4B8BAB3C0C0BBC2C1BDC2C1BCC3C2BDC1C1BCBEBEBBBCBDBB
BABDBCBABDBDBABEBEB4B8B8B5B9B9AEB2B2AFB5B3B3B6B4B6AFAEC2969B92232BB11318
B60C10B30C11AD1317991A2096414D89627946486E1730680C326E234A7E5E7EA08B99AA
9D8089771B24910F18890E158327317D4E643C375E10275E0A2E6630547C6E8C9E869B9F
91A0A2A5B0B7919FA7B8CCD7B8CFDC94ADBD85A6B99BBDD1BAD3E2BFD3E1BDCFDCBDCDDB
C4CEDAB9B1BD845E6C5920324A344A839AAFA9C3D394ABBD7991AC122C5B01185601154B
4765856F8BA018315001154000133E0C2343284452425C5D4B635E4B606229393E2AAA28
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004DB71DB7A38F91969EBFC8DA837F8F6A434B
61131664080A6424266A4F51675D62755D6460273063262C83676A747477747A7D797C7E
8484868989888C8C8A8E8F8A8F908D91918F928F8C96928E948E89948E879890879C9188
9D8D859D8A839F8B83A28E85A28E81A38E7C9D8872A18A73A187719A81689E86699E8768
A08A6A9E8A689F8B699E8C69A08D6AA59170A391719F8F72A6977DA7987FA2937EA39783
AAA08DA29988A59D8B9B95829D9784A099879E99869D99869C9A889B9B899C9D8D9C9D8F
9D9E909D9F93AAACA1B8BAB2BCBEB7BCBDB8BDBDB9C0BFBCC1C0BCBDBEBCBBBEBDB9BDBD
B7BEBCB5BCBCB6BCBCB5BBBBB4BBBBB1B8B7AFB6B2AFB3B0B1AEACC5A1A4912D33AD171D
AD1115A01D219B3E47936475554E6B3442683049752C4C765A7A968399AB91A0A79A9DA0
A58D906C262B7E232C8244555442641D2A5C07245C1338674E6F8C7B939D8E9FA08E9B9B
9CA7A9C7D4DCB0C2CC92ADBE5B819A7DA1BB355D777DA4BBB7D3E2BCD2DFBFD3E1BFD1DF
BDCDDAC2CCD9B1ADB8725A684737495E6F82A6C2D1ACC3D48098B3203D68001A53031852
1D355D718FA61F3C510B263F25415745606B4E66694C615C52635D4E61602334373A7A35
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0025D90BB9A2867C8082A4A9B468535D591C22
6D171A71181A5E161A663C4168545B775F67642E36601F26866467726E727175797A7C7E
8080818989898C8B8A8D8D8B91908F928F8E94908E928F8B928E89968E89958C859D9188
9D8C859C8A839E8C83A08E839E8C7F9F8D7B9B8872A08B73A28B739D856A9D85689E8567
A28A6B9F8969A08D6D9E8B6B9F8B6A9F8A6BA39071A09171A4967AA89C86A69A879F9380
A29987A9A192AFA7999C95859C9481A098849F98859C99849B9A879C9C8CA0A1949C9C91
9C9D909FA193A6A89CBDBEB5BFBFB9BFBEBBC1C0BFBEBEBCC1C1BFBBBEBCB9BEBDBABFC0
B8BFBFB3BCBCB6C0BEB1BAB7B2BDB9B2BCB8B0BAB5ADB4B2B3B2B2C8ABAE913D429A2226
9F393F9A6575615772373C5E605B7C7A627C917E919295A094A0A697A1A498A1A1979B9B
9A9594866D6E856F7B2E30550C255A0E2F63315377667F907F91938594919FACAAA7B2B3
8E999E97A3ADA0ADB88699A8345067688399748D9E9EB7C8BCD3E0BDCFDCBED0DCBED0DC
BED0DCBDCEDABFCDD8A5AAB5676A7A43576BA2BFD18DA8BA25425D29476F011C4E01174E
072148506F7F435F654660674F696D5168695069664D645D4E625C495C5D213238494A47
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B0926D74716D7572785B3C41551B1C
7B3C3C742D315A0C116126296A4A4F74555D682F375A1B1F8260637270716F7576757779
7D7D7F8887898B89888E8A88928D8B948E8D908A878E8885918785918482998B869F8F8A
9E8C859F8C85A28E879E8A809F8B7FA390809F8D789E8C769E89729D84699D8365A1886A
A0876AA48E719D8B6D9F8F6E9B88689E8B6FAA9A7F9F9175A092799E927DA79F8A9E9681
A29A86A39C8CB2ACA1A29C8E9A92819D96839F99859E9B869A9986A1A395A7A89FA19F98
A1A096A1A196ACADA2C0C1BAC1BFBBC1C0BDC0BFBFBDBEBDBDBFBEBCBFBEBDC1BFBFC3C2
BDC1C0BAC0BEB8C1BDB8C1BDB6BFBBB7C0BEB3BCBBB2BAB9B6B7B7C2B3B5936769A06A6E
7F66773C3F615A5A7C906C868A3B4C84212B995659A6989B959EA197A1A1999F9F979E9D
949897969594838A9320355528486D5D76917B8C94818B898A938D89928C8B9190939799
959296948F96968F95A0949CA297A0B2A7B1988E98B8B1BDC4C5D1C2CCD8C2D0DAC0D0DC
BDCFDCBACEDCBACEDBBACAD5A0AFBB51697B84A5B76985937992A0637C932E476B04204C
234563617F88637B7A596E6E5C7070546968516A664A645D4C635D43585C1D3039565B5B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A67D537B6D656C5F655634395F3334
794F50652E3152090B702F2F6B3A4077414A661E24601E217F62627172746F777A737679
7A797D8480838E8A8A8C8A878C8A858B85818E84829086848F818091817F92807D9C8984
9F8A859D898298857C9C877E9C867EA49185A29181A3907D99836D9C83679A80619C8264
9E86699F8A6D9B8A6B9D8F6D9C8D6BA09174A79A809C8F76A2967DA19780A19B859E9884
A39C8BA8A294B2ACA1A59F929C9584A099879B97829D9B869A99869D9C90A8A79DA8A49A
A9A69BACACA1B1B6ADBAC1BBBBC0BDBEC2C1BEBFBFBDBFBCBFC1BEC2C5C2BEC2C1B9BDBE
B9BCBDB9BEBEB5BEBDB5BEBDB3BCBBB7BDBDB5BABBB6BABBB3B5B6B6B4B4B6ADACB9A9AF
7C6A7F8F6B89984D65931F2EA012199F11189D424C69586A6B7F8C92A1A2979D9C9BA09D
949A969297958A949378868C7C8A93838C92888C8B8A88858E8A85928481957B7D9B747A
94606796555E9045508F39458C323C8A2F3C862F3C8B3E4C965D6BA2828FB6ACB8C3C8D4
BFCFD8BBCFD9BBCFDAB7CAD5B6C9D299B1BE82A0AF86A2B0AAC4CF8BA2AEA9BED1516D83
7F9BAD637B82677B7C586C6B596F6C566B684F67614A645E4C63602F434D1F34405D6766
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074912F7E67597262634E30336A4949
725352501D1F530E0E7A3839641F25671019670B11712E317E61636D6A6F6E747A71777A
7C7B80827D818882838886848785828983818A817F8B807F8C7C7C8E7A7A917E7C92807B
9A878099877E9C897F9E8A819E8A83A18D839D897B998471978069A0886EA0876A9A8265
9C896C9B896D9D8B6E9D8D6F9E8F719B8E73A2977FA399809F957DA9A08C9F9785A49E8D
ABA496ACA69AABA79CA9A5999A96849B98839996829B98859796849C9C8EA2A297A2A097
A8A99FA5AAA3959E978B96918994938E9B9BB0B9B9B7BEBBBEC2BCBCBFB9BCBEBBBABCBE
BBBDBEBABDBCB8BEBCB8BEBDB6BCBCB6BABAB4B7B7B7B9B8B5B6B6B6B5B6BAB2B3C09EA6
A85F6F962536A2131FAB0C14B00A12A50B149734424C3B584D69818CA2A6969F9C9CA39F
9AA09C9197938B94908B92918D8F8F8D87889885859776778E585B893B4183222C83141F
890F178F0B15950B16980A13980A119506109207128F0714870B1A8017267F303F976B79
B8ADB9C0CAD5B7CBD7B2CBD6B1C7D2B1C7D5A3BECF4F7085799BAE5C7C8A6C8794637986
5E737B5C6F725A6D6C596D6B586F685169634E67614E66673A505B091E3024404C5E6D6D
219E1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004AB2187F654B6E5F595239375E403E
70585563413E4C19177E42455E11176306096A151682474A6A4A50736B706B74766C7576
7D7E82868285857F818782808A8381877F7E877E7C8A7F7D8679758979768C7A778E7D77
95847C96837C99867F99867F9D8981A08D819C887897816C99836B9C866E9F886F9E8A6F
9E8F739B8F739A8D72A090769D8D759C8E78A0957FA69E8A9F9785B1A89AA9A193A7A294
ABA69AB1AAA1ACA69DA6A4989796869998859A9887A09F8E9B9A8DA0A094B0AEA4A9A79E
A9ABA38990899CA59DB3BAB2B5BCB89FAAA8818E8CB8C2BEBCC1BBB9BBB6B8BBB9B8BCBB
B8BBBAB7BBB9B6BABAB5B9BAB7BBBBB3B7B6B4BAB6B4B7B4B4B6B3B6B4B5BEA5AA8F3F4A
A01C29AD121AB00B10B1090EAF070DA709129123336145653A537490A8B295A2A098A09D
969B9993969393918E978A8C9B7E81935C6285353A801B21870E168F0B1592061096040C
9B060C9E060E9F040D9E02099E04089B010698010899030D94020D8F04108907157B0F1F
7B3345A68B9DBCC3D0B7CCD6B4C9D4B6C8D68197A82F4A5F446274637F8A627A83768A91
5F7376677B7B5B6F6E586A6A576D69516A674D6666384F5A0C1F3701102D0B213852656A
25A52100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004DB4158163416C5C525A423C553531
6A5250624F4C5A403D714344550B0F6210128242437946495E353A7C6C6F6E71726E7776
787A7C848284817C7D8981808C8280887F7C887E7B8178748074718575738774738C7975
92817A92817A99857F98847E9A867D9A877A9885759A88719B886F97836AA08C739C8A70
A293799D91779F9178A4957EA1927BA2957FA39782A69F8CA39E8BA9A494A4A193A5A396
A9A398B3ACA2AEAA9FAFAEA19D9F909E9F90A09F92AFAFA29D9F93A4A69BA9AA9FAAABA1
B0B2AB818983B1BAB3B6B9B4BFC1BFB5BCBB7A8483B1BAB8B8BDB9B8BBB9B9BDBCB8BEBB
BAC0BCB7BEB9B7BCB9BDC0BFBEC1BFB7BBBAAFB6B3B0B6B3B2B7B2B1AFB0BD9CA08C2932
AC131DB70D13B4090FAF080DAB060BA909138D1423754C6D2B426487A3B098A4A59CA1A1
9A98989E8E90A17A7F934F5789262F89101A8F0C1491070F94040C98010D98010A9A0109
9B02079D02089D03089E030B9F020A9E02089A020997020A94010A92010B91020C8E0410
830917721D2E9E7D8BC4C7D1B9C9D3BBCBD87E909BA6BAC6788D97A7BEC681989EA3B8C0
6A80867E93955C6E6E5A6B6A586C6A536B6B37515A081D36010F30000C31011230314454
387B3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0083592F735A4A664B43532E29
6D4A495D4443644E4E6A46474E12135F20218A5A5D612D305923277D6365717171747877
77797A7B7C7E7D7B7C817C7A857E7B88807D847B788078748077727E736D8575708C7A76
8F7E7897867F97857F95837B97847A99867B9886799B8A789E8A7697816B9C89719C8C73
9F90789F9079A1927CA29680A59883A1957FA59984A59E8AA6A08DABA596AEAA9CA5A196
AEA99FB2ACA4A9A69BAFADA1A9A69CA5A398B1ADA3B0AEA4A9ABA0A1A69CB0B5ACC2C7C0
C7CDCBB5BEBCBBC3C1AEB4B2B1B6B4ABB4B37F8988B4BCBAB7BCBBB7BBBABABFBDB5BCBA
B6BFBDB5BFBDB3BCBBB3BAB8B6BCB9B6BABBB4B9B9AFB5B3AFB5B1B5B3B6C7A9AD8C2C34
AB131BB60912B50812AF0710AB050FA80913870E1A7B506D1C31557D99A9979FA1A99C9E
A48084934B5489202B900F1A93071098051095020C95030B9401099A030B9A030A9A0107
9A01079D020B9D020A9D00099D02089B010597010692010893020991000993010B94020C
8C020C8108136F1D2AA98A95C0C5CFB5C8D5859EAB92ACB88DA6B17D99A286A0A670888F
627A7E5F73755D706F5B6B6A576A6B4A626B0E243C011034010C32010B3202123610253D
464D4C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7210754B34735047522824
7644434C1B1B6848486851525F3E3E4D292A7E5B5F5F2B31551A1F826264757171767878
79797D79797D7878787F7D7B827C7C857D7B7F76747E75727D756F7B716A837570847571
8D7B77927F79937F7899857C96827A96837C99867C9885779F8B7B9E8A749A88719A8A73
9F8E769F8E779F907DA09482A29684A79887AB9F8DA69E8DA6A090A8A395ABA79AAAA69B
AFA99FABA69BA9A79BACA9A0AFADA6A5A59DB1AFA8ACACA2ABB0A6B5BDB4CAD4CFC9D2D1
C9D3D4CEDADACDD8D9B8C3C49CA7A7838E8D9AA4A1AEB6B3B6BBB9B5B9B8B6BBBBB2B9BB
B3BDBEB2BCBDB2BCBBB1BBB8B5BDBAB6BABCB1B5B6ADB3B1AEB4B2B5B4B6C7AFB3913B43
A6121BB3090FB20910B00911A909109E0D168119257B5975182C4F7E8B9FA28B929F5D65
91272F9A131C9B08129C050C9B03099A020B97010A930008930108970108980107980108
99010A9F030D9D02089F040A9D02089E03099C040998030B93020991010891010A92020B
8D000988020B7B07126D2330BAA5B1A5B4C229475C4266784869764A676F6A8387687C82
5E76795A6F705B6E6E5A6A6A586A6E2D4354021435000C35010C33010C32001036061B3B
414D5400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00419E08713B237F574E5F3231
77393C4D0C0D68383A65494D6551536455576F5C615F313754171D805A5E776E70727174
7475777676787777767A7A78827E7E7D78787871707B73717D74717D736F80736F82726D
8874718F7875947D779C857E94807896847C9D8A809A877B988778A08E7DA08F7C9C8C76
9F8E7AA4927FA39383A39686A59989A99C8CAA9E8EA69C8DA8A192A8A194ADA79BACA79B
A9A39AA9A59CA8A59DA7A69EAAA8A2A5A49EAFB0A8ADB2A9A9B3AAC9D4CEB6C0BDAFB7B6
AAB4B3B8C4C3CDD9DABDC8CC8E9A9B9EA6A5ADB4B0B0B7B3B4B8B7B6B7B9B3B6B7B1B9B8
B1BBBBB5BEBFB5BCBEB4BBBCB4BDBCB3B9B9B2B8B8AEB4B4B1B7B6B4B3B5C5B1B59D4F58
A41722B20B13AD0A0FA70E149611178E2C358A576A453F5F494C6C8B677C8D3441981521
A50C15A80610A3030B9E01089D02089B020B9701089601079501079903089B0309970107
9A02099D020A9E0207A004099D00079D010898010698020796020892000891020B8E010A
8D020989010982020B72081380475099949D6E84904A6A7792B0B87B949A92AAAE809498
839A9C5D7675576C6A59696953656D10233D011037000B36000C33010D32000E33021738
3A47570CCB0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00449E0571321880544C683935
611B1A580C0A773939511E22643F4368565B6B5C6263363C5313177F545975686B6F6E70
7272727474747675737575737A78787D78797E79767874707B73707A706E7E706E82706D
86726E8B746F947D779681799581789A887E99877E9E8C829B897C9D8A7CA493839E8D7C
A0907FA59585A59386A59689A5978AA5988BA89C8EA89C8DA9A08FAAA495A9A497A7A398
AEAAA0A9A59CA7A79EABABA3AFADA6AEABA4AEAEA4ADB0A6B5BDB6C4CEC9A7AEABAEB2AD
A8AEA9A9B4B0C8D7D6CDD9DBB4BFC0ABB3B1B2B6B4B5BAB9B6BAB8B3B5B4B4B8B7B4BBB9
AFB8B6B1BAB9B3BBBCB1B9BBB0B6B5B4B8B7B3B7B6B0B4B3B2B7B3B5B5B5C2B0B4A65F67
9F1822AA0E149E121590252D995C6A68566E3F3E5C6E5B79874A61871B2B9A0C17A60711
AC090EA9040AA8040BA4020B9D020A9B010999020998020B960109950108970109960107
9A01099E020AA1020B9F020C9D020C99010A95020993030890030A8E01088C01098A0109
89020A8600078301077C030C6B121A846267B1BAC095ACB789A2AB9AB0BA738C907E969A
657E805E76755A6E6D586A6B465665031334010E37010D37010D33001030061833041B36
2C3D4E1D9C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D407794023754B436E3C39
580F0C5B0E0D7D3538560D115416196D4F5168575B6A3D43521114794D4F76686B717073
6F70727272717473717474727C7A78807B797D7A75797871766F6C7A6F6E7E6E6C836F6D
856C6988706A907A7395817A97847D97847C98867B9A887C9F8C7EA39183A18F81A29182
A29283A39484A09283A19485A09485A29688A59989AA9E8FAA9F93A69E92A9A399A5A198
A8A49BAEAAA2A7A79DACACA2AFAFA7A9A9A0AEAEA5AEB0AAB5BBB6C5CECBAAAFADB0B3AF
AFB5B0AFB9B5CAD7D7C8D5D7B1BABCB0B8B6B3B9B7B1B7B5B6BABAB5B8B9B5B9BAB2B9B8
B0B9B8B2BCBBB2BBBBB0B9B9B4BABAB7BBBAB2B5B4AEB3B2ADB4B2B4B7B8BCB1B3AB757B
8C1F259220259D535F7D647F363D643A42697C607D802E439214249F0A16A4040EA9060D
A9060BA9060BA7050BA3040C9F03099B02099801069B020A980108960107960107950108
98030A98020B99050E94060E8C060F870A11810C127A0A0F77080E7D070E81060E83030A
85030886020883000982030C73070F74353F8A808A72869259727E637A8260787B688283
637D7E5C75735B706E596C6F314357031239000C38000D350317361C37493D59642C4654
1D333F1C9F1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774021774C456A3837
5C1D1B60212279353A55070B5D1D1F6A484B6B4E54662F34561013794F4F6F636568686A
6A6B6D6B6A6B6C6969706C6D7976777E7C7B7E7D787A787379736F79706D7C6E6B806D6A
816A6888706C8F797496817C947D7996827999857AA28F82A29181A79686A59485A49384
9F9183A39587A497879E9280A29685A69A8AA59C8CA79E90A59C90A69D93AAA199A8A098
B2ACA4ADAAA1ACA99FAEADA1B1B1A7ABABA2AFB0A9AFB1ABAFB4B0C8CFCDBCC2C1B4B9B5
B7BBB8C4CCCCCCD7DCBBC6CBA7AFB0B2B7B6AFB4B3B4BAB8B2B8B7B6BBBDB4B8BBB5BABB
B3BCBBAEB8B5B0BAB7B0B9B8B1BAB7B3BABAAFB6B4ACB4B3ABB5B4ACB4B4B3B2B2AB8F91
8550529E788545496E1F3568545886835473842136950D1DA20814A6070FA5040BA5040A
A7060BA9050CA40309A3040C9F030A9C020A9D040A9B010A9901089402079203098E060B
85090D83121A86222C8836448346557B4E606B4A5C694D5F6E4E6077485873313F701521
7C091284040D85020B83010B7C050D6A15206146517C8B965B727C778B93738B8C768E8F
6C84865C74735A706D586C70263A5002113B000E380314342945554460634B6261445B5F
1C323A25A92B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723A15794E45663937
61322E693E3D6B343751080B69262A76434A6B313A590E135D1B1B735252665F625F6162
6365666868696665666C6A6D7473767877777E7B787D78757A746F79716B7A6E687E6D68
816D6889746F907C7598847D99857E96827A9B877CA18F80A19081A59284A59283A49484
9E8E80A190829E90809E9381A19887A19989A69C8FA59C91A6A094A79E94AAA199AFA79E
B1ACA3AFACA3B3B0A6B0B0A5AFAFA5ADAFA4B3B5ACB3B7AFA6ABA6B0B7B4C3CDCCCAD3D3
CED4D6CBD2D5BCC6C9B0B8BAADB3B2B7BBB9B6BAB8B5BABAB0B8BAABB5B7ADB7B9AFB7B7
AEB8B4ACB7B3AFB9B7ADB6B5ADB6B5ADB6B5ADB8B4AAB5B1AAB6B2ABB5B4ABB2B1B0ADAD
B3ACAF797E9323376167628E884B698C192A9F0C18A40711A5040BA9050CA9050CA7030A
A8040BA6030BA3020AA1030CA0030D9B020A98030998020A92060E870B1182182085323D
7C475572546C5A4E6F363A631F2B5A1122540F24521126541427511C2A50333855685469
6D2D3F770E1C84051084010C7E030A6D0B15552E3A9AA4AF9EB5BE798E9599B1B5698184
6E86885D73725C7270596F721E364B01123C011537203E4F405F614A64605065604C6363
1F363C40484700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00713910775043663C3A
5E3431745752643D3B541214681A1F73242A640E135D0B0D6A34346A56575E5C5E5A5C5E
6061636767676A67676B686A7371747573757976758079768178767B706E7B6F6C7B6C67
7F6D6783706A907C7596827B98847D99857C9D897EA08D7FA18F80A08E7FA1917FA1927F
9C8C7A9E8E7E9B8D7C9F95839E97869E9788A29A8BA59C8EA79E91A89E93AEA59DACA69E
AFACA3AFAFA6AFAFA6AEAFA6ACADA4ABADA4AEB1AAAFB4ABA8ADA6A7ADA8A6AEABABB3B4
B3BABDAEB4B7ACB5B5AFB6B4B2B8B4B8BDBAB5B9B8B2B8BB8F999C89979A7E8B8C9AA6A5
ACB8B4AEB8B5AFB9B6ACB5B4AEB7B6B0B9B8AFB7B6A9B2B1A6B2AEA8B3AFAFB6B4AEB0B2
ADACB1A49FAD8D72898F3E57961425A30914A9080EA9060DA8050AAA070CA8050AA60308
A30207A5050AA2020AA1030A9C030A93020B8D070F84101A832D397A4559644C6B3B3B65
1B2B5E0E245C0A225C12286020356530436A6272908D9CB598A7BE9CAAC191A3B8758497
766B7D763A48740B1681030E7F0109720510602A395D5D6D889EAA627980677F81647D7D
5D77755F787559706D5872731F3A4C011538102A434562694A65614F68614F65614D6165
1E353F44505600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00773F13794E42704445
582A2C765857684B4B5D212360060B68070B5F0C0C682E2C6C50515D56585B5D5C5B5D5C
5E5E5E6865666B66676C6768716C6F706C6F7772737D74748077747F72718173717E6D6A
816E6888736C90797395817995837997857B96847A9B897D9F8E80A08F809D8E7C9D8F7C
A39583A09181998C7C9C907F9A9180A19A88A29A8BA59B8FA9A094AAA198ADA59EAAA6A0
ABABA3B0AFA9B3B0ABAFAFA7AAACA4A4A79FADB1AAAEB2ABA8ADA7A5ABA7A6ACA9AFB5B5
AAAFB1ACB2B1AFB4B3A7ACAAACB2B0AEB4B3B9BEBFAFB6B8869092AAB6B7A3AFAE84908F
AEB9B7AEB8B7AFB9B9ABB5B6ACB5B6ADB4B6ADB2B5A9AFB1A6B0ADA8B2B1ACB5B2B0B1B3
B7ABB1B48993903642A01522AC0A14AF070FAA040BAB060DAA070CAA050BA80308A50207
A4030AA4050EA2050E9D060C91090F81121B813442734C68433D671A285D0A235F0C2865
1833683C4D7764688882738B8362768557698753638A56658C5D6B8F6A7890828E9BA3AD
B6C0C8A08B947229347C091581020C78040F6C2635392E406A80895D7579667C7B68807D
5D76725F7572597270557073223D4C0118333550614F676A54686451686347605E3F575F
17314026394604C50700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783B0C78483A794C4D
5224267553536A4C4C642D2E5806075D0A0B652D2D6A4F505E5457545457555758595A5C
5B5A5D6362646867666C686670696C716B6F766E6F7B74707F7771847A7683757282716E
86726D907874917B7594807898847C97837C9B877D9A8A7D9A8C7C9B8E7D9C8F7C9D917E
9F94829D9181998E7C9C917F9E9382A2998AA69A8FA4988FA7A095A7A198ABA69FABA8A1
ACABA1AFACA5B1AFA7AFAFA5A8AA9FA7A9A0B0B2A9AFB1A9A6ABA6A4ABA8ABB2B0ADB2B0
ABAFADA7ABA8AFB3B1AEB4B1ADB6B2B1B6B6B6B7B9B9BCBD8B949594A0A08290908F9D9D
A9B7B5ABB7B5ACB7B7ADB7B8ADB7B9AEB6B8ADB6B6B2B8B8ABB2B1A7ADAFA9ADACB9AEB0
B9899096323DA1141DAF0D14B20A10B0080FAA050DA9040BAD080FAD060EA9050CA6030B
A5050F9F070F93080F85121A863947734E6938355F12245E0725640F2F682F4B77606E8D
7F758B855B6C7F36457D1B2983101E860B1B880C17880C19810B1778141F622931888289
B5C6CDBBBDC7855967720F1F80040F7A040F6A1D2D2F2236758E989BB5B76D8383889E9C
5F75725F75735A716F59707337515E0119304863724C63665467665265654F646B1E3547
031A39071C38068B1200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008846107847357C514E
4F201F774A49663C3B6C38394F13125B282764494B5E54565351564E505354565858595B
5C5B5E626164656566696769706B6D756C6E776F6E78726E7D7870867C77877876857370
86726F91797690787495807996837D95827B97857B9486789A8C7C9E8E7EA19181A49685
A194839B8E7D988B799E917FA39685A39687A4988BA69B90AAA298A9A39AADA9A0ADACA3
ABA9A0B0AFA5B3B4AAAEAFA6A8A8A0AEAFA7ABABA5AAAAA4ACADA9ACB0ACADB2AEABB1AD
AAAFABAAADAAAFB4B2A8B0ADAEB5B3B1B6B4B6B9B8B2B6B6B1B8B89CA6A69BA7A7A5B1B1
A9B5B5A9B5B5AAB5B5A9B3B4A7B3B3A8B2B3A8B3B3AAB4B5ACB3B5AAADB0B4AAAEB4838A
99313AA5131CAF0B12B30B10B1080DAD060EAA040EA9030DAA050CAB040CA50209A2050A
99080D8C11178A343E8057703F3D6812235F0622600B2C63294A72667A93807B89885D6A
7E2B3686111C8E081294061196030F97020D98030C97040F8D08137D1D2A7654658C9CB1
A3C5D7B9CBDA967F916714287C04127B04106E1F2E2E2033506C787E9C9F677F80677F7C
6178765D73715C7071596D6F48616A021C2F405D694965675066694B616922384D031638
01143E04193D024C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00627209774732825A56
55201F7B37375D1516682F2F6742435843465A50555250554D4C52515155525456535655
5C5C5D6261646362676766696F6A6C726C6D746E6D78736F7E787382787688797A847373
857070937A788F7773917D7892807B95848093857C94877A998B7C9C8B7DA49284A09282
9F9382A196839D927E9F9581A09984A59E8BABA190A89E91ACA598A7A397ACAAA0AAA7A1
ADAAA4B1B0A8B0B1AAA8AAA4A4A69FA1A29CA7A5A0A8A5A1A5A4A1A8AAA7ACAEABABAFA9
AAAFA9AAAFAAAFB4B3ABB3B1AAB4B0B1B8B7B3B7B8AFB3B4B1B8B8AAB3B3A5AFB0A6AFB1
ABB5B4A8B4B2A9B4B2A7B1B1AAB5B5AAB4B4A9B3B4A9B2B4A7ABAFB3A7ADBB8B93972E3C
A91521B30D15B2080FB20910AD060DAB040DAD0711A7010CAB060DAA060DA4070D940C11
86222A86506553496F1729620726651031683A5980617991737B8A88717D823F49861723
9409149B050F9C040B9A010A9A010A9B010B9A020A93050D7E131F7545601D26530B3464
5787A9B6CEE296859666192B7C061377030E6F2434291E373B596959787C627C7A667B79
6578776175745D7170576D6C566F72102939314D5E4D6976334C5D10254101123700103A
01113C04173E06152A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A1077A4B33825A56
5A1F1E610D0C600A0C602627624A4C564D515752565250544F4C51524E53555356555557
57585A5D5D616060646766686D6968756F6F76706F7A75717F7773817675857677867274
85726F8E77738D7470917B7693827B92837D94877F95887E9C8E819E8E809E8D7EA09182
A29585A39786A49786A19683A19A86A39E8AABA593ACA596ACA598A7A398A9A79CADA9A2
AFAAA4AFACA4B2B3AAA6A79FA1A49B999B929D9E959B9B95999B97A3A5A2B0B1ADA8ABA5
ABADA9ADAFADB3B6B6AFB6B6ADB6B5ABB4B4B2B7BAB5B8BAB5BABBAFB6B9ACB3B7ABB4B6
A9B5B4A6B3B1ADB6B8ACB2B6AFB6BAACB4B7ABB3B6A9ACB0B0A5ABB78992993541A5131F
B10C14B10910B50A11B0070FAC040CA80209AD080FAA050CA8070CA10B0F8E13188E3F4D
6A4E6D26336808296A0B316D345782647F9570808C808188886771792A3787101B970712
9D030B9D02099C01079B01079A010998020996020B830B148346582A2B53072D6043759F
9FC8E1B9CBDD927C8D6616267B061276030E6E2B3D1F1C3A5272885D7B8288A0A1657A79
6275745F73735F7374596E6F546C6E324C5A0E274118335204173E000F3C010E3A010D39
010F3A02163E04162C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DAE12825336805A56
602729570A07651F1D6A41435E4D50585056534E534F4C4F4B484B545053514E50555457
545558585A5E5B5D616462666C6869706C6C7471707B76737F787581767682737383706E
8974718C7672917B778E7A75907F7791837993847B96867B9A897F9E8C7FA18F81A39484
A29585A79A8AA69988A69A89A59D8AA7A08DABA393ADA499ABA398A8A399A8A59CADA9A2
AEA9A4B0ACA7AFAEA79A9B949A9D959193899294898D90868C8F8892958FA8AAA4A7A9A3
AAAEAAA7ACA9B2B8B4ADB5B2AFB7B5B1B6B8B3B5B9B5B7BAB3B7B9B4B9BCAFB4B9AAB3B5
ADB9B9A8B2B3A9B2B4AAB2B5A9B1B4AAB3B5ABB3B4B0ACAFB99299983B44A61822AF0C14
B00A0FB30A0FB4090FB0060EB1080EAF070CAD090CA8070C9A0B118D232D8D576D4B4671
112B67072C6B234B7D5D7D9B7B919E7F8E9284848986666E75243084091492060E980209
9B01079A03059902049C03089A020A9500098C070E862E3E4C395C07265A3568949DC9E4
B6D0E0B6BCCB8664726A101C7D060E6D040D6B36491519397B99B069838B6E8385647978
6277765F74725E72705A6F6D566C6C38505D01163501123E010F3F020E3E010E39010D37
010F3702163A0D203600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050AF0F82522E795851
623939511C196D433F644E4D5D51545A5358504E5349474B49484B4F4D4F575556535253
56575A56575B5B5B5F5F5E626666676D6C6B7773727972727D747280747383757386736F
89756F8B7671917E79917D7994817A93817995847B96857C9A897C9E8C7E9F8F809F9181
A09383A49787A49787A49887A69C8AA79E8DAFA696AEA499ADA49CAAA29AA8A39BABA6A1
A9A49FAFAAA5AEABA4999A928C8D858C8E838E91848D8F828B8E838E9086A0A199A5A6A1
A3A7A5A3AAA8AAB3B0AEB8B4A5AFADAFB6B6B0B5B7AFB3B5B3B7B8B3B8B9AEB5B9ADB8BA
ABB5B6A8B0B2ACB2B5AFB4B8B1B5B8AEB2B5B0AEB0BD9CA29D4751A01720AD0C13B10A11
B00910B00910B0070CB1060DB50A0FB2090EA80B0F961017903847755274242F660B2D6E
0F387441688E7594A881969E87959885898C90777E772C37810B168F030C920109970208
9701059A03089B02079A000895020A91030D7C0C17824F6B1421511947778DBDDAAFCFE1
BDCDDBA49CAA743948790B1781050E6A0C1858354E0916384B687B617A80647A78617A76
6079745E777359716D5C6F6D596D6C354857011337010D3F010D41010D40010D3B010E37
0110320A233C31475208C90800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B3107C4820795A51
6952505E49456857536158565F57595954564E494C4440444342454B4A4C555254535155
52515659595E5B5D615C5E616262636C69697873737B72737E7576807575827473877672
8A78728C79748F7C788F7C77907D77917E7795827B9A887F9B8A7D9D8D7E9F8F80A29585
A29585A69989A79A8AA69A89A39A88A59E8CACA595ACA499AFA69DA9A298A9A39CA9A59E
AAA7A1A9A6A3A8A7A29A9A938A8C81878A7D8A8D7F8B8C808B8C838D8D8595968FA5A8A3
A4ABA7A7B0AEA1ACA8AEB8B6A4ADAEADB2B5AEB2B5AFB3B6B4B8BBABB1B3A8AFB2AAB3B5
A6B0B2A5AEB0ABB1B4B0B3B8AFB2B5B3B0B5BDA4A9A659629E1B26AD0D17AF0910B30A11
B10710B20910AE060DAF050CB50C11AA0C0F971C22934D615D4E77152A68062C6C244D82
6184A37995A281999D8093958490938D8388753D467A0C188D030F94030D95040B97020A
95010899030997040992040C8C050D8108138231444B3A65092A616595BBB0D7E8B9D0DE
B6BCCB8E6D7F6C15257F061279050D7225343525430D2346557284718889657978627773
6178726076735B716E5A6F6A566C69435864021334030F3E000E3F010D3F010E3C001037
071F3933505F50676A15971600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B80491E775A4F
665B5A61595665605C5F5B5B5854555B55584F494C47424644424549484A55525657565B
5051554F5457565A5D5A5F606364656967687471727872747B71747E7374847777887976
8879748778728D7C768F7E77917F789380799481799A887E9C8B7F9D8D809B8D7F9D8F80
A29383A39484A29585A69A8AA59D8BAAA393ADA79AA9A498AEA89EAAA59CA8A39CA9A59E
A9A69FA7A6A0A7A8A29FA29A8A8D82898C7F888C7E898D7F8B8E828D8F848E9389989F96
A0A6A1A5AEACA3ACABABB6B6A8B1B3ABAFB4ADB1B6AFB4B8B2B7BBB1B6B9AAAEB1AAAFB2
A3ABADA4ADAFA7AEB1A9AEB2B0B1B6BAAAB0AB707996212CAA0F18B10910B20910B30811
B40911B0070EAD070BAD080EA80E1598232E935B753F3F710C2C6E0C35733B638C7191A5
7F979F84989C7E9392809291878E908C6D736E182286061192040E93010B91030A8E020A
8C050D85080F7E0F167B1B247D2C36733646745879122158255282A1CDE7B4D1DFB8C6D4
9F8F9F7630427E0C1980030E6D0811713D5412173A4261805F818B869DA0697D7E627673
6378726178725B74705A706E586E6E4E646F041634010E3B01103F00103E001239102A43
33525D4664665B6F6E17991800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008852227B6152
655D5A605C59625F5E605F615A575A5853554E474945404245414547464B504E54514F56
5254584F5455555A5A5C5E5E6162626968697370717C74757E75757E7473827574897978
8B79768B79748E7C75917E788F7C7696827C98867E99897E99897C9A8C7F998C7E9C8F7E
9C8F7EA295839F917FA09383A19989A59F90A9A396A4A195A9A69CAAA69FA5A39BA8A59D
A8A59CA9A9A0A8A9A29C9D968E90858A8C80878A7C888C7D898D7E888E808B9184929990
9AA39DA5AEACA7B1B2A3ADAEA4ADAFACB2B6ADB1B6B1B5B9B3B6BAB1B6BAA6ABAFA7ACB0
A1A9ACA7B0B2AAB1B4AAACB1B5ADB3BF919B922C38A8131DB00C12AF090FAE060DB2070F
B40911B0060EAD080FA10E16972C398A5A7C2B336E072A7118437F577D9F7E9BA7849B9E
8A9C9D8A9999899897859393939092743F487C0F1A8D040E8F020A8F030B87060C790A12
7D27337C445768496355496C4043692E39671A3066072C656993BAB6D2E6BAC7D5A092A4
814759790F1E8606107B060E7126343D2C4C061A4354749065838B62797B667A7B647676
6679766177725C75715A706F5A6F71566A730A1B3601113901143C071F3E274357435F68
4864664964615A6E6C1DA12000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00637C197D6252
655C5A5F5B586663626161615B5959524D4C4C464645404044424349474A525054525055
514F545353575556575C5C5C626161696768726D6E7972727C73727F7473837676837373
8471708E7A768F7B7594807995827B93817A96857E96887E97897E998B7D9B907E9B907C
978C789A8E7C9A8D7C9A8F7E9B9582A39D8BA59F90A4A092A5A397A2A298A7A59DAAA7A0
AAA9A0ABABA3ABAAA5ABAAA5989892888B7F888C7E878C7C898C7E8A8D808C8F858A9087
959D97A1AAA8A8B1B0AAB3B2AAB2B2ACB1B4AFB4B7B2B8BBB1B7BBABB2B8A7AFB3A7B0B2
A6AFB2A7AFB3ABAFB4B2ACB1C1A3AA98424DA31823B00C13B40C10B20A11AD060EB30A11
B20A0FAD0A109E0E169634437C587E212F6E09307628538B6E92AF87A1AA8C9FA18F9F9E
92A19E8C9B9A849493838F8E998D8F6D2831860B1791020D8D020985050D781A23744459
493F6519245B0C21610621640E316B2C4F814566956080A8ACC4E1B5BACC998395804354
76101E84061280060D711620623F590F1A44103056577687678184627A785E7472607573
6579776176745B726F5C716F596D6D566B7111263803173219364A3F5F6A4C696C4F6969
4E67654A64625C7170393F3C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0041A915806253
6B5E5E615B59625F5C6565635F5C5D554F514E4548484242474444474647515053575557
5150525353555555575C5B5C615F606A6766716C6B726C6B766D6D7D7274827477837575
82716F8F7C7A8F7C768F7C7593807A94827E92817B93867C96887C968878988C7B958978
938876938777938676988E7C96907C9A94809E97869E998AA09D919F9E93A4A49BA9A7A0
A7A59EABAAA4ABA9A5AAA6A3A5A29E92938B8E9085878A7D8B8F838C8F848E92888F958D
98A09A9CA6A2A5B1AEA3AEADA9B3B1ACB4B3AEB4B4ADB6B5A6B0B1A4AEB1A3AEB0A4AEAF
A4ADB0A9B1B5B0AEB2C2A9AFAA68729B202BAC0F17B20A10B70C10B30A11B10A11B0080D
AD0C1099101599424F6D557C172F6E0A34793361917598B088A1A88C9EA091A1A192A0A1
8E9E9D8D9D9C8396947E8D899186856D252B880A1494030E8D040D7C121C77475D1F2050
06215D1C3F7A2546840226625B82ADB4D2EDBDCFE6B8BED6A498AE8F61767A293B7F0E1C
85050F82060F73141D73455D1E214A0A26555C809D64828C99B1B4687C7D5E73745A7370
6177756377775F73715C716F546D6A546C6C314C513250574664684C6B6B4F6D694F6A66
4E68654966654761633D4A4A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048AF1B856858
6E606068616067635F6968645F5D5B524A4C4B4044493E424C4346474143504B4D575554
514F4F504E515553565857595C5A5A6661606F6968716C6B756D6D7B7170807474867979
8F7E7F927F7F917D7A907E7791817990817A93817B928079907F7491827595877A938678
958878928573948573968976928773958B779A92809993849794889C9990A1A097A8A59E
A9A7A1A6A5A1A8A7A4A9A6A5ACA8A5A29F9B9A999496989193968E999D969AA098959B95
9BA29E9CA7A2A2B1ADA3B2B2AAB7B6B0B9B9ABB0B4A7B0B2A4AFB0A3AEAFA0ACACA3AEAE
A0A9ABA7AAAEB3A0A8B8828C932C37AE1820B50E15B3090EB3090EAE080CAE080FAA0A0F
9A121795425363517B133072093679426C9A83A2B790A2AB91A1A48D9DA08F9FA28E9E9E
94A4A48B9A9B82929182908F97908E743339870C1594040E87040A872E3A3F274A071B52
0E31668EAFD2AEC7E54F68888FA2BFACAFC4A08DA29161777E2D42831627880A1588060F
7F060D75182276485D2A2853041C4F28496E9FBFCE7D959C788E91697C805E72725C7471
6177756379775E74715A726E556E6A576D6B5269684F68664D68664D6866506D694D6A67
4A686A33515C0E2A3A35474F0ACA0900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049B31C856B59
6F6462625B5A696561686660645F5E52494A483E404D42444E41444E42445246495A5154
534F50504D4E5553555958595D5B596762616F6769736D6C78716F7B707182757787787B
8F7D7F8F7B7C927D7B93817B93827C917F7B927F79907D758B7A6E9080728C7E6E8E8172
8D80708C7F6C91856F928771928771918671968A78968E7F918A7E9894899D9991A8A59F
A9A7A2A5A5A0A6A7A3A8A8A5ACABA9ACABA7A5A6A1A3A7A2969C969A9E999B9C979C9E9A
A5A9A7A5ADAAA5B0ADA1AEADA5B1B1AAB4B3A9B2B4A1AAACA1ABACA3AEAE95A29F9EAAA9
9FA7AAAFA9AFB788929336439F1923B00F15B20C13AF0A11AA060CA9080EA3090E940F15
96425363507C1330720A397F4A74A286A2B695A2AC9BA2A8999EA2959C9F95A0A1909D9E
8D9C9E8999998595948491928A8C8D8254597A10198F060F88050C83243155304E30355D
6A7A97A5A9BEADA6B98D7A8D8963778340548021378710248E08178D040E8A050D7B0A13
762632724D6B252858051D551638605A7A8D748B927284886A7E8065787A657876627672
6076725D75735C757257716D546F6A546D6A546A675168654F68634F6A6653716F49676C
2A4756051E3901173531455615971700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB71D80644A
6F635F665D5D6B67646A68656A6565574E51514548513E41492F324D3438534347564D52
5853574E4C4F5452555755565C5A586863626E6768776E6E7A706F7D71728576798B7B7D
8B79798E7A7A8F7C79907D79937F7C917B778F78748B746D8E796F8D7A6D857666867969
8D806E91846E91856E998D779588749488749188748D87748F8C7B918D819693899A9891
A3A39AA7A89FAAABA4A8A9A3AAABA6AEAEABABADABA2A7A49BA29D9AA09CA0A4A0A1A6A2
999F9CA4ADAAA0A9A7A3ACADA8B2B2AAB4B3A7B1B0A5B0B0A4AEAFA6B0B19FAAAA9EA9AA
9DA1A4B6A0A69649549A1E2AA81018B10C12AC080FAB0A12A80A11A20A0F9410168A3947
614E75102A6B0935784A75A18BA1B69A9EA7A69FA5AC9BA3A98E96AA8E96AB969C9F9799
9597988A94948896968693938A91939A828770222C830A1589040D840916882B3F834258
864D5E8542537F2E407A1A2E7E0D208808199107169506119208108309107A1A237D4357
54446915215904215C1739675D7C93788F9775888B7F8F926E8082667A79617572637673
6176736278765B737159726E546F69526B65536C66526A654E68654A67693D5B66153148
02193D00113A01153A294055169B1D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B81B7C5435
79665E645C5A6A66636D69686A6465594D51574246522D324312164B2024584045554C52
57555A4E4D525353555554555E5B5C68636570686B786D707A6B6E8373758B7B7C907D7D
8C7A788876748572708D7978927C798F77738D736E8B70698D736C8A73678A7668918170
91846E978974978974988974978975978B79938B78918C799A95858F8C7D8B897C929286
9D9F92A4A69AA7A8A1A6A7A1A9AAA5ABACA9AAABABA7AAA8A1A6A2A0A5A19EA4A1A0A6A4
A3A9A8A0A6A6A0A6A7A1A9ABA9B1B3A9B4B4A5B2B0A3B1AE9FADAAA7B4B1A6B1B0A6B0B0
AAA8A9A67C828C232DA4131CAF0F14B10B10AD090CAD0C11A60A0F980F129039446B5579
132E6B0D37774C71998D9AACA18E989F707C954F5B8B2E3D8B21318C20328C2C3B934A54
9B70769F90948D949686959594A0A1A9A7AB876067721E277F0A13890511880612830715
820915890C178A07128B05118B030F8B050E87080E810D137B1F277D4252634B68252959
081C58041E5E173A6C7EA2BF7D98A5A2B5BC798C9091A4A875888D697D7D697D7B627474
63777564787661777459726E566F6A536E69506B6850696A456068264156071E3E01133D
000F3D02103D01123B1E364F2A323400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058B91880512C
7B645A645C5B6C68686D6769675E5F5B484B5633374F191B460C0D471A1D5A4047564952
5754595455584F51535354565D5C5C66616370676A766B6E7C6F718377768E807F917F7E
8F7C798F7C788874718F7A778F79768D75708B736B886E678B6F678970658B7769907F6F
8D7E6B8F806C9C8D779F8E77A0907B998F7C96907D94907E918E7F908D808F8D808C8D7F
96968A9F9E95A4A49DAAABA6AAAAA6ABAAA8A8A8A6A6A7A5AAACAAA7A9A8A4A9A7A5ABAA
A4ACAEA0A8ABA0A8ACA1ABAEA6B0B2ABB6B5A2AEACA9B6B39BAAA79EACA9A2ACACA5AAAC
BEACAF9951589E1A22AC0C14B20C11B10A0FB20C10AD090FA00E13912E387D628119336F
103779586D9A9A8BA09257648A2A378D1421920D18980C189C0D199A0E19960B1793101C
8317249959629D8E928A9598839496828D918483868B6F7374383C74191F7A0C157E0813
7F0611850814840912810912790D18771D267A36407C50635B4C6B282D5D0D1C550B1C57
203163556289535F7B9BA6B78A939CA4ADB37C8B8F6E81856A7F81667B7C667B7C627676
6479776377755D7371596F6D56706C546E6D4E6C6E375461102A4401153B01103C031141
000E3F010D3D00113B1328452C373E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059B71587542C
80665D6A63636B696A6F696A6E5C5F5D393C551F23571C1D4A1B1B4C2F30524144554A4F
58545758575A51505552515659565968636473696E786D707C72718479788C7F7D907D7D
907C7B8F7B788F7A798F7A798D76748D757189716B886D66866B62876F628B7667877463
8C7A668F7F689A89739B897391816B958B769D97849592829290839192848F908395968B
93948B9C9B96A6A5A0AAAAA6ACAEACACACABABAAAAABACACADB0B1A8ADAFA5ACACA1AAAA
A2AAACA2AAAC9EA8AAA2ACAEA5AFB1AAB4B3A8B4B1ADB9B69CA8A59DA8A89EA7A9B2AFB3
BB949A922E36AC141BB60E14B40A10B4090FB40B10A90B1198252F966A8922336D1C3D83
5D62989263848A293D9513219D0E189908119609108E0B14840F1884161F89101B940D19
910B187E1622986C748A90957B9395819698A5B3B48C9194837F837561696844526B384C
6E354A713449733C4F71465A694E6753496A2F345D152153111F54252F624D4872654B6E
744A64763F5377384B76394877455084616985777A767C7C7484836C7E7D657877647776
657A766478765D73725A6E71546C714A6772254157051C4000123E010D40010D40020E42
010E41000F3E00133910284032434600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00936139
856B6371696B6E696A7164666C4B4E571C2058171A5524234D2F2D4C3D3C504544554B4C
584F535D555A58535757545759575A686367736B6E756B6C7C7371857C7A897D7D8C7A7A
907A7A8F7A79927B7C90777A8C7274876E6C866E69846C65836B60897262846E5C867360
8E7C678E7E6696886D8D7D648B7A60978A7399907D9A968894948891938691948995978E
99999192928B959691999D9BA4A9A7ACAEACA8A9A8ABACADA6AAACA5ACAEA7AFB1AEB4B7
ABB0B3A1A6A99DA5A7A1AAACA3ADAEA3AEACA3AFABA9B5B1A2AEAAA2AEABA5ADAEB8AEB2
B0747E9B1C28B20F17B50A10B80F15B20A0FAF0C139A141F995772393B711F397B5A5189
853E6392182FA10D1CA20A14990A108B1119872933874A5A76566D6B556D8B5C6F811F2D
8D0A15840C158244525B61716787937A959ABED1D49EADB178888F6C7B863B4B601F2C52
1A295A1B275A1A2A591222560A1D540A1E5710225934396866507575405C742238780F23
7E081B8207168206168006157A0814720F196D2229815A5C8D85847D86876A7A7C657777
677A78617574596E70566C753F586B162E4F011341010F43010C41020E41010D3F010E3F
02103F00133C0A233E334F5C43525500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0096663B
88716771696B6E6566765B5E612E315C1B1C551C1E5733344E3B3B4B40404A3F41554A4E
5A4F5660555D5D535A5E585C605A5F6C636873696C766B6D7F75768A80818A7E808B7C7C
8F7D7B8F7C788E7A768E78778A71727F67667E6964806A6282695D886E5D8C735F8D7863
8877608C7D6595886E94856998896DA0937A97907B99968792928593958A8D90868B8D86
8F8F898B8B868B8C86878B869BA09DA6ACABA9ADADACADAFA9ADAEABB3B2ADB6B7ABB3B5
A5ACAFA5ACAFA2AAACA3AEAFA3AFAEA7B2B0A8B2B0B0BAB8ACB6B4A9B3B2A7ACADC1ABB1
9A4854A51723B40C14B80D13B40B10B00C11A01019953E554A3B692B3D75796C9A853453
9B1528A20917A108149410197F212E76445D564D7427376B0F2A6310295B5148687D3143
890C17890B1482394E303254587B9574909A83969D7C8C9476899167808AA3BDCC5D7799
032558305887668CAF6D8CAF6A7EA4595C7F705673703049761529800A1B8705138D040F
8F020D8E010A8B010A8B010B87020A82010A7C060F6E12197D4A4E7D72746D7778687879
62757564797C5A727D2F4860091F49011448020F48010B45010C42010D3F010E3C01103D
001339122F4936576149646846565618971400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A17646
827164726A6C6D5B5C653E3D6029285F28285833354B373A493D3F4C42434B4044574A51
5C4F5660545B5E545B635961655A626F626974676C796D7085797B8C80818B7E7E8B7B7C
907F7E8E7C798E7B778C767388706F806A687C665E7C66597D6658876F618A73638A7864
8675618B7D699488739A8D78998B749C8F7A99917E9996859291858E8F8391938894968A
8F90868A8A8289887F8989818C8D879EA29DA9ACA8A9ACABACB0B0959D9CA6AEB1ADB5B8
AAB2B5A7AFB2A3ADAFA3ADADA4AEADADB7B8AAB3B5AAB2B4A3ACAE9EA7A8AFAFB3BD9AA2
8E2A37AB111EB40912B80D14B30B11AC101792263679587B3743738777A28835509D1322
AA0D189E0C178D1B2987485F574C78182E6A092A6E1038752F54826173938C7085791E2C
8F0B168A0B1681395128285235567772919E768F93A6B9BE94A9B52D4A5CAACADAACC8DC
3E5F7E678BA8B4CEE0A8AFC08C768A79384E7814278508178C04108D020F8D010D8E020B
90010B8E010A8B00088A020987010885020A83020A7D060F690E1782565C767574687779
61767C5067771D375502174501124801104901114A031046010D41020E3F00103D02193E
1A3B5140626A4868674A646447595916961400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A67744
8671627E6D6E67464663322E653430643F3D523B3B473B3C44393B4A3D414F404654474D
5A4E525E54595C535A60565E62595E6C6267766C707B70747F7478867A7E8C7D808F7C7E
8E7B7C8E7B7C8D7A79887472826C6B7D65637D645E7F665A7D6558846E62867164877566
8878668E7E6E9084719185719386739D917FA19787948E80908F83999B8E98988D97968C
96938A8E8B838A89808B8B818788818E90899B9D97A4A6A1A9ADABA9B0AFACB5B5ADB8B7
ACB6B7ADB5B7ABB3B5ACB5B7A8B1B3A9B1B4ACB4B7A9B2B4A5AFB1A6B0B2AEADB1AE828B
8E1F2BAC101AB50B14B40A13B20D159B121C9E5B71474066877499893650A01526A90C15
9C101791304171486E2E38720E347B0C3979335D8C6989A68091A39A88947E3944860E1C
920912830D188048641B2252476A8D8FAEBD546F78B1C9D0C0D5DF718A9983A0AF9DB8C7
768E9F6877888B8291835564751E2E8009188A030F92020E91010A8F000A91010B90000A
8E01098A00088A01098901088501078301087F00057F010974040C6D242A82707366767C
465F73122C5002174901114A010E4A01104C01114C010F47010E4002103F01153B1D3E52
3F676A496B684663614D666550626217991700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA23
8E6E5D8464655A29286E3A3575514D604948503D3E493A3C493A3E493A414D3F4653464D
574C535C535B5D545C62575F635A6067606377707272696C83797D83777B897C808D7D80
8B7A7D8C787A8D78788974728167667F625F7E615C7F635C80685D846D61836F61867365
88756893827396867591826D9C8D7B9C8F7F9E9384938C7F91908497978D9594889A988C
9C9B909091889091898C8D858A8B848689828F938DA2A5A0ACB0ABADB4B2AAB3B1ADB7B6
A9B5B4ADB8B9ADB6B8ABB3B6A7AFB1A9AFB2A9AFB4A8B1B4A2ACAF96A0A7A6A4ABA4717B
911926AD0F18B00911B40E15AB1018A0333D865A6E876684913C56A21727AF101A9E111D
8D35486A537B1D367409377D22528A6389A9809BAB8A98A09B8B918A4853871320950713
9107117D192A65446D0B20595A7EA6B5D3E47E97A17D959E90A7B0748B99536E857A96AB
9EADBD7D6D7C793C4B7A121F8506128A020B93030C93020A91020891010A91010A90010A
8F020B8C010A88010886000983010982010683010782010A7B040C630D156B505C42546E
09244F00174D00134D01114D010E48010F4901124B00124701114202143F0F2A443F6569
4A6E6B4B6A654863604B6762556A671CA11D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B91F
9166507E53535C2727764A476D55535A4B494C3C3B44353547383C4B3D4450434A52464C
584D545B515960565E635A61675D626A6063786F717F757982797C837A7C857A7B8A7C7E
87787B8E7C7E8C78788A73727F6462785D597C615C7F645E846960866F64867062897466
8B786A907D6F9B8A7A9685729C8C7B9B8E7D9B908197908295938697988B96978B9C9A91
9C9B929799908F92898D918892968E8B8E88898F89969C98A5ACA9A7B0ADACB5B3ACB5B6
AAB4B6ABB5B7ACB5B8ADB5B8A9B0B3AAAFB3A9B1B4A6AFB1A3ACAF939AA0B1A9B0945761
941620AF0E15B40C12B30F15A21517BD656AB67D89953F4FA11826AD0E16A2141D9C4258
6854811531750B3B7F3664967396AF8BA0A88F979CA28E968A475387142397081696040E
880E1985435E28275E06276540688D7895A57A9199748B9799AEB9B2C6D7223D5C314A6B
7B738A6F31427B0E1C88040D8A02088F020A93020B93010B90000991010B8E010A8A010A
87020984030984040C84030D84020B84000986010983010A7A020C61081A472A480A1746
01154E01145201135201125001124A0013441129521D375F01123F01153A2D4E5D4A6C6A
51706A526D6A4C65624F6864576B6922A72500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057B81C
9763467B4B455D2F2D765856695A5B574A49493B384737354838384B3C3F4F4044504147
5749515A4F565C5359605A5E655E616A60637C717481757883777C84797C83777987797A
87797A8877788B76768970707F6463755A56765D587B625C816960856F62887063877061
8C7668907D709987789D8E7C9E91809D90809B90829A938795938793938A95958E9B9A94
9B9B9593958D8B91878F968B8F948B8D918A858B858F9792A2ABA7A5AEACA9B2B4A8B0B4
ADB5BBACB6B8AAB4B5ACB6B7ACB6B7A9B2B5AAB3B6A7B3B4A3B0B1A5AFB2BAB0B69D5B66
9D1824B20F17B20C11AD1014A22325E68E92AB4F57A11B26AD1116A31419A2475765507C
1130740B3C7E4F7BA5819FB391A0A99B979EA4848C883C4A88122095061397050F8B0A15
88384C4E3E690A2462143A6D61869E89A2AABACDD65A76876D8B9DBFD6E67F8FA5675F76
692F42750C1984030D8A020A8D010790010990010992010A9001098F030C89030E7F0610
740B1270131A711B2372162175081283041085010B7E01097206134A09261A0F3D05134D
001252011355001254001650061F492847614A667D1A325100153E051A3B3F616D4B6C6A
53706B516C6947626249646552696B3E494700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0D
995D386E3C3171504B776765645A5B5448474C3C394A38374736364E3E3F5245464E4243
574B4D5A4E535F545960565B665C626D61687D6F7780717982757E84777D85767A87797A
8B7B7B8B787A89747686706E8168647A5E597C615A7B625A806A5E846D60886F63907869
8772638B786A8F7E6F968878998D7CA094849D93869692849394879C9C9398989095968E
9798919599928B948A98A3999BA39A8B908A8C928C8E97939CA6A3A3ABACA9B1B3A9B2B5
AAB4B6ACB6B8A9B4B4AAB4B4AAB4B6A4AFB1A6B1B3A6B2B3A6B4B5A5B0B1B6ADB2A3616C
9D1822B10B12B50E13AD1216B9353AD15F679F1A24AE1119A711199D39496E547C142F73
0D3E7F4E7AA38DA8B989929B9B8D959B6975862837921020970712950711890E1887384D
594470102764133A6F8BAECD6A889777939EBFD7E0A7C0CE657F8F9AABBA958A9A703645
750D1A82020C8700088900088E020A9001098D00088C020989040B7F08107717237C3B4A
724F63594A64453F5D4D3F59734052710C1B7E030E77020F5A072224083707104F001357
001354011553011A4F18385D395C6E4D6E783F5C6E04193B0720470A254040646D4E6D6C
53706C4664663A5761142F401F3B4944545900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
92572D744A3C745F5D736B6B635C5D534745503E3A49353240282A4E3A3B524445504647
5247495B4F5261545A60535A675A616E5F667E707781747B85787F83787D84777A897A7B
8B7A7B8B787A8B78798874737C6561755B55775C537A61557F685B886E638970638D7666
8B78698D7C6D8F7E6F96877A96897D988E8299918496938493938598988D97988E9A9C92
9396908C938D9CA7A3C5D2D0C9D3D2B6BCBB8D93908C948F99A29EAAB3B1A7B0B0AAB4B5
A9B6B7A7B6B6A8B5B6ABB5B6ACB6B7A9B3B5AAB5B7A9B4B5A9B4B5A4B0B1B5B2B4A56D72
9D1E24B71217B80E15B00D13C9303AB41F28B3121BB0151D9D2A39875E821D33730E3B82
47719F8CA0B39C969D9D7981893E498B1A26960D199B071693091481121E87465B514370
0E2568082F704D769DB6D5E796B0BB6F89957E99A1829DA5788F998B8C987F505E781220
8A07128B000A8801088800068D01099102088B04097B060C79222A7B49595C4867292D59
102054061B5208205210224B51415B691B2D78061564051B31072F0E0F4C021359011359
0216530721512A4B6752727C5573784D6A741A365001183B27436308233B4465704F6D6E
4F6C6B39556208203C00143803193441545E08C80800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8E572676544474635F726868675D5E574846533A374A2728441D224F313857414855474D
564A4F594D545D51596556606958627060687A6D747E727882777D82777C827478897A7D
8C7A7E8A757A8B76788872727E6664755A56775B527A5E5480655B896E65907A6D8A796A
8D7D6D9384749285759B8E7E978B7D968D8196918395938396968796978B95978D91968F
7B837D7D87839CA9A89DACAEC6D1D6C6CED3888F908A918D99A39EA5B0ADA4AEADA6B0AF
A6B2B1A4B0B0A8B3B4ABB5B7ABB5B7A7B1B3AAB5B7A5B2B3A3B1B39AA8A9B3B5B6B28488
952127B51218BA0D15BB0E18BA101ABB1019B81118A91F269852693836681D3875546696
968FA7A177859547548F202E96111E9B0D15980A13890C178126367D54733336690D2A6F
0732723D66907394A88098A27B939B768C9678949BB6CFD57C89958A748271202D870815
8E030C91020C8F020A8C01088F020A8F0209850C10873D4754405B1D2858091F5906225B
11316037577A728CA5717D8E7C65716313206E0819450424170B4104115901135D011756
102C58405D755371785975775D797D385366021A3D122B4C3C58720218343A586C4B6975
3853660B224300113C020F3C0112332F435312961700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
915C277E5D49634C48715F5F6A5D5E594546522B2C440C1049121750292D563C42524048
574751594D565F535D65586168596073636A7B6D757D6F7882747C83757B827276867678
8D7A7C8B73768A7174897070806763765957735753795E577D625B866D65927B70928072
8F817197877999897A998B7B968A7B9A91829790839390829A988A999A8F999D95858D87
737E7A9FA9A8CAD7D8A6B4B9B7C3CBBCC6CC848A8F7E84828C9591A2ABAAA3ABADA5ADAF
ABB4B4A7B1B0A7B3B4A7B1B3A7B2B4A8B4B6A4B2B3A3B1B29EACAE95A2A6AFB5B7C1A2A5
8D2C31AD141CBB1019B70A16B50912BA0F18B31118B4373FB172857457797F597C934F69
922E41981C2B9F131FA00C199D0C18920F19821E2B824960584C73172C6606296D16407B
4C74997795A68298A082939BB6C7D093A8B7446173BCD1E2A8A7B67842507F0F1B8E050E
91020B92010B91010A90010A90020B8F030A800911783449281F470A2056193C694C6F8D
6D8D9E738B957A838C88747C6D2F396D091565091F2C052F0B105003135F01145A143162
4B6B815773785672715A76774D6A760C254500183C2F4C63445E710115380B2148183356
051B42011141010D3E010C3B010F361C2F46189E2200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D662E855E495B39367259596D5A5B583D3F4512134C090B5012144E2326543D3E524348
55484F574B525D515A62555E6759607263697B6C747F6E7782717983727A807074857678
887678857273897273886F6F8166647B5F5C735652795C587E645E876F688470658E7C6F
9383749787789787789B8C7C9486789E9286958E81959283959486949688989D927A827A
78837F8A9695C2CFD1A8B6BCB2BFC5A9B3B98A9194848A88949A97A4A9AAA5AAADA7ACAF
AFB4B7A6AEB0AAB4B6ABB5B7A7B2B4A4B1B2A2B0B0A6B4B4A7B3B4A7B1B3ABB4B6BBACAE
974B50A11720B50F1AB90F1AB60D15B70F16AE0C13AF242FAA3F5089263E8C1C319B1828
A51420A80F1AA50A159F0D188B101D7E2A3A8A637F454474102A69052E711640756085A4
7694A295ACB192A6AC80919DC5D4E0A5BACB29455B93A4B79586946E2230890C1690020B
91010A93010B92020B8F030C8D010A8A020A86050F791B2C63405B35415E6784987B98A3
93ADB2859297887C8379454E6E0E1B7406155606221B0638050F5201125D0117532F4E6E
5B78805E76775D767459757C2A465D00183D0A26434563724A6572061939001340001242
000E40020E42000C3D000D3B010F3710233C1DA52A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A16A2F885C465C34317356566F595B593536480B0B570F0F4E0D0E4A2020553E3F514246
55484D584A5161535D6556606A5A6275626A78656D7D69717F6C747F6F777E6E72827475
847575847374877273876E6D816664785C577659547A5E598066618670698A766D907D71
928273918172908272928575978A7B988E819A938696928598978A999A8D9A9C927D837C
727C798994939EA9AC8592998D9A9F828C8F888E91898E8EA0A6A5A3A9AAA2A8ACA7ACB0
ABB0B3A8B1B3ABB6B7A9B4B5A8B3B5A7B2B3A4AFB0A8B3B4A8B2B4A9B3B5A7B2B4B1AFB1
AD7D818F2129A9111CB10D1AB30C14B50D13B00A11A80D17A0111EA31221A7111DAA1018
A80F15A2101896131E8A25358D4F66705A7E2E3A6E0E2D6C0B32712A52825F84A17F9CAB
829BA1BACDD2B0C4CB6D7F8CA5B6C2B5C8D5758B9C7D87988C6D7C6F131F89080F8F030A
8C01098B040B83060C800B137B081080050D87040D7C081575303F9F939FA0B0B88DA2A7
ABB6BC8B7E867D4A557116227B071373041549092A11084003105501165A0421524A6A7F
5C77795D75755A74774866760C2647011A4024455B4C6B73506C740D213D011341011043
020F43000C41010E3E010E39011036091D38323F4500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A902587553D60332E765653715655522221520A0A590E0E4E1212532D2C584241554647
594A4E5A4A4F6151596756606E5963775C6577555E704E5677606878686F7E6F73827374
8374748372728772738B72718469677D5F5A7C5E577F625D836B6686706A8B776F907D72
8F7F719082728C806F928674948A7A928B7D9A95889693869594879694899E9C958A8B86
6B706C737A7A6972757981848F98988289878B908D969997A7ACACA8B0AFA6AEAEA5ABAD
A7AEB1A8B1B2A8B4B4A8B4B4A9B4B5A9B2B5AAB2B6A6ADB1A6AFB29AA5A7A5B3B4A9B2B3
B6A8AAAE6D74921521B11521B40B14B80D14B40E13AE0E15AC111AA50E17A0111895141C
8E242C8F3E4F8754706858812D3A6F0D2F6C0A33702A53845D82A17794A5AAC1C9A1B6BC
7A9197A0B3BCB1C4CE889AA680939C8C9FA6A6B8C08083907C4C5C7B0F1D8A040B8A0309
83070C7B1B2480415171475D704359702937760C15830611730B148C545DC7B8C09C939E
8E6F7D74303F760F1C82051280030D6D081B360932090D4A011357001B54294C6C5C7B83
6078765F75794D6876153151011C44102F4D446771516F6F557073243B4E02163D011142
000D41020F41010F3D011036031939031B3339474E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
55B71B814C2F6A3D367B5B5872524F531F1B510D09541615582C2D513736524040534546
584A4E5D4D5464535B6B586071525B6B3A4465242F7036407D5B6274626878696E77676B
79686A8571738973748C7373856A687F625E7E605C7E615E81686489716A8C766C8D7A6F
9180729181728A7A6A928574928A79918A7C99948897948894918696948C99989195958F
92958F878B87949A969396948A8C8880827D858883979C99A2A7A6AAB0AFA8AEADA1A8A8
A9B1B2AAB3B4AAB4B4A8B4B4A8B3B4A8B0B4A7AEB3A8AFB2A5AEB197A3A5A6B4B6A4B2B3
ACAFB1BA9298942733AE1622B80F17B51014A71B1F9E303A933A479247577F435888607D
6E5D824346771D336D0C326E123E75345C8A5E83A389A8B99BB4BB889BA2A0B1B5A4B6BC
859B9F85999F8EA1A6A5B8C178919E9DB8C4B5CFD96B707F723C4E820F1F8B030C86050B
7E1C257348602326510A22531229505049606E3542730A147F0611750F1DA45B6A7E3949
7318297E081885040F80040D7108126A263C261541051351001752193D62537886627D80
60787D516A7D173252011A4508284B3E6173516F7357716F57706F4E6671061D3C00113F
021044020F4200123C06203C314F611931423A4B500BCB0A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59BA1C814D2D784D477452526949454B221B4D1D1758322C553E3B4E3D3D4E3F4153464A
584B525F4F5866525B6D51597448506A212C670C166D1F277F5459705B61716168726166
7664677D696D81696E856B6F896E6D8468657E615E7A605C82696488706A8B736A8B766A
8F7D6F907E718977699385768F8577928A7E98918696928896938B96958D96978F9D9F98
979C939AA097979B959395908C8E8882847E8D908C969D9BA0A9A9A2A9ABA5ACADA1AAAA
A7B0B1A9B2B2A9B2B2A7B1B1A6B0B3A9B2B6A8B3B5A5B0B1A6B2B3A5B0B2A5B2B4A8B6B8
ADB1B4B58B9292202BAE131CB40C12AA1217B352628363874F55823E507D253F6E17366E
10346D1940773157884E759B7195AE84A1AE869EA59CB1B5A4B7BB92A1A690A2A58B9DA1
93A8AB849B9EA3B6BBC3D7E33A576D55788EADCAD69198A6703F4E7F101C8D060F85050F
8831413D25470E23563E5F907E9DC19DAAC096788575232D7E050E84030F8109167E0614
83061284050F78070F6B141C6835463F2F500A13460215501333604A70865F8089627C88
446078122D54011A4808244A3E5E7255747A59737458726F57706E596F73374E6004193B
00133D01163F102B4936576447666A2C454E374B5016991600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2DDD0D7E472187554D62333474504C52342B53372F55403952433F4B40404D404353454B
5A4C54624E5867444F703C4767232B6F17206E0911650F157D4B506D555B726065726265
7B696C7A666A7C656A775D61876D6F8469687F63617C615E80656289706B8A736D88746A
8F7D738F7E718D7D6E91837595897E968C82978F869892899A978F99978F98999092948B
959A92989D97979C978C918B898C8684877F979D96949D99919B9B8C9697959E9F818B8D
97A1A2A1AAACA7AFB0A8B2B2A9B3B4A7B1B3A6B2B3A2B1B19CA9AA9AA6A7A5B0B2798689
95949AB8828B991C25B10F17B60C13A91420A75A78272F69134284406EA05177A06184AB
7697B681A0B78BA6B48BA4AD89A0A58CA0A38B9FA08EA1A48DA0A393A5A88A9D9FA4B9BC
C2D9DF6A848E839DA6AFC7D3728C9F607C91768D98959DA5825E687716208C081188030F
781120783E5A513E608F88A795849F87677B8449577C1C2881060E87020B88020A85040B
7B070D6C1019662C3B5038501F214606154801164F00164F1F3F6A4B6D8A4E6C852D496B
072353011B4F07254F395A6F5B777C5D76775B737356706D587270546B6B5A72773E5764
1C37482A4A5744646B4B696B4D6969334C522E444821A62300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008345177E403164292677504C5C443E55423B56453F5243404F404050414357494B
5E4F53694C5457232C6A21286C171E731A1E690F1461171C6F4349664D55705D626E5E60
7665667B67697C666A7A626582696C806769806666836766886B6A896D6B876F6A88746C
8A786F8A7A6E8C7F708F837496897D968B81978E859A948B99958D98968E999990999B92
979B95949A95969B98878C888589828C91898A938B7F8982808A867B86827B85847E888A
919A9E97A1A39FA9ABA6B1B2A6B1B3A6B1B3A2AEAFA2B1B1A3B3B3A3B1B2A6B1B398A2A5
AAA1A8A766709F1A24B60F18BA0E15AB101CAC536E393C7130609782ABC88DA6B492A6B0
96A9B093A7AC90A3A791A1A693A4A78FA1A48CA0A18DA2A39BAFAEBFD1D595A9AF94ABB0
B1C9D177929C7C99A07F999E93ACB77792A966829AC1D4E29B8F976E2A34810D1689050F
820410780B1B74192D711C33731A3075112577091880071182030A850208830409790E13
7E374467476026274A0918470218480C28522C4B720A244F011B480A245406205001194D
011C500E2D5641637957767C5E7778667B7C5E73735A727158716F57706E5A7374536D6F
4A686753706F59757254706C4F696930494F26404437443900FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4C16702E1764261D7F58535F4D475648425748434F3F3D513E405440425C4749
5F4648653F435F272C66212361191B6825286D34376B424565494F624B556551596B585B
7563647663647762647960647C63667F6568866C6E8369698A6E6E846A67846C668B756D
8B796F8B7B708F8375948777978A7B968D8097908598938C99958D999790969590989B95
919791949D979198948389837C817B828780777F7876817A77827A7A847F7B8280828A8D
869193929EA096A2A39DAAABA5B1B3A7B2B3A4B0B1A4B3B3A4B3B4A2B1B3A2AEB1A8AEB3
A999A0954B54A61721BA0E16BC0E14B20E189A283E705480274B7B7FA6BE96AEB49BAEB1
9AABAD97A8A997A7AB96A3A990A1A69AADB0A6BABB8FA4A694A8AAB4C7CC86999F889CA2
879CA298B0B68CA9B27B9BA5B8D7E636577A092F5C7EA1BCA2B1BA8A6F766F232C7D0E19
82060F8404108003108004127E04117E04127E06107C060E7B040B7F02097B060C863844
49324F0F194803184B1029562948665677886A8793455D70162E4C041C45061E48132C52
2E4B68506F8058787C5F7C7C617B7A657D7F6277795F74765A7273597072587072526C6B
49666256716E536D69526F6B4C6968223D442441463C4D4400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0099591E642307652A1F7E5753624E4B56484353443F513D3D543A3E5E3D435E393E
5E3639693C406533365B28296D404069424767494E654E555C4A525F4C56634F58665258
705C5F7461637661647C62677D62667E636685696C866A6A8A6E6E896F6C87706A917C75
907E758F81779084779487789A8D7D9991839792879A968E96948C9A98929E9E99969A94
898E898F97917C867E727D746D776F6E766F727C7676817C77817D747F7B757F7D7E8889
828E9086959592A1A195A4A4A5B1B2A4AFB1A7B2B3A5B0B195A2A4A2B0B2A4B0B3A6ADB1
B29FA7904048A9161EB90C12B90A10B50B129E101F9750722C35636E92B293AEB79EAFB3
9EADAF98A9AA97A6A996A4A997A6AC9EAFB3A4B7BB899BA292A5A98FA2A597A9AB92A2A9
90A4AAC2D9E36182983159739CBED557779510345B3D657E9BB7BDB4B8BC91777F763B46
6B1D286A0E1C6C0B17680914680D176816206A26307C3A44812D3776050E77070F7E3C4C
25183B0E194725335877869E778591636D73676D70676E715E6D724F636F50687557717C
5471765673735A78755B79765C7A75627C7B6077786074765E77775B73755A7174546E6D
4C6A6753706C4E6965526E6A4F6C6D122D352E4B50485A5000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007483155E21046C3730774E4F624A475A4B455845415A3D3E54282C5B252C612C33
65343B6C4045613A3F5E3D41654A4F654D56665059655159615159594951624F56634E54
6853586E585D755F63785F627D64657E6567866A6B8A6C6E8668698A6F6C856F6A8F7C75
8B7A7291817B91847B93867995897C9991839A948795928798958D9898919999938B8D86
777C747C817A737B736D796F727D74737E7678817A777E7B79817E78837F727F7A768381
7D88888592928D9C9C93A2A298A5A6A6B0B4A5AEB0A6AFB1A2ACAEA3B1B2A5B3B4ACB4B7
B4A2A8924149A9161FB80D15B80A10B70A0FB00F189A283E76567E3B537C95B1C599AAB0
9EADAE9AAAAD99A9ACADBCC19CAAAF93A2A694A4A790A1A790A4A790A3A7C2D5DBAEC2CE
88A1ADB4CEDC7B98AE3A5A767190A3819CAA8BACC0527A8DA8CAD2C2D4D9C0C6CFA69EAB
6D5E6E564359583F595A415D5743604D41613938583D3550723F517109147A060D8A3543
74455B62405967415364384761313C5D2B335E2E3362363A6A4B4E6C6062656B6B5D7170
58737058736F57746F5C77745B7773637D7B647D7C62797A607B79607A7C546D72476465
4665624868634E6C6753716E476169041E2D39575E4A5E560DCE0A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0049A80C5B2206703D36683A3B684844604B455D444161363758191D5F181E682930
643138542D346A4D555B464E5B4953624D5965505B64525A5F4E575A4952614D545F4A50
624C52664F546F565B745A5D775E5F8169688A71708D7072876B6C856E6B826F698B7A72
8D7B74927F7B93847B928579998E7F9890829D978A9C988D9A978C918F8882837B797D74
767E74737971737C73727D74727C7478817A767D767C837D78817D78827E77837D7A8683
7782827D89898998988D9D9D9AAAABA4B0B4A2ACB0A4AEB19AA4A79BA6AAA2AFB1A9B1B4
C3AFB68C3B45A4141DB80F16B90B13B90C11B70D14A211209E506D3F3B657893B297ACB9
9BACAE9DACAF98A7AA99A7AD9CAAAE97A6A890A2A2BACCD0ACC1C6899FA6B5CCD399B1BD
6E8797879EAB97ADB99BB4C66C8AA09BBACE82A7BE235168ADD3DFBDD5DDC1D4DEC0D1DE
B2C5D46D8399334A69172F550B234D091F4D0F224D413A5B64283C78081581030B7F0B16
740F1E6C09196D09166D07136C071269050E65050B63040C5F0A1258171E6743456C6666
5D6C6A576F6D5B74726078765F79755D7774607A79627C7C5D7A785B7779344E56224146
40605F44625E49686449676C1B354700163018334347605D1DA01900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DAD0F6025076B342B67322E6E4642694A455F3332591A1A5D10135F13185F2327
60363A6043495B474F5A49525F4D58624E59645058604E555A49525747515C4953604B53
5F4A50614B506951556F5559785E608166678A6E6E8D70708A6E6F87717084726C8B7A72
8C7B73917F7895837A9A8B7F988E7E99928495918599978B969387817D747E7D757D8079
727871727870727A74737D78717C77737F7A79847E76807A77817D77827F75807E768282
7682837B88887C8B8B85969696A5A79AA8AB9CA7ABA2ACAF9FABAE9DAAAEAAB5B9ACB3B7
BCAAB191444EA2141EB30C13B80D12BD1015BA0C13AE0B15961B2E88587B3E4D7290ABC2
99AEB59BAAAF98A7AA99A9ADA6B7B99BADB093A7A9BBD0D49AB1B689A0A58AA2A795AAB1
9EB6C089A1AEB0C8D588A5C0183D693F6A91618FAB5E899DB8D9E3C0D7E0BFD4DFBAD0DC
BBD1DCBAD1DEB2CADE9DB0CB757E9A625C78664D666E3449710D1C82051086010987030C
83020F7E010D7B010A7600087301087201076F01057002086E020868030C5B090E623135
6E6365616F705B71705E75765D767357726E5873715D77765B78765A7678344E56153039
426364466362415E651D364B01153301103101132D384F5523A82400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0054B4156B300C592012652F286F433F6C3F3D5C1C1B6111116614165C171B6C3E44
60454B5E495058474E57484F5D4B54614C535F49505A454D59444F5946515A49535D4953
604C51634F52634D4F6C545774595D84686C8A6E708F737488706E836F6D8875728D7B73
8B7A6E91807694847B988A82998D8397908498948899978A828074807B71827D787F7E78
757973797E796E7674566462566664516260586A686A7A79758281758081747F80758182
7782837A85867B898978888889989A99A8AA9AA9AB9CA9AB9DAAAC9BA9AD9BA8AFA0A9AF
B6A9B0954F589E1720AE0910B50A0FB6080CB80910B40910A60F1A96334B644D725E7699
92ADBE98A8B19BAAB09AAAB0B2C5CB9CB3BA8EA5A98DA6A992A9AD95A9AE8CA4A7B3C9D0
A6C4D46388A383A5BF7193B2052D5B14426C6790A7B3D3DFBDD4DFC1D7DFC1D5E0C0D3E0
B8C9D6A6ACBE8E869B785C726B384B661D2D6A0D1B79081782030F87010B87010789020C
85020C80010A7C010A7601087401087301097001056E00066F00076C000867020859090E
63383C6B6A6B5B6F6E57707058737055726E54716D55726F577471577472455D640B2330
3F6068324F580E243B011034000D32010F3101112D1A303A327C3500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002DDC0C71380A4D190463342C7F53505B222063171660110E651F1F5B282A64444A
59464E58474F58464E57474F5C4B525F4B526048516046525E45505B45505B46515E4A54
5D4A4F624F52634E506C555870585C80666A8A71748C757487726F87736F8B79758E7C74
8C7A7092837990827992857D90877D958E839A948A8D887E7F7C727F7E747D7C757B7C75
798179626E6959686660736F687A766677765267674D6264677979748281748280758283
7681837985877784857685857F8F9092A3A596A6A98F9DA197A5AA95A4AA96A6AB98A4A9
ADA6AB9B5F67991822B10D15B90C13B90A10B90B12B80C12AF0A119C10209A506C48466A
7A98B1B2CAD59FAFB593A4AB8B9FA6889FA590A7A98CA2A5B8CED2BED4DDA2BEC89CB8C4
7EA1B60C3656567B987292A77095AE5B89A38BB3C1BED8E1BFD2DDC1D4E1BECBDBACADC0
9482977C4F666923386D12257209177D051381020D83020D83010B89040D85020987010A
83000881010A7C010A7501087401097300097100067001077001076E00076B0206650307
530F136E5C5C5B6C6B54706E56747156737154726D54726D55736F53706C4C666D041D31
1C364F041934000E31010A31020B31010C2F010F2C0B1D2A414D4300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007E410F521E07683A317A49465917146C1E1A5B14106A37346345465B484E
55464D54454C56454D58464F58464F5D4A545B44505D434F5F46515F49535B46515E4A53
5F4B51614C52664F536F56596B5256785F638770728F76758D74728A73708C7974907F79
93817A96857D92847A91847A91887E958D84968D86857D7674736C6A6F676E756D797F79
6F797550625F677A776E7F7A707E786D7D795C7070475E625369696B7E7A6E7D7A727F7D
707E7E717F807280817989887B8B8A83949581929489999D8C9BA098A9AC92A3A796A5A9
A6A8ACAC7F868F1A24B0121CB90C16B90912B70B10B6090DB1080DAD0D1793172A8E5A77
515B7999B5C49DB2B890A2A78BA0A3B1C5C7BBCFD29CB1B6ACC3CA9AB6C45E7F907F9EAA
7C99A67795A982A3BA7E9DAFA9CFE42C5B768EB8CBBCD5E1BDCEDAACAFC1968399855168
7826397A11217B05137D040F7C000981010A83020980010981000983010985020A850108
8401088402097E01087801077401087401087301067201067101067001076C0105690105
59060A5C393D556064526E6E547370526F6C52706B52706B4F706C4E6C6F3D5867041838
000E34010D34010C3300093101092F010B2E010E2C0314243C484300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0081420D5A240B663329793D3B651D1A6E2922652F2C6B4949634E5356464F
54444D55454E55424C59454F5C485258454F563F4B58404A59424C5E47545B46525C4950
604D525F4B51634D546F565B73595C795F63846A6E8C73748E7372896E6E8F78778F7C78
907F7893817A96867E8F83788E857B91897F877F777A776F656762656E6A5B6561777E7C
5661625063646677786D7A7A6F7C796A79765F7372475D604F6566677B796F7D7B768080
747E807481827483837383827E8E8D829392778A8A91A2A392A2A499A9AC8C9DA094A3A7
9BA5A7BB9EA48B2732A71521B60C18B70811B60B10B6090DB60A0FB40A13A80F1B972A3F
835F795E6E8391ACB697ACB18B9FA3B9CCD1BBD0D7A7BDC58BA2AA8DA8B088A5B0849EA8
87A1ACB3CEE35B7EA4406A9477A5C534617EB2D1E7B0BCCE988DA0865C707A2A3E841526
8A0A168A050E87020A8102087E01097E00087F02087D01067F010784020A840109840107
83010582010780030979030A7303097003096F03076E01066E01056E00066A0105670004
5C050B512532343A45506C6E53716D54706B536F6A516F6D4C6C7329465B071E3F000E39
010A36010A34010A3100082F000A2D000E2E00122A0012223846460ECE0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008649105F2A0E571E156B27236A241F6C36306E4D4B6D585C56474C53454A
55454E50404953414B57454E5A4A515D4B5259444B574149533C4758404D57414C5C4950
5F4C51614D5365505770595F765E61795F63886E728D75748A72708D7473907A788E7C77
90817C93847E94857E92867F8C837A8A8177807B6F78786F5F6660626D69646E6A7A817E
4B56574F62646173756775786573765D6F70586C6E44585B556A686D7F7B75837F778381
6F7C7D6E7C7E738283738383748485778888788B8A8194948A9B9D8C9C9F8B9C9F94A4A6
9AA6A9B9ACB29A515B981A26AE0F1BB40912B80C12B70A0FB50B0EB3090FB00A13A61220
9A3C506A536DA8BED4B7D2DF96AAB299AAB28FA4AB899DA78AA0A896ADB4BDD9E59BBAD1
7D9EB984A4C8062B64042F694973989AB4C9A6A4B88C667E7D344C7B12268909198F0411
8E020C8C02098800088200087F01097E00097D02097D000681000887010A870209830309
7E040976070E6F0B14660F195E161F5D19235D161E600B1468050B6A0107690104660005
5C040C542737161C2E4D696F506D6A516D694F6B6A3F5C6916314C02163E010F3F010B3B
010936020934010A2F020C2F00102B0B263726454E0E252E2C3D3B21A11A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0064790B642E0E54190B6120176F38317855536C585964555755474A504447
53434953404856414B54424B56464E56454C5A474E59454D553F4857404B57404A5A464D
5E4B51604C526650556B5659776365786164866E718A71728B73728E76748D7672917F79
8A7C778F837F908580908580908680837C727E7C6E7B7E706C736A68706A737973777C78
495655485D5E596C6F5B6D7256696E53686D485E6241575A6073716F7E7872817C6F7E7C
69787B707F836A797D7887887A88887B8A8A84959581939480919393A1A595A4A795A4A6
9FADAFADAEB2AF818A83222DA31621B30B15B80B12B80B11B50A0FB30A10B20911AE0B16
9D142492445C685E7A778DA28FA4AE92A5AA9AADB3BFD3DCB1CAD694AFBCA3C5D91C4369
244D756F91B048668B4F689178829D90798B8644597D182E880B1E8B021191030F93030E
8F020B8D010A8A020C8400088100098001087F010880010883010889020A830209770C12
72222B733F4F684861544260453C5A3F3956463952674151590D16670308690204680205
58070E512D4209142C4B66714F6D6B4D6A68425F66061F3A021541000C4000093D010839
010736010835010C3001142C18353F305454375A5728424224373125A71F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0041A2056228064F1304602C2173534C705F5D685C5B615455574A4B524144
593D44512C364A283159424A57454D55444D5B48515A454D553F4858414B543F485B484F
5E4B50624D526954576C58597461627763647F676A876F708A73738D7775907B77917F7B
8D7F7B8B7E7B8E817E8F837E897E777E766C7E7B6D7D7E7176796E72766E7679717B8079
5E6A68435657475C60455D61425C60415C5F3E585A516768697A7973807D727F7E697879
6B7B7E7283876F7F838391938390927987898897988898988191928E9C9F99AAAC94A6A7
A0B0B1A7AEB2B7A0A99C5A66901C27AD0D17B50A10B50A11B30A11B40A11B40A12AD070F
A70A15911122944F64928695BDC8CFA3B4B79CB0B5B8D2DE6C8EA17B9CAF80A0B252728A
68859F839BABABB7C9A499AE89586C8025378B10208F041391020E8D000A8E010991020B
8E010B90020D8A010B88010A8402098101097D0209810209830106820208720811804454
513E5E1E25540A1E53051E54031E4E061F49102241544357510E1A630208670102640206
55162036273E081B374966734F6D6B4E696749626A021635021040010D42020B3E010839
010936000B31071E3623454E365A573D5F573E5D56354F4C1A2E2735792B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004AAA0C5D1F0051190962392E735D557269636B615E6358575D4D4E584045
5329304409115522295C3D4353404857454F5A464F564048513B4458424C55414959464C
604C536752586B575D705C5F7460637C656881696C8970738972718C75758E7879907D7C
9384818E807B8F847E9086808379727D746A80786E7B796D76776C7B7D747C7E767D817A
757D794F5E5E3E515440595A415E5D496362536A686275726D7B7A6E7A7773837F6D7D7B
6676776B7C7D6F7F82818F918290908392928B9A998695948796968B9C9C889B9C8C9FA0
9BADAEA2AEB1ADA8AFC09DA793414DA1161FB20C14B30A11B30A12B60B13B30A10AF0910
AE0B13A30814941826A45E69D7C4CBC9D2D58DA0A598B0BB5C7B8B7E9CAB819AA4BCD0D9
C3D1DBA6A4B28B6D7E833B4E8415278F061596041096010D94010C90010A8E010991040E
8E000B90010C8D030C89040D7E060C75080F891E257D07107E030B75050F76344646385F
06195402205E1536682F4F7544607C55677D605E6F5227375A071166010765030458090F
5432420F14330C26434767744F6C6C526B6A5068700C203B010F3C020E40010C3E000938
000F341730473559603A605D3A5E563E5F563F5E55354F4C172D28444B3800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052B2135A1C00511A0B6A40345E443C71635E6E63606658585F494B532C31
571A2251060D4E0F135F383F533E4755444D58454E58424B533C4457414958444A59454A
624D536A565B6D5B607563687761657B636783696D876D71876D6F8B7273897173907D7C
91837E90847C8E857D8D857D877F757E776D7F7A707C796F7A7B70797B717D80787E827B
7D837E737C79616E6D60716D5E726D61746F6878736C79746F7B766E7C778F9E98B6C3C1
B3C0C18F9D9E7B888A7D898B8695959EAFAE97A8A69BABA997A8A793A4A593A5A89BAEB0
8EA1A39CACAFA3ACAFADA6ACB0868D8D242BA90F19B10A10B80E15B40A12B10810AF0810
AA050BAB0712A50B18961B29AA6571BBA8B0949DA28EA1A7B7CFD8B4D0DF98B2C2A6B2C1
AC9FAF925F737F2336890D1E94071597030F98020D9A030D98040E92010A8C01098D010C
8B01098B040C810A107312177D303496495184242E77040F77060F6D1D2B593F610C1B53
04235F2D507D4D708864808C6B798073646D5C2A355A081367030B6802075B0709613039
27223B03153B23425D496973506C6C536B6C546C7313274002113A010F3C00113C0A1C42
0118333A5A6542666340625B4161593D5D543E5B55334D4C162B2A49554800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0056B6145E22015F29195B2A1F5B36307B6563736161684F4F653B3E561A1F
550C125304074E0C10633B4155404954434E5A485257434B543E445941485E474E584349
604C516F5C5E7461637865687B646A7C636782686C84686D856A6D8A6F71886D6F897372
8C7B778F847C8F887F8C877E807B717C796D7B7A6F79796F76776D787B707F827782847D
82837E7D807D7A7F7D777F7C707A75758078727C75757D79707C78899895C8D7D6C9D6D7
CAD5DAC6D2D87C8B8F7887897D8E8E8A9C9C9CACAE83949587999986969B81929884969C
8EA1A5899C9F9BA9ABA5ADAFAFA5A9A3646A9A1D27AE0F16B60D13B20911B0070FB10A11
AF090FAE070FAC0710A40B17931B28A05E68C0B1B69CA8AEADC3D246657F60728E927E95
89445A88182F940C1D95031095010C99030F95010A95010A95020D93020D8A010888040D
7F081072131E7A3C49724D5B906872752E3972081478050E6A111B69405B15194A031C55
4A6A9488A4BD718694727781755D6465252F6307116B020A6C010666010572262A5D3947
1315320D23424363734C6C6F506B6A516A69546C731E3348011434061E3C2544573E5C6D
09203238576044676246665F43625B405E57415E5A284245142F2E4556480FCE0900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00642A03602B1A521D125F332D7F6362765858632F30641E2057090E
590E124F0A0D521E1F5C3C3F53404852404B5A46505A454E57434B58424859434A5B464E
6551576F5C5F7362637966687E696D785F6282666A83686B84686B886D6F82676A856E6F
8976748E837D90877F9188818177707D766D7B797078786F72736B76786D797A6F838279
82817B80827D787D7A7C8381767D7B7C868077827B76817C6E7E79A0B3B1C5D8D9C8D8DE
C9D7DFC9D7E085959D788B8E8295957E9090899A9B8396968B9C9E808F94849499798D91
889C9F8FA0A49AA8AC9AA6AAA4ABAEBBA4A9893B439E181FAA0A11B10A11B0090FAF070D
B0080EB0090EB10910AE0911A50D168F1824A25F68B09EA77D879561687E81637D812D44
8F11249806179A031098020C97020D99030E95020C94020C92020C8D030C81071071131F
753B50624A6A332E5251406075384E740D1B7A060F6A0A15734258231F4D0418540F315E
92B2CAACBDCE88819272495964162470081475050C7200067201066F0308670A125E1B29
4F2F424E4F5D536A6E4F6B6A526E6A506968536B6E334B551E3B473C5D6548696C4D6A6E
152A382E4D594568684A696444635C415E5A405D5B122D30163332435A4B21A31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006E340A622D17511C105E3029835C5B723D40611619610F105A0E11
5114174F2223533335574244523F46513D465B464E58434C58444D543F485C474F5D4951
6351576F5F6472626579676A7D6A6D755F637C6466806669896F71866C6E806668826C6A
8977748678728E827C9286818275718276717C777177766F74756D74756C7A7B717C7D74
81837C7E847D78817C78827F767F7D78837E75817B75837C6F7F7997ABA8C4D8DAC5D8DE
C4D6DFB8CAD375888F7185888295957486858FA1A1839696889B9D8191978193977A8E91
7A8E919BADB199AAAEA0AEB49FABAF9EA1A5AD8E938529319C0F18AE0C13B10B0FB0080D
B30B11AE070DAE070FB10A12AD0911A30C178F1926A86571B8939D96606E842235920C1C
9C05109E040D9E040D9C030D96000A97020C94020C92040D890810750D19722D415E4467
2D316714245F4D4978683153750D228106136F071173384D352C570516531431677E9DBD
7683937E6A7D692F456B0F217604117C020B7601067501077402077202086D010766030C
56081253282D656061546764536D6A516A685068684D68684665634867634967644D696B
1D36431D3B4944676948676245655C43615C3E5B5A082225223F3F40574A23A71C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0083481359240A4E1B0E6C3D378250516824276915157125255C2525
5831334F33354D373C513E4654414B56414B58424D56424B543F495A454F59444E5E4953
604F566B5B617361677B696E7A686D7A676B7763647C656784696D866A6D836867856E69
86726D8A7B748F837D9187827C726E7D74707A757274746F75776F787A72787B72737A71
757E7677817978827C76807C757E7A757D7A737E79727F797B8A867B8B8AA5B7BCB4C7D0
A9BCC47B8F9674888C708485839596788A8B889A9B819496809498778B9081959A84989D
788D918A9EA299ABAF98AAAE8E9DA29EAAAF9A9A9C9B6F738820289E0B13AB0A10B00A11
B30C14B00811AD0710AD070FAD0910A20910921219AF4A55A547538A17269209179C0511
9E040B9C010A9D040D9A020D9B040F95020E8C050F7D0D177E32426C4766302D5D0C1E5F
0D2267433F7A6B3459760D2582061477071279324646325C0A1756031A59485C8789869E
6F4659691A2D72081B79030F7D010B7E020A7A010877000A7300077301086F0106690005
66040856060A5D36375F62605067644E67644D66634D67644A68634A6964466560496767
27424D152F3C44666747676046665C43635C41605C133130314F4D43594D36782A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063750B592405562315713B367231307321236715136A2C2A633B3C
56373A48292E543A41513E4751414C56444F56414D58434E56414B5A454E5B46505B4650
5E49526B575E705F6579676D7C686F79656B7B65687E63678B686D8D63677C5250896962
88716B8776708F847D9088807A746C7D76707A767073746C74766C767A70737A726E786F
707B7378827C78817C77817C747C77777E7977817D75848079888675848478898B788A8E
7A8C907083866C7E817385897B8C8E7B8B8E7B8D8F7F9296748B8D758D8E6E84887B9094
73878C7A8E928EA2A49DB0B08FA2A395A5A9879495AEA6A8925C628A1A25A00D16A9040E
B50B14B30913AD070FAD080FA80B129C1418C54E54AB343E97101D9C08149C030EA0050E
9C020B9C020C99030B9A040F9606108409167821316A3B5840376511205D031F63152C6D
565386672E527A0D248805147B0813752A3D5239620E1454081A5C363E72705B7B65283D
6F0F1E7905137D020D7E000A7F01097E01097F020A7B010A7400077301076F01066B0105
6901046303055011126558575367644E67654E6865506A664C67624B6662476561466363
35505614303845676645645D47665E44625C45615C3B58513B595141574B4A4C3A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0041A208551E02622C1D61211A72222074201E6C25236F3C3B623A3A
512728481B205B383E543E4554434C54434D56424D54404A57424B5E4952604A535F4952
6049516753597260667B676E7F69707E676C796065805961854C537B3237752F2F8F615C
8C7570897C77887F788D867D7C766D7B776D7B786F78786F797A7173796E6C766D6E7670
767D797A827E767F7B76807C737E79747E7977827B81908B7C89897987877B8B8A829391
7E8E8E71838474878976888B7685897A888B88979A788B8E7E92937F9494768C8D7B8E90
7A8E90768A8D7E949596AAAA899E9E90A3A48DA0A18E9B9BA3989A995B638D1721AD131C
B40C15B50B13AD090FA90C13A0191EC74F53A72B369B0D1AA70A16A5030E9F010A9F040C
9A000A99020B97060D8F0A15811B2A81455F4C3B6417245F06256719387842568C746991
7235508010248F06168206127625385B40680D14540B165B3B366B683F6265152B770818
8106117E020B80030C7E010A7F000A7E010B7E01097C020B7501077202086E00066B0105
69010466020552070C482F364A5B5E4C68674C67644C69654F6B664D676345625D456260
4662633E5D5D44656247655F46625D48635E49635B4660563B554C42584E48504000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0049A90E591F0663271B560D0674241E6D25217F4945704141582223
5115164E14174E2328573F4454434C55424D53404B53414857464A5F4B51614A52624952
60464F6852586F5B617D676E7F686D7C676A7D656881575E712C32882D317E29298C5552
8A716D857875897F798E847F7E766F79756C7A7A7174746D78797272786F6D786D6A726C
767C787A807C77807B76807B75817C76837B7A857D848F8B7883847986877E8E8D839392
7A898A7788886D81827487886C7C7F848F948793988494978E9FA08E9F9F7C8E8F748689
798C8F788C8F6F868892A8AA96ABACBDD0D296AAAC899C9E97A1A2B3A4A688444B951823
AB0E16B40D14A80A0EA1191FCD575EA92D37A00F1CA70813AD0A12AB060FA4030C9F020B
9C040D95050E860E1883344A6E5076282F670724630B316F5A7FB299ADD67561827B314A
840D1F9006138807147E263967486E141B5A131D5F4B3A6F6025466F0D217C031382010C
86020B81000982030B81030B7D010C7800087A01097D010B7A02087501087101056E0006
69000265010355050C3F212E2F3D4A4866684866634867624968634B686346656144635E
49666249676147655F47645E47635D48625C476158435D5435504A39524A43524300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB0116227065516094F080269251E804C457A4F4C683434571214
570F12541A1D502A2C553E4255434C57434E55414C54414958464A5E4B4F5D474F624650
60414C674A536F525B785B627E65697864677A656885626882434A761B207C24238F5652
8A6D6A847370847875877C79847B7579746C74726A73736B73746E70766E6A746B69716A
6E746F757B76767D78757E7A7E888475817B75807B8B97947A88877686867586867C8C8C
7E8F8E7083826C81806A7E7F72848684929789979C8B9C9F97A6A99AABAC7385897D8F93
7285887F9395798E918CA1A49DB2B4ACBFC49DB0B499ABAE97A7A7B7BFC1A69197994D58
9B1A23AD1319A6181AD3575FAF323DA3121EA80712AC070FB00A11AC050FA5020D9D030C
920911831A2779415C443D6C0F2968052D6D325E9191B5D9AFBEDB8F74927A29448D1023
9205108A09147C22356B4970171F5B1E28675D4977631D3B760A1B83041082000A840108
8601078601098401088002087D040D75040B73010876030B75040A75040B730108710107
6C010366020453060D3F21341A293B45656A4767644A69644968644A666548656246655F
47665F4A686146645D47655E45645C46635B466058435E563B5A5526453E435748209F16
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057B615692B034F10024F10076B332C83544E7C4A485418175E1919
5D2020572C2E593E41523F4556434D503D47513D4856424B5D484E614B5260464F623A47
5E2B386E3A4668343E602F37805C617B60667C63698162678752577728297426218A5750
866B66857570817671847B76827A7477716976726B7A776E75756E70746E6C726D6F756F
707570737975747976757A79838A8978817E76817E788683758583758685768686788585
7C8A8A788A89647877667B7C728689879A9D8D9FA2859A9C94A7AA93A4A97F929775898D
6C8183B2C6CA92A6AB7D929695A9AD8D9FA69AACB1A1B2B6A7B9BCCDDEE2C5CDD2BFA8AF
954A5297242AC74B50B8353DA7131FAB0913AE0810B20A11B20A11AF0912A80A11930A10
91323C6A4260272F66062A6D1A48816F99C0B0D1EAA8B1C68A697F812B428F0F20960711
88070E7D2334725076191F5D1F27676B507C691C3677061583020B85020A810007850108
8401068501088403087F030975040A68060D5F0A12611A2367262E6A1C2568070F6F0208
6D01046303065211192F1D330D213644666E4667664968634A69654C68654C666349655F
47665E47666047676144635E46646044615D46635C415F573F5E5714332E354C4122A51C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006D2D07501003541A10713A33783936753130642220612B27
5E3735573D3E544043503D4453404A53404A523F49533E495C46505D464E624049622836
560B176416216B1F295C1A218B585F6E424A6C444B815E657B51556E383685504B87625D
856B6882726D81756F847B75867D77776F6A79726D7C787174756D6F736D6E736E727772
6E756E727973757B77737875777D7A7C8582737F7C73817E738280788886728080839091
7987887484846D7F7E677B7B728688889B9D809396889CA08DA0A592A4A97F9298778B91
758A8E6E82896F838A7F949999ACB0A3B4BBC9DBE0CBDCE2ABBDC4B2C5CCB5C8CCA4ACB0
B99FA7AD636DB03742AF1824B40F1AAE050EB30B11AF080DAE090EA8080F9B0E12AB3D41
A062732B2B57082F6D3A699D9BC3E1BED5E9AAA9BE885E787E2338910D1D9A0813910B13
7E2230704D711C24601A27696A5080701D3980081785010C84010983000983010984010A
83010A80020A79050A6C0A0F641B24693C4A584056453B5A36314F6A4D60580D196E050D
6C010659040754293513122B0C263D40646C43646245645F4867614B67644D66634A655F
496860486860476962456560476562486662405E584262563D5C512E4C452C483B25AA21
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0077350C511203581F156729226C1F1C7226236B312D643E3B
5B4341534141503D41523F464F3C44533F48523E47563E4A5B404D63414D63323E601823
6B161F630C14651419530F1378454864353A5B2E34816165806466876868846765846866
8A716F88767182756E857B75897F797C726E7A716B7E7871797A72727770737A736E7470
6B726E747C76757B76757A7671787476807B707C7874807D79848473807F6E7C7C728281
7688867183817789886B7C7D697B7D7D90918598997A8C908FA1A690A2A78093987C9096
7F949971878C8EA2A7B0C2C799ACB1889BA2BFD4DBC1D5DCA9BBC2A3B5BCB4C6CACDD9DF
C2AEBAA35263A41827AF0A16B30811B60B13B40A10B0090BA90C0CA01718C64F51A1323B
81344A48426B4975A2A7D2EDBBD3E3A8A1B58C5972821E39910B1C9E0A15910A14842738
6E4B701B25631025686056886A1F3F83091B8A030E88010A83000982000981010881030C
7C060F6D0A1267202A6A4456493F5C1E264D091C4B07194D1F26536244605709196E030E
6903075F181D40283707122C1B394C3D616442645F4766604B68634C67664A68654A6863
49686248696148696247676146655E44645B4363594161543C5C5123443C315146317A2C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0084421155190661271C55110A6B1E186A28237148425C4540
53433F5044424E3F414E3C43503E46533F485840495E3B475F323E69354260202A5A0912
6C161E5E0E145E1B1F643334704D4E6C4F50634949725C5D7C6969806D6D806C6B836D6B
8B7572897671837770877E77887E7A857C777B726B78736977776E71756D6E746E6F7572
767C78767D78767D77767B76747A76747D79717B77737E7B727D7B6E7C7A6E7E7C6A7C7A
687A78697C7B7184847080826C7B7F80909382939595A5AA7C8E9385989C84979B7A8E91
72898B789193B0C5CBC3D8DFB5C9D08A9EA67B90989DB1B8BDCFD59FB0B7AFBEC6CAC7D3
AC77889D2639B3101FB80A15B70912B40911B30C12AA0C0F9F1819CF595BA52C3196101C
82192D674E7254779CB4D1EA9F96AB844A6282183092081B980713910C1682293C6A4D74
18276706236B4247816933567C0C218B02108C020C89010A8602098101097A030A6C060D
691F286F465B493E61141F4F061C52041E53152C5A3E436B5C405F5B162B6906136F010A
650105641A214E2C38191C2D37515943636146655F46635E4B6964486663476763496762
4766604968624C6C6649686348676046655C4564584161543C5C5128484216342C435241
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008E4F145C24095A201159180D70312876463D6E50485B4742
5443405043425245464D3E434E3D45553C485F37425D212D59121D67242D68232A61181D
6B292F6029305D323765494B6B585B6756586655577767677A69697F6D6D7E6B6C826E6F
8773718A787284777089807A8B827E89827B7F7A6F74706576746C767871767C75777D77
787C7A767A77767B76777C77777D7A798381767F7D707A776A77746979766B7B7A70807E
728381768888788A8B6E7E817584887B8A8E88989C7C8E9483949B7B8D92809395ABBEC0
B0C4C87F969C718A927E969F89A0A695A8AF9CB0B5C1D2D7CBDDE1C7D5DCA9ADB7BD9AAA
983549AC1426BC0E1ABC0B15B80A13B30A13A70D13A82327C852589F222AA3111BA00A14
881120764A68333D618C80A07E3C57851429950919970714860B1687384C574068112566
052E732E4B846E567C72132E8A05168D010D8C020B8A020984010879030C6A0E186D3648
4D3D5B172150051B55041E561D35624F5B7D6B62795A2E415E0F1E6C051172010C6F0108
69000660040A510B11502F34565A5948625C45635C44615C4867614766614A6964496862
47665E4B68634B69644A68634967624A666149655E4463583D5C523957511F3C32435343
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF003E9F02652D08541D095B231569392D7651486A4C455C433F
564342554344503F41503E43543B445429355314205E0F185A0D1264232869303559252A
6C4449603F4760444B6950586551585D4A526A595F79696C7C686B7D686B816D70856D71
8A74748A76748A7A76887D7A8A807D857F798480767C796F78766F767871777A73767B75
787B7A757878767A77787D7B747A79717A7A707B7B6F7B796B79777180806F7D7D788783
6D7C796A7D7D697C7E6B7E806D80827F92958B9EA1869A9F7E9196788A8F83969AA2B5BA
A3B6BD7D92987F949A8CA1A7B1C4C9C0D2D6A1B4B8ACBDC2C4D4DBBBC3CCB7A3AF934556
A0192AB00B18BA0B14BD0E15B80E16A80E15AD2D31CA545CA2232EA6101CAA0812A50812
870914A25C707C516B7D2F498A122796091696091186111C7E3B534D42710F2A6C0C3A7B
608CBC818AA860253C840C209003128E010D8C020B86020978050B6B18246A42572E2A51
081A50031D55153061526284766D826C4253621B2B67081671040C7401097200076F0108
6E01066D02076202054B07085C444151625846635B44625C4767604867604B6962496862
4867604B68634E69654D676549676548656347645F45635C415F543D5A522947403E5143
20A01500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047A808632E0556250E54251567372E5A29236638325C3A35
5842405544444F3C3D51363D4A2028531720591016560C1061242765383C6C484D69484D
64474E644A53654A546A515A59424C503B465F4F5775666A7B696D7C686B80696D876D72
8C74778F7B798B7B7A8C807F8C83808A847F827E798B8881797A7273756E72766F737871
757B77747977727975757E79757D7B717A7A717E7D707D7C6C79797682836E7B7A72817C
6F817C637776667A7C65797C6E8284798D8E839899819699A8BDC09AAEB38A9DA285999E
7C8F959FB2B7879AA083959CC0D2D9C6D8DEACBFC4A2B3B99FACB3B1ACB6A36C79951D2D
AE101CBA1019BA0D15B70E13A60E11AE2D31CD575DA4212DA60F1BB20D16AC070FA50710
8F0812B955637F1B2D8F0F1F980915940C15841A25844B6739366B0C2B720D3A7B6B98C4
ACC7E28672876F182A8A061792030F90020C8D040C7E061071222F6445601A1E4B041752
0A2158394B7267647D6F4B5E6B2130700B1A74031176020C7602097501087202086E0006
6C00066C01056601045704064F242451565143605942635C4567604968604C6A62496762
4968624C69664D68654D66644764614A676348676145635B425F533E5A530D2A252F433C
22A31B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004FAF0E5D260150210E602F2361231E52100B6E38325B3833
55413E534443523F40502F354E1E254F141A56181D5D282A66404465484F685057675156
634B52695059674F5966515959454F4C39445F4E5777676C7B6A6D7D6A6D836C6F876F72
8C77798A797A8A7E7E908785908A8786837E84827E8A898482827B787A7273766F70746E
757B76727A766E7A76717E7A768280707D7B6976726A7673737E7C727C7C707C7C71827E
718582677C7A627677677A7E75878B83969885999A8095967C9295788D917F94997D9598
A0B7BBC5D9DEB7C9D08FA1AA8EA1AA9FB2B99DAEB39EADB2A3AAB0A0838E852837A51320
B40E15B80C13B20D12A11012B0363AC9555DA31C29A70C1AB10B15B40A12AC070EA40510
920811BC4B578C1220960A178C0C168328397A5174292E6907276F19448382ABD2B8D6EC
AEB8C97F5A6E7C152690061492020C91030D83071179253562416113184A06164F1B295A
5C577B6542596422326E0D1D7A06137E030E7C010B7700097702097401087101076D0005
6A00056901046301025802064C19202B293145616040635F4666624665614B6A65496864
4967644967634A686449656148656049686246656044635C425F56415B5616302E324A42
23A81F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0055B5125F28005A28155F271F560E0B560A07723B355F413C
54423F4F4040533E40512C335B2A325B293062373D59383E5F454E614B54634F56665357
6853596B555E6B545E69535B5B47514735405C4C5576676D7C6B6E7E696C836C6F877174
8D7A7B88797A8477798A817F827D7A888581817F7B88888493948E85877F72746C73746F
7276736C77755D6E6F4F64665B6F71687A7968767276817B6F79746B7473627070687B7A
667B7A647A7865797A6A7E8461787F7F969B7A90918296967B8F908BA0A2B3C7C98DA3A8
92AAAFAFC4CC9AABB48798A17F9298A3B6BCC9DADEBFCACF968D94874856901624AB0E19
B71116B30F16A0161B9C3E44C87D868A1C2BA40E1EAB0612B20912B10710AC0610A70912
920A0FBF4C57881320821221793146644E7A192A6A062B712B548C98BFE2B8D7E9C1D5E3
ABB2C1815A6C7F172794071591010B88040D7A1A26744D671818451A1F52443964633E5D
641F346F0C1E7A05137D010E7E000B7D010A7901087501087301057301077101066E0106
6D01066901036401025802064F1E271413223652593F6160456561486663456560466662
47666346656049686249666147645F47665F47656045645E4362593F5B52345249284135
337B2C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDC0B692F02612C1752140B580C08560A066B362E60413A
594340523F3D52393B4D23284A161E5B2F385E42475741485E4A52614E55604D52675558
6653586B555F6E55616B545E68525B523F4963555D73656B7D6C6F826D6F876F71877172
8A76788676778376768077747E7976888481817E7B8D8C8890908C878A8477797172746E
7076745D6A6D3C5357365056385257576D6F6A7A77717C766C76726D7A766D7D7C637777
667B7B6D8181677A815B74814562707892987B918F839696849799A3B6BCC4D7DF9AADB6
80959E7B8F989CABB3AFBDC599AAB0A4B7BCCADBE0C3C6CF946F7D821E2E9D0E1BAB0C16
AF0F169F131E9742547358749476907C1B2FA40D1BAC0611AE070EB20811AB060FA50710
920E13B14E5776293A8253723935680D286C083274507AAAACD0EBBBD7E8BDD5E0C2D5E0
ADB6C4866877791B2B8E08168E030E7D040C95485550314E503D61663B5B651B346F0A1E
7B051481030F84020C82010C7F020B7C01097601057100047102047102066E02066D0206
6E01066B01046701035703074F26300A0D1F2F4D5740636145645F48676244655F476962
4666604866614967614A686048665D4C676047645E46645D4565583F5E4E3D5D4D375443
44503B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00763B095E250F511007550E085D1F166F453A62463B
583E375238345639383E1518542A30573A4157444A57484B5544495F4E555B4A51604F53
69555B6B545F6B52606B505E6E5460705B6470606775666C7A6A6E7D6A6D826B6E80686B
857074806F718477768B817E867F7C8883818C89868B8A878E8F8A8B8D8781857E72746F
7277764C5B5E385056324F55355055546A6C68777777807E6D76736D7A7968797A677A7B
65787965797D6079832A4B5C4D6D7C7E969C98ABACBACCCF8EA0A584969C8A9CA580919B
7B8C958B9DA4C9D9E0C9D6DFC5D5DD96A7AFA9B7C0AB9FAB8C4658961523A50B15AF0F18
9D131C9B455B64517F1B306B6E6692792036A20E1CA80610AA050CAE0710AA0710A30A12
8C151EA062746152761D2C6507286E1D49857CA6CEB2D4ECBBD6E4BED5E1BDD3DEC1D4DF
BBC7D28C7D896F2836830A198F081483061096364283364B6D1B30730A1C7E051382020D
83010C83010B83010981010B7C010A7801077302056C01056703066208086C1818660A0D
6902066B010565020552060C4A2B39070F252F4F5B40646342625D47666146645F476760
45655E4B686349675F48685D49695E48655E4A666046645D446457405F513D5D4D375545
43533E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0082460E571B0452110754170D6F40366A4B415E473A
543B324F3831573D3A422929543D4050414754474E564A4E54464A5C4B525D4C53614F58
6A555F6D56617057637055626E555F715D6466565D5F515773666A79696D80696E7F656A
80676C837072867A7981777486807C8984838B88868E8E8A8E8F8A8D8D898788837F817B
7278745A6768334B4E314F52415C5D6074736C7A796F79786D77776C7979677778697A7C
6D7F826378813A5A6A284C5D6F8D98768D91899DA1A6BABF788C917F939886999EBACAD0
B5C4CC8E9FA7B0C2CBBDCED7B4C6CE8FA0A8A4ABB3A584918C2737A10D1AAA0E169F141E
8C33485D4877122B7313327A796C9880253A9D0C19A3050FA6050EA80811A4070F970811
8828385E466A112C64072F6D456FA19FC4E5B7D7EABBD5E3BCD4E0BCD3E0BCD1DEC0D3E1
C2D1DCA7A7B17F5662700F1D85041089040E83050F84061583041186020E86010B86000A
83010A83000883010980020D7B010B7301086B04085D060C591A2060363A82565A5D131A
6603086B010661030456151E35223704142D33556044656543615C46625D43615A4A6863
4B68634D68634A666048675F44655B46655F46645F42605B43625A426057405C513D574B
4254410ECE0900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF008E4E135416004F10035F251A65362E603E355F463C
58413855423D5444424D3F404E414451434A54454D55474F58494F5D4C505F4E5468545D
6D535D6B4D58745863715A636E5A616B5A605D505652464D73676C7C6D71826B70785E63
6E55597E696C8677777F757288817D8883808C8A868686818989868F8E8C91918E898B86
787C756D76715667645367666C7F7E6976746F7C796D7978727C7E68757764737765777B
667B814B687A10365062849799B4BA748A8D778D91768D9289A0A381959A8CA0A6C6D9E0
C6D9E1899BA682949F93A5AFB5C9D0BAC9CFACABB2A87480931A28AA0E199A10188D3748
675078192C6C23377C605890905C7C891C2EA10E1AA50914A30610A40812A007108F0A15
8539512A275A0F397374A2CBB2D4EBBCD4E4BFD7E1BFD4E0BCD3DFBBD2DDBFD3DFC0D2E0
C1D2E0B2B9C6977E8C7C293784061389010C87010989010B88010B860009870008870109
84010982000981010A7D020C74030B64070D5E1A235933423C30452F293C603E4C590A16
6802076B03075A060A582D3B14112D0B223B40616A47646645626049636047625E4D6764
4E68644B64604B66614A676248665E44625D43625C42615B44625C45605C425A533E574B
4357421FA11500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006C7A0F55170055190A5B1F13581C1466332C57322A
5C413C55433F4C413F493E3F4D3F4454434C56454E5746505B49525F4C5265505570525A
73475056262F79545C725B606F5D626E5E6465575D52454D6D61667C6D717E676C755B5F
6A515476616483747689807E87817E827E7A87848083847D8586818E8D8B999A988C8F8D
828682727773767E7A7D8683747E797B82807A8483737E7F707C7E67757760717364767B
5D76841B3F5C1943605F818E6F8A8C768D8F788F927C9295C2D6DAB6C8CF7B8F988FA6AE
8EA4AB8497A07789958C9EAAC6DAE2CAD8DEB6ADB69954619F1A28A9131E972B357E576E
333762605C8D7A4F79742341A33A4D981724A30D17A60B16A60C179C050F9A0812870F1C
7A42601621582B5889ADD7EEBAD5E0C2D6DFC0D4DCC2D5DDBED2DDBFD2DEBED2DDBED1DC
C3D4E09CA0AE7855677417288706148A020D86010986010A850109860107830006830107
82010880030B78050C69070F621A23663D4D4436501B2040202444533C56541224670510
6B02066105085B202A37263F0411321C3B5240656A47656445625F49656347635F4D6965
4965614966614A68624866614A686047655D46645D44625D46635E47615D445D553C584B
3C543F22A71A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A2095418005923125A1B105C140C65251E4E211A
61433D53413E4D403F4E40415242475A484F56444C5B4852634B56684B5369434B713F47
69262F6A262D815258765B616F5D626F5F656C5C6262535966575C7B696E735B60705459
674D507460627F7072817776837D7A817C7A807C787E7C767A7A758383807C7C7C6A6E70
686E6E6A716E777F7999A09EB1BAB9B2BCBB98A2A3727F81707F806D7E7D6D8180637880
3E5B76072C534A708B6A888F6E868593A7A77D91947D9295AFC3C8A1B1B9788A93798C93
B3C6CCC7D9DFA8BAC3798D97A5BBC3B6C6CCBBB0B98B404DA11925A20F1AB84C5AA3667D
8D58748A37518E192C92101EBF424E9A131F9F0914A007149C05119B0712940A147E1829
64456A0A255D527FA7B6DAEABDD5DCC0D4DCC0D4DCC1D5DCBFD2DBC0D2DDBED1DCBFD2DC
C1D3DBA3A7B379526176132487051386010B8401098401098401098500088201097E0209
7A040D6F0912691E296B3F51483B571A21470D1944302F5452344D550E216805116C0208
6004075A1C22452F430B103503193B3357684166674767634A68644A6965466560486862
47666149686249696348686148676048675F43625A47655E43615A44625B405F533A5A4A
3D5843337A2700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BAA10581F015C281650130859160D6A3128633C33
5D423C543F3C51404055434756454B5A474D5C464F624650663E49622D37672B347C3840
76242C7B2C33845057785C6374636A7263686D5F636B5E626E60666E5D62735D62694F53
6F55597762657D6E6E7B716F7E757379716F7F797578746E76766F7F807A8485827E8181
7C8482616C67A9B4B1C7D2D4C1CDD3B9C7CCC5D3D7A7B4B86C7B7E697A7A687C7F5A7585
103257133A605C7D906B83877C9191C5DADA9FB1B5778A90768A9097A9AFA9B9BF82939A
B3C5CDC6DAE3A8BDC68EA4AE839CA394A8AEBAB3BB9655619A1B27AA121EA41A279C2332
9519289E18249C151D931C23C7546097111F9E09169D0814990511980712870914833950
37305F072B6385B0D1B8D7E3BFD5DDBFD4DEBDD3DBBED4DBBED3DBC0D3DCBFD2DABED0DA
BDD0D8A7B0BD7D61706D142484051488030F84020B84010A86020A83010B7E040D710811
6918276C3E515142611D234E0818481C26534C3F62582840600D1D6B040F6D030A5E0509
5920274A35490C143502163C1E3E5545686F4768654967624B6A6448676345666045655F
47686249686347676248686247666048676141615A44615B46645C426157405F513F5C4D
3D5544434C3500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0054B415602704511D0A4E160A5D291E6941375E4239
5C453E55423C53424157444958464C5C454B623F47602F39672D3768252E76343B813D42
711F26792A32854F57795D65715E677162687063676D60657063686E5E627A666B7D676B
70595E776366807170796E6C786E6C746B69736C6873726A77796E8A8C82878983888C88
868D89939F9AC6D1D3B8C1CB7C889174818A819095C6D4D87F8B906F7C8060737E294564
0327533055758EA9B47A8E92788D91859B9E72868A71848A778B90BFD3D7C8D9DFA6B8C1
798E9A7A919B88A0A89AB1B990A7ADB5C7CEC0C5CCAE8D94852A349B1720A5171FA01822
90141E8B252F964B55BB7B859D435191101F96071293050F91040D940B147C11207D5274
14235C1A4377A7D0E8BAD4DFC1D5DDBED5DEBBD3DCBED6DFBED4DEBED3DDBDD3DABCD2DA
BDD0D9AEBBC875647466182A81091785010E83020D83010C7F030C7406106A16216C394C
523F611F2654061C4F041E502B39634E395755142868091672040E6D040C5C09105A2935
40334C0B133A01173F1939543F646C4A6A684A68634C68644A6964476761466862466661
4667614B69644B69644A686348676244645F41615B46645E45635C436158446156405C4F
3F584747533D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059B8156C30064911024E1C0E67403262453A5C443B
5D473F56443D5745455A474B5E464C643D445E222A5F151E732B3465222A74353C7F4247
6C292F6C2F3480575D765E666F5F677060696B5E626E62656D606574666A79696C7B686B
7D686B7E6A6C7B6B6C796C6C736967716865726D677A7971777A72848880848983878C88
89938FB4BFBEC8D2D8858E987A838A798386667476B9C7CC818D9564727D465C73082551
0B2F5A51738BA1B9C184969C74888D7B9193A6BBBDB3C5C97B8E9599AEB5ADC1CA8399A2
748A948499A2C4D9DFC5D9DFB5C9D29AB1BDACC3CFA4AAB1B39498915056934853955568
855B776C5F833F42668A728F7722388C0C1A8F071088030C8C060D8A0C187D2F46463C6C
0728655984AEB5D9EAC0D6E0C3D6DEC2D6E0BED5DEBED3DEBCD2DDBBD1DCBED3DCBDD3DB
BAD1D8BACAD57368775E1C2D7708167E020D7A040D7408116C1823713C50554160232955
091D54031E552E4F7A7C9BBA70778E4F21356208156F050D67080E5C17205C38492E2849
071643011B451B3D5A4165714767684B68654966614A66624A6963496A644A6A644A6965
4968654A676446656046666043655F45666141645E40625B42635B4361584260553D5C4F
3E5A4943523A0FCF0800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00733408491503572D1B654634644C3D5E473B
5E48415C45425B434461424764384065273161111B620D15752A306423296B31387C4A50
754C5279585D77606577676D6E5F6770606972646970646870646872676B786A6E806E72
7965687B6668826F707C6F6E726965746D6878736D7D7A767D7E7A8488838A8F8A878E8D
7B8788B3C0C4C4D0D7727E84737D7E6F7A76697875BBC9CC67777F566A7C1A375C082F61
1F466B54758361787D687A807183876C8185BDD3D7C3D7DD8B9EA583979F7F929AA5B9BF
9AAEB48A9EA5C3D6DEC6D8E2AAC1CC7494A83E657CAECBD8C0CBD0A9A6B270749238487F
1839780E39783A52867E597C7E172C8E0A15900A128A050C8C09117B142360365C132460
0F3B719AC3DFBAD7E3C1D6E0C2D6DEC2D5DFC0D4DDC0D4DEBCD3DABDD3DABFD3DCBDD3DC
BBD2DABFCEDA7F77855E25366B0B176C071161111E683448584362282C5B081D5604225A
2D4E7D5070937E9EB593AFBC777E8B552D3A570C1559121B653847493A56161E47041747
05224E204760456D764A6A6C4F6B6A526C684B69634B68634B69644B69644968624C6A66
4A696549676347676245686245686245676142645D3F615A42635B426359426256415F54
425E4E47564121A11400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF007B400E4D1F075D3B25624732614B385C4639
5F46406044435E3A3D67373D5E1F276D20276A151C641118753538703F42744A5176555D
735B62715E6371616676696E72636A72626873636874636870626574666A7A6B6F826C71
85686D8764687C5B5D806C69746B64756F6878746F7F7D7A8888848C8E898A8D8A6B7474
727F81A3B2B6C5D5D9839495707F7D6D7A7795A3A2A0B1B5586C793A53700321540D3366
3D658058757E6E8488AFC2C6BECFD5758991788D9683979F8799A07E8F9696A9AFC5DADF
C4D7DF8B9FA78DA1AA93A7B0A1B6BF93B0BF65899DB8D6E8C4DAE7ADC4DA3B5D8F053282
1247945E8ABD9995B682374D8D10219108139911188F0911850F1B854259302B5C072966
5886AEB3D7E9BED6E2C1D5DFC1D5DEC1D5DDC2D6DEBED5DDBCD3DABFD6DDBED3DDBBD0DB
BED3DEC1D0DD85859354303F551A255E2E3E493552222652071A53021F5A0C3063355A80
7EA2B8698998627E8A829CA487959B564A53563B4652415622274D051A49011B4B0E2D54
3B5F74456C724B716F4B6A684D6A674C69644B69634D69644F6B674C69654968624F6D69
4C6A664B6A65496A6345676145665F46655E45655D46655F43645D3F6158436259425D55
445F5346594923A51A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00824811582F0F5C3E275F4731604B385E4639
66473F693F3F572023652229671B2372232969191D5C171A6B3C3E68494D735A62715A63
6E5C6471616A74656A76656B7D6B726F5D64725E6576626874616877636982676D845C63
8249516E2F357946497F6462786D677F7A747F7D7981807C8586808C8E888D928D898F8D
8E98998B989BB7C7CCB9CCCFA0B1B2ABBBBCA4B3B7687983556D81142E5A011957153663
5C7C8C657F83667E82A5BABFA9BBC2687B82667A808FA3A8C4D6DAB4C4CB7C919AA3BDC5
A1B7BF8B9FA772878FA6BDC3C7DCE1C6D9E2ACC6D891B4D283A9CB94B7D8254C7F03317D
1B4D8D96ACCD9564798D1B2B9F111E970A14940A148A101C7A293D553E660C245D1E4979
A3CBE3BAD6E0C2D6DEC1D4DFC1D5DFC3D6DFC0D3DCC0D4DDBCD2DABED3DCBDD3DDBCD0DC
BCD0DBC2D3E08F99A665616C685F6A343755071A4C011D58072C5F264E72466F8851788A
6C909B98B8C256747F9EBCC4A1B9BF67757D7D8997142844021C480A29542B4D6B4C6F80
5272785070704D6C6A4F6D6C4F6D6C4A68674A68654F69674F69664D6A664C6B654F6C6A
4F6C694C6B664C6B6547676147676148676246645F46645F43625C426058426058445F57
405D52475F5023A91F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008B54145B320D5A3D255B46325E4A385F4337
643A33652829681D2164151A61141B662024652B2C6A3F41684C5065515769575F6E5D66
6E5E686E5F6874646A77656B78656D78646D746067785F677D5C65785157824E54773239
80292F822E307D41418468647A6E697E77747E7B7781817D8688828B8E88898F8A8D928F
8F96958F989B889298919BA397A2A9818D936A787E5E6F7B3C5271031B540018582C4D73
98B6C29BB2B75F777D5A73786B808584989B6D82859CB2B6C5D9E0B9CBD5748994748F96
A4BCC2BFD3D9A0B6BC9AB1B8BED4DBC0D3DF97B1CB224C7F0F457F8BB8DE8CB0D042638F
738DB2A892AB8A2D419E13209D0B14970A128A0C16751E2F75577915245E0B2F6884ABCC
BAD8E4C2D7DEC3D6DCC2D5DDC2D5DDC2D4DDC3D6DEC2D3DCC2D4DCC1D4DBBED2DBBED2DD
BCD1DCBFD0DDA1B2BD99A7AFBECED74257740E2B5B1A40742D5B82608CA180A7B820475C
7196A8ACCBD77D9DA875949F9FBBC37D959C637B85314D6036546B4C6C7F688892617F84
5673754E6C6B4B6A68516F704D6B6B4B68694A68684C68674A66634A68634F6E684F6D6C
5370715572704A686547666348676146635F46625E43605C46635F446159436056466156
405C50486053434B3800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF006B830F5F390D5C3E255E4432644939633D32
581C176E212069191A661C1F5C20226B3D406C4B50654F5462515665545C6959636C5D67
6A5C6671626B77666D7B666E7D666E7C636D7A586381535E73363F752A32802F347D2427
862727781F1E8747478264627B6E6B8177767F7B797F817C868A848F948E8A908A8F9590
8F95918C9292898E9073787B70767A6B7478626E74596B7F182F5C011D5D05265E416381
69858F6A808563787D5D747698AEB0C3D8DAB0C4C96D848C91A6AE92A5AD8C9EA6758B91
BBD2D8C5DAE1B3C8D195AEBB91AEBEA3BDCBB0CBDF3C608A2A5C8E9CC8E9BDD9ECA6B5C7
B9AEBF964F629C1B2CA50F1B9D0C13910F187A1E2D6744631C2A5F082B666088B1B8D8EA
C0D8DFC3D6DCC0D4DAC2D7DDC2D7DEC6D8DFC4D5DDC4D6DFC2D4DCC0D3DABFD2DBBED3DE
BCD1DCBCD1DBBCD1DABED1D8BCD0D8AAC0D07F9DBA133762012754527A999BC1D52F546B
42687B84A5B2809DA85D798468838B839CA1647F847A949CA1BDC5658188849FA385A0A2
5773734E6C6B4E6E6B4F6D6C52706F4E6B6A4C6A674A68654A68634C6C6751706D4C6B6A
4D6C6C4C6B6A49686549676449676446645F45635D44625D45625D49645E466158476157
445F54485F5449524200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049AF0D653E0E5E40246144326842365E261D
5E130C6815116015105E24226A4346684F556352595F52595E515761535C655862695C67
6C606A6D5F6877626B80616B87626D8658646C2E3C8134416C151E7A1F2472181B893333
7E2C2A6A1F1E672F2F7B5D5C7B6E6B79726F767470797C768689838D918B8E948D8F9790
8F98918F9791888F8A797F7A707774737D7D65737D394D6D031C56092B6D264E7C4E7183
5C767A6F838396A8A8677A7D889CA2BBD0D69BAFB67488908B9FA5C3D5DAC7D8DE98ABB4
8CA3ACA1B6BF94A9B47B96A731576C88AEBFC3DBE8B6D0E685ADD075A2CB87AAC9B0B2C5
A87383942133A81320A50D1796111B781B2C775474202E62052C6548729CB3D8EBBCD8E2
C0D7DEC2D8DDC1D8DCC3D8DFC2D8DEC2D6DDC2D5DDC1D3DDC1D3DCBFD3DCBBD3DABAD1DB
BBD2DBBDD1DABDD1D9BDD1DABAD0D7B7CDD7ABC5D55B779605274F244B6D739AB07699A9
4F727F50727D8AA8B07E9AA279959BAAC7CC98B3B9728B93A3BCC37B939A637B81647D81
5B7477536D6F51706D506F6D506F6E4E6B694D6B664C6B664A6A664C6D6A4B6C6A496B68
496C694C6C6A4C6C694A686647656347656244625D47666148676149645E466159476157
476157475D524C574800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B41269400D5B3E205F402D5E2E21540E05
64130A63160E682D26603B36634A4C63535A61555D5A4F565F535A62535C6758626F606A
70606A735C6779545F6C37436C2D387E333F832B387A1E29791F24731F2068201F8D524F
82514F774A497A56547B64627C716E77736F7A7A747E817A8789838D908B8C918C8B928B
909991909991919A93828883757C796D7777637280192F59021A5D001F5E2F54775E7C86
667C7DA5B6B7C8D9DC8899A06A7D85768A919EB3B7A4B8BD93A5ADC0D1DAC1D2DB91A5B0
7E95A08A9FA7BED2DBBED5E293B1C1A6C5D3BFD5E2B1C9DE4066910A3C7A436494B59FB9
943345A81425AD0F1C9D131F8326396443671E2D62072E69416D97AED2E8BEDAE3C0D9E0
BFD7DEC1D8E0C2D9DEC3D7DEC2D6DDC2D6DEC1D5DFC1D3DEC2D4DEBFD4DDBAD3DABAD3DD
BBD4DBBFD3DBBFD3DBBCD2DCB9D1DAB8D1DAA7C3CD7795A95F809A4269844A728696B7C5
789AA8436777A7C8D5A1BECB6B899594B1BB96B1BC627D87667F8663777E5E73795D747A
64797E5D7577567371506E6E4F6F6E52706E506E6A4B69664A6A664C6B694C6C6A476965
4A6A654D6C6A4B6A674665644B696647646147646045625E48676147655F47635A49645B
466257455E524A594A209F1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0055B914693E095F4020633F2B5C2317590C03
66170D6121186D453C634D485F4E5062565B61575F5D525B60535C64545E6A5761755C66
7B586480535E6025317E3D457A3339701D24923D44691B217C393E743F407F5756866967
826A6A735E5F715E5D7F706E7E74717C79757F817B898D85878A838E908C8A8E898E948E
979F979099918D9491858B897379776B75794B5C74021A4F00175C06265A52748B93ACB1
70828676888E93A5AD68798067797F798D92C4D9DDC4D9DF9FB2BC8699A483969E95AAB1
7D929991A8AFC5DAE1C4D7E1BACFDC99B4C880A1BEABCDEA51769E1E43759D9FC6965068
A41E2EAE1321A218269239516447721B2C6A052D6A45709CAED1E9C0DAE7C3D7E0C4D8E0
C2D7E0C2D7E0C1D7DDC4D8E0C2D8DFC0D5DFC0D5E0C2D6DFC2D5DEBED3DCBAD4DBB7D2DB
B9D5DBB9D3DBBAD3DDB8D2DCB4D1DBB5D0DAB0CCD759778A88A8C2224266214569A0C4DA
799DAF254A607091A692AEC064808F55728069868F6581875A767999B1B373898C6A8287
9EB5B962797E5A7675547170506F6D516E6C4F6E6A4A6866496865496865496966466661
4969634E6D6A4D6B6B4A686848686447656046635F48656043615C47666046655E47625C
456259445F554B5C4E25A61E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00704209613B1B582A17602215570D04
6621186F3B316C4A43644E4A5D4B4C5F51555D52595C515A62545E64525E6E5461693E4A
612330752A386F242F8042478B55575C1F238E515679484D8562667C6468817072817375
78696C79676A7968698477768076747C79757F807A878B838689828D8F8A9195908C928D
929B938F99918F9995888F8E747C7C6A768122385D021D5C001A5D12325E628292B9D0D5
74868C61747A6A7E83B4C7C9A9BBBF6B7F859EB5BCA4BBC5859BA5778C93A8BCC1C6D8DD
BDCED491A5ADA6BDC4ADC2CBA9C0CF4C6D8E1646728DB6D7B6D1E8A3A5C0A9738C982236
A91A289C2231A45D78615284162F740A35785582AFB4D7EDC1D9E6C4D8E3C6D8E2C7D9E3
C3D7DFC4D8E1C4D8DFC5D8E1C3D6E0C1D5DFC3D7E1C0D5DEC0D5DDBED4DDBED7DEBAD4DC
B7D2DAB7D4DBB6D3DDB5D1DCB6D4DDB7D1DBB6D0E036536E88A9CB173662022654507895
84A9B95577884E6D7E65818E7A95A0597680A1BDC3A4BFC4647F84A1BDC09DB7BA657E84
70878D637B7F5D7877587572516E6C53706C52716D4D6C68486764476764466863486863
4668624A69664967684A69684969654A69634A67614A666247645F47655F48676046625E
46625A486359495E4E367B2A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007C490B5D300C59230E602011601F15
743931632E266C403953312F634C4E6252556054595C4F57634F5B634856714C59612D39
813F4B64162280353F6F3A40815C6075515683616680666B7C6B707A6D727F747982767B
796A6E7B686B7A686A7D71707D74727A767182827D898A84888A858E908C9395928A8F8A
8F98908D98928895918590907A858A57677E061F53001E64103572254C6E5C7B86677E81
6D80856C7F827C9195C5D9DDBCD0D66B818768818886A0A6B3C8CE9EB0B7A2B4BBC4D5DD
B3C5CD9BB1BC8CA6B1AEC8D3C4DBE892ADC6507797ABC9E0C7C8D7B4859A8F2A40971F33
9A3E53956A91414983103179164281729CC6B9D9EEC3DBE4C3D9E1C5D8E2C6D9E0C4D7DF
C5D9E0C6D9E1C6D9E0C6D8E2C7D8E2C5D6E0C4D6DEC2D5DFBED4DCBED6DCBFD7DDBED7DD
BBD5DCB9D4DBBAD6DEB8D3DEB6D3DBB7D0D9B9D3E33E5E7B3D64865378982F5473456982
6586948BA9B55172808DACB8AECAD4849FA98CA8B2ABC3CE70899369858D6C878E667D84
6981866A8284617B7D5A777459767457737153706E506F6C4B6A66476764496B66486864
4969644B6A664A69684969684969654B6A654B68624C686447645F4A686048665E45625B
46655A476457455C4E49503D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008750105E2D08622E175A23127D4438
692D246122186F372E562E2B654C4E665457665358684F58603B48693B47703C475E2E38
82535C531F26774449724D51795F657F686D7D676E7B686F76686F7A6E747F747A85797F
87777C7F6D707564667D6E7080777576726F82817F8988878C8C8B8A8C8A8D908D929692
9198938F9B948C9A958491917B8A942E4267031B5D021E6B0F3671476E88628084708585
BACDCFB5C8CA6A8085869EA47B939867808360787CA9C0C5C6D8E0BCCDD597A8B09FB2B9
A4B7BFA8BEC95E7986ADC8D6C3DBE5C4D8E3A8BCC8ACB4C0B59AA8833E4F944051B77F98
696092203E880B3E8632629999C1E2BDDCECC3DBE3C7DAE0C3D7DEC5D8E2C5D9E1C5D8DF
C4D8DFC6DCE3C5DAE2C6D8E2C6D8E1C6D9E3C6D8E1C3D6DFC0D6DEC1D7DEBED4DCBED5DE
BCD5DDBAD4DDBAD3DEB8D3DFB7D4DCBAD4DDBDD4E27492A9466D885B859B84A9C13B5F7B
7B9DB2ADCBDB36586C6185989EBDCB86A3AE5D7A8569858F6A828B5D7880819CA38BA2A8
6D858AA1B9BF6E878B5D797A597675597475546F70516E6D4D6B6A4C6B694A6969496868
4A69674968644767644969684A69664B6A654A68634967634A686347635E4A675F46645A
446458426055465F5249534300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009254185C250764311C6935246A3023
632014601A0F6931266C4B43614E4D6750526A464C5F2C355F212C733038601F265D2930
79555B65494D6D5254755E6176646978676E7B687079687171636B796D737E74797F737A
87777E8473777C6C6F7C6D6F796E6E817A7A817E807E7E808687858C908B8B908C929894
939A97939D98939F9C8A97987486980E2656031A650018660C2C606A8A9C7F97998FA3A3
BDD2D5AFC3C96A808660797EA0B7BABFD4D591A3A88DA0A7B1C4CCA0B2B998AAB298ABB1
C5D8DFC8DBE3AFC4D09EB5C2ACC5D1AFC4CDAEBEC6B4B8C08C7981AF8B95C7B4C86A79A9
103C8D084299548EC7AED9F2C0DEE9C4DDE4C6DAE2C9DAE3C8DAE2C7D9E2C5D7E0C5D8E0
C3DAE0C1DBE3C4DCE4C6DBE3C5D9E0C4D8E1C1D7E1C2D9E2C0D6E0C3D5E0C3D7E1BED4DE
BBD4DEBDD5E1BCD3DFB9D2DEB8D3DEB9D1DBBDD3DF94ADC31B40615E89A7577E9F012552
3A60829ABCD17798AA5174845F808C77949E6A878F88A5ACA9C3C978929A8BA6AEAEC4CE
768F977992996E898D5F7B7E597776587574567172506C6E516D6F4D6A6C4966684C696A
4E6D6A4D6C68496A654969664968644B6B644868624B6A654F6A674D686249675D47655C
48675D44615A4760554A5A4A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003E9D04571B02622C186F3928622113
71251C62170F642C246B4C4668514F633F42652C33702B3362171F671F2766272D5C2F36
6C515768565A66555A6D5B6273636A75666C7B6B7177676E6E6166776D737E747A7C7178
81747A7D6C727C6B6E7E6F707C6F6F817877807B7C8382838788868E918C8D938D898F8C
8C9391939C99919A998B979E51658205215D021B6A001A631F3F6BABC8D7A1B5BA8A9CA1
8A9EA47C9096889CA15D7579B7CED2C3D7DCA9BBC18EA0A88EA2A8BBCDD3BDCED59EAFB9
BDCED7C1D3DBB1C7D692B0C5668CA498BACAABC0C8B5C3C9BCC5CCC8D4E57E9DC20F448B
0440A30747A27FB8E9B9DEECC2DCE2C3DAE0C7DBE4C9DAE3C7D9E0C8D9E1C6D9E0C5D8E0
C1D8DEC3DCE4C3DAE2C4DBE2C6DCE2C4D9E4C0D6E1C3DBE4BFD6DFC1D6E1C2D8E1BFD6DE
BDD5DEBFD4DFBED3DFBBD3DEBAD3DFBCD2DDBED3E0A5BCD60B2D591B46716F9ABC14385E
446A885A7E8F86A5B06F8E9973929BAFCCD599B7C085A2ACAEC8D28CA6AF69848D7A949D
69848A637F836581836580815B7777557272567373526C70526E71516C6D4D68674B6867
4C6A674C6A674667624766644968624A6A634B6B644D6C664F6D694A676246655E47655E
47645C47615B4962574A5D4C1EA01600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0047A70C5B210168311B5C200F6F271B
64170E6320176839316D4D49674244682F35641D246D252A66242A5B262D714B53684F56
65555C675A5F64545D6D5A6474626B77676E7A6A717B6B7177696F7F757C7D727A7D7179
83757B806F737C6A6E7B6B6D796C6C8076757F7A787F7E7B8889868F938E8E948E8E9591
969D9A979E9A959D9E92A0AF28406D04236B001E6D00206033557B84A0B07F959C75888E
768A90B4C6CBC7D8DE8CA1A871899292AAB08FA3A7889AA091A5AAC8DAE0C9D9E2A9B7C3
ACBBC5ACBDC5B7CEDC5B7D942B58739DC1D4B8CFD7BED4E0A2C3DD699BC75B97CB4283C5
04469F03489F629CCFBBE0F0C4DEE4C4DCE2C6DBE4CBDDE4C8DAE1C7D9E0C7D9E0C6D8E1
C6D9E0C8DCE4C9DDE5C6DBE2C6DAE1C5DAE3C4D9E3C4D9E2C2D9E0C2D9E3C1D8E0C3DAE1
C1D8DFC3D6DFC2D6E1BFD5E0BDD5DEBED4DDBED3DEB5CEE21E42661E4C75527F9A7CA1B6
7CA0B66B8FA1B1D1DF93B2C3698B9CA6C5D49CB9C667839276929D6E899265808769858A
749093617D7E839D9F708A8C647E825F7B7E577575526E70526F70506D6C4F6E694E6B66
4D6B684C6A674868634B6A664A69644D6A654E6C664D6B654D6C674A696547666146635E
46615A476159435E53485D4C20A31800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004BAC0D5F2604612713601C0F71251A
5F1B10703C32734C456D44446A3236661E256E21277433376B3D426F515A68565F655961
62585F6559616B5A646F5D6675636C7969707868707A6A727F6F76806F767F6B73836E74
70585B8C7276826B6E7E6B6C7B6D6C817776827B7985817E8585828B8E8C888D8B8D9290
929795999F9C959EA37688A30B28640221740F3384163E7A476A8A58748072888D8A9CA2
6B7E85A2B7BEBFD4DC8DA2AB7289938AA3A8C4D9DDBFD3D9889EA6A4B8BFADBEC697A7B1
9FB1BBB9CBD4C7DCE4BCD6E1A2C0CEB2D1DEB9D5E1B6D6EE467AB00B59A62A79BB91CDF5
467AB14984BE98CCF3BDE1EFC6E0E6C9DFE4CBDEE4CCDDE4CADAE1C8DAE2C6D9E0C4D8E1
C8DCE3C9DDE4C9DDE4C9DBE2CCDFE6C8DCE3C6DBE3C6DCE4C4DBE1C2D9E2C2D9E1C2D9E1
C0D7DEC2D7E1C0D6E2BFD7E1BDD6DFBED4DEBED4DFBAD3E47FA5C24778A05888A9A7CFEA
406A8D39668AA1C8E17293AB57788E6C8A9C77929F6A86937590999EB6BD77929786A5A9
ADC9CE748D907E999E728E936380845F7D7F5C7B7B5471714E6C6B4C6C694D6F6A4E6C69
4C69664A69654B6B674C6B664A6B654B6A654E6C664F6C674D6C6749696546656043615B
405F58436058436056465B4C25A71D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0055B512682D03541606671F15611D11
70382C71423A70403C6227276722246723255C21246B41446A4E5466555E635660685D67
695F686B5E676D5E6871606872616978676F7B6871826B7485656F845863693D46946F76
67464A8462657C5B5D715857847471847C7988827F87838081817E868886868A898D9291
909896939A9B8F99A44A5F8704206A001F780124770F366F597B93627C83AEC2C7C7D9DF
869AA369828D6E8A919BB3B994ABB0829CA2C2DBE3B7D0D87F99A092AAAFAFC4C7C0D4D8
A3B9C0B1C5CDC9DAE1CCDFE5C4E0EB8DBCD782BBDFACDFFC4F89C01764AE468CC1BCE5FD
D2F2FFA3D5EF80B8DABFE5F3CCE3E9CFE1E7CCDDE5D1E1E8CDDDE4CADCE4C4DAE0C2DAE0
C6DEE3C7DCE3CBDEE4CADDE4C9DCE4C8DCE4C6DDE4C5DBE4C6DCE2C6DBE3C4DAE1C3DAE1
C1D8E0C0D6E1C0D6E3BED5E1BDD6E1BED6E1BDD4E0BCD4E96A8EB60A397B1A4C888EBEE7
15436C1E4D756C95AF7191A56D8A9B7B95A3A7C0CB92ADB78FA8B1B6CAD298B3BA7A98A0
9EBBC27893996A858B668287617D815F7D7F5E7D7C58777553736E52726E4F706C50706D
506E6B4B69684B6A674C6C674E6C674A68644D6C674B6A654C69664B6A6548676242625C
3F60593F5F57416055455C4D474D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0A7336065A190756130A753B32
78483F612F266C30296F2D2863221F71403E6E4E4F6C585C64565D6659616A5E676D626C
6A5F6971656F70626C70616A7661697D606B835D69814F5A7A37447C293770212D7E494F
805C607A55587B575A8167697C6C6B807876817E7A8484818282818A8B8A878A89858C8C
8B9494939B9E8E9BAE1F376A022071011E790122702549797A98AA627981879DA5A1B7C0
647A87637D897B989FC2DCE0C4DAE279929D738F9A7E99A094ACB1A7BDC1C0D4D6C9DCE0
C9D9DFCAD9DFC9D8E0D0E3EEC0E1F44383B22B7AB291C9E8B9E0F9A8D1EBC9F1FDDAF9FF
D2F5FF7BB5D775B6DAC7ECFBD4E6EED4E4EBD1E2E9D2E3EAD0E1E8CFDFE7C6DAE1C4DAE0
C9E1E5CBDEE5CDE0E6CBDEE5C7DBE2C5DBE4C7DDE5C7DBE4C7DCE4C9DDE4C7DBE3C6DBE3
C2D9E1C2D7E3C2D6E3C2D5E2C0D6E2BFD7E3BDD4E1BED6EB6082B00535810A4188659AC5
6F9AB7638BA57C9FB2ADCAD8A3BBC988A0ADB4CED8A9C3CE7F98A59EB6C18BA5AE738F97
789299768E936E898D7F9BA0698387647F82637F815D7C7B57777454747153756F52736F
4D6D694D6C684C6B674F6D68506E694D6A664B6A644C6B664E6C684D6B674D6B66486762
46666045645C47655A435D4E48534000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783A085417015D2317744139
69332B62231B6D2F256A342C673B366B4D4D69585C65596163575F61555D665B636A5F69
6C616A6E606972616B765F677A525D7738467626348D354083212F811221730D168B484E
7F585C7352548C7073897476786A6A7F767376726E7574728486858C8F8F8A8E9082898A
8B96968D9BA07287A107246102217700207A00226E5478A3BBD7E87D959C5C767E607A82
A3BAC38DA5AF748D97B5CFD7A6C0C96E899490AAB2B7CED4C9DDE2C1D2D6D0DFE1D3DFE2
DDE9EDE9FAFFBBD2E1C6E0F0C7E4F595C0E1A4D4F1D9F7FFF1FEFFF4FFFFCADEE6ABC7D4
B6D8E7B3DDF2B2DBF1D7EFFADFECF4DCE8EFDAEAEFD7E8EED3E4EAD2E2E9CDDFE6CBDEE5
D0E2E9CFE0E8CCDFE6C9DDE5CADEE5CBDEE8C8DCE5C7DBE5C5DBE5C4D8E2C7DAE7C5DAE5
C1D7E1C5D9E4C5D7E3C3D6E2BFD5E0BFD7E3BED5E2BFD6E690B0CE3C679C4B7EB574A4C8
A9D0E88BB3CF81A8C1B5D2E29FB7C8809BAC96B2C08FA9B77A94A0829DA68DA8AE7A9298
9FB7BCA3BBC1748F95A1BCC47B969C6D868B6B8588708C8D6381815C7A7A597775567570
55757054726F52726E506F6B4F6E684D69654F6C674D6C674C6B684C69664E69664D6865
48656047645B47655844605247574600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C3D0E531903643122723C2E
5A190F611B1061291D7A554B71585465535561555A5F555C5F565C60555C61565F655961
6C5B63745B667D5B656F3F4A75313D701420780D199328338518247E0A147B1119914A50
724C4F7C61628A7575837473796E6C827A767D78747473707B7C7D86898A8D9192899191
8B96968E9FA7435F8104256B00237B072E87002670547AA584A2B2748C92647D8287A0A5
C4DAE1BBD0D98096A28099A290A9B0A9C1C7ACC1C8C3D8DDCCDDE1D4E1E2EFF6F6F2F7F9
E3EAEFCEDFEAADC5D3D6EDF5E4F3F9EFFCFFF4FFFFF5FFFFF0FCFDF4FEFFEFFAFEF1FFFF
EFFDFFF3FFFFECF9FCDFEBF3DFEAF1DEEBF2D7E5EAD4E5ECD4E7EBD4E6E9D2E3E8CFE1E8
D0E1E9D0E2EACADDE4CADEE6CADDE4CBDCE5CADDE6C7DBE6C3D9E4C4D7E4C5D8E5C1D7E4
C1D8E4C3D9E5C4D7E2C3D6E4BFD5E0C0D5E1BED4E0BBD2DEABC7DB9AC0E74F80B673A3CE
9CC6E82150785080A49CBDD498B3C692ABBD94AEBC9DB5C28BA4ADA3BEC6B2CBD188A0A8
A4BEC6A9C2CA7D959E7E969E778F946F888B748D8E7C9596748E90647E7F607B7C5F7B78
587674567474567676537271506F6B4D6B664E6C674A69644D6A674E6A66516B694D6864
4D686149655C486659456255465A491E9E1400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008246145621086331205B2114
5E1A0C6225155F3527735D53695A5862555860545A60555B5D53585C52595D515964545D
70565F724954672D387C374281313C7918218A2028962F3687252C76171D8D3E43835054
836769816E6F8474758174737F7573837A797F7B797B7A787B7C7C868A8A8A8F8E8C9493
8D96988B9BAC1D396B02237601248217419C012B715D85A97F9BA6ABBFC29AAEB47C919B
ADC3D09EB4C194AAB69BB2BBBBD0D6CCDEE4CDDDE2DEECEFE3ECEFF2F8FAF9FCFDFBFDFE
E6EBEEDBE4EAF2FCFEF8FEFFFBFFFFFAFFFFF3FFFFC9E8F1B7DCEAD2E9F1F2FBFDF8FCFD
FAFFFFF9FEFFE9F0F7DCE7F0DDE7F0D6E4EBD6E4EAD6E5EBD5E6EAD5E3E7D3E2E7D0E0E7
CFE0E8CDE0E8C9DEE5C9DDE5CCDFE7CADBE3CADCE5C6D9E5C3D7E4C4D9E5C3D8E4C2D8E5
C0D7E4C2D8E5C4D7E2C2D5E3C1D4E1C1D4E1C0D3E0BDD3DFB4CDE55278A806387E255A95
81B1D4527E9F648EAC85A5B8A9C1CF95ABBA9FB7C4BBD0DD9BB5BF9AB7C1ACC7D18AA2AC
87A1A9899FA9899EA78CA0A7869A9F8A9FA2849B9B81989A7A92966C8587678283637C7D
5C79775A787959777854747451716D4F6F685070694E6D68536F6A526D694F6B684E6B64
4E6A604B695E48665A476457475E4B22A41A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0060730D5D270B572412581C10
5F24156C3F2F69504371625B6A5E5F63555B60535A64565D62555B5A4D555C4E5669535B
5E3B4377434D661D2875232D82303772192077171E7521268E4B4E864E5190646884676B
7E6B707F747783787B84797A83797B837D7E7E7C7C808180808382858A88848D8A889190
909A9E798AA10B266202257E012489002685083579678DAE8AA0AAC6D4DABECED699ACB8
95ABB7AABFCABFD1DCB9CBD3C6D6DBD3DEE3E6EEF1F3F9FBF8FCFEDEE4E8DDE4E9FBFDFE
FBFCFDF6F9F9FAFFFFFAFFFFF5FFFFE7F5FCD7EDF6A5CDDCA8D4E3DEF6FBF8FFFFFBFEFF
E9F0F3D4E1E6DCE8F0DFEBF4DBE5EEDAE6EFD6E5EAD8E6EBD6E4EBD7E5EBD4E3EAD0E1E9
CDDFE8CADDE7C8DDE7C9DDE7C7DAE4C7DAE4C7D9E5C5D8E6C4D8E6C1D7E3C0D7E3C2D8E5
BFD6E2C2D6E2C3D6E2C1D3E1C1D4E2C0D2E0BED1DFBFD3E1ADC5DC4A6E9708356C295A89
6A96B0A4C8DB91B4C88DB0C0B4D2DFA8C4D585A1B0ABC4D096B2BD7797A27E9BA67D97A2
7F98A196ACB58DA1A99AACB4B3C5CB9BAEB292A6A9889DA07A9296728B8F6B8787617C7D
5E79795B78785C79795574724F6E6952706B51706851706B51706A516F6A506F6A4F6C66
4F6A604C675D4B675D49655A445C4B32772800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A309612806521B08582111
693C2C6D514364544B6D615C685D5D61565862555B66555C664F5762484F5438406B4C55
5F3B43804C546E222D721D257C30356A24296F2D338C565B8E626993656D97626C7D4D59
8666717E7277837B7D847A7B847979827B7A838181818381828686818987858F8F8D9697
909B9F8296AB0E2C65022782002891002C8E23549488ABC896A7B2A9B4BDA4B0BAAEBEC5
B2C3CAC9D9E0D0DDE6D2DEE4EBF5F7F0F6F9E9F0F4ECF2F6F7FDFFDDE3E8D8DFE4F9FCFE
FEFFFFFCFEFFEEF7FBDFEFF9B3CDDAC1D8E5DEEFF8E6FAFEEAFDFFF5FFFFF8FFFFF7FEFF
ECFBFEE4FBFFE0F6FFE1F0FADBE9F3D9E5EED7E6EED2E3EBD0E1EBCBDEE7CBDFE8C9DDE7
C9DCE9C5DAE6C7DCE7C7DDE8C1D8E1C0D7E2C3DAE6C0D7E4BFD6E3BFD7E2C0D8E2BED5E2
BCD4E0C2D6E1C2D5E0C2D3DFC0D2E0BED1E0BACFDDB9CFDDB3CCDD63849D8AB3D17BA6C8
628BA5A9D0E7517C9C5985A595BACF6D8FA27090A088A5AF7E9BA46F8E98A6C3CC9BB6C0
819CA6AFC8D298AFB8859AA49EB1BA879AA085999C8BA0A47D9297748D91698586658182
627D7E5E7A7C5D797A56737153706C58726E58726E55716D54726E52706B57736F526D69
536A65536B654F68614C685D455E4F414B3700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EAD106326014B1200522111
6A473869534867574F6D615C6C625F635758665357694B5263343D6228325E2A337B535B
603A4186545C5F1C23712A307E454A7D4F5686575F87535D8A4C577326328D303F761E2C
7F4750877276877D7F8A8081857A7A847D7B84837F888987858A89898F908F9798939C9D
94A0A293A5B6234376032C86012E9A0133973366A7AED0EAB7C5CFC3C9D0C9D0D8D1DBE2
D5DFE5DDE5EBD9E2E9E0E9EFF2F8FBF2F8FBD5DEE5D3DEE5EDF4F6F3F7F9F3F7F9F9FDFE
FDFFFFF8FBFDDAE3EAD9E8F3D2E6F0EEFDFFF6FFFFF6FFFFE5FDFFC0EBFCB4DEF4D7F3FE
BFD9E3B6D5E1C1DFECCFE3F0D1E2EDD1E1E9CEE0E8CCDFE8C6DDE6C6DDE8C4DBE6C5DBE7
C5D9E7C5D9E7C4DAE5C5DBE6C2DAE2BED7E2BDD8E2BDD7E1BED6E1BED5E2BED5DFBDD4E0
BBD2DFC0D3DFC2D4DFBFD0DCBDCFDCBED1DFBAD0DDB5CFDBB5D1DE7192A585ABCA194070
2049786F9CBE1241662C5B7D5881957596A57D9EA98FACB5ACC9D07E9CA6A6C2CDA8C3D0
73909D96B2BE839FA9849EA887A0A78A9FA6879DA1869A9F798E9472888D688285678284
617D7E5D797B5B78795976755976735971705B75725D777457757152706C55716E57716E
546B685369665369634E685E47635441513C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056B6166227004D1903582F1E
6A4F3F69564967594F6F645E6E62606E5B5D69474C622932661921650D1761172081515B
623C457D555C60343981565C8259617E4D577A364275232E8931398C2932861520831721
80383F8E7275887D808C82848980828781818B8C89888D8A8990908C9394969B9D999EA1
9AA0A49EABB94C699605328A0237A6023CA3275CA0AFCDE9C9D2DADCE0E5DBE1E9CFD9E1
D4DEE6E1E8EEE2E9F0DCE4EDDEE6EDE7EFF4E3EAEFD9E1E5F2F8F8FDFFFEF8FCFDDBE2E6
E0E6EBF9FDFFEDF1F4EEF2F7F7FEFFF4FFFFE6FAFFD1EEFF8ABEE33C8FCB549FCFC5EFFE
DBF6FFC4E9F8B7DBF3C9E1F1CBDEE9CCDEE7CCDFE8C7DCE4C2DCE3C4DCE6C1DAE3C2D8E3
C3D9E5C7DBE7C5DBE6BED6E0C0D8E1C0D8E3BCD5DFBDD6E1BDD6E0C1D6E3BFD4DFC0D4E0
BED2DEC0D3E1BED1DEBED2DEBCD0DDBACFDBBBD2DCB9D0DCB6D0DE7594AB3E668C022861
042A624170916590A46E95A8668A97ADCCD790B0BA7C9BA7ACCAD484A1AE75919F84A1AD
6B8895698591718F9875929B85A0A7869FA57F969C7B9197758A916D8489647E82627D80
6380805977775473755775765674725A74745A76765C767458757053706C57746F5A7471
516C67506963546C63516A5F4B6658465A4700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0C6C330554270C573822
66503D68564766594E6F625C6F5D5B76585955202464141B7B1C21700F145C10167A4C53
6F50586D50577B5D647D5E657B5058803E487D222D811A238B272F963039871920871F25
7932388F72788980848D888B8B888A87858788888B90949691989B959C9EA1A5A7A7A7AB
A9A9ADAFB2BC7D92B70938890345B00850B53672B3D0EDFFD7E1E9D7DDE4D2DBE4D2DBE5
DCE6EFD4DFE6E6EFF5D4DCE6D2DAE4E2EBF0FAFFFFFAFEFFF3F7FAF5FBFDF4FBFDD1DBE2
D9E2EAF7FCFFF8FDFFF4FCFFE5F2FDA5C4E65A8EC08FC1E99CD0F65EA0D38AC7EDBFE8FF
BEE1FC5889B384B5DBBEDCEDCADFE8C5D9E2C8DBE5C7DBE2C3DBE1C3DAE3C2DAE2C3D9E3
C3D9E3C4D9E3C0D7E1BFD8E1BDD6DFC0D6E3BFD5E0BDD4E0BED4DFC0D3E1BFD2E0BFD2DE
BED2DDBED3DFBAD0DCBCD2E0BAD1DEBAD1DBBAD2DAB8CFDAB6CFDC92B1C3456B8644698E
51789C48738CA5CADA9DBFD1638A9EA0C4D68DADBD5778886B8B9766828D607D87809DA6
7B96A0708D96A7C6CD7C99A290AEB78AA7B06E8990678085647E83637F83617E815B797B
5E7B7C5575745574745371725371725773765A76775D77765D77745E7974607E77647F7A
526D694B6661526C63516C634C695B475B4C1B9D13
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006F38075A3111583C22
644F3C66554767584E6F5D576E535077494A631D1F660B0F761719691314622324764E53
7B5A637F576177485382515B83475182323C7E1A25841C24862930852F377E292E7C3034
86525991767D91848B97929797979A919194949497989A9E9A9CA1A2A5A7ADADAFB1AFB2
B9B4B7C1BCC3AFBDD7214F92084FB41160C22F70B1B9DDF5CEDBE2D9E1E6D7E0E7D9E2EA
D7E1E9CDDBE0DFEDF3DFE8F0D7E0E8E0E9F0E5ECF3E8F0F7CFDAE3D5E2EBE2F0F6CCDBE2
DEEBF5D3E0EFBFD1E5C2D8EEC7DEF8759EC9326FA591C3EABBE0F3BDE4FC75A8D74682BD
81BBEC417DAE7AAED2C0DDECC9DDE3C7D9E1C7D9E1C8DAE2C6DAE1C5D9E2C5DAE3C4D8E2
C2D9E2C2D8E2BFD7E2C0D7E3BFD6E1BFD4E1BFD4E0C1D7E3BED5E0C0D5E2BED1DFBFD2DF
BED2DDBED5E1BCD3DFBDD2DFBBD1DEBAD1DEB6D1DAB6D0DAB8D0DCAFCAD66183939BBFD5
7FA6C6416C908EB4CF496E8C174162567E9660829258768669879296B3BC708E979DBBC4
A5C2CA708D97A0BDC67E99A364818A638289618085688488658184688587688587668385
5A767753727050706D516F6F5572735370705472725976745E7975637E796A878267817E
5A74714D6662516B664E69624D695C4D615120A319
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C470D5E3811573C20
634E3A66544769524B714F4B7A4A486422226C191A650B0C6B1A1C66272773424573454F
7C43506B222D84344073242F85343F8D364174161F7D242980393D955D6289575B996C72
9B70799268708A6C72A4969AA09EA29E9EA39E9FA39D9EA1A2A2A6ACABAFB5B5B6BCBABB
C9C7CAD1CED4CBD4E84A71A90647A5024EB24184C5B8DBF3D7E2EAE3EAEDE5ECF1E3EBF1
D5DFE7CBDAE3CBDCE4D4E3EAD0DFE5CAD7E0CAD8E4C0D0DDC5DAE6BCD3E0B3CAD5B7CFD8
C2D9E5BFD8EE6485A77596B9BCD8F2BAD7EFA0CAE990BDE3A6D1F2A2D0F31A599C0D5BB2
377FBF99CDEEABD0E5C4DBE6CADCE3C9DBE3C8DAE3C8DAE2C7DAE1C6D9E3C8DCE4C5D9E3
C3D9E4C5DAE5C4D9E5C3D9E5C1D8E4BFD5E3C0D7E4C0D7E5BED6E3BFD6E5BFD5E4BED3E2
BAD3E0BBD5E4BCD4E3BAD2E2BAD3E2B5D1E1B6D1E1B4D1E0B7D2E3B5D2E386ABC180ABCD
133E7604306E4977A24E7896355D775E85979EBEC88AA6B27B99A4A8C5D18DAEB97C9FA9
97B9C06F8C9769858E6D868D6581866B888B5C7A7D6480846683856784856B8888688486
5F7B7C5472704F6F6B4D6B6B516E6E506E6E4F6E6C516F6C5775705D797566837F677F7F
647E7C60767459726D526C64516C5F52675724A91E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00885311613D13553B1E
644F3A644C406D47415C221F742E2D6C1D1E6E1C1D601818743C3E73434867333A6A2934
6C192672101C87242E872C366B19228640477235397B42468F5E659668718F5F6A8E5B66
8D4C59702A33AB787CB39CA0ADA6ACA5A4A9A6A6AAA4A4A8AAABB0B7B8BDC2C4C6CBCDD0
C0C4C9C1C3CABEC5D37B97C10E489D044FB53172B9BEE0FADBE4EBDBE0E6D8E0E7D3DBE4
CFDAE4C6D6E1BED0D8BED0D7B7CBD3C7DAE6C6D9E7AEC4D399B2C08CA6B2ADC7D29EBAC7
B3D0DDBFDBED9AB9D492B2CDA4C0D6B0C7D79FC3E329649F256BA88AC6F24781B62B6DAC
74B2DEB6E5FDC1E0EFC6DCE6CADDE6CBDDE8C6DAE5C9DDE7C9DFE7C9DEE8C7DEE8C5DEEA
C0DDEAC0DBECBEDCECBBDDEEB7DCF0B2D8F0B3DAF5B2DAF8AFD9F7AED8F8AFDAFBA9D4F7
A6D4F8A5D4F9A1D0F6A4D1FAA1CEF69FCBF59BCAF398C6F196C4F197C5F45589BE4C85C5
0E4092023185427BB687BAE198C5E378A4BFA2CAE2A5C7DF6F93AB93B6CD6D94A75E8695
7397A270919A6E8D959AB6BD728E9493AFB4829DA2617C81648184607D80698687698588
637E815673734D6C6A506D6C4F6D6C4E6C6B506F6D52706E57757054716D55726F668180
6984838EA6A56C827F58716B536F6351685A25AB22
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00905D17624113533B1E
5D4A345A4132572A215B1812742621661B196D2E2E713E416C3C4261282F5A11186F1C25
791C2575101A81242D80353C71343C8F61688661668E646C89515E8139487D3140A35B68
8F3E4AAA555F96565BC2A4A6AFA7ABA8A9ADA8ACAEAFB5B8BAC1C5BCC2C7B6BBC0B4B5BD
AEAFB7D3D1D7CAC7D0B3BEDC24509A064AB01655A3A7CAEBC5D3DCCBD5DDC9D6E0CDDAE5
C0CED9B2C3CDC4D6DEC1D3DCA7BBC8AFC5D4A7BECE88A2B086A1AEB1C9D4C4DAE5A6C0CB
98B4C0AAC4D2A7C2D1A0BCCDAAC9DCBAD8EC9CC2E4205E9C2B75B39CCFECCEF2FFB7E7FE
88CCEC7FC0E3B6E2F8C8E1EEC9E1ECC8E1F0C4E2F4BFE3F5BFE8F9BAE5FBAFE1FBA5DEFC
9BDBFF8DD0FE83CDFC75C4F968BBF55EB1F452A5ED4E9DEB4190E23C89DD347FD52E79CE
2971C72A72C92369C21E62BC1D5EB71C5AB41856B01954AF1750AD164CAB0D45A40F48AB
0A3FA702339A0B419B1F55A2295EA71F51973362A33A64A32F5A953D689F436FA1507EAA
81ACD18DB6D56D94B09FC3DD7FA2B76E90A06E8B995F7B865C797F5A787A627F81678387
6781855A767753716E4F6C694B69654B6A674C6B68516F6B5875715775705E7C79668381
718E8D849D9E8096955F7775536E6752675D29AD26
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A808633F12563C21
5B422F573A2B54281B53130A6620175B1F197648466B3D41592128621A205D09106E171D
7622297521296B252C8D5D64835C658C616B8F5A668844527F27398A2033851B2BBB6872
9749538E3842853D43C19EA1AEA7ABAFB3B7B5BEC0BDC7CAB7BFC4BCC1C8BCBEC5BDBBC1
BDB6BCC0B5B8C6B6BAB8B4C83D5896063D9C11499AA2C8EDC0D5E2B3C5CEAABDC8B5C7D1
B2C3CDA8B9C4C5D7E2C4D7E29BB0BD8AA1B093ABB6B3CAD390A8B39BB3C0C2D8E3B6CBD4
AEC3CBADC3CCBDD8E4BDDDEF6D95AD97BBD0D0EAFBB3D5EBB6DDF1E3FEFFD0E9F4AAD3E2
7CBBD798D6EBC0EDFAC6EDFBC0F0FDA9E4FD8AD4F77BD2FB6ACBFA61C7FC44AFEE329FE8
2795E72090EC1A8BEE138AEF0B80ED0A7BEF0670E80D6CE60D60DA125AD21356CC1654C8
174EC01748BB1B47BA1B43B61A3DAD1B39A81B39A61733A0142E9A122993112890102890
122C95122E970E2A920E2C910F319209298B072684072782082C84062A8105297E052D7F
0B3483153E8811397F2C539529528C33598B4569914C708F56788E5678865B7C85618089
607E835E7B7D5675724F6E6A4D6D684D6B684D6C694E6C6851706B52716D607E7D688684
7B9896809999849B9E637B7B516B6651655D454B3A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047AD0C6841115B3C21
4A29164A26155227194D15095B21156D3A32623132591E24601C226F20265F090F67151C
6D2B306E3A4078515781646A846069763542791D2D8A2633972C3A9B22328E15239B3F48
BF7A82964D5685444AB7989BB4B0B4B6BDC4B9C3C8B7C0C6B2B8BDB4B6BCB3B2B8B3AFB4
B7AEB2B3A8A9AA9E9FA4A2B052689A08358A0C3D8B90B6DCAAC3D2A7BDC8A4BBC4BBD1D7
C5D8DFA0B3BEADC0CCA9BCC7899FA8859CA4B5CAD0C7DAE2B5CAD595ABB9B5C9D5BCD0D9
C2D6DDD4E6EBCADEE7C6E1F0ABCCDDD8F3F9F0FFFFEAFEFFDDFEFFC5F4FFA0DDF4BAFAFF
ADF4FFA5EFFF95E5FE70CEF854BFF14CC2FA32B5F523AEF411A1EF0C9EF50696F3048CF2
0787F50174EF016FED057DFA0375F5016AF00562E62152CE4441B05C399E64379463318B
692E856E2C82722B80742C7D7228777226726B236D671F68611A605E185A591555581658
53175B4E175E4C156048145F44165E3E155F3A165F371B652D19642415642319691E1A6E
1B1F77131D7710237B0B237C06227905227304226A0626670F30691D3D6D2E4F78436689
5478915F8090597C83517275517171516F6E4F6D6B4E6D684C6C67506E6C5271705B7B78
8EACAB9AB4B4859EA15B7577506A6750645C444A37
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB4106B3F0C552C12
4E23134019084F29175123126C34255C1D166522226C2428661C217023295A0F1467262C
80545A73555C735F677A676F8C67706A1F2B8216238F1E28A3363E8511198E1D24832F34
B07C8182585DA78186B6A3A7B0ADB3B0B1BAAAAEB4AAAEB2ABADB0AEADB2AFAEB3B0ADB3
ACA9AE9F9EA08E8F9089919B6179A1062E780A357B789BBF8AA1AEA2B4BDA6B9C0C1D5DC
C4D9E0A4B9C4A4B8C3AEC2CCC0D5DCB9CED4B7CAD3CADCE8BDD0DDBFD3DECCE2EDBDDEEF
B3DEF4C7F2FDCFF9FEC7F3FFC4F5FFC9FCFFB3EEFE89D6FB6BCAF449B7F032A8E837AFEC
26A1E21E9FE31CA3EC0D99E90B9CEF099FF1079FF108A3F6019BF4009AF6029AF90092F4
0391FA0283F30281F40586FA047FFA087AF8266EE96D51B7AF3980C62A5FC62250C92450
C71F47C81E47C81D44C3183EC31B3DBE1A39AE0E2DAE1330AA132FA5112DA3122E990D28
910A278C0828910C2F8E0C2E860A2C810D2F770D30701237660F37620C38650F3E600F40
5910465413504B15533C14562D11552411571E135B13135D0B145F07175F051C62042062
08266318386B2E517943678650758852737E51727552716E53726D577471537270537373
75959798B3B689A2A659727648636251645C3C7F31
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B915723F0D532007
5524134D231157311D61311E6523165A09065B0809782C2F632023703436622F34805259
764853663E4A7A5E6879646D8A686F6C2D3781212C80141CA03D427D24288B4144956466
A68F91A49699A59B9EA8A0A5ACA6ABAFA9AFAAA6AAADADAFABACAFA7A8ACA5A6ACA4A7AC
989CA192979A8C91958491986E87A50628690A31717091B19EB3BDCCDBE0B8C8CEB4C7CF
B3C7D2A7BCC7B1C5CFBBCFDAC3DCE6C8E1ECCBE5F2CCEAF9BFE6FCB8E7FFB5EEFF74C3F6
53B4F541A6E550B5EF3CA3E2339EE039ABEC259EE81399EB0C96EF0693EF0492ED0792E9
0F93E71897DD27A4E226A0DD29A9E528AFEB23B3F31FB5F81BB7FE15B4FF0EACFF11AAFF
0DA2FF0E9BFF0D96FF0B8AFB087AF20E78F43666DB873D94C92552D61B32D2172BCF162A
C30C20C50E23C40F20BF0B1CBC0D1CBC101EAD0713A50413A30816A106149C051390010F
8A010F8C01109608198F031287051281121B923C459F5B638A424F7115287E0A1F860519
87051B84061F8006237906266C0829630A2E580A324909363A0839350F46260D4B1D0F53
15155C0B1861041A610524640E32652649733F627E50728158787D597878547271567575
7494948DA9AC819A9F5E787C46615E55685E2AAD25
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00733A08571C06
5B2313592A196333235D1F1262120B6B13105E0A09712B2C5924266F4548724C50703B46
671E2C66202D8E606A6C4D558263698E6067803842711D2387414497666AA484889C8B8F
9A93979C989C9E999DA49DA1ACA3A8ACA6AAABA8ACA8A6ACA3A4A9A0A1A6999CA29AA0A6
949CA08F989A8894968393997E95AD0C2E660A336E7295B49EB4BEC5D4DCBFCDD7B4C5D2
B5CADABFD9EABEDBF2B8D9F6AED9FC95CDF97ABDF161ACEF3B90E0308CE3238AE41186EB
078BF3068EF60B94F80891F5028CF00695F70193F20195F10596EB119EE92CAEED54C5F3
7DDCFAA0EFFFA4F7FF97F7FF75E8FF5BDBFF3DC5FD2CB9FC1BACFB0F9EFB038AF30586F6
057FF30172EE056EED0460E20351D4064ECE324EC1772B7DB51740C11225BB0C1CB7091A
B3091AAD0516AF0818AD0817A205129F08149707139104148F031294051492061383010D
7C030E7A010D7B020D7C020E70050FB1696EDFB7BBBEA3ACCFB2BCB383906A1321820715
88040E86010D86010E84020E81020E7D02107802107603147105186C051E6508275B0C33
4D0C3B3B0C42280E4B1A15570F1B60081F6305225F1334663257785176885A7C83628082
728F8F88A4A76E888C5672734966605B6E6322A41C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723209591804
612514662F2153140A6A1C16630B076D1312590C0B703A386A424371484C643038702732
70111D680B158A4D54815C64856B748D737B6E484E8D6166937276948187988D95968E97
9991999B9399A1979CA2979DA79DA39F9AA09B9AA09A9A9F939498929599959B9F959CA1
8C9498909C9D819293819497849BAE1D40721947828DB6DEA2C0D8B2C9DEB8D0E8BAD7F5
AED5FD81B4EB5C98DC4385D82C77D7146CD8096AE00971EC0671EF0270EF0273F30278F6
0182FA0087F8028DF70190F50194F6059CF910ADFE1BB5FF33CAFF45D2FF54D5FF66D5FD
68C8F66CC3F550ACEB349EE71C92E9128CEF077DEA0879EA0772E20868DD085CD60D59D6
0F51CB1247C21942BB233EB42230A2282C9A3E25877E1F66A81134B0091CAE0819AB0617
A504139F0110A106149D0B16860A118523288F3A43893645741727780A1B7C0A16721018
78282F681C255B0C1664121C5D0E1A905261976E7C502F42776070D4BFCC7742506E0D1B
74040C77040D78030B79010B78000A7C020C7B03097901087A010A7C020B7C030D790210
77031772061F650A29570F35400E402E14501A17580B1A5D07225F0E30603C6080628595
7393988CABAE6480824F6A684B665F5E6D620ECE0A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0079350F581706
6C2D1F641F165D0C0869100D6209056C201D66302F6C4946674645562328631B24863039
700C15720C14772D359671798B78838B7C8787777F87757B8C7D848D838A9089908F8892
928B94988F96998F96978D94958E95949097908F959191968F8F958E92988D9599969DA3
929A9F93A0A287989B8D9FA693AAC13D61990C3E8B5F95DD568AC95A8BCD669BE0417DCB
2C6BC70F51BD0950C70651D00457DC0262E90064EC0067EF006BF20171F40378F7047FFA
078AFD0A92FF0D97FF0F9CFF0B9CFF0C99FE0694F80791F3098EEF0D8AEE0C85ED0D7FEB
0E7CE8157BEA1471E3156ADD1B64D9235DD42E55CC374FC23B42AD443AA04C359A553598
603793632D846A287B7627777A236E7B1F697E1759971545AA0D28B0091BAD0617AD0817
A80716A406149E07138F121ABE7072DEB6B9DCC2CBDDC3CFCDABB888505E5A1722BA898E
D7BDC0CAB2BAA48B91C8ABB1865D6A4F1D2E9A7684AD95A28E8390C2BCC78A6E7C561E29
793A3E6E2D315C1317610E1465091066040B6C040B700208710006750106770106790108
7A010B7B010C7A020D79031273051C670A2A530F35360D3E1F12490F1652051E571E4472
749EBA8FB5C465848856717049615A57605300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C391162210E
7531255E0C07660B096C141163181276403B6F4F4A6A53506C4F4F5F292C5F0D138D3238
73151C71171E6D2C348B6B74887B84847982847982837780857982887C858D838C8C858E
8E87908C858C8E858E8D848C8F868F8E878F918D9492919792939895999E959CA2979FA4
98A1A895A2AB92A6B781A0BD6B93C73060B001339A0539A50D44AF0541AF0850C20650CB
033FC20134BB0138C2013CC8004CD7076DF40473F8077BFC097EFD0B80FF097EFC0B83FE
067DFA0379F50274F10173EF0272EF046AEA076BE70865E11264DF175AD4245AD23257CD
4457C8514FBF634DB97049AE74409F803E998334898E3284952D769F2F729824679B2567
98216197236091225E8A205C8A24628425637B215F892059A3183FB81029B60818B90B18
B80C18B30916A60B189C2431F9B5C0E1B7C8996B858A6178CCB9C6CEBFC85B424CCEBDC6
C6BAC78A7286B29AAACCC5CE948893786471CDC0C9AC9FAFA79AABC3BECC9086948B7882
C5B4B8BAA9ADB59EA1B49398603239A36B75661F2963030E6A01066D01066F0003720106
7502087401097701097C010A7F010B7F031078051668051D5A0C2C44123F24134D0F2163
1138755885B07EA4B9617F8351666046493800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C6C0B6E3118
651E11610A05630C086A211A74393172443E6D4944735451634544703C3C621012711C1E
813D3E794748825F657E6C727D737A7F757E7D727A8377817E727B80737E857A84847D86
877F89887E87897F8890858D93878F938A919994999191969A9DA299A0A599A5AD99A9B6
98ACC2829DC2577EB51E529D0F4CAB0945B1012FA50126A00024A0002CAB0345C50650D4
0037C3002EBC053ECE064AD80459E7096EF90372F90473F80470F30167EC0462E9035ADF
0558DB0B58D90E51D0104AC61C4AC12C47BB3D48B7544AB56644AA743D9C863E9794398E
9F3485AB327FAD2D79B02F79AF377A9C3272953676923C7E8C3F828A478C7D4A926B4590
624A965246944B4D9C454EA23B4AA43649A83147A74D48A4883378BE1D43CE1727CD141E
CA121CC4101BBA111EB01C2EB33C52A039537E203C6A263EBEA6B2D5CED6776874CFC1CD
BBA5B6632A46662B45D1BBC89A939E968E9BCBC0CE634059552740BFAAB99B92A09B919F
B7ADB653435292828FBEB3BD584752CAB2BE7445555D08176701076700036800016B0206
6A070A6D10166E08107A030D7C010A7F030B7A010B7B030F7C07167609236311373F154B
1C1D621132754C75A47394A9556A6824A72000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003A9B026C2E0F
560D025C090260170D743B307A433C7339326028227F554E55342D784D495D221F6B3331
89676779686A786B71786D757B72797970787B70797B6E777D717B776B767A707A7A727A
7D767E857B848B808791848A9B8F959D959AA09DA29CA1A89BA5B394A6BE7C98BC567CAE
315C9E1747990B42A40540AD0441B6043EB8012CA600219D0024A4012CAE0749CC0D5FE6
0855E10349D80348D7024BD90657E5045BE9045AE50757DE084ECF0C45C31841BB1F35A8
2D319D4234995432906130887936898834808F30799D3079A62C73AA2F72B13D7CB24686
A546899C4C938D51998A65AE786BB16571B75175BB497DC24282C82E76C6257CD1218ADF
1B90E71993EC118EEA118BEF1288F20F80F2137BF1256CDF7451ADC32F61E4283AE1212A
D91A25D11823CF1D27C71D2CB01B2BA02C3AB1646ECEA7B0D5C5CFD6C1CE765565D3BAC9
C7A5B775243F732037D8B5C2A699A7A194A5CBBACA632E475D192FC5A1ADA993A276556B
CFB3C289748381727FC2B9C4544452C5B1C07B51625F091A6B01096900046B0205690308
67181ACA90926F232D720815760A1072070D72020B79020C81030E870513810516750C29
5A18482F206211286A466891556B7525A72300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049AA0C6C2D09
5710015C140572362571392D642018772B23651F18824E4672524979605A7B625D796361
7A6E71736D73736D74706970726B71786F77736770766872746771756A747970797B727A
817980897F8890858E9589919D939EA39FAE9EA8BE849ABD5477A82F589B134496073B9A
0438A00338A40334A4012FA40034AE0136B40638B6002CAD0430B50336BB0546CD0758E1
065AE60751DE0748D40946D00440C80D42C51C3DB82B31A1422E93522A84612577712470
7C22668722639126659329669C326F973A7891488A855199795AA36F66B0646FB7607CC2
577EC15884C06698CD6FACDD75C5EE64C8F157CDFA48CEFC44D2FF34C4FF25B8FF15ADFF
0DA9FF0CA4FD0B9DFF0892FE0787FD047BF70675F30F61DC5348ADA92862D31D34CE1120
CA101EC30E1AC2121DB41520AD3940E8A9ADE3C6CCDBC3D2C79DB493506C79354BE1BBCA
C199AB79223A802839E2B9C4A48D9DA08A9DD1BFCC6B42535D2939CBADB8A789995D283F
7E4F60A98E9BBDB2BCBEB5C1584553C8B3C17C5162650C1D71020A7000036D0105670408
5A151AC9A4A87038436A10209A4951A25A6168101A6E0610750610840A1589070F8A0512
850E24691B4831205F12296138536C22A72700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B1136A2A06
5C1B08672916793E2D67231763100791392F65160B6C322779595078696379706D777071
7772786D666F6C666D6C666B70696F72697174697174667070626B6F636D776D7580767E
837C848A858F8F8C999293A8868FB1687BAC375798164292083B99073EA60438A70336A7
0032A20132A2022D9E0530A60738B10437B4063BBB0333B90331B80430B90332B90C44C9
0945CA053DC2012BAE0123A1011F9520208A5E2B847A1E69891A5B8E1B578A1B54892660
80326F6F3A7D684E975A539F4F5AA74268B7387AC8348CD8339AE435ABED33B2F14ECBFB
72E3FF90F2FF9BF4FF98F1FF7EE5FF55C9F931B0F226ADF61EABFA109AF3078CF20180F0
0381F4037FF50074EF0067E90161E8005DE20058DB074BC9393AA18D1F5FBE122EC30E1F
BF0B17BC0915BB0D18A0131EE1979EE5C9D1C09FB197597487304F861D3B95374CF9BCCD
CB8CA07E1932963447F0B7C4A5758A8C5971DEBFCDBEA6B3B6A0ABD1BEC8987585976274
C599A75F4451A3939FB7A6B466505ECDBAC67F576665102175030D770106710104670307
58161BC6A4AB6A39485E10228F525CB98B9454162385414A914F57721824850E17940E16
960B1787112E5A275D192362183156327A3800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDB0C632200
5B210976402B6929186C190F75140D781B11813727814E3E76594E746661776E70777177
78717A756C766760676963686861676E666E72697074656F75646E73656F766C74807A84
818291848EA56D7FA4405A911B3E870C368F04319704329F0131A40130A50130A50233A8
0236AA0539AD0334A7012CA00535AC073AB30839B5072DAA0B239E101B8F19137F23157A
342F950A1A85011A8600167E0415761D106764256E782464783073693C84513E8C3D4698
2B50AA1E60BF1D80DC2096ED1A9AEF26B2FB1AB4FC23BDFE30C5FF30C0FE29B7FB24A9F3
2DA6EF2696E32699E6259BED128BEA0982EE047EF10279EE0279F00170EE006AEB0066E9
005FE10267EA005EE40056DD0053DA0157DC0357DB0347C6303EAB84256DBD1437C70F1F
CA101AC60B15C10F19A91D26F0ADB6E1CAD48D6879955469DA91A3D3788D96253CC35066
AF39509F142DA51E34CB5A70A2354F8F203BBB6379D492A7B88096CF95AB964B6283364A
D59FADCCABB6CFAEBC916679855D6ECBB6C0B39AA48B4D5B6F09167A030C7701066B0407
632528C3A9AF6C4D58521C2983545FB58F9B4D1F2CB7919CB398A19C6B776F1F28801922
9317228E142D6326561F256708204D343E3E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00672B02
6B391C76462F6C2A1A6C120A7A150D6D1408925443916D5C755F55665955776E6F726B6F
766F77736B765C555E665F686B616B6B626B71676F70646C776A74756D77787685717892
566A912C4A8310388207348D033194022F9A012C9A012B9C012CA00331A70333A80233A9
0237AE063EB40836AB032696112E9B182E9A2929902D157336095B46084D5F0E496D124B
601B5C1F0D5F041877001B81021D85142B913444A72E44A6224DB21860C81474DB198BED
1995F80D8FF814A3FF13A7FC0D9EFB12A3FE0B9EFB0792F6048BF20182EF027DF0027CF2
0275EF0271EE0273ED0175EE016EED0068EA006AEB006AEB006CEB006BEA006AE7016AEA
0066E70067E9016AEC0267E80162E30162E60160E40558DB2E52C5803685C31E44D41321
D8141CD5131BD2151DC01A26E17787F5C1D0E5C2CFE8BECBFBC1D1CE6D85AC1C34BA1327
BA1123B80C1EB50B1DB40E24B30D26B00E26A61026A61B349F1A35991731961028911024
8C1F32A0455A953B507C1B31964054B87D8CC798A5B06F7F6D09197C010C7C01066F060A
804749C2B2B7C0B1B984646D8B6D75A68691532A37C8ABB8685461997B8BA8828CD19CA6
7C223184193461275920276A051D4F18612800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A3F0A
6C3D1A6E40277439256917087A21117A31209266558E7569817269685F5878706F71686C
756C746F666F4B424B575059675E686E646E726872726C7573727F6870874B5C821E3871
072B76042D86032F91022E94002893002896012A99042E9E012FA00131A30433A60633A7
0934A80F30A11B289121136C3C17644E11586B1A5970134A6E0E3E660D3B5D0C3F54114B
522D75252B870626950129A2022DAB023CBC0B56D60B63E20E71EE0B7CF50C87FC0A89F8
067FF1037AF1067DF2057DF20072ED0070EC0073F00069EA0067E90066EB036EEF0069EA
016CED006CED0172F10174F00376F10277F0037EF40281F20387F40389F40A90F80489F5
0287F5068DFA0084F50180F5017FF6037FF70177F30470EF2267DD7749A3CA2957E61E2E
E91E24E31C20E01B20DB1C28D02A3DD5556DE07A91DB7792C6506DBC2744C6182CCB1421
C70F1AC10B18BF0B17BF0B19BF0C1BBD0D1AB70C19B70D1BB50B1BAF0A19A30412A00613
9D091897091A9407198F03148C081A861024871B30861A2C7F071583010A8102076E080C
AD797DAB929C8D6778764A59AD91979A818A5C3C49CFB9C5B4A5B0766271B09FAAB1929F
A66173811F3B6223542526670820510D921C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00647609
6D350E703D2086503678381F74331B996A55917565826F667B6F6976706B6861616D6568
6F676D71686F5850565A54596D69706E67746E697B666A8343537718306606246B012479
012887042C91002A91012A94012A95012A96012A98022B9A032D9B072D980E2A931E288D
31207D401567571458620D426C103B6B113E5E1448501550380A4E290D5B1A116A141D7F
13349E0C3BB30130B10538BF0942CB0341CB0855E00760E80563E80261E50265E70160E1
0159DA015ADC005ADD005BE0005DE2005FE30265E80169EC0067E9006DEC0073F00175ED
027BEE0484F10687F20A89EE0E8EEE1492EB1B9AEA21A5F020ADF417A8F01DB0F11DB1F8
12ADF90FAEFE09A9FE0BA7FF07A0FF0B9EFF0A94FF0B8AFF1D79F47866CDC83671EC243A
EF232AEA2127E31B24DF1923DA1927D41B32CA1B35C91B38C81633C50F28C50E1FC60F1C
C30C17BC0A15B90812BD0B15B90A12B80C14B30811B80C15B60B15B00A14A3030E9C020C
9B030E97010B98050E92010B90020E8D010F8B030F88020E86010C88030C81040A6E1217
CAA0A38866736121396A243ACFA7B3C4AFBB816D78BEAFBA82767FC4B9C5C5BAC6957784
AA647690243E731F473422590E1C460C8E1700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048A809
6F3004692B0D7F4A2C8051348A634A8C715E8674667C6E646D605A746A67504747665D5F
696366716A706A6469615F66696B7764698248527B192D6305216403217302237E022484
02268A02278E01268F02289302269303279105268F0B238B1621822A1C7444196660195B
73154D7A1142761341691A47542256311A5E212478162B8A081F88051E8E032397032FA6
0B46C00E4ECA0035B70639BE053ABF0136BD0441CA024BD20045C90047CA0149CD004ED0
0152D20056D5005BDC0061E30065E60571F1006FEC017AF20382F5078BF60890F21192EB
25A2EA3DACE858BAF16DC5F383D7F895E5FE9DEFFF8FEDFF77EAFF58DAFF56E2FF3DD0FF
20BCFF11B0FF08A8FE07A1FD0498FF038FFD0280F90278F9096BED4A5ACC9B2D77D21B3B
DE1927DA1422D40E1DD4111ED1121FCC1020C50C1CC70D20C60C20BC0719BE0A1BBE0C1C
BA0916B70814B30812B30914B10811AF0811B00711B10712AF0812AA07129C020C97010B
97020D95040D8B01078900088801088701078602078200068301098201097D050C772227
D2ABB0BBA2AB9E6D7F6F233A954E63C792A6916C7ED2BAC7B0A0ABB8A6B6C4B5C3D0B4C0
AA677897253D841A354E1D40251E3909C70A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052AF0E
7129026D250A874E338E664C8B6F5883715F7B6D618173696E5E5773635F4E3E3E625455
6B61646F666D79758064677A4C58781C2F63081E64031D6E021D7604217F042181021F80
02208302228A03258E04248D051F850E1B7B1E166B37125E5615566F15497B1540791542
6D1A4C591E58402065231F6D122680092D930633A5083AB2032FA8052CA6062EA8032FA8
0437B10944C00032B20029AB0126A60026A50132B30346C80146C70049CA0657D8045EDE
0262E10167E5016EEB0478F4017EF50288F8018EF70699F413A4F233BAF652CDF97AE3FE
9DF5FFB5FEFFC3FFFFC6FEFFBEF9FFABEFFF8BDFFA69CAF648BEF52AAFF216A2F00D9AF4
0390F5028BF90286FA007FF8027DFA0275F8016BF10468F20560E72558D0683B95A92156
C01534C3112BBE0C24BE1126BA1126B60F27B20F25B10D26B00E25AD0E24A90C23A70A22
A60A1EA60A1EA50A1DA3081CA20719A30819A50818A50515A30615A1061696010D95030D
9905108D01098300068101058000067F01077C00047B00067B01067B0107750209711019
98535FB48392C78EA07A2236790A2182162E7F2239C78196D19CB0966C80C5ABBBB597A5
B26F8095223984122757142811C80D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BB613
772B00742A0D763D258C695188705B81705F7F71657C6D6479686177655E685552615151
6F62676B63716465802E3C69081D5A01176300176D021A77011A7A011B7D031A7B001271
021572051D7D081C7D12187122105E4211535C0E426E0D3878133B711A42602355452465
27217114257F09288B0630990536A6053AB0063EB90A43BF0536B000249E011E9A001B96
00219D053CB90237B90026AA0024A60026A80031B5044ACD045ADC0363E4046CEC087BF7
027EF50486F9048FFA0799FB07A1FE0EADFF15B5FF24C5FF3BD4FF51DBFF66E1FF6AD8FA
6FD4F961C4F452B6EE3FA5E4329EE52095E61593EE0B8FF2068EF4078FF90385F7027CF5
0176F30274F3006BEC016BF0026CEF0164E9025DE1035CE10156D90B51D02843AE583083
7824638220597D1F577822587425596E1F576D20586A1C556D20586A1F56641B53641A52
671B5068194C691949701D496F194474184279163D7B11377C0F31811030840E2B870D26
860A1F7B061675031173020D76020D74020A7001066F01056F02066E01056E01066F020B
750819730F2378172A7E0D1D8704129106178F071B8E11288F1E37873147E7B4C5E3B0C1
99405591172F76102729881300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7D36036D2A0884543783664D826B587C695A7A6B5E7D6F657C6C637263596F615A6F6365
6D6674484D6C16245503185C02196803196E021671011774011A78021B79051A76010C63
070B5F151060240B50400B455C0C3B6B0C336C123B601A4A481F592E21681723770A2786
05299206309E0432A20535A60837AB032FA6012CA70233AE0330AA001E99001894011A98
0127A80842C40341C7012FBA012CB6053BC40442CC0452DA076DF10679F90483FA0792FD
099AFE0B9FFF0DA4FF0EA8FF05A2FE09A7FE089FF90BA0F7099BF20C9AF30B98F20B94F1
0D94F40A90F3088BF50585F60480F50581F7027BF60177F50278F50274F30170F00067E9
0063E60161E3015EE2015EE3015EE0025CDD0155D40355D2014FCD0249C9094BC21741AF
2539A02A35982B399B2235962136961F35951A31931B2F931B2E911E30941A2D90192C8F
1C2E8E1B27871C268222298223267B2727782D277430206E3320693A20674423674A2361
54285E522352501D46491033500D2C540A2155061657030F5B030A5C03096002076A0106
77020E78021075010E7D010A8A020A94051094030F9907159908198E0E21AA4157A9455A
9D223793132C6D193A264F2800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C49107A411989644379634878645075635278685A7A695F7A685D6C5A506E625E676470
353C5C08194D01155902196702176B02176D01136A01156D02197104186E0A1364180C53
2D0A464C0E3F5A0930620A2F5F103A4B12463318591D1E6F0E2580082C8F042C96022D9D
032FA20330A4022EA201299C001C8F00188A00198C022DA20331AB0022A0001D9F0329AF
002DB60648D00450DA003FCE013ACA084DDC034CDB0760EB0979FD047FFD0587FF0991FF
068DFC0184F70285F90080F60183F80287FB0184F80283FA017EF6017DF70182FC017EF9
0179F6027BF80178F70277F70072F10371F2016CEC0268EC0267EA0466E90162E5015CE0
015CDC0058D70155D50257D90156D40256D30050CC014CC7024CC80249C70147C20346BF
0645BC053FB8043DB5043DB4023BB0053FB2043DB3043CB30238AF0437AF0333AA0435AA
0435A90231A70431A5042FA2042F9E042F9C06319A062D95062B93072B9109298F0C298B
0D288210287C14257517216E1F2167271F5E2B194C2B0E362E082634061C3F0516550515
6D071973031573010F7B01098D080F93060F91030B96040E9E08129A06129A0A19990D1B
9F14228F19326027521E184311901900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
3D9E02764016866440756042705F4670624C6C5C4B746253705D4F6B5E55605E64252E4C
05164A02175C02176601166902156A03166A011366041466081360120B4F2C09434B0B39
5C0A2F620C2F58113A40124A24115913186B081E7C05278D042E9704339E0331A1022FA3
012EA4002BA200299E01249700168700198A0020920536AD033EBA053ABD002FB70132BE
0136C5054EDA0E6AF3045BE8074FE10448DB044ADC0961EE066FF6006FF40374F90070F4
026FF4006CF2026FF6046FF7016DF20170F4006EF00270F2036CF2016BEF016FF1006AEE
0066EB0067EE046FF1016BEC036AE90264E40160E10262E2015CDB015BDB0159D90255D6
0155D20155CE0152CF0253D10053CC0151CA0151C90350C80350C4014BC20148BE0247BD
0244B70140B4023FB20341B20341B0023FAD0441B10441B10340B0033DAD033CAA043CAA
053CAB0338A70337A60335A30233A102329F02329E01309C012E9A022F9B022E9A012C95
01299201299102289004289003278C06278709227C081B680814550B1048110B3C260F3D
3F123F4F0E355A082471071B8408158B04108D010B980510A70E14A2080EA0070D9F0B12
9209177D1C3E4429620C1A4F155A2600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B00D7B4612805E33735F3D6B5B406A5C43695A426C59446B5B4E5854571B253D041643
01165302175F021463031467011162031261040D57110C4D23063E4108325A0B2D5D0B2F
500E39340D44190E520E186B051C7B03238802278E022A94022A96002A97012B9B002CA0
012CA4022FA70230A8022EA700289D002A9E0134AC0343BF034BCC0850D40342CC043FCC
0542D1034DD80B67EE0C66EF0146D50039CB013BCC0245D4045AE60160E90262EB0263EA
0162EA0160E80162E9005EE60162E80365EA0162E70061E5005FE30160E20160DF015EDF
015CDE0362E20363E40160E0025FDE015CD8015BD7025DD8015DD6035DD6025AD20156CB
0155C70253C50252C50655C60756C50855C10551B90851B6084EAD094FAA0D4FA70B4BA0
0F4DA00D4998104894124A95164D951A4E96164A92164B9216499015468E13468C15498E
14458C13448A1041870F3F880E3E870A3884093885063384043285073689043387043085
042F86032D88022B8B012A8E022C9001298D03268A02238203217B031E73041A6C061969
0F18671A175F2B18514316465C1237710E2B7F071C940A19A50F16A60C109F060A9D0912
8E0C22671E4F2E2C7409215E1D223400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C5510825F2D6E59366D5D4169593F6D5B436E5B4B534B4A13192D03143A02174B
02165502165A000F5802115D040D560907471C043936052C4C0726540B2A490D33310D41
150B500A1666031B7302217F012589052C94032C97012996012696022999012A9B012BA0
002CA40233AD0138B3023CBA0541BC0440BB0649C6034DCD0455D70757DB0347CF033CC7
063CC9003BC60351D70653DB0038C50233C30132C30037C5034ED80258E00057DD015ADE
015BDF0058DC035CE00059DD015BDE015DDE025ADC025DDD015CDD015AD80159D40059D4
0058D30159D2005AD2025AD2045BD1055CCF065CCB075CC60C63C90D5FC10E5AB5125BAF
155BA9195BA51F5CA4225A9F265F9D2B629C30659B37699B3A6A963F709743749541708E
4873924C7491507791567E94597F955B7F96587C93587A905A7B9052738A5074894A6F82
51748C5B7F955A7D935E829A5579915378904A6F8A466A893C608231587A355D8032587F
2E547D274C7A22487C143B750C3675063074022A7302297502277802257A022479012279
021E79041F780821720D1E6A1D1C61321A564F18476F1434870E1F990C16A1090FA20B15
8D102A622B651B297507235F0C922000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00788E13896026745A356B573B6A59406F5E4C5E5350181A2B031234011343031851
031759021457020E52070D4E1509402E07324507254F09224209272C0B38150D4A0A1560
031971011E7D03258503288A03298E01289101289700279900289E022DA2012FA30132A8
0237AF0139B40442BE0245C3054ACA0247C7044BCB024DD00250D4054ED30039BF002DB4
032CB3002DB50544CA094ED40036BD0133BC053EC7003CC3044ED30457DB0257DC0258DA
0257D90155D60156D50155D40155D40258D70257D50157D40357D40358D0045ACD065AC9
085BC30959BA0E5AB8135AB1175DA91E5EA62562A12E68A1366FA24276A54D79A2517C9B
578199597F9565869B6786986885936C8894728E9878949C728F95719192719191789597
7D979C7A9399829C9E89A2A38AA5A590A8AB90A7A990A7AA92ABAD8EA5A893ABAA8EA5A5
94ABAD9EB5B59CB3B595ACAFA0B8B896B1AE92ADAB8DA6A88AA4A7809BA07C989D79939B
658289607E85607F8A5879884B6F823B6279335A76274E6F19406813396A093065022965
02266C0226710225740425770425780925771824712F2161531D4D781535950F21A91724
8D1736522B68142B770420580A8F1B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CDD099566217A582C6C53366C5942655A5121232F04103101113E011449011552
0416590410520C0A451D04333F0A2D500A254607232E082D150A3C070F52031565021A74
03238402258901248901258A01268D002892012A9A022DA10130A70134AB0238AF023BB2
0440BA0341BC0344C10145C5054ACA0445C60342C40146C80248CB0343C80235BA0026AA
0126A90128AC043ABE0A4ED10141C50343C6084FD0024ACB0550D1004ED00251D20051D0
0254D20153CF0254CF0253CD0556CD0456C80758C40855BB0953B0145BAF1C5DA92863A7
3069A03F73A14E7CA25580A06088A06386996586946886906D89916F899271898F738B8D
768C8E799192849A9D83989A869B9D879C9E8BA1A1889FA089A09F8AA29F92AAA694A9A8
97ACAC9AADAF99AFAFA0B7B5A5BAB8AFC2C1AEC1C0AEC0C0AFC4C2B3C8C6BBCCCBB6C6C5
B4C5C5BCCBCBB7C7C8B4C5C5AEC1C0ACBFBEA7BDBD99B1B195ACAE8BA4A77D969B819B9F
738F8F6D8A8A6A85876681855A787C5474774C6D6F45676C3F6067385A66325764284D61
1D445E173C600F335E03285D01276702287304297B092A7F1D2E7D3D296B671E4E8D193C
832049462D6F0E2C790B255A0D8F1A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0028DB0A7F571F6447266D5A4837333506122802123902144401144B00134F
05114E0E093D29082D4408214C08213A08291B06330A0B45021157011868001A75012183
02278B02288E02288E01248D012791022D990130A00233A50437AD053DB4023BB30139B3
023CB6003BB60140BD0140C00341BF023BB90031AE0238B5023AB9023BBB0335B70126A8
0124A70226AB0130B3094BCC0349C9034CCB024EC9014BC6024DC8034FC9024FC60451C3
0650BF0852B80B54B11055AC1A5AAA225EA22E69A03D72A04C799F5E85A562849E6D8A9C
728D98789297708A8C748D90779091748C8C768F8D79939081999879908F839A98899D9B
8FA3A18DA1A092A5A59BABAC96A5A59FAFAFA3B4B4B0BFBFB1C0C0BDCDCCB8C9C7BCCACA
BECECEC1D2D5C2D5D5C7D9DACADBDCCBDADBCADADECCDBE0C8DADDC3D5DAC4D5DAC3D3D9
B8C8CEB8C8CFBAC9D0B3C1C7A8B7BDA2B3B997ACB08DA5A8849DA27E979E7891996E8A90
6B898B658284607C7F5E7980577578516F704E6C6C48676744636142615F3C5C5A3A5C5A
3457563456592F52592A4D5C1C405911355B052D60022A6D052E7F1032882A2E7E502466
5E2D6C302F7B0C2D79122855108F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006A88185A3C13584B3D10151F02132F02153C021544011546071346
150B37330A2844071B430A20270429110A3E040D4F02145E011869011E7502227F012587
02278E01268E012890002891022D9803319F0131A30235A90336AC0135AB0136AC0137AD
0037AE0139B1013AB4013AB6023CB70137B10130A70030A60134AC0138B50436B60027A7
00219F0123A40029AC0440BE034AC5034DC4034DC0044EBA0950B50B4FAB1452A41F559D
2F619F3F6EA04E7AA15A83A261859F6686976B8B92708D92738B8F758A8D728688788C8E
758B8A7B918E8096938398977F949382979591A7A392A9A698ACAA98A9A9A6B6B5B0BABA
B9C4C5BAC7C8BDCCCBD1DCDBD9E0E1DCE3E6DDE5E7DFE5E9DBE2E8D5DFE5D4DEE4CCD4DB
C5CFD5BDC8CFB0BCC4A9B3BBA2ACB5A0A7B097A0A99399A48D929B868B937B808781878D
767E85767E86757A83757A826E747A6E767B6874766674756372766170755F6F735E7276
587172556D6C536A6C51676C51686C4C666848656549676542615D3D5E5A3C5D593B5B56
3958533656503856523755523353512D4F53264A551C405909305D0530720C35831C3789
2033861232850C307319244200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB4116C4D20352D2308132102153402153C02144006123C170C30
390B2549091A3403161A05270B0C4203105501146301196C02207502237C012482012688
02288C02278F022993012994022C98022F9D012FA2012EA40130A6012FA40031A50134A7
0439AD0338AE0135AB0136AD0137AF0239AE0238AD0338AB033BAF033BB50337B4022CA6
01249D02249D0028A0083FB00A49B00C4BA518539E2359973768994D799E5E819E69849A
79909F72899370888D6E84877186887086847089847288867C93908498978194938B9F9D
8A9E9C91A4A29DAFADA1B1B1B4C2C0BCC9C8CBD8D6D4DFE0DAE6E8E1EBEFE4EEF2E5EAF0
DFE4ECD4DBE5C6CED7BCBEC7B9B8BFA09BA296909691888F8780877D777D787276776F71
796F6F786E6B776E6A756C66776E68786E69796E6A7A706A7E71697E6F687E6F667F7168
7B6F65786D637A6D64786B60786B5E786A5D7268596F65556D65546D6558696156656355
5E6153595C4E5B5D53575B54555C56505C554B5C534C6057475D56435D573E5B543A5850
3D59513C59513B565038545039574F39585233544F3352502C4C54183B530A325D063475
0A3D8E0738871130650F911D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADD0B765526221D17061529011534021437030F33130727350A20
4509192F0315120321050B3E031358021767011A6F01207901237C02248003278703288A
002388062B93022894012691012892012996012A9A02299D01289A022C9D012FA00134A3
0135A60034A80135A90237AA0238AD033AAE023AAF0036AA0139AE023AB1043AAF0432A0
03298B0629811438842751913965984F779B61839B6A87956A858C778F93708688708487
74888B6F8687718786768B897A8F8D839894879D97889C969BAFA99FB0AEAAB9B8BDC9C9
CBD7D7D9E4E6DFEAEDE3EDF2DFE6ECDADDE4CCCDD6B9B8C3A7A7B295939F87858C837E82
7D777B7A74787972757A71717C716D7F6F6C806F6786736985736781706283715F836F5D
836C5A806B537B6A4F7D6C507D6D527D6D557668507B6D547D6D55806E577D6D557B6B54
7C6D567C6F57796A527B6C5376684C76654A76654A74634878674B7B694F7C6B52796C51
776B4F75684E7467507066506F67506D664F6B664D64644D5E634E565E4C505D4B485949
445847465A4D41574C3D544C39534B36534A3958503B5A5137554D2C4B47214249113852
0733610A3366172B490AC80B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007B55241F1A1307192C0116320411300E06212E07193F0917
2A04150F041F040B37031453041B68021E7402217C032582032583012383042687012284
03268B03279001269101258E01258E012691012693022695012697012898022C9B0333A1
0233A10132A20134A30135A60338AB023AAC023BAC033BA8053CA3063B98124291244C8B
3E5F8E547092607A91667E8B6981876E8588708688768A8A718684768B8A768C8B778E8C
7F9695809797899E9C98ACA99EAFACB4C4C1C9D8D4D7E2E0DCE6E7DBE6E9D4DEE2C4C8D0
B3B5BCA3A1AA8F8C94837F867D777B7A72757B70747C6F747E72737D716F7E7169817367
7D71627D74647E7462756C57796E5676695472654C73674B73674D72684C72684B74694E
6A5D42695D416960436A62446B6546676144635D406B654B6D674D6A634A6D68506F6B56
6A67536A675269655066624D6A674F6B674E66624966624A6761496C664D6A664C69654A
6762476A62486C644A666146696547686040665C39675D3B6860406661426160415F6145
5D61475A5D49535B484B59484557484153493B53493855483B5A4C314F4327483D214441
1E4248102F3B115B2000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF005F811A21180A0918230415290C0B222504163C0815260412
0D051E030B3100104602195E021E6E001F78012282012385012083022182011F7F022284
03268C03279100228B01238A01238901248A01248C01238E022491012793012B98022E9E
00309F0132A001349F0237A10339A0053B9A073B9017478E2C568D466B925C7C966E8796
748A916D81836D80816B7D7D748786758A88819696809595839594899B998E9FA097AAA9
ADC1C1C0D3D7D0E1E5D4E2E4D5DEE2C5CCD2ADB0B69A9BA087848A77757A737071726C6B
746B68786B67786A647D6F668073667B70607B705F7F71627E7261756C58706851746D57
6D6A526B6A536A684F6E6A506C694E68644C6A654A6A65496C684C6C674B6A6749686447
615D3E656043686445605D3E62604165614465624563614665624864604669674F666550
646651696A5565675267675665665466675266675163624E61634B5E604863664E61644E
62654F62634E5F604A5E61495F62475B593C5753325955315753305752315653305C5836
5D58375D583A5A583D575B43545C455057464C5A493F54433A5343344E402B493A27483B
244639254336139C1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047B21436230811191B070F1B1C0915380A152904110F061D
030C2D01113F011653031D69021F7501207D002183012285012083011F80011D7D021F81
01208602208B011E8A01208B01218900208701238802248B00238C022691012A96022D99
013299023596053A900C3F891B4886355E8D50739664829A6C869272878E75888B7B8D8E
7A8E8C758987758A8A7A8F8F7F9393879A9990A2A1A5B6B5B5C3C4C8D4D8C7D3D9BFCAD1
ADB8BE919BA17E848A74757B7471756E6969736C68716960766B5F766A5C776A57766952
7A6D5573674F6F654C70684D716C507570557A755B77705A746D576A664D67644A727056
6E6D546A6A4E69674B68644868654966654865644869654A6361446A65496B6649696547
646142666344666445646243626243605E41606042605F425E5D40615D43615F465F5E48
62614C6768536767556967576465526A6B5567674F63644E65685070745E696E59616552
6366525D604C5C5F4A5A5F485D6249605F485A5A3E59583B59583A595837575433575231
5753315651325250345153394D513852543F51563F4D58434555433E5241354E3D2D4A3A
26483525473430462F0CCD0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005A390D1F1A10130D12280810310914130516060E29
01113700154B051D64021D70011E7701217E01218101218402238503208200197B01187A
011A7F001A82001984011F8A03238D01218901228701238801268B022C8F032D8E043189
0B38821A467F305984537693678395708992788D92798C917D8F937B8D8E7E8F8F839694
8195928398948CA19F9BAFAFB4C6C8C4D3D6C7D2D5B5BEC29AA0A581858D6E70756A6769
6966626969606F6B60726A5E706456695C47665B3F675D3D6860406D64466B6044695E42
6B614471684D6F694E6B684C6868497171517976587670566A664C6F6E516E6E4F6E6D51
6E6A4F6863466763436661426966466867496766496561456764446B66496B6649696548
6965476663446665456463445F5F40646345646245615E415C593C645F465E5C435D5C41
5B5B4062604864624D69685461634D63664E62654C686B5361654D6265515E614F606453
696C5A5E62525D614E5A5F4B595E4A5B5F495D60495A5C445A5E425A5D3E575839565739
595A3D57593F5559414C543E464D374B513B494F37494F3848523D4554403D533D354E3A
2D4A382646322B46311DA31700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005F80153A250923100B2C0E121D0913090D1E031431
011540021D5B03206E011E74001E7702217C012180022284022183011C7F00197B00177A
031A7E021B80011D83012188002088012388012385032684042A80062E78123B75315682
56779363808F708A92788D90768A8A7A8F8F80939482939587999A8396948DA09C9CAEA9
B1C2BFBECECDBCCBCDAFBCC08F979E777C816A6D6D6666626A675F6B655A6E66576A604B
666046625F426663456A6447675F44685F41665E3D6A63406E69486C67496A6347655C41
665F436C664C6B694D6E6B506C6C4D6C6C4C6F70506C6A4E6C6C506B6D4E6A6C4C6D6C51
6C664D6B644768624167613E64603F666345605F40656143656343676244696447656145
666245676244656342626143656445656346666248615C42635F43615C445C5C405D5D3F
5C5C3D605F4163624665654B63654B61644960634A61644B62674E686A566B6D5B656756
646755636755646856676D5A5A614D5B604A5B5F48595D44555C41575D4153593C555B3F
565B40575C42535B434D59444451404A5645404D3B323C2938432D424F3641523840523B
3A513B324B362E483335422B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DC0B5C360935160526100F110F19051428001636
021B4E02216701217302227A03247E02227E032381011F81011D80021F84011C7F011B7C
001C7E021F82011F820020840021840226830226760A2D6E244675496987648290708890
7387898196937E93907C908F809591899D998FA09F95A4A4A6B6B6BCCBCAC0CDCDAEB8BA
909799787E80696B6B6867656A65616D685E6F6959706A53736A4F70664B6E664A696246
6C674B6F6D506F6D516D6A4F716C51746D526F6A4E6D684B6F6C516F6C536D6A516D6750
6A654D6E6A51706D536E6A506E6D4F6C6D4E6B6E516A6B526C6E526A6B4F636546666347
69634868614468614067603C65603D615D3D5E5B3C605C3F615F3F615C3C635E40645D40
656043656142666344636242626241615D40605F43605F436160445F5E425E5E3F5F5E40
60604160604063634461604563644961604962624C5F614A60624A656550656753636451
61655060654F5E634C5D644C596149586048585E465B5F495A5F49565D46565D44555B42
545A3F565A42535B42505E494856474353472C40322639292C3C2838462F425038434F37
4350383C4E38344B363447311B9D1100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0045AB0E4B220223110B0E162101152D001840
03205C02226C01207301227B022580022381011E7E011C7D021E82021E84021E82031D80
011D8000208101227F03257B0428721539733A5A815E7A90748B977F95977E93927D9190
8899968A9E998A9F9B8B9E9C98A9A8ADBCBBBBC8C9AEB9BF98A0A7787D82696A6C646362
67656174716A7772687972657A73647B75657A75647874617B7662797460797662777560
76756072735D75755F74725E73715C76715B75715B72705A74755E70705C747160757462
7475617576626F6F5B6E6F587071576E70556C6F566F705B6C6C5567674D636446656346
666144666143666140655F3C655E3A63603D605C3E625D405F5C3E605C3D605A3B615A3D
645E41635F42615F405E5E3C5B5D3860603C5F603E5D60415C5F406060445F5E40605F40
5E5D3F5F5F416060435F5F465E5F485F604B65675164675060634D62614C5D5F465C6046
6368505C634C5D654C5C644B59624959624A5A614A595E485B5F4B5A5C4A555844555944
54574251563F4E573F55655047584933453923392C273E2D32473340503D45533F4D5843
49533B454F373D4E3734452F1EA21500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074451429170B0D1824011837001B4C
03216201226D022273012279032580012482022180001E7E032184032186011C80011C7E
001E7C03247904286E183C6E456683708B997E93978293948B9C9C8CA19E8BA09D90A4A1
91A3A19DADABA6B7B8A9B8B9A3AFB1899192717276605F6262605F66635C6A675B716D5D
726F607C7B7081817794938AABA8A0A5A19C9E9C999C9B9693918B93928A8B8D83818479
8084778185767E80717D7D6E7B7B697A786478776273755F70745D6C6D5B6F6D606D6D60
6C715F6E73646C72616C72606E74607476627175626F73617075626B705C686B5465664F
63644C626349636448615F425F5E3D5D5B3E615F42605D405E5C3E5E5C3E5F5D3F605D40
625F415F5F415C5F405D6041585C3C5A5D395D603D585B3C585B3F5C5C415E5E415E5C3F
5E5B3F5D5C415D5D435D5E485B5E485A5E4A5C604C6165516165505D60485B5F44585D3F
595F445961495B644B626752646A555D624D5B604A585E475A5D48575945585B47545845
4E523D4D533E4D59455061503E50412C40322A3F313349373E533E4959474E5E4D4D5D4C
505D474D563E464F373C49303C442400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003BA40B321D0B111C2A031B41021E56
022165022471012375012379032681042887032887022586012486032586012081032178
06276C1F3D6F4D6988718B98819697869592909D9996A2A19AA8A791A1A19CAEACA1B3B0
AFBEBE99A4A87F878A696F6D5E605A5F5D53665E51675D4E746E5D868674999A8BAEAFA3
BEBEB8CFD0D0D0D1D6E1E1E8F4F0F9EBE4EFD6D0DCCDC9D7BEBCC6B8B6BEACACB09EA09F
989C9693958C9091879494889294858F8E808E8E7E8C8F7C8B8E7A898B7B868578828375
7F81727A7D6E7178676C75646A74636C71616971606A72626A75646671636A74656A7465
697363657160606B5A5B64506067515B624D5E654F60654E5F654B5D624A5B614A596049
586047576149556148545D47515B4350593D565C41585B43585C46575C46565C455B5F48
595C46575A46575C495A604E585F4D57604F5761515760515B63515C644F60664F60654E
5B624A5E66505D654F5B64505B634E5C624D5E624C5A60495D634D585E49535C454F5642
4B523C5058465B685946564B2D42352C4335344A3A3E5241495C494E5F4E5163544D6254
5668565E68544E533B434B3140462200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA1B3C2407131B26041B43031E59
012168052A7C01247A00237A002581032C8D022A8E00258601248401237E01216E15336B
4560806D82908090948D9C9C93A19F9BA6A49AA5A497A2A3A5B1B3A3ADB0A1ACAD798586
676F6D5F605C615E5469635168624B6E644D786D537F765D85816A7777647374657D7C73
86848189898A949298B2B0B9C5BECCC8C0CFB3ADBBA29EAA9A97A296949B908D90888784
88898187887F87887D8384778083717E8172797B6C777A6A7579687375677175676F7365
7377697175676D7465737C6C7782727782736C78696974666A796B6C7C71697B7066776C
64756A6172695B6E66566A5E55685955665957665855655659685957665852625456675A
5264575263565467595463574F5F505261515362515260515260524F5E514C5C4E4E5E50
4C5D4E4A574D4E5A5157645D57665C5B6A615A6B625B6A605F6D5F5D6858626959686C5D
6C71616F7665687461636E5D636D5B646A596369575D64505B634E565F4B4F59444E5642
4D55415B665748594E33463D2F473A3049393D5643465D4B4F625053645554655950645A
5C7064606F5E535B44474D3134761D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005D3E121E1E1E051B3B031F56
00226909368B002A86012682022A8A043195022C900126830325770D2D6B3450765D7485
74858B818F90919E9D96A3A28E9D9D91A0A199A8AA8F9D9E7F8A8A646B69595D57585B50
6463526C67516E664D6E64496F664A6B61456960426961436E684B706B4E736D54726A55
6A64526B66566B6557706A61726C6877716E746D68736D68716D646F6C616E6B5E6C6A5C
6B6B5B6C6C5B6A6A586E705B6A6E556B6E586B6D59696C596B6F5D6D72626A72646B7669
6D7A6C6F7C6E727E7274817473827673857B75877D6F81795F776E59726B577269566F69
536B664C646147625E45615B3F5C54415C55415A53405751445B54425951405752435A57
4058553E55523E57523E58533A554E3B554D3C554C3D544C3E544E3F544D44575042574D
40564A3F534C3E52503B515038514F405854425A53455A504A5B4D4F5C4E565F52595F52
5D62525D63545C65545E69596671616A74646870605A645358625055604C4D57444C5644
5661514E5D52364A40374C413E56463F5742405743506555596B5D5A695D56675957695F
5D70665F6E6158614C4A4F3424A41300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7F182C22110A1B32021E51
002168093B9403389901309103349602349605328A04297021406E4C637B6B7E847A8988
84918D828E8C8F9B98909C9A909D9D8390916E797959625C585B4E62604C6A664E726F55
6F6E526E6B4F6F6A50706A5170674D6D65496E65467268486B63406B633F685F3F6C6245
6D63456D634572674B766951716550796D597C6F5C7A6E5B79705A776F59757058716E58
726E58746F586E6A516C6B506A6B506C6E566B6E586A6E5B656D5C656E6166736864736A
5F736A61766D5D726D59716C56706D4E696549636043605D32544F2546421E423C1C3B37
1C3A3717363316373413322F11312E11312E14322D14302C13302C12302B142F2D15312F
132E2E102D2C0F2D2B10302F1033301D3E3B213E3B28423D31453E3A48413E4D433A493C
3A4D3E35493E28413B1D3A381C3A3925443F334F473F574A485B4A4F5C4D55605361695B
606958616959616B5A667160636F5E687262656F5F5B645456615054614E4B5A47576658
4A5A4F384C42394F4341574A485F4E5166544F62515B6B605E6C625B685E5B6B5F58695D
5C6C625E6A5E5B624C53533313D10900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0027DB0D5237121C222B031D48
01266B053A94033EA4023CA2063C9F03358C0B32722D4B6C5568756E797D778180808C87
838E8A808B8A828E8C76827E626B645B60555D5D4E68634E73694E796E51746C506D684D
69684C6D6C4F6D6A4F6C674E70694F716A4D736B4E746C4E716A4A6F68456F66436F6241
7365417769447B6C497E6C4C7E6F4F80715184735685745985775C86785E83795D80785C
837B61847B627F785F79775F7B7C6471745F6F735F7179686C786B6470685869624D605F
3C53522E4948213E3E1938380F302E102F2C17373124443E2F504A3D5B564D6B65607B75
5C7572506B67486460405C564560583B554E3C554D3A514C394F4A344C44334B42324942
2F483F2C453E2C463F27423C24413C223E391F3A35253E38293E35314137364539374738
3243332B3F3020392E17322C0C28241230292D493F3E54464B5D4C566354677265636E60
5965565A65565D6556595F4D5D644F5D63525C62515B6151545F4D4E5F4F4C615344574E
3C524841594C4860524E645753675A5B6D606170655F6C635C6A60606F655E6F6459695D
5D6C5F616C5B5E6348417F2300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0068891F3D31220D1E3D
052D6E09449E0343AC023EA40637910F34723148654F5D62646A697377747A808077807E
757E7C6E76745E675F565C4F5B5C486B664C71684A6D64436D634373684C70674F67634B
6E6B526C694D6865496E6A4F6F6B4E716B4C6D6748716A4C72674A7569497C6F4E7B6C4A
7A6B4677694278694578684775664472644073654377674A75664A83755A7A6E54796F55
7269517169546A6753686A56696C5A6A6E616972646875676979705264612A413F122D2C
0725230A2A251A3A33314F49536E6672897F8FA49CA5B8B2BBCBC7CDDBD8C3D2CEB5C2BE
A3AEAC8A95947A89836A796E6E7A6C646D5F646E615D655960665B62665A5D6457586050
5965525864555B675A5762585160554F5E524F5E534D5E504D5D4F515C4F4D584C505B4E
535D4E4B5948425443415243364A3C2B4337253E2F2D41324C5D4D6673645D695C5C685C
5965575A65565D63515D604B60634D5C604D5C614F595E4F5560544E5F56445852455A54
4A605750675C586E625F726764756A67756B66736A62716861726760716660726759695D
606E605E66525F603F2DA91400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0E6A4C2226272F
0625590B459A0546AA053D94103670364962545D5F575A53696A6472736D737572676B67
5D61595758495C5A43676346726A4A776B4B7265476B62426E67496F684B6A6348706A51
6E69506762496B66496F6B4D6C684A6D6949706946716543716442786B4B77694B756646
74654273653F72654073654271634070633F6F603D6D5E3D7061416D5F4174664C756A50
7269526D68556265535E655561675A626B625B6B64475A562C4441112A290C2A2524433D
4261596C897F99B3A6BACEC6D2E1DDECF4F2F6F9FDEBECF3DADAE3CBC7CDB0AAA99F968F
8F8378857769796E5C736A53766C51776B507A6C51796B4F77684D806B537C6A4F79694C
7C6F508072597D705B796E5C776D5B746B59726A55706951776E547D7055786C52796D54
73684F71694F6562485C5C43595F48535E4B485746394838384938536050606B5C5F685A
5C65535D655061654F61634E6164505D6152576052545F554D5D544A5D574E625C536662
5C6E6761736B6779716A7A7061716768766E66756D67777164756E63746C637369616F63
636E5E65664E655C3430A70C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B318503C28
17284615468C094091133A7332445B4E54545B5E5461635667695E686A605D5F545B5B4B
5D5A426862426C653F7066426F654375694B7267496961436A65486D694B686346726C4F
6F684C6661446E6A4C706C4D6D694A6D67467065416E613B6D613B6A63406761426F6546
7064416E623D6E613C74664271623E70623B71643D72653F7265406C5F3D7265476F6449
6B644B66644E666857646A5B626A5F4D5D582239360A26220A292522403B58756B86A099
9EB5B1ACBFBCB0BFBEA6B1B2A4A8AC9F9BA09A919691868A8F82828D7B778D7B6F8D7A66
8D785E887255816B4A7C68457C68427E6842806B437F6A41826C42876B448568408E7145
91764A90744D89724F897254856E52866F538672538B7452957E59937B58927D5E917D60
8875598272537E6F51756A4D6D674A67634A63654E5B63504E5B4A4954455E6455636656
61644F61654E6367516266545B62565C675E56655E526460536863586F685A6F6862746F
6C7B77707E7C70817B6F807764756D6C7C766D7C766B7B7668777168756F65736B636D63
6669586B63446D582546B71500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00855E2D
342F3226426F183968314256494D4A535449585C4C6063515E604F595B49595943625E42
6D64436C5F3A6B5E376E66416A62426C634473694A6D674966624469684A6E6C4F6B674B
6F6A4D6A6547676243746F4F6E694A6F67476E633F6E613A6C623B6A65406A65456D674A
6C66486E674971694A7065446D623E6D643E6A60387168407269437169486E6949696446
6A654A686750626554535B4F36443C0B221E0C2B242B4B424E6C647B948E8EA19D919E99
89908E7B7E7C70716C716E67716C6579736B837F748D897B9D96849C93818A82706D6450
6A644A7A745A7C765D736F55635E435E593E5B573A5E5A3867603976663F79653C7A6439
76613578643B7868437B6A4A7866477666476E63446C61436A6145665D4765604D656351
60604D5E5D4966634D6C69507570536A6346686449666852696F5E5A6051626556626350
6568526067525C66545F6B615C6C665E726F5D73716A7D7C697D7B6E847E687B7571817E
78878575848471827F70837C71857D71838072837F6E7D786E7B766A756F67706864685A
686148705B2D68902000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE10
583D1F404147323A3F46463D5251405959465D5E495B5F455A5D415C5C3E5C5A3A615C39
63593267592F675B3069613A68623D6C634074684872694B6C67486763476A674E706D54
6D684C6C66476E68466D68466F694A6E65457367447266417367416E6440736A47726949
73694B736A4C72694C6C64466862446A66456A643F6B623B7069446D6846686442666141
6D684B65654E444C3B2C392E50615A4159533452484F6B5F697C73757E78747871737368
7571647C75677F77657D746065634E797D6A989E8FB1B7ABB8BCAE9D9D8F8A8879777767
7174657A8075687068505D5545554A3B4E413548373B4B35434B2F615F40756C4A776946
73633E726441736849736C516C6A516567505C624E555D4B545F4F525C4F535E51556256
5663555C685A555C4C5A5D477B7961726D54706C536D6A5671715F686C5B656956626856
5F69575E6C5E68786D6B7D787185827389877087847D908E7F93917D928E778C877D8F8D
7C8C8A7B8B89768A85768C86758B857487867182816E7E7B6C7A74656E6764695C67644A
6F5C30678F2000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
5C7F1A473419473E2750492F5A553B5F5C445E5B415C5C3D5E603D5D5D3A4D4E2B534F2A
615529635424635627645A2C635A2D645A2E6B5D356E603A706440736A4A6F6A4F6B674E
676449635D3D665E3C6A63406C65426E65436F6543716745756946726643746844776944
7568437668457567477264456D62436B60416F63416D613C6C613C615833655C37766D4A
70694B6060473D473668746ABBC8C3606E6C57685F5362565F685B6C6B5B74705C74715C
73725D77756073725D71705C6D715B7077637D81728183768385788687798182746D7265
5B675E4758553C4F4F2C44441C39351938311A3A2C2F483648563F67684C766E507D6F4F
746948736C4F7C7A636F7462636D5F5A6A5D55675A56675C57675C5D6B615F6E615F6F62
59695B505C4B5A604B706D5775705A75705C74715E7471606F7061656A5B656F5D667366
72847A7A8E897D908D8092918092927F90917C8F8F869897869998859A98819794859796
8192918496938195927D9390778D87748785768585707C7B68736E60665A6360456C5D2F
66912200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59780D5337115544255A4F3062593C635C3E635D3F5A57395455385257384A4F2F504F29
6158296657256959276859286759286357246B5B2B6D5C2F6F5F3572643D716844706A4A
6F6A4C6965456965426C67436D67466F68476C67466A65436B62416F63406D603C6D5F36
6E5F3471623874643C7968427D6C467B694276633B76653B73663973663878693F7D6E4A
746A49636144444834898F82979C9660625C65685A6066567177667573607A7661767561
707361727968656E606672666B78696570626C7467687064646F6558655E43524D334641
1F3633142D2C08252402201E0929231C3B32415C51596B5D646C5776715672664973684B
6F6C527A7E6C7982756C7B7063776E647970657B70697A7069786E68756B627064506053
4A5A4B5F68546D705974725C75735E7776647475666F74676D766B79857B8B988E859591
8C9F9D99ABAB9AAAAA95A4A492A1A38897998696968B9A9A8494938093928B9F9D90A0A1
8A9B9B8999988294947E9290788985788984717F7B6E77736B6D63686247756132997734
29DE0C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6A40045A40155D4C2A6657376A5C3D6B5F41565436333A1F303E26414F374D563C515536
57542C5D54246456266B5B2C66572766572565552669592C6B5A2F6D5D326D603670663E
746B457069466E6A466E69486E694B706A4E746E53777154716B4C6A62416A5F3B6D5E38
69593167592E6C5E326E60346C5D336F5E346E5C306E5E2E6B5E2D6A5F2E6F623572633D
72664365603E5B573B6F69527C766167604B6C69517479656C7262777663797462787563
6E736541504828403C1E3C371C3A341B353018302A162F28112C270E2825223938384C4A
3D514F3E5353425B595169635D7368576A5D5D6B5D676F5F71725F746F557771567B7A63
7A816F7B877B7C8A8272857C687E755F776E50685F4D6258526158536159536056556253
5F6858747765787A65797C697A7F6E8085778A93879CA79E9FADA5A6B3AFABB7B5A5B1B3
A3AFB1ACB8B9ABB6B8A2AEB0A2B0B19BA9A99AAAAA9AA8A99EABAB99A7A795A4A494A3A6
909F9F8A9A9A8798988291917E8C8877847E6C756C6F70616B5F427F643077992600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB40F
613D04604B1C6758306B5B396D5E3F564F33343A22223420203724293F2D455543515B47
595D415654305D552C5F552961562A5F562863592E675B326A5C346C5E37695D35695F36
6E633C7067416D6641706B49736D4F726C51746E55706B517670567973567B75577C7357
786D4F7167466A623D6C653F6E633D70633E6E61396E61376C61356C65396D663F6C6441
726A4A6F69476F65416F5F3B71603A6C613C726F516E725C767A67807E6B7E7A657E7D6A
4C5548283E38203D3A1738341638331B3B3723423D36554C506D6592ABA8DAEBEBF1FAFB
F0F6FBC8D0D798A1A4848D84767C6E6C715E74766171715D6767556D715E7077656B7869
697A6C6D7D7473807A707F796F817B6E847D667D7760746D627069646F676A7466757C69
787E697A7F6D898F7E9EA699AEB7ACBFC8C2BFC9C4BFC9C4BEC8C5BBC5C5C2CDD0BAC4C7
B6BFC2B4BDC1B0BABCADB7BAADB8BAA7B4B5ACB9BBA9B5B7ABB6B7A6B4B49CAAAA97A5A6
8F9C9D8B9A9C8B999A818C8D7B838073786E6C6955766440916F362ADF0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0044AD07
6443096955246C5C316D5D395E563740432B2F3D2A273E2B223B2A233B2C2D4334415244
535F4D555D45595B3B5E5C3965633F6865426561406862436A644469624168613F67603D
6C63406B63416C66456E6A49706A4D746D53756E54746E53746E516F6A4C746D50736D51
746D52736B50736A4F787154777254777052726B4A726C48726C48746F4D747151757156
7B765C797357776A4971603B7460356E5F326F6946706E557B7A64807C667F7A647E7D69
636A585A68595564565A695C5767595A685C5F6B5E6B76687D877A929992A4A3A4B0A9AF
A59EA4948E92827E797E7968817C617972557B785B62644E4B55444B5848505F52607066
819288C7D2CFE3E9EBDEE5E7BCC4C899A4A67E8985777F767C827680867A888E7E999F8C
B6BCA9CBD2C4D7DFD7D6DDDAD6DDDCD4DBDCD0D7D9C8CFD0C4CDCCC4CBCEC1C8CBC2C9CD
BEC6C8C3CBCDC5CED0C0C9CBBBC5C7B0BABDB0B9BEACB5BBAEBABBA5B2B39CACAB95A3A5
909D9E899799869293787D78716F60726448856B3C779A2D2BDF0E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042AA04
705011705B29705F31675C374A4B313947343247352F46342B43312A42312B42342F4437
3A4D3E4D5C4957624B5B60485D614761644964654B64644B65654B67674B6A684C6A684B
6C684B6D684C6F6A4E716C50736D53746D55716B52726C51736D4F726B4A6D6544716647
74674A746749726649746C4F726C4F726D50716E4F737250757252737050757154726E54
756E57756C547A6D507A6B4979683E7261356D6037706645756C507A72587F765F807962
7F7A608A8468948B6C988A6B94866798896C9C8C70A291749B896C99846C967F6C917B6D
8E7D6E8A7D6C8B806B83765A7F704E7C6D4A8880636B6D5757614E5B67555F68556E705F
807F709E9890ADA5A39D98998D8A8B898784908E87A7A49AC4C5BBD5D8CFEAEFE4F5FAF0
F4F8F1EDF2EEE7EBECE3E7E9DDE1E4D6DBDFD1D6DACCD1D4CFD5D5CED2D4D7DADCDEE3E4
D8DFE0D8E0E2D5DEE0C7D1D4BFC9CCB7C0C5AEB8BCA9B3B7A9B4B6A3B0B29AA9A995A2A6
8A9798818B89787B717067507E683E9D793E2BE01000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0045AD06
775614755F2B6E6032565331444E383E52413B5341354C3B344B3A364D3C324839324738
3246343A4B384754425862505C6551606651616550626551626551666A5466674F6A6950
6D6A506D68506D68516D68516E695275715C736F5A74715A736F54736E506D6849726B4D
756C50786E51766E50746F50716D4F7975587775587A795C79785B7E7C607B785E7A7860
7C79617B735C7E745B82755A8679598074517F724F7C714F78704D766F5079715581765A
7C72518174508978508A754C87734987714A85704A826C44826C448269427D66417C6847
7D7152827A5E7D785B7D7354776A45766842756B496E694D6B6D5374775D8280639A8F72
A6987CA59782AFA496BFB8AED4CFC7ECEAE3F8F6F0FFFEFAFFFFFCFFFFFCFBFDF8F7F8F6
F7F9F8EFF0F2EDEFF1E6E8EBE5E9EDE6EBEFE1E7EAE0E6E9E1E7EBE6EBEFDFE4E8E4E9EC
D8E0E2D5DCDFCED5DBC0C9D0BEC8CDB5C0C3ACB8B9A9B4B6A3B0B1A1ADAF9AA3A5899190
7E827A756F5B7C694494743D54C01F00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CB40B
7D5B17725F2962593053573D4654433C53423C56443D554642574A4055473D52453A503F
384D3940523D41513D43503E4E5847575D4C5B5F4F5C61515D6353616555656855666852
6F70596C6B556B6C556E6F586C6E5771715B71705B74735E75745D75725A78755D73725B
78755D79745D74735971715675745C79766078765E78785F76765F7878637C7D687E7F6A
7E7F6B7979647B78627D78617D7961827E6588846A89856B88876B8A896F89876B898569
8C88698C8968908C6B938F6D9793719994749992739990719C94749E95769C96779A967A
9F9E849FA088A3A58DA1A2879F9E81A19F829F9E839B9B819C9D85A4A48DB5B39CCFCAB4
EAE3D0F8F3E5FEFBF3FFFFF8FFFEFAFEFDFBFEFEFDFEFFFFFEFEFEFEFEFCFEFEFCFCFCFC
FCFDFDFBFCFEF5F6F9F2F2F8E9ECF3E2E8F0D9E0E5D2DCE1D0DBE2D1DBE3D3DBE4D1D9E0
CCD4DACAD3D7C5CED3B8C2C8B7C2C6B2BDBFA8B6B6A4AFB0A1ADAD9AA09E898880796E5B
7E6A4498773E52BE1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA11
845F1B725E295D58324F57404A5A4B4056483C5647415B4D475F52465D50455C4F445D4B
4059434458444657444856444F5947525845565947545A47525C48535C4A58604E5B6352
696F5E7278647178646D77636B746070736071716073736071735F70725E6D715D6C705C
7374617878667E806C7F826D797C677777637475607778627374607274647B7F6F7E8270
7D826E7478637679647B7E687F816C8689758D917C8F927F8D907D868A78868A738C8F78
8F957D949B82939A83979D8897A18B9BA18DA0A391A3A593A4A793A8AB98ABAF9CB5BAA9
B9BEAFB9BEB2BAC0B3BCC2B4C2C7BAD1D4C9D9DED1E4E9DDF1F5EBF9FBF3FEFFF8FEFEFA
FEFEFAFEFEFDFEFEFCFDFDFCFEFEFDFDFDFDFEFEFEFDFEFDFDFEFEFEFEFFFDFEFEFCFDFE
F6F7FAEEEFF5E2E5EBDDE0E7D1D7DFD0D7E0D1DAE1CCD6DFCCD9E1C8D4DDCDD6E0C7D0D8
C6CFD3BFCACEBBC7CAB7C3C6B4BFC3ACB7B9A4B0B09EA7A38C8C817F735C856C45729831
2ADF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C621B775F2A5A542F49523B4D5F4F495E52425B4E3F594D465F534C65594E655A506858
516955526654516051546051555F4D59604B595F48565E47525C464F5947505B4B535F51
596557606C5D636E61697569707D706E786B6D73656D71646F75656E7767717B6A737D6B
71796872796A747B6C757B6B747867757866787C687B806D8388787E83767D84767C8472
7E87747D87737E86737F8775868E7C89907F8A92819196889196898F95878D9482939C89
97A39097A49195A38F9DA9989CA998A4AC9EA9AFA4B2B5ABC3C7BDD4D7CFDEE1D8E5E7E0
EAEDE6ECEFECF2F5F2F8FBF6FCFDFAFEFFFBFDFEFCFDFEFDFEFFFDFEFEFDFDFEFDFEFEFE
FDFDFCFDFDFEFEFEFDFEFEFEFEFEFFFEFEFEFCFDFFFBFDFEF5F8FAECF1F5E4EAEDE2E7EA
DBE0E6D6DBE2D1D7DED4D9E1D3DAE1D2DBE2D2DCE2CCD6DDC7D3DAC5D0D8C9D3DAC4CDD2
C0CCCEBAC5C8B7C5C6B4C0C2B2BCBDA1A3A188867A7B6F578A7146789D342BE01000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6E8D147A5E235F552D454C33495A484961514B6658466053475F544C625951675D586F63
5D73666275685F6E63616E63636F6165705E626B57606A555D6753576150556250546252
536052525F5354605755625956675C5B6B61606D6265706768756A6473676A786C6D7A6D
6F7C707581767582777886787784747C88787E8A7A7C887A7A867B839086849186889488
8392848493848998898B9A8A8C9B8A899786909C8C959E91939C8F99A2949EA798A4AD9F
A7B2A3B0BBAEBBC6B9CCD6CBD7DFD4E4E8E1F1F4EEF8FAF5FDFEFBFDFEFDFEFFFCFDFEFD
FEFEFDFEFEFEFEFFFEFEFDFDFEFEFDFDFDFDFDFDFCFDFDFDFDFEFEFDFDFEFDFEFEFEFEFE
FEFFFEFEFEFFFCFDFEF8F8FBF6F7FBEDEEF3E2E6EBD7DEE4D6DFE4D2DDE3D2DCE1D2DCE0
D1DADFD5DEE4D5DFE4D1DBE1D0D9DFD0DAE0CBD7DCCAD5D9C8D3D6C5D0D5C4CFD3C4CED0
C0CACDBEC6C7B2B8B79D9F998A8373857353957A497BA1332BE00F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DC0987621E6C5B2A4B4D2C4E5C47495E4F486251526B5D51685C52675D556B62536B61
576D6262766C68797168786E6C7B706E7A6C6C7867697564667260626F5E5E6E5C5D6D5C
616E5F5E6B5C5C685C5A695E5D6E635F6F655E6C635F6D6461726A5D6E655B6D6365786F
697C756A7B77697B766A7D7670847A73887D768980778A8281938D80918E84959080928C
83978F889C938FA49998AB9F9EB1A2AEBFB0B7C5B7C4CFC4D3DCD2E2E8E0EFF4ECF4F7F1
F8FDF6FCFFF9FCFFFBFDFEFCFEFFFDFEFEFDFEFDFDFEFEFDFEFEFCFEFDFDFDFDFCFDFEFD
FDFDFDFDFEFDFEFEFEFEFDFDFEFEFEFEFEFEFDFEFFFDFEFEFDFFFEFCFEFEFBFBFDF5F7F9
EEF1F5E9EDF0E0E4E8DDE0E7DDE2E9DADFE5D5DCE1CFD8DDD0DBDFD3DFE4D4E0E4D5DFE2
D2DCE0CED8DECAD6DCCBD7DCCAD5D9C4CFD2C7D3D6C0CDCFC3CFD2C4CFD1C0CACCC0C4C7
ADABA8988F858B786192785279A03C57C32400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007492187D601F5E55284950364D5D4D485E50506759536A5D586D63576D655A7169
5C72695F756B60746A67796E6E7E73748075738172717F6F707D6D707E6E6C7C6C6F7E6F
6C7A6C6C7B6C6C796D6E7B706E7E756C7D7472817973827A798981788B83748982788D88
859895869896849695879A988AA19D8BA39F97ADAA96AAA69DB1AF9FB1B2ACBEBFA7BBBA
AFC3C1BACDC9CADED8CDE1DAD3E5DCE1EEE7E7F2EBF2FAF4FBFFFCFDFFFDFEFEFDFEFEFE
FDFEFCFDFEFDFEFEFDFEFEFEFEFEFEFEFEFEFEFDFDFEFEFEFDFDFCFEFDFEFEFEFEFEFEFE
FEFEFEFEFEFEFDFEFEFEFFFFFDFEFFF9FBFCF3F8FAEEF3F5E9EFF0E4EAEDE0E4E8DDE2E6
DEE4E8DAE1E5DAE2E6D8DDE2D9DFE5DEE4EAD4DBE0D6DFE1D4DEE1CFDADECDD7DACED6DA
CDD6DACCD5D9C8D4D8C5D2D3C8D3D5C4CFD0C8D1D3C4CCCFC2C8C9B6B6B4999086917E6A
977A59A7835357C2292DE11100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006D8F15745B205954304E5843475A4C4C6355536A5D5B70655E736A5D726A
60746C60736C64776D65776C68796E68786E6F7E75707E7472807573807478867A77867A
73827874837978877D76867E77898171847D7F928B84938D7F8E898697928DA19F91A3A2
8B9E9D95A7A695A6A592A6A4A1B6B5A6B9BAA7B9BAAABBBBBAC9CAACBDBFB2C5C7B7CACC
C5D7D8C2D2D2D4E4E4D8E7E7DDEBEBE7F0F1EAF0F0F5F9F9FDFFFEFEFFFFFEFEFEFDFDFC
FDFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFDFDFDFEFEFEFDFEFEFDFEFFFDFDFEFEFEFF
FBFBFCF8F9FAF2F6F7EDF0F2E7EDEEE2E7E9DCE4E6DEE5E8DBE4E5DFE9EADCE5E7D7E0E2
E2EAECE2EAEEE1E9EDE3E8EDE4E8EDDCE1E8D2D9DFCDD6D9CED8DACDD7DACBD5D7CBD4D8
C6D0D2C6CFD2C9D3D5C8D2D4C9D1D2CACCCAB8B4ADA1968A94816C9A7E5CA7805156C027
2EE11200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006C8D167259225C583648553D4A5F4E53685B5A6E635F726961736A
66776F66766F6979736F80776C7E756C7F786E807972827A73827972807872827874857B
73867D74867F7A8B847B8D867F938D819590879B978699968DA09C8FA3A095A6A598A9AA
9AADAF9DB1B1A4B8B6A4B8B6B3C4C4B2C1C3B5C5C8B4C3C7C3D2D4C2D4D4C3D5D6C7D8D9
CDDCDED2E0E0D2DFDFDBE6E7E2EBECEBF0F2F3F7F6FCFDFEFFFEFFFFFEFEFEFFFEFDFEFD
FDFFFDFEFEFEFDFEFFFDFDFEFBFDFEF9FAFBF9FBFCF6F8F9F2F6F5EFF2F4ECEFF1EAEEF0
E7EBEDE9EEF0E6EBEBE9EFF0E3ECEBE1E9EAE0E8E9E3E8EBE4EDEDE2ECECDFEAEADFE9EA
DCE3E6D5DCE2D5DEE3D7DEE3D5D9DED5D9E0CCD4D9C9D2D7C9D3D6CCD4D8C9D2D4C9CFD3
CED4D7CED1D3C6C5C4AFABA39A8F7D9882659F80587DA13F5AC42A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CB61381632A655B3354583D515E4C596A5D61726866776E
68797066766E6B7B746C7E746C81766B807873857E76868077857F7887827B8C85798C83
7D908981928E80928E829691899D9A889C9A8CA09F91A5A38DA29F95A9A699ABA99FB1B2
9CAEB0A9BBBBB0C1C2AEBEBFB8C6C7B9C6C7C0CDD1C4D3D7C8D9DAD0DFDED3E0E0E4EEEE
EAF1F2EDF4F5F1F7F7F3F9F8F9FDFCFCFFFEFAFDFDFAFCFDF9FBFBF8FAFBF4F7F8F3F6F7
EEF1F1F0F3F3EEF2F3EBEEF0EAEFF1E7ECEDEBF0F0ECF2F2E8EFEFE6EDEFE8EEF0EDF2F3
EDF3F3EEF4F7EBF2F2EBF2F4E4EEEDE5EEEDE4EDECE0E5E8DBE3E5DAE4E6D7E3E3D6DFE1
D6DEE0D0D9DDCFD9DBD1D9DBD3D8DCCFD4DACDD3D8D3D9DDD2D8DBD2D5D8C6C6C6B1ACA5
A194879B86719D8061A8855983A73E2DE21400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DE0D698D1F78612E68623D5D644B5E6A59637367
6B7C71667970687A716F81766D81766E837974837D7A85807E8A847A89837A8C8780938E
8596928A9A968C9E9B8DA19E95A8A696A9A897A9A99AADAEA1B3B4ADBEBDABBDBBADC0BF
BBCCCCC2D1D2C3D1D3C1D0D2C2D1D1CBDADBD7E5E7DBE9EAE5F1F1F0F9F9F7FDFCFBFFFE
FCFEFDFCFDFDF6F9F9F3F6F6F4F7F7F4F5F7EDF1F2F0F4F6E9F0EFEEF4F5EDF2F3ECF0F2
EBEFF0EFF3F4F2F9F8EEF5F5E9F1F0EAF1F1EFF7F5EEF6F6ECF5F3E9F1F2E9F2F1ECF3F4
EBF0F2E7EFF1E3ECEDDFE8E9E0EAEBDEE8E8DAE4E3DAE2E2D5DDDED5DFE0D3DFDFD2DADC
D0D9DAD0D9DBD4DDDCD4D9D9DBDCDFD7D5DAC8C5C5B6ADA6A9998A9C87709C8362A7865B
80A23E59C32900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0027DC0B658E207A65336D6340696951
666F5D6573656C7B7072817573827873857B7988827A867F7C88827987807D8C887D8E8C
869693859692869996889C9B8FA2A18FA1A295A7A898A9ACA0B2B4A9BABBB5C4C4AFBEBE
C0D0CFC4D3D2C5D3D6C7D5D8CCDDDED0E0E1DBEAECDCE9EAE7F2F3F2F8FBF3F8F8F6FBFA
F4F9F9F2F7F7F2F7F8F4F9F9F3F7F8F6F8FAF6FAFBF6FAFBF0F7F6F1F7F7F1F7F7F1F6F7
F4F9F9EBF0F1F1F7F9EEF6F5E9F2F1E8F1F0E8F1F0E6EFEEE6F0EDE8F1F0E4EDECE5EDEF
E4EAEDE1EAEBD9E5E6DCE6E7DAE3E4DAE3E3D7E1DFD7E0DED8E1DFD6DDDCD6DEDCDCE1E0
D8D9D9CFD0CBC7C2B9B8AC9CAB9785A28771A18364AB875B5AC7305BC42800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADF0E47B618866931
7561366B63416D6D536B715D707A6B7380747484797988807B89827F8B867A888480908D
8395928295928499968398978EA3A28FA2A490A2A393A4A696A8A9A0B2B3A8B9B9B0BFC0
B6C6C5B7C6C6C1CED0C3D1D4C8D7D9CEDEDFD0E0E2D5E4E6DCE9EADFEAEBE0E9EAE2EDED
E7F2F2E6EFEFEDF4F4ECF2F2EDF1F2ECF0F1EDF2F4E9EEEFE9EFEDE7EFEEEAF2F1E8EDEF
EBF0F2E8EDF0E9F0F1E6ECECE5EDEBE6EFEEE3EDECE3ECEBE3ECEBE2EBEBE0E9E8E4EAED
DDE4E6D6E0E0D6E0E0DCE1E2E5E6E8E6E7E7E2E4E1DDDFDBD2CFC9BFB8AEB6AB9AAD9B87
A48C73A68A68AB8B5E57C6315CC72E5EC52900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28DE0D47B5188E6E347F6A3C746843726D4F71735A777D6A7981747E847D7F877F808C86
82908C80918F839794809593879B9A90A4A48D9E9F96A8A89CAEAE9FB2B2A6BABAA9BCBB
B2C2C1B7C7C7B9C8CABFCED0C6D5D6C9D9D9C8DADACFE0E1D5E4E4DAE7E7DCE7E6DDE8E8
E2EDEDE1ECECE5EFEEEAF1F1E6ECEDE8EDEEEAF1F0E7EFEEE7F0EEE4EEEDE5EEEDE6EBEE
E7EBEEE5EAEDE2E9E9E8EDEDE3E8E6E4E9EAE4EAEAE6EBEAE5E9E8EAEDEDEBEDEDEEEDEE
E5E5E4E3E3DFD6D2CBCFC2B9C3B0A5B7A092AD967EA88E6EA98B647DA44757C5305BC62D
2EE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BF204ABA1E6B962D8A713F836F467F6C4B7F70537F775E
807B6983847681877C848D8585908B8C96948A96948B999890A2A099ABAA9CB0AFA4B7B7
A8B9B8B3C2C2B2C2C4B7C7C9BFCED0C5D5D6C8D8DACBDDDED0DFDED7E1E1DEE7E6DEE8E7
E2ECECDFE8E8E1EAEAE4EDEDE3ECECE7ECEDE6EDECE8F0F0E9F0EFE9F1F0E7EDEDEAEBEE
EDECF0EEEDF2ECEDEEECEAE9EAE6E4E9E3E0E1D8D4D5C8C2CDBEB3C6B3A4BBA694B49B85
B09578AE906FB18E6759C6385CC7355EC6312FE31700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C32453C0224CBA22
47B7239A77478E724687714B85725483725783775F837D6683826E898A798C8E80989A90
9EA49AA0A69EA6ACA5ABB2ACB8BDBBBBC0BFC1C7C6C0C6C3CCD0CCD3D4CED5D6D1D2D4D1
D6D7D4D7D4D2D8D5D2DBD8D5D5D2CED4CFCBCFCAC4CCC6BFC7C0B5C0B7ACBFB3A7BEACA0
BDA898B69F8FB09A84AE957AAF9272B2926EB2906A87AB505AC7375ECA365EC83130E418
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059C32657C32851C0274CBE264ABE2845B92543B826
6F9C3C9B80529A7F529B81579C815B9E84619F84639E8361A18662A38863A68C66A88D69
A98B69AC8D69AE9069AD8E66AB8B62B08F6581A94C81AA4A54C63556C6335AC9365CC834
5FC9335EC83030E41700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0108209 0.97619 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 181.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000]B000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooolP003o000@00[f0`0W
f``09]/<05F^6P1bTR<0Li8T07NC901eTbH0VG8g09]d>`2JMCd0LiP`07JJ<P1hVc<0IJd^03g?7080
:MlC00D0:=hA01oV3000o`002_L401C^1`0Q003o00T0oooo8000o`001010h000P<0008300030X00;
0?n000D0P<0000<00?l0043P0020`0008@00o`3=0?ooo`002P3ooolL003o000P02KJ2`25OBT0UV/`
09I_<`2GLCP0Uflj09I^>P2HL3`0Wg920:Ef@P2`NDP0]G]>0;InD`2gQ5`0^X=K0;^5GP2cQe`0/XYP
0;:9H@2aR5h0[hMN0:f6G02YPU@0YWe<0:9kBP2MNT@0WWY207JK<@1=_1h0C;XL04^h6`1>^A`L003o
00T0oooo7000o`000`20`000oh000?n0000M0?n001`00?l0c@3oool000X0oooo5@00o`00;00Dk@H0
9]X;02KJ2`0/d@h0II/R06nB9`1`Ubd0VGI209afA`2ONDd0XWY?0:1aB`2LI4@0UUHl09M==P2VAc80
]SlY0;Xf8P2k;ah0^R/N0<mBA`2b:a`0[b@E0:0_702JAS<0OBXK08D_8@2<=BP0T3d/0952;@2BB340
ZFeD0:1/C@2RM5@0Wg=?0:UlE02SOe80Wga<09]gA@2KM3d0QhDd07>F:`13`AP07N@:5`00o`090?oo
oaD00?l000@0@>0008300020`000P<009P3oP002083001L00?l0c@3oool000X0oooo4`00o`00<P0]
d@`0FZ8J08mX<@2>Jc@0TVlj09UfAP2KM4X0UVM308]H=`23@bT0PRhK07/M3P1l5@T0P@d708@81`29
20T0S@L:08l5202M1`P0/`h;0<PD403E5140e1D@0=<D3P3A50d0dAH?0;dC3`2U3@`0WQ/L09TR8`2;
20X0T0X:08X82P2R>C/0SB/Z0:Q=C01d4@`0RBHO07LP5027@c00aIf90;^RRP2[TG80XHIO0:21DP2J
MSl0Nhh`06jB9@1D[AX02_H34`00o`090?oooa<00?l000<0P<000<2P003oP0009`3oP0000`3@D7P0
oh000?n000030?n000030<2P0010h0000?l001800?l0c@3oool000X0oooo4000o`00=`09mP<0Ak@C
07Yi902:JC80TFdo09=UA027DCD0NcdV06lP4@1Z3PD0K0L207060`1h0`<0Q0@408X50`2?1@@0U`D6
09T51`2N1@L0X@H:09`6202G1PT0U`L;09l82`2g3`l0dQLC0=hH503R6a<0h1PA0=lJ4P3J5`l0aQH@
0:dQ7`2F61H0ZQlO09d:302K1PT0U`P709@K4P3=NVX0QBLO09/^;@2I;2`0VTi90=2i/`3<`k/0dLNk
0;b^V`2dWhD0[9=`0:65G@2MOD`0U70e062F6P0Sf0L04@00o`090?oooa000?l000<0@>000<2P003o
P000:@3oP000103XJ3`0d51h0=1@N02h>;@20>QX?0@0oh0000<0P<00003o0000o`003`00o`3=0?oo
o`002P3oool?003o000i01;/1028Hb80RfXi09=]A@2JK4`0OCXW06`A201b2@D0M@H307T4101l0P<0
O08407/11@250PL0S`@609<4102H1PL0X0H80:X9302X1PP0[@P:0:T82`2U20`0WPH;09l:302S30`0
/`l=0=0H5@3T71H0hB@L0>8l<`3N6a40hQTA0=l`;02_7A`0VP@50:@82`2X2@T0X`L709TA3037JEd0
Q1/D07h31@1k20H0[UA;0:MhK`3?_kT0_k^d0<_6`P3:`kd0dlRm0<2dYP2iZ9D0X8Y[09IiB@2>JBl0
=/L>01000?l02@3oool?003o00030830003oP000oh0002X0oh0000<0d51h0?n0002P8?000P3@D7P0
103oP000X23`0=1@N03@D7P20?n0000308300000o`000?l000h00?l0c@3oool000X0oooo3@00o`00
?@0[cPP0E9hF085a;02<Hcd0OdD`07@V6P1_4PX0M`L608@6202710D0QP@408L40`2?1@L0S@<708/2
1`2A0`H0W0D709l51P2S1`P0Z@L90:/72P2]20T0/@T90;8:2`2X1`/0Y`T<0:`<3`2/40l0Z0l;0;8>
2`376A80gdi50>9FD@3Q8QH0iQ`C0><M5P3F7AP0_A<B0:L=3@2N2@X0XPT909`81`2L3Ph0U@X708T3
101i0P<0NPh<078G4`2eQ840f<c:0<k=b`2n^KH0_[N`0;JaZ@35`K/0b/>l0;j`X@2_Vh00Vh5H05jX
:@09mP@03P00o`090?ooo`d00?l000<0P<000?n0003oP000;`3oP0001@3@D7P0^3Rd0:0Pl02P8?00
^3Rd00<0d51h00<0j6Pl0<2P0010h0003P00o`3=0?ooo`002P3oool;003o0011032o0P1dHa<0Q5l_
07e<;01a;a`0JA4807<7201l10T0OP<608430`290`@0S0@208d50`2B10@0V@D609/51P2I1@H0W@H6
0:H82@2Z2@X0ZPL90:/7202^2@T0/`X;0;<;2P2a2`X0[@/:0:/<2`2[3Ph0ZQ0>0:hB3P2_5100YaXD
0>>TW02jM6/0WB@L08lL501i5a00JA@?05lC3@1D4Ph0E@l=06P?3P1j3a00V1dN09X;302K1`P0S0@3
08<20P231@D0PaTI0<bCTP3?`;d0a/G00=C?b@2l][40cL[70<_:b031_k`0cL_80<c8`P2k[Y/0TXeK
05NT:P0Bk@P03000o`090?ooo`/00?l000<0`:000?n0003oP0007`3oP0000`3XJ3`0oh000?n0000?
0?n000040>QX?03@D7P0j6Pl0:0Pl080d51h00<0^3Rd0=1@N02h>;@00P3XJ3`00`3oP000@>00003o
000;003o0<d0oooo000:0?ooo`T00?l004@0:<X2071[4022FRP0K3dP05lD2@1Z20H0L0H607@51@1h
0`D0O`<708<31P270`@0SP@609051P2C1@H0U`@609X41P2P1@L0XPL90:871P2Z2@P0[0X90:d:2`2]
2PT0[`/:0;8:2P2e30`0]0h<0:l=2`2^40`0Za0=0:PE4@2P7AP0RQhI06XM601@<Rh0J5U>08MaIP2R
ShD0^JRM0<BdZ@31]JX0^:fQ0:2BQ`1gIEd0DSXd03XE4`1L3Pd0S0l>09P;2@2H20L0XQ<?09hU8P36
MWH0^Y>@0=G<a`3<aL00^kB]0<>n^03:b/H0b/[:0<c=cP3<c]00c<k=0<S6`P2f[:00X8e_03g07@/0
0?l02@3oool9003o00030830003oP000oh000200oh0000<0d51h0;Ph]03oP000203@D7P00`3XJ3`0
oh000?n000050?n000030=1@N03XJ3`0d51h0080X23`0P3XJ3`20=1@N0<0X23`00<0d51h0<2P0000
o`002P00o`3=0?ooo`002P3oool8003o0016017Z0@1mEaD0OeP_05`W4P1D1`80I`@507051`1a0`H0
L08307P21P1o0`P0Q0@708T41@2;0P@0T08709@31`2G10H0U`D509d51P2S1@L0Z0L90:d82P2[1`T0
ZPX<0:`;2@2^2PX0]0`<0;@<2P2`30T0[Q0>0:T?3@2S4a40RR0J04XE3014:R00TWie0=c:`03Ve/X0
j]cD0>kTh03^in@0j^OT0>KThP3YiN40k>KP0>SKe03RdLH0aKJ[03d]9P152PT0OQ4?09H;302F1`P0
WC8c0?g;cP2^QHL0d;Rd0=O>b033_[T0em?>0<k9``2n^kP0b<S70<O:c03>d]D0blc?0;fn_P37a;d0
Xi5g03?65`X00?l02@3oool8003o00030830003oP000oh000200oh0000<0X23`0?n0003oP0002@3o
P0020=1@N0H0oh000P3@D7P0103oP000X23`0?n0003@D7P20:0Pl080d51h0`2P8?000`3@D7P0P<00
003o0009003o0<d0oooo000:0?ooo`L00?l004T04^X107=b4P1j=QD0GQ4605450@1D0P40I`<406l4
1`1a10L0L@8607L21P1k0P@0P`@708T51@2>1@D0TP@509H61`2G1@H0U`D50:881`2X20P0Y`P70:X;
2@2R20P0WPH80:<;2@2Y2@/0[PX<0:l=2P2[3PT0XQ4>08`E4P1Z61@0Id8g0:ZFR03Ibkd0imcA0>[T
h03/inH0inCT0>SViP3VinD0i^KV0>GTi`3Xi^P0inGW0>GSh@3UhMd0i=oH0<o4_@1ZEU40>``:07PB
4P2B2P`0YSHi09Lh?P219BH0/gij0=72_@2bYj00`KRa0<S3_03=cLX0e=?C0<k>d03=d=<0cm3C0<S8
c@33aLH0^KF^09^HL`1GXbh09[H500P00?l02@3oool7003o0003043P003oP000oh0001h0oh000P3X
J3`>0?n000030>QX?02h>;@0oh0000H0oh0000L0d51h0:0Pl02h>;@0^3Rd0>QX?03oP000j6Pl0080
d51h00H0X23`0;Ph]02P8?00^3Rd0?n00030X008003o0<d0oooo000:0?ooo`H00?l004/04nX306Qd
3P286PL0V@T509h9202F20T0R0D508H61@1n1@@0MP8307H21P1m10P0P@@708L52@2710H0SPD609D6
1@2H1PH0VPL809l61`2V20T0Y0L90:06202T2@P0V@<609T72@2L1`T0X`T<0:@:3@2Q3@/0TaH@05`L
4@1aDdD0/j:D0>;Fb`3Yh=/0j>GP0>OTh@3Wi^D0j>KU0>KTi03Wi^H0i^KT0>OVi`3Ui^P0inOY0>KW
j03Si><0h^?R0>3Qh@3Oh=l0g=OA0:jPUP1N>380M`l@098F6P2<1`/0U0X:09m9BP3Kb<P0_KB]0=G:
`P38`;X0_KRd0=OGeP3DemP0cm7A0=7Be@39bll0bLg@0<C5a`2VXYh0YIN808U]C`0V]PD01`00o`09
0?ooo`H00?l000<0P<000<2P003oP0007@3oP0020=1@N180oh0000<0d51h0>QX?03oP0001@3oP000
102P8?00j6Pl0;Ph]02P8?020?n000030>QX?03oP000X23`00@0X23`00<0j6Pl0<2P0000o`001P00
o`3=0?ooo`002P3oool5003o001=02CC1P26>Q40OQ0309P51@2Y20P0[@T90:h<2P2f6a@0^1P@0;P>
2P2a30/0W@T808`51P230PH0P`@608L41@2:1@H0S`@409H61`2M1`H0X@D60:87202O1PL0W`L909`6
202J10H0W0D809`92`2I2``0TQ4@06lB3@1^ASX0a;NX0>CLd@3WiN00iNGS0>?Th@3Rh]l0i>?Q0>CS
hP3UiN80iN;T0>KSi`3Vi>H0inCW0>?Ri03Ti>D0i>GT0>?RhP3RhN80h^;T0>CSh`3Shn<0i>3M0;Z_
Y`1C61H0P`T<08h21@2Z3Q00TPX>07L/;@2oWI80b[V^0;nbY`2m^:l0c/k90=7CdP3;c<h0dM7C0=?D
e`3?d=D0alO<0;bk_`2b/:L0UHel08IXB@0CfP801P00o`090?ooo`D00?l000<0P<000?n0003oP000
703oP0000`3XJ3`0d51h0?n0000D0?n000030=1@N03XJ3`0oh0000<0oh0000H0j6Pl0=1@N03@D7P0
^3Rd0:0Pl03@D7P30>QX?0030?n0003XJ3`0^3Rd00<0X23`00<0j6Pl08300000o`001@00o`3=0?oo
o`002P3oool5003o001=075B201a2P00QP810:451`2[2@X0[`/;0;`Q6`2d6@l0`QdE0;h>2@3130T0
a0d<0;P>2`2X2@T0T`<408@310281@H0R0420985102P1`P0XPL50:471P2Q1`P0W`L909`31@2R1`X0
X`X:09L:2@2540d0F0`906M3<`3@`;40iMoJ0>7Pg@3Rhn00h^;Q0>;Qh03Sh^00h^7O0>?Rh@3ShN00
hN3O0>7OhP3ShN80i>7S0>3Oh@3Ph>80h>3S0>3Ph@3QhN40h>7Q0>CRh`3Th^@0gmkQ0=kJf01fEU00
NQHD090I602<1PL0R`D807lG5P2KHE/0flc70<k3_032]Zd0^;2V0;nl]@3:bl/0d]KG0=CFfP3Be=L0
dM7D0;jo`@2RXih0W9ZA08efIP0KcPP01P00o`090?ooo`D00?l07P3oP0020=1@N1L0oh0000<0d51h
0?n0003oP0001@3oP0000`3@D7P0X23`0:0Pl0020=1@N0@0oh0000D0d51h0:0Pl02P8?00d51h0830
0006003o00P0oooo8`00o`005P1Ae3L0RkEM08njI02F`Fd0Y<>20<B]U`2eVh80Yk>00;j[UP39^JX0
ZYjD08^1NP1SI600Th]n09NbQP2@_H40T<Ij08;4J01MdDX0C]<k02cU800El0hP003o00P0oooo8`00
o`001`1XZ3`0oh000>QX?03XJ3`0d51h0?n0003@D7P00P3XJ3`00`3oP000X23`0:0Pl0060:0Pl0<0
D91h00<0:<Pl003o0000o`007P00o`0;0?ooo`002P3oool4003o000=03:e0`1b4P40N@<109830`2T
1`/0WPD60:/=3@2e6A<0^B4E0;hK4P2m3@T0`P`90<@<2P020<D=2`100;l=2`2W20L0SP<408P40`2=
1@@0VPD80:071P2N1`D0XPT:0:@92P2U2@/0X`X:09d92P273P`0FA`C089UDP39]Z<0h=_B0=gKfP3O
g]`0h^7O0>7Sh03Qh^00h^;P0>CSh03ShN00i=oN0>?LfP3Sf]T0gm?A0=W7a`3Ka/L0fLC40=k<c@3S
fMT0i=oO0>7Ph03Ogn00h=kQ0=[Kg@3IfMT0^jbW06PQ702^BDL0PPT:08@51`2B:B/0R4=70<:RY032
]:l0_[BZ0=C;`@30_KD0`[nk0<O7a`3AdmH0dMCH0<g=d@36bLX0_<2o09RJT`2OT8H0C6DF01o@1`D0
0?l02@3oool4003o00030<2P003oP000oh0001/0oh0000<0d51h0>QX?03oP0005`3oP0000`3@D7P0
oh000?n000050?n000090;Ph]02P8?00oh000=1@N02P8?00^3Rd0?n0003XJ3`0d51h00@0X23`00<0
oh0008300000o`001000o`080?oooa/00?l002802oP702kT6P1AdRl0PKU=0:JWI`31XGl0b;6E0<>`
V038^J@0`;>P0=S?`P38^jl0bl>g0<2eZ03?a[`0aknh0;Ne/02d/JX0[:^Z0;>d]022UJ80TZFb035?
I`1]Ri/0_/gB0<[>c`3=cLd0cLc<0<g<b037`K/0_[B[07SAK@1KdDX0:n@O7000o`080?oooa/00?l0
00<0:<Pl08300020`000103oP0020=1@N0070;Ph]03oP000d51h0=1@N02P8?00j6Pl0;Ph]0020:0P
l0030;Ph]02P8?00X23`00D0X23`0`3@D7P00`2P8?00^3Rd07QH]002052@N1`00?l02`3oool000X0
oooo0`00o`00D@0Ci`40LBH107<20@200@80V`@70:L62@2Y2@T0[a8@0;DL5P2f6A80^aL@0;X<2@2o
30T0``/80<H=2P393P/0b@h:0</?30313P/0/`/:0:061@2F10D0W0P80:072@2P1PP0XPP709d82@2=
1PL0Q10>06<Y7`2fXi40gM?60>3Le03Lf]D0f][F0=gMf`3RhN00hN7P0>7Ph@3ShN00i]oL0=c9aP31
U940/71]0:5@C@2C<C40SQdQ09@K7P2F71`0UR8T09Lj>02PG5P0_iJC0>3CdP3Pg]l0fm_M0=OGf@3K
e]D0QDe607X;2P281PL0RPL808<62P1g10P0Pbd^0<Z`Z@39`[X0`k^a0;J_Y034`l00cLk>0<c<d03?
dMD0dMCG0<[=d02f^[d0/;>b09RDS01U?S40YWYS02j/3004003o00T0oooo0`00o`000`10h000oh00
0?n0000J0?n000030>QX?03@D7P0oh0001X0oh0000<0d51h0?n0003oP0001@3oP0020=1@N080X23`
00D0^3Rd0=1@N03XJ3`0oh000=1@N0030:0Pl0030=1@N03oP000`:0000@00?l0203ooolH003o000Y
02oU701Nc3T0PK]@0;jLNP33Xh80ajV90<R/R`39[i00ckJN0<beW@3B_:T0a[>P0;jcY@2h/:H0b/>k
0<k7_P3:bL00b<Bm0<S4_P3Bd/`0`l>l0;jn^02AV9X0VjBZ08fQ[`2>Z;X0OInd06Z:WP34d]H0bM7D
0<_Ce@38d=80bm7D0<S@dP37c=00a<[:0<W7``2o/:T0Timc05>a=P0Ak0T06000o`080?oooaP00?l0
00<0J:Pl0830003XJ3`0203oP0000`3XJ3`0^3Rd0;Ph]0020;Ph]0040=1@N02h>;@0^3Rd0=1@N100
X23`00D0^3Rd0:0Pl03@D7P0Z8Pl043P000H003o00/0oooo000:0?ooo`<00?l00540AI@108070@1j
0@80NP0009T31P2X1@H0[@T80;4D4@2]4`h0^b0J0;LB3P2i2PP0`0`80<@<2P3930/0b0h90<P>1P3<
3P`0c0d;0<l>3@374@l0WP@309X61`2O1PP0XPP80:<:2@2>1@L0PA8A05LF3P2cWhh0g=K<0=_Ie03K
fmH0g=_F0=kKf03Jf]L0gMkL0>3Og`3Vgmd0im?A0<BGTP2?>cL0UQhN09dD5P2O4Q<0X0l?0:4;3@2T
2`d0Y@`;0:@<2`2J2`X0T`l?088C4`2hMg<0iMSF0=[Jf`3If]X0f=OG0:AlM01a3`P0R0L4098A4@26
30l0O0@7090S8`2IIF00bL6m0=3;b038`[/0dM3>0<72`@3Bd]<0d=7D0<_>d@38c<h0d]GG0:FUY`2U
Y9h0JDY209QdJ`1cNCl01000o`090?ooo`<00?l000<0P<000?n0003oP0006P3oP0000`3@D7P0oh00
0?n0000R0?n000050=1@N03oP000d51h0?n0002P8?000P3oP0020=1@N0060?n0002P8?00X23`0=1@
N02P8?00d51h1000o`080?oooaD00?l002h0=mhQ07;0A`2[XFd0_ZB20<2VQP35[8h0bk6F0<feWP3A
^jH0c;ZS0=6nZ03F`J`0e/F^0=C1ZP3D_JX0_k>V0<o9_`2g/j/0cLRo0=WHd@3;b<80d/g80<S4_@3?
blH0blS20<[?c@2X/[L0FG:<07ZD/01^S:H0X[c=0:c4cP39e=L0bM;E0<O@dP3:dMH0aLgB0<G>e@34
cM<0a<c?0<C:c@32aLH0_kbi0:NGR@1>/3802?D45P00o`080?oooaD00?l000<0J:Pl0<2P003oP000
303oP0001@2h>;@0j6Pl0:0Pl02h>;@0oh000080j6Pl00@0^3Rd0=1@N02h>;@0d51h4@2P8?000`2h
>;@0Z8Pl043P000F003o00/0oooo000:0?ooo`800?l005<05>T107`j0@291040R08308`20P2K0P@0
Y`D70:T71`2V20L0/aTG0:lA3P2b2PL0^P/90;h;20322`T0a``;0<L;2P393@/0b`h=0<`=2`3?3P/0
d10<0<D>2`2f2PX0ZPL70:871P2H1`L0NPX;05XI4`2IOVh0fM?90=cMfP3Kf]P0f][F0=_Ke`3OfmT0
gMcJ0>;Og03Na/@0]GMf0:51@02Q92<0Y1DE0:LA402W3`l0YPlA0:L=3P2V2Pd0Y0P;0:D:2@2Q20L0
W@T909X;2`2A2@/0Ta/I0<jIUP3QfMP0f]WJ0=[If@33YIh0M1X@08@71@2710H0PP@807h61`2J<C40
SDa90=K4`02m]Jd0/ZZN0;jk]03=c<`0clkB0<_<d03<c]40a/[=0<C9c@2h_[h0W9jI07AOE`1_Ddd0
Y92300[V0P03003o00T0oooo0P00o`000`20`000oh000?n0000J0?n000030=1@N03oP000oh000280
oh000P3XJ3`00`3@D7P0X23`0;Ph]0020=1@N080^3Rd102P8?00103@D7P0X23`0>QX?010h003003o
00P0oooo4P00o`00<P0hgR40OkQ<09nWIP2hXGd0^ZB30;jXQ@30[8`0b;>G0<fiX`3:^ZP0_K:U0;N[
W03Ha[<0g<Re0=c:]P3Nc;D0g/Vb0=[9/`3?`:`0clFk0<_4^P33`KT0/JnW0=;@b03@blH0b/K20<g5
_P3@bl@0a<>n0;g2``2i`/X0KHJK069nV01ENID0MiN[0<WIg03;e]P0am7E0<WCe`3;e=P0bM7H0<O?
eP31b/l0`Lc?0<?<d@31b<`0_/?70;^f]@1oSf806>8>5@00o`080?oooa800?l000<0P<000>QX?03X
J3`01P3oP0000`3XJ3`0^3Rd0;Ph]0060?n000050>QX?03@D7P0j6Pl0;Ph]02P8?000P3XJ3`20=1@
N0030>QX?02P8?00^3Rd0180X23`00<0^3Rd043P0000o`005000o`0;0?ooo`002P3oool2003o001C
05Qm0@2C4`H0RP<208d21@2K1@L0XP@80:D41`2V1@H0Y`@60:T52@2[1PP0]@X90;X:2P2l2`/0_P/:
0<<;2P373@T0b`h=0</=303>3`/0c`l:0=8@3@3C4Ph0eA4>0=<D4@2j3@/0R0`:06L_902fXHd0fm;9
0=cJf03Mf]P0g=WH0=cJf@3Ofm/0h=OE0<ng]02dN7L0YS0`0:hH5P2c5Q<0^1DD0;<B4@2]4@h0ZA4>
0:D>3@2W3@d0Y@X;0:H;2`2Y2``0X`T809d92@2H20P0T`L808d72@2><2d0eKB]0=[Fe03Ge]H0eKnl
09Dk<`2?2`L0QPH4094O702B:2P0M`P;07DB502KJf80`K:W0;jeZ`2o^[80_kbh0<o>c@38b/X0cLoC
0<C8b`37c<h0]kbm09nTX@22M6`0Bc4/0;nf]@0/X1400`00o`090?ooo`800?l06`3oP0000`3XJ3`0
d51h0?n000060?n000030=1@N03oP000oh0001`0oh0000<0j6Pl0=1@N02h>;@00P2h>;@00`3@D7P0
^3Rd0;Ph]0050:0Pl0030=1@N02h>;@0P<0000<00?l0203oool@003o000e027[5025/E80]Yeh0;fQ
P@2lXhD0^:>80<2ZS039/Y<0c;RN0=:oYP3A_JL0eL^m0=gJeP3;_[40f/J`0=c:]@3JcKl0g]?40=o=
]P3Nc;H0f<Zf0=K7]@3Db;T0d<O00:f/YP3>c<@0b<:k0=SFc@3>cL@0cL[30<?1^@2_/Jh0[K2`092Q
[@2/`</0IhJO06Z<Y02N^lT0bmGH0<[EeP39e=H0bM;G0<O?e`33c=80`<S>0;k7c033c=40aLgD0;k7
c`2la<T0/kRo05APC`0He1405000o`080?oooa000?l000<0J:Pl0>QX?03oP0000P3oP0000`3XJ3`0
oh000?n000050?n000030>QX?03oP000oh0000L0oh0000D0j6Pl0:0Pl03@D7P0^3Rd0?n000020=1@
N0040;Ph]02P8?00X23`0;Ph]180X23`00<0D91h003o0000o`004P00o`0;0?ooo`002P3oool0E@00
o`004^L108HM002A3PP0PP4109041`2I10H0V@4409l41`2Q1@H0Y0@80:H42P2Z1`P0/`T90;P;2P2l
2`X0_`/;0<<=2@3330T0a`d;0<T=303=3``0d10:0=8A2`3A4@/0e14=0=LD3@365a80NRXR0<BaY@3M
eM00f=KE0=_HeP3OfmT0gMWG0=kHe`3E`<00YfMR08XS7@2Q5aD0/Q@C0;HC502b4Q80/1<B0:XD4@2P
5Q<0U1@B08dF4`2;4a40S`lA09`<3P2T2`/0XPT90:092@2I1PH0T@<508h31@2220H0XEU>0=[8`03E
e]L0f<S70:E@A`2a8QL0XbHJ09/g<@2H?ch0M@L:07P92`1m=C00dkNb0<2c[P2dZ:40^;J^0<c=bP3:
bl`0al[=0<W=d@39bll0/[Rj0::XY`2?Qh@0@B@P09N<RP1EQcH00`00o`090?ooo`03003o0010h000
oh0001X0oh0000<0j6Pl0?n0003oP000103oP0000`3XJ3`0oh000?n0000P0?n000030=1@N02P8?00
X23`00@0X23`00L0d51h0:0Pl02P8?00X23`0?n0002P8?00d51h00<00?l0203oool=003o000c01Kb
3P1GbCL0T:UK0;>JL`2gWg/0^J640;bSRP32ZY80a[2I0<ZeV`3:]IX0ckbS0=6mY`3C_ZP0elVg0=_A
aP3Fa;00e/:]0;jdY039bLH0f][F0=_>_P3ObkL0flVd0=O6/03EakP0cl:d0=[BbP3=a[h0c/_20<S3
^@3CclL0bL>m0=WFd`33`Kd0Z:bY09>MY@1YP9@0JXBM09JbaP28YKH0b=SK0<cFf03<e]X0cMGK0<_C
fP37cm@0_/K;0;W3aP2h`/D0`<W?0080_/S?00@0_/SA08NEXP1lP800;=HQ4`00o`080?ooo`d00?l0
00<0:<Pl0830003XJ3`03`3oP0000`3@D7P0^3Rd0?n000070?n000060;Ph]03@D7P0^3Rd0=1@N02h
>;@0oh000P2h>;@80:0Pl0030;Ph]02P8?00X23`00T0X23`00<0D91h003o0000o`004@00o`0;0?oo
o`002P3oool0E@00o`00;k82074C0P1h20@0NP4208X2102?00<0U04209X31@2O10P0W`<50:<51`2W
1PH0/PT:0;L:2P2m2`X0_P`:0<4<2@343@X0aPd;0<H;2`3:3@/0cQ0;0=4@2`3B4@/0eQ<?0=0E402D
4Pd0/i660>7He`3Lf=/0f]OJ0=gIfP3Kf=H0g=SF0=c7aP2FBdX0VaPG0:HA3@2[4Pd0[a8?0:X?402Y
51@0XQ`I084N6`1C4Ph0>P`702X90`0Y2@H0=`P:05lA4P284140VPT909`81P2F10<0TP4109420P29
1080P20F0=6aY`3GemP0g<g;0:eKD@2o;b<0Y14:09LM6@1l2@L0O@D608LG5020=C00^iZH0=G<cP38
`l@0^;6]0<G3`@37bl`0aL_>0<?:cP32a//0`/G909:GU02KTi40ARHR08QgM01]Odd00`00o`090?oo
o`03003o0020`000oh0004<0oh0000<0X23`0?n0003@D7P02@2P8?000`3oP000X23`0=1@N003003o
00P0oooo2`00o`00?00Fl@d0B/l]0:>LJ@2bV7L0/iai0;:MO02lY8P0_ZRA0<J`VP38/id0b;:I0<Rb
U`39/YT0c;JM0<bjW`3A_Z@0dknW0=K1Y`3G_j80b[NQ0<>iZP38`kX0dLVm0=k=^03Nb[<0flR`0=O4
[03EaK80dl>d0<k1/`39_[40e]?80<k9``3?blD0b/S20<S0^`35`;`0c/k;0;Vj]`2:VjH0OIJW031@
KP1VQIh0/<WF0<[Ef@3=eM`0c]KM0<gEg@38d]P0am7E0<39cP2na/T0^<350;K0a02i`lX0^<C?08ND
YP19Gg40JGe/01WT4A800?l0203oool;003o000302S8?02@L7P0oh0000@0oh0000<0j6Pl0?n0003o
P0002@3oP000103XJ3`0d51h0;Ph]03XJ3`70?n000040;Ph]03oP000j6Pl0=1@N0<0^3Rd00<0d51h
0;Ph]02P8?001P2P8?000`2h>;@0X23`0:0Pl00:0:0Pl00302S8?000o`000?l001000?l02`3oool0
00X0oooo05D00?l003JF0P132080O3`k06`41@260PH0S`8409410`2I0`H0X0@90:44202T1PL0Z0H8
0:l82P2e2@/0_0/;0<0<2`3330/0``X;0<H=2`383PX0c0l:0<l@2`3A40`0dQ8<0<hE4@2[5Q<0TDi7
0=c?b`3Ke]P0fmSJ0=WGf@3Lf]/0h=KF0<BUY02HBdT0VADD0:P?402Z3`h0Y`h=0:HD4P2B61D0KaHD
05<K5@1M@cT0OF]O09F4M`2PTH<0Vheo07IUF@1<=Rh0C0l=098?3`2M2PT0V@@509D20`2A0P40R`81
07/<1P37V8h0f]KF0=[;b@2/FDl0]b<H0;lY7P2T81P0P`h:09/[:`275Q<0Ob0M0:1YJ@3B`<@0_[bm
0;Zh]03;c</0`l[:0<37b034blh0`<K90;jo``2Z[Jd0V9FC04hh<`21LW00OfmM00<00?l02@3oool0
1000o`00P<000?n0003XJ3`N0?n000030=1@N03XJ3`0oh0000L0oh0000<0d51h0>QX?03@D7P0103@
D7PD0?n000030>QX?02P8?00X23`00X0X23`00@0d51h003o0000o`000?l0203oool:003o000m02WR
6@2LUf<0ZiA`0;6IN02dW7`0]Yn20;ZSR`35[YH0a:nH0<:^U@35[I@0aJbB0<F`U`3:]I`0cKJK0<fi
W`3?^j80d[fU0=BoYP3H_j<0f[nU0<JcWP3:^:@0g<Vc0=g:]03Jak40f/F]0=K2ZP3B_ZL0elBa0<bm
[P3=a;P0`[R[0=3<`P31_;@0e=3<0<Bn^033_[T0^K>_0:j_Z`2[/;P0V:Rc08FK[01nV[80H8:M0<GE
g03<e=X0cmSO0<gFg`3<eM`0bM7I0<?;d`38d=P0a/kH0<3:d@2mbM00^L?;0:R`^P1/OXh0NHZA08BK
LP0B003o00P0oooo2P00o`000`10h000oh000?n000030?n000030>QX?03oP000oh0000`0oh0000<0
d51h0>QX?03oP0001`3oP0001@3@D7P0X23`0=1@N02P8?00j6Pl0080^3Rd00<0X23`0;Ph]02P8?00
1P2P8?000`3@D7P0X23`0:0Pl00;0:0Pl1800?l02`3oool000X0oooo05D00?l004YV1P1[Ee00MVY]
04<310251@P0T08709<11P2O10P0W@<709d41`2Q1@L0YPH90:h82@2e2`T0^P`:0;h;2P3230/0a0/:
0<D<2@393PX0cA0;0=0>2`3B4@`0d18>0:@E401o@cP0elNo0=oMg03Ge]H0f]OH0=_Hf03Md<l0XfUU
08`Q7P2O5140ZPl?0:L>402S40h0Ta@B06HG4@1WAST0VXMh0<Zk[P3QeL`0h]OA0>CMf03Th=/0iMkI
0>3Gc`3Ibl80[i6807lH502M2@X0V`L:09D5202=0P<0R@8207`70P2nQgP0em??0<VbZ`2L=bP0]A8:
0<4M502e81T0RP@408XB5P2C71X0Qa/G08Ha;`1k@T80b[^h0<C0_02j^KH0^[bk0<C;cP36cm40_lS:
0<39b`2LYZL0V9bJ05U=B02:PX40QgY]00<00?l02@3oool01000o`00oh000=1@N02P8?0G0?n00003
0>QX?03oP000oh0000/0oh000P3@D7P00`3XJ3`0oh000?n000050?n000030>QX?03oP000oh0000H0
oh0000<0j6Pl0?n0003oP000203oP0000`3XJ3`0d51h0;Ph]00:0:0Pl0040=1@N000o`000?l0003o
00P0oooo2@00o`00?`1K_CX0V9=S0:RCM02`Vgh0]J260;nSR`3;X8T0^G5N0<JBN02nZ8`0_JN<0<>Y
S@35[940a[2I0<NbVP37/iT0[Z:?09JAPP2RWHh0cKfV0=O0Y`3J`JH0f<>W0=W5[03Kajl0g<Va0=[8
/03I`j/0f;nX0=BlY@3A^ZD0ck^Y0=74]P39_[<0c<:e0<W2]P31^[00d<_50<S4_P31_[X0_;^f0:BU
Y01PLGl0Rij_07B@Z@1nVk00]<[E0<gEf@3?emd0bmGL0<gGh038d]X0am3E0<K?eP2laLh0][o70<;=
e02la/h0][g406mlR`1`Q8l0UibN03G=:@0A003o00P0oooo2@00o`000`2XR3`0oh000=1@N0020=1@
N0@0oh000P3XJ3`50?n000040=1@N02P8?00^3Rd0>QX?0d0oh000`3@D7P00`2P8?00j6Pl0;Ph]002
0;Ph]0L0X23`00<0d51h0:0Pl02P8?002`2P8?000`1@T7P00?l0003o000?003o00/0oooo000:0?oo
o`0^003o001MPbL0RhR506AXJ`0I0@40H@H808831`2>0PH0TP<809<2202H0PL0W@@80:@72@2^20/0
]0/;0;T;2`2m2`T0_`/:0<<=2P373@X0b@d:0<`>303@3`h0dA4?0;/E4@29A3d0elO00>;Og@3Lg=d0
fMOH0=WEe@3I`;`0_UiD0:LG4P2N2`P0X@/<0:4=3P2E4Q@0MQLE06<c;02]Vhh0gM?80>7Le03Rh=d0
h^7P0>7Qh080h>3N02D0h>3O0=kOg`3KgM`0hMSE09iGC`2I2`X0V`H709T6202C1PL0S@D6088>1@2o
R7H0dlg70<2OV02@81<0/0T40<8;2`2n2Pd0[PT<08l31@231@P0PAhO0>>WZP28De@0aJjZ0;Vb[@32
_k/0b<W90<;:c032b/d0aLg@0;c5a`2W/[80SYRH07ejN01kM7D0RGme00<00?l02@3oool01000o`00
j6Pl0:0Pl02P8?0E0?n000030>QX?03oP000oh0000/0oh000P3XJ3`C0?n000030>QX?03oP000oh00
00P0oh0000D0j6Pl0;Ph]02P8?00d51h0;Ph]0080:0Pl0040=1@N000o`000?l0003o00P0oooo1`00
o`00@@0Cl0`0QiQH09n>L02WUg`0[Yj60;>SR`2jXXd0`8Id0:Ph9P2d8a<0_F=70<:SQP33Z8h0`jV<
0<FZS@39[Y<0aJfE09B;NP2=Rg/0XIZ:07enM@28QgX0e;nV0=O0YP3J`ZH0fLBW0=_7[P3Lb:l0f/N_
0=S4Z`3G`:P0eKjV0=6kY03?^jL0akJP0=32/`37_;00dlo50<K3_038aK/0_;F^0=3<a@30_k/0^KVg
0:nc]01fQ900BfJ0061oV`1iUZT0bMGJ0<oGgP3<eM`0c=KM0<WDg037d=T0aLoG0<G=eP2a^Kl0`LkD
0<7<e02oc=D0HG>304aULP2<Vj<0Nj=_01400?l0203oool7003o000302S8?03@D7P0^3Rd00<0X23`
00<0d51h0?n0003oP000203oP0050:0Pl0d0oh0000<0j6Pl0;Ph]03@D7P00`2h>;@00`3XJ3`0^3Rd
0:0Pl0060:0Pl0030;Ph]02P8?00X23`00`0X23`4@00o`0;0?ooo`002P3oool0E@00o`00XX=N07Ek
P01MIf/03@4103420P1I0P80P@<608410P2;0PH0T`4309X21`2R10T0[0H:0;89302h2``0_0`;0<4<
2`322`T0a``:0<X<2P3=40h0cPl>0<dA3`2C4a00`JFN0>;Ng03Qh>80gmoQ0>3NgP3La/80^V=J0<4M
50375100]A0<0:0;2P2A4Q40FQ4=06U=@P3:_:h0h]cE0=kNfP3Ng]`0h>3O0>3Qh03Shn<0h>3P0>3P
g`3Ogml0fmkM0=gOgP3Og=`0/7mf09D?302I0`H0W0H909X72@2D1`P0R1880<B?OP3GclT0ZXMn07@7
0@2W1PH0_0P90<0:3@2i3Q00X@d?08@31`2>6al0Ma@M07@W;03G`<40c<S50<G4_`2h^;L0`<K:0<K@
dP2f_/40aLoA0:Fa/`2EXJ80N7Qd06eWI@2;PGL00`00o`090?ooo`05003o003@D7P0X23`0:0Pl03@
D7P0503oP0000`3@D7P0oh000?n0000:0?n000030:0Pl03@D7P0oh000200oh0000<0d51h0:0Pl02P
8?00202P8?00103@D7P00?l0003o0000o`080?ooo`H00?l004<08]dE07NKC`2LSg40XiIo0:RKQ@2^
WXH0/J250;VGO02RCSH0[T0U0;mYB`38UgX0`:B90<2VR031YhL0a:N70<FXR@2cWhL0KVmR09nMQ`2T
WXd0SH^106Q_I03=_J<0e[jU0=[1Y`3J`jH0f/F/0=_7[`3IaZh0f<B[0=K2Z@3D_jT0dKZS0<bgXP3<
^:D0a[FS0<BdY02i[J00dLg50<?0^@34_kX0^k:[0;Zd[@2l^KD0^KJd092:TP2iYj`0/9NF0:RCU@36
_;l0c/oB0<_Df@39dmX0bM;J0<S@f@36c]L0`<>n0<73[P30b/d0`LgG0;o<f02DX[00HgF208JFW`2/
[:`06><A01000?l0203oool6003o0003052@N03@D7P0X23`00@0X23`2P3oP0000`3@D7P0X23`0:0P
l0030:0Pl0d0oh0000@0d51h0;Ph]02P8?00j6Pl0P2h>;@00`2P8?00^3Rd0=1@N0020:0Pl0040;Ph
]03@D7P0^3Rd0:0Pl080^3Rd1@2P8?000`2h>;@0X23`0:0Pl0050:0Pl003052@N000o`000?l000h0
0?l02`3oool000X0oooo05D00?l00;BLP029V9d0D5eN01030P0Z0`D0:`4105T41@240`H0S@880901
1`2E0PL0X@<90:/72`2_30h0/Pl>0;X<30323@`0a0`;0<L=2`3;3P`0c10>0<d@3P325140TdHo0=kE
d@3Ph>40h^;U0>7Oh@3TbLP0`fUR0;lT703:4Pl0c1<?0<TE402/5Q80HaH?08ieI@3EbKX0h]gD0>;P
g@3Mg]/0gn3M0=oQgP3Ngmh0hN;S0>7Rh@3PhN40gmoN0=gNg`3Mg]h0g=WG0:MdJ`2H3`/0X`T:0:46
1`2M1PL0U0H608/L3P3:Wh/0fmKA09]aJP1d2@D0U0@40;P:2P302PX0^P`=0;TG6@2C0`H0R0H908P7
2`1k2@`0O3dl0<:d/P33`[l0bLW90<G6bP38cm80aLg@0;k7b`2ka/X0SibO096GU`1ZI6D0ShAl00<0
0?l02@3oool01@00o`00j6Pl0:0Pl02P8?00d51h01<0oh0000<0j6Pl0?n0003oP0002P3oP0000`3@
D7P0oh000?n0000E0?n000030=1@N03oP000oh0000P0oh0000D0j6Pl0;Ph]03@D7P0^3Rd0=1@N007
0:0Pl0040;Ph]000o`000?l0003o00P0oooo1@00o`00A00Yda/0QWIJ08YoI@2KT7P0XiR00:RLP`2[
Vgd0[ieo0;FNO`2oVgd0^Hi_0;jOO`2kX8<0_:220;nQO`2oXH00_j5n0<6RO@2UT7@0GF9I07QmL01h
OG@0HfiZ07MkK`3>_j@0dl2T0=O1YP3J`jL0g<J/0=[7[@3JaJ`0fLF]0=O1ZP3E_jX0ckbT0<bhX039
]Id0aK6L0<ZlZ@2k[9/0_K:S0<:j/03>b/<0a[fh0<Z_Z`2cM6l0ZTM30:HV9P2/5aT0[A<E0:XC5`2V
72<0ZT160;J2QP3>aLT0bM;H0<[Df`35cmD0aLRl0:nWJ@39bK<0_lWB0;O5c`2KYkL0D69`06enQ`2G
Wj40B;lk4000o`080?ooo`D00?l000<0D91h0;Ph]02P8?00102P8?000`3@D7P0oh000?n000080?n0
00030=1@N02P8?00X23`00<0X23`3@3oP0002@3XJ3`0d51h0:0Pl02P8?00^3Rd0=1@N02h>;@0oh00
0>QX?0070?n00080j6Pl102P8?000`3oP000d51h0:0Pl0050:0Pl003052@N000o`000?l000h00?l0
2`3oool000X0oooo05D00?l00;BTR01KKG80DEiO01L41@0_10L07`8301`10@1N10H0Q@8408X1102?
0@L0WPD;0:<73@2N3Q80XQ0B0;@>3P2l3@d0```;0<H=2`393P`0bPl<0<PB3@2K7QD0c;6X0>;Og`3N
g^00g]kN0=o5``33De00bA`E0=8E403D5A00d1P@0;TJ4`1h71<0Yi1n0=gEb`3Pg]X0h>3L0=oPf`3N
gml0h=gO0>7Pg`3OfmP0h=7A0>?Bd`3RgMX0h>7O0=oOg`3Ngml0g=CA0914?02N3@T0Y0P90:H72@2P
1PL0T`P709Th:@3<[9/0f]7A08YBC@202PL0RP<30:T92@2k2PX0^`X<0;L72`2/2PX0S0@5098>4P25
20X0Uchh0<J/ZP39aL@0^[^i0;o4a03?f=X0bm?G0<G>e02la/`0Tj6R08J>S`1MFed0ThV100<00?l0
2@3oool01@00o`00d51h0:0Pl02P8?00j6Pl01l0oh0000<0d51h0?n0003oP0005P3oP0000`3@D7P0
oh000?n000090?n000050>QX?03@D7P0X23`0;Ph]03@D7P01`2P8?03003o00P0oooo1000o`00A@0V
dAX0L7E?08ImJ@28PF`0V95l0:>JP`2WW8@0ZY^10:jMP`2aWh80]:620;^TQP2gWWh0]9ah0;BMM`2j
WW/0_9ag0<2NM`2nWFl0^9]`06EOD01DGUL0GfEN06a/G`2fYi00d[fQ0=>oY@3D_ZH0f<:X0=W4ZP3K
aZh0fLJ_0=S5[P3G`ZX0dknY0<jmY03<^:00bKFM0<>`V036/Yl0dl>b0<>bX`3:^Jh0_IN<0;AME`2]
8al0/Pl?0;<82`2d20T0]PP90;L72@2f1PT0/`H90;472P2X2a80XC8i0<>SY`39d=P0a]7G0<C>d030
_jX0[:Ee0<77_@2i`l/0//3<04aMKP1dQHd0T9VM06N`F`0@003o00P0oooo1000o`000`1@T7P0X23`
0:0Pl0070:0Pl0030=1@N03oP000oh0000L0oh00102P8?000`3@D7P0oh000?n0000<0?n000050>QX
?03oP000^3Rd0>QX?03@D7P0303oP0001P3XJ3`0X23`0:0Pl02P8?00^3Rd0>QX?0L0X23`4000o`0;
0?ooo`002P3oool0EP00o`00RX]O04YMG01BGel06@8302P20`0H0P801@4002010@1V10D0O@4408H2
1@2B0PP0X0H<0:dJ7`2[61/0]B8T0:HE5@2f3@h0a0d=0<H>2@364@X0/a/C0:1QF03Rg=/0gmoQ0=[J
g03Hal<0]e160<<G4@3;4P`0cA8>0<lE402/6A80LbPM0;:HR`3PfM<0g=_J0=cMf`3Mg]/0g]kK0=kG
e@3H`;l0_hb90:M?B`2N<Bd0UCPb0;BDRP3Ng]`0gMcN0>3Jf@2iTXl0RADF0:092`2W2P/0Y0P809d7
1`2<2`L0]FQE0<^gZ@3Db<H0OS4[08X71P2?10H0T`830;892@2h2@P0]`T:0;D92`2E0`D0QP/>09LY
:P256aX0RTa80;f_[03:c<d0bLoA0<K?dP3;e=X0bmGL0;W3b@2MZJh0S9FH05YKGP2@QX001_<10P00
o`090?ooo`04003o003@D7P0X23`0:0Pl0<0oh0000<0^3Rd0?n0003oP0006@3oP0000`3@D7P0oh00
0?n0000=0?n000030>QX?03oP000oh0001<0oh0000<0j6Pl0:0Pl02h>;@00P2P8?000`3@D7P0X23`
0:0Pl0040:0Pl003043P0000o`000?l000P0oooo0`00o`00AP07m@D0E8ln08nCQ@2f]k80S8Yh09VD
O`2RVhL0Y9^40:VKP@2/WH40/:260;6NP@2dW7h0/iUh0;BJM02dVg<0]i]a0;ZJK02nVg00_YUZ0;nN
K02eV6`0XXeX0;>KNP33YH@0bZn:0=6kW@3C_Z@0e;nU0=O0Z03I`jX0e/:/0<2cX@2o/j40cl6[0=;0
Y`3@_:<0c;RO0<VeW@37/YX0b:nK0<BZUP38Xi40_FUM0;<U8@2g3Ph0^@/;0;L82`2e1`X0]PT:0;H:
2@2g2PX0]PP;0;45202`1PL0[`H80:X7302I6b40^iJK0<O>d`2maKh0_[bC0:nUB`2k^800`<O70;[4
cP1JJGP0Jgn909NUZ`1iXfh@003o00P0oooo0`00o`000`0Xb3`0X23`0:0Pl0080:0Pl0030=1@N03o
P000oh0000P0oh000P3@D7P80?n00080d51h00<0j6Pl0?n0003oP0005@3oP0001P2h>;@0X23`0:0P
l03XJ3`0oh000>QX?0H0X23`4000o`0;0?ooo`002P3oool0@P00o`00Fi8m04AFD`1LJ6L07@@40282
0`0=0@000@0101010@130@80L0D707`1102;0PL0X0H;0:/93P2Q1``0Y`lC09X82P2_30d0`0`<0<D>
2`3050d0SB4E0<JZY03Mfmh0gmoR0=_Dd`2lP7T0]Q/E0<<>303530T0a`l<0<4G501j9ah0^Z:C0=oG
cP3Lg=/0fm_K0=kMh03OgM`0i=OE0;B1OP2?<Rl0XR4N0:hG502P7QX0H1T>0:nKSP3LfmP0g=KE0=:e
/@2E?SL0V`d<0:89302R20P0X0H709T6202B60h0`hM`0<o2]`39^KD0NA/G09082@2A1@L0S@440:86
1`80]PL90180]0P60:D92@1m1@D0/eMK08/=401o7Ah0ekZj0<g;cP2g_;h0cMGI0<cEg@39dm`0bM;J
096NXP2BWJ00C4mA08j6O@0Ec0<2003o00T0oooo00@00?l00=1@N02P8?00X23`0`3oP0000`2P8?00
d51h0?n0000H0?n000030:0Pl03oP000oh0000X0oh0000<0d51h0?n0003oP0002P3oP0000`3@D7P0
oh000?n0000<0?n000X0X23`00<0P<00003o0000o`00203oool2003o001701GQ3@1QJdP0TiJ=0:bk
_030b<X0S8f109ZHQ@2OVhT0XYb40:NMQ@2XVGX0[I]m0:nKO02`VGT0[IIa0;BJM`2cUW80^9M/0;RE
H`2kUV80`9]Y0<:PL031Wg40`j1d0<BUO038Ygl0bZb60<bbTP3A_9l0dKnT0=NoZ@3B_j`0Ui:30:bU
U@2SVXl0R8Mm0<c0ZP3?_jD0cKZQ0<bdWP3:/I`0d:2A0<UhKP2j?cP0^a8A0;l;3P2m2@/0^`P<0;T7
2P2d1PP0/`L90;@62P2e20/0/0L90:l83@2_1`/0[PH80:X5202W1PT0UA/O0<J][P34c<@0]Zmh0:NG
6P2WVaP0]kI[0;c3[`1ZNh@0E6ik08fNY@2@RXH04000o`080?ooo`800?l000<0:<Pl0:0Pl02P8?00
202P8?000`3@D7P0oh000?n0000A0?n000030>QX?02P8?00X23`0080X23`00<0j6Pl0?n0003oP000
5@3oP0000`3XJ3`0X23`0>QX?0020?n000030>QX?02h>;@0X23`00<0X23`4000o`0;0?ooo`002P3o
ool0EP00o`00DH<[05aZI`1CGUd07@@401H10@050@000@0001<10P0`0@80CP4206l310240PD0W`D:
0:/8302E20/0VRX/08T:2`2`3`h0``l<0<<=2P2c81D0TUI60=cDcP3Mh><0hmkP0=6TX@2a=Rh0`14?
0<D?3P353P`0a0l=09DE402^Rh00h=S?0=gLf03Kg=`0g=_L0>3Lf`3C_KX0Y5aJ09dT8`2V5aH0[AHC
09dJ5P1X9Q/0X8Mi0=[@b@3NfMT0`jRQ0953>`2G5Q80X@X;0:<9302Q1`T0V`H709051P2D:1`0_8mj
0=?:`@2hWIT0OA8>08d41P2;0P@0S0<709D21@2`20`0]`P:0;D72@2`20T0V`H808L8302;1`/0QAHH
0<6ET`30^[/0`lG90;o5b@37cmL0b=3J0;o:e02V]K`0PY:E05]NH@27N6l05L/20P00o`090?ooo`04
003o003@D7P0X23`0:0Pl080oh0000<0d51h0:0Pl03oP000603oP0000`3XJ3`0oh000?n0000;0?n0
00030>QX?03oP000oh0000X0oh0000<0j6Pl0?n0003oP0002`3oP0000`3@D7P0^3Rd0;Ph]0070:0P
l0040;Ph]020`0000?l0003o00P0oooo0P00o`00B01=R3P0R8Z20:fh_P1UNh40am3D08jBRP2DUHH0
WIV709nGQ02VV8D0YYMk0:ZINP2WU7<0[IUh0:jJM02`VGD0/iMd0;BDI`2gU640^YEO0;jKI`33XW@0
a:5f0<:PMP35YWd0b:V20<f_S@3=/I40ckVK0=>nY@3F`JT0]:BF08V7P@2e/:<0[ZVN06edKP2k]J@0
dKnW0=2mYP3@]Z80e9N90<0j=0326A<0aA4>0<<<2`2n2PX0^PX:0;X92P2f20T0[P/<0:@D5P2M:Rl0
SSE007diB01i>TX0QcQ409HW;@2O2a00Z0H90:85302I@4@0b<W:0<C:a`2]XE00ZYP80:jO2P2`Xbl0
THi>06QfL@26U9L0Ui>B01KO30l00?l0203oool2003o00/0X23`00<0^3Rd0?n0003oP0004@3oP000
0`3@D7P0X23`0:0Pl0020:0Pl0030=1@N03oP000oh0000d0oh00103@D7P40?n000030>QX?02h>;@0
X23`00@0oh0000D0j6Pl0:0Pl02P8?00X23`06RX?00?003o00/0oooo000:0?ooo`1F003o001MSC80
JWId06Y`L`0M1PL03P4100D20@010@404`8302P10@0_0@40A`4207X21@2K10X0Y`H<09l<3P2YADH0
YQ`K0;`<3@3330X0`a0;0:U1=03E_kH0gmoP0=oOhP3AYJ@0/3@^0;dE40323Pl0bA8@0<LA302a5@l0
UU]<0=O@aP3If]L0fm_K0=cKf@3FdL/0VXf2080h;`2Q61D0ZQHF0:@I6`1o6QH0ICX]0;j`XP3Pf]80
hM_H0<NSW`2A;BL0U`h=09l;3P2Q2Pd0WPP:09l82@2K20T0T@T609m4<`2jWX`0e/o:09Y]I`222PP0
S`@708h21@2:0PD0R08309820`2_2@/0/`P:0;@91`2]2PL0T@<308D71`1l3@h0PSXk0<F_[P2k^k`0
`LG90<_@e039d=H0`lcD09j]/P2FYZX0FEeN07e[G00Gc082003o00T0oooo00@00?l00=1@N02P8?00
X23`0P3oP0020:0Pl1d0oh0000<0j6Pl0:0Pl03oP000103oP0000`3XJ3`0d51h0?n0000;0?n00003
0=1@N03oP000j6Pl00h0oh0000@0d51h0;Ph]02P8?00d51h1@2P8?00103@D7P0P<00003o0000o`08
0?ooo`1:003o000PcQL0N7ea0:bg^P2f`lX0_<W@0<_Be`2GViH0U9:409bEQ`2OUH@0XI>00:>FO`2U
UG/0YiEi0:fFM`2[UFh0ZiM^0;:HM02bTVX0/Y=O0;NEH02mVVP0`J5c0<JSN`34YGh0aJMo0<RXP@3;
[hh0c;>D0=:jW`3B_:<0eL2X0;f[W@1_L6l0NX5m06mjM01VLVT0aKfZ0=C1[P3H_jd0eXf20<4X9`3:
4Q40b0h<0<X?3@393Ph0`0/<0;T;2`2a4A80Y2ld07M0DP15?EX0>D=V04UAL01PJ840K7^D04]TQP1V
Lhd0RUm^09PO:02R1`/0U@`@0;FCUP32cM00];1o07U/5`2ER`h0[Z0709j@4P1GG440NXV?0:2PX00Q
fQL?003o00P0oooo00<00?l0052@N02P8?00302P8?0B0?n000030=1@N02P8?00X23`0080X23`00<0
d51h0?n0003oP0002@3oP0000`3XJ3`0d51h0:0Pl0060:0Pl0070;Ph]03oP000oh000?n0002h>;@0
X23`0=1@N0040?n000040=1@N02P8?00X23`052@N0l00?l02`3oool000X0oooo05H00?l006RI@@1l
RY00K7Z301H61`0>0@401`4100410@0B0@40;04202l00P0f0@40K0<809P52P2X20d0ZPX>0:LB502h
40l0`@`;0<D>302m4`d0]g=V0>3Je03Kg]h0fM3B0:]=B02g4a40_a8?0<8B403740l0aA<>09HM503D
^Zd0fmWE0=OGeP3Mg=d0fm_I0=oJd`37^Zd0Mcha0:DO6`2D81d0GQHB05@e:P3=_k80hmkH0=oKf@3B
]KD0Tc4]0:8B3`2T30h0X`X>09l8302O2@T0VP@609d72@2C2@H0ZEa:0<bgZ`3Ec//0PTQ008<51@2:
0@@0S@8708X210280P<0Q`010:06202]1PL0[`H60:l7202J0`<0PPH508@F5`1_5AH0Z8>10<[<c@2l
`<<0b<_A0<_Bf02ka/h0^/K=08BCV01[Kg40OfeO01S<0P800?l02@3oool01P00o`00d51h0:0Pl02P
8?00d51h0?n00080X23`7P3oP0000`2P8?00oh000?n000020?n00080d51h3`3oP0000`3@D7P0oh00
0?n0000<0?n00080d51h1`2P8?00103@D7P0P<00003o0000o`080?ooo`1:003o001EQ4L0Y:n`0;G3
c02nc]L0]lW@0<KCf02MXj00Shn309NCQ`2PUhX0XI>20:>CO@2SU7X0Y95g0:^AM@2/U780[IE^0:bB
JP2_TF40/iAQ0;JFI@2mWF/0aJIk0<JWP`36Z8L0aZ^:0<^^S`3;/YD0bkJI0<njW`3A^j80eL:Z0=O3
[P2[Wi40Ti6609fLSP2k/Z40e<Fc0=No/03FSH@0aRTV0=0C503?4A80c@l?0<d@403;3A00^a4A0:Tf
>@1_Ael0<CaQ04eKM`2?UYh0[K2b0:R]/P2CWJT0NhjR03]GMP2J^<L0am7J0;^KXP2F8BL0W@P<08@g
?`2l`/X0/Zmf08Ab501[H@h0Q80>0:2D2P2@RS40QY1l09RNV`0ka2`?003o00P0oooo00<00?l00:0P
l02P8?00302P8?0C0?n000040;Ph]02P8?00X23`0=1@N0X0oh0000<0j6Pl0;Ph]02P8?000P2P8?00
0`2h>;@0X23`0:0Pl0040:0Pl0060=1@N03oP000oh000=1@N02P8?00d51h103oP000103XJ3`0^3Rd
0:0Pl01@T7P?003o00/0oooo000:0?ooo`1F003o001/WTX0QiJO07N6T@0<0`@0304100L10P010@40
5`8203<20`0c0@80=@410581102>1Ph0Y0H;0:d93@2_2@`0^@/=0;d<3@3330d0]b8J0=^dZ03Mg]/0
g=kO0<bYZ02V8a`0XQ8@07T=2`213@`0_A@B0;LP5`2PF4X0g=?<0=SIeP3JemH0g/o?0=g8a03Qf=@0
h]_F0<2VW@1Z9al0HSP[09>0L@3?a;P0i=kI0>?Fe02jV9H0UD4n09hF4P2V3P`0YP`>0:<93@2Q2PX0
X@P80:062@2M1`X0TP/70;UlJ@3Ic/D0clG107L[90241080R@8408/31P2:0P@0R@8408D20P2>0P<0
Y`H70;LE502^1`T0Z@/908TD4`2[E5H0KA`M0:9dL02e];<0`<K90<C;d033bm@0bM?N0;?1b@2N[K@0
JW1d08=dJP0Gc0@2003o00T0oooo00H00?l00=1@N02P8?00X23`0=1@N03oP0020:0Pl1l0oh0000D0
j6Pl0?n0003XJ3`0oh000>QX?0030?n000030>QX?03oP000oh0000T0oh0000<0j6Pl0?n0003oP000
3@3oP0000`3@D7P0X23`0;Ph]0070:0Pl00308300000o`000?l000P0oooo04X03nd;09RNV@2d`/T0
]/G>0:2d_@2F[;<0/L;80:F/[P2>ShD0UiB909bFR@2NU8D0X9B10::FO`2UUgl0YYAi0:fEM@2]Tfl0
[95Y0:n?HP2dU6<0]iEU0;fLK@32XgX0`jV70<F[S`38[Y80bkBG0<beV`3=^Ih0d;bP0=6mX`3E`JT0
el>^0=[7/03Ib;H0elRh0=O7]@3G`k@0fIN=0<@Z903?5140d18A0<d@403=40l0b10?0;/Z;P24C680
<d9Z05Q]RP2LX:80c<K10<Fg]P2lXZ<0/I:C0;FIU@2WX:80O8fP06J5X02md=X0c=;H0:ekPP2C3A<0
RQXP09fIX@2c[g`0ZI@E095o2P1ME`/0MG8=09jB2P2LU2<0ViQ[05Bk@Pl00?l0203oool00`0Xb3`0
X23`0:0Pl00=0:0Pl1l0oh0000@0d51h0:0Pl02P8?00X23`1@3@D7P40:0Pl0060;Ph]03@D7P0oh00
0?n0002P8?00d51h1P3oP0000`2h>;@0T71h003o000>003o00/0oooo000:0?ooo`1F003o001`Xdl0
U:J[0723RP070`@02@4100@10@0200006@8203D10P0g0P40>P8204H20`1g1PX0WPT=0:T8302]20X0
]PX;0;h>3@313`/0`4Dj0=k<a@3Nhn80h=cM0:iKF01g40d0BadH06AAA@21Cd@0Y24D0<EYE@38/:80
fMSF0=_8a`35Q800_TM20;De;`32THX0h]cF0=oHd`2VVHX0e/jo0>CQf`3Rh^00a<S607UPG@1M9R<0
EaHC05dC401b4100T18C09`<302Q20P0X@L80:062@2L1PT0UQTB0<ROT03Ke=00`:fY07XG4`2:0`@0
Q`4208L20`270P@0QP4508H10`250P80WPH80:d6202`1@L0ZP/=0:Xi?P1n4a@0SR@S07P[:@36^KT0
_<730<3;c@31c=80a=3I0;W7dP2DY:d0L7b207ehLP0Ec0D2003o00T0oooo00@00?l00=1@N02P8?00
X23`0P2h>;@20:0Pl1<0oh0000<0d51h0>QX?03oP0001`3oP0001@3XJ3`0oh000?n0002h>;@0j6Pl
0080oh000P3@D7P=0?n000030=1@N03oP000oh0000h0oh000P2h>;@70:0Pl00308300000o`000?l0
00P0oooo04X0@m0i0;[6c@2ca=40VZnk07RCW@25WJ<0_L_B0:je^P2<SXL0VYR<09bFR@2NUXH0XYR6
0::HQ02PTgd0XY=i0:ZDM`2/TFh0[i5X0;2@H`2dTfD0]iEZ0;fMM@34YX<0`ZR<0<B/T037/I@0bK>I
0<^fVP3:]i/0d;bQ0=BnYP3F_jT0el:/0=[6[`3Gak80e/Ja0=O4/03N[j80aCTb0=@H4P3C5Pl0cQ4?
0<DD4P2j8B00ZdMB059>N011F7h0TI:H0;>VV`2jUX`0/VMR0:de=02Z61`0Y0hA0:<C5@2R<C<0Ygf1
06]jT02mcmX0bM;I0<_2b02>:C80SPhE085dP02la/@0[ZIU0:JE3`2PT@/0JV4709>:302IS`P0YiXT
07RX@0l00?l0203oool00`1@T7P0X23`0:0Pl00=0:0Pl0030>QX?03oP000oh0001X0oh0000<0j6Pl
0:0Pl02P8?000P2P8?000`3@D7P0j6Pl0?n000040?n000050=1@N02P8?00X23`0:0Pl03@D7P00P3o
P0020:0Pl0030>QX?03oP000oh0000D0oh003`00o`0;0?ooo`002P3oool0EP00o`00KJ9<08ZMX@1Y
N80020<400<10@0100400@4101T20@0k0P80?`8203l20`180@@0HP8608@5302O1`d0[0L;0;<:2P2l
2`/0_a0>0<MVG03Rf=L0h>3S0=Fj^@2@:200PeE80<:eZ03Bc<<0g<Rn0:AJA@3<VhP0fm780=WFdP2H
JF80T2LQ08DJ501H50d0ITm20<o6^`3RgmX0g]cF0=oMf`3;c/d0PXZ404QBB@1[I5X0R7a_08]oLP1k
L6@0E4Hl03<A3P1R3Pl0V@`=0:492P2R1`H0WPP70:0e9@3</Z40f=;A0:^<R0213P/0S0@508X31025
0@80Q@4308@11@240P<0P`4208l3102[20P0[PL80:`61`2V2@d0Ta8C094L6`1n8R00`:RX0;2d]P37
cm<0`lkE0<C>e`2kaM00T:2X07B1QP1dL6X05/d70P00o`090?ooo`05003o003@D7P0X23`0:0Pl02h
>;@00`2P8?0A0?n000030>QX?03@D7P0j6Pl00D0oh0000D0j6Pl0?n0003oP000oh000;Ph]0040?n0
00040=1@N02h>;@0X23`0:0Pl080d51h00<0X23`0=1@N03oP0006@3oP0000`2h>;@0X23`0:0Pl006
0:0Pl00308300000o`000?l000P0oooo01`0C/e90;G2c@2Q]L@0JHB@04QVK02L/KL0_/kE0;Fo``2<
SXP0UYF:09VDR@2KTHD0X9F40:>FP`2RTgl0XI5i0:RCMP2ZT6h0[HmT0;6@J02bU6/0]9I[0;bON@2o
X7l0aZR<0<N/T`34[I<0bkFL0P3<]il0;03?_:<0d[jU0=G0Z@3F`J/0el>[0=W6[`3Hb;40h<Ba0<]P
E`3?6QD0eAP@0=@E403271H0YE5M06EEN@0bBGP0MXVO0;>ZW`30WHh0]eiG0:hP802e30h0^PP;0;H6
2@2`1@H0/@H70;072@2P5Q/0KDmU08>M/@37dMX0c=3I09aLI@2>31@0LEAR0;C7d032b<00Zj970:^L
1`2RT`D0TH8<06]W1P2JTP`0N:PA3`00o`080?ooo`03052@N02P8?00X23`00d0X23`00<0d51h0?n0
003oP000603oP0000`3XJ3`0X23`0:0Pl0020:0Pl0030>QX?03oP000oh0000L0oh0000<0^3Rd0:0P
l02P8?000P3@D7P0103oP000d51h0:0Pl02P8?070?n000l00?l02`3oool000X0oooo04000?l006jR
C02;WZ<0DEiU00T21002000000000080000R0`<0>`8303d10@0o0@40C@8606422P1]00H0U0L<0:`8
302d20X0_0X:0;lA3P39MF`0iMkN0>;QhP2mU940SC0Q0<ndY`3EdL`0dmKD0=S;aP2UJUT0dk6R0=gG
d`3@blH0>RdS01h<0`0X6Pl0OWAU0<Vo[`3Mel`0g]kI0=cLf02KXIL0F5iA09nQT`3>akT0flo40>3E
c@3NeLh0gM;;0<^n/P2/WY<0BR@O08/@502R2`d0X`X709h:202XCcd0c;f`0=G@c`2SNGH0R0`<08l3
1`2@1@T0Q`440P220@<050210@00Q08408T10`2S1PT0ZP@60:`61P2^2@/0U0L808H>3P1e5QL0bjnc
0<?5b02ma/T0^LG90<GBf@2fa/h0XkBk07F3Q`1`KFP05/h80P00o`090?ooo`03003o003@D7P0X23`
00D0X23`603oP0020=1@N080oh0000<0X23`0=1@N03oP0000P3oP0030:0Pl0030=1@N03oP000oh00
0080oh0000<0d51h0:0Pl03@D7P01`3oP0000`3@D7P0oh000?n0000>0?n00080d51h1`2P8?000`20
`0000?l0003o00080?ooo`1:08fCK`2a`/d0NI:P03mMIP1CL7L0Q9bT09^a]P2mbL`0RHn;09FES02I
UX/0ViF709fFQ@2QTh<0Xi=o0:BDO02WU7L0Yi5^0:V@J02`T6L0/IA]0;RKMP2iWG`0_J630<FZS037
[I<0a:fD0<VcV`3<]Yh0ckNO0=2lY03@_jL0e<:/0=K3[@3HaJh0fLRa0=[7]@3LVY00abLP0=HI4P3D
5`l0abHP09MLK@0bC7L0FG>C09jQY`33/:<0aiB70;@m=`2g40l0^`X;0;P72P2j1P/0]`L:0;452@2b
1PX0/PD80:/72P2BA5@0Df^:0<7Cg@37dm/0ZH>;08`>5`1U@E40/lSC0<;?e02l_9@0/J<`0:NF1@2M
SPH0HU`806AS202GQ@h?003o00P0oooo00<0d51h0:0Pl02P8?003@2P8?000`2h>;@0oh000?n0000G
0?n000050=1@N02P8?00X23`0:0Pl03@D7P02`3oP0001`3@D7P0X23`0:0Pl02P8?00d51h0?n0003@
D7P00P2P8?000`2h>;@0oh000?n000040?n000l00?l02`3oool000X0oooo05H00?l006FF@@1MK6l0
DEeP00@20P020@40000000<0000Q0P<0=08303410@0e0@40BP8505h3201U0`P0P0@90:/9302g2@X0
_P/;0;`A303<P7D0hn7Q0>;Si@29O7@0RVUM0>3He03Mg=d0fmWI0=B[ZP2dFdh0fkFX0=gIe@3Hdm40
YY^A09jDQP2i[Il0d/[10=cJd`3LgMH0gMgJ0<g7_P2]ZIH0e]C40=kLdP3NfmH0g]cJ0=oMg03Lf]X0
gM_L0=gIf@3Id</0ZiJ?07TH5P2L2`/0W@P709P=2@2eL5d0d/[20=OAd02DH5`0S@`<0984202A0`H0
S@<608D110260PH0P`4408H21@250PL0V@H90:`7202_1PL0[@H80:882`2;1`X0P@hA08M3A@2j];@0
b<oC0;k8c@31cMD0^<O@09NX[`1lRXl0LFiY01O>2@800?l02@3oool00`00o`00d51h0:0Pl0050:0P
l0l0oh0000<0d51h0>QX?03oP0001`3oP000102P8?00d51h0=1@N03XJ3`30?n000030>QX?03@D7P0
d51h00P0oh0000<0d51h0?n0003oP0000`3oP0000`3XJ3`0oh000=1@N00@0?n000030>QX?02P8?00
X23`00H0X23`00<0P<00003o0000o`00203oool0B`2MSgX0UjVi04MVM01;JW<0HGj409nc^`22VJ00
a<oE08^AT02BThd0VYJ?09VCQ`2LUXD0WY>00:2BN`2SUG`0YIEj0:NBL@2^TW00/9A]0;6EK`2hWG/0
^J620;jWR`33ZXh0aJjD0<J]T`37[iD0b;:J0<fgW@3@^Z<0d[jW0=?2Z@3E`jd0e/Fa0=O6[P3Q_Zd0
adi50=@L5@3C5Q<0aRLR08mPN00eE880WJB/0<2dYP35[il0c9240;P/:@2k30d0_0T<0;X9302d2@X0
[10A0:HW;@2H<3L0XaLM0:l62P2]1PX0R39303mMP`2/a]@0am?K0;6CWP2:41X0GSM90;78eP2mbmH0
`/oA0;RdP`2XVQd0XY<409b@201lL0T0SX4@027I100>003o00P0oooo00<0d51h0:0Pl02P8?003P2P
8?0H0?n000050;Ph]02P8?00X23`0=1@N03XJ3`0303oP0000`3@D7P0X23`0:0Pl0020:0Pl0030?n0
003@D7P0X23`0080X23`00<0j6Pl0?n0003oP0000`3oP0000`20`0000?l0003o000<003o00/0oooo
000:0?ooo`05003o001BPbP0LH1l05EVIP010P800P010@40>`030@406P8102`10P0a0@40=`8203l1
0@1:0@<0E00207021`2N2@`0^@/<0;l<2P2n4@h0bGE^0=ODe03EemT0];B^0;Zg/P3De]H0fM?D0<jY
YP2`>cH0]R8J0<aeJ`3O`[l0gMKF0=gFe`3PemL0h=?A0<o0`02c[Z@0e]790=oMfP3Lem80iN?N0>GW
h`3Qh^00g=cK0=gMg@3MgM`0g=[J0=gJg03Kf]`0e]KE0=[Ed@2QHe`0U0h<09X72@2G5@l0`I1m0=SB
c@3Gd</0Rdi508`81`2F1PT0T`8708l21P270P<0Q@830080QP830180P`<708T2102V2@X0[0H70:h6
2@2Y2P`0T@T<09`Y:@228b<0`jn`0;Ro`@2c_/80_/_B0;W8d`2__lL0O8jC07=aKP0Hc`X2003o00T0
oooo00<00?l00>QX?02P8?001@2P8?0=0?n000040>QX?03@D7P0^3Rd0=1@N0/0oh0000<0j6Pl0;Ph
]03oP0004@3oP000103XJ3`0oh000?n0003@D7PA0?n000030;Ph]02P8?00X23`00D0X23`00<0P<00
003o0000o`00203oool0B`2JR740SZ6^03iNJ01;Jfh0KXZ@08fT[@2G[K@0`m7F08ZBT@2BU8h0ViJ?
09ZAR02LUXH0W9B209fBOP2RUWd0XY=i0:NCMP2^U7L0/YUi0;:IMP2gX7`0_JJ70;VTRP35[i@0`ZbA
0<N^T`3:/YL0c;JN0<beW03?^J@0d;jX0=;0Y`3C`:`0eL>_0=S4[03Q[9/0`bPN0=PJ403<6A@0/UaW
02U8N@2BXK40`[BU0<BaWP3?YYH0]STe0<@A4P2m2@`0^PT<0;<<3@2P8B<0TEIW044kH00Q9Dd0S3]9
0:`63@2V2@X0MC]=045US`1ZRjH0aMCK0;2DW`283aT0GCA80;37e`2ha/l0`]3G0;Zm/02/Y5h0Wi<I
09f=0`2TU@T0TH0:046b1`0>003o00P0oooo00<0d51h0:0Pl02P8?003`2P8?050?n000030=1@N03o
P000oh0000h0oh0000@0d51h0:0Pl02P8?00X23`203oP000103@D7P0X23`0:0Pl03@D7P20?n00003
0=1@N02P8?00X23`0080X23`00<0oh000=1@N02P8?000`2P8?060?n000h00?l02`3oool000X0oooo
05H00?l0051o8@1;FeD0AeMG00010@020@400@4000800@0I0`408P8102`20P0m0P<0@04104h1101M
0@D0M0@908/52@2b3@h0_P/;0<8=2`2n=c@0g[Rh0=gHf@3Jf=L0dlc;0<ZWZ02fHV40/BPV0;h@3P35
4A00_QLE0;ln>`3>NWP0bgem0<I/J`2hCdh0NC@_0;b^X@3Qg=H0g]gK0>7Qh@3Ui^L0iNKX0>;Ri03L
gMd0g=gN0=kMg@3Kfm/0f]WK0=WIfP3If=X0f=OH0;VCS@2A4Q40W@`>09h[7`3:Zi`0fMCD0=[<b`27
@S/0T0T809H62@2@0PH0SP8508H10`260`<0P`8208@20`250`D0Q04409@41@2W1`H0[0L;0:`8302X
2`l0V0P=094K602QNgP0/[Jh0;_6b@2kb<l0_/gF09FV[`25UIX0LfiZ01[A2`800?l02@3oool00`00
o`00oh000:0Pl0050:0Pl1d0oh0000<0d51h0?n0003oP0004`3oP0000`3XJ3`0oh000?n0000?0?n0
00030=1@N02P8?00X23`00D0X23`00<0P<00003o0000o`00203oool0B`2SRV/0RYVT04m[LP1UPXH0
OIVP07fIX@1kUYd0^lcA092JV02CU8h0UI>:09NAQ02IU8@0ViB409jFP`2SVHH0XIIn0:NFO@2_VG`0
/9Qg0;BMO@2kXX<0^jJ70;bYS@34[Y<0aZnE0<N`U037/YL0bKBL0<ZdW@3>^:40ck^U0=2mYP3B`JX0
eL>/0=W3[@3EQGT0cb0K0=LL5031?C/0EEMm06Z7YP32^K00bKBU0=>]X@31J5l0_ALE0<H?3`2m2Pd0
]Q0?0:4oA@1CAFH0;d9]06YhU02GRYP0X3Dj0:d82`2P82D0AcYI076=Z`1mV[80a=CN0:n=VP293QL0
FCA:0:S2dP2jb]80_lkF0<;=d`2k`[X0ZJQf09F<702RT`T0UHH:03?9200>003o00P0oooo00<0d51h
0:0Pl02P8?003`2P8?000`3@D7P0oh000?n0000C0?n00080X23`00<0^3Rd0>QX?03oP0001@3oP000
0`3XJ3`0^3Rd0:0Pl0020:0Pl0030>QX?03oP000oh0000D0X23`00<0oh000=1@N02P8?00102P8?00
0`3@D7P0oh000?n000020?n000h00?l02`3oool000X0oooo05H00?l005:0801YMG00B5MG00010P02
0@400@4000800@0H0P406@0001l0000g0`D0@04105L11P1^1@X0N0<708@52@2U2@/0_0`;0<4<2`2o
4Ph0`e5@0>BZZ`3AYJ@0]gIc0:D/:@2c4a80_@h;0<8>2`3640d0aQ0<0<LD403561H0`ALH0<<K6@2M
6QH0REmA0=gEcP3Nf]X0h^7P0>?Si@3Vi^P0iNGW0>CTiP3NgMd0gM_J0=oJf03Nf]T0fmWI0=_Ge`3J
f=L0fMKG0;VFTP2A5140U`X80:A2<@3;^:/0e=?D0=_=b@28?CL0T0L909432@2=0`P0RP8408T30`28
0P<0Q`4208@00P240@<0Q04508P00P2T1`T0[@P90:l93@2^2Ph0V`P;08L?3P2RL700cL_=0:Rc]@2m
bm80]/K@0;S8dP1mSI<0MWAa02Jh3P800?l02@3oool00`00o`00oh000:0Pl0050:0Pl1`0oh0000<0
d51h0?n0003oP0009`3oP0070:0Pl00308300000o`000?l000P0oooo01l0P:iH096MX`1TOX@0M8jE
06:0R027XjX0R:6Y0:fm`P2HXZ<0SY6;096@RP2BSh<0UI:309ZDQ02LUhD0X9V60:FIQ02[VH40/IYn
0;:MOP2dWh@0^j:70;VUQ`2mZ8/0aJjE0<B/T@34[i80a[2F0<NbVP3:]id0b[ZO0080c[bT02X0dL2[
0=G3[@3K`:X0bEA:0=DL5@3::2<0Q65l05=aU`33^kH0cKZ[0<n]WP2lJ640]R0N0<L@40323Q00^@d@
0;DD5@2?AE80Kg620:fWY@2iTXh0Yd0o0:L<3@2O7b<0GD5N03=BOP1INYH0DGF=0;W?gP2UOhT0Q`lE
05LjCP2[aM<0^/OB0;_;e@2kb]<0/[k70;>n``25Th00WJ1L09B;5`1iR@l>003o00P0oooo00<0d51h
0:0Pl02P8?003`2P8?000`3@D7P0j6Pl0=1@N00B0?n000030;Ph]02P8?00^3Rd00P0oh0000@0j6Pl
0:0Pl02P8?00d51h0`3oP0000`2h>;@0X23`0:0Pl0020:0Pl0030=1@N03oP000^3Rd00L0X23`00<0
j6Pl0?n0003oP0003P00o`0;0?ooo`002P3oool0@`00o`00DX8Q059QF`19F5L00@8100<20@010000
0`4101`10P0_0P<0=@4204421@1C0`D0J0@806l:3@1d1`/0PPH:09T71`2g3P/0`@d:0<H?30345Q80
^AhL0;0Q7P2^5Q<0^@l>0<8?3@333P/0a@l<0<D@3@343``0aQ4>0<LA3P2o5A80WAHE06l^9P39^K00
g][I0=gLg@3Ti>@0i>GW0>GUi`3WhnH0j]kO0=fh]`33Ph80/6UY0:e_K`3C_;P0fMSF0=KEeP3IeML0
[85m094B3P2G3P/0Z5=20<k2]`3Bdm<0e/[708Y3>`2B20T0U0@908/21P2:0PL0R@8408P21@270@@0
0P260PD04@250PH0PP8309/8202]20T0[PP<0:l:3`2/6Q`0P`/<095ADP38`l@0]l;30;g:d`30cmX0
Xk>l08JFW@1cKfl0=:4C00800?l02@3oool00`00o`00oh000:0Pl0050:0Pl1/0oh0000<0j6Pl0=1@
N03oP0003P3oP0001@3XJ3`0oh000?n0003oP000j6Pl01@0oh000P3@D7P60:0Pl00308300000o`00
0?l000P0oooo04`0JKDl09FQX@1hSYT0JhRB07fHWP1kUYl0Rj>[0<3>e02JXZ<0Q8N208^:P@2BTX@0
UI>509bFQ`2PVHX0X9Z80:NLR@2[VhH0/If40;>OQ@2gX8H0^:690;ZTR02lYh/0`:^B0<6/TP32[980
ajjH0<JbVP38]ih0bkVQ0<jkY03A_ZH0e<2Y0=K4[@3Q^jT0`S@[0=<N5@2iF640CUR20;V8TP3:Mfl0
eJJI0<^:P02[9240aQDE0;lH5`2O@Td0PdIF0:P/;`2[5aH0`GEX0;=XG@2W8b00YPl<09H_=@18>U`0
>5Al08ZJZP2IZ[P0UK720:S0d02KKGL0R0hF05A0E@2ab=L0_LWD0;g;e`2lcML0//3:0:jnbP1OLWd0
OHUi09:DCP2KSAl08]/53@00o`080?ooo`030<2P002P8?00X23`0140X23`00<0j6Pl0=1@N03oP000
3`3oP0000`3XJ3`0X23`0>QX?0060?n000030>QX?03@D7P0oh0000D0oh0000<0j6Pl0;Ph]02P8?00
102P8?000`3@D7P0oh000:0Pl0080:0Pl0030>QX?03oP000P<0000d00?l02`3oool000X0oooo05H0
0?l004Qf5@0lBT<0B5EG00810@030P40000000D1000R0P80?@8404X2101E0PD0IPD807L=4@2W=3L0
PA@G07`42@2@10H0Z@P90<0=2`373PT0bA0=0<<<2P2j2PP0]`X:0;X;2P2k30X0^`T80<4=2P323@d0
`Ph?0<<@3`324Q80RAD>06m1=P2n[J@0g=SG0=_Kg03Ng]h0i>?U0>_TiP3]alP0hi>F0=QNGP36:RD0
_a`I0:PB4@2O6AL0Yg9Y0=SGe03Ce]H0elk>0957@P2I40h0Ta0;0:YWEP3Ab/@0d<oB0=S=cP2:Bd@0
SPP80984202<0PH0R`<908T21P280@@0Q`8508L21P280`D0PP8508841`2@10H0[PT=0:d8302`2Ph0
[0d>08T;302FFe@0/jfX09jXZ@2ea</0_<gF0:jobP21TIT0N7Ef03JS5`800?l02@3oool00`00o`00
oh000:0Pl0040:0Pl0030=1@N03oP000oh0001P0oh0000<0d51h0;Ph]03oP0002`3oP0001@3XJ3`0
oh000?n0003oP000j6Pl00@0oh0000<0j6Pl0?n0003@D7P04@3oP0000`3XJ3`0X23`0:0Pl0050:0P
l00308300000o`000?l000P0oooo04`0Dl</09RQWP2<XZd0J8J?06V6S`1cSYD0PIfU0:>f_02RZ:/0
OX1k08V9P@2ASX80ViN909bHRP2RVh`0Yin@0:fRU02cXYH0]Z>?0;NQRP2jXX/0^:::0;RTRP2lYhd0
`ZjE0<:^UP34[ID0ajjI0<NbW038]9l0c;NQ0<jjX`3A_jX0dKn[0=G3[`3P/Z40`BPP0<TU802UK7h0
/EU[0<LN8@386aP0^eeL0;Q_L02d7ah0aA<C0;/nA011@6H0P82@0<>1O@2/5140]10A0:h@402T8b@0
MSa?02H_F@1FMI00[[k6096PZ@1lTJ00@F1k09R``@2BF6<0RPlG05A9GP2ecM/0_LcI0<3<f@2oc=P0
^LOC0:c0c01eT:D0KXNC09fWV@2HTUP0>M4L3@00o`080?ooo`030830002P8?00X23`0140X23`00<0
d51h0>QX?03@D7P00P3XJ3`=0?n000030=1@N03XJ3`0oh000080oh0000@0j6Pl0?n0003oP000oh00
0P2P8?000`3XJ3`0oh000?n000020?n000030=1@N02P8?00X23`00D0X23`00<0d51h0?n0002P8?00
2@2P8?000`3@D7P0P<00003o000<003o00/0oooo000:0?ooo`1F003o0011KP`0E65H04eIF`040P80
1@8200<1000@0@40<08404L21@1;0@D0CP4405P31P222@/0W0P:08/92P1f1@L0SPD809T31P2c2PX0
`Pd90<H?2`363``0`@h;0;T92@2i2`X0^0X80;`;2`313@/0`Ph=0<4>3@314100W1@B08MOD`3<a;T0
g=SF0=[Jf`3LgMd0h]kM0>W=c@3JOh<0dSLf0=LO7@3L7Q/0da/E0<dJ5P2h5a@0QAXE09N0M03Gf=D0
dmCD0;JGU@2<71X0V@h;08`A2P2aNFX0eM3<0=3@dP3FdM40SV9L08H;2P2@0PD0SP<508/31`2;0PH0
Q@4308<10`220@D0Q@8508P31`280`P0R`870:P8302a20/0/`/>0;0<3@2=30`0YGUa09BDR`2:UI40
^<G;0;C4c02hall0QYJM06m[K00hYAT2003o00T0oooo00<00?l00?n0002P8?00102P8?000`3XJ3`0
oh000?n0000G0?n00080d51h3@3oP000102h>;@0oh000?n0003@D7P30?n000050>QX?03oP000j6Pl
0?n0003@D7P04@3oP0000`3@D7P0X23`0:0Pl0050:0Pl00308300000o`000?l000P0oooo04<0AlHN
09NJT`20Uj80MI:N05IhO@1SP8<0SJF/08FIX@2W/[D0NGei08F5OP2=S880WIR>0:FNU02[Y9P0[jJJ
0;>WVP2eYiT0/J6?0;>OR`2fXHX0^:B:0;ZVS@2jYX`0_JRB0<2YT`33Zi@0aJnH0<NaVP38]9d0c;VT
0<nlYP3?_jT0dL2]0=G4[P3P^JD0_S4W0<h/:@3GMGd0aB@U0=8G5P308b00NUA[08ehRP2X?ch0^1/J
0;dK7`2f@TP0]T0m0;0Q7@2f3Ph0]0`<09Df>00m=540>TI^07mhQ02TU8h0aL700;W0``2N/;X0NYJ[
08:I[@2;Ae00Ra<J05E?I`2fc]/0_<_F0080_/kH00L0^lgJ0:o2c`1bRi`0Mi:O09NTY`2HW9H0DJY3
00d00?l0203oool00`20`000X23`0:0Pl00B0:0Pl0040;Ph]03@D7P0j6Pl0;Ph]140oh000P2h>;@8
0?n000030>QX?02P8?00X23`0080X23`00<0d51h0:0Pl02P8?000P2P8?000`3@D7P0oh000:0Pl00:
0:0Pl00307QH]000o`000?l000/00?l02`3oool000X0oooo05H00?l004Ac4`1LJF<0BEMH00<10@07
0@402P0001l10`0o0`H0A`4404H310120@<0BP8408H:402E2Pd0M0D706/3102;10H0TP850:@51P2l
30T0`0/90<@=2`323P/0^@X80;X<2`2k2@P0``d>0<<=30323@`0_`/:0;HA401f9b00bKje0=SHeP3J
f]/0f]WK0>?JfP3O];<0be]K0=HW9@3N7aX0eAD?0=<F4P3@5a@0aQTF09dJ5`1R;R<0b<:h0=KFe03:
_;`0T4U809H@3P2H30X0Q0l50;J6M`3Ed]00d=7C0=?Dd`2>Mg<0N0h@0944202?0`D0RP8408D10P22
0@<0OP0307h110230PH0R@<908/42P290`L0X@L<0:h82`2b2P`0]0d=09d;3P2>AT80Xi><09:HU@2X
]kX0_/cE0;2maP2?X:H0MWIg03ZX7P800?l02@3oool00`00o`00oh000:0Pl0030:0Pl1/0oh0000<0
d51h0?n0003oP000303oP000103@D7P0oh000:0Pl03@D7P30?n000050=1@N03oP000oh000?n0003@
D7P04P3oP0070:0Pl00308300000o`000?l000P0oooo04`09]/=09NBQ@2G[;H0FWN005mmP`1KNGh0
FgEm07Z=T@2`^K`0MWUg0861NP2<RGl0V9B:0:BOV02]Yj00[:>I0;2UUP2]Xi40/ZFA0;6PS02cWhL0
^JB;0;ZUS02oYhl0`J^D0<6ZU@33Zi@0a:jH0<J_V03:]9d0bKRP0<^jX@3>_Z@0d/6Y0=;0Y`3H`jl0
dW]_0<PZ8@3<9b@0b2<M0<93@@28Hg`0=eR40;2c/`3@/Z@0`h9e0;M4?P2b=3@0Z3/n09M3B`2b>S/0
Z`h>09Q;E`24@UD0ZC]30:4N8@2Q7R<0X3]10:AgN023S9H0Rj2b08JFZP27=C/0RaDM05UJL@2jd=`0
^/[E0;S<e`2hbmL0^/cI0;S9eP1hSZ<0DFj307jCW@2?W:00NG=]3@00o`080?ooo`030830002P8?00
X23`0180X23`00@0^3Rd0=1@N03oP000j6Pl403oP0000`2h>;@0X23`0:0Pl0050?n000060=1@N03o
P000oh000>QX?03@D7P0j6Pl0`3oP0001P3@D7P0X23`0:0Pl02P8?00j6Pl0?n000`0X23`3@00o`0;
0?ooo`002P3oool0EP00o`00@g<B05IVH018EEL0104101010@0J0@40:@4204<21@170PD0>`4203l1
0P0n0PD0FPH;06<5201?0@<0L0D908d51`2C10H0W@@40;T<2`302`X0``d;0<4<2@2n2PT0`0d<0;l<
302m30d0_@/<0;h<302m40h0UA@@0:>2M`3IeM80f]WK0=_Jg@3NdmD0c8J60<@l>P3A8A`0f1TD0=HI
4@3A5a00d1HC0<LJ602=6A<0H2hT0:fQU03Jem<0a[jm08ABD0296AT0V@`=09`=3`2:5`l0_9:50=?B
d@3@dM<0dM;A0:bTX@1F3Pd0S0L:08/21@290PD0QP8308820`1m0@<0P04408@210250`D0R@@708T4
1@2G1@T0[@P<0;<92`2d30`0Z@d?07d>4@1S9BD0Vi6>0:fj_P31cmL0_/cG08ZLX`1VJF/0>ZTP0P00
o`090?ooo`06003o003oP000X23`0:0Pl02h>;@0j6Pl6P3oP0000`3@D7P0oh000?n0000;0?n00080
d51h00<0oh000>QX?03@D7P0103oP0001@3@D7P0oh000?n0003oP000d51h01<0oh001P2P8?000`20
`0000?l0003o00080?ooo`1=01kT2@2OThD0RYjZ06AoR01LNGh0NI>H082HW@2[^kl0]l3607UlOP22
PG/0RhQo09VCRP2QWID0ZZJN0:RUV@2]YIH0/:BF0;JVU@2cXHh0]J290;VTS@2lYhl0_:J?0<2XT@31
ZI80`J^C0<:]UP35/I/0akJN0<^iXP3<^Z<0ckjW0=;1ZP3Fa:h0e/Bd0=c6]03MZY`0/7Ie089/P01A
IhX0Hh2N0;2c]`35^Zl0aKVZ0<FfY`2eXiX0OgZ605aTNP1UIG/0XSi40;<;3@2b4QH0/0X?0;<6302b
1P/0[`@:0:X52P2N3Q<0Z71h06AfR01HHG@0QBL_08dF8@1IGGD0^]7K0;W:e@2jc=T0^lgH0;c=f@2i
bmP0VK7707nL/02AY[00Vj^a08F4Q00:iP@03000o`080?ooo`030830003@D7P0X23`01<0X23`0P3@
D7P>0?n000030=1@N02h>;@0X23`00@0X23`00<0^3Rd0:0Pl02P8?000P2P8?000`3XJ3`0oh000?n0
00060?n000030=1@N02P8?00X23`0080oh00302P8?000`10h0000?l0003o000:003o00/0oooo000:
0?ooo`1F003o0012LaH0JGYg04MCE00B0P809P8302L10@0`0080A@8504h21P1>0@@0E08604431P1=
:b`0P5=C05D;30201PX0T0D909H41`2M1@H0[PP80;h;2P332``0`P`;0;l;2P2j2PL0]PP90;T:302l
2Pd0_Ph@0;8Q702;Bd80em3;0=_Mg@3MgMh0emKF08E[J`1m7ah0^1dK0=HK5`3F6180daLB0=@I5P34
6aT0N1LC07mWGP3<a;d0gmcJ0<_=b`18C4L08Pl:04/:2P2=3Q00VPh@08`O5`31VXh0dm;A0<o@dP3A
dMD0bLW804H^;01_2``0R0D608P30`280`@0P`4108010@1o0@<0O`4408811@240`L0R0@908h21@2]
2``0/PT:0;<:3@2_30h0T18B068D4@2ORhX0]l?:0<3@f@2b`l/0UJF/05iRI00k[242003o00T0oooo
00D00?l00?n0002P8?00X23`0>QX?0080?n000030>QX?03@D7P0oh0000l0oh0000H0j6Pl0?n0003o
P000oh000>QX?03@D7P80?n000060;Ph]03@D7P0oh000>QX?02P8?00d51h103oP000103XJ3`0oh00
0>QX?03oP0020=1@N180oh001P2P8?000`20`0000?l0003o00080?ooo`0I003o002MRW<0SIn[06V6
S`1_RXl0HWj305ilO`2:XZL0]LC907j3Q020PG/0S8^009^FR`2TWID0YZ6I0:RTVP2[YIP0/:FF0;JU
UP2gXHl0]in90;VRS02lYHh0^ZB=0;jWT0020<2[T`0b0<:_V036/Yd0b;JP0<ZiX`3=_:T0d;j[0=6o
ZP3D`Zl0fLNg0=G7^P3Fb;`0c<:k0;Zh^@33_kd0b/2f0<Vm[`36^Z`0`KNY0<>iZ`30]ZP0^k6R0;NY
V`2jPGT0ZAPG0;H92`2c20T0]@L:0;H62`2d1`T0/@H80;051`2/1@T0UALO09J?X@2TXjh0R1hU08hG
8P1LI7d0^LoK0;c=f02kc=P0_LkK0;_<fP2jbmP0R9nd07BBY@24V:80T9nV08:4R00G_``<003o00P0
oooo00<00?l00=1@N02P8?004@2P8?00103@D7P0^3Rd0=1@N02h>;@30?n000030>QX?03oP000oh00
00P0oh0000<0j6Pl0=1@N03@D7P00P3@D7P60:0Pl0030>QX?03oP000oh0000P0oh000P2P8?020?n0
00`0X23`00<0P<00003o0000o`002P00o`0;0?ooo`002P3oool0EP00o`00BGlW05Y]K`1?DeL0:@@4
03D3100Z0@40;`4304<20`1=0@D0D08605@1101M2`l0LdA508I@C`1l6a/0QPD60945202H10L0W0D6
0:@51`2k30`0`P`<0<4=2`2k2`L0^0X80;X;2`2l2`/0_``=0;@G4P2oJE/0`:VN0=_If@3Mg^00d]KF
06UbKP1NGUL0NfEL08ld;`3:81/0fa/G0<lL6P2Z6QT0J1TE095oM@3Ie<`0g]kJ0=[If037b<80/[6V
0:2KS`1WEdl0Ja4B09P=402>81T0a9nD0=?AdP3>d=<0cm;F0<oBe02ATX`0:0T706892P2210H0Q@82
08410P200@80OP4308021P281`P0Q@<608H420240@D0Y0X;0;4:2`2b2Ph0/@h?0:`b<024>CL0W7in
0;6l`P2nc=D0`/oI09>S[@1RHf@0=jLL0P00o`090?ooo`04003o003@D7P0X23`0:0Pl0T0oh0000<0
j6Pl0=1@N03oP0003`3oP000103XJ3`0oh000?n0003@D7P20:0Pl0030;Ph]03oP000oh0000@0oh00
00P0d51h0>QX?03oP000oh000=1@N02h>;@0X23`0;Ph]0D0oh0000D0d51h0?n0003XJ3`0^3Rd0>QX
?00A0?n000030;Ph]02P8?00X23`00<0X23`00<0P<00003o0000o`00203oool0C@00o`00Z8i]09JW
/P24WjX0I829055`M@1WQXP0KhZ>0:bl`026Rhh0P81l08b<Q@2NVi<0XIfF0:JQW@2ZY9d0[:FJ0:nV
V02eYID0/j6>0;BRS@2fXX`0^JB<0;^WSP2kYXl0_jZD0;j[U@30[IL0a[6L0<ZeX@3=^JL0ckb/0=2n
ZP3A`:/0e<>`0=G5]03FbKX0dlRh0=38^03?a;T0b/:d0<W1/P37_K80`k^^0;^gZ@2l]jX0^K6U0;R/
W`2lR840ZRDW0;D;3@2d2@X0/`P:0;D92`2/2@`0YA<E0:8L802U3180Z`@809T63@1G>eX0Kg>808PF
7@2?51h0H6Il0;[?g02caLl0^lgH0;[<f02kc=L0]lWG09b_a@1DL8H0MhfG08ZKW`2;U9L09IhJ00`0
0?l0203oool00`00o`00d51h0:0Pl00D0:0Pl0050=1@N02h>;@0j6Pl0;Ph]03@D7P0303oP0000`2h
>;@0X23`0:0Pl0050:0Pl0030>QX?03oP000oh0000T0oh000P2P8?020?n000`0X23`00<0D91h003o
0000o`002P00o`0;0?ooo`002P3oool0EP00o`00CH8^082AU@1PGf<0<0@403410`0U0040<P8504P4
1@190P<0B`4405411@1P0PP0J`XA078:3`1k10P0R0D709851`2I0`L0W@D809l41`2g30d0``d=0<8<
302l2`T0^0/90;/=3P2i2`X0]`X;0;@[8`37TH40eLW20=SHfP3DdLl0IVUR07b2N03BcLH0gm;=0>:/
Y@31<R`0ca`K08`G5`0l30H0Rge`0=_Fd@3Oh=l0hN?R0>3Ph03Lg=/0e=OB0=CDcP3?aKh0QT8m09<>
3`2?7aP0a9nE0=7AdP3=dM@0c]?E0=3DeP3:b/P0?CTe01`1001T1`X0P@4307l10P1o0040O`830884
1P211`P0NP4407l32P1l0`H0U`H90:`82@2a2``0/@/=09`=3`1m3a00UEmO0:Va/`2mb]<0[K_70:6a
^`1MGf40=jLM0P00o`090?ooo`04003o003@D7P0X23`0:0Pl1d0oh0000@0d51h0:0Pl02P8?00d51h
1P3oP0000`2P8?00oh000?n000050?n000070=1@N03oP000oh000?n0003@D7P0oh000=1@N0020?n0
00030=1@N02P8?00oh000100oh0000<0d51h0:0Pl02P8?000`2P8?000`20`0000?l0003o00080?oo
o`1=003o0025/ed0U:B^08^T/P1FLW`0;d]@05mhO01SOh@0Z;Rl08nDUP1lOGT0S8^509RIS`2MWI<0
YJ2G0:bTW02_YY`0[Z>H0;>UV@2dX940]Z:=0;NQSP2gXh`0^JF>0;fXT02lZ980_JbE0;n^V@33]9h0
bKfZ0<^j[03>_Z/0c[nZ0<o1[03Ba;80dLJf0=;9^03Bb;X0clJi0<g4^P39`[D0al2c0<Rn^033^[80
_kN^0;^dZP2j/:@0_Xn:0:PV9`2h3@l0^0X=0;882P2Y3`h0WR/a078mDP15@6<0@TYY08MBGP2Q2Q00
U@P=05E0F`1mPYP0Qa<J08h<5`1UHGP0^<oL0;_:eP2hb]L0]/SF0;S:e`2da]D0XkK<07N@YP2>Xjh0
V:Z`09RSZ00oLbh03000o`080?ooo`03003o003@D7P0X23`01D0X23`00<0j6Pl0;Ph]02P8?000P2h
>;@00`3oP000j6Pl0?n000080?n000L0X23`00<0j6Pl0?n0003oP0000`3oP0001@3XJ3`0d51h0:0P
l02P8?00d51h0080oh000P2P8?020?n000`0X23`00<0d51h003o0000o`002P00o`0;0?ooo`002P3o
ool0EP00o`00HIY:08fPZ01[J700>PD603H20P0Z0@40<`8304@31P0n0@<0?`4304P1101O0PP0L@@:
07L32P200`T0R@D:09441`2H10P0W0<709l61`2_2@X0_P`<0;l;302i2P/0]0P90;H92`2e2@T0]PX;
0;@l<P2jU8H0f=7?0=KDe@2FQH00PfmT0<k8`03Kfm/0gmgM0>G9b@2]AD<0O1HC05e0>@2WXYT0e]C=
0=oQh@3Lh>80fn3P0=gQhP3KgMl0eMSH0=7Ee@3Ee=@0[H9n08`D4@2:6Q<0_YN?0=;@d`3?d]D0c]7D
0<oBe@3?dM@0WifI03XR7`1Q2@T0P@8308810`1n0@<0O@4308X@4P235A@0LP8506T210258240T0X<
0:h=3P2a2`/0/P`=0:D@402>5QL0Q3dn0;Rh^`2e_lP0`/kG09ZZ/`1]L7@0?:`S0P00o`090?ooo`04
003o003@D7P0X23`0:0Pl1d0oh0000<0^3Rd0:0Pl03XJ3`01@3oP0000`3@D7P0X23`0>QX?0080?n0
00050>QX?03oP000oh000=1@N03oP0000P3@D7P0103oP000^3Rd0;Ph]03@D7P@0?n000030>QX?02P
8?00X23`00<0X23`00<0P<00003o0000o`00203oool0C@00o`00PJM809ZU[@1kUj<0>EMP05A/L@1U
OhH0NiFJ09BVZP2GWj80O7ij08F5OP2FV8d0XJ2F0:JSV`2/YYh0/ZJP0;6UW02bY9T0/j>C0;>QS@2c
X8T0]j::0;^TS02kYhl0_JZB0;n/UP2iZiP0/[2T0<_?cP3=bL40c;bZ0<boZ03<`:`0c/6a0<c3/P3@
aKH0d<Fg0<c3]P39`KT0bKnh0<W0^035_KD0_[R_0;bh[@2l]JX0`Z>K0:Xb=02h3Q40^@/>0;4=3`2P
;C40JdQP02/lI`12F7L0NXRC09jOWP2WM7@0WP`@09HP900d=U<0TY2P08HA6@2>1Pl0IU5T0;O@g02k
bm@0^/cE0;[<f02gbML0[L3=09BZ_P1<KX@0NiJQ086DW022SiT0@e`j00`00?l0203oool00`00o`00
oh000:0Pl00D0:0Pl0040=1@N02P8?00^3Rd0;Ph]080X23`00<0j6Pl0=1@N03oP0001P3oP0000`3X
J3`0^3Rd0:0Pl0050:0Pl0030=1@N03oP000oh000080oh0000<0j6Pl0;Ph]02P8?000`2P8?000`3@
D7P0oh000?n000020:0Pl080oh0000<0^3Rd0:0Pl02P8?002@2P8?000`2h>;@00?l0003o000:003o
00/0oooo000:0?ooo`0^003o002:NUh0ZKc806]YLP0l1@H0?@<302T10P0S0@80=P8303<20P0c0@40
@04305/11P1b0`P0O0<908422P230`P0R@@609D41`2H0`D0W`L80:L61`2h30`0^0/<09d51P2F1@H0
[PP;0;87202b20P0/D0c0;fPTP3Gdm80c<[:06]YG03?a[d0emCD0=KGf03<cLd0RGel04PW8`1nLVT0
b/[30=WIf03Ifm/0f]kO0=[Kg@80fMgN02H0f][L0=SIf`3EfM/0dmSH0;^TXP2761D0RQH@0;^?Q`3C
dmH0cM;D0<oCe@3?dmH0cM;D0<g?c`35]k80Te59084610250P@0Q04507l11@1n0PD0N@8407@10P1T
0P<0QQ<H09H;402P2P/0/Ph=0;<=302W61L0gG]n06lW:P2h[[80]<770;c9dP2V]L00IVab042c;@80
0?l02@3oool01000o`00d51h0:0Pl02P8?0J0?n000050=1@N03oP000d51h0:0Pl03@D7P00P3oP000
1@3XJ3`0X23`0=1@N02h>;@0d51h00X0oh0000P0d51h0?n0003oP000j6Pl0?n0002h>;@0oh000=1@
N080^3Rd00<0d51h0>QX?03oP0003`3oP0050:0Pl003052@N000o`000?l000P0oooo04d00?l005K5
<@2GWZ<0L8ZH049OI`0kDeX0FG=g061lP@2<XZT0WjZ]07j3P02<ShP0UiV>0:2NV02XXY`0[JFN0:jT
WP2`YI/0[J6F0;6QT@2dXHl0]J6:0;JRR@2jYHd0^jR?0;fZT@2m[9H0XiZ;0<C5_@2i_KX0b<6d0<Zl
Z@3=_Z/0c;n[0<k2/@3>`k80clBg0<g4^03<aKT0b/:h0<_5_036`;H0`[bc0;jh/@2m]jl0_[6Y0;AP
GP2h4aD0^Pd@0:dG5`2AADl0=caV03iJOP27TiP0WIfC0::PT@2]V8l0W3<e0:493@1j>DX073aU07]m
R0224QL0UPD>06TfAP2_bMP0^/_G0;[:e`2kb]X0^/WG0;C7d`2T^LT0Hh2B07jHX026VIl0OXjI03Pj
>P0<003o00P0oooo00<00?l00830002P8?00502P8?000`2h>;@0X23`0=1@N0020:0Pl0030;Ph]02P
8?00^3Rd00L0oh0000<0d51h0;Ph]03@D7P01@2P8?040?n000030>QX?02P8?00X23`00@0X23`0P3o
P0000`3@D7P0X23`0:0Pl0020?n000030=1@N02P8?00X23`00X0X23`3000o`0;0?ooo`002P3oool0
EP00o`00SgmU07N=VP1UIV`0>@D403/30P0Q0@406P4103H20`0^0@80<00004L1101K0@<0L@8507X0
1@2210X0Q@<808/41`2>0P<0T`<509T41P2O10H0[PT;0;<:2P2U2@/0TP<40:T7202a20P0/@L60:h]
9@34UHX0fM7?0=3>c@2b[Z@0eM;=0=GFe@3Ae=<0N8J101@S601hNFd0d<k50=SKfP3Gg=/0e]cK0=OM
g03GfMX0e]_J0=OKf`3Jf]/0f=WL0=CHf`3BemL0/I6@08/C4`2@5180/gmg0=?De@3=dM@0d=GF0<gB
e03=d]<0blc=0:fHV024>cL0Q0H808P21P270@@0P`8507l21@1j0P@0M`4306L10P1m1@P0X@T>08l1
0`2Z3@h0/P`<0:`=4@2J41L0M1<G0<Be^P2a_<<0a]?M09FV/`1dNh<0@;8/0P00o`090?ooo`04003o
003@D7P0X23`0:0Pl1`0oh0000D0d51h0:0Pl03oP000oh000=1@N0030:0Pl0030=1@N03oP000oh00
00`0oh0000@0d51h0?n0002P8?00oh00102P8?0A0?n000D0X23`00<0D91h003o0000o`00203oool0
CP00o`00E/4X0:2RXP1^Q9<0CVYd04IPI@1FLWT0NYFJ08VNXP2X]KX0QH^<09:CT02IVY@0XZ6I0:FS
V`2YXid0[JBM0:nSVP2bXID0/9n?0;:OSP2dWXX0/j280;JUSP2hYi80^ZVB0<6^V02_X900YYnB0;J_
W`3<_JX0c;f[0<fm[P3;_:X0cL6_0<c0/`3<`kP0cL>j0<k3^`3;`[T0bL6i0<Jo]@34_K@0_;Za0;fi
/@39[jX0ZRT]0;d?4P2a71X0aVUT08m6D`27Gfh0Wi^E0:>RUP2QX9<0ZinC0:AIE`2P3@l0V2/c02l`
F`1aT:P0XjR_080H7P2H0`X0OAl/09n/^`2kbmP0]lSE0;S9e`2hb=H0]<OD09ba`P1_Rih0NI:L09>X
[@2@XZX0?4A600[V10/00?l0203oool00`00o`00P<000:0Pl00G0:0Pl0040;Ph]02P8?00X23`0;Ph
]0H0oh0000@0j6Pl0?n0003oP000d51h1@2P8?000`3@D7P0oh000?n000020?n00080d51h102P8?00
0`3XJ3`0oh000>QX?0030:0Pl080oh0000<0j6Pl0:0Pl02P8?002P2P8?000`10h0000?l0003o0009
003o00/0oooo000:0?ooo`06003o001hIdT0QIbT06e[LP0h1@D0<@820P0M0@40CP0h0P@0=`420403
0`1=0P@0GP<407421P1l0PP0PP<708D31`2;0`D0T@D609<41`2K1@P0V@<60:<5202^2@T0[PL70:X5
1P2^1`L0/PL80;D82P2^40h0]e5;0=>]ZP3Hd]80f=;@0=K>cP3=^[/0NgAb041<@@2FVHd0cLg60=[K
fP3Ff]/0emcL0=WKg03JgMd0f]_L0=SIf`3GfMX0fMWL0=OGg03BemT0d]3A099DD`2D4140U18@0:=T
G@3Bd=00cm?F0<kCeP3?d]D0d=7B0:Z=SP1n:bX0Q0`=08P320230@@0Q08307l10`1l0@80NP4407T1
0`1W0P<0NP@60:072`2@1@L0V`/=0;8=3P2_2`h0XP`?08/V9`2bYZP0]L780;k=e`2Y^/P0JgEk05R0
<`800?l02@3oool01000o`00d51h0:0Pl02P8?0O0?n000050>QX?02P8?00X23`0:0Pl03XJ3`0303o
P0001`3XJ3`0oh000?n0003XJ3`0oh000>QX?03@D7P00P3XJ3`00`2h>;@0oh000?n0000@0?n000D0
X23`00<0d51h003o0000o`00203oool0CP00o`00:]lC09FES`2@YkD0@5aU04=LHP17HFD0M8nC07J>
T`2g`/P0QHZ>092@SP2JV9D0XInJ0:NRW02YXYX0[JBL0:jRVP2_XI<0/Z6B0;:PS@2dX8/0]:280;NV
SP2kYi80_JZG0<6aWP35/j00aK>S0<VjZ03;^JL0cKj/0<^o/@38_:`0b/:^0<[2/P3;a;L0bL6g0<c3
^`3:`[T0b<6j0<Bn]`32_KD0_[Z`0;nh/@35YJ80ZQlS0;LB4@39E4h0YQlP0:h=402K6ah0S7en09nR
V`2/W9@0YeaK0:<@502U2Pd0WD1;06I;I02YYZ/0TiBL08@V;P2I0PT0R`LA09QgQ02ncML0^<WE0;W;
f02fbM@0]/SE0:Fkc01>JWh0KHJ?06b1Q@1eR8h0>dQ?01W23@/00?l0203oool00`00o`00P<000:0P
l00H0:0Pl0030>QX?02h>;@0oh0000<0oh0000H0^3Rd0>QX?03XJ3`0d51h0:0Pl03@D7P60:0Pl003
0=1@N03oP000oh0000@0oh000`2P8?001@3XJ3`0oh000?n0003XJ3`0^3Rd0080X23`0`3oP0000`2h
>;@0X23`0:0Pl0090:0Pl00308300000o`000?l000T00?l02`3oool000X0oooo01`00?l007m^D@2M
/[l0K6Uc03@51`0U0@40704102<10@0e0P@0<08203@00@1:0P@0GP8507<31`1n0`L0Q@D908H42@2:
10H0S`<609D4202I0`H0U08509L21@2U1@P0[`H80;061`2b1@L0/PD80P2e1`/02`2c2`h0/2LW0;UI
F`2fGf80YdY<06hZ:01SDTT0`Kng0=SHe@3Hf]/0fM_M0080f=[L02/0gMSL0=c6b`32TIH0WFmc08Ei
N`3Adm@0emOK0=7Ee`2OSXh0PAdO09X=402J3Pl0VT4l0=77a@3=d]<0c]?E0<oDe@39aLH0O3<b08/:
2`2:1@L0Q08408810`200@40OP4307`20P1k0@<0M`4306L20`1f10H0X`X>09H;3`261PT0[``A0;0<
3`2V2`h0R1DH0::9S02`_/D0`=3K0:Fe_`1cOH40F8<e00800?l02@3oool01000o`00d51h0:0Pl02P
8?0P0?n00080^3Rd203oP0000`3@D7P0X23`0>QX?0020?n000030:0Pl03oP000oh0000<0oh0000D0
^3Rd0=1@N03oP000^3Rd0>QX?00B0?n000030;Ph]02P8?00X23`0080X23`00<0d51h003o0000o`00
203oool0CP00o`00:=/<09::NP21UZ00H7^403aDFP1AKgL0MI6G07jDV@34c]H0RHbA08j=S@2FUY80
WY^G0:FNW02ZXIh0[ZFL0:jRV@2/Wi<0[Yj?0;6NS02cX8T0^:290;RTS02mZ9@0_JZH0;f[W032/J00
a[>S0<ZgYP3:^ZP0c;n^0<^o/@37_Zh0aKf^0<O0/@36`[D0b/6g0<S0]`39`kX0aL6h0<>o]P30_K@0
_[bc0;ff[P37/:d0Z3Dh0;DA4P30;2`0/`hA0:TA4P2B?Dd0;SYQ0::AU@2RATD0Y`lA0:/62@2Z10T0
Y@D909h9402H<cH0Yi2A08Ti?P2H0`/0V@@<08HQ:P32]/00^LWD0;O9e02eb=@0]/[G0:>kc`1<JHH0
>eEc02i7HP0hD6L0<DQA02ZT6`/00?l0203oool00`00o`00P<000;Ph]00C0:0Pl0030=1@N02P8?00
^3Rd0080X23`00<0^3Rd0=1@N03oP0000P3oP0000`3@D7P0^3Rd0:0Pl00:0:0Pl0030=1@N03oP000
oh0000<0oh0000@0j6Pl0:0Pl02h>;@0j6Pl1P3oP0001P2h>;@0j6Pl0?n0003oP000j6Pl0;Ph]0X0
X23`00<0J:Pl003o0000o`002@00o`0;0?ooo`002P3oool07P00o`00PFmF09f`_@1]J7<0;`D601l1
0@0K0@408P4102X10P0O0@40:P4104H20`1N0PD0LP8807/21P2310P0Q`D808h31`2C10L0T`<50983
1`2@0PH0U08809h31`2/1PT0/0L80;06202b1PT0]0L90;D:3080^0`=03H0^0lC0:0E5@1O4@h0L5]A
0<W8_P3Gf=T0fM[L0=OJfP3Jg=`0gMCF0=Bb]P33N7h0ZCY006/P7P1F>SH0ZjRR0=CIf@3=cM00]KJe
05A?BP1Q4A40V0h@09`<402B7Ql0b;6]0<oDe@3@dmD0dmCG0;V/[@1h5AD0S0<608/31P270P<0QP41
08D20`210@<0OP4307`10`1g0@80J@<305@10P1k1`d0M@H;07<51`2Z3A00/0/>0:X:3`2B2`l0S5MI
0:Zc^P36dmh0Y[Fo079jP01IPcL2003o00T0oooo00@00?l00=1@N02P8?00X23`7`3oP0000`2h>;@0
j6Pl0?n000080?n000060=1@N02h>;@0oh000>QX?02P8?00^3Rd103oP0020>QX?080oh0000<0d51h
0?n0003oP0004@3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030=1@N000o`000?l000P0oooo04h00?l0
01C^1@2SUh00UZVd04APJP1ELGX0=5IK076;SP1iT9H0`m3H08fCV02@TI40VIVF09fKU`2RWiX0YZ2M
0:^UWP2ZWiH0ZYfA0:fLSP2bX8d0/9n:0;FPR@2iXhd0^:ND0;^[V02nZiT0`JjL0<JcY039]jH0akRX
0<Vk[P3:_k00b/6c0<Bl/@36_[@0a<6e0<K2]`37`;H0b<6g0<K0^032_kH0`<2j0<70^P2n^K@0_KJ`
0;b@S`2Y?Cd0YRDX0:0c>`1kBV40?T=^07I>J`2R9BX0Z`X<0:h82@2Y1@L0Y`870:L3202Z10X0W`L=
08=<E`2=F640T`H=09P32P2?10d0RCM30;Zj``2dam<0]LWJ07nK^P0Q?G800AE?004@@`013S/00@hf
01X^@`0hQB`;003o00P0oooo00<00?l0043P003@D7P0502P8?000`2h>;@0X23`0:0Pl0020:0Pl003
0=1@N03oP000d51h0080j6Pl00<0d51h0:0Pl02P8?002P2P8?001`3XJ3`0oh000?n0003XJ3`0d51h
0:0Pl02h>;@0203oP0020=1@N0<0oh0000<0j6Pl0:0Pl02P8?00202P8?000`3@D7P00?l0003o0009
003o00/0oooo000:0?ooo`11003o0027N6<0^<WG06mWLP0`10H0904201d0000R0@40:P4102L10@0a
0P80@`4405L11@1a0`L0O@D8088520281@T0S`@609021@2?0P@0S`@609031`2B0`P0T`860:<41`2_
1PX0/@L:0;<72P2d1`X0]@T;0;T>3P2j3Pl0/Q4D060>3@1[Fdh0`[je0=KGe@3Ef=T0e]WJ0=GJf`3I
d]80`XB70:/f>`2V9R/0Ea0@05iCBP2m_[<0e]SC0=GIfP3Ce=D0dm3?0<2j]P1e>cL0U@lB09X:3`2B
4140]h^80<kBdP3@e=L0d]GH0;JSY@1h4A40S0<508h51@280@800P250@404`250P@0OP8307/10P1h
0@80LP<404D10@1A1PP0D0@805l31`2R3A<0Z`/=0:T:3`2G2Q40SDiC0<C8d@32c]/0/;g:07R0QP1E
PcP00P00o`090?ooo`04003o003@D7P0X23`0:0Pl1h0oh0000<0X23`0=1@N03oP000203oP0000`3@
D7P0X23`0?n000030?n000030:0Pl03@D7P0oh0000<0oh0000@0d51h0?n0003oP000d51h4`3oP000
0`3@D7P0X23`0:0Pl0020:0Pl0030=1@N000o`000?l000P0oooo0P00o`008`2[U780SIjX06AnRP0g
F5d0E7=h05UeO@2<XJP0_L_B09FMX02?U9@0UYND09ZLU`2NWiT0XYjJ0:RPV02VWI80ZY^?0:fJS02`
W8/0[I^70;:NQP2eXHX0^:JA0;bXT`2mZYD0_Z^I0<2_WP34]J@0`[NU0<BjZP36_Zl0b<2c0<:k/@32
_;40a;jb0080aknf02L0aL6h0<?1^032`KT0_knh0;jn]`30_KH0_[Zb0;bc[P2eZjL0O7^804]KNP1C
EGd0ST1E0:PC6@2a2@d0[PL;0:`7302X10T0Y`D:0:L42@2X0`L0W0D906DdBP1hJ7P0R@`D09H2202D
0@/0R@D@08URK02[`mL0D6bI00@NG@025e/00A9A004>@`013Ch00@`e008B;P0mG3H02`00o`080?oo
o`800?l000<0d51h0:0Pl02P8?00602P8?001@2h>;@0X23`0:0Pl02P8?00^3Rd0140X23`00<0d51h
0?n0003oP0001`3oP0000`3@D7P0X23`0?n000030?n000030=1@N02P8?00X23`00L0X23`00<0d51h
003o0000o`002@00o`0;0?ooo`002P3oool0EP00o`00QWMQ0:2b`01YI6d0;0<402H10@0O00008`41
03020`0_0P80=08104D1101H0@H0K08507T21P1o0`L0Q@<808h41`2?0@H0S`@608h31`2<0`H0SP@6
08h21@2O1@L0[PP<0;062P2a1@L0]0L90;P<3@2j3Pd0^0h@08hB501aDTT0`[fc0=KDd`3Ef=X0eMWK
0=SJf`3Gb<T0_71d0:4];P1i6A/0BAPG07=/H`37a[h0emWF0=WKfP3Ff=T0emSJ0=KHfP3FeMH0[HN6
08dC5`2H2@h0V0d?09]ED03AdL`0cMCE0<oDe@2fYZL0MA4B08T31P2:0`@0R08308H10P240@40P081
07`10P1j0@80N04207P71`1I51@0W6m_06Hf=`1B0`D0V``?0:X;3P2V1``0VP/A09YNHP2g_LH0a=7O
0;6ob`1kPXX0EX@i0P00o`090?ooo`04003o003@D7P0X23`0:0Pl1d0oh0000<0^3Rd0=1@N03oP000
1`3oP0000`3XJ3`0^3Rd0=1@N0060?n000040=1@N03oP000oh000?n00080j6Pl00<0d51h0>QX?03@
D7P03@3oP0000`3@D7P0oh000?n000030?n000030=1@N02P8?00X23`0080X23`00<0d51h003o0000
o`00203oool2003o001=08NcGP2EY:`0BFMc059`M@0kDeL0QIfS0::f`02iall0WZN]08^ATP2FUiH0
ViVF09nMVP2QWYT0Y9fD0:>ISP2VUX`0Z9F:0:bIQ`2]W8L0/Ij60;>RRP2fYHd0]jN?0;ZYU02lZiH0
_:ZD0;j`W@2l/Yl0`kNS0<6jZ@35_k00aknd0<2l[`32_K80a[nf0<K0^`33`[T0`/2g0<31]P2o`KP0
_Kng0;Vj/`2j]k80^KJb0;6bZP2^[JT0/96F0:0a>P2a3Q@0]@T?0;<73P2]2Pd0X@hD09DW;`29=3h0
VQXP0:D52@2E51X0?c9G086<X`2392/0U`<;09@12`2:0`/0DRM502I5O`016Eh00AEI008IFP0<8eD0
93QG02i1G00:6cT0324f03<g>009i@<02P00o`080?ooo`800?l000<0d51h0:0Pl02P8?00;02P8?00
0`2h>;@0j6Pl0?n000040?n000030>QX?03@D7P0oh000080oh000P2P8?001@3XJ3`0oh000?n0003o
P000d51h00X0X23`00<0@>00003o0000o`002000o`0;0?ooo`002P3oool0@`00o`00Sh=_0;o@h01R
G6H0<0<502h20`0U0P80804102h20P0b0P<0<`4104L2101O0`H0K@@707H32@1l0PT0PP<908h32@2A
10T0T0D708/21@2:0`H0S@<709411P2L10L0X0L90:l8302b1PP0/`T:0;D<302f3Ph0Y1<C074n>`38
`kh0eMKF0=GGf03Hf=`0el_=0;n?TP2VBT`0Ma`N04@T7`1XI5d0[ZnV0=GFdP3Ifm`0e][K0=OJg03E
fMT0dmSJ0=;IfP3Af=T0^ZVY08HG6@2I2Pl0V@X>08PL6P35[JX0c];C0<oBe@32/[@0MaPH08X41`2:
0`H0Q`8208D10P220@800P1m0@<04@1j0@<0M@4207420@21;b/0JSHg070a=01_1P/0V`P>09h6302Q
20h0W@/A09E;D034`ld0`/oJ0;S8dP1iPhX0F8Dl00800?l02@3oool01000o`00d51h0:0Pl02P8?0L
0?n00080j6Pl1`3oP000103XJ3`0X23`0;Ph]03XJ3`70?n000030;Ph]03oP000oh000080oh0000@0
j6Pl0=1@N03XJ3`0d51h303oP0000`3XJ3`0d51h0?n000050?n000@0X23`00<0d51h003o0000o`00
203oool2003o001=07:Z?`2EWZ40EG1k03aHG01WPXP0N96M06f6T02eaLd0Yjnf08^@T@2=T8l0UiJ@
09fKU@2OWIT0X9V@0::FS@2UU8`0Z9N<0:bIRP2_VhT0/in:0;6NR02aX8P0/j:<0;FTS`2gYY40]JF>
0;JWTP2aXHh0]ZVF0;J]W@2o^Z/0a;fc0;jj[`30_K40`[nd0<C1^`33`kd0`L2i0<32^`2m`;T0_Kni
0;Vk]02j^K<0^;Na0;Bc[02iVYH0YRhc0;<<4`2e2Ph0/`T>0:@C5`2>>TP0E41W02TgIP1@@F80U1hX
0:842P2O=Cl0B4QY07JG[`25EEh0TPL>09<12@2410l0?Aa5008EF`0165T04RmR05YkX01PPY`0Pif[
04EMM00O=DT0CV=U02lh?@0Ab`P02P00o`080?ooo`800?l000<0oh000:0Pl02P8?00:`2P8?000`2h
>;@0oh000?n000030?n000040=1@N02h>;@0X23`0:0Pl0<0oh000P2P8?001@3@D7P0oh000?n0003o
P000^3Rd00X0X23`00<0J:Pl003o0000o`002000o`0;0?ooo`002P3oool01P00o`00Vhml0<?Bg`1H
CeH0:08302h20`808P4104h0:`4202h10@0o0P<0C`8505h21@1Y0`H0K`4507`320250`H0S`@808`2
1@290P@0R@8508d31`2>0@L0TP<609d5202O10L0[0H:0;062@2e2`h0]Ph?0:XB4@1e81`0^k:/0=CF
eP3GemT0fMOJ0=>n`@2NEe/0MB@W04DJ601WI5d0_Kng0=KFd03Ig=T0f]gP0=OKg03Gfmd0eM[L0=CI
f03Ef=/0eMWK0=CHfP2VP8<0T1<E09X93P2K2Ph0U@/<09aFE03Aa/D0cm;B0<W0`@1i9RD0R@<308X2
0`270@<0P`4208<20`210PD0O04307T20P1g0P80M04107@72@228240OQLF0884202K20d0V@D<09T4
302N2A00OA@J0;Z^]`2oc=T0[[o;08:;U01EQ3h2003o00T0oooo00@00?l00=1@N02P8?00^3Rd703o
P0001@2h>;@0oh000?n0003oP000j6Pl0080oh0000<0j6Pl0;Ph]02h>;@02P3oP0000`2h>;@0oh00
0?n000020?n000040>QX?03oP000j6Pl0=1@N1@0oh00102P8?000`3@D7P00?l0003o00080?ooo`80
0?l004d0DKlZ0:>YZ`1MMh80Gg^205IdNP1iTid0T:N`0<GBf`2]][d0NX2207]nN`2DTHd0W9JA0::K
UP2PUhl0X9F;0:2AQ`2WUX/0ZYR80:ZIQ02/VX<0[9b30:nMQ@2bX8T0/In60:fLP`2]W840ZiZ10:bM
Q@2/WhP0[ZFA0:nWU`2k/jL0`;^`0<2m]02h^;80[:n]0<73`@2l_[X0/KJb0;bo^02m_[/0^kfk0;Vi
^02f][80^jfZ0:E0A02e3Q<0]`/>0:d;402M<3/0FDIZ024lL01FHHH0Ree^09<I902T1@d0Y`@:0:46
3P2@;CH0YjB_08F2T`225Ad0TP8;06H98`0A4U<00a]N04ATS`2M]l`0VZo107fFYP0jE6l022=203eH
H`1BI5h0?DQ;01;?3@0:003o00P0oooo0P00o`000`20`000X23`0:0Pl00[0:0Pl0@0oh0000D0j6Pl
0;Ph]02P8?00X23`0;Ph]0040?n000030>QX?02P8?00X23`0080oh0000<0j6Pl0:0Pl02P8?002@2P
8?000`1@T7P00?l0003o0008003o00/0oooo000:0?ooo`1F003o002OTX00[:jk03LL8P0T0@40:082
01l1000U0@40:`8103410@170`D0C`4305/1101Y0@@0M@<607`21`240PL0R`D:08X31`270P@0R0<4
08/3102>0`H0T`@809/41`2[1@T0/0L90;072P2d2Pd0/`lA09`T8@23Fe@0emCB0=CGeP3Ff=P0eLS<
095HG@1:61L09APD08:5OP3;c/L0fmcJ0=[Mg03GgM`0f=gM0=WJg@3Hf]`0emWL0=GIf@3Df=T0e]WK
0<k;cP28@4H0V0lC09d;3`2L30h0V0T:08TO7`2bSHd0d];A0=7>cP1g>cX0PPD708X20`2:0`D0P@05
07d00`1n0@@0N`4307X10`1i0@<0MP4307D10P1b0PD0KP4407d21P2G1`X0UP<:09H3302I1`l0Q14G
0<B_]`31bmL0`<gJ08B<UP1HR482003o00T0oooo00@00?l00=1@N02P8?00d51h6`3oP0000`3@D7P0
oh000?n000020?n000050=1@N03oP000X23`0:0Pl03@D7P02P3oP0020=1@N0D0oh0000@0X23`0?n0
003oP000d51h4`3oP0001@3@D7P0X23`0:0Pl02P8?00d51h00800?l0203oool2003o000h05>o:02L
Wil0QYbZ055^M`1OO8D0LHbE0:>d_P35d=/0]kk707=gO026R8P0UI:@09fFT`2LUi00V9B<09fCR`2Q
T8H0Y9640:NEQ@2YV8@0ZYR40:ZIP02[VX00ZiMm0:nLP@2/W7l0ZiYm0:^KP@2ZVh40[9b30:^QS02Z
XHl0[jRG0;B^XP2o_;<0W9nJ09fSX02e^;P0X:>P0;2d[`2FWY`0^;fi0;bl^02h^;@0][>_0;AlO`2]
5A/0]``A0:d?502>@540<3a^04=GQ02=JWX0URlf0:4<4P2V0`X20:@32@0C0:H42@2C1Ph0L5Q]06Uo
U026CE@0Q@PB03D>?@046Ul0FX2Y0;39fP2ca]D0NY>Z04maU`099Dh0=UAX06AmP@1FIUl0?T]:022n
6`0:003o00P0oooo0P00o`000`20`000X23`0:0Pl00Z0:0Pl0050>QX?03oP000oh000?n0003XJ3`0
0P2P8?000`2h>;@0j6Pl0?n000050?n00080X23`00<0d51h0?n0002h>;@02`2P8?000`1@T7P00?l0
003o0008003o00/0oooo000:0?ooo`0Y003o002RR7H0Gcm703L72P0U0@808`8101h10@0U0@40;P82
03X20P190P<0E@8506<31`1[0`L0L`8807/22@1n0@P0P`<808@21P250`@0Q`4308d31P2>0@H0T@88
09X41`2[1`X0[`L90:h82@2d2`d0ZATF0:iVG02fZ:80eMGG0=CGf037`/<0QFIY03hP801RH5L0ZZfT
0<k?bP3Jg=T00P3Ig=d0:`3HgMh0f]gO0=7Ef02e`<<0YJn_0=GHf@3Ef=/0d];D0:^<S`266Qd0V`dA
09l;4@2L2a00V0T<08/<3P2<>c/0a:n^0=;DeP1cEUP0K`d@08L51`280P@0P@4207`00P1m0@@0N`43
07T10P1h0@<0M@4207D10`1b0@D0L@4307d21P2G1@T0V0D<09@42`2G1`h0Q10E0;2HW@31bmD0]<7?
08N?V@1MRTL00P00o`090?ooo`03003o003@D7P0d51h01`0oh0000T0^3Rd0?n0003oP000d51h0;Ph
]03XJ3`0^3Rd0:0Pl03XJ3`01@3oP0000`3XJ3`0d51h0:0Pl0030?n000030=1@N03oP000oh0000D0
oh0000<0j6Pl0?n0003@D7P04`3oP0040:0Pl0030;Ph]000o`000?l000P0oooo0P00o`00C@0XgQ80
UYF@08BLZ01LNX<0HWn709bb^`30d=/0_/[E096KXP1jOX80SHf<09:@SP2ITi80VI>@08b7P02MTHP0
WXb40:6?P@2VU8@0YiAo0:BBN`2XTg`0ZIIl0:^HOP2[VGh0YY=h0:RDMP2ZV7h0ZIb40:RNR02]XY40
ZYj>0:^SU@2PWI00/;2W0;Ff[@2^/jX0_[nj0:FWY@2m`;`0VJ2M0;Rl]`2i^;D0]KBa0;Zb[`2XC500
^0lD0:l@502BAUP0=T5a06aHN`2J=d@0X`lE0:T6302Y1@/0Y@@90:H42P2V0`X0Z0D;09<>5@18?Eh0
Ih^Y07]lT01/7C807Q1902PSE@1aSjT0/LWG0;C9f`1YQZT02baJ05IiS`25WJ<0KX2105EUG`0eAdL0
;Zl/00X00?l0203oool2003o00030830002P8?00X23`01L0X23`00<0d51h0:0Pl02P8?00402P8?03
0?n000040>QX?02P8?00^3Rd0>QX?0P0oh000`2P8?000`3oP000X23`0:0Pl00:0:0Pl003052@N000
o`000?l000P00?l02`3oool000X0oooo02L00?l0071?:01E3Ph0=`8201l10@0N0@407@8102L10P0d
0P80>`8204P10`1H0P<0H0850601101W0@H0KP8607@21P1m0PH0P@@708@31`280`D0S`<809<3202B
0PP0VP<70:X82`2a1`/0/@P<0:l92`2X=Rh0]iN=0=?@c@3Be]P0Xjf_02hi>00k?SL0VifF0<o@cP3G
f]/00P3Hfm`0;@3Hg=`0f]cM0=cGf@33Zk40GeII04aKF02e_KP0em[K0<g6a`2IKFh0R2DV09L=402K
2@d0WPX@09T83@2E20X0T@P;08X<3`2BBDX0clO909VDT`0j20H0M`L808H20`1o0@<0O00207h20`20
0P@0N`8307<10P1e0@80M@8307<10`1d0@<0O@8509D42`2E10`0T@@;09<93@2H:2/0[8bB0<;:e02k
b=L0QXnH05j<BP02003o00T0oooo00<00?l00?n0003oP0006`3oP000103@D7P0j6Pl0?n0002h>;@3
0:0Pl0030>QX?03oP000oh0000@0oh0000L0j6Pl0:0Pl02P8?00^3Rd0?n0003XJ3`0d51h00P0oh00
0P3XJ3`00`2P8?00oh000?n0000A0?n000030>QX?02P8?00X23`0080X23`0P00o`080?ooo`800?l0
04d07^@:09VCQP2G[[`0GGb509:X[`2a`<d0ZKW707b6TP1jP8@0Q8R;08Z:R`2AT8`0Ui6>09ZBSP2A
Rh40VI2709^;P`2QSX80Y9:20:F@O02XU7/0ZiAl0:ZEO`2TTGL0Z9Ei0:VIOP2VTWD0Yi=h0:VIPP2[
WhX0ZZ2?0:JOS025QGX0QHZ206ahM02e^k80`l>m0<;2^P2`/[00YZ^Y0;2d/02j^KL0^[Zg0;Ng]02k
];00ZD]@0;P@4`2i=CL0SeU/09<iC@2U4a/0[`P>0:d72`2[1@X0Z0H=09/<3P2Y:bX0XPL=0:D52P2=
;Sh0;TA`08VZ_P2M]lL0OFR201`ABP1?5cX0J72=08f/b`0jFXX03c1Q04eZP`1`RI40IWUm061bL019
GEd06Rlk04:7@P0:003o00P0oooo0P00o`000`20`000^3Rd0:0Pl00Z0:0Pl0<0oh0000<0d51h0>QX
?03oP000203oP0000`3XJ3`0X23`0:0Pl0030:0Pl0030;Ph]02P8?00X23`00T0X23`2P00o`0;0?oo
o`002P3oool0EP00o`00FBX704l4100e0@807@4201h10P0L0040:P4203420P0i0@80B08404`11@1G
0@H0H08606D11`1Y0PL0L08407/11@210@H0Q@<608P3102;0@D0T0<808h220270`L0Y@P;0:l82@2b
2P/0[`/;0:I1>02jXi`0e]GD0<g@d@1XLfd0PhZ00;k1^03Fe]@0e]SI0=OJg03Gf]d0f=cM0=K<cP3:
XZH0Xf9X05<W:@20OGL0b<g80=SKfP3Ca/T0[5UL0:@N802L4140W@`A09l;3`2P20d0WPT>09T83P2B
10X0SPD:08@=3@2RLG40a/;204Xk>P1C20X0P@<508@21P220@@0P08408421P1m0PD0LP4207D2101f
0PD0M04607D11`1i0@L0U0D=09L4302C10X0TPH<08T?5@2UNGh0/k[50;_9e@26SYL0I89>0P00o`09
0?ooo`03003o003oP000oh0001/0oh0000<0X23`0?n0003XJ3`00P2P8?000`3@D7P0oh000?n00006
0?n000030>QX?02P8?00d51h0080oh0000<0j6Pl0?n0003oP000203oP0000`3XJ3`0d51h0:0Pl00C
0?n000<0X23`00<0^3Rd003o0000o`00203oool3003o001<09b=O02DZ;P0QIjX0;C5d02KYkL0KUeY
07=QI`1nOh<0PXN808Z:R@2AT8`0THn909>@R02ET8L0V8j409^:P@2MRX00XHan0:F;NP2WTW`0Yi=j
0:JBM@2ST700YI1^0::@L@2WTW80ZYAb0:NFNP2VVWl0ZIf40:JNR01XK6@0JWMc05QXI@2^]J`0`/:i
0<?1_032`[d0`/:n0;no_02k^kL0^KZe0;Jh]02f][40]gio0;0F6@2g4QD0[a8I0;0:402b2@d0/`T>
0:X8302K3A<0RRll07A8EP2E?TD0X0P?09PL8`1>?6D0?6BC05EoW@1cUZX0];o>03LdGP0L4dP04R1I
00d]H`1<Ji80OIjh07VEY`23VZ@0N8fH04eXM`0?9T<00A8a03=L@0X00?l0203oool3003o00030=1@
N02P8?00X23`0080X23`00<0^3Rd0:0Pl02P8?003@2P8?001P2h>;@0j6Pl0>QX?03@D7P0j6Pl0?n0
0140X23`00<0j6Pl0?n0003oP0001P3oP0000`3XJ3`0^3Rd0?n000020?n000030;Ph]02P8?00X23`
00l0X23`2P00o`0;0?ooo`002P3oool0EP00o`00FaH404T2100a0@408@0102820P0P0@40:04202/1
0@0i0P80@@4204400@1A0@H0G@8706<1201W0@@0KP4507/21`200@D0Q`8708T30`290@80S`8508l3
20220PH0X@X<0:l;2@2`20X0/0T;0:H`:P2iUI00e]CD0<W>cP2c]Jl0d]C>0=?Ge03DemP0e]SJ0=KJ
g@3FfM`0e/S=0;=[LP2B<SP0CA<B079/IP3Ad/h0f=WH0=[@d`2fKFl0/a`M0;DB502R3100W@`@09l9
3P2Q20h0X0T>09X63P2G1`d0U0P;08`51`268BD0cK>d09RET`0f3@h0N@H;08<21@240P<0Q0850883
1`1m0@D0O08607X11@1f0@D0N04707T1201k0@H0TP@;09D32`2@0PP0T0D:08T7302DGEl0a/_B0;W5
d@28T9X0MeaD0P00o`090?ooo`03003o003oP000oh0001/0oh0000@0X23`0?n0003@D7P0X23`2P3o
P0000`2P8?00d51h0?n0000>0?n000030=1@N02P8?00oh000140oh0000D0d51h0:0Pl02P8?00X23`
0=1@N002003o00P0oooo0`00o`009`2UTgT0YkO40:ZnbP2N[k`0IT]G06`B6@1h=3L0P7j00865Q`2:
Rh/0Shj<096?R`2BSXP0TXb409N;Q@2JQh00WXQo0:2;O@2QRgT0Z95m0:><M02SRg00YY5c0::@LP2S
Sg40XY5_0:JDL`2VV7l0Yif70:BKQ@2SW8H0SXin07Z0M`2<T8D0ZZ^P0<30^P35`[h0`L6o0<6o_@02
0;bl]`0S0;Zj]`2g^K<0]KJ`0;RATP2[6Qh0^0/>0;H:302e2@h0/PX@0:DB5@2>=400ET9P04Y1I@1l
<D<0T`XB09<R:@1F@fD08D=e09F_`P2D[/40VKG70<;Bg02QUZP0FAdl04@O@P2B[L<0[lOF07NBYP1i
TZ@0LHRI01<ZC`0254D00Q0n004?=P0W<D802P00o`080?ooo`<00?l000L0d51h0:0Pl02P8?00X23`
0;Ph]03oP000j6Pl00h0X23`00H0j6Pl0=1@N02h>;@0^3Rd0=1@N03XJ3`A0:0Pl0030=1@N03oP000
oh0000@0oh0000L0j6Pl0;Ph]02P8?00j6Pl0?n0003XJ3`0^3Rd00H0X23`0P2h>;@:0:0Pl0X00?l0
2`3oool000X0oooo05H00?l004dF0`120`<0<@4102810@0N0@407`4102H20P0W0@40@08304`20`1?
0`@0DP8405P1101O0@H0J04506l20`1j0P@0OP4408D21@270@<0S@8509<2202E0`T0V0D:0:<82`2/
2@/0/0X;0;092P2T61@0ZfiW0<2k^03@eMD0d]GE0=CHeP3EfMT0eMWK0=OGf@3JdmH0cJZ_0;=BF@2:
7b00B1LD07=ZHP39bl<0fm[I0=[5b@32Mg/0]R8U0;lB502f41<0Y@d@09h<402O2Pl0X@T=09l8302N
20h0U`L<09@8302B1P/0SPX?09]BE@3D`<40Gcdn06d520220`L0P@8408<310241@L0N`4407T11@1g
0@<0MP8407H11@1h00@0O@4509H6302D0`T0S@<908`32P281@/0QTQ<0:na]`2ob]D0RY:M07=ID@80
0?l02@3oool00`00o`00oh000?n0000L0?n000030;Ph]03XJ3`0oh0000T0oh0000<0^3Rd0>QX?03o
P0004@3oP0000`3@D7P0oh000?n0000?0?n000050=1@N02P8?00X23`0:0Pl03@D7P00P00o`080?oo
o`<00?l004d0TZ1W0:Ria@2X]/L0KV=]05d]<01m?d@0JbX_089jO01mP840QXZ;08n?S@2BT8`0Thj9
0969PP2GRhL0VXJ209n7P02RRgh0X8ai0:F@NP2OSG<0YI1d0:6<L02QS6h0Xi=d0:6BL`2STgD0YIZ4
0:6LQ`2SVhH0X9^709nKR@2OWHd0XZ2C0:VYW`2j^kD0`/6n0<;2_`2n_K/0_kjk0;Vj]`2i^kP0/kNb
0;:f/@2fUYH0YQLL0;L;3@2e2Ph0Y@lE09@d@01IAF/08Sec069?L0296b/0T0dE07l_?@0g>6@0:4]i
09:Y_@23UjT0MXbR08>R^02odMl0`lgH09IcP01V72l0OHVM0:Nod01@KHl073QW05]hS`0;8DL00A54
008A?00B9cl09cY700gL2`09003o00P0oooo0`00o`00103@D7P0X23`0:0Pl02P8?020=1@N0030?n0
002P8?00X23`00d0X23`00<0^3Rd0=1@N02P8?004`2P8?000`3@D7P0oh000?n000020?n000070>QX
?02h>;@0X23`0;Ph]03XJ3`0oh000>QX?0080:0Pl0030;Ph]03XJ3`0X23`00T0X23`00<0D91h003o
0000o`001`00o`0;0?ooo`002P3oool08P00o`00C1X303X20P0^0@807P4102020P0M0@409@4202l1
0P180@D0D@8404`20`1=0@80E`4306410`1Z0@H0K`8507P10`1m0080Q04208/2102A10L0U`H809D3
2@2J10T0X`P90:d;2`2]2@X0[`X:0:8H502mPGT0a[fi0=CFe`3Df=T20=SIg00S0=SBeP36Uih0]E=H
0;HX:`2l;b`0[7M`0;Vg[P3DeM80g=7C0<N:S`2c>Cl0`1`Q0<@D5P2i4aD0Za@G098A5@2241<0NPdB
07/=4@223Q40S0hB094;3P2B2P`0U@P<09T83@2:2a80Sc]00:agM`1^2P`0P0<607h10`210PH0OP44
07`21P1i0@<00P1f0@803@1i0@@0O04707l11`2E10`0UP@<08h22P2;0PT0R0D:07hh>`2e/;D0^lKA
08N?V@1dGED00P00o`090?ooo`03003o003oP000oh0001`0oh0000<0d51h0?n0003oP0001`3oP000
0`3XJ3`0d51h0>QX?00U0?n000050=1@N02P8?00X23`0:0Pl03@D7P00P00o`080?ooo`<00?l004d0
PJmI0:Rb_P23N8H0H1TL06Y0@@1`GF<0HBH]07e`LP1iOX00QHN708f>RP2@T8d0Ti6>09F>RP2GSXL0
VXf409b:PP2QSX<0Wh]h0:>:M@2NQV/0WhY[0:2<J`2OS6X0XY5`0:FFNP2UUWd0YY^60::JQ`2NV8@0
X9Z709jJR02MWH`0WYjA0:FWW@2j_;@0_knk0<;1_@2n_k`0^[jl0;Rm_@2e^[X0/kRh0;2f/`2lYZL0
XAlU0:hB5P2M=3d0JdeW02m4L@13I8`0QYFU08YDF`278B`0GCUF01X_H011HX<0Q9VN0:Nc^02S]l<0
RZRl07FJ[`2ldn40_]3N0<37d`21HW00GEib0:BmcP1;IHT00QQB055]RP0L=e403BA6039<F`1;HEh0
>Ta>01W96009003o00P0oooo0`00o`001`3@D7P0X23`0:0Pl03oP000d51h0:0Pl03oP0003@2P8?00
1@3@D7P0oh000>QX?03oP000d51h01<0X23`00D0^3Rd0?n0003oP000j6Pl0;Ph]0030:0Pl0030=1@
N03XJ3`0^3Rd00X0X23`00<0^3Rd0:0Pl02P8?00202P8?000`1@T7P00?l0003o0007003o00/0oooo
000:0?ooo`0F003o001;5`<0=04202P10@0K0P407P4101h0000V0@40>`4404D1101:0@@0A`8304/1
0`1H0@40GP0206D20`1]0@<0O@8508<11@260P<0S04609011`80U`D800<0V@D80:D92P2]2P/00P2^
2P/0:P2P5aD0_HAn0<c4a03Ee]X0eMSK0=SHg03Jcm<0_8B:0:hZ;P2m5aL0`aDF0<19AP3Aa;d0fmcI
0=cEeP37Q8`0^2D/0<0F6P2n5aT0Z1TJ07`F6@1?2`d0;@@701P41@0B10D04`<201d30`0c10L0F`hB
07X>4P2@2Q00VPP>09H93`2=2a80TS<e084J6P2110L0O`4408421@1h0@80M`4207H10P80M00200d0
N@4607`2201l0@L0U0D;09H22@2?0@L0SP8808P32@1i:2`0[:6V0;o9e@1nQi40L5mH00800?l02@3o
ool00`00o`00oh000?n0000L0?n000030=1@N03oP000oh000300oh000`2P8?000`3@D7P00?l0003o
00080?ooo`<00?l004d0I<=008>4Q`1M<SL0M2LY060Q9P1`EE`0HRH]07]YK01dN7X0Q8B508f;RP2B
Shd0Thj=096<R02FRhH0WXj709n<Q@2OS840Whej0:2;M02MQFT0XHQZ0:6<K@2NS6/0Xi1c0:6CM`2U
VXH0XIR40:bUUP2MUXH0WiR509bJQP2RXiH0WinD0:FVVP30`;T0`L2n0;no_P2l`;h0_<710;O0_P2e
_[X0]Kjk0;6i]`2m/[@0V4a@07eAH`1QEgD0NTML09V1RP2FX:@0V9nN09><S01FF6h0:4E_06EkRP26
Ti00VJ:R09BHWP2GVjD0O8FE09VQ[`30cMX0`=3L0;g?g02ga=00IgN708NU]P1;IX003RME03MEK@1C
KG00DfY]059ZJ01=I5d0<dI;02RY:@09003o00P0oooo0`00o`001`30X000X23`0=1@N03oP000j6Pl
0:0Pl03oP0003@2P8?020?n00080j6Pl00<0^3Rd0:0Pl02P8?004P2P8?001@3@D7P0^3Rd0:0Pl03@
D7P0^3Rd01X0X23`00<0D91h003o0000o`001`00o`0;0?ooo`002P3oool0EP00o`00CaP303820P0U
0P40704101d10P0R0@00<P83040210140P80AP4204P10P1?0@80F04205d2101T0@D0L04607l11`24
0@L0R0<408/21`2C0P/0UPD:09T72P2K1PT0YPT;0:h:302a2P`0/P/>0:<J6@2nQh@0cLK60=GGfP3G
d]L0d;Fl0;M]L`2b9bT0`QLH0<TF5P375AD0_TY90=O4``3L`L@0`gMm0;HY;P2_6Ad0S1@F060?4@0_
2P/0:b8N03/n>@19DD`0H6MS06]`K01YK6H0DUI?03a0>P0M61@080H605<;3`2;3A40T0L:09462P2:
2@h0Sa@H08<31P220`H0O`4507L10P1e0@80L@8107820`1c0@<0M04407D11P1j0@H0U0H;09T42P2?
0PT0S0<808<22@1d82D0]JNY0:jh`029TI/0JeiL0P00o`090?ooo`03003o003oP000oh0001`0oh00
00@0d51h0?n0003oP000d51h1P3oP0000`3XJ3`0oh000?n000040?n000030>QX?03@D7P0X23`00H0
X23`00<0^3Rd0=1@N03oP0005P3oP0040:0Pl0800?l0203oool3003o001=04O38@1fIV80G3Pk06Tl
?@1T8240K2/c06PN8P1gJ6/0LGMj07mmP@2;QhL0RXR408^4P@2>PH00TGmm09Z7PP2KR7l0WHV10::>
P@2KQW40WXEY09b5J02MRfd0WHi^0::ENP2QUG`0Xi^60:BNS@2]Yi/0XIb=09bHQ02KVHH0XJ6E0:NU
V`2VZj80Xj^W0:nf]@2m`Kd0_/6n0;Zm_P2i_[d0]kjm0;Jl_02f^[X0]KJf0;^Z[P2CEf`0WR<b0:D>
5P1k@e@0MX^F09ZPW@2EVYL0Qi2A08N<S`2AQ8<0SVUY08i:D@2A=3d0U2D`094M9`2=7b`0T45?0:B4
TP2ma]00]lcH0:g2cP1oW:d0Pj2^07>;W01XOXL0HGAd05U^J`1BJF@0B61Q01lf@`0hWC/02@00o`08
0?ooo`<00?l000@0P<000:0Pl02h>;@0d51h0`3oP00=0:0Pl080j6Pl602P8?00103@D7P0oh000?n0
003@D7P60:0Pl080d51h00H0j6Pl0?n0003oP000oh000=1@N02h>;@<0:0Pl00307QH]000o`000?l0
00L00?l02`3oool000X0oooo05H00?l004dF0`0b0@807`4101T20@0N0@408`4103<20P150@@0@`42
04810P170@80D@4305P10`1Q0P80J04307@210200PH0QPL:08D31P2<0@H0T`8:09L42`2L1PX0X0L<
0:P93@2`2P`0/PX=0;@<3P2T71`0`Xj:0<o8b03A`/L0VVQ`06PP:@2H7Al0`AHE0<DD5@385AD0aa@E
0<Q2@`39L7<0[C<i09hM8@1Q3a00<1@C040n>01VK6H0W:6O0;c0^`37b/D0c=3;0<oBd03?e=80dMGB
0<_?bP33bL80/KB_07]oN@0l>SL0>@T:07l;402=1`X0S@@808P31`200@<0O`4407h31@1g0@80M042
07820@1a0P80LP4307820P1b0@@0N@460986302F10/0S@4808X320210@H0LQXN0:FAU02U[;<0PX^D
06QOG`800?l02@3oool00`00o`00oh000?n0000L0?n000030=1@N03XJ3`0j6Pl00/0oh000P3@D7P2
0:0Pl0@0d51h00L0j6Pl0?n0003@D7P0d51h0;Ph]02P8?00^3Rd01H0oh00102P8?02003o00P0oooo
0`00o`00C@0Vf@`0Mf5>05Pm>@1XCd`0ISPh05l=4@1j>S`0KUIK06eeM@20Oh80QX2008^3P@28Ogd0
QGYf08UgM@2AOgT0UhAm09^7O`2LRG/0VXI^09f8K`2OSW<0WI1e0:6BN@2QU7l0Y9f:0:ZTU@2XY9L0
/:ZP0:>RU02MW8`0XZ:D0:RXW@2/[:@0UYnG0;Rm^02DWYd0^;nk0;Vl^P2i_[/0]kbj0;Vm_@2h_;/0
/[Re0;Be/`2VJg80[1@M0;4:3`2[2100OC=:061iS`2IXZ40VIJF09QjO@2@A4/0RQTP09484@2G10`0
W@@;09h42`2N0`P0V@<;09<33@2921D0QSU:0;Je`@2hb]H0MX^K07:<U`20UId0K86305a_KP1IK6X0
BVAU01@W?P045380>G=600T00?l0203oool3003o00050830003@D7P0^3Rd0:0Pl03XJ3`00P3oP00V
0:0Pl0050=1@N03oP000oh000?n0003@D7P00`2P8?000`2h>;@0d51h0?n000080?n000030>QX?02P
8?00X23`00X0X23`2@00o`0;0?ooo`002P3oool0EP00o`00CQD203D30P0P0@40604101d10P0V0P40
<`4204/21@150@80A04204L10`1>0@<0H08506T21@1/0@@0LP8507@210293a<0NP<408/21`2D0`X0
V@D;09d62`2Q20/0Y`T<0;0=3`2b30h0/``?0:HJ703ASXl0]hjB06/h?@119bP0OFe/0;I/J`2n61T0
aQ@F0<DB5@344aD0^aTM08LH6`1<30l0>28P06mbK@2e^[D0a/g80=3Fd`3Gf]`0emWL0=GIg03Df=/0
cm?G0=7Ff@3@e]P0d]OG0=7Fe`3Ae=L0cm;D0;c0`01QHUh0@P/<07h:3P271PP0P`870801101m0@80
NP4307@00@1d0@80LP8306P20`1`0P@0L`4307@01@1j0PH0T0D;09D22`2>0@X0QP8808421`1f6Al0
[I:F092EW025SI@0JV=Q0P00o`090?ooo`03003o003oP000oh0001`0oh000P3XJ3`00`3@D7P0X23`
0?n000070?n000050=1@N02P8?00^3Rd0=1@N03XJ3`0103oP0000`3@D7P0oh000?n000030?n00003
0=1@N02P8?00X23`01D0oh00102P8?02003o00P0oooo1000o`00C01cGC00H3df06@l>`1XC4`0EbLX
0794B01/@D@0M7Ee07UjO@1nO7/0Q7el08ElN@1oMg80PGA^08]kMP2EPg`0UhAk09V6O02MRWT0VhQa
09f=M@2PT7/0XiJ30:JJQP2VWhh0[:NI0:bWW02/Z9h0[J^Q0:^YX@2/[Z<0];bc0<O?c@33cL`0[KJe
09:LV`2d^kT0]kbk0;Fm_@2d_K`0/[^h0;Jl^`2a][D0/[Fd0:]`MP2_3QH0/PTA0:L94`20=DT0C65k
0:69SP2I@TT0U0lI09P53P2E0P/0U`8:09T22@2L0P/0WP8:09d2202H0`T0TP8909<230290`d0P3E1
0;FjaP1QOXh0J8B?07::T01OMGP0G6m_05Y[K00R>4d00@dd004?=00X=dH9003o00P0oooo1000o`02
0>QX?0030=1@N02P8?00j6Pl0080d51h9@2P8?00203@D7P0oh000?n0003oP000d51h0:0Pl02h>;@0
j6Pl303oP0000`3XJ3`0X23`0:0Pl0090:0Pl0T00?l02`3oool000X0oooo05H00?l0050C0P0h0@40
904101`10P0K0040904003T10`1;0PD0@P4204H10P1;0P<0B@4205H10P1Y0PH0K08407421P1S0P80
I0D606H10P2;0PL0U@8809/5302J1@T0U`H90:882`2`3100/P`?0;D<4@2_5AP0b5MK06hT:@0a8Al0
Z:RS0=cGe@2jOgh0_1/L0<<C5P334QH0^aTK07L@500V30/0G5]I0:^^Z@3Ae<l0f]_J0=SLg@3Ef]d0
e=WL0=GJg@3Ef=/0e=SL0<oEf03Ae=P0d]KI0=?HfP3Ce]X0c]CG0<kCeP3;dM@0_l?004<_;P1S3a40
O`H:07l22@1l0@@0N00207L00P1e0@80M`8507<31@1K0P80H@8407821@1b0@H0N04708h32@2@0@T0
SP4=08L12@220@P0K0P:095_K`2:Si<0KgQl06iWI0800?l02@3oool00`00o`00oh000?n0000M0?n0
00030=1@N02P8?00oh0000H0oh0000@0d51h0:0Pl02P8?00d51h1`3oP0000`3@D7P0oh000?n00002
0?n000050=1@N03oP000X23`0:0Pl03@D7P0503oP0040:0Pl0800?l0203oool4003o001=05Y[4`1b
AT00H1/L06Hg>@1VCe80IdQ>06Xf>`1dKW00M7Ef07QgMP1nNg/0O7Mf07]dL@1nLVl0QG9_095jM@2G
PWX0VXQn09^9O@2QSgl0Whik0:FDQ02UUhT0Z9b=0:ROS`2ZYIL0ZjJL0:VVW@2[ZZ<0[JbT0:je[02k
a<00[;>`0;k:b@2c_l40Zk6_0;Bi]`2e]kL0/[Zi0;Bl_@2c^[`0/kZi0;6f]P2d][D0/hB;0:PC6`2Q
51X0RSa:061<J01iAUh0VQLS0:T8402T0`/0W08:09P22@2G0PP0V08809`22P2P0`X0W04:09L3202B
0PT0SP8:08X22@1m10d0PeAL082EX02=YZh0PIRL06V1PP1IKF`0DfAZ00HE>0013CD00Q4b01/^A@0;
fPX02000o`080?ooo`@00?l00`3oP000103XJ3`0X23`0=1@N03@D7PU0:0Pl0060=1@N03oP000oh00
0=1@N02P8?00^3Rd3`3oP0000`3@D7P0X23`0:0Pl0080:0Pl003052@N000o`000?l000H00?l02`3o
ool000X0oooo00T00?l0058C0P0n0P409P4101l20@0O0P808`8103010P170`D00P0n0@80:@1:0P<0
C`8305T21@1V0@@0J@420702101`3`l0Qbh^07L6202=0PL0U0<809D31`2G1@T0T`@80:4:3@2_3A40
/0/?0;<<4P2`4aL0YcDc0714?`2VYZ40e]OG0=[Hf@2fPGh0^1TJ0;hE6@2T5QX0I0h@04@c<02AUI00
blg;0=SJf03NhN00g=gO0=WMg`3Ffmh0e=[M0=GKgP3DfM/0e][L0080d]KI0200e=OJ0=CHf`3AemP0
d=OG0<oEe@3=d]D0c=7B09:?SP123`l0N@T<0803201m0@D0N`4407T1101j0P@0N04307D10`1^0`D0
H@4307@21P1d00L0N@4609042P2E0@P0T08:08T320230@L0K@T<09ilO@21Q8L0KGAh071XIP800?l0
2@3oool00`00o`00oh000?n0000L0?n000030>QX?02h>;@0oh0000H0oh0000<0d51h0:0Pl03@D7P0
403oP0000`3@D7P0X23`0:0Pl00D0?n000@0X23`0P00o`080?ooo`@00?l004d0AYDC0753?P1L5aH0
JB0T06<c=@1YADX0Ic0b071YK01^KVl0LFm_07]hN01oO7T0NGE`07a_K@23KF/0S7E`09J1N`2HQG/0
X8j00:BCQ02RTX<0XiF60:6DQ02UVXX0ZIjA0:RPUP2ZYI`0[:VP0:n_Y@2][J@0/KF_0;g4`P2c]k<0
`lg>0;O2a02a^;H0];Vh0;Jj^`2c^kX0/K^i0;2i^@2d^kX0[kFd0:jf]@2bVYd0TD99061>KP1BBg80
QS1509l<602V1@d0Z@H<0:D42`2N0`X0V`<909L2202C0`T0S`P@08lI8`25:CH0M2`g07LZ=@1j51l0
P`D<08@22`1d5Ql0MgJ106AkQ01]QHL0HW]k05]`KP13EV800Q0i00`P?P0jEEd0:d9<017B4`08003o
00P0oooo1000o`001`30X000oh000?n0003oP000d51h0;Ph]03@D7P09P2P8?00103XJ3`0^3Rd0:0P
l03XJ3`:0?n000<0d51h103oP00:0:0Pl003052@N000o`000?l000H00?l02`3oool000X0oooo05H0
0?l005@A0P0n0P809`4101l10@0N0P80704102L10@0h0P80=08203H10P1=0`D0DP4205d21P1R0@<0
J0830741101l1`T0P`/<08L31`2@0PL0T`<809@3202H10X0V`L;09H72P2L20/0[0`@0;<<402V6Ad0
ahj:0<K1_P3Gf]/0f=[N0=WIfP2fPX00ZAhM06DA400i8A/0MGE`0<C9aP3Hg=`0gn7Q0=kQi03Kh><0
fmoQ0=SLgP3Ffmd0eMWM0=CIg03Ef]d0eMWL0=3Ff03Af=X0eMOL0=;GfP3>e]P0d=KI0<oEe`3;d]@0
bm3C0<[<c@2;Lfh0LA8C08431`1n00D0OP4507`1101g0@D0N04407L11@1d0PH0L`4707/22@1i0@L0
N04408h32@2D0PP0S`<908P220270PP0KP@908]NH`22OX<0HfEZ079YJ0800?l02@3oool00`00o`00
oh000?n0000L0?n000030;Ph]03oP000oh0000@0oh0000<0d51h0:0Pl03@D7P02`3oP0020>QX?080
oh0000<0^3Rd0>QX?03oP0000P2P8?000`2h>;@0X23`0?n0000B0?n000@0X23`0P00o`080?ooo`@0
0?l004d0>Id:06m5?`1X?c`0GR<U06lZ<01R5a`0JSho061OH01UIVL0JVQZ07AbM@1jMgL0OgQe07]`
K01oKFP0RgMa09R4O@2JQW`0XHn10:>APP2PT800Whmo0:2FQ@2RVX/0YYjB0:ZQV02_ZZ40/:nV0:n_
YP2_/JP0[;6Z0;6h]@2naLL0^L730;2g]@2g^kT0Z[6c09RTYP2Y];40[[Vf0:ff]@2_^;L0[;Jc0:Vd
/@2^/[80X9jX06YCM02D8C<0YPTA0:T6302X10X0YP@:0:832`2K0``0T@L?08HQ;@1Z=D`0AS]O02/e
I00Q<V00A5Ik05UYR@1YKH@0MCQ80805401h1@l0K5MT086GX01dS8h0HW]j05]aK`0lEF001AXl03aI
G`1?IV40=TaA026V:008003o00P0oooo1000o`001`20`000oh000>QX?03oP000j6Pl0?n0003@D7P0
6@2P8?000`2h>;@0X23`0:0Pl00;0:0Pl0030;Ph]03XJ3`0oh0000H0oh0000<0j6Pl0=1@N02P8?00
1@2P8?00103XJ3`0oh000?n0002h>;@90:0Pl003052@N000o`000?l000H00?l02`3oool000X0oooo
04400?l005@<0@150P80<@4202@10@0L0@806`4102L10P0g0@80=@8202h10@130P<0F`<806021P1U
0P<0K08407<2101j0P@0O`4408P11P2>0PH0T`<809H42P2I1@X0V`H909h92P2M1`T0[Pd?0;D=4@2T
6a/0_hb90<g9b03Ff=`0fM[N0=SFfP2BN7X0@ATG07IeKP33bL80e=OE0=WMg`3Jg^40h^?W0=kQi03J
h>40g=oP0=SLgP3GgMh0e=WL0=GGf`3Bcm<0c/G;0<2a]`2iXZX0^9bW0;ZRZP35_<40dM?F0=3Ee`3:
d]@0bm7D0<[@dP32^[/0MRha08042@0207h11P0307/11@1^0P<0L@850080N08600h0NP4607X11`1l
0PP0N`8509042`2C0PT0SP8908L120230`P0K`@808QGF`23PH@0DEEJ06eVI@800?l02@3oool00`00
o`00oh000?n0000L0?n000090=1@N03oP000oh000?n0003@D7P0j6Pl0;Ph]03@D7P0j6Pl00/0oh00
1P3@D7P20?n000@0X23`00<0j6Pl0?n0003oP000403oP000103@D7P0X23`0:0Pl02P8?02003o00P0
oooo1000o`00C@0lWPP0MdY406Ho?`1U>S/0H0P:06H^;P1OE5H0FE]K069PHP1[J6L0LF]^07A^L01n
MW<0PWEc089`K02?N780UX=j09R5O02LS7h0WXmn09nCP02LSgl0W9:00:>JR`2WWI80ZjBL0:bYXP2a
[jP0[:fT0:^]Y@2[[jT0Yjf[0:fb/@2]/[00[;:`0;Bh^@2OYZP0VJJV09^XYP2^^;L0[;Jg0:jf^02^
];H0ZK6`0;2a/@2_O8D0XA/V0;094@2Z1@`0[0L>0:P42P2T1@h0UPXA08<Y=`1@=eX07BmU02Y1LP1G
E7H0ND]Q08DeAP29<Ch0QSY708IeOP2b];d0NRLd07d43`1@9CH0MXjE0768QP1OMW<0FW9`049LI00P
>Th0DFMW04mUI@0N=TP03VXV00P00?l0203oool4003o00060830003XJ3`0d51h0=1@N03oP000j6Pl
9`2P8?000`2h>;@0oh000?n000050?n000030>QX?02h>;@0X23`0080X23`103@D7P01@2h>;@0X23`
0>QX?03oP000d51h00X0X23`2000o`0;0?ooo`002P3oool0F000o`00E@X104T20P0i0@40:`4101l1
0@0K0@40:04103X20P0`0@807`4002/10P1;0@D0G`4306H10@1^0P<0L04107H10P1m0P<0Q@4208`2
1@2@10L0U`D;09P3202M1@X0X@L:0:T9302`2`d0/``?0:@N7036U8h0c/_90=SGg03BaL/0RGEl02HU
9@1iPWX0blo<0=cOh03Jg^40g>3R0=oQi@3PhnL0gN;T0=cQh@3Kgn00f=[O0=gKgP3Fa<`0^hfI09]L
IP27?4@0OBPc07TR;@1j6BD0PQ/W088b>P2dUYX0dM3D0<_Ae@39dM<0bm3B0<o;cP20A4P0P0D;0881
202100D0OP4307X2101h0PD0N@4507L11@1j0PH0N`4707l42P200PP0T`<;09<11`2>0`T0QP460801
1@1]0`L0Q55B07QfM`1EEe/0If1O01n=2000o`090?ooo`03003o003oP000oh0001`0oh0000<0d51h
0?n0003@D7P00`2P8?000`3@D7P0oh000?n000090?n000030:0Pl03oP000oh0000D0oh0000<0X23`
0?n0002P8?000P2P8?000`3oP000d51h0?n0000B0?n000<0X23`00<0oh00003o003oool01`3oool4
003o001=03^^1`1lCd<0IS4`06H_;`1K<C40G51C051@E01EEeP0GemQ06IVJ01`Jfd0MFi^07]fL@26
NWP0QW9a095iMP2DPG/0UHAm09N:N`2PT840XIB409fAOP2QUX<0YYb<0:VQU@2[Yid0[:ZR0;:bZ@2Y
ZZ<0ZJVS0:VYY02/[j`0Zk2[0:fa[`2[];40/kRg0;6g]`2R[:d0Z;>c0:Ze]02X/[<0ZKBd0:Zc]@2]
[K40[gZ20:LJ902b2Q40[PH>0:X43`2[1Pd0X0L=08dS;@1N@6006RiV02]9M@1SKH<0Q4aH08dC7P2F
1@l0V@8=09L43@2082l0Be=d09^jc`1oCEl0N`DA04hQ<`1IMh00IWil065fM@1MLG40E6]^024lC017
H6T083A<008C>`049C402000o`080?ooo`@00?l000D0P<000>QX?03oP000oh000=1@N00W0:0Pl003
0;Ph]03oP000oh0000@0oh0000<0j6Pl0;Ph]02P8?000P2P8?000`3@D7P0oh000?n000020?n00006
0>QX?02P8?00X23`0=1@N03oP000d51h2P2P8?08003o00/0oooo000:0?ooo`1H01K]1P1N6@h0BP<2
04420P0_0P80804101X10@0W0@40?P8403T82P1I8bP0=@D603h21@1P0P@0J@4306l2101b0@<0M`43
07l110260@<0S08509<42@2E0`P0V@D909d72@2S20`0[@X?0;8;402e3A40XahN0<:CT03?bLT0bK6g
075;DP0a92<0MGag0<_Ac`3Oh^@0f]kQ0=_Ph`3Qh^H0g]oS0=cPh`3NhN@0hn?V0>3Af03BZ[@0`GR1
0:Q1B`268BP0IQDI04X?4`0a3A<0;@P;05d?4@284aH0TA0D08XU:P2WO800b<O:0<[Be03;d]@0c]3B
08=@D`201``0P`<708811@200PH0P@480802201l0@D0NP4607X1101o0PP0P@D;07l32@2B1``0U0<8
09432P2:0PP0O`4406`31@1nBT/0Q7n104Y<CP1QEeH07hd7003o00T0oooo00<0@>000?n0003oP000
703oP0000`3@D7P0j6Pl0=1@N0020:0Pl0030=1@N03oP000oh0000d0oh0000<0d51h0>QX?03oP000
0`3oP000103@D7P0^3Rd0:0Pl02P8?020=1@N1<0oh000`2P8?000`3oP0000?l00?ooo`070?ooo`@0
0?l004d09=@7081EAP1M61L0I2DU05a>D@1CCe@0D4eA05ACE@1IFUd0HV9U06eYJ@1dL6l0OGMc08=f
MP26LW40SWQd095nN02CQG`0VHYo09n>P02RU8@0YIV80:BJQ`2XXY00[JFH0:VUV`2^ZZ<0/JnX09nQ
V@2GV8l0U9J?0:BVX@2Z[:L0[k>`0:jg]@2a][P0]KVj0;2f^P2[][L0ZKBd0:^b]P2/];L0[;2c0:mo
Q`2U72H0/P/A0;<9402^1P`0Z`P=09`@5`1n?540:cMZ02E9O01UOY80Og^307l`?02C2180W0<809`2
1`2I0PX0Ra4K044eF@17MIh0//SK07Y2D@1g1@l0A2Ho06F3TP1`QXH0HGEd05mcLP1HKVh07cM<00PK
A0013c`00@hi00HI=`08003o00P0oooo1000o`001020`000d51h0?n0003XJ3`W0:0Pl0030;Ph]03o
P000oh0000@0oh0000<0d51h0:0Pl02P8?000P2P8?000`3XJ3`0oh000?n000030?n000<0X23`00<0
d51h0?n0002h>;@02P2P8?08003o00/0oooo000:0?ooo`1H02[I2P1Z;ah0@@@203l30P0]0@808@82
01`10@0Z0@80>P<302`10P150`@0@@<402`10P1K0PH0I@4406L10P1^0@40N04307h20P250@80R`84
0943202H1@T0UP@809d62@2T20`0[@T>0;<;3`2g30l0ZA/M0=^EUP2oPHL0Kb/_06MIF034al@0g^7Q
0=oSi@3Lh^@0f]oR0=_OhP3Oh>@0fmgP0=kLh03Qc=<0cXJA0;XmBP2V8b`0Na@J03/:3@0]9B40A4U3
05eVH01mQX40Ti>=0:ZCS02ZKF/0T1TL08l;401l8B<0[i^K0<cCe@3:dm@0c/oA07a3A`221`X0QPD6
08D4202310P0P08807h2201j0@H0N@8507X21P1n0PH0N@D906d2102B3Q80U`@;09H32P2<0PL0P@47
06/31`1jATL0OGIh059@E01HAdD08H`6003o00T0oooo00<0P<000?n0003oP0007P3oP0000`2h>;@0
d51h0?n0000<0?n000030>QX?03@D7P0X23`00<0X23`00<0d51h0>QX?03oP0000P3oP0030:0Pl080
d51h4`3oP0020:0Pl0030=1@N03oP0000?l000P0oooo1000o`00CP0Yf0P0O5<l05lm>P1WD4h0G5AG
04]8C01:BD/0EE=E05IFF`1MGF40I6AU07=_K`1lM7@0PWEd08UfL@2>NgH0TGii09B2NP2JRGh0Whio
0:6DQ02VVHT0YIZ90:ZRTP2^YI/0ZZ>K0:ZVX02/ZJ@0TiB;08^>P@2<SX80UIJ=0:FXY02V[j`0Z[>b
0:nd]P2b][P0[KBf0:^e]P2Z/K<0/;Bh0;6c]P2eTYP0Xb8/0;0;4P2a2A00/0L=0;8;402K8R/0GT5W
01LfL@1;Ki80OYJO08R=T01n>dD0S@D@09H32P2H0PP0V0<908d53P1c<T/09dYi0:[=h@2ZYK@0MQPV
07H?6P0Y9D@0GGN306AjM`1PN7<0FW5^05Y^K00O<TX00Pi0004>?P0353L0<4UF00SH20L00?l0203o
ool4003o00040830003@D7P0d51h0;Ph]2H0X23`00<0^3Rd0?n0003oP000103oP0000`2h>;@0X23`
0:0Pl0020:0Pl0030>QX?03oP000oh0000<0oh0000@0d51h0:0Pl02P8?00X23`0P3oP00;0:0Pl003
052@N000o`000?l000D00?l02`3oool000X0oooo05P0:MT805hU400l0040?P<302h10P0U0@409041
02l20P0i0`<08`4103h41P0e0`@08`4205H21@1M0@80H04306X10P1d0@80N@4208010P270P@0S`<8
09@2202E0`P0V0H:0:882`2_2Pl0^0d@0;l@4P305QP0`c8c07PK701fIf<0eM[H0>7UiP3Tj>T0gnCV
0=[OhP3Kgn80g=oR0=kLh@3@/;L0_fig0;dg@02o7R@0Na0C03P@4P1ED4d0W:>O0<C=b@3>e]@0e=SH
0=?Gf035`<D0U6M_08XR:@2C1`h0T0P=07dJ6P2DOgd0cMGE0<gDeP2k/kH0MB/^08H62P2510P0P`46
0883201n0PP0N0<807T52`1i0`L0P0<908@32@1m2@d0M0L70:<B5@2K2@l0VPD;09022@220@L0KP@8
07]4AP24OGl0AD9105A2?00QSPH00?l02@3oool00`20`000oh000?n0000M0?n000030;Ph]03XJ3`0
oh0000/0oh0000<0d51h0;Ph]02h>;@00P3@D7P20?n000030;Ph]03@D7P0oh0000<0oh0000D0X23`
0=1@N03@D7P0X23`0>QX?00C0?n00080X23`00<0d51h0?n00000o`00203oool4003o000/00cg0`1o
EST0I5aI069OGP1JEEP0BdE804M5B01DDUL0D5AG05UMGP1RHf@0Kfe^07acM@21MGD0RWUf08akM@2@
OWP0UX=l09^:OP2KSH00WY200::DP`2SVHT0ZZ>E0:ZUVP2YYId0ZJJN0:RYX@2EV8h0RHao08Z>O`2<
THD0VJ6I0:F_[P2W/K80[K6f0;:f^P2]/[D0YZb_0:R`/P2Z[K80^:N^09ld?`2_31<20;88400P0:X:
402I;Sh0@Cib0299P01/Rih0QYZM08BEU027LgP0P0dG094330281Pd0PahZ06h_@`1H>5@0:SIX07ZR
``2b_</0Q4IF08074P1S9SX0;49T06^7S@1VNGT0HgUc05aeL@1JL700;D1C004A?00<8T<0=51L059Z
J@0=cPh7003o00P0oooo1000o`000`10h000d51h0:0Pl00W0:0Pl0030>QX?03oP000oh000080oh00
00<0j6Pl0:0Pl02P8?000`2P8?001@2h>;@0oh000?n0003oP000j6Pl0080d51h0`2P8?000`3@D7P0
oh000=1@N00;0:0Pl003052@N000o`000?l000D00?l02`3oool000X0oooo01L0;=/;054D10110@00
@P8302h10P0W0@408`0002l10P0h0`<06`4102L41P0M0@80:08305/41P1F0040G04206X10`1d0@<0
N04207h10`250@@0S`4809H42`0209L52P0o0:08302[2@h0]`d?0;/=3`2l51H0R1DE05<f<`3;d/l0
gnOW0>;Wi`3Tj>X0gN;T0=SNh@3Jg^80h]oS0=>W[`2`=Sl0_aTO0<LG6`254Q@0?bhZ0:6WX@3?e=<0
f]oO0=CKgP3Cf]`0e=SK0=7CeP2EJG00Q1TP09<9402C0``0SPT>068B4`1hL6d0b]?B0<_Be02LR8T0
M1PK08H42P220`P0P04708022@1m0@T0I@4305`00@1h1@X0Q08808L42P1l10P0J`<409P@4`2710H0
TPD;094220220@D0L@@807m5A@20MgP0CD]804Xj=00QS`H00?l000T0oooo00<0P<000?n0003oP000
703oP0020=1@N0`0oh0000<0d51h0:0Pl03@D7P01@3oP0000`3@D7P0oh000?n000030?n000@0X23`
503oP0020:0Pl0030=1@N03oP0000?l000P0oooo1@00o`00C@1YNcD0I5aK06ARH@1IEED0BTA404M5
A`1DDUD0DU9E05UIFP1RH640KVYZ07Q`L021M7H0Pg=b08mlM`2CP7T0U8=m09J8O@2IS7`0Uhai09N;
NP2ITGh0XIZ90::OT@2TXiT0ZZNP0:^[Y@2UXih0S8n408V=O`2<T8D0TYVB0:>]ZP2Y/[40[[Be0:jf
]`2W/;@0YZna0:^`]02jZk00Z5aU0:d@602e2a40/@T@0:X<4P2?=dX0<3]e03MPT@23WJT0T:2Q08nN
W@23TY00PEUL08d74P272100HC9;028aIP0?;6/0DgJR08NM_`2UW[D0QD1@0849501f7RX09bQ@04YZ
PP1cRX`0GWAc06=hMP1MLg00FVm^03]CFP0V@Dl0BVQ[04mYI`1>IfL07Z8R00L00?l0203oool5003o
00030=1@N02P8?00X23`02D0X23`00<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0X23`0:0Pl0040:0P
l0040=1@N03oP000oh000;Ph]0D0X23`00<0d51h0?n0003XJ3`0302P8?000`1@T7P00?l0003o0005
003o00/0oooo000:0?ooo`1H02WH2P1:2`40@04104020P0`0P809P4102@10@0/0@40=P8201P20P07
0@4040@403L2101J0@<0E@0005T10@1[0P80MP4307X10`1o0@80Q`4308h3202B10/0U@D;09052P2F
1``0YPX>0;8;3`2h3a80Pa0B04h/:`2_/Jh0g^;S0>7Uj03QiNL0hnGX0>7RiP3Oh>@0gm3F0=RIXP2o
=Sd0`aHK0;lB5@2I51H0G3`i0;W0^@3FgMT0f]oO0=SNh03Dfmd0dmWK0=?GfP2fWZ<0RB8X09D;3`2C
1P`0TPH;074<3`0f61L0Wj>Q0<cAdP2k/[D0LcTl07`<4@210P/0O@4907h220210`P0PP8807l42P1^
0`P0LP@608P42P280`P0QPH:06`82P1T2Pd0K@@708d52`2A0`P0QP4707H42022ATP0SXN804U7AP19
=C808Hd5003o00T0oooo00<0P<000?n0003oP0001`3oP0000`3@D7P0j6Pl0?n0000A0?n000030=1@
N02h>;@0oh0000/0oh0000<0d51h0;Ph]03oP0001@3oP0000`3@D7P0oh000?n000030?n000030=1@
N02P8?00X23`0080d51h503oP0020:0Pl0030=1@N03oP0000?l000P0oooo1@00o`00C@1WSS/0JV1O
06UVH@1JE5@0Bd1304a2A@1ECU00DDm@05MFF01MFeX0JfEU07E^K@1nLg@0Rgam099mO@2BPGX0TX1k
091nM02APW@0THAe0964L@2CR7<0UXah09J@P`2MVY40ZJJQ0:NVX`2[ZJH0Y:>N09VMUP2KWYP0WJ:N
0:>^ZP2U/[80[;Be0:B][`2OZj/0XJZ/0;2OYP2VG6P0Y1`T0;<<4P2^20d0Y0/A08XjC`0U>gP0AfjK
096R[P2CWj80TInP08jMWP24Ti80QVU/08X:4`275b40<bYB06^1Y02>U:d0TWjD08i8GP2752@0QPPA
07PU=00c;UP09dI[086IX@1/P8<0HGEc065gM@1MMG80Eg5/05E/JP1?J6H0D6aY04=QI@0B;D808W`b
00L00?l0203oool5003o00030=1@N02P8?00X23`02@0X23`00<0d51h0?n0003oP0000P3oP0000`3X
J3`0X23`0:0Pl0050:0Pl0030;Ph]03oP000oh0000@0X23`00@0d51h0?n0003oP000j6Pl3P2P8?07
003o00/0oooo000:0?ooo`1H02KD20151`40?@4103X20`0Y0@808`4202/20@0b0@80>@4202820P0l
<C40FCe104l31`1F0@80E@4105h20`1/0@80M`8407`10`1o0P80QP8208X21P290@H0SP8808l32@2E
1P`0Y0T>0:/;3`284A@0Je9@0<K9b@3IgMh0g>3S0=kSiP3Mhn@0h>GT0=gHg@37SIP0_T5:0<`R9`3E
5aX0aQ@H09/H6@1bB4D0blk<0=[Og`3Igml0f=kO0=OLg`3DfM`0eMWL0<c5b02==S/0W0`A09462@2:
1@X0K`X?03XT8P2DVID0bLg=0<W8c@26E5/0N@dB08042P1n0PT0O@8:07d12P1o0PP0PP8908<32020
0PT0OP<708D420260PT0QP<9094T9`20?Ch0I@D909@63@2@0PL0Q@4707X42P27BD/0QGam05=<CP10
;BX07h/4003o00T0oooo00<0P<000?n0003oP0001`3oP0000`2P8?00d51h0?n0000@0?n000030;Ph
]03@D7P0oh0000/0oh0000<0d51h0>QX?03oP0001@3oP0020>QX?0@0oh0000D0j6Pl0:0Pl02h>;@0
^3Rd0=1@N00E0?n00080X23`00<0d51h0?n00000o`00203oool5003o001=06R:;P1]HEh0K6QV065J
F`1C?D40BBHY05I8C01CDED0EEAF05eKFP1/IVL0NFi_08AfN02=Ng/0RgQf095mNP2?N7<0SGA]08Yg
J@2>P6h0U8Ma09R:MP2DRWL0TXil096>P@2KVi40Z:VP0:VZY02/[J/0XZNS09jTX02PYJ<0XJVX0:J_
/02X/k80Xk2^0:F`[`2SZJX0X69[09lI8`2_3Q@0[@X@0:8<4@27=TL09CQa04a^V02JT9d0WFih09]H
I02KJG80Uh^>08VEU@2IUiX0O2/d08H74P267c00QRTh08@F9@2821H0S0TB08@M9`1P=Dl07RQO02e>
O01mUZ<0P9:F06f0PP1TMgH0HgQe05ieL`1GLF`0DfeW04iWJ00]BET01Q]0004C?00RDCh01`00o`08
0?ooo`D00?l000<0oh000:0Pl02P8?000P2P8?000`3@D7P0X23`0:0Pl00N0:0Pl0030=1@N03oP000
oh000080oh0000@0j6Pl0:0Pl02P8?00X23`0`3@D7P30:0Pl0040>QX?03oP000j6Pl0>QX?0<0oh00
00<0j6Pl0;Ph]02P8?003P2P8?07003o00/0oooo000:0?ooo`1202?A1@141@00?04203410@0V0040
8@4002T10@0c0@40?04103/41P0l5ah0AA<J05@21@1D0P<0D04205/30`1X0P@0M@4507X10`1n0080
Q04208L1102;0@D0SP4609D42`2H0PL0X`T<09P=4@1761T0^Kfl0=SJg03Ff]d0f=gP0=cQi03Kgn80
gmoS0<FAW02f9S40dAXP0=PI6P3F5QL0/aLI05`F5`2l]K@0f]gP0=WLh03Gfmh0emcO0=OKg@3FfMd0
e]SM0;6;T`2D4AT0W0H=08l72`1f3A009PP707j6P03Ae=@0cM3C0:^IW@1g6R00QPL>08<32P1o0@P0
OP490P1o0PX050220@P0P04807l220200PP0Q0<908P32@290`X0S0/@0:ho@@2H41D0W`H<09011P25
0@D0O0D:07dl@02ERhh0E4m@03DS7`0NRP800?l02@3oool00`20`000oh000?n0000I0?n00080d51h
3@3oP0000`3@D7P0oh000?n0000;0?n000040:0Pl03oP000d51h0:0Pl1H0oh000P2P8?000`3@D7P0
oh00003o00080?ooo`D00?l004d0KhHR07=SGP1]JFX0I4mB05DR9@197Ah0ETI<05MEF@1BDUD0FeUK
06eUJ01jKg00RGak095mO02>NWL0SgUg08adKP29KVH0RWAV08ekJ@2EQW00Vh]d09VAO@2DT840T922
09>DR02RXI/0ZjbX0:^ZZ@2[[:`0Yj^[0:>[[02PZJ`0Y:j`0:Rc/P2T/Jh0WjZZ0;FWZ`2N;3<0/@dD
0;<;402_2a00V3=103I2N01FFh`0TdQI09@E8@2D31D0T10K098?6P2;9C00ThR=086CUP2ASY40NDeB
07<T<P1i7Rl0NbHd06/aA01?=eD0;c9P03<cI01HB6T0Meib08]jPP1jP8<0K82006EiN01UNGL0GG=b
05Q_K`15HFX04b]9004@?P023d400A0l024c@`07003o00P0oooo1@00o`00103oP000X23`0:0Pl02P
8?020>QX?200X23`103oP000103XJ3`0X23`0:0Pl03@D7P50?n000<0X23`1@3@D7P01@2h>;@0X23`
0:0Pl02P8?00^3Rd00d0X23`1`00o`0;0?ooo`002P3oool0F00Rd0D0A`H103/10@0_0@80:P8202D1
0@0[0@40>04204020P160P@0B0P;04L31@1F0@@0D`8404T20`1J61T0HADF06H2101g0P@0O@8308<2
0P260@80R@4308`1102B0PL0W0L:09d>3`1R30d0NW9^0=OIfP3Ifmh0f=[M0=OLg`3IgN00fMCI0<NH
X@2i<C/0baHK0=PH703J6AX0dQTI09L/:`2YTY40fM[J0=_Mg`3Hg=h0e]WM0=SDfP3=]Kd0/H><0:IU
L02N=3d0X``E090;4P1P2Pd0;@d=06=XI@33b/T0dM?F0;je_@1n?4<0Q0TA08P32P260`/0O`8907l1
2@1n0@P0OP8808422@220@P0O`8808021`220`P0Q@@:08T22@2I2@h0YPdA0:T<3`2R1`/0U0<808P2
1P1k1@P0Rda>08=gN`1NEUP0:ALB01f80P00o`090?ooo`030830003oP000oh0001T0oh0000<0^3Rd
0>QX?03oP0002`3oP0000`2P8?00j6Pl0?n000030?n000040=1@N03XJ3`0d51h0>QX?0<0oh0000H0
j6Pl0:0Pl03@D7P0oh000;Ph]03XJ3`F0?n00080X23`00<0d51h0?n00000o`00203oool5003o001>
04^b7@1lK6P0LFAU064];`1G8b@0CCXi0557B01LDUT0FeEJ05eIG@1_If/0NW1a08UnO`2>O7/0T7]i
08eeMP23K6P0Pf]R08UaG`2;N6<0TX=Z09:2I`2JT7X0UiF8096CR02BTh`0T92;09RMVP2Y[:`0ZZf^
0:Vb/P2[/K@0XZV[0:>][P2V/Jh0Z[Fb0:J_[`2aQXh0ZQ@N0;L<4P2d3180X1`X0593L@1NBgd0UAhe
09h<60278Bd0HciL0450IP1g?E80R@`F06A5FP1/RYL0UjV^0764S01GJhH06cAU041IQ00fAW@0BCUP
07D/AP213b00R0DB08L4401n1a40MbD/085bM01ZNGT0I7Qh05Y`M`0dBf<01aU9004=@`023Sl00A4m
01D_BP12Ee`01^D51P00o`080?ooo`D00?l000<0P<000:0Pl02P8?000P3XJ3`00`2h>;@0X23`0:0P
l00M0:0Pl0030=1@N03oP000oh000080oh0000X0X23`0;Ph]03XJ3`0oh000>QX?02h>;@0X23`0=1@
N03oP000d51h202P8?000`3@D7P0oh000?n000020?n000030>QX?02h>;@0X23`00T0X23`00<0:<Pl
003o0000o`001000o`0;0?ooo`002P3oool0F00Rd0D0B`H203h20P0^0@409P4102L10@0^0@80>082
04420P100@80@P4204P20P1@0`@0AP8206XL801k82P0Na<I05X2101S0`D0N@8308<10`230@40QP42
08/11@2B0PP0T`T@064:3@1NC4P0aL[70=SIf`3Gf=`0e]SK0=GIg03:/KP0Z5IO0:dR:@325AH0caDE
0=@E5`3F5QP0aRd]0<jWYP3HemP0fmkQ0=[Nh@3Gcm@0`IZT0:mDH@2Y82/0W`hE09d=5@2F3QD0J@X?
02/>3`0o@cl0R9:<0<W>c@3<cM40/9^S080h@P242A40Q`D:08L42@2810T0PP4608821P200`L0OP87
08022@200`P0N`4507h31`210PL0P`<:08L11`2L20d0[0X?0:d:402R1Pd0UP8808P11P1i10P0PD=4
0923Q@1LDE@07@/701^70P00o`090?ooo`030830003oP000oh0001P0oh0000<0^3Rd0=1@N03oP000
103oP0000`3@D7P0oh000?n000040?n000030=1@N03oP000oh0000<0oh0000<0j6Pl0?n0003oP000
0`3oP0000`3XJ3`0X23`0:0Pl0020>QX?0030:0Pl03XJ3`0oh0001H0oh000P2P8?000`3XJ3`0oh00
003o00080?ooo`D00?l004h0D[/S07i_J01WAD@0Hc8`04lh>P19?T00DTE:05eBE`1PEUh0I5YP079V
J`1nLgH0Rgj008imO@2>O7X0R79`07iWHP1nIUT0Qg5S08QgI@2@PVl0UXUe09fBP02DTH@0UIJ:09FD
RP2;RX80RX^309bOVP2Y[:X0Y:f]0:bf]`2Y/K@0Yk6a0:^d]P2W/;80ZJf`0:9JI02a3QP0]P`D0:`?
5`1lAf<0M5Z009`K;02N5b80KCUK02<jMP0^DhH0JgVD08<fA@2<2aH0DS=G0620V029X:L0OIFS09jk
c01QO9@0ViFV07lfB0272AL0S`8=08l1302>0@X0R`8908D22@200`X0M2<[079eN013Ffh042M?008B
B@014D/00Pm4008A?P0O?e<0AVMW04aRHP0<c0/6003o00P0oooo1@00o`001020`000X23`0=1@N03X
J3`Q0:0Pl0040=1@N03oP000oh000?n00080^3Rd0P3oP0001`2h>;@0X23`0:0Pl02P8?00j6Pl0?n0
002h>;@01P2P8?000`3@D7P0oh000?n000050?n000030>QX?02P8?00X23`00P0X23`00<0D91h003o
0000o`001000o`0;0?ooo`002P3oool05P0Pc`<0BPH104010P0c0@80;04102h10@0^0@80=@420401
0P110P80?@0104@20P130P80E`8406l21P1j0PT0Q0<806P41`1;0040LP<508010P240@8208L10`0/
08d51`1O2`h0EDE10;^l^@3De=P0e=KI0=KGg03Ie]/0aJ6X0:H_>02d5A`0^A4G0;`@4`334140cQ<E
0=0D5P3=Fed0e<_<0=cMgP3Lgn40d<;:0:M@F`2Y72H0[a<L09hA601_2a40A`P;02H:2`11@d80UJ6P
0<7:b`3CfM/0aLC;08eOIP1o82P0P`dD08L83`250`X0R0<908P320240`L0P@8707l1201l0PL207l2
2@0B07d21`1n0PP0P`<808@2202:0`P0W`T=0:X8402[2@l0YPH=09/42`280@L0N@@908U9C02APX<0
Cd=301/71@0IQ@400?l02@3oool00`20`000oh000?n0000G0?n000030=1@N02h>;@0oh0000<0oh00
00<0j6Pl0?n0003oP0001P3oP0000`3XJ3`0oh000?n000020>QX?0D0oh0000L0d51h0;Ph]02P8?00
d51h0?n0003@D7P0^3Rd01T0oh000P2P8?020?n00003003o003oool0oooo00H0oooo1@00o`00CP0Z
gA40RF=J06Le<`1WCdd0Bc/k04Tk@01AA4/0FU1G065GG`1UG640LFQ[07idN025NWd0Rg]n08eiNP25
KF/0OF5L085WGP25Kf<0RGIX09J4M@2HRGH0WI6109B@P`2GUh/0W9Z@09:DR`2>T8P0Rhn80:>XX`2[
/k40[;Jf0:fg^02Z/[D0Z[2d0:F^/@2QXZT0V3i90;0=5@2d3aD0Zc0f09IPL`2Q7bl0Xah/05i4K`0J
A880HHFS08nFX02>C5L0T`XF08LM;@0X;F<0LYB`07^BW02DZ[L0BF=n089`PP1n62D0R`<<09<3302A
0@X0S`4:08X22P260`/0Q08908@12@1_1a80@3YF00<JD0014e000A5<00DHB`0874X042U704Y/J`1=
J6D0DVYV013B4@H00?l0203oool5003o00030830002h>;@0oh000280X23`00D0j6Pl0?n0003oP000
oh000;Ph]0020?n000070;Ph]02P8?00X23`0:0Pl03XJ3`0oh000>QX?0050:0Pl0030;Ph]03oP000
oh0000P0oh002P2P8?000`1@T7P00?l0003o0004003o00/0oooo000:0?ooo`1H023=0`1:1040?P41
03@10@0_0@40;`8102`20P0a0@40?@4103h10@0l0040?P8203l10P1T0`H0LP4507`11P230PL0J0<7
0440001_10P0P04208D10@270P<0S0<508D8301;9bD0Zj^W0=;Ce@3Ce=T0eMKI0=SGg03C_L<0X3Hn
0;@C602i41D0^@lF0;X>4`313a80bA0E0<dE603@Kg00f=CF0=gNhP3Ig]l0RGQm06lM901]4AH0DPT=
02T10P0<1`L06b@Q06eiMP2`^KL0d]SK0=;IgP2obm<0HV=^03dB600l1`T0?@D805@93P1e20l0QPD<
08T32P230PP0O`8807l22@1n0PL0O`8508022@1l0PT0P0<90842201o0@P0RP@:0:0:302X20l0ZPT>
0:P83P2K0`X0R@4707T4201e=CL0PG=e04/m?P0I10<0:DT2003o00T0oooo00<0P<000?n0003oP000
5P3oP0000`3@D7P0X23`0?n000030?n000030=1@N03oP000oh0000X0oh0000<0X23`0?n0003oP000
0P3oP000103@D7P0X23`0:0Pl02P8?020?n00080X23`6P3oP0020:0Pl080oh0000<00?l00?ooo`3o
ool01P3oool5003o000P027U2`27DSd0Ke1=05mBDP1:>SP0BcXk0513A@1ICE80GeIK06IMHP1eJFh0
PWEk08AhO028NW/0RWMh08A[JP1iGUT0OVIM08M_HP2;M6H0TGma09^=O02NTX<0UYB709RHS`2IVI80
T9F=09FMT`2;T8X0Uj2L0:N`/02[/kL20:^e]`0/0:Rb]02V/k@0[k2c09lkAP2c3A@0[A4E0<EBE`2W
9Rl0YA`U06=7L@0NBHH0NYJ[09V<U@2A?T`0T`XF08dF8`1@>F<0<5:307>AX02O]l<0Rj>c07]/O`1f
4b40R08:08l22@2?0PX0RPD<07lG8`1/;Sd0GR`o07LF901o0Pd0C`PU00XBC00155@00AIB01HcFP10
GW802R5502A2EP1@Kf`0Af=U03A>E`0QYbP6003o00P0oooo1@00o`000`20`000oh000;Ph]00R0:0P
l0H0oh0000D0^3Rd0:0Pl02P8?00X23`0>QX?0020?n000030;Ph]02P8?00X23`0080X23`00<0^3Rd
0>QX?03oP000103oP0020=1@N0030>QX?03oP000j6Pl00X0X23`00<0D91h003o0000o`001000o`0;
0?ooo`002P3oool0@P0Oc@<0BPD203X10@0/0@40<08202P10@0T0@40<08203d20P0k0@00?04103L2
0P110P@0J08507411P1g0@H0N@8805D2100l0000K`@708<110280P<0RP8408d41P1Q2`/0PW]e0<gA
d03>dmD0dmKH0=KDf03>^;d0ZUAJ0;0E6@2h4A@0^A4C0;X@502l3a<0`A0D0<H@5@3:51P0afEV0=OC
e@3Lh>80fMkO05aTI`0Q7Al08b4Q034d<P1@F5D0Phn=0:^f]033b//0dmWL0;g:dP27VJ<0>TiF01DS
9P0W;Bl0;cHg02T_;P0I5A@0:@@606<940211@`0P`8908032080O`8801@0P@8808431`1g0P@0N`47
08@22@200@T0Q`4909l93@2Y2@h0Z@L>0:P83@2J0`L0S08707L42@2?EEP0P75b03d_<00E0`<0>@`3
003o00T0oooo00<0P<000?n0003oP0005P3oP0000`2h>;@0d51h0>QX?0020?n000030=1@N03XJ3`0
oh0000/0oh0000<0X23`0;Ph]03@D7P0102P8?000`3@D7P0oh000=1@N0060:0Pl0030=1@N03XJ3`0
oh0001@0oh000P2P8?020?n00003003o003oool0oooo00H0oooo1P00o`00C@23DcD0M6IT05eCDP1>
=C<0BBd`05A5B@1GC500HEAL06QIHP1fJ6l0PWIl08=gN`2;NWd0RgMj08=]J`1fG5D0OFAH08]bIP2<
NVX0TH5b09R;O@2HT8<0UYB509NHS@2?Th`0TI^G0;g9bP2UZj`0TY^F0:Na[`2X/k<0YkBd0:bf]`2Y
];H0Yk>d0:Z`/@2SCE80^10G0;H>5P2m72H0/QHN07i4H`0WA800PhJP09QNJ@2B7RT0U@/G08DV=`16
>fT05cag07jN]01nUj40S:N^08>6TP1l8c40S@<=08/2202?0PX0QADL05XeCP0V;Ud0635P03mCM@1W
=DL0I0HL01L=AP0255X05c1M03mNL01HMG/0:DAJ01hhF00R?e<0BFI^01<[B00253L08ghe00H00?l0
203oool6003o00030?n0002P8?00X23`0080^3Rd7`2P8?000`3XJ3`0oh000?n000020?n000040;Ph
]02P8?00X23`0=1@N080oh0000<0j6Pl0:0Pl02P8?00102P8?000`3XJ3`0oh000?n000020?n00006
0;Ph]02P8?00X23`0:0Pl03@D7P0oh00302P8?06003o00/0oooo000:0?ooo`1H01k<0P181@80=@41
02d10P0_0P808@4002D20`0b0@80?@8203X10@0l0@80<@8203l31@1a0`T0N@8:07L32P1R0`P0A`43
05@20`1h0P@0PP4308L21@2>10T0QPL<05<Z9P2o`Kd0c];D0<oCe`3@e=L0bk2f09To@`2]6A`0/Q4C
09`C5`224A@0OQ<F09XD602n4aX0`PhC0<@@5@2f=C/0f<760=[Nh03Kh>00`<W80;:l^02Y]Zl0[;Na
0<C=c03BfM`0dMWL0<S@f02?X:P0?EEL0398B`1WNGH0UjBP0:F`[`2Y]K@0Y[6a09:MUP16BTD08P<4
06`840220PX0Q0@908<420200@L0PP4808<3201d0@80O0@908@22@230PT0S0<809l9302V2@d0Y`P@
0:<4302K0`X0S`8807@42@21CDl0M69V03@T9P0C0@40?@`5003o00T0oooo00<0P<000?n0003oP000
5@3oP0001@3XJ3`0^3Rd0=1@N03oP000j6Pl00l0oh0000P0^3Rd0:0Pl02P8?00X23`0=1@N03XJ3`0
oh000=1@N0X0X23`5@3oP0001@2P8?00^3Rd0?n0003oP0000?l000P0oooo1P00o`00C@28GCP0JUID
069ADP1;71h0CAhR05@nA@1HBU@0HUIO06QIH01gJ700P79j08=dN@2:N7X0Rg9e08E/JP1eF5D0Nf1I
08adJ`2APG80V8Qj09R;N`2ITH<0UiB609VLTP1lQX40]L300:nl`P2PZ:h0QHf:0:>[[02X/K80Yk:b
0:Nb]02V/kD0XJn`0::/[`2WIf/0]18K0;L:5P2h31D0]2@/09=UO`29E7<0UBDf0:0@702H3QT0PSA6
03PlK@0>=G@0HXFP08:FWP2U^<@0P9V[091eP`272QD0TP8;09412P2@0`/0O1l]01TPC`0cEW/0L8bJ
085lQ01]72L0B@LW00LBF00;8eh0DFmm05IbL@1DL7L01Qm103YEJP066d003bM<004?@0013ST06VLd
00H00?l0203oool6003o00030?n0002P8?00X23`0080oh007`2P8?000`3@D7P0oh000?n000020?n0
0080X23`0`3oP0000`3@D7P0X23`0:0Pl0050:0Pl0D0oh00102P8?000`3oP000d51h0:0Pl00;0:0P
l0H00?l02`3oool000X0oooo05P07L/204840@0]0040:P4102/20P0S0@409P4103X20P100P80>@01
03h10P0a0P@0:@4404h3201E0PX0C08904421P1M10T0O`H;08@420240PL0R@8708/3201U3@l0T8R5
0<gAdP3@d]H0d=?F0<Nf^P2N>d40YaHI098B5P1<2@d0:ATI03Ph=`0m?3h0;Q/L08DA5P2l3Q@0`@hC
0;`C5`2jCEL0djJ^0=_<dP3Mfmh0g=_O0=[Jg@3HdmL0aLG=08jOZP1EJWD0AeeS06]kOP2/]kP0`<S9
0<gEe03@emL0d=KI0<oEf@3?emP0c]OE0<37a@21NgT0HQPL08432`270`X0QP8808D31`240PL0Q@<7
08821`200@T0P08908@21`2F1``0XPT<0:@73P2U2A00XPL=09/32P2?0PP0L@D709AUI@1ZEUX08A8D
01@20@0n2P<00?l02@3oool00`20`000oh000?n0000E0?n000040:0Pl03@D7P0oh000?n00080j6Pl
0`3oP0020=1@N0030:0Pl03@D7P0oh0000X0oh0000<0d51h0:0Pl02P8?000P2P8?000`2h>;@0d51h
0>QX?0020?n00080d51h0P2h>;@00`2P8?00oh000?n0000A0?n00080X23`00@0^3Rd0?n0003oP000
0?l0203oool6003o001=09=S?01XB4H0I4Y;04d>3P1>6AX0E45305M:D01RE5h0JEYQ07MVKP20KWH0
P71f08EfM`27Lg@0QF]Y07QKE`1mHEd0Qg9Y0960LP2DQGD0UhUj09ZAQ02GU8H0V9^?07V2O02MZJX0
W:V_092HW02AUYD0Y:V/0:Z_/`2Y/kD0ZKBf0:Fa/P2X];@0ZK>e0:b9S@2T5R00]@hJ0;H>5@2^4Q/0
WR8d09lF902V4AX0VQ@Q088iC`13A7@04cMd05IjVP2BZk80S9nY0;73d@1/Oi80P4]H08d73`2?0P/0
RPH>08D53@2131P0Je5V08BLY`2DWJ<0O4UB07D85P0c23400a9H020lI@1MMgX0G7Ef03IBIP0<:4L0
BfQc00HH?P0144<00@e0004?>@0KBCT01P00o`080?ooo`H00?l000<0oh000=1@N02P8?000P3oP00O
0:0Pl0030;Ph]03oP000oh0000H0oh0000<0d51h0:0Pl02P8?001@2P8?000`3@D7P0oh000?n00003
0?n000060;Ph]02P8?00X23`0;Ph]03oP000d51h302P8?06003o00/0oooo000:0?ooo`0C03:i1`0f
0`408`4002D20P0O0@409P4102X10@0i0@40@041040100150@40=@8401P10`0Y0`H0<0T;03462@15
0`P0O@H@08T22@0208`42@1308h31P232`/0EBHT0;k1`03;d=<0c];E0=7?e02AE5X0UaPN078?5@0Y
0`@0>cll0:6]Z02`_;P0/K^g0:R/Z`1o<S<0]1<E0;h<4`2n3A40^Q<J0:/O:P2cCET0b8>=0<^<VP32
NX/0XEU[04X^?P0=82P0DVMY09FSX03>dm@0eMWL0=?FfP3AemT0d=OI0<oFf03@e]T0d=GG0<cCe@3?
e=L0d=7B07i;CP1j1@/0P@<708L320290`P0Q@<708821P1n0@H0P@<:07`120220@L0V@P>0:06302S
1``0Y0T>0:47302I10/0RP4806l82P2FJFX0Dcdo00h4100D0@40?PX4003o00090?ooo`030830003o
P000oh0001@0oh0000@0d51h0:0Pl02P8?00oh000P3@D7P30?n000D0X23`00<0d51h0?n0003oP000
203oP0040:0Pl0030=1@N03oP000oh0000D0oh0000@0X23`0=1@N03oP000d51h4P3oP0020:0Pl004
0=1@N03oP000oh00003o00P0oooo1P00o`00CP1fNb/0KdU406<k>01E3`h0DbTY05E4A01KBe00IUEM
071FG`1`A4h0ME1H07UYK`1nKW00QW=d08U_K@1nH5/0PFIR08YdK02@OW80SX1`09>8M`2FT8<0UYB7
09VGS`28RXD0OXF408Z?SP25RHD0WZ>Q0:R_[`2V[Jl0ZK>d0:Vd]@2Y/KD0Yjnb0:2/[P2/[k40Y4mH
0;0F8P2g3QD0ZQXQ09hY=02@<T<0M49M04I5M00Q@GL0AffE07jJZ@2T^;h0RYjU09b^]`29WjT0TYn[
07/Z>P2:10/0O28^04PeE@1A>540MaDP07dN:02RN8D0OC1008084`1c3ah06a1400LQF01?Kgh0G7Ak
039=I00894X0>EYY05E`L00O=Tl00A12008@@00?9T<093Q500?b0`D00?l0203oool6003o00050?n0
003@D7P0d51h0?n0003XJ3`0102P8?020;Ph]1X0X23`00<0j6Pl0?n0003oP0000P3oP0020=1@N0T0
X23`00<0d51h0?n0003XJ3`00P2h>;@0103oP000j6Pl0=1@N03XJ3`20?n000d0X23`00<0:<Pl003o
0000o`000`00o`0;0?ooo`002P3oool0F018Y`h0<`@101`0000J0P803`4102<20@0[0040>P8204@1
0@1:0@40C@4204X3200N0P@0J5EG0:bKX01U@TH0MALL08P53P2<0`X0S0@809462@2B2Pd0KQHD07AT
GP3;d]40bm7C0=;Ce`2eVZ00Ob8U04l;3@0]71`0IVa[0;g7`P3FfMT0fmgO0=[Mg`3Gg=/0^i2=0:DN
7@2n3Q<0`0lC0<8?50334AL0_aDL0;TI8@2e6R@0YQ`X05d@600e;c80Pi6@0;O2`@3?e]D0d]SK0=;H
g03@e]T0c]OH0<oDe`3@eMP0d]KI0<oFf@3<eML0c]KI0<oEf02AMWP0M`P?07l21P2810X0R`D;0883
1`200PT0O@8907h3201l0`P0Q0<709T73@2M1``0X0L;0:@:3@2N1@T0UP<:08L11`1`30l0XWYl058n
@0090@406@81044:1000o`090?ooo`030830003oP000oh0000X0oh0000<0^3Rd0:0Pl03@D7P01`3o
P0001@2h>;@0X23`0:0Pl03oP000d51h0080oh0000@0d51h0:0Pl02h>;@0j6Pl0`3oP0000`3XJ3`0
oh000?n000080?n000040;Ph]02P8?00d51h0>QX?0<0oh0000D0d51h0>QX?03oP000oh000>QX?002
0:0Pl0030=1@N02h>;@0oh000140oh0000<0X23`0;Ph]03@D7P00P3oP0000`00o`00oooo0?ooo`06
0?ooo`H00?l004h0HX/N07I:A`1O?3H0E38[0550?P1A@dL0GDiF06]9D`1^=Sh0K1@M07@d>P1aGF<0
MVEX07iXK023JF/0PVIT07iTH02:LV`0SGU^08ilK`2BQWT0UXj309RDR`2HUhl0Ui^C09RNU`2>T8/0
Rhn809NPWP2JXj@0V::S0:N`/02X/[<0Z;>e0:>`/02S[[00VJ6T0:MCG02`4AX0/10H085@L`0hEXT0
?5b:04Q[U@1VQZ40PijZ08nTZ02FZ:/0TjJY096Y[P2V_LH0FGJ;09>T[`1j<Cd0RPH@06hZ@@1<Dg`0
SXfW08=1C@231@h0Q0H@07`94P1W82h0=2M900@FCP0bE7L0D6f101PcG00484`0=eEZ05YdM`1HLFl0
D6M^01P_BP0P?5<0AVAY0399CP0>d0l5003o00P0oooo1P00o`00103oP000j6Pl0=1@N03XJ3`40:0P
l0030=1@N03oP000d51h01X0X23`00@0d51h0?n0003oP000^3Rd302P8?000`3@D7P0oh000=1@N002
0:0Pl0050=1@N03oP000oh000?n0003XJ3`03P2P8?000`1@T7P00?l0003o0003003o00/0oooo000:
0?ooo`1104NV3P0c1040704101P20P0@0@408P8102`10P0h0P40@08204P10P1B0080FP<705PS9`1D
>D40J3e8074Q:`1m1@d0R08;08T32@2<1@X0U0L;08TJ6@1?;2H0][Rd0<W@dP3>d=<0/YZO07<_=00g
3@d0IVQW0:je/`3=dm@0f=?G0<BJX`2^JWH0X86:0=KJg@3B_l00V2d^0;lD5`313Q80aA0F0<<>5037
4QH0`A<F08T@4P0k30`0FEYF0;K0_@3@fMP0dMWI0=CIf`3BfM/0d=KJ0=7Gf@3=e]H0c]GH0<kCeP3=
e=H0cMOH0<kFf@3>e]P0d=OI09IiO@1k2a400`200PT0501n0PX0O08907/2201i0PL0O@<808X32@2H
1@/0V`H;09d7302Q20/0W@D;09D42`260@P0NADI0:9jO@0a7b@0104101`10P152@<00?l02@3oool0
0`20`000oh000?n000090?n000040>QX?02P8?00d51h0>QX?0H0oh0000D0d51h0:0Pl02P8?00d51h
0:0Pl0020>QX?080X23`00D0j6Pl0?n0003oP000d51h0;Ph]0020>QX?0T0oh000P2h>;@00`3XJ3`0
oh000?n000030?n00080^3Rd0P3@D7P30;Ph]0030?n0002h>;@0oh000140oh000`2P8?020?n00003
003o003oool0oooo00H0oooo1P00o`00CP14Y0`0KS0S06e?BP1GAT00DD1005I5A`1SBDd0HR<Y06LH
7@1]8BD0J3Xo06QBFP1bH680NVEW07eTI`22J6X0QV]Z08M]J@2;Mfh0SGia09F8N@2GSX<0VIF=09VG
T02GVY@0U9^F08>8P`24Rh@0O8Io07^5PP26T9<0V:>U0:B`/@2U/K80Y;>c0:Ba/`2UXjP0XCU30;P?
5`2e3aP0O4=X05N0YP2EZ[<0UjV]09BTZ@2DYJT0U:RZ0:Vl_`2>XjP0TZZb086NYP1oW;40K8ZU08ig
O`1n4A/0P0LC07X?8@1j3Al0O@PB08432P2051`0D3=?014QC@0T@680>UEb00XSC0088Dh0945T04e^
N`1NNG/0HgUj05]cL`1ILG80CfYY05IaK`1AKF/09d9801fT80D00?l0203oool6003o00030830003o
P000X23`00@0X23`0`3oP0000`2h>;@0X23`0:0Pl00H0:0Pl0<0oh0000<0d51h0:0Pl02P8?002P2P
8?000`2h>;@0oh000?n000050?n000030;Ph]02P8?00X23`00d0X23`00<0D91h003o0000o`000`00
o`0;0?ooo`002P3oool0F016Y0d0<@<102400@0f4Q806@4101X10@0T0040=@8203T10@160@80E085
05T10`1I10T0G0TB06<5301a0`T0O`8908L22P280`X0R`@;08l72`1a:BD0WYRD0<gBd`3<d]D0/InR
06@[;`0j61L0OX:00<c?d03Ed]P0a:F_0:U4D02/6b@0R1HJ07EFEP3Ifmd0bjFZ0:DU:@3151H0`Q0D
0<PA5P3:4aH0`a8F08P@4P1A?C/0X:JS0<[Cd03Efmd0e=WL0=;If`3CfM/0d]WL0=3Ff`35a//0/ZR_
09b0S02GOHT0/Jje0<_Ce`3Be]X0d]OJ0<c;d01oBE40PPH>0843201m0@P0OP8908022@1i0PP0M047
07@1201d0PH0OP@809032@2I1@T0W0D:09l73@2K0``0T@<:08D11`1f6Qd0V7Qj01/@4`020@406`81
04<80P00o`090?ooo`030830003oP000oh0001<0oh0000T0X23`0;Ph]02h>;@0^3Rd0?n0003XJ3`0
X23`0>QX?03oP0000P3XJ3`20?n000030=1@N03oP000oh0000L0oh0000<0^3Rd0:0Pl03XJ3`01@3o
P0020=1@N0030;Ph]02P8?00X23`0080X23`0P3oP0020=1@N180oh000`2P8?020?n00003003o003o
ool0oooo00H0oooo1P00o`00CP14]`d0IBXG06m@C@1GB480ECLj05lb>@1W>Sl0H3Dh06U5B01WBe80
HTmG061=EP1YE5T0M5mR07aRIP22IfX0R6]/08Q`J`2?O7D0TH=i09J9N`2ITXD0V9F<09^JU029SHH0
OhN0071kLP1cOGH0N85m07F0O@1mRHT0RiZJ09ZWZ02V/;<0XJb]0:Bb/`2^ZJh0WB`d0;T=502h2a40
X2Hj05=MQ02H[kP0W:b^09f//02JZJh0UJJ[096TY`2W^L00Y;c6059dS01jVJh0Bg2:0:o4bP2LQY00
ISA3068U>@1N:Sl0F3A707LO:`1o82/0@bi>05Y=I@1VE5d0I51D065OI@1KKW<0Eg=b05UfLP1LNGD0
Hgak061hN01KLgH0C6UW04i/I`1?K6`083a402RR;0D00?l0203oool6003o00050830003oP000X23`
0:0Pl02h>;@0103@D7PL0:0Pl0<0oh0000<0j6Pl0:0Pl02P8?002`2P8?000`2h>;@0d51h0=1@N002
0=1@N0060>QX?03oP000X23`0:0Pl02h>;@0d51h302P8?000`1hF;@00?l0003o0003003o00/0oooo
000:0?ooo`1H04:S300`0`008`8305@a<P0M0P805`4102420@0a0@40>00104L10`1<0080C`0205<0
0P1N00D0IP4506h11`1h0@T0PP8;08@1202:10X0Q`T<07UAC038c</0cMCE0=3AdP1fDeL0:PP;06AT
G`3:c/h0e<cB0;63S@2N<3T0^1DK09<C5P0n3Pl0[jb[0=gLg`2jM7`0^1TP0<<A5@354AH0aa8F0<TC
602[4QH0A1XJ0;2h]P3DgMX0eMcL0=CKg@3BfM/0e=[L0=;Jg03?dMP0W8:B085:EP1f8bl0O1@Q06dJ
9P1@?D@0^L740=7GfP3BeMT0Y9:J074N:0241@/0P@8807d2201m0PL0O`<907L21`1a0@H0L`4707P3
1`1l0PD0SP@:09D42@2L1@/0W0@;09P52`2<0@P0Q047088];@28KFd03@D70040000I0@00?PH1003o
00T0oooo00@0P<000?n0003oP000d51h4@3oP0000`3@D7P0X23`0=1@N0020=1@N0050?n0002P8?00
d51h0?n0002P8?00103oP0000`2P8?00oh000?n000060?n000030=1@N02P8?00oh0000D0oh0000<0
d51h0:0Pl02P8?000`3oP0020:0Pl080oh0000<0X23`0?n0003oP0004@3oP0030:0Pl080oh0000<0
0?l00?ooo`3oool01P3oool6003o001>02KE1`1V;a`0JSll0694@01L7b40HQhT05hf?01OBE40GD]F
06A?FP1PCUL0G4YC065;DP1XDED0ME]N08I/K02;Kg00QG5]08akL`2CPW/0V8]n09VCQP2JUh/0QH=k
07QmM@1cNW<0Lgef07N1NP1iPWd0Mh9o07R3P`20SXh0TJ6R09n[[`2PZjh0XJfa0;J`]@2I:S@0]PhE
0;X=4`2a3QP0Od1O07R>Z02K[;40VJR/09f^/02W^[`0UZfb09bc^P27X:d0VkC505QkV`1JQ9`0^MKP
0;oCgP2V^lX0IgfJ03]8K01:>5H0M14P08@53P1i1aD0L`D?06l4301Z0`T0I0XA06@i?01QK6`0Fg=a
05mhM@1KMW<0GWYh04QSJ00_CU40AF=S024jC@076cD0<7hl1@00o`080?ooo`H00?l000@0P<000?n0
003XJ3`0^3Rd0P3oP0000`3@D7P0X23`0:0Pl00L0:0Pl0@0oh0000<0^3Rd0:0Pl02P8?003`2P8?07
0?n000030=1@N02P8?00X23`00T0X23`1@00o`0;0?ooo`002P3oool0AP12X``0=PX704d`<@1I@dD0
4`4101H10P0N0040<08203/10@160P@0B`4304d10`1F0@D0H`4606X11@1b0PT0NP4:07d21`1o0PP0
QP@908PL7@2=NgL0b]?C0<gEeP2e/;40?2DV05aKF@2f^kT0d<g@0:U[M`2M82`0/A<I09`A5P1@7b00
ViRG0=CFe`3Jald0[cPo0<DD603641@0bQ8G0<PA5@2n5AX0Ka4D09:>S03EfMT0fMgO0=SNgP3Ffmh0
dm[M0=7Df@2o[[H0TUIQ08DO:P294AX0R0`D07/<4`0m3100ADU:0;c7a`3?eMP0]Zje07<i@`1k3AH0
P08;08832`1o0PT0N`8607T11`1b0@D207411P0@07T11P260PH0S0<80903202E0`X0V@@:09@32P2<
0PT0QP8808@d=@1hG5l0208400810@0N0P40?`D1003o00T0oooo00@0P<000?n0003@D7P0X23`4@3o
P0002@2h>;@0X23`0;Ph]03@D7P0^3Rd0:0Pl02h>;@0j6Pl0=1@N0030?n000030>QX?02P8?00j6Pl
00P0oh0000<0X23`0>QX?03oP000103oP0020=1@N0@0oh0000H0j6Pl0:0Pl02h>;@0j6Pl0;Ph]03@
D7PC0?n000<0X23`0P3oP0000`00o`00oooo0?ooo`060?ooo`H00?l004h08N@9064Y2`1^?cT0HRHT
06@F5P1R<CD0G4M?05Q8C`1MBe<0H4]B05e6D01KAe80Gd]B06=?D@1_Ee/0QVa_08]cLP28M740SG]b
09:3N@2ERH00V9:708Z7O020OGD0NWeg06UcK`1MKV/0FF]Z06EfMP1ePH40MX:307Z6Q`1nSXh0UjNY
09RVZ@2IYjd0YjR]09Xh@@2`2a<0^0X@0;P;4@2R62H0JEMi09J^_P2JZ[40VJje08jUZ02X_/<0X;W1
06F9X@1`TZd0>VB709VlbP30eMl0^lSG09bBY@1hAU/0LATY07X74`260`d0Q`8:08<12P1i0@T0M049
07011`1_0@P0I0@906A4AP1KKVd0Eg9`05EcK`1FLfl0CfY/01/fA`0A9ch00@dc004?;`0WASL5003o
00P0oooo1P00o`000`20`000oh000?n000020?n000030=1@N02P8?00X23`01d0X23`1@3oP00>0:0P
l0030=1@N03XJ3`0oh0000P0oh0000<0d51h0:0Pl02P8?00202P8?05003o00/0oooo000:0?ooo`1H
03jP2`126140BBX[02T?4`0E0@80608201`10@0/0@80?08204<10P1;0@80D@4305h21P1U0@D0JP87
06X42P1a10/0OP<708021`2510/0S3/l0;6_[03=dmD0c=?F05MFEP1YK6L0a/c;0=3;d02MGFH0X1HK
0:X@5P2=4AD0@1TI09nUX`3Bf]X0fmKJ0;APJP305a`0b10B0<XA503=4QH0aATK07/A4@28LW00d=WG
0=OMg`3Fg=h0f=gO0=CLg@2PZk@0GTiM07hV=02G41L0V0hB08d=4@1^3A80:PX:04iKEP2a_k`0d=OI
0<6oa01h?D<0OP/C08<42P1n0`P0O@4907l22P1m0PP0NP8807421@1^0@<0L04407T110230@@0P`43
08X21P2B0`T0U`@;09<12@2@0PX0Q@<909MCEP0k92P01P4200@10@0V0@80@@@2003o00T0oooo00@0
P<000?n0003@D7P0j6Pl403oP000103XJ3`0^3Rd0=1@N02h>;@20:0Pl0030=1@N03XJ3`0j6Pl00<0
oh0000<0j6Pl0:0Pl03oP000203oP0000`2h>;@0j6Pl0?n000020?n000040>QX?02h>;@0X23`0>QX
?0@0oh0000H0j6Pl0:0Pl02P8?00j6Pl0;Ph]03XJ3`C0?n000040>QX?02P8?00X23`0;Ph]080oh00
00<00?l00?ooo`3oool01P3oool7003o001>06/b301a?CL0IQlK06Ha;`1NBDh0EDE=05Q5CP1JAe40
FTE@05a3CP1MAe<0Gd]B06==D`1_EUX0P6IZ08ieM02<MG<0TGmi09F4O02@QW/0THV107MdK@1WKVP0
KWId05a^K@1_OGX0IGMe04aSI@1/OG/0Lgmo07>1PP1jRXT0P96B08jOX@2DYJP0VjJY0:5HH02/51l0
^0/E0;L:3`2c2a80VB/o07=hS`2FZk80X;Fh0:o4bP2H/KX0NiRU08bX^01WRjT0H8bX0:_7f@2RVZ/0
QdEJ088B802010h0O`4908022@220PT0Q@8908@2201l0PT0L`8907421`1`0@L0JP4505TK8P15CED0
Dg1_05=`K01@Kfh0;dYL008@=`0133<00@X_004?;@0N;C@01?<31000o`080?ooo`L00?l00`3oP000
0`3XJ3`0X23`0:0Pl00N0:0Pl0030=1@N03oP000oh000080oh0000<0j6Pl0:0Pl02P8?002@2P8?00
0`3@D7P0oh000?n0000:0?n000030=1@N02P8?00X23`00P0X23`00<0:<Pl003o0000o`000P00o`0;
0?ooo`002P3oool0F010Y0T0Aal@02440`0G0@805@4101`20P0O0@80:`4203/10@160@80DP8205P2
0P1O0@H0I`8606D21P1;00@0C`8407d4202310L0P@@808eCD033a<<0c]?D0;c5a`0b@cd0]l2i0=7D
e@2]R8l0UQTN09h@4`1i4AD0;0H608>:QP3?f=P0e]OL0<NJX`2b8BP0a1<F0<@@50383aD0bQ0E0:HO
7`1O>SP0dM?A0=KMg@3Gg]l0emcM0=WLg`3Bfm/0UJBV02LS:`1N4QT0U`lC08TB5P1J31007@@403i>
A`2c_kX0c=KF0<S>d`26HFT0P14H08H42`230`/0OP8807h120200PT0P@<:07`22`1`0@D0K0020781
101l0@D0PP45084010260PD0S`4609D22@2D0PT0S`4908@32@25A4T090hD00H10`070@40;04103l2
0000o`090?ooo`030830003oP000oh000140oh000P3@D7P01P3oP000d51h0:0Pl02P8?00oh000=1@
N0@0oh0000<0X23`0=1@N03oP000203oP0000`3@D7P0oh000?n000030?n00080X23`1@3oP0040:0P
l0030=1@N03oP000oh000180oh0000@0d51h0:0Pl02P8?00d51h0P3oP0000`00o`00oooo0?ooo`06
0?ooo`L00?l004h0K4L>05hP5`1`>SD0JeEF05A6BP1C@T/0ET=<05Q8D01JAdh0ET5:05Q1C01MBU00
I4mE07=MH020If/0S7=b08mgM@2?OgT0TXEo0926O`23OW80L7A[06UbK@1RJfT0EFQZ061`M01DJF`0
CfAT0761O01`OWh0Kgj107N6Q`1lSHd0PiFF092PX`2IYjT0[8^C08hN:P2_3aT0^0`A0;@;402^3AL0
SCY@092O]02EZ:l0WK6i09Zb_026Ykh0IXVZ02U;N`1kRJ<0SUY`08<E:@2?1A80SP8;08H12@200@T0
O`8808D22@211@`0Ma/U06DZ?01@:Cd0FbLf06D63@1X0PD0EaPU010H;@1>Jfh0C6UY01PaC@013cl0
0@Th008:<`076S809dM=028g=`0BdPl4003o00P0oooo1`00o`020?n000030>QX?02P8?00X23`01l0
X23`00<0^3Rd0?n0003oP0000`3oP0000`3XJ3`0X23`0:0Pl0060:0Pl0030;Ph]03oP000oh0000H0
oh0000@0j6Pl0=1@N03@D7P0d51h0P3oP0000`3@D7P0X23`0:0Pl0080:0Pl003052@N000o`000?l0
00800?l02`3oool000X0oooo05P0@jT=03/F2@0M0@405P4201L10@0J0@406P4002X20P0l0P80AP41
05@20`1K0@D0H@4606P11@1X0PH0I`@:06831P2110X0R@@:08@:3@2CJ6D0b/k?0<_Be@26U9H0N8J2
0<oCd@2fWJ@0S3<j08P@5@1=2@/0;1/K07EkN036cl`0e]3F0;n@VP2[=Sd0_Q<H0;d?4@2n3a40a0hB
0<4D5P28>c`0/Jn^0=OKg03Gg=h0e][L0=CAe@3DcmH0em[N0=3KfP2R[JX0ABl`05dC5`0_20T07a`J
05=QFP2/^K<0cmKG0<33b02;KgT0LaLP08D5302810/0PP<907l2201o0PT0O`4808032P1l0@X0L@46
06T10@1`0@<0O04408821`1j0@@0P@8508`21`2E0`X0U0<:09822@2310T0T5UM01031P030@402P40
03H30`0o0`403M812@3oool00`20`000oh000?n0000A0?n000030=1@N02P8?00X23`0080X23`00<0
j6Pl0=1@N03XJ3`00P3oP0000`3@D7P0X23`0=1@N0080?n000030>QX?02P8?00oh0000D0oh0000/0
j6Pl0:0Pl03@D7P0oh000>QX?03@D7P0X23`0;Ph]03XJ3`0X23`0;Ph]00E0?n000040=1@N02P8?00
X23`0=1@N080oh0000<0P<000?ooo`3oool01P3oool7003o000W05=U1P1I9AP0LUiI06IKFP1HAdT0
DBL_05Hc>P1E@d/0FDI?05I0B@1G@D/0GDY@06QCF01aGV00OFIY08UbLP2>N7L0TH1m08j1O@2;PGX0
OgQ]07UjKP1hNg<0Lg]f04IIF`13G5l0Af5Q06=eM01bOgd0JWYk06n0P`23T980Q9>D08JFU@2?X:40
UjVZ0:bY[`2^O8L0WB4[0080]0/B02D0/@TA0:<<602HDf80`<G:09ne_@1aTJ80Q9n_09JV]P2HOY40
R2Lh0987502A0P`0T08;08l2302;0``0OPD<084;4P1o0`/0K2i301hXF@0E<F80:D5T04HkD01N1`l0
HP@703`Q=@0:8Cd0C6Y`04mXJ`055S/00Pe0004;=`0E;D@0=5QG03mOE`0W?cX07k4I00@00?l0203o
ool7003o0080oh000`2P8?000`3@D7P0^3Rd0:0Pl00M0:0Pl0030=1@N03oP000oh0000<0oh0000<0
d51h0;Ph]02P8?000`2P8?000`2h>;@0j6Pl0?n000070?n000030=1@N02P8?00X23`0080X23`0P3o
P0000`2h>;@0X23`0:0Pl0080:0Pl003052@N000o`000?l000800?l02`3oool000X0oooo05P0@ZX?
02T60@0K0@405P4101`20P0F0@80504002/20P0m0P80BP4205P10`1M0PD0H`4606`2201_00P0M`4:
07d32P240`T0RP@;084;3P2PPGl0cM;C0<SAd`1ePh40a<_;0:VNX`1U:c80CPlB028=3P1GH5`0Z;Jb
0<kEe@3Ca</0ZeMT0:XJ8@2k4Q@0^`lB0;`?4@2m3Q00`A0@0;L];@34[J`0f=cL0=SLgP3FdMH0/7N1
09`jA02L<T00X6=b0<g<dP3Efm`0WjFX02hg>01^OGP0YKF]0<OBc`3=cm@0WX:;07`e?P1i4AP0N@<8
07h320241@T0PP<808032P1n0PP0O@4707h2201k0PX0M08606h10`1d0P<0OP8407l11P1k0P@0O`45
08T21`2C0`X0U@<:09<22@212@`0L4A500T00@020@403`4103L20`0m0P004L812@3oool00`20`000
oh000?n0000A0?n00080d51h0P2P8?020;Ph]080oh0000<0d51h0:0Pl02P8?000`3XJ3`70?n00003
0=1@N03oP000oh000080j6Pl0P3oP000102h>;@0j6Pl0?n0002h>;@30:0Pl0040=1@N03XJ3`0^3Rd
0=1@N1H0oh0000@0j6Pl0?n0002P8?00d51h0P3oP0000`20`000oooo0?ooo`060?ooo`L00?l004h0
F6X;05h/7P1ZDD`0K5]K05`c=`1D3180F2@Y05@oB01GATl0ET1805Y4B`1MBDh0KeaP07QTJ020IVX0
QVa_08Y`LP2>O7T0T8Im08V2N@1mNFl0NWU_07anM@20Pgd0Lg]h06YgL`1/NW@0LGag09BSW`30c<d0
U:6T07n=SP2GZ:P0Sj6P08bMX02?XZD0VJRZ0:VZ[P2TKG<0ZA8J0;D<4`2a2A40[@L?0:<>6P2WHVd0
X:J/09Rb`P2<UJX0U5M[08d@8@2G1100V08<09D33@2;0P/0PPTA07TZ<`27A4`0NPhH06hN;00P95D0
@F6<06ElR`1^F600HPlI06T2201S9Rd04a`k03=CJ01>K6h0Dfa_00hP?P0<8D<05Ba603iPH`13He`0
@5iG028k>`0XWbL4003o00P0oooo1`00o`020?n000050;Ph]02P8?00d51h0?n0003@D7P07`2P8?00
0`3@D7P0oh000?n000030?n000050>QX?02P8?00X23`0:0Pl02h>;@01P3oP0020>QX?0030?n0003X
J3`0X23`0080X23`00@0^3Rd0?n0003oP000j6Pl2`2P8?000`1hF;@00?l0003o0002003o00/0oooo
000:0?ooo`1803^N2`0Z0`406`4101H10P0G0P404`4101810@0V0P80@P8304`10P1E0@80F`4406H1
201/0@P0LP4:07d32`240`d0QP<;08D32@233140Z8V:0<[@dP2c_;h0ZkBd0<;:c@0_=cX07AhL03m7
A027Ti00a/g>0=KDf038Z[<0XS]60;0B5`2g3a40]Pd?0;L=4@2k3A80_`lB0;h@4P2oEeP0d<[;0=[K
g@3If]h0S71h084M9`1n4AL0HPdA038=5@1KI6d0bMCH0=7Jf`2ia<40cmSH0<gCeP2dZK00QTmL07DF
801g3QD0M0XA07<93`1h0`T0O`@907l3201l0@L0N`8707h11`200PT0OP<;07D11`1d0@@0O0850P1n
0P@03P210@@0PP4408L21P2@0PX0T`8:0902202161/0F3Hi00L10@030P80604203d20P0m0P004L81
2@3oool00`20`000oh000?n0000A0?n000050=1@N02P8?00X23`0;Ph]03@D7P0102P8?00103@D7P0
oh000?n0003XJ3`80?n000040>QX?03oP000oh000:0Pl0<0oh0000T0j6Pl0:0Pl03@D7P0j6Pl0=1@
N03XJ3`0d51h0;Ph]03@D7P0603oP0000`3@D7P0X23`0:0Pl0030?n000030830003oool0oooo00H0
oooo1`00o`00CP0eU`@0FRDE0719A@1[=cT0GQ8D058D5`1G=3H0Dd1705M3C01IA4d0FD=;061=E01a
H6<0O6U[07]RIP25JV`0Q6Y/08MbL@2=PW/0RWmi07igL01fMVh0N7U_0861NP1lPG`0N85n07R4O@1c
PG/0/LC40<OHg`2O/;P0O8n@08>EU@27VIX0PY:G07jBU@2HZ:`0WJZ_0:RWZ`2G@dX0ZP`D0;493P2a
2@l0/0TA0:4?6@2SGfX0S7V808L`A@2I21H0V`@>09P23@2D0`d0R0LA074S=P16=f40Cc]P07PG:01b
5240=2UD02Y6MP2=V:/0M49E07895P1e0PP0LP<806H;501B;3P0G6EX05=/J@1BJVX0>EEJ04IUIP0c
CEH0=UIM04MVH011GU/05C4b039o<`@00?l0203oool7003o00040830003oP000d51h0>QX?080oh00
00<0^3Rd0:0Pl02P8?007P2P8?000`3XJ3`0oh000?n000030?n000030>QX?02P8?00j6Pl00D0oh00
00<0j6Pl0:0Pl02P8?000P3XJ3`30:0Pl0030;Ph]03oP000oh000080oh0000<0d51h0:0Pl02P8?00
2@2P8?04003o00/0oooo000:0?ooo`1H03JI1`0W0P006@0001H10@0H0@405@4100`0000P0040@@83
04d10P1F0@80FP4406D11`1Z0@H0L`8907/22P200@X0Q@8:08H42P242a80YGn20<W?d@2j`l@0a<_=
09^TY`1HIV80Q92:0:nh]03?e=D0c<780:elQ`2K<3`0/14G0;L?3`2f3A00]@h@0;@;3P2h3Q40]Pd?
0;P>4@2oGf<0dM3C0=OKgP3>dmH0<cLj01D72P0?1@H04ADF055RH@2DYJD0_l_;0=CMgP3Cg=l0];k6
07I`NP1D;c/0@@`F02L11P0K00806`4202T2101C1P`0L0@;07/22@1h0PH0MP4507X11`1m0@P0O089
07P1201k0@L0O`8607d10`1o0PD0PP8608@11P280@L0S0480902202<0PL0ScDf044/;@0300400P01
01/10@120`<0?P4001710@T0oooo00<0P<000?n0003oP0004@3oP0000`3@D7P0X23`0:0Pl0050:0P
l080d51h00<0X23`0?n0003oP000203oP0001@3@D7P0oh000=1@N02P8?00d51h00D0X23`0P3oP002
0:0Pl0030=1@N03oP000oh0001L0oh0000<0d51h0:0Pl02P8?000`3oP0000`20`000oooo0?ooo`06
0?ooo`L00?l001T0>Zl805HR3@1e?c`0Ja`M06L];@1B<CD0DCa305=1C01G@dd0ET9<05Y5C`1NBU<0
KeeS07]XKP1jIFT0PfMZ08ERH`27KfT0S7mh08InM`1lMW40MGI^07MkLP1bNg<0N89l0080MWmk03<0
MhJ208BDUP2DYjd0LhJ;07V;S@1nT940OI:E07N=T01kSi@0RinR09^][`2EY:P0Vi6D094Y<@2Z2Q80
/`/C0:d8402U3A<0[CQ109TN:`2K1Q80W@<;09/43@2C1Q40Na`/04leF`0F9V<0A3U_07TE;P1k41h0
B2eF01<SH01ZFWP0L1h^07X44@1n0PX0N`8:07@1201]0@H0H`@705LT9@1JHV00CVMU04eYI019If80
>eML02e<D@17IUh0A69L02m=B011GCl01000o`080?ooo`L00?l000<0P<000?n0003oP0000P3oP000
0`2h>;@0X23`0:0Pl00P0:0Pl0030>QX?03oP000oh0000P0oh0000X0j6Pl0;Ph]02P8?00X23`0>QX
?03oP000^3Rd0:0Pl02h>;@0j6Pl1`3oP00:0:0Pl0@00?l02`3oool000X0oooo00<0<iH602X50`0I
0@400P0H0@40700E0P80404202410P110P<0CP8205P1101N0@D0I@4506/11`1a0@P0NP<:08022P25
0`X0R`H;08T9402HGV@0b<[>0<S@dP3<d]@0Z[Bc0;W3`03;d]80cLkB0;^MY`2MAU00WQXS0:dA5`2c
3A420;<=400e0;8=3`2d3Q00/PdA0;L@4`2j4AD0^4aB0<o8c03Eg=h0d]_J08NGU@1[NgT0NhZ809f]
Z`2kb<L0cMSH0=;Lg@3Cg=h0XZjd02/mAP0=5QX04Q<E020T9P0_>CT0=D4o038n>`0R:BT050P:03/5
2@1Z1@/0N@4807T2201j0PT0N@8707`22@1m0PT0O`8807h1101m0@@0O@0307h110250@L0R04808/2
202=0PL0R@@808`m?P0/7Ah00`4200H10@0Z0`D0A0<404010@0B`P402@3oool00`20`000oh000?n0
000A0?n000030=1@N02P8?00X23`00<0X23`0P3@D7P20>QX?0/0oh0000<0d51h0?n0003XJ3`0102P
8?001@2h>;@0j6Pl0?n0003oP000^3Rd00P0X23`00<0d51h0?n0003oP0004@3oP0020:0Pl0050=1@
N03oP000oh000?n00020`000203oool7003o001>02?C1P1M9A00J1dH07@]:P1W=cL0CQ/N05Hg?01D
@d`0ED9=05I3BP1PBU<0HDUA06eIG`1nJ6l0O6EY07i:DP1n;S00SFMS08QmN026OWH0NgQ_07QhL01`
N6h0LGUd07V1O01eP7`0Mh=k07n;R@1kRXX0P92?07>5QP1cQHL0Q96E08:EU`20U9@0NHb?07N<S`2D
ZJX0W;2`08nQXP2RSi80UR8[0;<=5@2X3a@0^3]20:<D802Y2180X@<<09T33@2<5B80IcQJ01h^IP15
HiX0JUEk088F:P263ah0E3=J01hQH01M:Th0M`TI088330210``0O@4;07d22P1f0PP0K`4606P2101D
1P`0@CY304YWIP1;JFD0BFIQ04MTH@15I600AfAN04QSG00oFE00@U=71000o`080?ooo`L00?l000<0
P<000?n0003oP0000`3oP0000`2h>;@0X23`0:0Pl0060:0Pl0030=1@N03oP000d51h01H0X23`00<0
^3Rd0?n0003oP0001`3oP0002@2h>;@0X23`0:0Pl02h>;@0j6Pl0?n0002h>;@0X23`0;Ph]0090?n0
00X0X23`1000o`0;0?ooo`002P3oool0F00`UP@0>AH?01@10@0D0@805`8200l10@0>0@408P410481
0P1@0@<0E`0305h20`1T0@@0K@460782201h0PT0O`<;08@22P2910T0RPH;08L/;`2aZZ/0a/g?0<cA
e@3:b<d0`:jg0:Z0R@2IBE@0UAHP0:<<4@2]2a00/0/@0;8<402a3140/@dA0;<>3`2b3Q40/`dC0;H=
502i3QD0[aTR0<B7T`3Id=P0emcQ0=OMh03Dg=`0e=gL0=;Lg`33d=H0UJR`09Z^/@3@g=d0U:BT05]]
K@1hRHL0V:RU0:bj^@2g`l<0^lO40;_6a02Z^KD0NHN602h_<@1420/0M`<907L11P1e0@P0MP4807/1
1P240PL0Q@8608421@230P@0OP4407d11@210PP0Q`4808T21P2:0@P0PP<9099@D`0F1PT00@0100`1
0@0j0`D0C@8404<2000B`P490?ooo`030830003oP000oh000180oh000P2P8?000`2h>;@0X23`0;Ph
]0020=1@N1<0oh0000D0j6Pl0=1@N02P8?00X23`0=1@N0050:0Pl0030=1@N02P8?00^3Rd00<0X23`
4@3oP0020=1@N0030:0Pl03@D7P0oh000080oh0000<0P<000?ooo`3oool01P3oool7003o001?02[I
2P1L7PH0GA`E07m?BP1M7Ql0F1hP05Dj?P1F@dd0E41;05Q5B`1PBE00HC]706a3C@1fDeT0Nf=X08AG
G@1h92@0Rf9M08AfLP25O7L0Mg=[07IeKP1^M6d0KWA_07EkM`1kPh40Mh5m07f;R@1fQXH0O8^;06j2
P@1]PH<0RIVM08nQY028VYh0M8R;092TY`25VYd0Vjnc09f_/`2a`<80/IFM09dW;`2o?480ZATT0:d9
4@2`2A40X0L?08DV=P0k=VL0:4j608NVa`2CLX`0S1@V08T>6P1M=el0<31Z06PS@0211A00Q04908H1
20220`T0M0D<06/;4P1_4aX0K`<:06T21@1C31<09R8g04IWJ@1:JFD0BfMT04QVG`18If00AVAN04IR
F`10GUL0;DLn017A3@03003o00P0oooo1`00o`000`20`000oh000?n000030?n000030;Ph]02P8?00
X23`0080X23`0`2h>;@0102P8?00d51h0?n0003@D7PG0:0Pl0030;Ph]03oP000oh0000@0oh0000D0
j6Pl0:0Pl02P8?00X23`0;Ph]0020?n000030;Ph]02P8?00j6Pl00X0oh002P2P8?00101@T7P00?l0
003o0000o`0;0?ooo`002P3oool0@P0cW0@0>1/A01810@0?0@404@4200`1000?0@409`8204<20`1A
0@D0F00405`10P1V0@D0K04607<2201h0`X0P@@<08D2302:10`0RPH=08Tk?02^/:h0b=;B0:6FW02=
=T80VQ`S09lA5@2V3180Z0P@0:X9402_2`l0/0/@0;4;4@2b2a40]@hA0;D=402g3Q00^0hB0;T=4P2k
41<0^14F0:TH902X@E40]7:20;n@W`2]RiL0R86;04mOJP0T>T<0AeiQ0;2o`03GgMl0bM3B0=7JfP3B
f]X0dm_M0=7If`3Af=/0cmSJ0<oGfP3?eMP0bmCF0;K1_`1P@400L0H;07@21P80L`4501@0OP<708T3
20280PD0P`8508D220220@H0OP4607l11`2500H0RP4808T2201i2P`0N4iA00`310040@804P410442
10190@80@@4001;20@T0oooo00<0P<000?n0003oP0004@3oP0001@3XJ3`0X23`0:0Pl02P8?00j6Pl
01@0oh0000<0d51h0:0Pl02P8?000`2P8?000`3oP000d51h0>QX?0040?n00080d51h00@0j6Pl0:0P
l02P8?00d51h403oP0000`3@D7P0^3Rd0:0Pl0040?n000030830003oool0oooo00H0oooo2000o`00
CP1R8@L0HBPO07</:P1V<2`0FChn058oA01A?TL0Dd1905U1C@1R?dT0HATT06HF7P1]<SL0Ic]1081N
HP20EU@0QfYW08AeK`27OGL0NW9/07YhL@1aMW00KgE`07AkMP1dNWL0MX5m07F2P01cPH40NXV807>4
P`1/Oh00PiJH08RKW`29Vj00NXnD07R<TP2HZk00V:Z`0<GIg`2[_L@0]lG:0;>1S@2]7BT0/`XD0;8:
3`2X3Q40[3@h06I1H01=N:L0[l?I091PN@2@4R80TA4M05hhG@0Z<Vl0LRI508H43`240@T0P`8:07`5
3P1^7BL0CRm602`/D`19>eT0H`PD06@83@1::CH04B4i045TI@18If40C6MU04YXH@18JF80AfIQ04AS
G010Ge<0;4]101K950<00?l0203oool8003o00@0oh0000<0^3Rd0:0Pl02P8?000`2P8?020?n00004
0>QX?03@D7P0X23`0=1@N1T0X23`00<0d51h0?n0003oP0000`3oP000102h>;@0X23`0:0Pl02h>;@2
0?n000030;Ph]02P8?00j6Pl00@0oh0000@0j6Pl0;Ph]02P8?00X23`0P3oP00;0:0Pl004052@N000
o`000?l0003o00/0oooo000:0?ooo`0e03NO1`0U2@403P0100/00@0?0P403@4100h0000W0@40@@42
04h20P1H0@80G04306<11P1[0@D0L04707H22P1n0`/0P04808P630231PX0RU9C0;[1`@37d=80RWn1
08PE6@2V2Ph0Y`/=0:P93@2]2A40Z`L>0;8=4`2`2Q40/@`A0;0:402`2Pl0]0d@0;T>4@2l3A80_A0C
0;/@4P2c3a<0[`dD0:/>5`2T4Qd0SadZ04L@700A2Q<062LZ08RGU`33cld0dm_M0=OKgP3Gg=h00P3E
g=d20=?Kg@0A0=?Jg@3@f]`0c]OJ0<kFf@3:dmH0bM?E09:6QP1U20d0M@<807811P1c00L0P`<908T2
1`250PD0P04607X41`230`P00P1n0@D030270PH0R@4708L21`1g4aH0LEIF00L310040@406P8304H3
0`1:0P80@P8101;20@T0oooo00<0P<000?n0003oP0004@3oP000103@D7P0X23`0:0Pl02P8?0F0?n0
00@0X23`2@3oP0020=1@N0<0X23`403oP0030:0Pl0@0oh0000<0P<000?ooo`3oool01P3oool8003o
001>074d3P1K7A80Kc0X06I9@`1BA440Cd1404lnAP1H?DL0GBPd06HX<@1U6B00Gb8W06Y9B`1XDE80
N6IV081]K@26LG00QgMa08V0N`22Ng<0MgAZ07=hL@1eNgL0MWah07MlN01fOg`0L7]i06elNP1]Ogd0
LhF50720P`22TYD0QIJK086DV02BYjX0QijT0:6g_`2H[;<0W[6h0;c=d`2h];l0Y3Y=0;T=6@2f2Q<0
Za<G0;Hj?P2P5Ql0NS5:07:2XP2:C6@0T@dO08hF8`1F=f005C5c06<iH@281QH0R`8;08422P1`51h0
Cc5<01XVE`0N<f40AT1P064K;`1_0`d0I@P>050L9@0n?TD0AVAO04QUH019If<0B6MQ04]ZI01:J680
B6IM041OE00VA3d08ZTQ0`00o`080?ooo`P00?l00`3oP0000`2h>;@0X23`0:0Pl0020:0Pl0050=1@
N03XJ3`0oh000?n0002h>;@0702P8?000`3XJ3`0oh000?n000030?n000030=1@N02P8?00^3Rd0080
oh0000<0^3Rd0:0Pl02h>;@00`3oP0000`3XJ3`0^3Rd0:0Pl0020:0Pl0040>QX?03oP000oh000=1@
N0X0X23`00@0D91h003o0000o`000?l02`3oool000X0oooo05P0;iH401h20@0@00006@D501@20P0>
0@403`4102H10P110P80B`4205410@1J0@@0H`4506`21P1a0@L0N08;07d32P2110`0P`@:080:3P2@
IfH0`lc=0<SCd`2DV9T0IA0D0:H=4P2W2`h0Z@X>0:`9402^2100/@XA0;0:402a2`h0]0dA0;H?502h
3a@0_0dC0;d=502m3Q<0^a4F0;0>4`2/3a<0XQ@G07`?500f2@`0=cLj071nO@2^^kX0cmSH0=OMgP3E
fmh0eM[M0=GKg@3EgMl0eM_N0=KKgP3EgMl0dmcM0=?Kg@3Afm`0cmWJ0<cDf039d]D0YJ2S064<4P1d
0`P0M08807P21P280`T0R@8708H11@250PL0K08407H320200@H0P@4508H21P260@L0PP<7084X:@19
;2d00`4200@10@0L0P<0BP<504D10P0n0@004L412@3oool00`20`000oh000?n0000A0?n000040=1@
N02P8?00X23`0:0Pl1@0oh0000D0j6Pl0;Ph]02P8?00^3Rd0>QX?00;0?n000040>QX?02P8?00X23`
0:0Pl100oh0000<0d51h0:0Pl02P8?00103oP0000`20`000oooo0?ooo`060?ooo`P00?l004h0E6T6
05LS4@1X>c80HT4k05I4@`1A?400Cbhf05DI8`1L51T0J3Dj06DoA01SATl0IDiF05i<E01jJF`0OfY]
08UaM02<NWP0Rh5n08J1NP1oOGD0MGQa07IkMP1eNWL0MWej075lN`1^NgX0LWmo07:2OP1XNg`0Jgn1
08:FV02<X:@0R9^P09:UZ`29WJ<0R9^R0;k@eP2W^Kh0];c40:5MJ`2^4Qh0^PdE0:dF702j?dH0Z1@O
0:P84@2M<Cl0PR]009<=6P2982l0ACQY02E>RP25U;@0N1@X09033`2810d0Kb8`02hYDP0D:E`0D55`
070gB01]2QP0M@8:0741201]0PH0I08505@M7@1;GeP0AFEN04]YH@19J680CFUU04]WI019IV80A65H
02e:@`0/MR`3003o00P0oooo2000o`030?n000080=1@N02P8?00X23`0=1@N03XJ3`0oh000>QX?02h
>;@M0:0Pl0030=1@N03oP000oh0000@0oh000P3XJ3`00`3oP000j6Pl0:0Pl0020:0Pl0040>QX?03o
P000oh000>QX?0<0X23`00<0d51h0?n0003oP0000`3oP0000`3XJ3`0X23`0:0Pl0080:0Pl0<00?l0
2`3oool000X0oooo05P0;Y@102D50@0[3`h0DcXj00h10@090@403@4002T20@130P80C08305810P1K
0@@0I@4506`2201/0@H0M@@908062`231@`0Q@D<07/:402KOgd0b];D0<SCd`2b_kh0?QXM09/@5@2W
20d0Y`P>0:`:3`2`2Pl0/0X>0;8;402e2Ph0^0d@0;H<4@2g3A80_@lD0;h>503041H0]PdC09l?501/
3a<0<`P:03@^;P26Ti40a]7B0=KNh03FgMl0e=gN0=CMg`3Efmh0em_N0=?IgP3Cfmh0e]cP0=CIgP3C
em`0c=3E0<_Cf@3@fMh0dM[L0<oHfP3<dmH0UXN;06L:401e0PL0M04607`11P270PL0R@8808X22@2<
10T0Q@@808@4202<0`X0R@4808T11P270PP0O0H908Q1@@13:2/0104100L10P0Q0@80C`@404L20P0k
0@403l412@3oool01020`000oh000?n0002P8?0@0?n000050;Ph]02P8?00X23`0:0Pl03@D7P04@3o
P000103@D7P0^3Rd0:0Pl03@D7P;0?n00080d51h00<0j6Pl0?n0002h>;@00P2P8?0?0?n000040>QX
?02h>;@0X23`0:0Pl0@0oh0000<0P<000?ooo`3oool01P3oool8003o001>05Q]2@1K:1X0F1<?06Ll
=P1C@T40DSLj05DT;01I92T0GcXo06E=E@1WDEL0JU=L065<E@1D@T`0NVU^085[KP2:MGL0R7Yk08^4
PP25Pgl0RXZ507UkM01cMg80JgMe06EeM@1[NGH0LGah06agM`1]P7d0IGYi06YnP`21UYP0OiBE08jS
YP2?Yj/0//G<08^MYP2DYjh0/L3509V1RP2J62H0]PlF0:@M8@2cBU80Y`lM0;<:4`2Y1a00Z2/d08/A
7P1l;D@0<CI^03UPV@2]c><0UhRI08P?7P2@0`d0NbDe02XUD@0b;U/0IC5:07<>7@1m0`h0N@4:07D2
201`0@L0J`4506@10P1C3aD0;ca404=TH@18If<0B6MT04UWH`19IV40B6IQ04ASF`0cCTP0;6`a0`00
o`080?ooo`P00?l00`3oP0001P3XJ3`0X23`0:0Pl03oP000j6Pl0;Ph]1h0X23`00<0^3Rd0?n0003o
P0001`3oP0000`3XJ3`0X23`0:0Pl0020:0Pl080oh0000@0j6Pl0:0Pl02P8?00d51h203oP00:0:0P
l0<00?l02`3oool000X0oooo04D0<IL303`F401O?cl0HDmA00X10@090@403P4002T20@140P<0C@44
05H21@1L0PH0I@4606`22@1W0PL0L0@908073@241@/0QPD:07T=4`2QRH`0c=;D0<O@d`37d]<0Ce1A
06L>4P2R3140[0X@0:d93`2_2Pd0/PX=0;D;3P2h2`l0^`dA0;T<402j3A00_0lA0<0?5@2h41H0TA0E
03`92`15AT<0SIZE0<;<bP3Hg^00emkP0=KMg`3EgMl0e]kP0=GMg`3FgMl0e=[M0<o>e@30[KX0[8VG
09MTM@27@U@0MS];04HhA@29Uih0cm[L0=3If`2k^[l0KSPo07L52`1h0PL0OP<:08D32@2:0`P00P29
0PP04@2:0`T0SP@709042@2A0@X0T`<:09H52`2C20h0O1DG09MUJ00C10D00@4100T10P0Z0P<0C`82
04D10@0g00003/0100T0oooo00@0P<000?n0002P8?00X23`403oP0040:0Pl0030;Ph]03oP000oh00
00d0oh0000@0j6Pl0;Ph]02P8?00d51h203oP0000`3XJ3`0d51h0:0Pl0030=1@N080X23`00@0^3Rd
0>QX?02P8?00d51h3`3oP0020=1@N080X23`103oP0000`20`000oooo0?ooo`060?ooo`P00?l004h0
@i8605TN3P1I4@/0Id4h05Ho>`1=:bd0Cb0W05Xl@`1IAT`0GdeD06ICF01/EF00Je=N06IDG@1hJFh0
Pfe_08I`L`24MGD0Q7ai08R4P@2>SXX0PhIo079fLP18Fel0=U5F061cL`1aNWL0K7]j06IjNP1WO840
AVAc08>IW02DYjT0W[2g08JHXP2K[;@0_<[B0:Jh_`2i_/L0SS]:0:L>602R7b/0HdM]07i6HP2W2QL0
[PL?0:P84@2L=D00GSmR01/dLP1RR[H0^MGW0<3Eh02OVJH0OaHU08P64020>Td0IRQ307H;7@210`l0
P`8<07`22P1b0PD0J`@606`:3@1/0PH0IP84054G800L;Sh0@VAP04MVH@17If00BVMQ04UXG`1:IUl0
AVEK03mNC`0nE443003o00P0oooo2000o`001`30X000oh000?n0003oP000X23`0=1@N03oP000802P
8?001@3XJ3`0oh000?n0002h>;@0d51h00<0oh0000<0j6Pl0;Ph]02P8?00102P8?020?n000030>QX
?03@D7P0oh0000P0oh0000<0d51h0:0Pl02P8?00202P8?03003o00/0oooo000:0?ooo`1H02V?0@1>
;2D0IDM902<?4`090@40204101010@0X0@40A@8204d10P1D00@0FP4706H11`1_0@P0M08;07L33023
1`l0Q@H;08D72`1f2a40XhZ>0<[Be@37dM<0b=CE08FBS`0_1`T0TQ@J0:X;4@2_2Q80/`dC0;@:3`2f
2@h0^@`?0;X;402j2`l0_0hA0;d=4P2b4QT0Pa<J02l41@1BFeX0_/[90=WOg`3Kg^40f=kQ0=SNh03F
fmh0e]cO0=GLgP3Dg=h0emSM0<Fb^`2HGF`0R2Hf08lH902>4A`0MQ0J02l7300M8bH0U:BS0<oKf`34
b<h0NUUR074B6@1k0`P0O088088320260PL0R`<908P220280@P0SP@:08h52P2D1Pd0U@<;09D32P2O
1`l0VPhC0:A=C`1eBDd0404300L20@090000;@8205T410180P80>P4101n40PT0oooo00<0P<000=1@
N02P8?000`3@D7P>0?n000D0X23`3`3oP0000`2P8?00d51h0?n000080?n000030:0Pl03@D7P0oh00
00@0oh000P2P8?020=1@N0030:0Pl03oP000oh0000h0oh0000<0d51h0?n0003@D7P01@3oP0000`20
`000oooo0?ooo`060?ooo`P00?l004l0A:D905@E101R;B<0HTHk05@n=P1?>cX0DCm205=4C01FBDh0
GTeC06UCG@1_EF00L5QR06QHGP1VFUl0OV]_07YPI@24Lg@0Q7ah08^7Q02;RhL0SHj:07f0N`1EI6<0
CFEU06YhM`1_NWX0J7Ih06UkO`0nG6h0IHFB07^AU028WJ80QIVN0;oAf02CY:h0Z;[30:foaP2XU9h0
VaPU09`K9@1K?VT0:c]o08E3G`2R2QH0YPLA09/84P1V=5@09dj409FgeP2le^@0_=CP0;oCh02h`Ld0
PD=A08L4402610h0QP8=08L12P240@X0P@8<07832`1P5Ql0BR/g06H]=P1Y0`P0GPD703hN<00Q>dd0
AFAR04MSGP1=J6@0C6IR04QWG`15I5h0@f9K04=NEP11EdL03=`800800?l0203oool8003o00040830
003oP000oh000=1@N2<0X23`0P3oP0000`2h>;@0X23`0=1@N0030?n000030=1@N02P8?00X23`00@0
X23`00<0d51h0?n0003oP0001@3oP0000`3XJ3`0d51h0=1@N0020?n000030;Ph]02P8?00X23`00P0
X23`00<0D91h003o0000o`002`3oool000X0oooo05P0>H`405<`:00^5QL02`4200D20P050@803040
02P20P150P80C`4205<10`1F0@@0I04606d21`1c0PX0MP<;07l63`1m0`X0P0@;07@73`2OQ8P0bm;E
0<SBe038dmD0^<G302dZ:P1;2`d0Ua0D0:h:4@2`2Pl0/PT<0;L:3P2i30h0_0dB0;/<402k3Q80Z18H
05H;3`0]71`0JW9a0<;=c@3Hgn80fMkQ0=[Nh@3Ig^40f]oR0=ONh03Hg^40f=gP0<_2a`2FHF/0UC0l
09PC7P2H3A<0T0lE06/=4`0Z30h0@Te908nNW037dM80a=7E06=[L`126240L`XA07/21`241@T0Q`<8
08`52@2;10P0S0<:08d32`2>10/0P`4508X2202E0`X0V0@;09h84@2F7200diFH06m7B`0M0`H04@82
01`20`120@80G@8304P10P0i0@007h<12@3oool01030X000j6Pl0=1@N03XJ3`20:0Pl0h0oh0000<0
X23`0;Ph]02P8?000P2P8?000`2h>;@0oh000?n0000:0?n000030=1@N02P8?00d51h00P0oh0000<0
j6Pl0=1@N03XJ3`0103oP0001P3XJ3`0X23`0:0Pl03XJ3`0^3Rd0:0Pl140oh0000<0d51h0?n0003o
P0001@3oP0000`20`000oooo0?ooo`060?ooo`P00?l004L0;<L605HK1`1K6a40GB/T05Y2?P1=@400
D45605M6CP1LBE<0IT]B0710B@1_?D@0LUaR06aMH`1RE5X0NfI[06iDE`1kJV`0QGik08=oN`21P7/0
RXZ807QmO01cNWH0SiRE092IV@1bOh00JGYj05U`OP0RB6L0JXN<082EU`2K/;<0TjF]09>W[`2K[KH0
PiJQ0;_=e02VOHP0XaHR09e>G`1[BFd0Q2M20:DZ>02R2QH0W`PC08d?6`10=600NJ?20;oEgP31eMd0
`=;M0;oBg@2a_<P0McE508P440250@X0QP490882201k1@d0KQ/V04/]A00X:4X0AbU306@8501R2Ph0
D2Pg01<H>@0eF6<0B6IS04UVHP0204YXH`0604UXH@17IEd0AV=M04APF00lF4H05/PA0P00o`080?oo
o`P00?l000@0P<000?n0003oP000oh001P2P8?000`2h>;@0d51h0:0Pl00I0:0Pl0050=1@N03oP000
d51h0;Ph]03XJ3`0103oP0070:0Pl0030=1@N03oP000oh0000<0oh0000@0j6Pl0;Ph]02P8?00^3Rd
0P3oP0000`3@D7P0X23`0:0Pl0090:0Pl003052@N000o`000?l000/0oooo000:0?ooo`0Z055n300d
4``060<201L:2P040@40208100/1000U0@80AP8304d10@1B0080F@4506@1201]0PT0L@4:07L32`1l
10`0O@@:08032`1h1`d0T6U]0<cAe039d]@0b]?F0<_De@2;UI<04a4@058:3P2V3140/@X>0;<:3@2f
2`h0^0/>0;X=4@2e3a<0TA8E03`@4@1_MWD0^LG50=;Kg03Ign80f=kQ0P3Ign80;03Fg^00d][M0<7:
cP3Cfmd0e]?H09]EG`2K5Qh0X@dA09@?501M2`l0:PL902LY9P1^PG/0^/O40<oIfP3;eMT0UjJ^059S
I@0S92H0A@P=07X32P250`P0R`@908h5202;0`P0RP8808h21`2>0`T0Q04608d31`2H10T0V@H;09/<
4@2]EeT0VG9g058_=00i3A00808302d20`1M10H0J@8404/10P0j00007h<12@3oool30?n000030=1@
N02P8?00d51h00h0oh0000<0d51h0;Ph]02P8?000`2P8?000`3@D7P0oh000?n000070?n000040>QX
?02P8?00d51h0>QX?0D0oh0000<0j6Pl0=1@N03oP0000P3XJ3`40?n000060=1@N02h>;@0X23`0:0P
l03@D7P0^3Rd0`2P8?0?0?n000030:0Pl03@D7P0oh0000H0oh0000<0P<000?ooo`3oool01P3oool8
003o001?02SG2P1J8`X0EA/@06Hl<`1I@cd0E4=505M6C01MAD`0I3U306X]=P1j;cD0P3i507IOI`1a
HVL0KV5V07=PI@1bFEh0NfY[07]aK`1hLFh0MgI^08J7P@22R8H0VJFR0;2k`@2MZk40UjBX06QjOP0V
AFD0C6j707N<S`2G[:h0MXV?0;;4b@2EZ;40W;>k09B[]02H[K<0/9NP09XL9`2R72L0U1/W0:0nA`2S
;c`0V@PC09H74@21:Sh0735V0:S;g`30eMh0_MCM0;oDg@2nd]X0]<?>078mC@251A<0Q08<08043@1b
5b<0DRm<01lXE00X;EH0FB8h06/74P1Q3aH0?2Ln00LF>P0O?ED0BFUX04]YI017If80AfMQ04YYI019
J680A6AN04ITG@13HEH0?eY:02>X7@02003o00P0oooo2000o`001020`000oh000?n0003XJ3`40:0P
l0040=1@N03oP000oh000=1@N1X0X23`00<0^3Rd0?n0003oP0001@3oP0000`3XJ3`0X23`0:0Pl005
0:0Pl0060=1@N03oP000oh000?n0003XJ3`0^3Rd0P2P8?00103@D7P0oh000?n0002h>;@<0:0Pl003
052@N000o`000?l000/0oooo000:0?ooo`0k05Yc3@0h5@h0604101<20P0700001@4000X1000Y0P<0
A00105020P1D0040F@850642201Z0@H0K`8:07422`1f0`X0OP@:0884301o1Ph0ReEI0<K9c03<dMH0
bmCG0<gDe`32blX0Hfi[01X6202<3a@0[PT>0:h8302b2@d0]``?0:d@50233QH0;PL707F0N`3Bfm`0
fN3S0=KNh03Hgn40emoR0=ONh@3Fgn80b=KJ0:6a]@35cm40e]gP0;NKX`2C6R@0X0/A094B5@1720/0
4a4B04iOG026VI@0a]CA0<kHf@3<e]P00P3<emX06`32clh0RiNE04HT9`1l1`h0Q`8808L11P280PH0
RP<908L21@2<0`H0S`@809042P2C10X0U0D:09D6302B3Q80_7n108]XKP1VBdl06@8602P;300e0`D0
G@@406`20`1B0P<0?`4101j20@090?ooo`@0oh0000<0d51h0:0Pl03oP0003@3oP000103@D7P0X23`
0:0Pl02P8?020=1@N0030:0Pl03@D7P0oh0000L0oh0000<0X23`0=1@N03oP0001@3oP0001@3@D7P0
X23`0:0Pl03oP000d51h00@0oh002P2P8?000`3@D7P0oh000?n0000<0?n00080X23`1`3oP0000`20
`000oooo0?ooo`060?ooo`P00?l004l05nh605dS1@1M=2@0H4Pl05a7@01LADL0HCm606<V;`1[7RH0
Jb/b07Q1A`1hD5D0Lf5Y071QJ01_HfL0MVU/07eYK@1nJf`0MfaZ07A^J@1kNgD0QXZ508F=S02mbLd0
NX>906ikNP2GYJ/0Aeac00lcGP1ZQi<0MHN<09>XZ`2O/[P0TZN^08jSZ`2V^/80a]WQ09bd`@2?Z;H0
[9JL07EGM016Bg/0HEQn08@D9@2=1`l0R0`G04hbG013JiT0_MOT0<?Fg`2oeMh0_=?L0;kCg02lcmT0
K4UH07<84`1^5B80F35=028[FP0S?fl0KhjZ06=AH`1Q2aD0GBDc02TVB00<9dh0<5EX04UYK01=JFD0
BfQT04YZI01;JVH0BFMS04EWH@14IV00@F=K04=RF010GDl0;hHV00800?l0203oool8003o0004043P
003oP000oh000;Ph]0<0X23`00D0j6Pl0?n0003oP000d51h0;Ph]00K0:0Pl080^3Rd0P2P8?030?n0
00030;Ph]02P8?00X23`00D0X23`00@0d51h0?n0003XJ3`0^3Rd102P8?000`3oP000d51h0:0Pl00>
0:0Pl0800?l02`3oool000X0oooo05P0DVd=04h[900H0@004P4100X20@060@002@0002L20P1;0`@0
E08205H10@1I0@@0H@4406P11P1U0PH0F0<805h4201j10`0P@@<08453@27>3h0^;Fj0<_CeP3;e=L0
cM?G0<kFeP2f_kl0?T9304l;3P2V3a<0[`X?0;8<3`2[3a@0IP`A02lE6@1_MWL0bmGE0=[PhP3Hgn40
emkP0=OOh@3Ign80e=OL0:Nb^`1OMWh0]<C60=KNh03?a//0Tci:09HC6P1d3A40>@T:038g=025UI80
//2k0<WEd`3>fMT0cMKI0<gGf@3=e]P0cMKI0<_Ee`39dM<0RgMk07T;4`270`T0Q@8608H21`2;0`T0
R`@808`51`2>0`P0T`@:0902202>0PP0T0D908/O8@2YP880X86602hK800F1@/090D903P10`1Q10@0
J`<305410@0o0@408H<22@3oool01P3oP000j6Pl0?n0003oP000d51h0:0Pl0h0oh0000<0j6Pl0:0P
l02P8?000P2P8?000`3@D7P0X23`0:0Pl0060?n000030=1@N02P8?00j6Pl00H0oh0000@0^3Rd0:0P
l02h>;@0oh000P3XJ3`20?n000040>QX?02h>;@0X23`0:0Pl080^3Rd1P2P8?000`2h>;@0oh000?n0
000;0?n000040=1@N02P8?00X23`0:0Pl0H0oh0000<0P<000?ooo`3oool01P3oool9003o001>06Tf
3P1O@R`0GdTi06A5@@1Q;C80HadU06dM8`1X9bX0L4]A07=JHP1bHVP0MfM^079QI`1dHfP0NVM/08AO
I@1kCU40NfYV07]gL@24Pgl0S8n;07f7Q`2[^[h0TjBU09FSY01^PHd05BmN02mCMP1UOX<0[l;806n3
R`2HZk40TJB[0;C:d@26VZ80WK:j0;77d@2G]l`0Xl3I01Y4Q019Lj/0T5=Z09D=6P2B3QL0Mbi601Ta
I`2K`=L0`MKP0<;Fg`30eMd0_]CL0;gBg@30d]h0M6aj05@hB@0M9E803ReP03IMOP1kWJ`0MY>M07Z4
R`1?C5h03B9=0291H`19K7@0C6m]04i/JP1;JFD0CfYW04aZI@1?K6T0C6]U04IWH@17IUl0AFAN049Q
F@13GUD0=H8e0P00o`080?ooo`T00?l00P3oP0000`3@D7P0^3Rd0>QX?0030?n000030;Ph]02P8?00
X23`00@0X23`00<0^3Rd0=1@N02P8?005`2P8?00103@D7P0oh000?n0003@D7P90:0Pl0030;Ph]02P
8?00X23`01D0X23`0P00o`0;0?ooo`002P3oool0F01IM0l0@AlH01/00@0C0P802@4100P20@070@40
9@8204X2101B0@80E04305`2101T0@D0J04906011@1G0`L0AP8507042`1o10X0PP@808LD6@2YSY80
bm?F0<_Ce@3<dmH0cMCG0<kEf02Y]K<091dL07L?502W2a40WPlE05493P1ADE00/[jl0=;If`3Ign40
f=kP0=WNh03Hgn40f=SM0;BCX01_C5/0=cTo0::a/@3Gg=l0bkk609Q?FP225Qh0>P`<030_;@1]OGT0
/l;10<oIfP3@fMX0dMSJ0<kGf@3=f=T0bmGF0<gFf03:dmL0c=GG0<WBe@2h/[D0MQPO08/52P270`L0
QP8608X3202910H0RP8509<42P2E10X0S`4908h2202?20d0]71_099jO@2VUYT06`X?01P31P0/0PH0
D0@806/41P1Z0`<0D0420441000RQ0890?ooo`@0oh0000<0d51h0;Ph]02P8?003P3oP000102h>;@0
X23`0:0Pl02h>;@30:0Pl0030;Ph]03oP000oh000080oh0000<0^3Rd0:0Pl03XJ3`01@3oP000302h
>;@0X23`0:0Pl02h>;@0oh000=1@N03XJ3`0oh000>QX?03@D7P0X23`0;Ph]080d51h00<0oh000;Ph
]02P8?001@2P8?000`3@D7P0oh000?n0000;0?n000<0X23`1`3oP0000`20`000oooo0?ooo`060?oo
o`T00?l004h0K54@05a2;01QACL0I2PU06LJ7P1O6Ql0JCDh06M;C`1WEUh0KEeW07=SJ`1jIVh0NF1Y
07]AF`1l?dD0ObX^080f=P1oJVL0P7Ug08>5P02<TH/0SiFB08bCUP23Ri40KWZ004=GLP037UX0G7^B
07:9SP1_QXT0VZja09R^]02CYZl0TjZa0;K;dP2H/;X0[LGA06Z:[@1IRKH0SJW509^8X02K6b/0V@dE
07PS=P0/=FL0JXnd0<3Hh032e]`0`mKN0<CFgP32e=`0_m?M0;gAg02^_lP0VZjm02m@N`0hHX@0Fh6F
07VL[01dTYd0PYbS05egPP1SP8h0MI:G05=`L01=K6X0D6i^04aZJ@1;J6D0CVeX04m]K@1>K6T0BFMT
04ITG`15HUh0AV9J04EPE@17F4T2003o00P0oooo2@00o`060?n000030>QX?02h>;@0X23`00@0X23`
00@0^3Rd0=1@N03oP000oh005`2P8?00102h>;@0oh000?n0003XJ3`R0:0Pl0800?l02`3oool000X0
oooo0480DVh=01`20@0H0@804P8200T10@090P402@4002H10`180P@0E@8605T1101L0P@0H@4506T1
201`0@/0L@8:06h22@1h0`X0OP8808L4202E2Q00TT=;0;F[/@3;d]H0bmCH0<cEe`3<dmL0bmCD07Am
N`1C41<0QADJ04D<3P1RJ6H0b]CD0=ONg`3Gg=l0f=kQ0=WNh@3Ifn40bKG109UAHP1J6b@0ASho0::^
[03GgMh0`jRa08Hf@P1]5Ql0=1dM07V7P`2b`Kl0bmOG0=7Jg03@fM/0d]WL0=3Ff@3>e]T0c]OI0<cF
f03;eMP0b]CF0<[Ce`36d=<0]Zne07PG8@2:10X208X42@0D08h62`2@1P/0T`D;09H42`2A0PT0T`<;
09832`2771`0bZV/091lP01TEET0;aXO02442P0f0`L0E08507821@1^0P<0CP4204000@0QP`490?oo
o`D0oh0000<0j6Pl0?n0003oP0003@3oP0000`3XJ3`0X23`0:0Pl0030:0Pl0070;Ph]02P8?00oh00
0?n0003XJ3`0X23`0>QX?0050?n000070>QX?03@D7P0oh000:0Pl02h>;@0oh000=1@N0020?n00003
0>QX?02P8?00X23`00<0j6Pl00@0oh000>QX?02h>;@0^3Rd1P2P8?0<0?n000040>QX?02P8?00X23`
0;Ph]0L0oh0000<0P<000?ooo`3oool01P3oool9003o000E05Yi3`1O@BT0GRTO06@E3P1R:B@0IdM9
06ACFP1NDUT0I5IO06eOJP1dGFL0N4YE07djAP1i8R/0LQhP08I1?`1a?3/0O6UV07QeL@22Q7h0SI:<
0080SiN@03T0NGmk06YgO@0F;El063]`05ahP@2M[k00NHbB09^_]P2>XJP0`mCL08fR[02P]Kh0WKK5
07fO/02kdn@0DWfZ08bH]`2N=dP0YQ4M07hV>P0`>6T0CgRP0;cIi031f=l0`mWN0<;GgP32e=h0`MCM
0;_Cf`2mdm/0_];K0;W@f@29YKT0<eMg07>GZ@1GNXL0UK:m08VV[P21Vj@0NY:I065hOP1LM7L0E79_
051_KP1@KVX0BfYV04a/JP19JfL0CFaY04UWI@17I640AfIQ04QTG@18HeP0BE]>00SW1P00o`00203o
ool9003o00D0oh001P2P8?000`2h>;@0j6Pl0?n000020?n000030>QX?02P8?00X23`01D0X23`00<0
j6Pl0?n0003XJ3`08`2P8?000`0Xb3`00?l00?ooo`0:0?ooo`002P3oool0F01;I@h05`4001@00@0F
10@01`0000H100080@00:@8304P10`1D0@@0G0050642201P0@@0I`4607022`1f0P`0NP8<07d12P1n
0@P0R0<909d93P2<5Ah0[H:90<O9c038d]@0bmCF0<cBe@3?eML0^;fl05HW:@0^1@H0B4Y70<C>c03E
g=h0emcP0=GLgP3Hg^00f]CM0;F=W02E>4L0MAPQ04<j=P2O[j`0dmcM0=?8d02BA540IaLO02TB502<
VIP0b]CF0=?LgP3Afm/0cm_K0<oJf`3@fM/0d=SL0<kFfP3>e]/0c=OL0<WEeP39dmD0bM?G0<K?e02Q
S9D0O@hJ08/42P2?1@/0RP8908/32P2=0`T0U0H<09432P2<0`P0S@<808/62P2KC4d0VXF;0;2PYP1N
DUP0;ALJ02L5300l0`P0H@D907/41@1^0P80C`4304@10@0QPP490?ooo`@0oh0000<0d51h0:0Pl03o
P0003`3oP0050:0Pl0060?n0002P8?00d51h0?n0002P8?00d51h1@3oP0001P2P8?00oh000?n0003@
D7P0X23`0=1@N0<0oh0000<0d51h0:0Pl03@D7P00`3oP0000`3@D7P0oh000?n000080:0Pl0`0oh00
00@0d51h0:0Pl02P8?00d51h1`3oP0000`20`000oooo0?ooo`060?ooo`T00?l00300C8h:05lj801K
60d0IbDL06U;A@1NCDh0H5EJ05mCG01XEF00KdIA078b?P21@TL0Nc<i07U0A@1lFe`0PFa]07ISI021
MG<0OWeh08R;Q02>TH`0TIRB08nHTP1nQ8<0DF1c004KFP0cE7H0S:6V07J8SP2;WJ80TZN]0:>i`P2;
WZH0Y[Vo0:Bj`@2icMH0Tjg107BK_@1cS:l0WF5l0:HL:P2?@Ed0:3Ib05EnZ@2menL0a]WR0<?Hh@34
f>020<;Fh00N0<3EgP2keMd0^=CK0;SCg@2fd]`0OYZ/05=cUP15JX`0GX:D06j<W@1SP8`0QJ6X07jI
W@1hT9D0MHbA05agMP1DLFl0DW1/04]YIP18JFD0B6QS04aZJ@1:JFL0BFIQ04MUH017IV00Af9L04QO
D`0Gb1800?l0203oool9003o00050<2P003oP000oh000?n0002h>;@0102P8?001P2h>;@0j6Pl0?n0
003oP000d51h0;Ph]1P0X23`00<0^3Rd0?n0003@D7P0902P8?000`1@T7P00?l00?ooo`0:0?ooo`00
2P3oool0F00oG0/07P4102h<3@169BL03@8100L1000:0000;08404X20`1B0@@0F`470682201S0@L0
J04707032P1g0`X0M`8907X22@1o0PP0S@<:09l83`2I2a<0TSHn0;^VZ`3;e=L0bMGE0<[EeP3=eML0
/;bo02L_;`18De40[kfj0=;JfP3Efmh0e=cN0=OMh03Ca<d0[69`09`T<@2661l0@2DU09f/Y`3AgM/0
f=KJ0:9YM01N6R40?2d_08VCU03:e=D0e=cN0=?Kg@3Afm`0d=_L0<oIf`3Af=d0blkF0;6U/@2FPI80
LGB20:2^/P3<eML0bmGI0;nnb020Ae40QPP@08T32P2:0@T0S08:08/32P2;0`P0S`@908l3202<0`L0
R0D807`?3`2hRh`0PG1g0:bSZ@0Z92`0JemS02<62P0o10P0J0@808431@1_0P<0D04104H10@0RPP49
0?ooo`<0oh0000<0j6Pl0?n0002h>;@04@3oP0040:0Pl0050=1@N02P8?00X23`0:0Pl02h>;@0103o
P0020>QX?080oh0000T0j6Pl0:0Pl03@D7P0oh000=1@N03oP000d51h0:0Pl03@D7P0103oP000103@
D7P0oh000>QX?02h>;@60:0Pl0030=1@N03oP000oh0000X0oh0000@0X23`0;Ph]02P8?00X23`1`3o
P0000`20`000oooo0?ooo`060?ooo`T00?l004H0@JH705h/3`1V:Qd0JBhU068f<@1TC4h0I5AH069:
E@1/@e00LCa706`/=01gDEH0OF5V07aYK`1mLGL0PWEi07]YJ`1nLg80OG]g08Z:Q`2>THh0SiJ@08bI
T`20SI0093UV00TZK@1;KX00P9FG08:GVP2Q]k`0Ign40:_0a`2U]kh0[l7908bT/02^b=D0^<oN09B]
`02]RY/0WD9H06mBP00TAhL0N9o60<;KiP34f>40a]WP0<KJh@36fN80amSR0<CGh030e]d0_mKN0;_E
g@2ie=l0^=?L08ZV^`1=M940CG:=08JV]P1NOhl0U[>n082KYP1XPh/0N96H07VAU@1XPH@0FgMf05Ib
L@1?KF/0BVYX0P1:JFH0201:JFL0BfUT04YWH`19Iel0AVAJ04IPD`0UZB000?l0203oool9003o0003
0830003oP000oh000080oh00102P8?000`3XJ3`0oh000;Ph]00J0:0Pl0030;Ph]03XJ3`0^3Rd02D0
X23`00<0D91h003o003oool02P3oool000X0oooo05P0?5T:048K7P1R=C/0FcDj01410@090@403P41
02P20`150P<0D04305`21@1P0PD0I@4906X12@1`10T0L`8907H12@1h0PP0P@4909@53P2J1P`0WPL>
09P=5@2MEEd0alS;0<[EeP38eMD0//?702a3B@1PMG40`<k;0<oIfP3Bf=/0e=cN0=SHg@32XJd0VS=1
0:4G7`1`3a80@RPX0::`[03Eg]h0e<cC0:=XM@1L6B00I6=S0;S5a@3Ag=`0e=kO0=?LgP3DgMd0dM_L
0=7Gf`31/kd0WW6108XoD@1W6RP0<10H02de=`2EY:<0bmGF0:Nf_P13A500FQ8I08T52`2<0`/0S0<=
08/22`2;10T0R@8808/21`2>0`P0S@<908@9302DD4h0b[Ji071HG02ITIL0<adW03@L8P0J10L0=P83
06h52@250`L0KP4204l10P130@4088412@3oool20?n00080d51h4`3oP0000`3XJ3`0X23`0:0Pl004
0:0Pl080d51h0`3oP0020>QX?080oh0000T0j6Pl0;Ph]03oP000oh000=1@N03oP000^3Rd0:0Pl03X
J3`00`3oP0000`3XJ3`0oh000=1@N0020=1@N0030?n0003XJ3`0X23`00@0X23`303oP0001@3XJ3`0
X23`0:0Pl02P8?00^3Rd00L0oh0000<0P<000?ooo`3oool01P3oool9003o001@03Bl1`1O:100JC0Q
06HN501Z?SD0IE1>06M1A@1U92d0J2H]06Q0AP1YDUH0Lf5V07UYK`1dIFd0Ng5g085dN`1oKW80O6m`
085kO024Q8@0SI:=08nFTP2CWIX0MhND00LPH@0;:6H0SZRb09V//028W:80QYfQ0:o3a`2GZ[40[Kk5
0:k0b02kcmT0V;?409Nda02a_lH0/:Rb0724/009@Y/0Sl3T0<?Mi038fn<0b=[R0<KHh032fn80aM_S
0<GJhP32fN80`MKQ0<7Gh02meMl0_=?O0;[CgP2^a=L0:51e03MNP`1MPI/0L92N07jMY`25XZX0Uk6j
08NQZP1_RY00JXF805ikO01GLg<0DVe`04eYJ`1=JfT0BfYV04UXI01;Jf@0CVaW04YWH018IUd0Af5I
02fF:`00o`080?ooo`T00?l000L0P<000?n0003oP000oh000=1@N02P8?00^3Rd0080oh0000<0d51h
0:0Pl02P8?00@P2P8?000`1hF;@00?l00?ooo`0:0?ooo`002P3oool0F011G0X0Jd9504hS:`0c51T0
308100L1000=0@40;08304X21@1?0@@0E`4305d21@1R0PP0J@4806l21`1a0`T0L`8907T11`280`T0
U0@;09X52`2O1``0X@T?09@H7P2`U9L0b=CF0;G5b`0lDUP0GG1`0<C@c@3>emP0cmWJ0=;Jg@33[kL0
W59Q09XN:P2L51`0C@dA04a9B@2P[J`0eMcL0<2V[`2D@4h0KA/R06]VIP36dm<0eMoP0=GMg`3DgMl0
d]WL0=GIg`3;`<X0WfUh08LT<01k51h0C@XA02HM7@1QLVl0Y;>a0<WCd`33c]00RifR05]YK@0o8R@0
P@T>08h42`2;0``0RP<<08X3202<0`X0RP4908/22@290`T0RBh^0=Fk_02>P8@0TH:408J3R@0T5Ah0
7@L<02P;3P1710P0M0@808821@1a0P80CP4204L10P0SP@490?ooo`060?n0002h>;@0oh000>QX?03o
P000d51h4P3oP0000`2h>;@0X23`0:0Pl0030:0Pl080d51h00<0oh000=1@N03@D7P00P3oP0001`3X
J3`0X23`0;Ph]03oP000j6Pl0=1@N03oP0000P2h>;@50?n000030>QX?02h>;@0oh000080oh0000<0
^3Rd0:0Pl02P8?00102P8?000`3@D7P0oh000?n000090?n000050;Ph]02P8?00X23`0:0Pl03XJ3`0
1`3oP0000`20`000oooo0?ooo`060?ooo`T00?l005009MD7064X3@1W8QD0IR@J06i6@@1Y>Sd0J2<Z
06d_=01YAdl0IUIM06MIH@1bH6T0NFU`07]/L`1oLGP0OFaa08=^LP1lK6d0PGUh08F4P@2<THd0TINE
09NOWP1?I8T01RIe02A8N01dSIL0NH^B0;O;d@20UYl0W;>g09V]/`2ibm80Xk>m0;W=e`2<Z[/0R:^m
0;[DhP1GSKl0EiS@02IS[02MbnT0a]oT0<_Mi039f^40a]WQ0<SLh`39g>@0b=cT0<GKh`33f^80`m[Q
0<;Hh030e^80_]GO0;_Ch@11Ji00M9ji05R0W02F^<`0MIFW07ZFX`1nVJ80LhnE07jIW021Vil0JhJ:
05ejO01BKg00CVi[04i[J01;JVH0Bf]V04e[IP1>K6L0BFQS04AQF`14H5L0=H4d003o00P0oooo2@00
o`001020`000oh000?n0003oP0020=1@N0030?n0003XJ3`0^3Rd04H0X23`00<00?l00?ooo`3oool0
2@3oool000X0oooo01h0BfL>05lj>`0X1`X0600200T10@080@403P0002d10P190P<0C04305@10@1G
0@<0F@0506L11`1]0@L0K`<807D32@1i0@H0SPD:09X62`2M1P`0W@L=09l52`2P3A40UdiD0;W0aP16
FF<0:D140;K4a03<eML20<kFf@0h0<Via02==4<0X1@N0:0B601I30l0EEAD0:Vf]P3Bfmd0d<C<094h
B02>7RP0Ec4a0;o;b@3DgMl0e]kP0=GLgP3Cfmh0e=GJ0;ZQ/P2@AUT0RaPU05`?500N0@@06b0P07R;
Q`2kb/D0b=?C0<[Ee@38eMD0amCE0<OCe02<O7h0N`hD08l52`2;0`X0RP<908T1202<0PP0SP8:08/2
2@221@P0YFe[0<W1``1ZF5`0XIZJ06eZK`0K2a00:``B05/h>`1=10P0M`<708@11P1d0P@0D00104@0
000/H`490?ooo`040?n0003@D7P0oh000?n00080d51h4P3oP0000`3@D7P0X23`0:0Pl0050:0Pl003
0=1@N03oP000oh000080oh000P2P8?001P3oP000d51h0?n0003oP000d51h0:0Pl0D0oh0000<0X23`
0=1@N03oP0000P3oP0090:0Pl0X0oh001@2P8?000`3oP000d51h0?n000060?n000P0oooo2@00o`00
D00Qi0L0HbD606DS6@1_?C<0K34^06DR8P1Y=CH0JU1E06MIHP1[H6X0Kf5[07=QJ@1mI6d0PEIQ07Lh
A01oEe`0OU]N07eXI`24OG/0Q8>108R:R@2<Ti80TI^S01`fM0018GL0@VF:07nFW02EZK<0KXVB0:k6
b`2=Y[00Tjbc0:_0a02ndMH0a=CL0<kQjP2E`M/0NkSN07:Xe@2Zenl0/Mga09o@j@3Ai>/0dN7X0<kO
iP34f^40bMoT0<cOi@38g>@0amcU0<SLi036fn80`]SR0<7Fh`2oen80_MGV03MPV@16NZl0@Vj@08:T
^025Wjd0Y/3;09V`^`25X:P0PIbR06b7S01/R8`0HWj005QhM@1BLfl0D71/04a[J01?KFP0C6YV04e[
I`1<JVD0A6AN04=SF@16EdD00?l0203oool9003o00030830003oP000oh0000<0oh0000<0j6Pl0:0P
l02P8?00102P8?000`2h>;@0d51h0;Ph]00C0:0Pl0070=1@N02P8?00X23`0:0Pl02h>;@0d51h0:0P
l0020>QX?0030=1@N02P8?00X23`0200X23`00<00?l00?ooo`3oool02@3oool000X0oooo05P0Eg<F
048P7`0N0@4070<200`10P060@402`4002`20`150@<0AP4204l10P1G0`D0G`8806T11`1Z0@H0K045
07<22@1n0`L0U@L=09h63@2K1@d0W@L=09d7302O2@h0SAdU06aOIP0M<C@0R9VJ0<OCe03;eML0cMSL
0<2f`@2G@U40Wa@M09`@601W3180@cTk0;2j^P3Dfmd0dlcB0:9DHP2G7BP0DQDH09NGUP3Fg]l0eMgP
0=KNh03Eg=h0d/gD0:A^OP27;3/0MADR03l93`0V8B80CemP08bMW@30c<T0b]GE0<SCe@36dmD0am;E
0<OCe037d]@0_KZm074K8P2:1PX0Q`8708/4202:0PT0S@@:08l5202>1``0O14C0<6WZ@2g/;H0GdU>
0;6a/@2ATiH0;R<V01h73@0/3180C0@707L320260`T0M08405010@130@40=4@22@3oool01P3oP000
j6Pl0?n0003oP000d51h0;Ph]1<0oh001P2P8?000`3@D7P0j6Pl0?n000020?n00080^3Rd00<0oh00
0>QX?03XJ3`00P3oP0000`2P8?00oh000?n000020?n000060>QX?03@D7P0oh000?n0003XJ3`0^3Rd
2P2P8?090?n000040>QX?02P8?00X23`0;Ph]080X23`0P3XJ3`70?n000P0oooo2P00o`00;P1W:PL0
JSDY068S6P1]>Bl0K4Y506MDEP1REel0HeMO06YMIP1eGVP0MTUC07HP;@2:9S80O0lJ08A>D`22IfP0
P71`07igL`1kNgT0Rhj?08VBTP1eR9/012A`008VN01jVkT0KHJ<09B//`2?Yk40VkFm09F^]P34f=h0
e^?T0>;[kP38gNP0c^Oc0<cUm03Jlo`0loko0=KXkP3CkOH0eNcg0=k[lP3Hj>d0e>GZ0<oQi`3@h^T2
0<_NiP0O0<SLiP34fN@0aMWV0<?Ii034en<0`=KQ0;kEhP25Z<`0HI;107fWaP29[/L0Tjbn09J`_P2;
YJl0TJZ`0:Bma01iTYX0QIjU06n8R`1aSHh0Gg]k05UgL`1EM780DG1/04i[I`1=JfL0CfYW04aXH`18
IU/0AUe>00SW1@080?ooo`X00?l0103oP0000`3@D7P0X23`0:0Pl0030:0Pl0050;Ph]03oP000oh00
0?n0003@D7P0402P8?000`3XJ3`0oh000=1@N0020=1@N0050>QX?03oP000d51h0=1@N03XJ3`00`3o
P0000`3@D7P0oh000:0Pl00O0:0Pl00302S8?03oool0oooo00T0oooo000:0?ooo`0j04eY400Q0P40
7P8201@10P0?0P80104100D1000W0`<0BPP;04P31P1>0@D0G`X@06@3201X0@D0J@4406P0101b0PX0
R@D;09L63@2H10/0U`D<09L42`2F10X0V0L=074=5@0o>3P0Wjj[0<OAdP38d]@0a=3F07nAV`1??DP0
U1PO08TA5`1120d0CTQ;0;C1`P3Ff]d0bk:m0:5:F@2W6R00SDE709RIUP3@f]/0fMoQ0=GLgP3IgN40
cK[50959FP1U5B00=`/>02LP801NKF`0ZKRg0<?>d@3>emT0c]GH0<cDf@<0bM;F01/0b=;D0<OBe035
al`0L2@[08L52`250PL0Q`<708/52P2B2`P0UQ4<08<51P2DE5@0`[g205Y7CP1hHfH0U9ZM04Q5B`0P
41L080H=02821`1B10X0M`<808D31`1i0`<0E0410481000dA0<02@3oool50?n00080X23`4P3oP000
0`2h>;@0X23`0:0Pl0030:0Pl0040;Ph]03oP000oh000?n00080^3Rd00L0oh000=1@N03XJ3`0oh00
0>QX?02P8?00j6Pl00<0oh000P3XJ3`20?n000050;Ph]02P8?00X23`0:0Pl02h>;@0202P8?000`3X
J3`0oh000?n000060?n000H0X23`00<0j6Pl0?n0003oP0001P3oP0080?ooo`X00?l004P0IT4>05`U
5P1S:AX0Je9606YLG01REEX0HEEK05a@F01WCeL0KSI107h_>@1l6b80RC0f08M2A`23HfL0PWAf089g
M`21O7`0OWmn08N<R`2=UYL0Bf:7008TP009<X<0M9BZ0;?4bP2FZkL0Ykc80;K9d03Eh^L0k?Cf0>[_
lP3fnOX0l?Oi0?Woo`3eoOl0c^Wa0<CTk`3hoOh0kOCf0>7[l`3Ji^h0enK[0=KUjP3Bh^T0cN3X0<WN
iP3:g>D0b=[V0<CHi@32f>D0`MOT0<?FhP31e>80_m?P082N`@0GBH80NJC008:V^`2W`M00Xk_9096^
^02=Yk80RZ:Z08^PZ02HZk80SjBV082GVP1/QhP0H7]k05]hN@1CLVl2055`JP05055^JP1?Jf<0BfQM
04MQDP0Eaa40203oool:003o00<0oh0000<0^3Rd0:0Pl02P8?000`2P8?001@3@D7P0oh000?n0003o
P000j6Pl00l0X23`00<0d51h0?n0003oP000103oP0020=1@N0L0oh0000<0^3Rd0:0Pl02P8?007P2P
8?000`1@T7P0oooo0?ooo`090?ooo`002P3oool0500fEPL0808101d20P0@0@403`8200@10@080000
:`8404P2101B0@<0E@4305h21`1S0PL0I@4606P21@1X0@D0K`4608`42`2C0`X0UPD;0P2C10X09`2D
10X0Q0X@03LJ6`2U/Jl0bmGE0<_EeP2ncM00DFUb03aCF@2LWj00HbX^03PQ8`1[MgL0^lO80=KFg02a
NhT0W2Db0:lD6P2Y:R`0a;2a0=?Mg03Ign40fMoR0=CHg02_V:@0KcM7038?5`10ADH0KX1o0:Ni]P37
dm80d=OJ0<oFfP3@em/0c]OI0<WDe`39dmH0b]CE0<SBe@020<KBd`0I0;2[/01d5200RP@<08H22026
0`/0R@L709TI40230`D0Ma4B0;n[ZP2JU9X0>b0W0:>KW`2RZjl0Cd1502873@0/2Q409`@805421P1m
10/0QP8807h2101J0@40AP4103I40P090?ooo`D0oh0000<0X23`0?n0003oP000403oP0000`3XJ3`0
X23`0:0Pl0050:0Pl0060>QX?03@D7P0X23`0;Ph]03oP000d51h0`3oP0020=1@N080oh0000D0j6Pl
0=1@N03@D7P0d51h0;Ph]0020:0Pl0050=1@N03oP000d51h0>QX?02h>;@01`2P8?080?n000030=1@
N02P8?00X23`00<0X23`2P3oP0080?ooo`X00?l004l0EVP9058L2`1[BS`0JUaE06YPGP1SEUT0IdUA
05he?P1ZATd0MCQ007P`=P1h?TD0ReIN08]8D`1oAe80Q7Mk08IlO024Ogh0QHN608R@T02AW9h0DV^@
008[S@0FAiT0XK[=0;O0b032cmH0e>3W0>C^lP3Xko@0jO7e0>O/l03lo_l0koGi0=c/mP3>hn`0k?[n
0>;io`3Om?d0d^Wa0=G[mP3FiNh0dN;[0<[Oj@38gNL0a]_X0<KLi`31f>80`=ST0;oFhP2oe^40_mCP
0<;Dg`2odMl0^M3M08n]`01YTKD0Ii2a03]XR@1dVJ/0PZ2/08JT[@2T`</0SjZe08jW/@2<Xj`0R9bQ
08:GW01^R8/0I82105ejN`1GM780FW=`05QdL@1DLFh0EFeZ059ZI01:IEP08JLM00P0oooo2P00o`02
0?n000030>QX?02P8?00X23`0080X23`00@0d51h0:0Pl03@D7P0oh00103@D7P;0:0Pl0030=1@N03X
J3`0oh0000H0oh0000T0d51h0?n0003XJ3`0j6Pl0=1@N03XJ3`0oh000>QX?02h>;@08P2P8?000`1@
T7P0oooo0?ooo`090?ooo`002P3oool0?00`D@@0804101l20@0H0@803@0000D10@080000;@8304D1
0P1?0P<0D`0205d11`1@0@D0E08606@11@1W0@D0L04608/3202?0PH0T`D908l2202@0`P0SPD:05X8
3@1PIF@0am;B0<SBd`39eMP0LXZA04aWJ`2da<<0am7B03Ln@@25UIH0`]3A0=SKgP2hTIh0WQdZ0;PF
702i4aP0/dA90<[4a`3Ih^80en3Q0=OPi02NZK80;bLa01LC5P1HJfT0[;bl0<SEeP3@g=`0d][L0=;H
f`3Aem/0d=SK0<kHfP39e]P0a]CH0<GBe`80b=?E01X0am3D08e^N@1m2aD0R`@=08/32P250`L0VAhC
08D:1@1n1@X0R4900<73`P1`H6H0KU9F0:FXZ@25T980<RX]01d83P0S1@`0<`D;06462P1j0@D0Q@86
07l10`1R0040CP4103I40PT0oooo1@3oP0000`2P8?00oh000?n0000@0?n000/0X23`00<0oh000=1@
N03oP0000`3oP000102P8?00oh000?n0003oP0060:0Pl0D0oh00202P8?070?n000030=1@N02P8?00
X23`00D0X23`2@3oP0080?ooo`X00?l004l0EG/:05DZ501YDd<0JeiF06mPGP1YAdX0JQdT06DA6@1d
Be<0LTiE07mHG`1n>D@0PbH_08`R:`21:300S7Um08b5Q`29QhL0SI>C09NLWP2QY:P0QYNa00DjV`0J
Ej/0b=c[0=WOiP3Eg^L0h>S_0=SPjP3ZlOD0koCf0?SmoP3Jh^P0m_[m0?7gn`3NkOT0Z<kZ072`gP2I
d>l0[]?Z0;7Dj`3:g^L0bMgU0<CLi033f^<0aM[U0<7Hh`30en80_]GQ0<3Eh@30dn00_m?O0;gBgP2k
dMd0^]7K09fjbP0cFH40>6:708J/_P26ZKT0OIfZ086OZP1gTil0L8bH08b[/`22WjL0P9ZQ06n7S01V
P8@0H7en05IeMP1ELg<0FWEf05agM01KMg80FGA_055ZH`1?JUh0:iDZ00P0oooo2P00o`020?n00004
0=1@N02P8?00X23`0;Ph]080oh0000@0X23`0;Ph]02P8?00j6Pl0`3oP0090:0Pl0030=1@N03oP000
oh0000P0oh0000D0j6Pl0=1@N02P8?00X23`0;Ph]00V0:0Pl00307QH]03oool0oooo00T0oooo000:
0?ooo`1H031?0P0R0P40704101D10P0<0@401P4100P1000[0P<0AP8305010`1G0@<0G@8705021`1=
0@@0H@4606T11P1e0@P0SP<909021P2A0`T0T04:09<63@1o3a@0@1lO0:Zf]@37dM<0b=CD0:k1`P1A
K6h0/L;10<oIf@3:eML0Sj6S0<CAd@3Hg>00cjfg0:P`?0305A/0a18G0<@D6031DED0dLc?0=_Rh`3K
hn<0b]OL03A=E@18GV00T:>Q0<7Bd@3BgMd0e=oP0=GOh03Bfmd0d=[K0=7Ig03@em`0bm;H09RW/P1F
KWX0OY>L0<WFf03:dmL0[jJ_07/_>`251`d0R@@;08/32P2<3@P0VB0B08451P1`2P`0[XR60;k1a01@
<SP0Tgmn0:>[Z`2S[k40De1D01T93`0[4AP0<`@:05/31@1i0@D0P@8507h2101W0@80DP4103Q30PT0
oooo103oP0000`3XJ3`0X23`0?n0000@0?n000030>QX?02P8?00X23`00@0X23`00@0oh000:0Pl02P
8?00^3Rd1`3oP000103XJ3`0oh000?n0003@D7P30:0Pl0030=1@N03XJ3`0oh0000D0oh0000<0d51h
0:0Pl02P8?00102P8?000`3XJ3`0oh000?n000050?n000030=1@N02P8?00d51h00D0X23`00<0d51h
0?n0003oP0001P3oP0080?ooo`X00?l004l0>j0505Xi6@1UDT40K5I?07A?C01[:BX0K18E06XX:P1i
CEH0NSi9080mA`219S40PRT_08U3B@2>F5h0T7Ak09fHW02IVId0WIjR0:b][`2l^[`0`lOF01mFYP0Q
JK/0a]k]0=kVj`3Ji>/0dN3W0=OSjP3GhNX0cmgX0<[LiP39g>D0[/CK09bge02]bnT0OJoG0;7JmP0i
N;T0IJ7B0:_>h`39g><0b=[R0<OJhP36f^@0a=WT0<;Hi030e^<0`MOS0;oFh`2odn80_MCQ0;cCh@2j
d^00]]7N0;G@g`21Y[h0=V2?05b5Y@10JH80N9NU08VV/@26Y[00QjJ^08FQZP1^RI00Hh6606J2QP1Y
QXL0HWn0059aKP1AKfl0DW1_05QeLP1TPG`0Hgek05I_J`1@Jf40>HDh00P0oooo2P00o`001@20`000
oh000=1@N02P8?00d51h00<0oh0000<0X23`0=1@N03XJ3`00P3oP0000`3XJ3`0^3Rd0:0Pl0050:0P
l0040;Ph]02P8?00X23`0;Ph]080oh0000<0^3Rd0?n0003@D7P00P3@D7P20;Ph]2d0X23`2`3oool0
00X0oooo05P0;dd202820@0L0@405P4200h10P040P401`4102L30P150@80C`8405H10`1N0@H0H`87
06021P1W0@H0J`4607d2202C0`X0T`8909L42`2I1@`0RP`?04092P21QH<0am;C0<WAe02Y[K<0UZFX
0;[:b@3>fMP0dM[K0<oJg02ob/`0hm;I0=>8V039=d@0hB4T0>XV8`3_;BX0kBlZ0>IRH03cj^/0j>g^
0>W]kP3Pi^L0dM[K0>3Zj`3QjNX0hnWY0>;Xj03Oi^H0h>KW0=cQh`3GgN00f=ON0<F/^@1^Cf80:38m
06f5RP2ib<X0c=GI0;6NZ`1m:c/0R`/E08`42P2:1@T0RP`50:H_6P231`D0MPT;09MPG@36`<40X9RL
06A3A02]ZZT0VZZY0:6`/@0O8BH050X>01X7300/0`L0H`@:07X11`1o0PH0MP4306<10P1C0@40>482
2@3oool50?n00080X23`403oP0050:0Pl080^3Rd00<0oh000=1@N02h>;@02`3oP0020>QX?0T0oh00
00D0d51h0:0Pl02P8?00X23`0;Ph]0020:0Pl0030=1@N03oP000oh0000D0oh0000@0d51h0;Ph]02P
8?00d51h1@2P8?000`3XJ3`0oh000?n000060?n000P0oooo2P00o`00C`16[0X0FcdI061:>01O:bD0
M2XW06`Q8@1]=3L0IR`c070O:P1l6RD0NB`d08A>E029EUh0RDeI09A@G@2GE5/0]JBX0:NX[02^/[H0
^ko30;bna037b=80F7bf01EI/@32fN`0d]_S0<cHhP2od=T0^<_D0;W>g02F[kd0[<G@0:C0c02[amX0
VKO=0:k;gP1RT/40GYk?07jbf02=bN/0`^3_0<[Oj`35gnh0`n?a0;SOl`2[fOD0WM?d08c9l`22__80
Mk?/06nZiP1XXn40HYcL05nEeP1JSm40Eh[@031W]@07>IL0?G>f05N7^01^U/80G8>[05R2XP1mXkT0
KY6S08^[^P1mVZ@0H7f3069oP@1WPXH0E79a04m/JP1>K6X0EG=_05QeLP1ZQXD0P9NF05QbJ`0mRT00
203oool:003o00030830003oP000j6Pl00@0oh0000L0j6Pl0?n0003oP000oh000=1@N02h>;@0d51h
0080j6Pl1@2P8?00102h>;@0X23`0:0Pl02h>;@20=1@N0/0X23`00<0^3Rd0:0Pl02P8?009P2P8?0;
0?ooo`002P3oool0F014?PP0808101d20@0I0P803P8100@2000400009P8204810`1>0@@0D`4305`1
1P1O0@D0H`8606d2201c0`T0Q`@;09D42@2I10X0W`L;0:893`1f4Q<0EDM60;c5a@39e=@0aK[106a0
C02cZ:d0d]_L0=;Lg@3Egn00en7R0>?Ri03QSiX0gCQ10?Hb=03n>SD0oD8h0?m<@@3nDd@0mWA[0?oX
jP3mo_d0o_on0?knoP3jnod0k_;d0?;dmP3`lo<0jnk_0>W]kP3Vjn/0h^KW0?7Mj03IUJT0SSiA02hG
8@2?Xj@0`mGG0=3Hg@3=a]00UD5D09X<6P2K1@l0U0<;08h91@2d@240UAd:08@41`1l:BP0cknn0;k4
b@1jIFX0QFa/09:JV`2N/;40Z;Fg02HP9@1KBT`06PD:038;3`1D0@H0K`4407/11@1c0@80H@410540
000j@P490?ooo`D0oh000P2P8?0?0?n000<0X23`00<0d51h0:0Pl02P8?00703oP000103@D7P0X23`
0:0Pl03oP0020=1@N0T0oh0000<0X23`0=1@N03@D7P01@2P8?090?n000P0oooo2P00o`00C`0Re@D0
H3hJ058c8P1B7Q80HB4F06Pe<@1P9b`0I1<J06lO9@1b=C`0QV1W08=4D@2:<3l0Sad]0:]KI02<@TX0
]jBW0;Fm`@2h`<D0^;[10;Vd^@2i[Jl0NhJZ00/nT`2Wa^00Z[o90;[=e@2_`L`0YKW409J]]`2`a]00
Z/3=0;W>eP33f>40`]o`0:;4e@3Hl?T0coCl0;GUl`2Jg_00XnCk08?FnP1G`oL0>kGg022Mk`0DR>h0
3H7b00Mgl@0?I>40<4jo03e5[@12?:40B3VL04LbT011;8L0>R=j03DOM00b8gX0;21i02LRM`0P87<0
629d01<SMP0D;7l04Bim01XkQP0Q@Wl0;U1l041QO@1FMhX0G7b1051`K`1?KF/0CfiY05EdLP1dTY00
RJ:T05QbL01;F4/0203oool:003o00030830003oP000oh0000H0oh0000<0j6Pl0:0Pl03@D7P0103o
P00A0:0Pl0060;Ph]02P8?00^3Rd0>QX?03@D7P0^3Rd:02P8?0;0?ooo`002P3oool0F01I:a008081
01`10@0F0@802P4100@200090@00:P<204820P1>0@80E`4305`11@1Q0PL0J`<907812@1g0@X0S`D>
09T42P2O1PX0Y0P=0:8=4@1_;bl0Y:RX0<_DeP3Ae=H0/79k08PZ=P3;/KH0f=gP0=WPh`3Ih^D0hnKZ
0?>i`P3/AU40ncDj0?hg=`3n@C`0o4Q10?]=A03lEDL0m79X0?gTi03oooh0o_kn0?[knP3inO/0loCg
0?;cmP3^l?<0ko7d0>c]l03`k?00l/OG0<e`Q`24:c`0E38i0:Zc]@3@gN80eMgR0=_BgP2iJg`0/1TS
0;8;4@2^2Q00X@P:0:d`502X;A<0T@T508L:302YNGP0aLK;0<;3c01G<SX0ZibK08REU`2@XZ@0QY2C
01`D600I2Ph05@85034>401>0P@0K@8307L10`1a0P<0F`4205410@0k@`890?ooo`@0oh0000<0j6Pl
0:0Pl03oP0003P3oP000103XJ3`0X23`0:0Pl03@D7P20?n000030>QX?03oP000oh0001T0oh000`3@
D7P<0?n00080X23`00<0d51h0:0Pl02P8?00102P8?000`3oP000j6Pl0?n000060?n000P0oooo2P00
o`00C`0Yf`X0HS<=04dQ401F;1T0JB`N05hD4P1/8bL0IbHZ07Q5C@1bEEh0PfM_07LQ;@2E:S40QbD[
09aXJ`2MPhL0[jJ[0:f//P2/[[40Zj^`0:JW[02CUYP0N8VO00P_M024X;L0/lG;0;c?f02Y_LP0_=7J
0<7HhP35gnl0_n?c08k=m02:d_@0P/_a07o?l`1M_o<0<Z_a01fOj`0KVn<07Z7U01ZUk00EZoD03JSj
00VQn`08UO/028[k00UkmP1DFL@0aBUI0<`M?P365SD0a1@`0;lE;@2/3240Y@dR09/:7`2=1Q`0TPTR
08@<8P27;T@0LAdj07<<;P1^33D0IPhk05@=?`103dD0:@i;01XDE@0@6eh05RmZ02Y=MP12I7X0E7Ag
05IdL`1UQHD0S:JZ059/K@13OT@0203oool:003o00030830003oP000oh0000D0oh0000<0^3Rd0:0P
l02P8?000`3oP0000`2h>;@0X23`0:0Pl00@0:0Pl0030;Ph]02P8?00X23`00d0X23`00<0j6Pl0?n0
003oP0002P3oP0050=1@N0`0X23`2`3oool000X0oooo05P0ERXA01d10@0K0@405P8200H10@020@40
200002/20P180@80D04205P1101P0PL0IP4607422P1h0``0P@8=09/63`2S1Pd0Z0L?0:`93P2S5QT0
XGn00<kDeP3AemP0d[Zo07LY<@0^1``0][Rj0=GLg`3Ig^80f=kR0>[PiP3ICeT0o2d_0?d^;P3m=300
oChi0?m<B03nCdT0oU9;0?UmM@3ol_40o_kn0?gnoP3moOh0nOWk0?Kgn@3bm?H0kNoa0?O]mP3ldn40
l8fM0<e4E@1^=d40W9ZL0=CNh03Hh>@0h=_T0=J/_P2kDVL0aAXV0<LB5`313QD0^PhA0<0b4P2j<A80
YP/90:093P2H?S`0clO60<G:d@2VTi`0FRT]0;Bc]P2>WZ<0Z[Rl0:6Z[@0D3a<03`<701D31@0a0`D0
G0<607D31P1h0@@0K@4205L10@1?0@40?4812@3oool40?n000030=1@N02P8?00oh0000h0oh000P3@
D7P20>QX?0030?n0003@D7P0^3Rd01T0oh0000<0j6Pl0=1@N03XJ3`03@3oP000103@D7P0X23`0:0P
l03XJ3`60:0Pl0T0oh00203oool;003o001>06HX1`1O:AT0H24F06<?2@1T3`h0JS<d06i3A`1^9C40
NSM007iNIP23EEd0QTeA09YoQ02JT9H0WYNL0:NMX`2UXJH0WYjT09RLX@2DVj00RiNI08:FX`0D>W80
T;3:0;c?g`2ecnP0Ul7Y07J/j@1<VNT0:hS[01Ioj`07Po@01Hkh00FAm@04UOH03:?h02Bdm@1?b?L0
OMKi073?m010^OH07Ygd00n9kP08L^H02V?L019Dd00E?kP0FS2;0;@A;P2c2AX0Z@DE0:L95`2C3aP0
T1l/08@;6`212A@0MQ<L06h95024=3l0XGj:0;BEXP1e6bT0O`@=07l23@1n0Pd0O0<>07L3401c1AP0
IPPV04l;=P0a54/05QaK01HbI`0nHG/0JhZ@07ZFV@1?JVL0>i@k203oool;003o00D0oh0000L0j6Pl
0;Ph]03XJ3`0j6Pl0:0Pl02h>;@0d51h02@0X23`2P3oP000103XJ3`0^3Rd0=1@N03XJ3`60?n00003
0>QX?03@D7P0X23`00L0X23`2`3oool000X0oooo05P0CbD=01d10@0L0@005P8200`20@070@402@00
03<30`1D0@@0F08505h1101U0@H0L@<908@;4P2>41H0V0/A0:d:3`2c20h0]@X=0;`=402e:bh0g<34
0=GFf03Fe]P0SX>303ll?P2JY:D0cMOK0=;Kg`3Ggn40emgP0>?6c@3=<3L0jB0S0>dR8P3^92<0kbLV
0?<];@3d;c40lbla0>U7C03jfml0kNoa0>W]k`3Xjnl0i^[]0>CVjP3^hnX0ijfl0=aJL@3Q>4T0fDA:
0=JXZ03AeMT0f^;V0=KKh@3Ga=80_fEg0;LS<P355b40b18G0<4A502g40l0_C0A0<4l4`2a3P/0[PT>
0:0Q8`3B/k<0algA0<W1bP1^>T@0ZXB50;c5aP2AY:H0Xk>f08jHW00C2`l050D801D31@0W0P<0F@`?
06h21P1f0@@0K08205d20P1?0@40>4812@3oool50?n000030;Ph]03oP000oh000100oh000P2h>;@0
0`2P8?00d51h0?n0000G0?n00080j6Pl3P3oP0001@3XJ3`0X23`0:0Pl03@D7P0j6Pl00D0X23`00<0
d51h0?n0003oP0001`3oP0080?ooo`/00?l004h0K2X=06TS6@1W3``0Ha4<06hh=@1[CD/0GQdS07hQ
:@1b82L0SWAn08MjP`27NH40SH>;08n8T@2CRY80TXZA096=U02BTIL0TYRM09JNY02AX:P0Pj2k01m=
W00bIkl0=6k801iNb007A<400dgC00AZl@05LoL01W[j00R3o008Q_T028Sg00R5mP08O^d047KT01a^
gP0^J=L0@5g:04e@^P1N@jL0KCN>07D]P@1m:WH0ObE/084SI`2775H0[Q0[0;<9602^2AH0W18N0=jU
[@2hUJH0_9fY091XL@2mYk80^jJ_07UJJ02aVjP0[jJd07mSK`2JLGD0REUL07Lh?P1g9Bd0K0890781
1P1g0PT0N@8;07X34@1]2B80AP`e020GCP0]Ch80LiV^05E^K00XZR<80?ooo`/00?l0103oP0000`3X
J3`0X23`0?n000020?n00280X23`00D0^3Rd0=1@N02h>;@0X23`0;Ph]0050?n000<0d51h00<0^3Rd
0:0Pl02h>;@00P2P8?000`2h>;@0d51h0=1@N0020>QX?0D0oh0000<0j6Pl0=1@N02P8?000`2P8?00
0`1@T7P0oooo0?ooo`090?ooo`002P3oool0F0198Pd0704102<20@0I0P403@4100P2000>0@40=@83
05L1101L0@<0I@4506h2201k1@d0T18H090=4P2M2Q00/0T=0;P:3P2k2`l0`@hC0;Pa=P3MaLT0dmGJ
0<_Ae01BGUd0Y[Jf0<WDe@32c=80cmWK0=;Lg@3Bf=/0aIRP0;XK8P3;4aL0ba8E0<XB5@3:51T0d1<H
0=DF603I6A/0dBD/0>Rk`P3QiNT0hNCX0=oSiP3ThnP0jLgI0<YcQ@35:CT0cQTS0<XG6`33C540c<W>
0=;KgP3Ffn00a;Fn09e5F02]4b@0]0`F0;@<502a2A80[0/<0:8K0@38FAl0WA040:L7302M3Q80]fi^
0<c;d03:b]40RfIc064T:02bYjP0]lC90:Ne_@2X]k`0V:>V04He>P0X31007@8503441`1D1@X0KP87
07810`1Z0@40G04104h10@0e@@090?oooaL0oh0000<0d51h0:0Pl02P8?000P2P8?000`3@D7P0oh00
0?n0000E0?n000050=1@N03oP000oh000:0Pl03@D7P02`3oP0020=1@N0030:0Pl03oP000d51h00D0
X23`2P3oP0080?ooo`/00?l004h0G5X>05l@1`1Y81P0Mchg06dl=P1[BDD0JRl^07Xm?P1kGf80O71g
07abN`1oLg`0OW9m085jPP29OhL0U8R?09^EVP2IWJD0TJ6d06n</@0oJJh03TR[00@h[P019:400cZk
00M?f003@<l01E;P00IVl006H^H02eCE01E7`00/A;D0>CfW05<oXP1`?IP0RcN;0:0oRP2S?XP0WDF?
08]BUP1aFYd0HV2W04aV]@0kKL00;Fk602EWc00^G/L0X3Ac0=PN:`3?5B00`AXX0:T`@`2JEFH0d;o:
0:B?W02GIWd0XFn209jDXP2GNXh0SV=f09J3T`2IQY@0RWZ708]nRP2POhh0I0DA06T1101Z2Pd0QS<j
07P63`1h10`0O@@@07T98@1;5TP0:3aj05UeQP0Cda480?ooo`/00?l0103oP0001@3XJ3`0d51h0?n0
003XJ3`0^3Rd01/0X23`00D0d51h0;Ph]02P8?00d51h0;Ph]0070:0Pl0030=1@N03oP000oh0000<0
oh0000@0j6Pl0=1@N02h>;@0j6Pl0P2P8?000`2h>;@0X23`0;Ph]0030:0Pl0P0oh0000@0^3Rd0:0P
l02P8?00D91h2`3oool000X0oooo05P0B1l<01l10@0U0P806P8200/10@080@403@0003H31@1M0@D0
I`8506l3201n3Q@0Q@lD08D73@2:10d0WPL@0;493`2f2`h0^0X?0;`=4P2/:2X0bkRj0<kEeP2mbLX0
Y;>c0<7=c`35d]L0[kg30<kHf@3@fMX0d]CG0:9MI`2g51X0_10C0;l@5@2o41H0`1<F0<TD5P3A61X0
e1LL0<`S:03W^[l0hNKY0>?Vj03]g^<0hYFU0<a6E`3D9S40eaXN0<lF6@3<61X0_TQ>0=;>d`3Bbm<0
_YFR0:91D02Y4ah0Z0PB0:D73`2T1`d0XPH<0:0L1`3<JBH0X2h;09D6202F2@h0RR`/0<ni^036c=80
[i^U05/J8`2KKFh0][Zm0:Vf^`2HYjh0U:BZ0826S@0g82T0?alV03LD6P0`0PD0F08507011P1a0@<0
J@4205`20@1@0@40B@<22@3oool40?n000030>QX?03@D7P0oh0000h0oh000P3@D7P50:0Pl0040;Ph
]03XJ3`0oh000=1@N1@0oh000P3XJ3`00`3@D7P0j6Pl0?n0000:0?n000050>QX?02P8?00X23`0?n0
003XJ3`01`2P8?000`3XJ3`0oh000?n000060?n000P0oooo2`00o`00CP1MK@`0GQ/:074d9P1T6100
MBLN07M;@P1jIf80NFe_071ZL@1`JFl0MFYc07AVL01eJg@0P7Qo08f6T02CT:<0NHN/03iTY@0DAJ00
13NQ00<cXP04<j/01CVg00<a]@04>;l02DoG00E1b@04<k@0:S>S05dVOP1c8VX0ORQZ07`dM`1g?X<0
LTbB065X/@1DP/X0DY_J06ffh023bnX0K<of03jon00Z]o/04Igi00RDnP05PoH00g3`00MOg@1a<h@0
bA@Y0<<=6P2e4Qd0ei6G0<JQ/@2JCf/0^WV<0:5IKP2jLh80WWZ>0;NJZ02/SYT0SF9e09=_O@2`Xjh0
SGf:0:F6U01/2AH0LP45060=4P2KKgP0OBll08I3C@1o:340P@hH08l<6@1O7Dd07cAR01G860P0oooo
2`00o`050?n000030=1@N02P8?00X23`01H0X23`00<0d51h0:0Pl02P8?003`2P8?000`2h>;@0oh00
0?n000020?n00080d51h00@0oh000>QX?03oP000X23`0P3@D7P40:0Pl0070;Ph]03oP000oh000?n0
003@D7P0oh000>QX?0030?n000030;Ph]02P8?00D91h00/0oooo000:0?ooo`1H04PL2P0O0@407P41
01H10P0G0P804P8101810@0i0`D0IP8607031`1c0PL0Sa<L08d<4`1m0`X0RPL@09`94@2_2a<0[0T>
0:T7302/2Ph0WA4G0;B?UP3:d]@0a]?D0<S>d`2^Y;00E5UV09n^/`3<emL0dmSK0<n_]P2T:C40bA@G
0=@G6@3J6ad0gAhN0>DW9@3`;BT0l2`X0?De;`3[CDD0o>3Q0?Kgn@3gk>l0iY:F0>iAC03hA3d0nT4f
0?Hf:P3a;b@0jb/U0>9ZK03]`L`0c5AV0<XQ;P3<5Qh0`@hE0;D;4P2X1``0Y@P:09`A1@36J1d0VS87
08h91P2=10/0Pa/O0=2^[`37bld0a/[A07E6D01S7b<0]ZFW0;2o`P2/_<00]lS<09^/[P1WHfX0=Q`X
028D7@1eHVT0@0D:06d42@1i0PH0M04306P10P1K0P40CP4104L30PT0oooo5@3oP0000`2h>;@0X23`
0:0Pl0050:0Pl0030>QX?03oP000oh0002<0oh0000D0^3Rd0:0Pl03@D7P0oh000;Ph]0080:0Pl0P0
oh00203oool;003o001>03j:101]>200K20C07PE3@1o;b40P5e@079WIP1fKgH0JfA]06UQJ@1`IVl0
M6I`07I]N01cN8h0C6BD01Y0S`05<IL00RnP008bY`02=J/01SV]00L^X00E<jD07Qb603@BJ@197Fh0
31Mi008IO`0c:X@0D3Z<03YD[@0WK/X068GU01ZOm@0HY?T05:Wk01ZUn00EUoD05XW/01B7k008NN`0
0W?^005ak@01JNX00FGW005RiP01G>000eKI05TkV@375Bl0d14J0<0G8@3Z[;T0_8nO0=j>XP2`:T00
/A/`0;LU>P2V73H0]dUO0;1BJP2@:Ch0]6al0;9eQP2;B5/0`9ZV08Hd@`1k0PT0L1hQ0:fGWP1iDE/0
OeQT0:N:UP2DHVh0VCa707HOA@0D8e`04jPJ203oool;003o00030<2P003oP000oh000080oh0000<0
d51h0:0Pl02P8?00:@2P8?040?n000030=1@N03oP000oh0000@0oh0000L0j6Pl0?n0003oP000oh00
0=1@N02h>;@0d51h0080oh0000T0X23`0;Ph]02h>;@0X23`0;Ph]03oP000d51h0:0Pl01@T7P02`3o
ool000X0oooo05P0AA/902810@0T0P807`4102420P0K0@805`420342101R0PD0K`860701201d2`l0
QRDY06h4301o1@`0TPL?0:0;502L1a00WPH<0:062`2S2100WbTe0;9/O@2cOXd0ZEMW07PS<01<?4<0
`lg?0=3Jg03OdML0]eIP0=@S9`3_9R80nRhX0?P/:03m=Bl0oT0h0?m;@@3nDdP0oUY:0?ahK03oe]h0
nmKS0?[>g03i[K@0nh9g0?i^G`3mHE40nUI60?Q`H`3fLF`0keeT0?19E03i<3<0nBLZ0?<U9P3V7Qh0
eaLK0<XB502k5@d0c64E0;A93P2N3@H0X0H<08l:3@2XL6l0c<c<0<C>d02l/[P0EA@N08mYJ@2o`l<0
]<;609V[[P2CYjT0SJ2R07A_M`0U21@080XG03dZ=@1f=C`0MP<908421`1j0P<0J04205h20`1@0@80
A`@22@3ooolF0?n000<0d51h00@0oh000:0Pl02h>;@0j6Pl9@3oP000103@D7P0X23`0:0Pl03oP007
0:0Pl0040;Ph]02P8?00X23`0=1@N0L0oh00203oool;003o001>03R]1@1^?1`0McLQ07LZ5P2>GT`0
Pg9Y071YI@1aJFh0HEQP069KH`1_J7@0I6Ml03E8M`0:;7X00bf?008[U001:YP00bjM00L_WP0H;9L0
<B5m04/BE01Q54h0FQ1:048>D00d97P03bnP00De]P07Bm002VKX00Mcl005LNX00f_X00=/j@00J>P0
0F_/001Yj`02L>h00WK_00Enl@0:Q>l04I3`012Jl`0CWoH02icj00JFnP06T?/01h;h04aTd@3I:D`0
jR0V0>0K903E;D40e4YT0<@W@`384b<0`PdH0;d;5P2l31L0]``G0;<;602Q1100VPHC09H6502@1180
RP`M08D95`240`X0UDeA08UPL@2GJWP0SgN20;6Q[02/WZX0YWB407XRAP0L8EH01lP=203oool;003o
00050830003oP000oh000?n0003XJ3`0402P8?040;Ph]1P0X23`4`3oP0002P3XJ3`0^3Rd0=1@N02P
8?00^3Rd0:0Pl03@D7P0j6Pl0:0Pl01@T7P;0?ooo`002P3oool0F01460P08`4102H10@0X0@40:@83
02810P0J0@809`0105X31@1/0`D0JP4506LD5`1b=CX0I`@<07H11@2>1@`0TPD@08P5302H1P/0XPL<
0:P93`2a31D0[a8O0:lF802l51`0La0E0:>NX03?f=X0e=cN0>:ma@33=Sh0jBHV0?DU903k:RH0oBXV
0?/]:@3j<b`0mSPb0?M2>`3hAcl0kdi:0>=[M03PMX00hGR10>MXJP3_GU80l4m20?A<@03`JF00lJJW
0>bUZP3cQh/0lS<g0?//:`3i9bT0lR8Q0>HK6`3M6AX0e1/H0<Xl303SQQh0]1l70;H<3`2c2a80U1PH
0<ni]`35cm00a/k@09n2R@1Q6R40Sg]n0:6]/@2V]K/0[[g30;;3b@2HYZh0<2@_040Q9P0e4a`0;0HA
064:501o0PH0P`0507d2101^0P80H@4304`10P140`490?oooaX0oh0000<0X23`0?n0003oP0009@3o
P0020:0Pl0030=1@N03oP000X23`00L0X23`2P3oP0080?ooo`/00?l004h09mH606h[2025E3P0RfUA
08EaHP1gJ600HUEC06MNH01aJg80Gf=d03A2LP098V/0129m008SQ@029Xh012F>00hPPP0/6g40EaQI
06lHCP1S6E00?B5S01TXQ00;;I/01BNM00Hg/006?kd00c6d008d^002B</00Tc?009Hf@01H^400Vg/
00=hlP03QO<059_e03ZemP1]dOD0U>3i0:7YoP28h_`0DLgj02jln@0>X_/01ICl00>7o003LoH0863L
0:0YJ03?5B/0b@lR0<@A902l3R80^0`Q0;@;7`2`2QX0[0TH0:X85@2[1aD0Z0LD09P23@2E10d0Q`47
08D11`220@L0O`4707`32P2EC5@0]XVH07hX?@2GCV<0aij_0;JM[@2iRIP0SAde03M6;003l@<80?oo
o`/00?l000@0P<000?n0003oP000oh003P2P8?020;Ph]0030=1@N02P8?00X23`01X0X23`00<0d51h
0?n0003oP0004@3oP0002@2h>;@0j6Pl0>QX?03XJ3`0X23`0=1@N03oP000^3Rd02S8?00;0?ooo`00
2P3oool0F01660T0:04102h10@0`0P80:P4102@20@0O0@809P8205031`1W0`H0I04506`B601f9Bd0
K@<:07d22P2O41T0X@hE09H7302U2Pl0[0X@0;D<502o4A<0aQ<C0<`E4`3B7ad0L2<U0<[;c@3CfM`0
emOL0<amR@3B9b/0jb@P0?HT8P3k:2D0oBdZ0?db;P3n>c<0oT8i0?e<@`3nED/0o6IN0?Z6R@3jYZl0
o;O40?bMXP3mOW<0oFYJ0?YQE@3iXil0kkRm0>VY[`3cY:d0jD570?X];P3f9RX0lR@S0>PO7`3I71D0
aRh60=im5P31BP/0_10?0;/:502f3a@0]E]J0=;?d037dm<0c<o@07m8D02=DE@0[JVZ0:bk_@2P[k<0
QYRN08fPYP2AWjD0;AlX040L8`0i41T0EA4K07D53P270PT0Q@4607d10`1b0@@0IP8305<10P150`89
0?oooaT0oh0000<0j6Pl0=1@N03oP0009@3oP0001@3@D7P0X23`0;Ph]03@D7P0j6Pl00L0X23`00<0
j6Pl0?n0003oP000203oP0080?ooo`/00?l003D05nd507H^1`23FCl0QFiJ07i^H01lK6@0LF1I06]O
I@1<Cfd03b=R008HK0026WP00a]j00<@JP0B5V/0=11D05h@@@1T5dH0AR5N01lVO00:;9<01cFU00@e
[P05=k800AjJ004PW@05?/000BZ`00<f_005FMh01G?a00N:nP09Uod02j7m00VVo`0D[o`0:K[i03Zj
n00j[oH0:9_`01N=kP09QO<01H?f009glP02K>`00FGY009SiP03FM/0153@02U0Z@1C;Gh0DBah04T/
M`0204@XM@0G03lTLP128fd0AR9V04`PG`1E75H0FaQ=06LIA`1Z5cX0Ha0/06497`1T1A80I0<906H2
1`1b10l0M`/K08@54@2C1QD0U10T0:Y>H@2aEVX0PQD`01Bf3`00o`00203oool;003o0003043P003o
P000oh0000d0X23`0P3@D7P00`2h>;@0X23`0:0Pl00U0:0Pl0H0d51h00<0j6Pl0?n0003oP0002@3o
P0000`1XZ3`00?l00?ooo`0:0?ooo`002P3oool0F01<6@X0;P4103D20P0d0P80:P4202`20`0T0@80
7@8203D21@1@0080F@4206@11@1a0@T0OP@<09<<5P2_5ah0/0hC0;0:3`2d2Q00]`XB0;l=50384A<0
cQ@B0=4D4`2o71h0M4eA0=GKgP3Cf=`0dl360;8f?@3:6ah0eaTL0><M7P3/7A`0l20O0?<Q8@3e9RD0
kR<S0?8Y:@3a:BL0lRd^0>h]=`3Z;ch0j2m20>L/?03V9c00jBP/0=lY;03POXD0f:2/0<R;U`3SVZD0
]R@]0</H703<51`0c14G0<LC4P34>0/0hHdF0<Q/4@2e5``0_0lD0;P?502X:BP0fl2n0<cBe@39d=<0
^IjW078I802VRH`0UZ6Y0;G3bP2lb<d0[ko30:Ri_P2BXjP0:APP04/C700]1@h0@0X@07863P2:0PX0
S`<:08`5201i0P<0K@8205/30P180`890?oooaT0oh0000@0d51h0?n0003oP000j6Pl5@3oP0000`3@
D7P0oh000?n0000<0?n000050;Ph]02P8?00^3Rd0?n0002h>;@01P2P8?000`2h>;@0oh000?n00009
0?n000P0oooo3000o`00C@1_Fa40P6=407ARB`1cHe40MVEH06YNFP0b>ET011MK008GJP025FX011IZ
01<@FP0l2d40F0df04X@A00W66803BN500D`VP02;j800RfR004PT`006hd013F^008Z[@02<;/025CN
00=9f@05Bm`026_d00=kn`05P?T00WWg009hm`02N_L00W[e009em001MoH00G7b00=cl`03KN`00VKW
00=Rh`02G=d00ESE009Ee002EM000U3:00=<aP02B;l014>h00@o]004?k0013nb00@k[`04>JX013NY
00@cY@03<Il0136K00D]U`07;9<022V900/WP`0@9Gd06B5/01/BA`0T2Rh0BP`[06@780201Q80S`@>
09d84@2N2180V`hJ06`RB@0DAcD00?l000P0oooo3000o`020?n000X0X23`00<0^3Rd0=1@N02h>;@0
<`2P8?020=1@N0030>QX?03oP000oh0000<0oh0000<0d51h0:0Pl000o`002`3oool000X0oooo05P0
DQl;03@30P0c0@80>@8303410P0[0`@06P4200`10@0Y0P<0D@8305`10@1[0P@0N@<:08<53@2C2100
Z``A0:l83@2a20d0]0T?0;P94@2m2a80`@hB0<<?4P2n41<0K@/?08R8R`3:e]T0c/oE09]BG@2Q4QP0
Z@dC0;<=4P303Q40eQHH0=DA503L5AX0fQ@F0>4I6P3U6a`0iQ/K0>HO7@3T8B40iR@T0>LT9`3U8bP0
ib@W0>dW:@3V92H0eCU10>B3TP3QQYL0bUMT0;PG702h4A@0/P/@0;P>4P2^7@L0dXHD0<b9602E7`@0
VP<909T42@2B4180/gYh0<_@dP36cm@0cLW?07m3C028@D<0aLC40:Ve^P2g`/L0/Ko409NW[P2DYJd0
UZ>Z038I800j2A40;0D?044:4`1^1`h0N@4307l110250PH0O`8407810P1L0@40C@<12@3ooolI0?n0
0080X23`00<0^3Rd0>QX?03oP0008P3oP0001P2h>;@0X23`0=1@N03@D7P0j6Pl0=1@N0H0X23`00<0
d51h0?n0003oP0002@3oP0080?ooo``00?l004d0IW/@07YO>01[Fd00JU]306aJB@0j?DX00aI;008F
H@024fD0111L01X9AP1>2S00E`dd02L>B`0:6W<00bF;008ZU@01:iT00BbR008`Z001:j800BnU00=7
aP06BM001D7?00MJh`07E^800C[<00=@g@02HNX00V?Z005Qj@00G^H00VCY005RiP01H><00EoO009O
h002H^800UkK009Lf002GMH00US?009DaP04E<H025K300MA^009Cj`034fT00i;W00ABID064jF01I;
TP0FB8l054R=01A5R`0@@8P033^600PfQ@06=8L013:600@^Q`02:h/00R^?008XS0038Wl011a`00/I
J00S65P0D1@o07P;902M3AP0X`T=09H;6P1;9F804b99003o00080?ooo``00?l00`3oP0080:0Pl080
d51h>02P8?000`3@D7P0oh000?n000020?n00080X23`00<00?l00?ooo`3oool02@3oool000X0oooo
05P0ER4<03T20@0j10@0?0<403020`0P0@804@0100X10P0]0`@0FP8306D20P1/0@<0LP4407X11P29
0@H0Z0P=0;493P2`2@d0[@P<0:h8302`20d0/PT@0:h93`2N31<0=`lB0:fj_039dmD0_J>]09@K902[
3a<0/0lD0;L>4`364AD0daDG0=LD5P3P6AP0iR0M0>dS8@3c:B<0lb`V0?Hh;P3b@SD0l4]40>a>C03^
CDT0lD@n0?M5?P3e?cX0l3He0>@g?`3S>4<0h2`b0=@L7@3:5aX0`a8E0;T?3031E0`0e9PA0:=11P2K
30P0VP<;09442P1d51L0cKRi0<C?d@35cM40_:Zb05`E7P1oEE/0V:N]0:jl`031c]00`<k@0;g9cP2B
XJD0UZFX06eZK00O1`h08`4<050C801`1@d0M`4307<00P1f0@@0N08307L3101Q0@40DP<02@3oool7
0?n000030=1@N03oP000oh0000h0oh0000@0d51h0:0Pl02P8?00d51h903oP0030:0Pl0030?n0003@
D7P0X23`00L0X23`00<0d51h0?n0003oP000203oP0080?ooo``00?l004d0@KT907aM<01/FSh0K5]4
04i5A@075CP00aQC008BE`093E409`Lf04D89`0h33P05A9I00DMM`039XT00bZE004XV@02;9l00C6W
00<j]@04A<4014O500=@d`04B/l013Fn0090b004A<d00cK30094c@02F=h00UWL009HfP01EmT00U[J
009Jf@02F]L00e[@00EJb@09F/@045fl01UQ]@0UJ[D0<6^Y03Q^W`14LIh0BWBH05EmV`1GOiH0G8>C
06>5UP1]SIX0M9>O07BBWP1cT9`0KhfG07REX@1kV:D0N9NR06b;VP1NOY40F7V>04MXPP11I8<0<EMn
01i6MP0B>7402Bea008TL@048g@03B9_02TOHP1N6D40TPlO09XC9`0i:fl02EXm003o00080?ooo``0
0?l000@0P<000?n0003oP000j6Pl1@2P8?000`2h>;@0d51h0;Ph]00k0:0Pl0030=1@N03oP000oh00
0080X23`00<00?l00?ooo`3oool02@3oool000X0oooo05P0H2/>03`50P0d0`80<P@402020P0H0P80
508100l10@0e1@H0H@<506@10P1Y0P<0L@8507T11P290`P0YP/?0:l@502X3100Y@P:0:D72P2X1Pd0
[0P?0:@83P1a2`l0A4520<G@dP3?`l/0VDME0:`C6@2h41<0a1DH0<lG6@3M6ad0k2<S0?@Y9`3i<B/0
o3T`0?e1>P3k@Sd0oTm60?mTF@3nQG`0o:VZ0?fka@3mZJ`0oH>00?m_J`3oJF80oeQD0?mDE03nBT`0
o4950?Pi?03_:bl0j2HV0=Dd403RUaL0d7lC0:/M1@2b2`d0Z@D=09@;3`2[KFh0dLg?0<G@d@3<cM80
PEaU05/=5P2?OX00SJ6T09f_/02M[K80Y[Nm0;K4c02R/KT0VJF]05]CG00^31@0;04904H4301_10X0
N`8607<10`1/0@<0H0<306l51`1U0@80E`D12@3ooolH0?n00080^3Rd00<0oh000>QX?03oP0008P3o
P0001@3@D7P0X23`0=1@N02P8?00oh0000T0X23`2`3oP0080?ooo``00?l004d02oL306im7P1XCBh0
GU5400`F<@0254H00aAC018;@@0l22T0>`PY01@<@P035VD00b:2008WS0019Xh00BbJ00<bY`03>[40
0cbf0090_003AL@00cfm0090`@03>[h00BJY00<^/`06BL/014c;00==b`02D<d00e;:00ID`P09E;d0
4UVi01mS/00bJjT0AGBS05MoW01RQIP0K8^F072<T@1fSi<0O9>D08>IV@2=XJ80TJ>T09Z][P2Q];<0
YkZh0:fo`02aaLD0^lg<0;g>d02lcm00_loA0;S9c02ga/T0ZK^n09V`/P29XZH0NYBI06b9RP1UPH<0
GWYo051`L@15IFL0>UaQ02eBG00SAUd04cQO00P]J`0<;7X0>2Y`070SEP0T;WL03e/h003o00080?oo
o``00?l000@0@>000?n0003oP000^3Rd102P8?020=1@N3l0X23`00@0d51h0:0Pl02P8?000?l02`3o
ool000X0oooo05P0BTh704470P0^0@408@4101410@0C0@407`8301T10@0Z0`<0F`P906041@2>;S<0
LPT?07@21`250PX0XP/A0:L>4`2O2a00X`/@0:D6302X1``0ZP/?08l>4`0i4A40WJJW0=C1b@2ZCU/0
]a/Q0<hJ6`3F71`0hB8Q0>LR8P3b92D0nRPT0?X/9@3n=Bh0o3D_0?Tc;@3k=C00nS/e0?Y2>`3d@T00
lTI>0?=<F@3a@dd0mSi30?He>03g=3L0lR``0>`Y;03Y9bh0hAlY0=dQ:P3J7B80d2XA0>9m503PYA@0
a40:0<`J50384Q@0`10D0;52@P3Pb<T0bm?C0<KAdP32/[X0IAPR06`M902@TIT0W:nf0;K6bP2f`lP0
[K_10::b^@2EYZh0If]g02/?700l3aT0A0H<05d52@2::Bh0M08807800P1T0P80E@/<06lG601Q10<0
F0T12@3ooolG0?n000030>QX?02P8?00j6Pl02D0oh000P2P8?000`2h>;@0oh000?n000080:0Pl003
0;Ph]03XJ3`0oh0000T0oh00203oool=003o001<02k?2`1SAAX0:RPX008E=`035D806`he03d87@0T
22d01`mB008JJP028Wd00RN;008XT@02:iH00S2Q008cZ001<jT00SN/008i/002>K<00SJ]008f[003
>KD00BNS004WY007AKT02djb01YHZ00cIj<0C7>N05aoV@1TQ9D0JXJA072;S01kT940OY:B08>HUP2A
Y:80WJj]0;72`02kb//0b=;E0<[Cf035cM40a<K:0;Vi_P2][[D0Y:FZ09fMX02BTi@0SHb>08R6R@24
P800OgYi07QgM@1hM7<0Lg1/06a^I`1XK6H0HfYV05UWH01GI600E69Q04aQGP18HU`0?eeH03]JD`0j
Ee40=eEA031BD`0RA5L03CEZ01<gQ@0><gT02ZdH003o00P0oooo3@00o`000`20`000oh000:0Pl003
0:0Pl0030>QX?02h>;@0X23`01h0X23`00D0^3Rd0=1@N03@D7P0d51h0;Ph]0030=1@N0030;Ph]02P
8?00X23`01P0X23`00<0D91h003o003oool02P3oool000X0oooo05P0Agl904L<0P0/0@40904102H2
0P0W0@40<08202@10@0K0@80@`8206`31P1n10/0N08906l11P2610/0X@`B0:X?502Z31<0Z0L>0:/6
3@2c2`l0[PdB07/62`2LLG@0fLo@0<9SK@377RD0cADG0=@H6P3E61/0eaLI0>0I6P3`7ah0nBLQ0?/Z
8`3j;RL0nTA00?Tk<@3lA3H0nTPh0?QD@P3gJUP0lg=Y0?AhL`3fMFd0nfAI0?U@A03mCD<0ndLo0?To
>`3d=C@0l2l^0>XV9@3F<A00iH8K0>6Y4`3AL@l0`AP:0<4=402o3180[1HI0=6SX@3?dM<0bm;D0<kA
eP2LIg@0NQ4I0:1YJ`2LZK00TjJ]09^_]02AXjP0VJZa09Z[/`2Q/[X0UiVQ05Xh@P0e3AL0>`@;06/9
3`272@l0P@<807<10`1O0P<0D@8305`4101H1@40ER032@3oool00`30X000oh000?n0000D0?n00003
0>QX?03oP000oh0002@0oh0000H0d51h0:0Pl02h>;@0j6Pl0?n0003XJ3`90:0Pl0/0oh00203oool=
003o001<00_g0`1iEBD051XP008E=00E2BD0>@TJ01D68`0455D00Qeb008TO`039XD00RF900@XT`01
9i000BRF008XV@02;9d00SBS004dYP03=jX00c^^00<jZ@08?J<06d:B03ACR`1<KXl0I8:B06n8S01e
Rhd0Mhb=07^AT027W9T0U:NT0:bm^@2mblX0`<_=0;o5b@2e^Kl0[:ba0:2JX@2>R8d0PgYh07edK`1j
LFP0NfiQ07]/FP1kKET0O6eF07IUC01cITX0LfQ=071VC01eJU40MF]D07=[E@1aJ540LFM=06iTBP1b
IT`0LVU?071VB`1`ITd0K6E<06YRAP1UHTH0G61705=MA`1=Fd/0@UI:03]EC00jF4d0:TU401HmD00A
>T<00o83003o00P0oooo3@00o`000`10h000oh000:0Pl0020:0Pl0030>QX?02h>;@0X23`01T0X23`
00@0^3Rd0=1@N02h>;@0^3Rd0P3@D7PB0:0Pl080^3Rd102P8?020;Ph]0T0X23`00<0:<Pl003o003o
ool02P3oool000X0oooo05P0<k/9048=0@0]0@40:@4202l10@141@<0C@L803020`0E0@40=P8306`3
201l0@H0O08707@11`2;1P`0YPdB0:P:402Z2A00[`X>0;<83P2k3180[@P=098D603:VId0cIbT0;XO
:P3<4AL0c14B0=LE5`3N61X0iQXM0?0P7P3m;R<0oSLZ0?lk;`3k>S40oeA@0?a?AP3oHU@0og=Q0?nC
P`3ob/D0onO/0?o/mP3ohND0ojRV0?mlM03oKF00of]N0?mGC`3nAd@0odE20?`k<@3aKQd0ij`L0>F^
6`3A@`T0fQXH0=0C5@3?51P0^d930=c@d03;dM@0bM7C0=7:d01k9S80N0lF0:^=T`2W]l00//;70;g<
cP2halL0/;k009JV[P1kSYL0H6Me02/E901<>440CR/b06863P2A1P`0R@<707T21@1I0P80C`830541
0P1@2@<0@4l22@3oool00`20`000oh000?n0000k0?n00080X23`00@0d51h0?n0003oP000d51h2`2P
8?090?n000P0oooo3P00o`00B`1CVQL07A`D00d>7`0a1aD04PLO008A@`037F/00B5o004RQ0027h00
0R:6008RS@018XX00B>:008TSP02:ID00S2L00<fVP0;?Y@09E:D04EZTP1SOY40MX^A0765QP1gRXX0
Q9NG09RYZ@2Z^K/0[;bo0:Re^P2T[;00X::U08^8R01kM700MFaR07M[G@1fJUT0NG1K07]bGP1eKEP0
L6]C06e[DP1[J4d0JFI;06UUBP1ZITT0JVI806EQ@P1UHT<0Hf5306=QA01SH4D0I6=<06IWDP1WIeH0
IfQD06EUC`1UJ540I6QB069TC`1NH4X0GF5905aJ?@1IEcH0F5Dc05YF=01HECP0DeLo051GA013ED<0
=Dho02Q8>@0TFb`00o<2003o00080?ooo`h00?l000D0oh000=1@N02P8?00j6Pl0;Ph]00H0:0Pl003
0;Ph]03@D7P0^3Rd01h0X23`00D0^3Rd0=1@N03XJ3`0oh000;Ph]0060:0Pl00302S8?000o`00oooo
00X0oooo000:0?ooo`1H00[f0`1D80H0<@8103420P141@@0F`P705D72@0^0P803P4102`10`1[10L0
P08708041`1d0PD0SPD;0:D83@2[1`d0ZPH<0:/52`2`1PT0]PH:0;4:3P2T<cD0j;:h0;i8D@3F7200
fa/K0=dK6`3Q6a/0jR0N0?8S7`3l:b@0oSDW0?hj:P3l>2h0nC@_0?i5?`3f>CD0o4I10?]@B`3iF5H0
mVQ_0?EeP`3gNhd0m71i0?QOI03mDUH0ndU80?e:A@3n@Ch0oC/i0?/f=@3^?Ah0ki`S0>6d6@3KTQT0
cbP>0=/J703F5QT0cQ`O0=>5Q`3Ad]D0bm?E0<WAd`2oXJT0QAPR09M8BP2bZZl0Vj^c09j^]P2T/[X0
/Kc00;O4aP2X]k/0/;o3079bNP0Z41X0>2<_040N:@1K1P`0R@D<08421@1h1@L0E`P904`51P180P40
Da0603iA0@T0oooo00<0@>000?n0003oP000>P3oP000103XJ3`0X23`0:0Pl03XJ3`20?n000T0X23`
00<0^3Rd0:0Pl03@D7P02@3oP0080?ooo`l00?l004X0ACl?02<=400K2AL00a8e00<LGP027WD00R5o
008RQ00177h00QUm004KP`028HX00B>800<WQP08<H<09Tj904Q[R@1[QI40NHjB082BU@23UI@0UJNT
0:>e]02T/kH0W:BW08R;RP1bL6d0JFAG06UVDP1^Ie<0Jf1906QO?`1/ITH0JF1406aTB@1]JTh0KFe=
07=`D`1/K4l0KFe@06aVB`1XHT40IfA506ERA@1XI4H0JFA806QTA@1UHd@0I6=506=PA@1RGD<0GEe1
05mN@P1VIDd0HVE<06=VC@1TIe40I6ME06AXEP1QIE80GV=@05aPBP1IGD<0Ee/n05MJ?P1FFd80BE<o
04QA?@0oBC<0@U<k03Q?>`0]B3<05KTA003o00P0oooo3`00o`020>QX?0030;Ph]02P8?00X23`01X0
X23`00<0j6Pl0:0Pl02P8?001`2P8?000`2h>;@0X23`0:0Pl00L0:0Pl003052@N000o`00oooo00X0
oooo000:0?ooo`1H003o001>J0h0>PT203/40@1J2PL0H@X904H51P0Q0@802@4101l10P1U1@X0PP<9
07T31@1Z0@<0Q`870:452@2X0`P0Z`@90:h5302c1Pd0_P/?0;PE603ZPHT0aeAM0<HG6P3>5AL0cQDH
0<hE6@3>4QP0fAHJ0>XL6P3j9Ql0oRhR0?d^8P3h9b<0hQdL0>L];P3G7Ah0lc@b0?/h<03m?CD0oCdf
0?Xk=@3n@S/0oClh0?`j<@3k;BT0o2l/0?db:P3m;bT0o2hW0?H`7`3VKAL0fZX>0=2Q2P2mE`h0^Q@@
0;l>5@2k3180ZB<T0=[2``38d]@0aM;B0<W?dP2JGFL0Pa`R0<2OX`2/^Kl0`]7G0<gJg@2jaLP0^/K8
0;[4a`2[^;`0YK:e06iXK@0k5ad0<0D=04P43@1X1P`0O0@:07@21@1S1`T0NTA703h4101I1`@0E0l1
02b>00T0oooo00<00?l00?n0003oP0001@3oP0000`3@D7P0oh000?n0000a0?n000070>QX?02P8?00
X23`0;Ph]03XJ3`0oh000=1@N0020:0Pl0030=1@N02P8?00X23`00@0X23`00<0j6Pl0?n0003oP000
103oP0001@3@D7P0oh000?n0003oP000P<0000P0oooo3`00o`00BP0c/0T0<aL900XD90026dP00R9_
00<TO@028X000Qj0008NP`027Gl00B62008TOP0E>7`0@5n306^5T01kSi00QIZF08RKVP2P/Jl0XJfa
09RPXP23QXH0LgA`079]I01eKf40MW1J07E^EP1aKED0LW5H075^E`1dKeL0LFeD075`F01aKUT0LFmI
06m^EP1^Ke<0KFmF06][D@1UI4L0J69506MQ?P1TGcd0H5do065M?P1SG3l0IF1206=Q@@1PH3h0H612
061P@`1PGd00H611065QA@1QHDX0HfE>069SC@1QHdd0H6I?05iTC01KHd/0FF5905]OBP1GG4H0EEY2
05=I@@1>GD/0<TDh02/o;@10CcT0Ae<l03e>>00YLb800?l0203oool?003o00030<2P003oP000X23`
02H0X23`0P3@D7PN0:0Pl003003o003oool0oooo00T0oooo000:0?ooo`1H003o0010O`P0?`L104h7
101P30T0F0X803810@0L0040304001810@170@D0J`8406L20P1R0@40O`030:852P2Z10T0/0H;0;<7
2P2h2Pd0^`X>0;hL8`31<c/0]Q<J0<0>4P2o3A80_`hE0;h>5@333QD0fAHI0>`M6`3j:2<0o2`R0?d[
903j:bD0hRl]0>ETI`3871l0m2l_0?`d;03l>B`0o3P[0?/f:P3j=R/0ncL^0?dg:`3l;RD0o34X0?`b
9`3j:b80n2TL0>Tc3P3f[BX0f;8=0=JL5@2[:`<0/@P;0:d63P2P1P`0X4=40<k=c`31c]40_lo@0<c?
dP1m<3X0PS0f0:>LXP2;XJT0[<390<cMi03<f^40bmOL0=CMhP3;f=`0]L7408IjOP1L<ST0@0H=06/:
4`284QT0PP/A06d1101I0`D0EaDI06071`1X1P<0F18302nA00T0oooo00<00?l00?n0003oP000>@3o
P0000`3@D7P0X23`0:0Pl0020=1@N0090?n0002P8?00X23`0:0Pl03@D7P0X23`0=1@N03oP000d51h
0080X23`00<0d51h0?n0003oP000203oP0000`20`000oooo0?ooo`060?oooa000?l004T0@dP>00TJ
<P027e/00R=b008UO@039XD00R>4008QQ0038GP07Ceh05AaR021U9L0T9nO09:TX`2M[jd0UjBV08F>
S@1`L6`0J6=K07akKP2DThH0Z:RT0<K3``31_L40[jf`0:6QW`2>THX0RH]o08V9N`26QWD0PX=_07eo
K01jNF`0MGUY06ieH`1^M680KG=R06]cHP1YKe`0IF]G061UC@1NHDL0H69805mPA@1MGdD0G61505UP
A01EG3h0FEe005ULA01LGT@0Fea405]NB@1JGd`0Ff9@05iSC`1MHTT0Ff=:05aUC@1PIe80GF9<05]P
BP1GG4L0D5E1059LB@11DdD0;T@e03mC@01>Gdh0D69@051H@@0oB2X00?l000P0oooo4000o`000`3o
P000X23`0:0Pl00B0:0Pl0<0d51h;`2P8?000`2h>;@00?l00?ooo`0:0?ooo`002P3oool0F000o`00
=9T604D90@1D30L0D@T504@71@0Z00008@4101<10@0?0P40:`4204l21@1G0P<0I04508011@2R1@X0
[PL;0:l9302`2``0/`T<0;@9302a2`l0[`XA0;D:3`2l3A00`0hA0<8>4P3:4a@0fATH0>XU8@3_:R40
l30V0>lf;@3/?C<0iShf0=eVI03PX:D0aU9@0=A<@P3BCT<0cU=60<]CA@3<ETL0c5M80<MCA03:EdH0
ae520<Q@@`38C3h0c4Tj0=58=P3:FBl0eJ]10=2b=03@TC00^3@E0;hO702T4A80Ta8D0:mcM037c]40
`<oB0<GBe@36`LH0KAPP080oA02c^;`0W[>i0<7BfP34eMd0_loF0<[FgP3:fN<0a=KP0<??e`29MGl0
EQ0I05h73@1W10X0PPP>08L42@1/0@80EP4206892`1j2PL0J0P205HE0@0[XP490?ooo`03003o0020
`000oh0003T0oh00102P8?00103oP000d51h0:0Pl02P8?020;Ph]0040:0Pl02h>;@0d51h0;Ph]080
X23`2`3oP0000`20`000oooo0?ooo`060?oooa000?l004T0?8L>00lL<@028F4012b2004WPP03;I00
0RJ2014aM01;I7l0P92E09:PW`2HYJD0TinP0869R01XKFH0If=D06aTC01_IDX0Mg5F07AaF`1hM6L0
OGYd09NAU02JTiT0RHB6085nN`1jNVl0NWY/07UjJ@1eNF@0LGAS071dI01^MFL0L7U[079lKP1ePgH0
Kgib06AhKP1OMF`0FViW051WH01;HUL0C5mE04iQEP1;GeH0BEeE04UOEP16Fdl0B5]?04QJD018Fdl0
AUQ=04QIE01;GeT0Cf=J05ISE@1OIEL0IVaL069]F`1SKUd0IfiN05]TD@1BG4P0D5U604YJCP0fC400
?5A1051TE01FIeT0FFaQ05]WE00kKRH00?l000P0oooo4000o`000`30X000X23`0:0Pl0150:0Pl003
003o003oool0oooo00T0oooo000:0?ooo`1H003o000XaPL0Ca@004H:100c0P40;@4202/10@0Z0P80
8@8101810@0J0@00BQhO07Lo@P1V0`T0P@4609d62`2/3100]1<B0;@A402e3Pl0^`h=0;d@3`3051@0
a1/G0<HV7P31<2P0`3de0;e9?@33GE00_fiM0;MfI@2dOW00/8Mj0:j>P@2ZThT0X9NA09VLV`2ETh`0
UY6709>AR02>SXL0S8b308^<P`27RH00QXZ008F9O`23RH40PHIl0824N@23Q7P0PX9b07inKP1jOVX0
N7iS07ihG`27LV40QfQI07iNC`1jFTh0QGYf096JW@2KZ:/0YK6e0:>GVP1j8B80WgAh0:bk`P2/`Ld0
]LSD0<CFh03<fnH0d]kX0<kKi@3<g>D0c=GP0617E@1X3aH0Q1HG08H?4P2U4AD0X0P;07h3101T0@40
I@8307850`1V3`<0GAd101_<00T0oooo00<00?l00830003oP000203oP0000`3XJ3`0oh000?n0000?
0?n000030>QX?03@D7P0d51h00<0d51h4P2P8?000`2h>;@0d51h0=1@N0030=1@N0D0X23`00<0oh00
0>QX?02P8?000P2P8?00102h>;@0d51h0>QX?03XJ3`20=1@N0030:0Pl03oP000oh0000T0oh0000<0
P<000?ooo`3oool01P3oool@003o001902;F2P0Y9R400R5L00DkVP04=i/01SB802Y7L01WMgl0PHj:
08FAS`1nRXL0Jg9/06ASDP1_J4l0KVa@06i[D01_JDl0L6Q;075YB01]ID80Kf=307EXB01iJe00Og1G
081cF`1nME`0NWAL07YcF`1cLEP0LG=K06icG`1WLFD0G6aU04]RG@0lEe@0<Di<039@C00aDTd0>UUD
03QED@0]BdL0:DI102Q3?@0U?cX093di020j=P0M>SH07C`h02@n>P0bA3/0>TTl03=6>00O>S@063Hb
03QAAP1?GTh0H6]M05iWF01OJ5P0H6UG069ZF@1HHU40Cem>04UKD00oETT0Bf5C05MZF`1MK680GVeR
05][G`1OIe@0:ZTH003o00080?oooa000?l000<0P<000=1@N02P8?003`2P8?000`2h>;@0j6Pl0=1@
N0020=1@N0030;Ph]02P8?00X23`02d0X23`00<0T71h003o003oool02P3oool000X0oooo00T00?l0
00_g101KB`H0?`/102`20P0/0@80<`4202l10P0`0P400P0Q0@80C@1H;C00PTQ=06l62P230`L0Y@h@
0<8R8`33:RP0_R/W0;DZ9@2]<RT0Wd<h09YCB@2FHeT0SgY^08f:P02BU8X0UibC0:6YW`2W/jT0]L:i
0;K0^@30al40_/Bo0;Bm^02ha<40]lC30;W3`030alD0_<G40;c3a@2naLH0_lS70;_6a@2h`/40];no
0:fj^P2W]KH0YKJb09RXY02CXil0RibH08>FU01jSXT0MH^407>7P01_Pg/0JWeg06aoN@1[O7H0JGYc
06IhM@1SMW00J7=Y07=ZG@1`Lg40NhZA08NGX02HZkH0/<GA0;W?fP2gc=L0`=?M0;oBgP35d]`0S7En
05/O902cQHP0N20V0:@?4`2/3@h0U0H807d20`1_0P40J@D206@H0`1_;`808=0100T0oooo00<00?l0
043P003oP000203oP0020>QX?0T0oh000`3@D7P<0:0Pl0030;Ph]03@D7P0d51h00L0d51h6`2P8?00
103@D7P0^3Rd0?n0003XJ3`90?n000030830003oool0oooo00H0oooo4@00o`00B01?NQd042I=00M5
Y008>hl0<dUV05eSH@1eN7D0K7=_061TF01SHTX0LVQ;06eTA@1_Id`0KFU@06YVBP1_Jdd0KfU9079W
A`1iJd`0N6U607EW@P1eIT@0LFA007=TA@1hJTl0MF]C06]XE01SJ5H0IVaN05e/HP0oDdl06cLd031?
B01XPg/0XKB^0<KAd03<d]@0/[Fb096@R@1eMfT0L71L06e[E`1_J5H0JfIA06a[E01ZJU/0HfIG061T
D`1UIU80I6=@065RCP1BFDD0A5=203E8>01@Gdl0GfUL05aUE01OI500H6=>05aQD@1DGe<0BeiG051T
G@1MLFL0I7E[06MeK@1TM6`0HW=Y061]H01RHTD06=@8003o00P0oooo4@00o`000`3oP000X23`0:0P
l0070:0Pl0030;Ph]03@D7P0X23`00@0X23`00<0d51h0>QX?03oP0000`3oP0000`3XJ3`0^3Rd0:0P
l0080:0Pl080d51h00<0^3Rd0:0Pl02P8?00102P8?000`2h>;@0X23`0:0Pl00G0:0Pl0030;Ph]020
`0000?l000/0oooo000:0?ooo`800?l005H0C[<D04@B000h1@<0?P@304<3100g0@40>P8202X10@0S
0@40D0lC08LU:P211P/0S@P>0;0K702a:bX0XD5009=AC028HEL0P7=X07YoMP1hPgd0MhV107N>R@1k
UI80PYVG08nRX@2O[jh0[kjn0;G5a034dM80dMcP0=[RiP3Qin`0hn[b0=gSj`3Oh^/0fMcT0=CEh03>
cMT0c/oI0<k?f03;c=P0alOD0<W8e@3;bmH0b/_F0<oAe`3Gf=/0gMkO0=_Nh@3Hg^40dMWI0<WBdP2j
b<H0X;6_08jPWP20U940MH^506b2O@1UOGX0H7Ye061iLP1SNG00H7A`05icL01NLfh0GFm^069bN01c
QXh0Vjji0<3FhP2[`/l0Yko=09ZR[`0l3a`0Tf=b06X@6`2T5a`0[Q8C09`71`2;0`H0N`8206d80@1T
8040PD@4003o00T0oooo0P00o`0A0?n000030=1@N02P8?00X23`00X0X23`203oP0080:0Pl0030=1@
N03oP000oh0000<0oh005P2P8?000`3@D7P0X23`0?n000080?n00003003o003oool0oooo00H0oooo
4@00o`00B00Bk0H0BCdd01Q1OP0`A5`0EUU@069TEP1NH540HUi506]R?@1^ID<0LVM906YTAP1[JD/0
KfY=06YUA`1`K4`0KfI406iR>`1ZI480KVI706mU@`1aI440Kf<l079W@@1`ITH0K6E:06IWD`1LHeD0
?4a501Tf<00nFeD0P9F?09BQWP2>U940S8V808n8Q02FRX00QGMV07maEP1lKe40Kf9206mR?P1jJ400
PVTo08A/@P22KT`0Of]=07][C01oKU00O71H079ZD@1bJTl0KFQ<06AVC`1GH500HVEE069VD@1PIe<0
GfQM05a]J01NLVl0HWQa06inN`1bPWl0KX1h0720N`1/NgH0J7A]06IXF01]JRh04^d6003o00P0oooo
4@00o`000`10h000d51h0:0Pl0040:0Pl0030;Ph]03XJ3`0j6Pl00H0X23`00D0d51h0?n0003@D7P0
^3Rd0=1@N0030?n000030=1@N02P8?00X23`00/0X23`00@0^3Rd0=1@N03@D7P0j6Pl1@3oP000103X
J3`0d51h0;Ph]02h>;@B0:0Pl0030>QX?010h0000?l000/0oooo000:0?ooo`<00?l005D0EC<904@7
0P1N30P0H0T704/20P180P<0>0<403831P1F1``0QQ0C07HA4@1f92D0Ocdl07iKE@1gLV/0LGYb07>0
N@1eQGl0MhV307N9Q01fRXH0OHn<082BT@20U980QiRG08NCUP28TID0RI6C08N>S`1oQHH0Nh1n07j0
P01dMgT0LWEf07AcL`1bLW<0LW9b07=aK@1fM6l0Mg9_07IdL@1bLVh0N7Md07elN@1mNWL0Ogij07]j
M@1mO7L0OWml08R6Q@2UY:@0_kc10<?4b02b]kX0X:6O09nNV@2QXI/0Uj2I09>NVP2<ViT0Q9RF07Z@
S01/QH00Hgeg065kM01MMW40GWIa05ieL01LLg40Igb308>GXP2CZ;L0HfIe03T=601L5B80O10I0:@M
7`2V3`l0WP`;08/410231P@0MP/206d^0P0b_@<00?l000T0oooo0`00o`0<0?n00080d51h9@2P8?02
0=1@N0030;Ph]02P8?00X23`0140X23`00<0j6Pl0?n0003oP000203oP0000`00o`00oooo0?ooo`06
0?oooa800?l004D0>:LC044l<P1ACSX0GEa505aO@01IFCP0GUL`06EH:`1WGS@0K64k06mVA01]J4`0
K6Q>06US@P1]IdD0L6I407=XA01bId@0MFU707EYBP1]HdD0K6A206eT?P1WH3d0KfQ9059G@P1:Ed`0
K7eh04aRF01[M6T0M7=U07MdH`1hM600Kg9N09:GR@2HVX`0O7e_06A]I018FED0;TDm02m6=01EFcl0
N6e<07AWAP1eLEP0I6]H05QTE01GI5L0FVQK05MTEP1OHTh0MW9K079_FP1/KUh0IFeL06]jK`1cQ7d0
N8Z807R<R`23UI@0OiBA082AT01nTHd0N8j907B6Q@1]NWH0I6QI06]/<`0Jh`P00P00o`080?oooa80
0?l000<0`:000=1@N02h>;@00P2P8?000`2h>;@0oh000?n000020?n000060=1@N02P8?00X23`0;Ph
]03@D7P0j6Pl0P3oP0030=1@N0030>QX?03oP000d51h0180X23`00<0d51h0>QX?02P8?005P2P8?00
103XJ3`0@>00003o0000o`0;0?ooo`002P3oool3003o001C04AN1P1?30<0L18<074A301R2PL0G`T8
04/81`0d1`L0>Q@A05Pg<01QG5<0HF]S06IfL@1_P7`0M8N007R:Q`1iRHL0MhJ007N1NP1cNG<0LgE^
075aI@1_Kf40L71P079bH@1hM6H0NgMW07mkI`1lMf@0MgIR07AfH@1cMV@0MWMV07MeH@1dLUl0M7AS
07EfI@1fMF<0MWQU07]jJP1lNfX0N7]V07QjJ@1fNf`0Mge^07n1L`24QWP0QHUl092CR`2HViP0X:BW
0:ZY/02SY:X0PXN607MlKP1fMfH0NWUU07ajI`20N6P0P7QZ07miK@27PWD0T8n308jAQ@2<ThT0QYB>
07Z>RP1^QX40HW]g05mgMP1NMGD0EF][05=MG019?CT0E28V07LA5P2A51H0[CXj09hF5@2?2@H0S@`7
07T@0`1CD@800P00o`090?ooo`<00?l0203oP0000`3XJ3`0d51h0:0Pl00n0:0Pl0030;Ph]03XJ3`0
oh0000L0oh000P00o`080?oooa800?l004@0<Jh505Q27P1SEcT0HU`n04E:;P1;DcL0Ee@^06EG9P1Y
FBT0IePW06aL<01`Hc/0LFY706eXA@1^J4P0L6Y<071YBP1]HSl0KEhe06iP=@1eIC`0M68i075R=01b
ICL0MVU505YI?@1lO6X0MgEX06Y]FP1cMF<0NGER06E/GP15Edl0@UI<045AB00gBd@0=DQ502a2@@0X
@d00=e5705QYF`1`L5T0MVmD07QmJ`1ePgT0I7Ya05]`IP1NK6<0EfEH061YF01eMV40NWaZ08>9O@2;
Uhl0V:JR09j][@2S/;40VjVZ096PX@2BXJ40Sj2O092PX@28V9P0OXn<07B1N`1]KEl0MG0d037E40<0
0?l0203ooolB003o00040830003oP000j6Pl0;Ph]080X23`00<0j6Pl0?n0003oP0000`3oP0001@3@
D7P0X23`0:0Pl02P8?00^3Rd00L0oh0000<0j6Pl0:0Pl02P8?009`2P8?000`3XJ3`0P<00003o0002
003o00/0oooo000:0?ooo`<00?l005<0AX8805HA0`1^4`/0Ja4:05h<201;3@H0B2HM04E0>@1<FE40
E6QO065cK01XNWD0Jh1k06b0N`1XMW00Ig9W06U`G`1_L5/0Lg1J07UeH01lMV00OGIQ07ahH@1kNV40
NGMQ07]fHP1kMF40NW=O07YeH@1gMF00MWMP07IfG`1gMEh0MWAO07IcG`1hMF80MgIR07QiI01dMfH0
LGMX071gJ01bNV/0NWa]081oK`27QW@0QXEc07eoKP1lP6l0NGea07EjL01gNg40O7ee07mmM022PFd0
P7]V081lIP1kNF@0M79M071]F01`KEH0KFQA079]E`1mMV80OgMR07idGP22MV00Q7a[08V6N029RWh0
PXb607N;Q`1VOW`0FgAc05M[J@1DGU/0E48l06`V9P2C7bD0WA4?094:102I5@X0La8503Ia0002003o
00T0oooo0`00o`000`30X000oh000?n000030?n000030>QX?02P8?00X23`0480X23`00<0d51h0>QX
?03oP000103oP0000`30X0000?l0003o00080?oooa800?l003L0EWT906QE:@1YFcX0?d<[02<i9`0`
ACD0D5]705UI>01QFc<0I5hf06UP?01ZH3/0Jf8l06iV@P1aK4`0M6iD07A^D`1fL5<0MfmC075XB@1c
JdX0LVQ5071W@01aJdH0M6i@07A[BP1`H3/0L60h071^D`1mO6P0OgaX04eJC@0jDDP0>E5804UOE01m
SXL0b<g?0;fm``27RX<0N7MQ075aFP1KHU00Hg1R08RGSP2Y];80SIbJ06moN01aNW40P8Qg09fST@2e
_K<0a/k:0<K>c@31b/X0`<W<0080^lC600X0]/320:fh^`2/]kT0XJn`09>QXP2:V9T0NWmj07I/DP1[
Tbd02oL41000o`080?oooa800?l00`3oP000102h>;@0X23`0:0Pl02P8?040=1@N0030>QX?03oP000
j6Pl00D0X23`1@3@D7P0102h>;@0d51h0?n0003oP0080:0Pl0030=1@N02h>;@0X23`00D0X23`00<0
d51h0:0Pl02P8?000`2P8?020=1@N0030;Ph]02P8?00X23`00T0X23`00<0^3Rd0?n00010h0001000
o`0;0?ooo`002P3oool3003o001C04BW3@1F5080KAH;06PC2P1G4PX0ABlO04eC@`1AG5<0D6=K05Q^
IP1UNG40IGI_05i]H@1SJe/0KgAM07AhG`1fN5d0NGAK07YdGP1iMEd0OGMO07YeGP1jMUh0NgIN07ai
H@1hMUh0NGAQ07]eHP1jM600NWQP07MeG01fME/0MgIN07IdGP1kMV80NgQU07AdH@1/LEl0LGQZ06ig
I`1`MfH0MgY[07QkJ`1fNFH0NG]Y07IgIP1bMf<0L7AQ07=dI`1eMFL0P7m]08=mJ`20NF@0PWUM08Mg
G@24M5/0R7]Q089hH01cK5D0LfYB075YDP1fKeP0M71M07]iI@1fM5h0NGAK07aeF`1mMEh0O7=J07ed
G@23OVh0PXIm07Z:QP1SN7P0EFi^05=YH`1HEe80IRHR08lF4P2;20<0UaT>060@100WRP400P00o`09
0?ooo`<00?l000<0P<000?n0003oP0000P3oP0000`3@D7P0X23`0:0Pl0150:0Pl0D0oh0000<0P<00
003o0000o`00203ooolB003o001105b0301aGbh0De<e03Y=>`0aB3L0<4Lg03A8>@1:F4@0G69<069U
CP1TIDh0J6U?06aYCP1^JDl0L6]B07A^F01cKe@0L6Y:07AZC01eJdd0Lfi@07EbE01gMUL0NGII07Qd
F`1jLEL0OW1B07e^B01fJdL0N71B07mfG022NE/0T85M08mmFP2BOed0SgUH08UcF@26NV<0PWUM07Y/
B01fLE@0IF]E07]jH`2KTX00[ZNQ0;Jc[`3<b/<0i^OQ0?Ghl@3bmO<0j>_]0>3Tj03Hg^40fMoQ0=kS
i@3Hgn40d][N0<;;d02b_<00Z;>f09j[[02:U980NgQW07J1>`0ceQ@01P00o`080?oooa800?l00P3o
P0000`3@D7P0X23`0:0Pl00E0:0Pl0030=1@N03XJ3`0j6Pl0080X23`00<0^3Rd0=1@N03@D7P00`3@
D7P20:0Pl0030?n0002h>;@0X23`00<0X23`0P3@D7P00`3XJ3`0oh000?n000020?n000050>QX?03o
P000oh000?n0003@D7P01@2P8?000`2h>;@0j6Pl08300006003o00/0oooo000:0?ooo`<00?l001H0
4n/406@Q101/6@h0GQ/@05<a8`1:D3/0C5]:05AREP1MKF80GfmR06=]FP1YKUT0LG=L07YfG01iMUX0
NGMM07YiH01mNF80OGUQ07]gG`20MUl0P7QP0P1jMU`05@1fLe/0N7IM07ehH`1mN6<0NGMM07eiH@1l
Mf00N7AN07MeG`1fM600LgEQ06meH`1[LV40JG5Q071eI`1]M680LWMV07MiJ@1eMfL0MGIV079fI002
06idHP0T075dH`1dM6@0NGEQ07UcG@1eJe80MFa@07E_D@1jLEL0NW9J07Q_E01fJd`0NW1E075YC`1b
Je00LfeE07QeH01jMf40MW=K07QdGP1jLe`0NgAN079`E01fLeH0Ng1E07e`F@1lM640Ngeb06n0N`1P
Mg@0F6iY05YLEP1U:280QAXD08LL401=30409H/10P00o`090?ooo`<00?l000D0@>000?n0003oP000
oh000>QX?00d0:0Pl0030;Ph]02P8?00X23`0180X23`00D0j6Pl0?n0003oP000oh0008300002003o
00P0oooo4P00o`005@1YRQ@0JE`]04eG@`0mETH0@UY<049HB`0nED80@eE104]FA01GG4X0F5m=05eS
D@1WJeL0Kg9M06ebG@1aLUh0M7AO07=cG@1cLeh0NGQS07QiHP0207MgH@0X07UjJ01nPFd0N7UT07ak
I@21PFX0S8ad08Z;M02:RW00Si5d09BEN@2IVh00WY^20::OQP2VYXh0[:nL0:ncW`2e]j80_/2]0<_=
_03Qgm40n?G[0?knn@3oo_`0o_on0?knoP3mo_d0moSk0>[/l@3KhNT0d]_R0<kIh@3>eml0am7E0<3;
c`2g`/H0ZkNh09bTX@2:PW00II@h03_=60P00?l0203ooolB003o0080oh009@2P8?00102h>;@0d51h
0=1@N03XJ3`90?n000030>QX?03@D7P0d51h00D0X23`00<0^3Rd0>QX?020`0002000o`0;0?ooo`00
2P3oool4003o000=04b31P1V<aT0FTH`04e<=@1AG4D0FFMD05aVEP1PIU@0KVmH07AaEP1eLeX0N7IN
07EbFP0207ihGP03081kH@1nNE`0OWQM0080NgIM03h0P7MP07egGP1nN5d0O7MM07aeG@1kMEd0NgEN
07UgGP1nNVP0NgES07ahI@1hMfD0MGUY06efJ@1XM6D0JGIV075kK@1fPW@0O8Uj082;OP1mR7`0NhQj
07J2L`1/MVP0IW9S06YfI`1YLfD0KG=T07AcG`1bK580MFe?079ZB`1eK500MG1G079aF`1bKeH0L6Y8
07YcE`1gLEH0M6mD07eiHP1oOFL0M75H07MeGP1lMeh0NW9H07UbF01hME/0M75H07A_D`1`Jdl0K6E8
06AN@P1_JE@0M7ET06]fJP1KK6T0F5aI04l/8@1B5`T0?Ph1017400800?l02@3oool4003o00030<2P
003oP000oh0003D0X23`00<0^3Rd0:0Pl02P8?004`2P8?00103@D7P0oh000?n00020`002003o00P0
oooo4P00o`00:P0o_0`0JeX[04UF@P18HE<0AEiB04iUF`1FKEh0FF]L05aWF@1OIe<0FV=>05=NC@1E
HU@0FfMJ065_I01VLFD0Jg=W06ahJ@1`O6`0MGia07N0L01jPW00OXIg086;OP22SGd0Phim08FAP029
UH<0T9V:09>KS@2IXY40XZjM0:nkZ`2oak/0dMG=0>GWh@3`l^d0mOOd0?[kn@3no_`0oOkm0?kooP80
o_kn0140o?gn0?Sin`3/l?<0hn[^0=_SiP3FgN<0dm_Q0=;Kh@3=f=d0am;H0<K@e02nbL/0]Kno0:BX
X`2AQVh0JiTh02WO4@0:003o00P0oooo4P00o`000`20`000oh000:0Pl00N0:0Pl080d51h00<0j6Pl
0?n0003oP0003P3oP0000`2h>;@0X23`0:0Pl0030:0Pl0030=1@N03XJ3`0P<0000X00?l02`3oool0
00X0oooo1000o`006@0Wf`/0Gd`S04m;;P1JGT80HfE>05YNB01DFDH0HFAB075_E`1hME/0NgUR07ei
G`1lN5`0OGEJ07YdFP1kMed0NgIK07afG@1mN5h0PWYQ07efG01lMUX0NgII07afF`1lMU`00P1jMU`0
:P1jMel0NWYX07YlJ`1iO6/0MGU[06efK01ZNW40HgI]05M^IP1CJV<0CfUT04YVH@1:HV40B69O04YT
G`1?If<0DVUU061eK`1[O7H0IgMb06MfK@1[Lf@0Kg5L07=aF01dLEH0LW1G06i_F01^K5@0MFeA07Uc
E@1kMUd0NWUS07elI`1oO6T0MGAO07QgH@1iMUd0NWEJ07]fFP1hLe`0Mg=L07E`EP80MG5H00X0LfiE
065OAP1EF4<0Addi05MIA@1_KE`0FVEI05EMD00j9QD0>R410`00o`090?ooo`@00?l000<0P<000?n0
003@D7P0C02P8?000`3XJ3`0oh00003o0002003o00P0oooo4P00o`00900;m`<0NV`P055D=@1:Ge00
DVUL05I[HP1IKfH0HgM]06]kL01aOFl0K7UY06MfI@1WMFH0IG9U06EdJP1WMfh0Jg]c06YlM01cQh40
N8Z707^@RP23VI80RijI09BVY02GZZH0Yk^d0;?6_@31dLH0eN7G0>caj`3hn_L0o?oj0?koo@3nooh0
o_kn0?kno@<0o_kn01@0oOkn0?Ojo03bm_L0k>ob0>CYk@3LhNH0g>;X0=CLh03BgN40d]cO0<oHg@39
eMT0am;D0<G@dP30b<T0ZjNQ0:6>M`1aWDD0CklX01K`2@`00?l0203ooolB003o0003043P003oP000
^3Rd01P0X23`0P3@D7PC0?n000030=1@N02h>;@0X23`00@0X23`0P3@D7P00`30X000@>00003o000;
003o00/0oooo000:0?ooo`@00?l00100=<D=05I:7@1VHSd0IfM7055A>01MGdH0Eee805eVE01_L5T0
LW5D07MfFP1lN5h0OGUL07]dF@1kMU`0NgIN0P1nN5h0?`1oN5h0OWIJ07aeF@1kM5L0NgEJ07]fG@1j
ME`0MgIO07IhH@1hNVL0LWQU06U`H@1TKV40DF9I05]cK@0lF5@0940m02M4@016HU/0HWmd06f7O01l
THL0KXIk05MbI`0_CD807S`d01D_;00I<340;TM704eTH01PK6<0JVeN071`GP1UIE00K6mH07QdFP1m
M5L0Ng=E07aeE`1jM5`0PX1[07emJ@1cLeh0MgIN07YdG01jLeT0N79H07]dG@1mMf80N79K079/C`1f
L5D0MW1H079]E`1NHD`0B5E302U0<P0V>Rh0EELo06Y[DP1HI540@chY02i?0@03003o00T0oooo1000
o`000`20`000oh000?n0001<0:0Pl0030=1@N03oP0000?l000800?l0203ooolC003o000M01cS1P1[
IR80CeQ104mUE`1MLFL0HGE/06EgK`1ZO780KGie07:1M`1dPWP0MHEk07N7O`1jS8D0OY:<08JGT`2>
XIh0U:JV09^^[@2S][D0[Kk00;O7b02ibld0a=KG0<oNgP3JinL0iNk_0?Chn03oool00P3nooh0603n
o_l0oOgn0?_lo@3gnOX0mOKh0?7dm@3/lO40i>_/0>3Wj@3Qj^X0gNOX0=kUj@3Li>P0fmoU0<gFfP3=
e]T0b]?F0<[Ae032a/D0/ZbP09jKM01R/Cd0@=0O00ch1@l00?l0203ooolC003o0003043P003oP000
^3Rd01D0X23`00<0j6Pl0?n0003oP0004P3oP0002P2h>;@0X23`0:0Pl03@D7P0X23`0;Ph]03@D7P0
Z8Pl08300010h00?003o00/0oooo000:0?ooo`@00?l00540@9d806UL;`1ZIcl0EeXk04=:<P1?ECd0
FV9=05UUE01YL5T0LW9F07MfF`1hME/0O7YM07ehG01lMeX0O7IK07aeF01jMEH0OGMH07ifF@1nMET0
O7MI07]hF`1iNF40LGAQ06mdH`1XLf00I6mO055QD`0lDTL0;dM002]6?@0bCdD0DVQN065bIP1fPgT0
PHj609BQWP2]]KD0_/;50<?6bP34bL/0/[bb09NPU02=UX/0HG=Z03A?B`1KLg80;3lh05EMC@1cL5d0
NW=K07ehFP1mMUT0OGEI07YeF`1kNF40OGaU07AeG`1cMEd0MWEO07agGP1nMEX0OWAI07YdFP1mM5d0
OgIP07aeG01iLeT0MW9G075`E`1]L5d0E5m?03=:>`0R@3809D0`03M8=01VITT0KFI<05I8<P0PS@40
0`00o`090?ooo`@00?l000<0`:000?n0003oP0008`2P8?040=1@N2D0X23`00<0d51h08300000o`00
0P00o`080?oooa@00?l003804nd505j;8`1RGch0GV]K06QhKP1XNW40KX5f0763O01jQh40NXZ507nB
S026Ui@0S:2L096TX`2GZZX0X[Bb0:Vk_02hb<T0^l[;0<OEe`3Dh^@0hnk]0?;hm`3enOT0loSg0?Sj
n`3en?T0l_Og0?7dmP3_l_<0koCe0>[`l03]m?@0jO7a0>_bl`3/l_@0i^k`0>;/k03NinL0f>7S0=GO
h03Bfmd0dm[K0=GHg038b<T0^kB/0:nORP26X5P0D/4_02gR5A<00?l0203ooolD003o0003043P003o
P000d51h0100X23`00<0^3Rd0=1@N03oP0005P3oP000102h>;@0d51h0=1@N03@D7P2083001<00?l0
2`3oool000X0oooo1000o`00D@1NQA80M6Lk06m`D@1GHd`0AeM304IE@`1:FDP0D5i?069/F`1ZKUL0
LWAK07QfGP1nNV40NW=G07ehF@20NU`0OgQJ07]eE01jLU80Ng=G07aiH01dNF<0JWAQ05]ZF@1=GeD0
@eI>039<@P0S@3H0;DTn03aCA01BHTl0GfQC06]ZD01bJ4`0M6M807MZAP1jJdH0MFa?07ijJ`2JVHh0
WYnC08AnL025Med0SGQF099lGP2FSWP0L79S08N<P@1UK5T0E5Ln07I/CP21MEH0OgQJ07ahH01mNfD0
NW]U07MfHP1eM5h0MWEL07ehG@1mMUl0O7AJ07ebF@1nM5`0NW=K07miH`1jMF40NGAN079`FP1[KeT0
I6aJ05MTE`0cBd00;4Lm039<?P0gCcl0?eQ905mZE@1`ID@0LE/c022a0@03003o00T0oooo1000o`02
0?n001h0X23`00<0^3Rd0=1@N03@D7P00P3@D7P00`2h>;@0X23`0:0Pl0030:0Pl080d51h00<0^3Rd
0:0Pl02P8?000`2P8?000`3@D7P0X23`0:0Pl00H0:0Pl080oh0000@0P<00003o0000o`000?l0203o
oolF003o000/02CK2`1FV2L0LfU606]`F`1aO6h0MHEk07^8P@1lRXD0PY>@08FHU02;Wih0TJBU09VZ
[02Z^k/0]/G50<7?d038emT0dn;T0=k[k03ZlO80kOGe0>kem@3`m_H0lOCf0?7em`3]lo<0k_Cd0>gb
m03/lo<0io3_0>K_kP3Uk^d0i>c/0=oVj03Ji>@0h>GV0=cRg`3@d/d0a/:h0;f`X02Q/7X0PZ]D05C2
<00^haHG003o00P0oooo5P00o`001020`000oh000=1@N02h>;@=0:0Pl0030>QX?03oP000oh000140
oh0000<0j6Pl0=1@N03XJ3`00P3@D7P2083001L00?l02`3oool000X0oooo1000o`00D@1RRAT0LFU1
07InI`1PLEd0DfEC04iPCP1?Ge00E69F05m[H01VKeh0Ig1J06ibG01hMUl0OGQK07YeEP1mN5T0OWMI
07iiG@1oNUh0R8AY07anI`1XLf40C65D03A?A`0S@CT06cL/02Dn<`11EdT0FfQE06]]D@1aK4T0MfLo
08E]?P22KT00N6Q207IV@P29N500P7IE08:1K@2VXiL0]kN]09>AOP22MeP0TGeH09AmE`2BNeP0T7eJ
07i]B`1eISl0NFm>07mdG02:Q6d0QX=[07elI`1iNV<0MGIN07]gG@1nN5`0OGQK07iiG@1oN5l0OWMM
07aeG@1mMUl0O7MR07]gI01gLf00MG5M06Y^F`1UL600DUmB041A@`0bCSl0=e=403aFA`12GDd0CFEI
069`H01UHD00N6D_01oF1003003o00T0oooo1000o`000`3oP000d51h0:0Pl00L0:0Pl0H0oh0000<0
d51h0:0Pl02P8?000`2P8?060?n000030=1@N02P8?00X23`01/0X23`00<0oh0008300000o`000P00
o`080?oooaP00?l001H02_L403K94`1BYBP0IXdn081hF@1oNVL0PHAg08:=QP24U900SIbK09BUY02O
/[80Z[bk0;K5aP2ocm00b=SI0=3Qh@3Ki^D0h>_[0>;/j`3Wknl0ing^0P3Xl>l03P3WkNh0j^c`0>W/
k03WinD0hMkK0=WBc03Bakh0b[b[0:bjR@2>^6P0HL9104[<:`0]haP03?P66`00o`080?oooaP00?l0
00<0@>0008300030X0000P3@D7P00`2h>;@0X23`0:0Pl0080:0Pl0030>QX?03oP000oh0000/0oh00
00D0d51h0?n0003XJ3`0d51h0:R8?00208300003043P0000o`000?l001T00?l02`3oool000X0oooo
1000o`00D@1TS1/0LVa807IoKP1]NVh0HW=V05i_H@1OKV80HViV071lM01mR7d0MX=b06A_FP1VJDl0
KFY<071[A`1dKDP0NG1@07egG@1nNf80Og]R07UjH01UL5T0>Dlm024k;P0hCcd0DUm7065XC01]K4`0
O71:08]hB@2;MCh0SG4g08if@@1OES80EE8d065K?P1VHTD0KVmG07UjI`22P6l0O7a]06ibH01YJeP0
EUY804I>>P1aJD`0Q7=>08YfCP29LD00Q6`n089aD`21O6D0NgaT07]iH01nNel0P7aM07mkG@1nNU`0
OgUL07mjG@1nNE`0P7YP07ihG`1jM5X0M71I06e[E@1WI500HVE?05UUE@1<Gdh0AEM604QJBP14GD`0
BFAE051WG@1=IU/0E6aS065^HP1SHT<0OfT]01kU1`03003o00T0oooo1000o`000`3oP000d51h0:0P
l00;0:0Pl080d51h00<0^3Rd0:0Pl02P8?00202P8?020=1@N0@0oh0000<0j6Pl0=1@N02P8?002@2P
8?000`2h>;@0oh000?n000020?n000030=1@N02P8?00X23`01X0X23`00<0oh0008300000o`000P00
o`080?oooad00?l001X0;>4B02GL4P1:^R@0A;TX06jL@P1YX4T0JZAB07^UH`2OUGX0Yif70:nTT`2c
Z9D0_K2K0;naWP33/Yh0a;>N0<6_V02X^HL0SL5c08flK@2<]f<0I<E605W9>01?cbl0;^@L02C[4b80
0?l0203ooolM003o00@0P<00203@D7P50?n000050>QX?02h>;@0^3Rd0=1@N02XR3`00P20`0000`1X
Z3`0P<00003o000Q003o00/0oooo000:0?ooo`@00?l00500F:8H06mV@01hOV/0N8=g07R7O@1cQ7/0
LX9i07J6N`1iRGd0P92707b=PP1iRWd0JgMT06Q`E`1[Ke40KVa<07=_D`1hN5l0NWeV07j0J`21Q6d0
K6]>06MT?`1_JD@0NVi:07]aC020ME40RG]F08YhC02?NDT0TWU708md?P2?MdH0OG5=07E`DP1eLUP0
KWEM05i_H@1dP7X0OXV4055QG00X@3D0:T0b039;>`14FdL0JF]>08akD`2@N4X0RgA5091nD`26NUX0
PWaR089lH@26P640Q7mP08EnH023OV80PGaP07ehF01mMUP0MfiA07=ZC@1aId`0JVE9065SA`1JH4/0
DV5<04UNC@1;HE@0E6MH05]/F`1KJel0FFiT05M_I@1IKfT0GW9[05a_J01UKUh0Kf@m06:K80@00?l0
2@3oool4003o00030<2P003@D7P0X23`00`0X23`00<0d51h0;Ph]02P8?000`2P8?001@2h>;@0d51h
0=1@N03@D7P0j6Pl0080d51h00<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0X23`0:0Pl00:0:0Pl0@0
oh00702P8?020?n000@00?l0c@3oool000X0oooo1000o`00D00Ni@P0OVLa08B1IP24SGh0Pi2907nA
R`22UI00R9^E08FFS`1oTH/0Oi:907^>QP1fQG`0Mh9h07R4N`1gPgP0MGm^07=nJ@1dNVL0MWUX07Uk
J01lKTD0S70g09=d?@1oJd<0KViE075hI`1fO6d0N7iZ07EkI@1jOVH0Q8=V08f6I@2=P5l0SX1M09J1
HP2RSgD0Z9j>0:ZUW02WXj00T8f108EjH028MU80PGA>081cB@29N4/0TGiC0960F02?QF80S8EZ08b5
K028PVP0PWaR07iiG01lMUH0NW9D07MaE01cKU00LFa=06a[C@1[J4h0IfQB061TDP1JIE80DVED059Y
G01CJUl0EfmS05mfJ`1WNVl0J7Ua06IhL`1QMW80GgQc05mgK`1UNg00IGEZ06]VA`1eNRP05>h61000
o`090?ooo`@00?l000<0@>000?n0002P8?004P2P8?00103@D7P0oh000?n0003oP0060:0Pl0030;Ph
]03@D7P0d51h00<0d51h102P8?00102h>;@0d51h0=1@N03XJ3`20?n00080d51h702P8?000`2h>;@0
oh00043P0004003o0<d0oooo000:0?ooo`D00?l004h0EJ4H07e]AP2<TH00RYVB086FT@26ViP0RIfK
08BHU@23UY@0S9fH08FHU021Thh0QI:=08:AS01kS8<0NH]n07f;O01oS7d0Nh=e07YnK@1oMUD0QFhm
095d>`2>M4@0K6=306=RB`1ZJEP0Nga[0869NP23T800RiR809>OS`2GX8l0W9n;0::PR02BQFL0U7mE
09Z3EP2LQ5h0Vh1J09UoD02DMd40UG]50:6@H@2OUW00VI=c09BAM@2BSWD0T8ae08f6L024O6@0OWQQ
07QcF01eLE40MW9A07AaE01dM5L0LW=I079eHP1^LfH0H6aQ05MXH@1MKfP0F6iT065fK01WO780Jh1g
06QnM01YOgL0JX1i06MmM`1VOWL0HGad06ElL`1/Og@0Jg1N085Z=00/h0l5003o00T0oooo1@00o`02
0?n00180X23`00D0d51h0?n0003oP000oh000=1@N00;0:0Pl0P0oh00802P8?020?n000D00?l0c@3o
ool000X0oooo1@00o`00C@0DkPH0JHlT08AfE`2?Uhh0Qi^F08FKU`2;XIl0Rj2N08:HU@27ViH0RijL
08RMVP2;WYd0RinN08BITP23UXh0QYJ<08>CRP27TX`0RI>708R?OP28RVl0S8EO08mnD`28M4/0Qg5:
08M`B`2;MU<0OGEM07f0KP2?UhL0[kRb0:Rc/@1iRhD0F6UN05YOBP24M4P0TgY409IlB@2USf40]jEj
0<>cRP30/Xd0ZZ:209NEM`2?TW@0TI=j09BEPP2AUH@0R8Yg08>4L01oPVh0OXA_07n6K`21Q6l0RXUe
09^CP02;QgL0PX9h07MlM01`Ng<0JgYe06UkM01XOWD0MHUo07>6O`1gRXD0LHJ106j6OP1^R800KhN0
06b5O01ZOgH0KW]^06ibG`1jJCl0>/dE00H00?l02@3oool5003o0003043P003oP000^3Rd01<0X23`
00<0d51h0>QX?03oP0000P3oP0001P3XJ3`0^3Rd0:0Pl02P8?00d51h0;Ph]0<0X23`1P3oP0000`3X
J3`0^3Rd0:0Pl00N0:0Pl0030>QX?030X0000?l000D00?l0c@3oool000X0oooo1`00o`002P0hbAD0
OWY80861M@2>ViD0T:>P08nSX@2>XZ00T:BR096UY02@Y:82092TY00n092TXP2=X9l0UZBQ09>SWP2?
X9/0S9bF09NUWP2AX9`0V:FO09fVW02IWXh0WI^809jHO`2OTW<0WHe[09R9I`2AR6`0S8Mn0861N@1a
MV<0NGaQ09:>K02`Z880c<>R0>WSbP3lnN/0mO?X0>cZg`3Qh=D0e=C60<S;^`2naK@0]Kn_0;:l/02/
^k40Y;B[0:>aZ`2M[:L0UJNQ09>SW@2HX9L0Y9nC0;BSU@2WV8P0V9>308j@QP23SHL0OXf507j?Q`1h
SXL0OIF?07RAS01hT8d0MH^807J<QP1`QGh0Kh1h06mmL`1ZLE`0KfQ606b9;P0MiPX7003o00T0oooo
1`00o`000`30X000j6Pl0:0Pl00E0:0Pl0040;Ph]03@D7P0d51h0=1@N0D0X23`00<0^3Rd0?n0003o
P0001@3oP0030=1@N0030;Ph]02P8?00X23`01P0X23`00<0d51h0?n00010h0001`00o`3=0?ooo`00
2P3oool8003o000S01G_201IYRP0R7E>08J2KP2EX9/0Vj^Y09b^[02J[Zd0Vjn^09V]Z`2O/[40W:j_
09^][@2M[Zh0VJ^Z09NYYP2Q/k00XK:`09ja[P2HZjT0VZb/09Z][@2J[:/0YKJe0:fk^02la<80`LW4
0<??a`3Bg]H0f^?K0=oWg`3YknL0moWc0?oon`3no_`00`3no_h08@3moOd0o_kn0?knoP3no_d0m_Sg
0>O/j`3Fh^40b=GE0;k;c02ga<D0ZkVi0::d/P2U]k40Y[6[0:J[Y@2^[J@0[JfP0:RXW@2PYZ40TZ:N
08VMV@28WIP0Q9^G08BKV01oUi<0OiFB07J:QP1^P7H0K7Q/06acH01dK4X0DJ@U02SO4009003o00T0
oooo2000o`001010h000`:000=1@N02h>;@H0:0Pl0030>QX?03oP000oh0000h0oh0000<0^3Rd0:0P
l02P8?00502P8?000`3@D7P0`:0008300009003o0<d0oooo000:0?ooo`/00?l001l0MY`_08IhF02E
V8d0X:^Y0:6a/02Q/k40X[Fd0::d]02Q/k<0W[:b0:6f]P2P/k@0XK>b0:Zj^@2T]K<0//?20:Rk^@2Q
];@0X;Bc0:Fh]`2R];@0ZK^k0;[6b038e]L0`m?C0<_Lf`3?g=d0gNOY0>K^l03cmoL0oOgm00<0o_kn
103moOd0703noOd0o_kn0?WinP3Qj>T0e^;Q0<kJfP36e=@0^/_90;S9aP2nc<T0`/k:0;C2_P2f`[X0
]l6j0;>j/`2Y];40VZZY096TX@2;X9d0RinK08RKV022V9@0Mhb806IeKP1XL5`0K6A708E]?00Yga4;
003o00T0oooo2`00o`000`3oP000d51h0:0Pl00F0:0Pl080d51h403oP00E0:0Pl0030?n00020`000
0?l000X00?l0c@3oool000X0oooo3000o`008P0Xga80GJ`c08:AE@2GSgT0Y:NM0:Rc/@2U];@0[;fm
0:Vk_02X_K`0Z;^m0:bn_`2]_kl0YKNg0:Vk^P2[_Kh0[[k00:o2`02c`l<0/lK50;_=b`2ocLd0a=;B
0<_Je`3=g=X0f>GU0=WSi03Ji>H0i>[/0>g`l@3bmO@0oOkm0?knoP3mo_d30?gmo@80o_gm01T0o_ko
0?Sin@3^mO@0g>OW0=WViP3GiND0d=gM0=CNgP3<emP0`]3?0;c9a`2g`l00];nm0:Vd/`2O[Z`0VJVV
096TX029W9L0O8R4071jL01ZKUX0LGM4056U:00jcQT05o4:00`00?l02@3oool<003o000408300030
X000d51h0;Ph]1<0X23`00<0^3Rd0=1@N03oP0004@3oP0020>QX?0030=1@N03oP000d51h00/0X23`
00D0^3Rd0=1@N030X000P<00043P000<003o0<d0oooo000:0?ooo`l00?l001805_4:04C78@1ZZdD0
Xhib0:FKR`2/[JL0/kjk0;2n_P2``L80/lK70;73``2Z_[d0Zkno0;31`@2hc<X0^lg<0;g?cP38e]H2
0<kJfP0;0=?Og`3Dh>00fnKW0=_Ri03Li^L0hng]0>W_kP3cn?P0n__k0?[ln`3moOd00P3no_h00`3m
o_d0o_kn0?kmo@020?knoP0C0?_mo@3_m_H0jO;c0=[Wj03Gh^@0c]WL0<cGfP34cm@0^<C70;>m_`2^
];L0XJNW08jBS01oPGD0MGMQ07ElCP1IW380AKTQ03?H5`0@003o00T0oooo3`00o`001@10h000P<00
0>QX?03@D7P0^3Rd00d0X23`00<0^3Rd0=1@N03XJ3`05P3oP0000`3@D7P0^3Rd0:0Pl0060:0Pl003
0;Ph]03@D7P0j6Pl0080P<004000o`3=0?ooo`002P3ooolC003o000K01Sb300cf1`0Lji507^[DP2?
XVT0[J:=0:bZW02_/JX0^Kbh0<38a@38dm00b]KD0<OEe@37e]H0c=[K0=CPh@3Ii>D0gnWY0=gXi`3S
kN/0hn[X0>G]k03]mO@0loOg0?KinP3hn_T0o?gm00<0o_kn01<0o_oo0?kooP3moOh0moSj0>_`m03Q
jNh0f^3U0<SDe@2mb<T0[KJe0:J[Z@2IV900T8Ug08n3JP1jRU80G9hf04Nh8P0Sfa008NX@01@00?l0
2@3ooolC003o0003043P0020`000j6Pl00<0d51h102P8?001@3@D7P0X23`0:0Pl02P8?00d51h01H0
oh0000<0^3Rd0:0Pl02P8?000P2P8?00102h>;@0d51h0=1@N03XJ3`3083001@00?l0c@3oool000X0
oooo6000o`005P0ej1X0Gl/_05?2;01kXdD0XXQU0:FBN`2`XY<0^[JZ0<S8`P3Ef]H0f=oL0=kTh`3U
inT0i^c]0>gal`3/k_40k?3c0>ocmP3fnO`0nocm0?[lo@3lo_l20?kno`0>0?cmo`3emOP0kNg_0>7Q
h`3Bd=80^[Vi0:RXY02IU8`0S89b08aiG`2CNeH0WH1C052o:@18f28J003o00T0oooo6000o`000`20
`000oh000?n000020?n000@0X23`4`3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030=1@N03oP000oh00
0080oh006P00o`3=0?ooo`002P3ooolL003o000N00gj1`0bia/0;^<J03KK7`1FaC80N[E;08NaEP28
/eh0RkMU09RfL`36ZHd0^K2:0<F^U@35/9H0a[6F0<>`U`32[iL0`:bC0;jXSP2c[XH0QKQ[082aG`20
[UP0OZaC07:^A`1?`S00DL8]03kA8@0/haP06O<=7P00o`090?oooa`00?l000<0@>0008300020`000
0P20`0000`3oP000d51h0=1@N0030=1@N080j6Pl103oP0030=1@N0050:0Pl03@D7P0d51h0=1@N03X
J3`01020`0000`10h0000?l0003o000L003o0<d0oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {180.75, 0}} -> {-0.106847, -0.0454574, \
0.0105606, 0.0105606}, {{10.0625, 98.1875}, {176.438, 4.25}} -> {-17.4879, \
-6.49014, 1.7365, 1.7365}, {{107, 195.062}, {176.438, 4.25}} -> {-185.905, \
-6.57348, 1.73742, 1.73742}, {{203.875, 291.938}, {176.438, 4.25}} -> \
{-402.835, -31.6328, 1.97589, 1.97589}, {{300.75, 388.875}, {176.438, 4.25}} -> \
{-593.828, -31.5061, 1.97449, 1.97449}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1T, pdf1, pdf2, {Red, Blue}];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2T, pdf1, pdf2, {Red, Blue}];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1T, class1, obj2T, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44639 
%%ImageSize: 400 178.555 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0106283 0.238095 [
[ 0 0 0 0 ]
[ 1 .44639 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .44639 L
0 .44639 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0106283 0.245293 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0063C92C62C62962C62893AA3CC38F53
C39053C59055C48E55C58F57C48E55C58E56C18C53C28E5591AB3F61C52861C62961C72A
60C72961C82A60C62960C7295EC62800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC223
5AC1215BC1225AC12158BF20B58345B88146B7834AB47E46B58044B67F41B88141B68041
B27F40B47E43B37E43B57D42B67F42B47E42B17D42AF7C41B17E40B47E41B58043B38042
B38042B58243B68346B68346B68547B9894D5BC1245BC2245DC4265EC4265DC42700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDF1159C02356BD20829D31AD7E41AC7D40AC7D41AC7C43
AF7D42B37F46B38144B28146B28147B28048B5814DB3804DB17E48B68049B77F45B88148
B6824BB6814DB37E4AB6804AB7824BB8844EB37F4AB5834DB38048B58148B68248B38045
AF7C40B27F44B28045AF7D44AE7C43AF7D44AD7B41A9763AAA793AB07E40AE7C3EB07E40
B18143B28344B0834683A23658C0242CE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002EE11300FF0000FF0000FF0058BE2256BE22
54BC2156BD23829C32AF7C45AF7E43AD7D43AE8046AE8048AE8149B1824DB0834DB38251
B88452BE8757BE8958BE8A58BC8654C1885AC1855AC4885DC6865CCD885ECE875BCF875D
CE885ECA835BC88259C98259CA845BC8845CC8845DC9875FC7875DC5875BC08558BD8355
B98352B48353AF8051AD8052AE8252AD824FA97D48A67941A67940AC7D44AE7C44AA7840
A37338A37436A57538AA783DA9783CAD7B3F819C2F56BD2056BF2054BD1E809C2D56BD1D
2BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0058BF22AD7A3FAC7A40AB7941AA7941AB7D47
AA7E49AB7D4BAE7E4CB38050B4814FB98454BE8659C2875FC68761CB8861CF8960D58663
DD8965E08767E08566DF8363E17F5DE47B5CE5785BE4755BE57158E36A53E0654DE2644E
DD6149DF614ADF624AE1644DE36651E26651E26854E16B57E06C58E2725CDF755CDA775C
D47B60C27A5EBE8266BE896BBB8969BB8C67B78962B3865DAE8359AF8357AE8154AC8052
A77D4DA57C47A57942A4743CA27135A47335A16F33A27033A47335A87838A87738A97839
A978367F9A282BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0054BB1F7D9A2EA9773DAB7940AB7943AB7B48AF7E4FB48255B98458
BD835AC5855ECD8660D78766DB8665DD7D60E0765FE0705CD9624DD75741D44C38D44232
D53E2FD43829D23224CF2B1DD32B1AD42716D42716D52419D52117D71F17D51E14D72018
D82017DA2117D92014D81E14D81E14D92116D61F16D41E15D11E16CF1E17CC2015C52015
B420158D130A8118137C1D167F251A85302290402F974D3B9B5744A66651AF735BB37E61
B58464AE825EAD815BAC8055AB8051A57C49A27944A1753FA27239A27235A07130A37230
A57434A77736A8783654BC1929DD0B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DD107B9831A77743A87643A57443AC7747B27A4DBB7D53C17D58C87B5BD1795BD97459
D5664ED0543FCE4634CB392BCB3123CE281ED0241BD11E16D61F15D71B12DA1C13E01C15
E31C15E61B14EB1F15EB1E14EC2015ED2014E81C0FEB1C11EC1C12ED1B14EC1C13EE1C17
ED1D16ED1B13EE1C12EB190FEA180EF22015ED1B12EA1910E8180FE91A12E71A11E21912
CB120EA3030395040895080C950A0C8E07088B0A0A8409097C07087B0D0B77100C771912
78241A83382B924E3FA0634FAB725CB27F63AE8160AA7D59AA7F54A77D4CA27941A07339
9E6C30A16F30A16E2F9E6E2C9F712BA0712900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0029DD0F53BB1F52BB21799932A17544
A57647AD794DB1774FBB7653C47758C97052CB664BCC5943C44332C23427C6291DC92116
CE1E14D21911D71913DA1712E01914E11611E61911E6170EE91A12E91913E81810EC1B14
EB1A10EF1C11F22012F22014EC1B0FF42116F11F12F42015F31F13F41F14F62116F51F16
F21E14F21D12F62115F41F13F42013F41F13F41F13F11D12F21D12F11C11EF1C10E91C12
CC0E09AD0204A40205A30105A60408A001069D04089B03089703079002068F040A8C050A
8304087B060876070A710A0B6D0F0E721A167C2D258743369B604BA77357AA7C59A87A53
A7774CA675449F6F379A6A2F9A682C9665249E6D274FB61100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0028DC0E7B9930A97A47AA7B4DAE7B50B87955
C17656C56C51C65D48C14737BE3526BE2518C21D13C7150FCD1511D2130FDA140FDF130E
E2140FE41610E4130FE4140FE51610E71610EA1A10E9160EEA1A11EF1C15EE1C13EE1A11
F01C11F11D12F32113F42114F01E11F42116F52215F72317F72116F92217FB2419F62016
F62114F92317F72314F31D11F52111F82313F62114F62215F41F12F11C0FF11D11EB1D13
C90907B20203AE0306B00507AE0408A70105A60207A40207A002079E02079D0209990107
9601079302088F040B88030B81020A7B03097A070B71070A6A090869110D6F1F1880382A
914F3B9E634BA77451A374499E6E3F9A6A3597662A97662296661C4CB30B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DD117B9A34A87948AF7D52B67C5ABE775DBF634EBC4A38
B73024B61E15BB150FC4120FCD110FD3110DD7100DDA0F0DDC0F0EDE110DE1110DE2110E
E41410E61611E61611E51311E41511E5140FE91912EB1811EE1A12F11C14F42016F41F15
F41F14F31F14F62216F72317F42115F42116F22013F92519FB261BFD281BFE2A1CFC271B
FD291AFE2919FE2A18FB2616F92312FC2514F72012F62112F62012F62113F41F13EC1D14
C90806BD0809BB090ABC090BB8070AB00106AF0309AF050CA70106A70208A70108A20105
9F01059F04089701069101088A01088601078403088001067E01077D030C76030A730609
6C0707630A0764170E712D1D884B369C6448A06B44A16E3C9A69309565229260146B8307
47AB0300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029DC0D
50B81B53BA1F7F9931A97747B07B4FB97854BD6F50B459419C34249A1B15AF1B15BE1511
C7110DCE0E0DD30E0FD60E0FD90D0EDA0D0CDD0E0EDF100FDF100DE2120EE1120FDE0F0E
DC0D0DDD0E0DD90A09D9090BD70A0BD90A09DE0E0BE71610F01C13F41E14F72116F82117
F92217FB2519F92317F72117F92519FC281BFC2A1AFC281BFE2A1DFE2B1DFE2B19FE2D1B
FF2D1CFB2716FA2514FB2314FB2313FA2212F92214F92312F82211F82114F41E13EB1D14
C40502BE0908BF0908C30B0BBE070AB80509B40409B00308AE0308AD0309AA0206A70206
A60106A301059D02049500059001088B0008890107870105870006870109840107820207
7E01077901077604086E0506690808660F0A70221586422B9F6645A07245996B34936222
824E0E7B470542A90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DC0A7594219F7337
A67944AB7749B6784FBF7250BD5C42B43B2AB12518B0140EB3100CB90A0BC80F0FCD0D0B
D20C09D50B0BD70C0EDB0E10DD0D10DF0E0DDF0E0CE4110EE61410E3130FDA0D0CD30608
D20608D30609D30709D6080AD40708D80B0ADC0C0AE0100BEB1910F31E16FA2117FB2318
FB2517FB2415FA2515FA2619FB281AFD2B1BFD2E1BFC2C19FA2A19FF2F1EFD301BFE2C1A
FD2B1AFC2919FC2818FD2616FD2616FB2315FB2316F92112F92213F72014F31E12E51911
C20602BD0908C20B0AC30A09C1090CB70407B20408AD0207B2060BAE0307AD0308AA0209
A70106A80206A402079D01069801089301099002098B01078A00068B01078B02078B0208
86010787010889030988050A82040A78030776070A6B0805610D05702D1A915739A16C44
97653683531D6C3E047B4A074AAF0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DB0C9F7234A77D43AC8247
B4804AB46840B0462CAC2716B41A0EC0130DC30C09C50909CA0B0BCD0A0BD00D0CD10C08
D60F0AD60C0AD90D0DDE0D10DF0D0EE51211E5140FEA160FEA170FDD0D09D00402D20608
D30709D5090BD4080ADA090CD90A0ADC0D0ADE0E0BDD0D09E10F09EF1912FC241AFE271B
FD2A19F92816FC2C1AFB2E1EFA311FFB3521F93721F93522FB3522FD3321FE321FFF301E
FF2F1CFD2B1BFE2B1AFE2918FC2717FD2718FC2416FB2315FB2315F82212F52316D9130C
BB0404BC0A09C10C0BC30B0CBE090BB7070BAF0409AB0309B0070CAD0408A90207A80208
A8020AA80206A70308A20106A1030A9B01089501069101058C01058C02068E02078C0208
8801078802078B05098C04098A04088503087F02087C040A77050C70080A660A056E1F11
85442B99643C9163317D4E156F3E0260780525D70500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE0FA67B3CAB8145B0853CBC8F37
D0913CA23709AF1807BF100BC40B09C80A09CA0B0ACC0A0BD00C0DD30A0DD60D0CD60E09
D8110CDA110ED8100DDE1111E31411E81511EA1811EC170FEB180DE10E07D70A05D50806
D30706D40708D60A0ADA0C0CDB0C0ADD0D0ADB0D08DE0F09E3110AF21C13F92619F62C1E
EF3826EA3D2AE94331E84837E9503FE75544E85D4BEC6051EB4C3DF43628FD3121FD2F1B
FE301BFE2E1AFE2C1BFD2819FD2819FD2718FD2415FA2314F62513EF2A16E62C19CA160C
B60605BB0D0DC00E0DBF0C0DB80A0CAF080CA60307A20307A50408A70408AA0509A60207
A40107A60309A50207A102079C02079A0207980205910104880004850004890107870106
8201057C00037F01058202058604078202077F02087E02087F020A7F030A7B0409750609
6A09056A1A0A87482999643B8C5C2A74410C76400345A90400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0049AE049867197D9A2BAA7942AF7F3DBE8F33C39822CD9D18
DF9922AC3201B71001C10A07C10606C40707C90B09CC0909D20B0BD70C0CDB100EDC120E
DA120ECC0D0AEB2F2CD3100EDE120EE71410EA170FED190FEE1B0FF11C12E7160DD70803
DA0B08D80A06DA0C09DA0D0AD90D08DB0D07DE1109E01008EB190EF82418F4281DC41C12
EA7B6CFBAC9FFEB5A8FFC0B5FFCCC2FFD3C9FFD7CCFFD8CEFDADA3E24437F83522FF321E
FD2F18FD2C18FE2B19FE291AFE291BFE2719FC2615F72A1AD82312E45945F17F6DB53126
AC1711B5130EBF1311B80C0DAF090DA6060A9E0409980307980407A00609A40507A50205
A40206A20105A60308A00206940003930004970305940307870105820105840005850005
8101057700017700027900027A00027700037601057601057A01057C01057D01067F030A
7C050B720807660A026C210F8C533398643B834E1D6E370260740326D60300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB00A9B6A29AD7644B26F48A05127A96218D0991ACD9F08D2A306
E49D19AF3300BC1504C20B07C00607C40807CB0D09D00B08D40B0AD80E0CDA0E0DDB0F0E
D40F0EB70302C21210C00402DF1610E8180FEE1B10EF1C0FF01C0DF21D11EF1B0FE9170D
EE1C13ED1C12DC0E06DA0E08D80E06DE1108E7170CEF1D11F92518FD291CF22B20A6110F
B6766EFFEBE6FCEDE8FCEEEBFAF1EDFBF3EFFBF3EFFCF0EBFFDFDADF6258F23927FC311D
FE3019FE2D18FE2B17FE2918FE2918FD2818F82616E62D1E941206E0A193FFE0D3F6BCB2
C86A5EAF3328AE1D17AB1411A4100E9C0A0A9408088C0A098A0D0B870A0696100BA51311
A10707A20407A6060B9F02089801089201078F01058F0205870104840004860004890206
8601057F01037C01037D01047A00037701047300027200027501047A01067F0207800207
7E02087B03077703076D07065908026B2B189259398C562B7339087D420224D40300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00728E1A9E703AA56E499F4C35952614901600B85A13D79B10D0A303D3A405
DF9D17AD3500B71102C00907C00607C60A08CD0C07D10D09D50B09D90F0ED90E0CDC0F0F
D50F0EC6110FEC3C39D61814E51911EA180DEE1B0FED1A0BF01E0EF01D10EE1D10EC1E12
ED2316EE2618E22215D5190DDC2516E22719EC2C1CF32D1DF62C1DF92A1CF52E21C42721
833E3BFAE9E7F3EEECF5F1F0F1EFF0F5F3F3F3F0F0F7F2F1FFEDEBE98884EC3E31FC321F
FC2E19FF2C18FF2C18FE2A17FE2A17FC2A18F12E1CBE291A944437F4D9CEFBF0EAFEEEEA
FFE3DCF9C4BBDE8D85BB5750A1372D8E23188620157C20157422167E2F22B05A4DCC6158
96110E9B05099F040B9C020999010A9202098900058900058902058902048701038A0306
8901058701058502058301047F01047C01047901037601037600047B00067F0106810106
820308810107800209770307660103580400540C0371331A8E5631774011733901708109
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25D806996B299E7044854D30702011850E07A40F09A81103BD5313D89B0FD1A403D0A303
DB9D15AC3B01B71403BE0906C20807C90A08CD0B07D30C09D80E0CDC100DDB0F0BDF120E
DD130FDD1A16E52621E31A13E9180EEB170DEF1B10ED1B0EE81B0DE62113DC2718D32D1F
D33A2DDA4A3CDF5A4CE66C5CEC7867EE796AEB705EE86353E55444E34333E43C2CD33D33
711F1BDCC3C0F6F0EDF8F4F4F4F2F3F5F4F3F4F3F2F4F2F1FDEFEFF4B3B1E2443DF83222
FE301DFE2D19FD2B17FC2A17FB2E19EE2F1DCB301E9F3F30EAC3B8FBF1EBF4F2EFF6F3F3
F7F2F1FAF0EDFDEAE5FAD6D0E1B3A7D7A495CF9E8DCDA190D3AB9BDAB2A2E4AD9FAF5951
8209099203089802099600099400099002098C00078C01078B02078A0105870003870003
8A01078901078601048400048000047E01057F01067F0106800208810108810007840208
84020886020B82010A7500046800015E01005A02005405005A15087F44267B4116723700
6E7F0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310
9870338C633E5E2B185B130A700B07930709AF0D0BAF1102BB4A0FDB9D14CFA302D4A805
DB9F14AE3D02B61300C30B08C70907CE0C0AD00908D50C09D90E0BDD0F0CDD100CE0110E
DF130DE1160FE31810E8180FEC1A0FEB180DE7180DE21C11D42015BE291ECC584CEC9589
FBB8B0FFCBC2FFD6CDFFDFD7FFE2DAFFE3DBFFDFD6FFDDD4FFD4CAFFC1B8F5A499E2877D
8E5048B9A19CF6F0EAF7F5F2F5F3F3F3F1EFF3F1EFF3F2F0FAF0EFFED5D4DF5952F33628
FB311FFB301DF83320F03423E23727C03728BC6356F3CBC0FBEEE8F7F3F0F3F3F3F2F3F3
F3F3F3F3F2F2F5F3F2EDE7E3ECE0DAEBDBD3E9D8CDEBD7CCE9D2C6D2AFA4A2645D801A19
8B060A95040B9A020B9900099401079000069101089001078C00068901058901068C0107
8C01088A01078800078601078001057E00057F01077F0207800105810206830107850108
86020B8502098303097601046700006001015F02025C020155020050090174361B7F451A
7237016F7E0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718C16976E38
704B294317094007024D0305620102890307AB0A0AB11004B6410DDE9D16D2A602D8AB05
E1A414BA4708BD1703C90D08CE0C0ACF0B0AD10B08D60C0AD90E0ADC100CDB0D0DDC0E0F
DF130EDF130CDF1209E5160CE7170DE6170CDE1B12C22015AC342AE0938AFED3CCFEE6E1
FAEDE8F8EFEAF7F0EBF7F1EFF4F0EEF5F1F0F6F3EFF9F1F0F7EEEBFAECEAFDEBE7FFE8E2
F8E0D8EDDFD9F1ECE6F4F2EFF3F2F0F3EFEEF4F0EEF0EFEDF4EFECFEE6E4DF7E76DF4437
E73F30E03E31D34536CE5346D27064EBAFA6FFE4DCFCF1EBF6F2F0F3F3F2F1F2F1F3F4F4
F1F2F1F3F3F4EBEBECE4E1E0E6DFDCE6DAD9E8D9D5E6D1C9CAA89E91564E6F121085080C
95040A9A02099F040B9D03079903099501089802099301088D01078B02088E030A8D0108
8D01088B01078C01088900088401068001067D01067801047701037700027B01047F0107
8101098202088003077B02056C00006400006101015E01005B0202550201500600692911
81441B77370122D10100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718D178F6330593115
3B0F033805044005074802065D01057D0206A30909AD0E02B03608E49F1AD5A803D9AB04
E6AA14C3530ABE1601CC0C09CF0B0AD10A0AD00A08D70D0CD70A09DA0E0CD90C0DDC0F0F
DD120EDD110BDF130BE61710E3150DDE1812BC1A13932A20E7ADA3FADFD9F7ECE9F1EBEA
EFEDE9F2F0EEF4F0EDF4F0EEF5EFEEF6EFEEF5EFEDF6F0EEF5EFEEF6F1F1F5F1EFF4EFED
F6F0EDF8F2EFF3F0EDF3F2F0F4F4F2F2EFEEF2EFECF1EFEEF3F0EFFCF0EDF5C5BEE9978B
ED9B8EF3AEA4FDC9C1FFDDD5FFE7DFFDEEECF7F0EFF6F4F3F3F3F2F2F3F2F3F3F3F3F3F2
F1F1F0ECEDECE3E2E1E4DCDBE5DAD7E6D5D0DDC1BCC3968E88453D6F0F0B7D06078B0208
9702099A01069D02079A00049701069500079702089301098E00088C01088D01098B0108
8901088A01088C02098801078502087F0106760002710001720102730101750002790006
7C01077D01057E02048004077902047102036901016501026000015A0101550201510500
651F0C7E3C1678380124D30200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075901D9F76484C260E3A0D03
3806033601053C0206490105650408800307990505AB0C02AC2D02E39819D6A605D5A701
E2A810C75C0DBF1A02CD0C09CF0A0BD10B0BCF0909D50B0DD50A0BD90D0DDA0F0DDB100C
DB0F0DDD100CE0140EE1120CE0140DD018167E0504BA827CF9E0DBF8EEEAF4EDEAF7EAE9
F3E1DFF6D8D8E9C2C1DDAEAED3A09FD09B9CCE9B9BD7A8A8DFB5B6E6C4C3F1D7D5F4E4E4
F6ECEDF4F0EEF2F1EDF1EFEEF0EFEFF1F0EEEFEEECF4F2F3F3F1F2F4F0EEFBEFEBFDEBE6
FDEEE8FDF2ECF9F1ECF8F1F0F4F1EEF5F2F2F2F0F2F5F4F5F4F3F4F4F3F3F3F3F2F3F2F2
EDECEAE4E0DCE8DFD9E6D7D1DFC5BEC99F97AA6A64862D2A7508078105078601068C0106
9501069E02099F02099C01079801079600079502089200069101088E01088E0209890106
8600068600068802088200047C01037501027000016F0001710101740101760103790107
7900067901037901027B01047D02057C06097402046E01026901026200015A0000550101
530400671F0A75340D7E3F0327D60300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00759222B19065BFA59233140D340808
3504053601053F04084A00046C0509890508990202B10E07AC2300E5911AD5A304D3A601
E1A90FCA650FBA1801C90C07CB0A09CA0707C90506D1090BD40B0AD60A0AD70D0BD80C0A
DA0C0CDE0F0DDF100CE2120EDE150FBF15145F0606D6B8B5F9ECE8FAEBE8F0D0CCE3ABA8
DB8E8DCC6A6AB03A3BAD2A2BB02626B22527AC2325A92628A62C2DA33433A14241B06365
CA9093D4B2B3D9CECBEDE7E5F3F0F0F3F1F2EFEFEDF1EFF0F2F0F1F2F1F0F5F2F1F4F2F1
F4F3F0F4F3F2F4F4F2F4F2F3F4F3F3F3F2F3F3F2F3F3F2F3F4F3F3F1F0EFF4F2F2F6F3F2
E6DEDAE1CEC6DCBDB0C5978BAF6E64842E277C0E0C87070A8C030890030A8D01078E0205
9401059E0309A000099E010A9C010A9800079500059201079001078E01078D0106890106
8701058701058601067F01047501016F00016E01017001007401027702037801037B0004
7D01057A01037701017501017601027C04087A03077601047001026B01026501025B0101
5601005304006A230B702D0465710300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B717B89770D3C1B1C7B8B5321B1A31090C
3205083502083D03084801056C070A8D060CA10507B10B09AB1A01E28717D7A206D6AA04
E0AA0ECD6D11B51801C60A06C90B07CA0909CB0909D00A0AD40E0BD50A08D70D0BD70B0B
D90B0DDE0E0DE00F0BDF0F0BDD140FBB1514520202C8ACA9FDE8E2E5B7B1C06660B3302D
B81F1DC21817C81413CD110FD21311D0100ED21313D11315D21917D01C1ACD211DCF2B29
CA3A39952E31613837E3D6D4F2EDECF0EEEFEFEEECEFEDEEEEECEDF0EDEEF1F0EEF5F2F0
F5F2EFF9F2F4F5F2F1F9F2F3F6F0F1F7F1F2F8F1F2F7F1F0F8F0EFF8EEEDF9EBEDFDE7EA
DAB6B5BB827CA0524988261F8712108E0D0C900406930205930105930107910108900207
9201079A020AA1020CA1030D9E030C9901079702079302088E00068C00058D01068B0206
8800058801078301067C01037301016E01016C01016E01017201017501027A02047D0204
7F02057F02057A02037600037602067702077C040A7A05087100026D02036B0204630201
5C01015601005709006B22077731014AA70500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028DB0DB39065D5C4B3D4CBC7C8BFC13A282A2D0B0D
2E05083101063702063E00015B010484070C950104A90908A91703DF7F15D9A208D7AA04
E0AA0ED07310B11A01C40C09C50907C40708C60606CA0807D10C0AD20A08D40A0AD70B0E
DC0E11DF0F10E0100EDF100CDE140FC81717690304A46E68EEB6AABF5B52B61E19C8120F
CE0D0AD50C0CD50C0CD50C0AD60F09D70F0AD8110DDB110DDB120DE01510EB1F16F7261D
F22B22D2302C620D0BBDA6A4F3ECEAF3EEEEEFECEBECEAEBF0EFEFF1EEEFF3F0F0F5EBE8
FDE3E0FFDDE2FFDEE3FFDFE3FFDFE2FFE0E3FFD9DDFFD7DAF2C3C6E6B3B5DB9AA0BF7279
8D313688191B8C0D0C930708970507970306960305940102920103930105930208910108
9201099801099E010AA0010C9C010B9701079400069201079002078F0106910107900107
8E01078801077D01037400006F00016C00006B00006E01016E00017001017401017A0202
7C00027C0104790004760005740106750106750509780C106F060A6A0104670102610202
5E02015C02015704005B0E016D2403833C0327D50300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0028DB0BAC8559D2BFAED2CCC9CDCCCDD3CFD1463B3D24090C
2E070A3403093B03094202075301047404098A03069D0504A61503DA7915DAA209D5A802
DAA70BD47A12B11D00C00C06BF0604B70001C50608CA0709CD0708D20A0BD30B0BD50B0E
D70C0ED90D0ED90E0DDB0E0DD80F0CCE11129C0708AE3F38E47263B82016CA100BCF0A08
D20C09D40C0AD30A08D70F0AD40D06D80E0AD8110BDB120CDC140BE0160DEF2215FA291B
F72A1AEB34288F191489605BF4E8E4F2EEEBF1EEEBEFEEECF0F0EFF1EFF0F4F1F0FFEEEC
D19594D57274DE7276E17377E07375E07273D9686AC15356A23A3D9F3234A42C2FA12123
961211990D0A9E0B089D06049C04029A0403960202950303910102900104940409900107
9200069901089F030B9C010A9A020A960006930004920106920107940208940206910105
8E02068702067B01037100006F01016D01016E01016F01016E01016D0101710201770202
7902027A0204790105770106730004700003680305C1666AA549506A060B6201035B0000
5C01015B0201580201530400621302762A0145A00100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007A9A35CBB2A0D2C9C6CFCDD1CECFD3D4D3D65D5657250D10
2C08093503093C02064703085402086901077E0206990809A01303D37215DCA30CD4A804
D6A508D37D11AE1D01C10C07C50A08BF0405C70609CB0709CF080AD1090BD10B0ACF0A09
D30C0BD00A0AC90404CA0303CD0606CB0706BF0806BE1712D22C22C71009CF0C07D10A08
D10B06D10C07D20F07D41107D31005D31307D21608D31807D31C08D51F0DE2301CE63624
E53B28E04636AE4035815249EDDFD8F1EDEAEFEEEAF1F0EEEFEFEDF0EEEFF3F0EFFBEDEB
EBB8B3E18A84E78881E7857FE8867FE68379E47E77D87570CD6D68C96760C65E57BE544A
A73C2C9E2D19A028149D210E981907941404900E01900C008F09018D06018E0403910205
9301069800079D030A9801079601059803079702069802079802089501079000048F0104
8B01048001037801027100007002006D01016D01006F01006E01016C01016D0101720101
7401017601027801037A01077500056E010467020591373EB05C64AF565D7115185C0303
5901005802025301025101005B0800701E033C940000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004DAF119D7551D3C2BCCFCCCFCDCCD1CFD0D3D4D4D77C76771D0A0D
2503053502084003074501075201066D040B7D0206930406990C01C66314DCA00FD3A603
D7A407D38111AF2001C20B05C80909C7050AC70408CA070ACF090DCF090CCD0909CD0A0A
CA0807C50303C30201C40101C60302CD0707CE0B09C80806C80A05CB0B06CB0C03CD1005
CB1203C71505C51905C41F08C2230AC42D13C7371CCC4529D35539DA654CF38C78F79C8C
FAA798FCB3A5F9C3B9EDD0C7EFE5DDEFEAE7EFEEEAF0EEECEDECEAF1F0EFF3F1EFF4EFEC
FAEBE5FFEAE2FFE8E0FDE3DDFEE5DDFEE5DBFFE4DCFFE6DFFFE3DBFFE2D9FFE1D7FFDBCF
F1C3B1E3AC97E1A489DA9A7CD48F71C87E62C17257B55F46AA4D35A4402A9D2F1F8D0F0A
9105089501079B0309990106960105970308980208980208970106950106930208900008
8902077B01027501017201006D00006A01006B00006E01006F01016C00016C01016F0001
7101007401027601027801047501057001056C020667070BA851589B464F9F4B528A3638
5803025701035001015001015D07016E1604585A0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063720B8A6049D8C9C7D0CED1CCCDD1CDCFD1D3D3D69F9A9C251114
2C080D3604093B00054301074F010570070F7F020696060AA11104C35714DC9D10D2A202
D6A206D68513B02401BF0C03C60908C6060DC3050AC3060BC6070BC7070AC60506C60506
C60405C30101C20201C40203C60303D10B0DD30F0FCB0A09BE0A05BD1608BB1F0BBF2E15
C33D21CA4F35D26548DA7959E38D6EEA9F82EFAC92F6BAA2F8C4AFFBCFBFFFE2D7FCE6DF
FAE8E2F7E7E2F6EBE5F4EBE6F2EDE9F1EFECEFEEECF2EEEEEDEBE9EFECECF0EFEEF1EFEF
F1F0EFF1EEEEF4F1F0F2EFEFF3F1EFF2F0EEF2EFEEF4F0EEF5F1EEF4F0EEF2EFEBF2EDE8
EFE3DDE9D7CDEBD7C7EAD6C4EAD3C0EBCFBEE9CBB9E9C7B4E6BEAAE7B7A3E4A693A6493E
840707920308980209970209930107920108920007920007950106960107950108910009
8601067700017200007402016E00006900006D01007101007101007001016F01016F0101
7001007101017201017200027001026E01026C0104700C0FC3676D711A23A858619B4E53
7523235C05065100024B0101570400690F03711E0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00742C057C4C3FDACBCAC9CACBCBCCD0D0D2D6D3D4D8BFBCBF2C1B1F
2A080C3302063B02084303084C01046502077C02068D0305A41403C25112DE9C13D2A103
D5A107D68512AC2300B90A01C10604C3060BB60306AB0003B50407BD0305C00304C20304
C10203C20101C30202C40203C90506D30D0FCF0A0DC0090B920402B34733E28769ECA184
EFB299F2BFAAF1C8B5F1CFBBEFD4C1EDD5C6EBD8CDEADBD2EEE4DCF5ECE7F2EDE9F0EDEB
EFECEBEBE9E7EFECEAF1EDECEEEDEAEFEDEEEFEEECEFEBECF0ECEBF2EEEFF3F1F2F0EEF0
F0F0F0F1EFF2F1F0F2EFEEF1F3F2F3F0F0F0F1F0F1F1F1F1F0EFEFF0EFEFF0EDEDEAE7E7
ECE6E7E5DCDAE5DAD6E3D8D2E2D7D1E0D6D0DFD5CFDFD4CCE1D5CCE4D4CAECD0C6B3746B
7B0D0C8B020794040A8E01068B01078C0009910108920008950108980208970208930109
8601067700017200007300007101016D00006E01007002016F0201700101720201710101
7101007101006F00016F01026D01006D01026A02047310118C3034AD5760A5576074292E
994A4C7320235305084700014F0201640D056C18013A950000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0053B11A6C20096C332DD7C2C0A7A5A4CCCCCFD2D2D7D3D3D8CFCDD1372C2F
27090A3104083802074303084E010662030877050A8300029A0C00B7450EDE9C15D1A203
D5A107D88511AB2200BA0903C00604C20609B80407AA0103B00003BA0103BF0205C00106
BE0102C10103C30203C60405CA0808CF0B0CCD090CBA0A0C7202027D4134DCB69DEED4C1
E8D6CAE5D6CEE3D8D0E3D8D0E3D9D0E5DAD4EAE2DEEEE8E6F0EBE9F2EDEDF3EFEDF3EDEB
F2EAE9F3E8E7F2E5E4F7E9E9EFE9EBEDEAEAEEEBE9F2EEEFF2EFEFF1EDEEF2F0F1F1EFF1
F2F0F1F6EFF0FBEBEEFCEAEEFBE8ECFAE7EAFAE8EBF8E7EAF7E7E9F8E8E9F4E4E6F0E1E3
EBDCDDE4D3D4E4D2CFE5D3CDE4D4CDE3D5CDE1D6CFE2D7D0E1D9D2E2D8D4ECDAD5CA9994
7E1E1C87090B8C0B0C961A1B8D121586070D8B030A910208940108950108960208930308
8601067B00027702027501027302016F00016E00016D01006A00006D0001700001720101
7301017302027302027001026D01016A00016601029035359F4C4FBA6F75AB656E9B565C
A15A5E883B426E21284A02074A01015E0B06671301555B0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF002EE012B27A54621B0B62201AAF8D89918583CFCECFD1D1D6D2D1D7D6D6D84F4748
23080A2F050B3502084002074E04095901056C0306860708980D04A93809E09A16D2A104
D39F05D98612AA2100BC0B05C10607C5060CC3070DBB0409B80105BB0104C10408C10206
BF0303C00104C20405C80707CC0A08D10B0CD10B0DC10B0E8407085B2420D4B6A8E8D6CC
E4D8D2E5D8D3E5D7D0EBDAD0EAD6CDEDD6CEF4DCD8F7DDDEFCDFE1FDDCDFFDDADAFFDBDC
FCCBCCFFCDCFFCBFC1E3A3A6875E62BCAFAFEEE9E6F1EEEEF1EFF1F0ECEDF0EEEFF2F0F1
F2EFEEFAE5E7E8ADB3EC9FA5E79298D3828AD0838DCE848DD78D94D38B92D28E96CE9197
CE959AD0979CCE9696C48F87C69489CA9C91CFA69DD4B2ACDABFBBE1C7C7E5C9C9E1B0AE
8A2F2D7F0D0BCB605CE88280C35D5DCB62658812168A030B9102099101079301068E0105
8300037B00027701017601017301017000016F01016D01006D01016E0101700201730201
7301027401027301017001016E00026B0002670103721A1DC1777AA5626764232BCA8A92
9C58608A3F498A414B530F1447010158060569110570200000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0059C229AC80665D1C115D130D91625D8E7C7ACDCACDD1D3D6D1D1D5D5D5D7696367
21090C2C040B3302083C01074703075202076002047601038E0801AA380ADE9715D3A104
D4A005D98912A92300BB0B04C20709C6050BC3040BC2050CBB0106BA0105BE0206C00207
BF0205C30207C40407CB090BD00B0DD70C0FD90F10D00F0FAF1111690907E0AAA2F9D5D0
EFCEC8E6BDB6E6B4A8E4A99DE5A096E79B94EF9C98F59DA0F18F92E98081E47776E37172
E06162E35A5CDD5151D14C4A903432886663F1E7E3EFECECEEEEF0F1EDEEEFEDEEF0EEF0
F1EEEBFEE4E5CA7A7BC64D4FC63C3DB7282CAA1D25AE2027B4252BA91F27A2252D952B30
8C2E319033368B2D2C892C2481251A83291D822D22803229964C4AA55E61A86364AF6262
9732318C201EDC7B7AC56A69953A3CC96F72C15C637F040C8E040C8D00088F01088C0207
8301047A01017701017701017501017302027001016E01016D00006F0101700101700101
7201017201017100016F00016F01026D0102690204620408600E14934C539E5A6397545D
8A454E9F5860954E585B161C4801025704046910086E1C0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE8351A07C6761241A60120D87524FB5A1A1D7D2D7CFD2D6D0D2D6D2D3D6878286
200B112B060C3303083901073F01064C01085C03076D00018C0903A63509E09A18D6A404
D6A206DF9118AA2700BB0C04C40809C6050AC5070BC10308BB0105B90005BC0104C00207
C40408C6040AC9060ACC070BD20A0DD70C0EDB0F0EDA120FD31915B91D1AE87471F99997
E68580C55F55BB4F41B64234B63D31B83C33C1423ACB4A45D04F49D55751DA645DE16A65
DD524FD33733D5463EE1695FD38177C8A59EF2E6E2F2EDECF1EFF1F2EEEFF1F0EFF2F2F3
EFEFEEF8EAE8F5C4BFEA9D96E17A72C14039B61E1DBE1717BD191AA81A1B90211F9F4B45
C27F78DA9993DC958DD58C80CA7C6FBB695CAE5A4DA24A3F9C41399335308624217E0F10
870E10901F21CC6C6EC46E6FD986899B464DC3656E8B19228A030C8C01088C0208890107
8401057D01037601017401007401017201007001016F02026E02026E01016E01016F0101
7302037401037301037101017001026E01016A01016401035F020658070C6C2129C07883
752E38BF7982AC6570671F274D02045905046910096D18003E970000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC875C997B696C332B62140F814A4CDBC9CCD3D1D7CDD2D5D0D2D6D2D4D8AAA8AB
1C0E1225050A2B01043501063C01074B01085A0204760405940E07A02F05E19C1CD6A505
D7A405E0931AA82700BB0C04C10506C7060BC8080AC4050ABD0104BC0106C20308C9070B
CA080CCB080DC90709D00A0CD40C0EDA0E0EDC120DDE1810D6180DDB2319D82924CF2D2C
C5302BB02C22A93426BC5140CE6C5CE78A7FF4A39AFCB4AAFFC1B6FFCBC3FFD6CDFFD8D1
F2A9A59B2E2A9B4840FFD7CBFFE7DEF6E7E2F4EFEAF0EEEBF1EFF0F5F0F2EFEEECEEEEEF
EFEFEFEEECEAF4E8E4FCE9E2FFE1DAF8BEB5BF554FAC1D1BA21B1B6B110CB68178F3D1C8
F7E2DAFAE7E0F5E0D9FAE1D8F4D7CEFBDBD2F7D2CAF5CAC1EBBAB3ECB4ACDB948C98312F
911113870B0FD56E71C97277BA6A6ECE7A82C96B74901D2689020B8F010A8E0108890006
8501067D00037600017300007201017201016F00016D00016A00016800016801006C0101
6F01017201027501047401047001026C01016901026501026402045F02065B050D73202B
74242F6C1D28994F5A6F232C5A070B6006066A0E076E15003D930000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B918A0805DA88F817140395F14117E464BDFCDD3D0CFD4CDD1D5D0D1D6CFD3D6BABABC
1B14161901042501043203083D06094902086106097A0608940E07A02D03E29B1CD7A407
D6A505E0961AA92801BD0E07C00607C5050AC50509C5060BC30509C3040ACA090ECC090D
C90708CA070ACB0806D20C09D70D0CDA0E0EDD150FDF2016F24636E43123D42016BE1F17
A2271FCE796EEFB5A9FBCEC2FCDCD2FDE1DBFAE5E1FAE9E4F8ECE5F8EDE9F5ECE9FAEAE9
FBD9D69F56545C2A21DFCCBEF5EEE5F8F4F0F3F2EEF2F1F1F2F1F1EFECEFEEECEDF0EEEF
EFEFEFEEEDEDEEEDEBF2EEECF4EDEAFBE9E4F8C5C1AA45437C1B19633530E9D8D1EDE4DE
EAE7E4EAE9E7ECEBE8F0EDEBEEEBE9EDE9E7E8E2E1F1EAE8EDE5E2EEE1DCF9DAD6BA7372
8A1417920A10981C23D87179CD717AD5767FC45963870A128D02099101089201098E0107
8400047D00037901027601017401017401017201006E00006B0001690101670000690000
6C01017001037301037301027001016B0002680103640002620104610105630109660610
6707116509137B263077242D650A0F6807096C0C087115033C910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC226A98E719D8B818059555A1817652C34D8C3CACCCBD0CBCED3CED2D7CCD1D4B5B8BA
201C1D0F00011700002701063402054501065600046D01048B0C079C2D03E39A1DD9A607
D5A605DC9315AB2C00BB0C04BE0506C30709C5070AC6070DC40409C7050ACB080DCE0A0E
CD090BCD0809D30C0CD60E0BD90E0CDA100EDD1510DF1F15F34638D02318AF18108A241A
CF9489F2D3CCF8EBE5F2EAE6EFEBE7EEECEAF0EDECEEECEBEEEEEBEEEBEBF3EFEEF6EFED
F8E0DCAE746D531E13BDA391E8DBCEF1EBE6F3F1F0F1F0F2F3F2F3F6F0F1F9ECEDF8E2E6
EBDDDFEEE9EAEDECEAF0ECEBF0EDEBF0EBE8FDE3E0CC8A886C21215B3835E6DED7EBE6E3
E9E9E8E8E9E8EBEBEBECECEDEBEBEBEAEAEBE5E5E6E7E7E7E9E9E8EAE9E8F2E5E4DDADAE
86202394080D97080F8E0A14991E2B9D242F8E0E168C030A900107930208940208910209
8701067E01037900017700017701017501017100016E00026C00026A01016B02016A0101
6B01026C01016E01017001016F01016D020468010561010460000661010865010967010A
6C040C6C070E7D2027832A3166080D660507680A086C11033A8F0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC82EB7A08B92847F9C7E7B551A1C5A1F26C9ADB3C5C2C7CCCED3CBD1D4C7CBCFB4B6B6
322F2E0900000E00002001052F020541010755050A6503077707048E2803E19B21D8A506
D5A505DE9515AB2D00BC0D04C20807C30709C6080BC6060BC9080CCC080CCF0B0ED10A0F
D0090CD20A0DD40A0CD80E0FD70C0DD90F0DDA130EDD160ED91812C71B177506059F6E65
EFDAD1F1E8E4EFEAEAEDEBECEEEEEDEEEEEDECECEBEDEBECEEEEEDEEEBECF0EEECF5EEEB
FBE8E3D19D91612315886353E8D5C5E8DDD7E5E1E0E6E3E3E7E4E3F5E9E9E5BCBFC57980
85494DCCB7B8EEE9E8EDEBEBEAEAEAEBE8E9F3E5E5EDC0BF7E3B3B461818CCBFBBE8E4E0
E6E6E5EBEBECEBEBEBE9EAEAE9EAEAEAE9EAE6E5E5EBEAEBE8E8E7EBEAE9F0E7E7EDCBCA
9C46449710109E05099C040B99040D94030C9202089201079300089301099101098E0108
8801068001047B01027A01027800017903037201026D01016D01016E01016E02026B0102
6900016900016B00016C00017001026E01036600036101055D00055C00046301076B030A
6C040B6D050C700D1274121869090D630407620606680F0277270000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
88A943B29C8CA296948B706F541A1C521317BE9CA1C8C2C7C9CBD0C8CDD1C1C7C7B5B5B4
4A43440C01030F00002101042F02073B01074801055A02076903018A2901DC961ED6A306
D4A406DF9618AA2B00BC0E05C00705C6080BC30709C8070ACA0A0ACC090ACC0A0BCE0A0B
CC0707D1090AD40B0CD80E0FD80E0CD80E0CDB120EDB110BD9120EBE1616570101AA9089
F2E8E1EEEBE8EDEBECEDEBECEEEEEEEBEAEAEAEAEAEDEDEDF0EBECF1E6E6F3E1E0F9E1E0
FCDAD3F8BAAC7E3325572A1FE4CEBDE8DBD1E7E2DFE8E5E4E9E7E3F9EAE9F0BEBEC24D50
A33333916262F1E5E3EDEAE9EBEBECEAE9EBF0E8E9FADCDC9B5A59651E206E4A4BE0D6D5
EAE9E7EBEAEAEAEAEBEBECECEDEDEDEAE9E9E6E4E5EAE5E4E0D8D7E8DDDDEDDEDEF0D2CF
B067628C0E0BA1070AA30308A202099C00079A02099702089401079202088E01088C0106
8901048401037D00017C01017D01027A01027601017201017101017001016E00016D0001
6C01016C01016D01027102037503057202056A01046401055E01045C00036501076A0207
6802076903086D070C6904096B070C68090B610605630D0074260100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78F5DB29E929B929199818056211F511011A47E81CFC6CBC1C3C8C7CBCFB6BCBBB1B1B0
655E600B02031201012401053001073D0108480207590207720803842100DB981FD4A205
D5A507DF9519A92900B90C03C00705C50809C60A0AC70808C70807CB090ACD0B0BCF0A0B
CD0A08D20B0AD40E0BD70E0ED90F0CD90E0DDC0F0EDC100DD8110DC51818650403836260
E9DFDBF0EDEBEDEDEDEEEDEDEEEEEEEDEBECEBEBEAEFEDEEE9DDDDE3C0BFEEAFADF3A2A3
ED8F8DE7786FA93930500E06C3AB9AE7DACBEBE6E0F3F2F1F7F5F3F0E7E5FED7D5CA5A5A
BB3935702E2BEFDDD9F1EAE8EBEAE9EBEAEBEDE9E9F7E3E3CA8E8D81222368191C8B6669
E8DDDEECEBEBECECEDE9E9E9EBEBEAE9E9E9E8E6E5DAD0CED1B5B4D2A5A8D29EA0DEA5A5
E5928F981A18A20609A9040BA70309A101079B0208980106B41C20C22D3195060B8B0003
8B01048702057F00017E01027F02027C0102790101760201740101730101710101700101
7001017001016F01017000027200026F01026C01056701046001045F0105630105650105
64020566020768050965010769050B6B090C650908631205742A0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9363BBA79E928A89AE9D9B5A2E2B511011885B61D0C2C9C0C0C5C4C7CBAEB3B3B3B2B3
7D7A7C09010416010329050C34020A40030B4601075F030983110D801A00DB9820D6A406
D6A607DF9319A92800BB0C03C10906C50807C50907C70908C80809C90708CA0607CF090B
CF0B0BD00A09D30D0AD60E0ED70D0CD80D0DDA0E0DDC110FDB120ED41816A414145A0D10
BB9E9EDFD8D7F0F0F0EFEFEFEEEFEEEEEDEDEEEEEDEFECECEEDFDEDDAFADBC605DC94341
CD2F2DD02821C42B26680C08947567E3D5C6E9E4DCF2F2F1F0F0EFF3F0EDFEE8E7C97776
AE32306D1D1BCAB1ADF2E8E6EFEBE9EAE9E8ECE9EAF3E5E5E8B8B6932B2B9B1E2172151B
8F6268E3D7D9ECEBEBEAEAE8E9E9E7EBEBEAE9E9E7EADFDCCCA5A494484990292D9E2E31
B4383CA31315A7060AAA0308A80208A10006980105980104B21418C22327B41E248E0105
8E01078C01068501027E01007C00007B00017A0002790202780202730000710000710100
7201017101017202017101017101037001056D01056700046000035C00045E0005610106
61010662010566040866020867030A69060B650A0A6E21157E381400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9063B9A69EA69E9E8D807D734A49500E116E3A43D2BCC6C3C1C7BFC3C7AAACAFB0AFB0
928F8F0D050717020426030B30020B3801083F0007550209760D0B821D00D8951ED6A507
D5A605DA8F16A82600BA0B02C10705C70908C50807C80808C70607CC0A0BCD090ACF080B
D10B0BD00A09D20C09D60E0ED60D0CD90E0DD90F0CDB110DDE130DDE1410D41B19A41417
69161BAA888EE5DDE0EEEDEEECEEEEEDEFEEEDEDEDEDEBECF2EBE8FCE3DFF9BEB8D76E65
C53125D7261AD0231C96211D643930DCCCBEE9E3DAEFEFEEEDEDEDEEEBEBF8E8E6D89A9A
A332308729259F7A77F4E7E2F1EBE9EDEAEAEDEAEBEFE7E6F8D4D2A84746AD1C1CAD1A20
7E161E86565CDDD1D2E8E6E5E7E6E5EBEBEAE8E8E7ECE8E5F3DBD7D89C989A35319F1718
A90E13AB080DAA0408AB0408A90208A6020AA10309980305B11E23A8161D990A118E0209
9001089202068C01038100017C01017A0102770001760000770101760102730000720000
7101007000007101017101027201047301057002066701035E00025A01035B01035F0106
63030961020664030765010767030A66050B5F08096D2218CBA99C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE976BB6A89F9A9898968D8C8866664E0F13582028CAB1BBC0BDC3B8BBBFA9AEB0AFB0AE
A2A29F140D0C19040624040A2E030C38020B40010A4700075F0604761901D0901BD6A708
D6A807DA9017A92700BC0D05C20806C60809C40606C8060AC80708CB090ACA0607CE070A
CF090AD10A0AD20B09D60D0DD60D0BDB0F0EDB110DDF130EDE120CE2120EE11612D91A1A
B71E2175121B9A6A72DFD0D7E7E5E8EDEFEEEAECEBEDEDEDECEBEBEEEAE6F7E7E1F8CDC2
DF8676C53B2BCF2A20AC221E53140DD1B9AEE8DFD7F2EFEDF0EDEDF0EDEEF5EAEAEDC4C4
B05B58A5524D9A726DEFDDDAF0E9E7EEEBEBEFEDEFECE6E7FAE0DEC0706CAC1E1BBF1618
B3191E84191F79434AD5C4C7E6E3E2E8E7E6EAEAEAE9E9E8EBE6E3F5DFD9DDA59EA43C38
A41312AE0A0DAE0509AB0307AA0207A80109A50209AB151BCC4C50D65F6382080A850004
8F01069200059001048701037D0001790001780101780102780102770201730001730101
7201007101007000007101027201037101036D01036802035E0101590101590103580003
5B01065D01066102076101056605096505095C0507641B11C6A59800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE9B6FBAAEA58C8D8DA5A0A27C6363470F13451014B69BA2BDB8BEB7BABEAFB5B4AFB1AF
B4B7B32723211C0A0C26050C2D01093E040E46040D49020A5905046B1600D0911FD5A609
D4A506D98D16A52300B60701C20806C50707CA0A0ACB090BCB090ACE090BCD090ACE080B
D10B0CD20A0CD40C0DD60C0DD80D0DDD1010DC110CDD110CE0140DE2120EE41310E51512
DF1A18CA212492171E77343DC1A6ABE0DCDDEDEDECEAEBECE9EBEAEAEAEAEEEDEBF5E9E3
F3CEC2E89686C13D30BB2A24610E08A98C84EBE0D9F1ECEAEFECEDECE9EAEFEAEBF7E6E6
F9D5D0FBD5D0F3DCD7F3E6E5F2ECECEDEAEDEDEBEDE8E4E5F5E3E2E4A4A2A52422BD1211
BF1111B1161A881B2169393AC9BDBAE8E4E0EAE7E8E8E6E7E8E7E7EBE6E4F3DEDBDCA39E
A0342EA30F0FA60205AE0508AE0508A80106A40107A1070DBE363DC5494E9D1B1E910409
9201069301069401078E01058400037A00017801017900017A0200750100730001740102
7201017101007202017301017301037001036B01026802035F0102590003560003550004
5500035900055D02075E00056102066105075E070763180FC5A29600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB986BBCAFA799999B8A87889E8A8A4314163F0B0BA4878AB9B3B5B8BABEBEC3C5C3C8C9
CBCFCE3D3B3D1E0B0F28070E2D02093F060D430309480108610B09691300CC8C1DD4A309
D5A307D98A18A62000B50802C30B08C40705CA0A09CA0808CC0909D00A0CC70305CD090A
D00B0CD10A0BD30B0CD60B0ED80C0DDC0E0FDA0F0BDB110BDE130CE21310E41412E71712
E81812E51B16D7201EAD21236C1B1F967A7AE1D9D7EBE8E7EBEAE9EAE9E9E9E8E7EDEAE8
EFE2DCF4CEC3DF877AB632297D16107C5552EBDEDBEDEAE7EBE9EAEBEAEBECECEEEEECEB
F0E9E6F1E9E6EFEBE8ECE8E9EEEBECEBE9EBECEBECEBE8E9F2E5E5F1C2C3A83939B61715
BA1410AF18149A252262231E786059DCD2CDEBE5E4E8E5E7E6E5E6E6E5E6EEE6E7F1D8D6
D5928E961F1BA50C0BAA0507AF070AAB0409A70308A4020A9E040D99050C9C060B980206
9200059502079701089602088D01068201037C00017C01017A0100760101740101760101
7301017101007301017401017501037301046E0104680203610103590103560103550102
5300025801045C01065F000563030863050860070767180FC9A59900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9667B5A89F9897968E8A8AA08F8F4B1F1F41090A8E6B6DBCB4B5B9BBBFC1C6C9C6CDD0
D2D7D95152551B0B1124050C2D060A38060A3F0307460004610A07691301C68619D29F08
D3A008D78515AA1F00BB0A05C40907C80908C80909CA0A09CD0909CF090ACE0909CD0809
CF0A0BD10B0CD10B0BD60C0DD90E0EDB0E0FDA0F0CDA110CDA120EDC1211DC120FE21610
E91A11E61710E11E15CE271FA12E2863312BBFAEA9E4DDDAEDEAE9EAE7E7E9E8E6EAE9E8
EBE6E4F4E2DDFAC1B6BF4941A0241F5B2220E7D6D3EDE8E6EAEAE8EBEBECECEDEDE7E5E5
F2EAEAF2E6E6F0E7E9EBE7E8EBEBEAECEBEBEDECEBEBE9EAEEE7E7F6D5D5B8615FA5201C
9A1A12811D14AA6358C3998FDCC7C0E6DCD7EAE5E4E9E6E9E5E4E6E8E7E8E7E4E5EDE2E2
EDC8C6AE57529B1511A30508A60308A60308A60107A40107A10107A00108A00108990106
9100049301069802089902089301068B01048300037D0100790001760101760000790202
7702027301007301017501027702057401046E01036701026100025B0004570103550103
5601045801045D030761020663030665040863070966160ECFAA9E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99262C2B5A99897939B97968F7F7E552928480B0B794F51C1B6B7BFBFC4C9CED1CDD1D5
D3D8DB7072741B0F12280B0F2B04083505093F02084F050A5E0908641100CB8B1ED4A10A
D4A008D68315AA1E02BD0B07C30606C9080CC90B0CCA0A0ACE0C0BD00B0CD10B0BD0090B
D10B0CD20B0DD30C0DD4090AD80E0DD80D0DD90F0FDA1312D61313D20D0DD00B06DE140D
E21912DA1C15C72519B03327C27165DCB6AFE9DCD6EBE4E1ECE9E8EDEAEAEBEAE8EAE7E7
EEE7E5F3E0DEFDC5C1C84E49BC2C275C0C0BBCA3A0EBE2DDEAE9E6EAEAEAE9E9E8E7E3E1
EAD5D5D1A5A9A6777C7D6164D6CBC9EFECE9EEECEBECEAEAE9E6E4F1DCD9CD8E8B862522
530602B4897EF1D7CDEFDFD9EBE1DEEAE5E3E7E5E5E6E5E6E5E4E7E3E1E3E4E1E4E5DDE0
EDD4D3BF7D778A120F9905089C02069F0107A10108A000079F01059E01079B0106960005
9000048F01049300059600069300068F01068801038100017C00027A01037A0103790103
7600017300017300017400037401057301046E01036900026401025E0103580004540004
5200045100045300055A01046103066303085F0407621107AE756000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99161C3B5A99F9D99858281A99C9C5E37364C0E0D64363AC7B8BBC6C7CCCCD0D4CFD3D8
D5DADE86878B1B1112280C0F2C050A34040B40030A53040B5705045B0F00CD8F1FD6A209
D7A30AD57F15AD1F01BF0C08C30607C9080CC7090BC80708CD0B0BCE0A0BD10B0CD20B0C
CD0707D20A0CD40C0ED60C0CD60C0CD70D0DD90E11D40D10D00D0ED00D0BD20C08DA140F
D51B17A81612A14036E9B1A6F8D8D1F1E5E1EFECE9EAE8E6EAEAE8E8E6E7EBE7E5EDE4E1
F2DBD9F7C7C7F09191CE3533CD28237A100F8A6763E8DBD6EEE9E6ECEBEAEEEDEBF1EAE9
F0D1D09C4B4F9C393D561415A88886EFE5E2EBE7E8E8E7E7E9E7E5F0E3DFE0B1AF7B3130
420F0BD9C8C0EBE3DDEBE5E3E7E5E5E7E6E7E4E4E5E2E2E3E1DFE0E1DCDCE3DCDCE4D5D5
DDBEBBB8726C840D0B9303059401059600059901079C0209990006990106980107960107
9100058F01059101049401059301059101058D02058601038001047A0002780102780102
7500007501027501027501047300047300047001016D0203660102610104590104560105
5400055001054F00055401055A01045D03065A0101620D0384351400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9060C0B1A69E9B98908D8DA2989A6A4648490E0E522226D2C1C5C9CAD0CDD3D8D2D8DE
D5DADE9C9CA11E1415280B0E2F080D35050C3E020A580A125B07085D1200CE9120D6A409
D7A109CD7411AE1C00BF0C06C40606C8090BC8070AC9060ACD0A0BCE090BD10B0CCF080A
CE0808D20A0BD30B0CD60C0ED50B0BD80D0ED70C0ED90F10D8110FD9110DDE1510D61411
B31413630C0BD9B0A8F3E2DBF0E6E5EDEAEAE8E8E8EAE8E8E8E8E6E6E3E3E3D6D5ECCAC8
F2ADADE07174D13839E02624DB231F9D19175E2B29E3D4CEEFEAE7EDEBEBEFEEECF2EBEB
FDE0DFBE6668AC3132791B1A7F4D4BEEE1DEEAE5E4E9E7E8ECEAEAF0E7E6F5D2D3995353
4B0F0CAA9590E5E2DEE7E6E6E8E7E7E7E6E8E5E4E5E3E0E1E1DBDADBCECBCEB6B0C79E97
BF7D7696312C8E0807950204950104930002950004950106940105940106930007930108
9201069001059001039301049503069001048A01048601058001047A0002780102770102
7500017300007400017601037702057501047201026C01026401025D01025A0103570104
5300044E01044C0004500106550004570103570101650D0286311100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BA905DC6B7AC969593A4A1A5897F84856769430D0D48161BC7B2B7CACAD1CFD7DDCDD6DD
D6DCE2B0B0B51F181A22080B2D060B33030B3700074600085806095D1100D09320D7A60A
DAA40DC76D11AD1900C00B05C50706C50709C70509C90609CC0808D10B0CCF090BCF070A
CF090AD40C0ED40C0CD60B0ED40A0AD80C0FD70D0DD90D0EDB0E0DDF120FE1140FD71613
A10F0E4A1313D8C7C1EFE8E6EBE8E8EDE9EAE9E7E8E9E8E6E8E7E5EBE6E3E4D3D0D19B9A
B94C4BD03130E42722EA211CE5221CC02323560D0ACAB7B2EAE6E2EEEBEAEDECEAF1ECEB
FAE5E4D08585A82E2E96292862211FE3D1CEEEEAE8EBEAEAEBEAEAECE7E9F7DDDFBD7876
7F27265C2827CFC1C1E8E7E5E5E5E5E7E4E7E1DDE1E1DCDDE2D8D8CBB5B0AD8074913F34
8B1C158E0907950303990102990103970203940003920004920005910006910108900108
8F01078F01059001049000039001048C01048600038200028100028A0A0C840C0D730101
7402027401027401037300027801057902067501046C01036300025D00015A0002590003
5400034E01044900024D0004580207580206550001620A028A341600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78D59C3B5A8A5A6A589898E9E989C836B6B411211420D11B79EA4CCCAD0D0D7DBCCD5DA
D7DCE2BFC1C5201D1F240C102E070D33040C33010640010858090B651700D49722D7A608
DCA40FC56712AD1701C10C07C40607C60609C80508CA0608CB0808CE0A0BCE070BCE070A
D00A0BD20C0BCD0705D40B0AD50C0BDA0E10D80E0DDA0E0EDD0E0EE1100EE41412DD1512
B71613520203A7908FE9E2E2ECE9EAECE8E9E8E6E7EBE8E8E6E5E3EAE7E4EFE3E1F1CBC9
E28E88CE473DDD2E20E8241AE7221AD428256B0B0A9D837EEAE4DFEEEAE8EBEAE8EEE9E7
F5E6E3E7AFAC9E352EA3352E6C221ABFA79FECE6E2EAE9E8EBEBEBEAE7E8F5E4E4E8ADAB
9B302E7B1819733E42CDBBBDE6DFE0E3DEDEDFD9DCDDD8DAE0D8D7E1D0CBCDA295A04D3E
8D12099304029701019902039701029501029201029101039201069302089201098F0009
8E01088E00059101048F01048F0106890004840003890002980407B11E21D14B4EBE4647
7A0A097101037001027101007A0304870B0F7600036C00026700026201035E00035B0104
5401034D01014900014D0003550207590208550002610801903A1F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B58D57C3B7AAA2A5A4909497979697806F6F3E14143D080C987D83D2CFD5D0D6DAD2D9DF
D5DCE0C6CACE282628220B102C060E36050F3502083C0109570A0B691C00D79924D8A90A
DCA410C06010AF1601C10A08C30708C60609C9070AC90608CB0909CD090BCE090CCE080A
D20C0CD20C0AD10C07D50E0AD80E0CDA0E0EDB110EDC100CDF120EE31210E31310DF1310
D218159710115F1A1EC4ABB0E7E0E3EBE8EAE7E5E6E8E6E7E7E5E5E8E7E6EAE6E5F0E5E2
FCDDD7F2AFA4D66152D73226E1251BD524208B16176F4743EADDD9EDE8E6EDEAE9EDEAE8
F1E8E6F2D2CCC17F73C07468AA7164BFA69CECE4DEEBE8E7E7E8E8EBEBEBF3E9E9F8CCCB
A73F3AA71E1D86161B74353CC7ADB1DFD5D5DFD8D8DBD6D7DBD7D7E0D6D5E6D0CAD6A598
A850428C0F079404029601029501029201028F00018E000290010390000691000891000A
9202099101069101058E01048D01068802078400039A0207AD050CAF060BA5080AAB1A1E
AA272C7300017000027201027A02038E11157601046E00036B0204670103630204600307
5602054F01034A01024B00035100065600075A01026408018F361D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18954CABFB2A1A6A59EA4A6808181A193934824263B090B765A5DD4CED4CCD0D5CDD4DA
D5DDE0CCD1D52A2A2D1E090F28030B35030F37040C3A01074B0506621800D29823D4A608
DCA513BD590DAF1400BF0907C4070AC30408C50608C60506C80708CB0709CD090AD00A0A
D00C0AD10B0AD10C08D40D0AD70D0CD80C0CDB0F0CDD100BDB100AD80B08DF110EE21212
DD1212D01919A014196B1720AD868EE0D3D9E7E3E6EAE8E9E9E9E9E9E7E8E9E9E7ECEAEA
EFEAE7F7E3E0FBC6BDDE736ACE2F27CC1E1BA21D1E4F1717D9CBC6ECE6E3ECEBE9ECEBE9
EEEAE7EDE2DEF6DED9F9DDD7F7E0D9EDE1D9ECE6E2ECEAEAEDECEDEAE9EAEDE6E6F4D4D3
BD625FB21B19B4151A8D131A651F25AD9194D7CDCCDCD8D6D8D5D5DCD8D8DED5D4E7D3CE
D7AB9DA852458D120B9303039100029000039001048E01038E01048F0106910108910108
9301099302089102058C00038802047F02048000029D0408B10208B40406AE0203A90307
9F050A8401037400027602057D07098F161A7300046E01056C01046701026201025C0003
5501044F00034900024800024F01055502055A00026407018A2E1500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18651CFC2B5B6BABA8B9394999B9C8C83834D2F2E3C0A0A694B4BD8D1D5D3D7DBCAD1D7
D5DCE0D5DADD393B3F1C0A102A040E33020C3702093D0105520706641A00CF9825D1A40A
DAA114B8500AB01300BC0604C4070BC30409C40608C5070AC80708CD090BCF0B0CD00B0A
CF0C0AD10C0BCF0A08D20A0BD40B0CD70C0CDB0F0DDD100BDA0F09DD120CDF120EDD0D0D
E11111E01315D71919B91C207C111A864A56D0B8C1E1DBDDE6E4E4ECEAEBEBEBE9E8E7E8
ECECEBECEBE9F6E7E4FECBC5CB5C57BF211EB42121590A09B9A09CEDE5E2ECEBE8EBEAE8
EEECEAE8E6E3E9E5E4E9E4E4ECE8E6EDE8E6EFEDEBECEBEAE9E7E8E7E5E7EBE7E6F2DCDB
DC9390AB1F1EBF1214B20E149212195D1217957776D3CBC6D9D7D3DAD7D5DAD6D6DCD4D2
E5D2CBD7AAA0A44D448C0D0B9102049202059101058E00038C00038D01058F0106900006
9201089302098F01058A0103840205750102760001980409AF0309B10104AE0002AC0102
A802059403057C00017601047E0A0C9B282A7101046E01046D01046601025F01015B0102
5401025101044C02054701024A0103500104550001640802862C1100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8DAD49D3C3B7AFB2B1969B9E989B9B8881804B2F2D400C0D603C3EDDD3D8D6DAE1D5DCE3
D1D6DDD5DADF4042471D0A122F081037040E40030C4E070C600F0C681B00D39A26D2A50C
DB9F15B24708B21202BE0706BE0407C4060AC50709C4050AC70608CC090ACC090ACD090A
CE0B0ACF0A0BD00C0CD40C0DD50D0ED70D0DDA100ED90D0BDB0F0CDE120DDE110CE11110
E11110E31212E1130FDD1817CD1F229D17206E1D28A38083D8CDCCECEAE7EAEAE6ECEBE8
EBECE8ECECEBEDEAE7F9E2DFECA5A2B62B27C52423871110935957F3DDD9F0E7E4EBE6E5
ECE9E8F0EBEAECE8E6EFE9E8EFE9E8F1EAEAF0E9EAEEE8E8EFEAEBEEEAEAEAE5E6F5E6E4
F7C4C2A8312FB70E11C20E13B60F15941115570B0B81625FCDC4C1DCD8D4D9D5D4DBD6D5
DFD5D6E7D2D1CC9B9592302B8B05059201049101048E02048C01048B00028C01028E0103
9102079001098B00058700048302056F0103690001890308AA060CB00307AC0001AA0101
A902039B03048100027902057801047702047301036F01036D01036701026000015A0102
5501035101044C01044801034600024A000256000165060281260C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B68853D2C1B6A7A9AAABB1B58A8D8F9A95966147483F0A0D542A2DDACCD1D6DAE3D6DEE7
D1D8E0D5D8E14D4F551E0A132C040D39050E43050D4F060D510302681D00D49B22D2A308
DCA017AD4006B21103C00908C00609C2070AC30607C3050AC50609C9080ACD0B0CCC0809
CC0A0ACF0B0DD00A0BD10909D40C0DD50B0CD40B0AD80C0CDC0F0FDE0F0EE11211E2110F
E2120EE61411E71712E61612E31916D91C1EBB1F227A1517875858D9CBC9E9E6DFEDEAE5
EBEBE6EBEAE8EEECEAF8E9E8F6C0BFB43532CC241FBB221EA93E3AFDC2C1FCD8D8FAD7DA
F8D6D9F9D6D9F9D3D6FBD4D6FAD2D5FAD5DAF9D2D7F9D1D7F8D4D8EFCDD2F3D4D8F6D2D5
FFC8C9BD4849BA1315C20D11BB0A0EAC090E8F0D11580A0C795959C8BDBBDDD5D4DDD8D8
DBD5D8DFD6D7E1C8C4AC6661810B089003068F01038D01038C01038A01018A01018A0001
8C01028B010687000487010483020572020560000072010395050AA30306A60202A80203
A802059A03067F01037300047902087801057300047000036C0002660103610203590001
5501035101054A01034600014300014900015E02046F060384230C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CD37D2C3B6C0C3C59BA3A79FA4A78C888A6952523E0B0E491B21D9C7CED7D9E0D2DAE1
CED8DED4DAE1575A611F0E172A060E3302093A010A44010B4C04036D2502D49C20D6A509
DCA017A73700B21003BD0805BF0607C00609C20508BD0207BE0206C8080CCB090ACB0709
C90609CB0709CE080AD00809D30B0BD30A0CD40C0BD80C0BDB0F0DDA0C0EDE0E0FE31111
E61510E91611E7160FE81711E81713E61714E21C19CC252386171966393BD4C8C4ECE7E3
EAEAE7ECEAEBEDE9E9F5E4E4F0B7B8B83636C41E1ABC2B26C7544EBD605EC46B6EC36169
CD636ACE6067C85B60C15258BD4F55CA5D63CB5D65C65C63C35E66B95B63B96168C66C6F
D76C6DC53937BF1412BF0B0CB7050AB00308A6080D88101544050679635FD1C6C5DED5D7
DBD5D8D9D4D4E2D2CEBF8A837E14108D03059001048E02048C01028A01018A01018A0101
8800018801028601038500028201027602045D00015D01017501038701039403049B0304
9C04078A02057000016C01047802077B01067901077401046E01016700016100025B0001
5300015101044D02044801024500014B000162010473040386210B46990400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DCA34D1C3B7BFC3C69EA6AA9EA4A7848485725F5E3F0F11411116CFBCC0D4D7DBCED7DD
D0DBDFD5DCE25E636A190B1425050C31030A39030E43020C500805722A08DBA225D6A509
DE9C18A83300B20C01BD0808BD0506BE0307C3060ABF050AC1050AC50408CB090ACA070B
CA060ACC080BCE0A0CCE0809D30B0BD60C0EDA100FDB0F0DDA0F0BDC0D0CE11011E5110F
E5130FE5130CE7170DEB1811E71611E61510E91B13E11D19BC2525550D0CAB9792EDE4E1
EAE8E7ECE8E8F1E7E8FADADED9878CB8262ABD1D1B820D0CEDAAA3ECADA4D17F79C05553
BE4140BC3737B83231B52F2DB5312EB3322DB23432AA322FA333329E35359D3737AB413E
B13932B32920B91D15BA140FAF0807AD0608A404088E0A0D5607054B2922BFAEA7E1D6D7
DCD6D8DCD6D6E1D3CEBE8F867F18138F03069101038E01028D01028D02028C01028B0101
8902018701018600018500018400017D02036501015200005A00006A00017601037D0003
7E01057001045D00026400027901067F01057F01067901047101006C0002690104600202
5801025101034D00024901034701014F0000670305740402801A0544960200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CC37D8CABFB5B9BBB2BBBE848D8F929394877878401213430E13BCA8ACD0D4D6D0D9DF
D0D9DFD4DAE07074791B0E1724050B31030B38020A3F01074E0603772F0BDCA222D9A50A
E09919A82B00B50D02BF0808BE0608C1070AC30709C3050BC20409C8060AC9060ACA070B
CA060BCC080BCE0A0CD10A0CD30C0BD70D0CD70D0BDB100CDC110CDE110EE00F0DE5130F
E61410E71610E5140EE91610E81711E5140EE4180ED81A16A618157A342DDDC2BBF1E3E1
EEE1E2F2DEE0F6D1D3F3AAB0C04348C41C1FC61C1B941416894B49F9D9D5FDE2DBFFD5CF
F9BDB6EDA7A1D88E85D1867CCE867BD18C83DF9D95E5A8A1E8B1ABEEBCB5EEBCB6F8C3BB
F6B8ACDF9284D6786BB64338A31D15A5120E9C07077D0304590D07906755D1B9ADE4D4D0
E1D6D4E4D6D4D9BDB8AC6C647F0D099202039501039101028E01028C00018E01018C0001
8A01018701008601008600018601018402037D0A096409075608077223225E0B0B5D0104
5D01045700035200016301037B02068201058402078001057701027101016B0103640203
5D01035401024D02034701024301014F00016A03047302017C160246970300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D9CDC3BFC4C5A1ABAD959E9F8486867F7271441819481015B0969CD7D8DDCFD7E0
CFD7DFD7DBE27D8086190C1326050C2D02073805093D03074A0702813A12DCA221D7A308
DA8E17A82500B80D03C1090AC00509C4060BC5070AC7060BC60508C70508C9070AC80609
C9070DC9060ACD090BD0080AD30A0AD70C0CD80E0BD80D09DA110ADB100ADD100AE1120E
E3140EE81811E5140EE6130EEA1611E91710E81B14CB14119E1C1BE9A19EF8C5C1F9CACC
FAC3C8E99EA4D26C71C0373CC72020D11717D01715C11D1E87181CAD777CF1DCDCF6EAE7
F6EAE6F6E6E3F6E5DFF3E2DBF9E9E1F6E7E1F5E6E2F5E8E5F0E6E3F1E7E5EFE7E3EEE6E1
F0E6DFF4E1D9F7D7CFEEBDB4D1877EA94039991B17800906AB5247D09181CE9D91CBA19C
CBA3A0C89895BC7B7594302C8C06049301019401029101018E01018E01009001008E0101
8C01018801008701008600018601018601018205039B37306C211CD69A97CD92935C1818
4E00025200015C00016F02047D01058302068601068702077F02057401026C0102650001
5E01025500024F02034500013F00005000026E04067403017D150245950200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D8CCC2C6CCCDACB6B89DA5A7787C7B908684563232440D119F7F87DAD6DFD1D7E2
CED7E0D6DBE486898F1A0B1326050C2D02093301064003075107028C4312D99F1ADAA40A
D68416A71E00BC0E06C20809C3060BC7050DC6060CC8060BC70608C80708C80707C7060A
C7060BC80509CD080AD0090AD50C0CD60B0BD60C0AD90F0BDB0F0ADC100ADE110AE2120E
E4150FE5150FE6160FE7150EEA1712EB1713EA1B15DA1917E24748EF7678E76B6FDA5B62
C33D47BC2631C92228CF1A1BD61715D71414D51413D11516C31E23951E28AC6970EDCED2
F3E5E7EEE8E8EDEAE8EBE7E7EDEAE9EDEBEBEBEAE8EDEBEAEBEAEBEAE9E9ECEAEBECEAEA
EAE9E7EBE9E6E9E3E1E7D9D7EED4CFE8B7B0BB69628E211B971F1BA0302CA33B3AA64343
A441419B31318E16168E08079603049601029401029100009101009102018F02018C0102
8B01018A0100870000860101870101860101820202851613AA534E85423D995C596D2525
5F06076802057502077E02068201058B050A8E050B8B01088502067800027001026A0001
6201015901025101034801024200015401017104067401017F150547950300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8AAA45DACEC4BEC5C7C2CCD1838E90888F8F9894924C2E2C440D108E6972DDD6E0CFD5E0
CED8E1D3D9E38F8F981D0D182B071030020B3401073F0206580F058E4612DAA31BDCA30E
CF7712AA1B03BA0C07BF070AC20509C5050CC6050BC9060CC70508CA0708CA0809C9060A
C70609C90708CC0809D20C0DD1090AD50B0CD90D0CDB0E0BDD100BE2130FE3130DE71611
E51510E71611E1120DE5140FE7170FEB1812EB1A13E71814DF1D1BDE2323DE2325DB2026
CC1118D1131AD71718D61213D61312D51313D51314D71416D7181BCD2025AE222BA13F48
CA8890EFC1CAF7D8DEF7DEE3F9E4E9F8E5E8F6E3E6F7E1E5F9E3E9F8E3E7F4DDE2F6DCE0
F7DDDFF4DADEEAD4D7E2D1D3E2D4D3EAD8D6ECC5BFC0736E9019179C0C0F9E070D9B060B
9E080D9C06099A03069801039801029701029601029300019301029201018F01018A0002
8A01018B02028802018600028702038701048601048104078212139C3C39A34846A34140
9727287F04088301078601068901068E030A91040C8E02088801067E01057501036D0102
6401015901015300034B01024800005D01027502047702028014064D9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B0814ED7C8C0C3C8CDA9B4B98B999B8992948483825E42424911127F585FDED6DFCED1DB
D0D8E1D2D8E191939C1B0C172A050F31020B35030A3A01054504008C5017D8A51BDBA30F
C66A11AB1903B90B08BC0509C00609C4060CC6060CC7040AC80609CB0709CB0909CB0909
CA0909CE0B0DCF0A0BD10A0CD40C0ED4090CD90C0EE01011DF100CE0100BE3110DE5140F
E51510E51410E00F0DE71511E8170FE7160FE91810E91813E71612E81816E31715DA1212
D40E10D30F11D91516D20F10D31011D71515D31112D51213D91615DA1919D41C1ECA2126
B8262EB43844BB535DC96B77DE8791E897A0DA8691DC8693E38998DD8491DC7F8CD97B86
CB6A74C76A73C57279B06D73B27F84C5A0A2E1C3C2EBBFB9A54C46950B0AA60309A60107
A40006A100049F00049C01039A01039700029601029600029400039401039200048D0101
8C01038A01028701018600028601038600038700048600068201077E04077E0507840609
8603088802088A02098C020891040B95070E94060B9003088A01078101057801046E0102
6501015C01015501014D01015000006701027B03057D03047F12064C9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5EC935D6C6BDCDD0D5ABB5BAA1AFAF7E87887B7B7E84696C47101371474EDDD3DCCED1DB
CED3DCCED5DD8D9298160A1426060D32030C37010B44060D490A039A601AD6A516DEA412
BF5E0FAD1604B90807BC0508C1070AC3060BC20409C7070CC8070ACB090ACB0909CD0908
CE0A08CF0909D10A0AD2090AD60D0DD70B0DDB0D11DF0F10E0110EDF100CE1110CE61512
E2120EE2100FE41211EA1613E5140FE81711E6150FE91813E81713E61815DB110ED10D0B
D00D0DD4110FD51311D31111D41313D41211D71514D81312DC1814DB1513DE1A17DE1B1A
DB1C1FD11C20CE2126CC2329CB272DC6252EBF1E2AC3212EC21E2CC41F2DC31F2BC11B25
C21C22BD1B20B2181E9F141B8E131D7E1B2489464AC89694D58E868E1510A00406A40003
A20102A00003A001049E00049B00049A0105960003960104970106970107930003900102
8F00038F01058B01048700028500018501028701048601058601078501068700058C0208
8E02098E020991050B91030A91020A95030B96050C8F01078A0107820005790003700102
6601015D01015702015201015901016E02037D01037E03037B0D034D9C0C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC733D9C9C0C6C8CDBFC8CD8B9799858E90929296654E524B141864353DDBCDD5CCD2DA
C8D1D9CCD5DD90979E18101729081034030D39020D3B0105480A01A36A1BD8A414DEA114
B64F0AB11503BC0807BD0407BE0408C2050AC20509C20308C30408CA090CCC0A0AD00A0B
D00A0BD20A0AD50D0CD50C0AD90F0CDC100EDC0F10DE0F0FDD100DE0100EDE100EE11111
DE110EE51311E71512E61510E71611E4130FE3140EEA1711E91814E41614D70F0FD00D0C
D00E0CD10F0ED71513D31111D21110D51311D81511DC1614DD1713DE1716DD1715DF1917
DC1916DD1916DD1A16DB1614DA1717D81719CF0F14D21217D31115D7151AD31114D31214
D11113CE1012C30C0FB4070CAE0710A00811890C13761417C36461A42624A10408A50106
A101029D00029E01039F01049D01069C01089A0106990105990106970006940003930103
9100039101048D01048901028802028601028601038500048601058701058800038C0005
90010890010890020A8D010792030C96030D99070F93030B8B01088401067D0204740101
6901015E00015801015700006502027503037D00027D0203780B0149980800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC832D6C4BBC7CACFAFB8BD8E999C8E989A888A8D7C696C43101358282ED7C9CEC9D0D6
C3D1D5C9D3DA9AA1A61B111826070E33040C37020A390205400701AB7318DAA714DF9F16
AC3F04B51303BE0A07BD0307BD0408C3060CC4060BC5050CC6060BC60408CA0809CE0809
D10B0CD1090AD30C0AD60E09D80F08D70C07D90F0BDA0D0BDE110EDD0E0EDB0D0DE11111
E41412E41310E4140FE61511E71712E71713E61612E91813E51612DB0F0FD40C0ED10C0E
D40F0FD20D0ED41110D10F0FD00E0FD61414DA1714DE1816DE1816DC1514DB1615DE1818
DF1B1AE01A18DD1914DE1815DD1816D41211D41212D61413D71414D71314D21011D20F10
D10E0FD10F12C3090EB8070DB0040AAC0208A5040999070B960B0EA30E11A30207A50106
A101049E01039F0104A001059F01089D01099C02089A01079A0106990106960004920104
9100049100058F01058B01038A01038801028600018501028500018601028701038B0105
9101089101098F020A8B01088F030B95040D96040C94040C8C01088401057E0103770103
6E02036201025900005D00016D01017801037F01047F03057A09006B600A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59C42CD8C7BACCCFD3B2B9BFA5ADB17F888A8083859A8B8E3F13154B1C21CEC1C3C7CED3
BFCDCFC8D2D69DA3A71A121727090E2E030838040B3D050A450B01BC841ED9A510E29E1D
A83400B71104BE0808C00609C00709C4070CC50509C60308CA070BCA0709CD090AD10A0C
D20B0DD50B0ED50D0BD70D0AD70D08DB0F0DD70C0BD70B0CD90C0DDC0E10DC0E0FE41213
E41312E51313E2110FE61413E61511E71413E71512E51413DD100FD30A0AD30D0ED40C0F
D60F10D40E0FD71313D00F10CE1010D31113D71415D91415DA1515DB1515D91614DD1717
DD1717DC1615DB1513DD1716DE1817D61111D61314D81514D91415D61213D10E10CF0C0E
D00C10CF0E14C1080FB4030BAE0108AC0107AA0106A50106A50208A30007A50108A40107
A30106A10106A001069F02069D01069C01069B01079C03089A0107990106970106920105
9000049001069002078F02058D01028700018500018400018400018400018600038B0106
91020991010A90010B90040D91040B94030B94020995040C8D03098400057D0004780003
7001036702036101026801027201017801017E02037E0204780700902D0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C22ADAC9BCBFC1C7C5CCD58F979C7A82849497987B6D6F3B1214431317B9A7A9B4BBBF
B4C0C2C6CFD19EA4A81B141926070D2F030937040B3C0508470D00C28A20D9A410DF961D
A42900B70F06BD080AC2080CC3070AC40608C70606CA080ACD090ACD0A0AD00D0BD0090C
D20A0CD60B0ED70D0ED70B0CD70C0BD90D0FD80C0DD60A0DD80C0DDA0D10DC0E11DF0E10
E31111E41213E31110E20F0FE51410E81411E61412E41314DA0F0FD60F0FD81111D80E11
DA1214D50F10D61314CF0F0FCE100FD01111D31313D41313D71415D81415DA1716DC1816
DD1715DC1715DA1714D81412DD1917D71413D81515D71414D41112D20F10D10D0FD31012
D10D11C9090FBC040BB10208AD0107AB0106AD0309A80109A9030BA6010AA5010AA30008
A10108A3020AA101079F02069B00039A00039A01049A0105980004980003970103940104
9100049101058F01059101059002038B02018601018400028401028401028500038A0106
8F000891010A93030C95040E96050D95040A94040A93050B8C02098500078101077B0106
7200046A00036A00027602047901027701017A01017C02037407008F321500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC32CD8C5BBC5C8CFB3BDC48A95988C94967E838584797B3B13153F1013A99698B3B6BB
B6BFC2C9D1D4A0A7AC1810182C091331010B3703093902054A1300CA9525D8A50FD78A17
A62303B90F0ABE070BC1060CC5080DC30506C70807CD0B0CC90608CB0808CF0C0ACF0B0C
CF070AD50C0FD60C0FD3090CD50B0DD60A0DDA0E10DB0D0FDA0E0DDB0F0FDC1010DF0F10
E21010E21011E2110FE61313E81511EC1914E61612DF1210D80F10D81112D60F0FDA1314
D60F11D00C0FD10F10CF100FD11312D31514CE1110D11312D41415D21214D41514D51814
D71D1AD1201BCD251CCC241ECE251FCD221ECD1F1DD11E1CD31817D31313D51112D71112
D71114CE0C11C1080EB40209AF0208AC0107AB0209A9010AA8020BA50108A20107A30107
A10107A00007A10207A102079E01049C01039B01049A0105980104980103980204940104
9200049000068F01069000059001038B0101860000850001860102850102870004890006
8E010992020B92010B93020B93020A96050D94040B93050C8B01088700088100087E0108
7600057200037A00058401068201047800017801017802037007008F361700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BF29D0BEB3CBCED5ACB5BA9CA7A9777F826C7072A59C9E3E1C1E380B10A59295B8BABF
BCC5C7CDD6D9A2AAAE16101828071231030C35020A3601044B1800CE9E26D8A711CF7D15
A41B02BA0D0ABF070BC0060AC5080BC20406C20403C70507C9060ACD090CCE0B0CD00C0C
D20B0DD20A0DD20A0DD30B0DD30C0DD50A0DD80D10DB0E0FDA0E0DD90D0CDA0E0DDF110F
E1120DE41311E2130FE81612EA1611EC1A14E31711D80E0DD20C0BD30E0ED3100ED71213
CF0D0FCC0C10CE1011CD1012CD1010D11315C90E0ECD1212D01717C81516C41C19C0261E
B22A22AB362FBA554DCE6D65E5847CE6817AE47872DB635FCA3F3CC52420D01A18D81716
D31011D21012C80C11B9040AB10209AC0209A80107A60006A70106A50105A30105A40105
A101049F01039F01059F01059F00049E01059C01049B01059901049500029101058D0206
8F02079002068F00058F01048D01018A01008700018601028701028801048902068A0106
8E010992010A92010B92020B92020A94040C92020A8E020A8701078400088101087D0107
7701047A00038A02089403088C01037D00007800017803036E040092381A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C028CEBDB1C4C7CEC1CBD1929E9F727C7C969B9B7C75773D1E2031060B9C8B8FBBBDC1
C4CDCFCDD7D9A0AAAC1411161F070C29030A300208370706502103D0A126DCA918C26D15
A11601B90A08C00809C2070AC30608C90A0CC60808C70609CC0A0CCE0A0CCF0B0CD10A0C
CF090AD30B0DD10A0BD60D0CD50C0CD60B0DD90E10D80B0BDB0F0DDB0F0DDA0E0BDD100D
DE120CE2140FE51610EB1812E91812E1140FD80F0AD20C0AD00D0AD20E0DCF0D0DD41213
CC0C0FC90C10CA1011C90D10C90F0FCE1414C61112C01816BC201CAB241F9E332CAE5D53
DA9E95F3C8C2FCDCD7FBE1DCF9E1DDFCE1DDFDDFDCFED8D6FCC3BEE88E89C2403BC41F1A
D01514CF0F10CD0E13C0080DB5060CAC030AA80209A80208A70105A40104A20104A30105
9F01029F01039E01049D00049E01049C01059B01049B01039900039401038700047B0002
7F01048B03078E02058F01048D00028B01018700018701028600028901048A01058B0107
8E020992020A94030C92030B94070E93040C94050E8D030B8600068301067E00067A0104
79010285010497030A9C01089501038701017B00017702036F040090331800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C027D2C2B3C6CBD0C5D0D88B999B8E9898868E8D7671713E2022370B0EA18B8FC7C9CE
CCD4D7CDD7D9A0AAAC1515181A060B2703092C03082D0202532605D2A225DDA61AB65C11
A51404BC0C0ABF0708C10609C50709C9080BC80A0BCB080CCD0A0BCE070ACD0809CF070A
CF090AD20A0CD60E0ED60C0AD60B0CDA0C0EDB0F0FDC0F0BDE110CDE110DDF120DDC0F0C
E0130EE41811E71812E71410E51712DB100ED50E0BD10E0CD3100CD81412D41112D00F11
CB0D0FC90C0FCC1213CB1213C81312C51715BD1D1AAC231E9022199C4A42DAA59DF7D7CF
F6E5DFF1E6E3EFEAE7EEEAE9EAEAE8ECEBE9EDE9E8ECE5E5F5E6E4FFDCD8F5ABA5BC3E38
C71E1BCF1414CC0C12C3080EB6050CAA0107A70108A70108A60007A20103A000039F0004
9F00049C00039D01059D01049C01049B00059800029800029A0002940003890105780001
7300008301058C01068E01048E01038C01018800008600028700038901048900048C0107
8E010791010995050C8F020891060D91050D9407108D030B8600068200057E0105790002
7C00008F02069D0208A102079C03068E01047E01027602026C03008C2F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55C025D1BFAFC7CCD1ABB7BE95A3A68D99986771709795954224253E0E11A68D91CECFD4
CDD6DACDD4DBA0A9AC1211151A03092B040B2C02062B030162340ED29F21E1A61DAE4E0C
AA1303BD0B0CBF080AC10609C5070BC5050AC40608C9070ACD0A0BCD0708CE0809D1090B
D20C0CD30B0BD20B0CD60B0CD90D0DDB0D0FDC0E0EDF0F0CE3140FE3120EE3130FE21210
E3140FE61711E71712E71511E31510D9100FD40E0DD6100FD50F0DDA1516D41211D21111
CF1111CE1213CE1616C71615BE1C18AF211D9A27209F4B44C89187E8C6BFF1DFDAECE3E0
EAE6E4ECE8E8ECEBEAEAE9E8EAEAEAEBEAEBEBE9EAE9E7E8ECE9E8F0E7E5FADCD8DE908B
B5302BC81919CB0E13C60B11B9050DAF040BA60007A50007A60108A20105A001059D0104
9C01049A00049A00059C02069D03069900039800029900029C0204990104930205870306
7A00028302068D01078F01058E01038D02028A02038902048901048C01038B00038D0105
90010792010892020892030A8D020992060D92060E8D030A8701078402087F01067C0003
8601059A050AA10207A50308A00408910306800103730102680200862A1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C127CCBAA9C9CED2B3BDC59AA8AD768485798484888989452A2B3E0D10A4878BD2D2D7
CCD5DBC6CFD79AA1A7140E1422080D30040D34050C310402784816D5A21EDF9F1BAB4004
B01206BC0A0DBF080AC2080BC4070BC20609BD0205C5060ACB0809D10B0CCF090AD20A0D
D30B0ED60C0CD80E0ED90D0EDA0F0FDB0E0FDD0F0FE1100EE41410E4130FE51410E10F0E
E4130FE51410E61611E51511DF1411D50D0ED30D0ED71212D51211D61213D41310D11312
CE1513CB1A19BD1D19AA241D972E26A1564ED1A29AEDD3CCF2E5E0EAE4E3E9E8E7EAE9EA
E7E7E9E8E8E9E6E7E8E1E1E3E7E8E9E7E8E9EBEBEDEBEBEDECECEDECECEBEDE7E5F2D4D0
E49793B62829C61317C80D13BC070EB1060CAA040BA50108A7040AA30208A001059B0002
9A00029800039701069900059801039701039902049B02059B01039B0105990206910205
8701038801048F01059001048E01028B01018B01028B00048B00048A01048A01058C0106
90010792020893020995040B90020993060C92060C8D030A8901088300077F0106800004
92020AA2040CA20209A402099C02058E01048201037101026301007E250E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C026C6B4A3C6CACECCD4DC859398808E907985856C6F704D3434400E129F8186D2CED5
CDD3DACDD4DD9A9FA5170F1623080E2B030B2F030B2F02028C5C1ED6A41BDA981AA32F00
B10F06B80508BE070BC00609C00607C0070ABB0302C5080ACC0A0BCD090AD00B0CD40B0E
D60B0FD70D0DD70D0BD80C0BD90F0CDA0D0CDB100DDF100DE3130FE31110E51410E61312
E61511E3120FE41611DF140ED70F0CD30E0FD00C0ED20F11D41212D21211CE1711C21A14
B8221DA92B23A03F36B7766CDEB7AFF0DBD4F2E8E3ECE7E6E9E8E8E7E6E8EBECEEEBECEE
E8E9EBE9EAECECEDF0E8E8EAEBECEEEAEBEEECECF1ECEBEFEDEDEFEEEEEEECEDECF1EAEA
FBD6D6BF5C5DBB1C1DC71012C10C0FB3050AAA020AA70308A60208A50108A000059C0104
9B01049A01049700049700059A0105980004970105970104980003990005990106950106
9301049302069201059001048D01028900008901028C0105890104860002860003890006
8C000790010892010996030B96040996060A94060B8F040B8901098100067F0005880106
9C040DA3050E9D00089C02089602058A000281000273010264010081250F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C025C8B4A2C1C5C9BAC4CC9EACB0909EA05A67669397974F39393E0F148D6F76D3CED5
CAD0D6CED5DD9A9DA21C111822070E2702092C0307330704976A1DD7A61BD38E1B972000
B10C08B70307BD060ABF0708C00607C10609C10607C40608CA090ACD090AD20C0DD30B0E
D50D0FD70D0FD40D0BD80F0DDB110DDA0E0DDB100CDF120FE2120EE3120EE51511E3140F
E3140FE2130FE21913D40F0BCF0D0BD01010CE1010CC1311C91713C6231BB2271DA53A31
B2645BDBA59DEACCC3EFDED8EDE4E0EAE6E5E6E6E6E5E4E5E6E7E6E8E7E7E8E7E7EAE8E9
EAE9E9EAE8EBE5E7E9E5E5E7EAEAEBECECEDEDEDEFE5E5E7EAEBEDEBECEEEAECEEEEEDEE
F5E4E5EEB0B0B02D2CC31414C30D0EB50609B0060BA70308A70409A50308A101069D0105
9B01039A0103990105980106980106970004950003930104960106970106960106930104
9401049402059301059102078F01068C01048C01048B0004880003870102870102870104
8800048C010791020994020A95030A96050C95050C90030A8B020A850006880106940106
9F030A9B040B8E02088B01058F02068C01048302027301016701007F200A21CA0200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD22C8B3A1C3C7CBBBC5CEA8B5BB7A8588818C8D9296984F3D3F3A0F157B5F66D5D1D5
CCD2D7D0D7DE91969B170F1423080E28030B31040A3A0702AB791ED7A51BC278159B1B01
B20C09BE080DC0070CC0060BC3060AC40409C50709C8070ACA0809CD090BCF090AD20A0C
D30D0ED40D0FD31010D91716D81211DB1011DB0F0DDF120FE1140FE0130FDB1811D61B14
D81C14DC1D15D51A13CC140FC81610C61B16C3241DB4251CAF3328BE5B51D7948AF1CCC5
F6E2DCF3E7E3EAE6E3E8E7E5E7E7E5E7E5E6E7E3E7EAE6E8E8E5E6E8DFE2EDDDE2EDD5D9
E8C9D0B595A0B2A1AAD4D0D6E2E2E4EBEBECEBEBEDECEBEFECECEFEAECEEE9EBEDEFEFF0
EFE8E7FBD6D5B95353B61616BF0C0EB9080BB3060BAD060CA50208A50309A20107A10109
9D01059B01039A0103990103990105950105940105910003920003920005930006920105
9100049201069000058E01058D01068D01098C01068B0004890103880102850001850002
8901058C000790020992020994030A96050C97070D8F02098A00078B000795010A9F010A
A0030B8D01077700038914178504088B04088202037501016A01007C1D0843950300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59BF24C3AE9DC7CDD0C5D1D998A5AB8A949891989B6F7174564448350B1483686FD3CFD4
CBD4D6D3DCE1889193110D1220070F27020B2B0205431102BD8A21D8A31AB35F11A21602
B40909BC060BC0060BC4070CC5060BC4050AC50709CA090CCC080BCC090BCE070AD20C0D
D20D0DCC0A0BC90F0EE62E2FCA090CD90F12DC0E0EDF120EDE1310CD0F0DBC1F19E96E66
D35A4FCA4B40C74639C6463DC85348CC665BD57D73E7A399F4C4BCFAD9D4F7E6E2F2E9E8
EDEBE9E9E6E5EAE9EAE9E8E8EBE9EAEDE4E8ECDDE3F2D9DFEEC9D1E8B1BDE69DABD87B8A
C35765A63D4C601C2A61454ED1CBCFEDEDEFEAEAECEDEDF0EFEFF2EBECEFEBECEEEDEDED
E8E7E5F6E0E0D28487B02022C41316BD080CB5050AAD040AA8040CA5010AA20008A10108
9F02069A01039A01039A01059600059001048E0104920206910102910102910005920106
9202069001058C01048901028A0104890105890104880003880004860102820001850203
8B02078D02088F020894040C95040C98060E97060F90030B8D010895010AA0010BA5010B
A0040B8401057402058B181D7901058203077C00037001016701007A1C0843950400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BE22C2AC9BC6CBCFBAC6CEA4B1B59BA4A969737592969A58494E320B13836870D6D2D8
CDD5D9D3DDE280898E140F1421050F2B030B280001411300C79525D9A01AB0530FA61203
B7080ABF070DC3090CC6080CC40709C4060BC4090CC1070BC1080CC4070BCD0B0DCF0B0C
D20F0FC00808B91010BA1313C2080ADB1012DE0E0DDF120DDD110FCA1010870202B66C68
F1BFB9FED4CCFFD4CCFFD6D0FFDCD3FDE3DBF9E4E0F6E7E3F4EAE9F0EAE8EFEDEBECEBEB
EAE9E8E9E5E5EDE4E4EAD8DBE8CBCFE3B2B9E6A1ACDB7F8BC3525EB6303EBA2634C3212D
C81E26C32026901B213D050DAA999FEEEDF0EAEAECECEDEFEBEDEEECEDEEEAEBEDE6E7E9
EDEDEDF6E9EBEBB2B6AE2C31C7161AC80D12BE080DB20308AB030AA6020AA20007A10107
9F02069A01039701019901039701068F01038A0005900208920106930106930205910104
9100058F00058C01058800028800028700028901038800048801058601048001017F0101
8601048A02068D010791020894030B98051096050F94040D97010BA2020DA9030CA70108
9C030A7D00027702077A02077500047802078413166E010266010076190843970600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
53BB1EC6AE9DC4C6CABAC3CAA9B4B97A85898A9598989FA35C4F533A131B80646DD8D2DB
D2D8E0D5DCE57D838C1810182707102F030A3305054C1C01CE9E29DA9E1EA13B05A30901
B70809BF090DC2090DC00508BF060ABD060AB7090CA502089D0106A80407BD090CCB0B0D
D20F0FC30D0FC32828DD4646C91512DA0F11DE0E0DE0100CDF100CDA1614B61112750B0E
965B60DFC1C6EEDEE0F2E6E8F1E9EAF3EAEDF1E8EBF1E9EAF1EBEBF3E9ECF3E9EBEEE2E4
F1DCDCEEC8CDEFB5BEE897A1CD656CBE4048BC2C36C3222DCB1E27CA151EC91318D1171A
D11818CD191AB022235B090D644649E4E4E6E7E8EAEBECEEECEEF0EBEEEFEAEBEDECEDEF
EBECEEF3EBEEFCD3D7B84B4EC31B1ECC0F13C40B0DBB080BB2050AA80209A30006A00005
9F01059B0004980002980102980103960207920209920108930107920006920004910104
9101059001068E01068C01048C01048D01058C0206870104880106880105840103820102
8400048801058E020690030795060C97050E95020B9A050CA3040CAB050EAB020AA50108
9603097700017602067C040977010777030876070D6F03066701026E120542950500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD20BEAA97B8BCBCC6CFD6A1ADB488959B9DABB06E757A675A5F3811197B6068D9D3DC
D5D9E2D7DDE7767C85140E1625070F2D030B3406055B2B0BD2A22CD59622972A00AB0D08
B50709B9050BBF070EBF070CBB080CB1070A9D0104BB2E34D5585DB027299C0405C30E12
CF0E10CC0F10E1373AE23A3ED21516DD1112E11110E21210E2120DE11411D81414C1161B
95111A882937B56F7CD198A4DFB0BAE2B7C2E4BBC4F4CBD1FACED5F5C0C9EEADB9E49AA5
D67B85C4525EC13944C62935CE232ACE1C22CF191CCF1418D21518D4141AD41518D21516
D31716D3191BBD1C1D8A1A1D441113C8C5C6E7E9EBEAEBEDEAEBEDEBECEEEDEEF0ECEDEF
EEEEF1EFEAEDFADFE2D07A7DB92023C81014C50C0FC0090CB6060BAD0209A60007A30109
A100089C0106990103960001950001960105960107940109920108910108920107910006
9000069101079001078F01068F02048D01038C00038A00048B0005890105860004830103
83010387010490040A8E01088F020A93030B97030BA40710AB050DAB0209A90209A30108
97030C7500036D020578050B7600057B04096E02076B01046901026C0B0142930400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52BB1EBFAB97BABEBFBBC7CEADBAC2A8B5BC6D7C7F91979C695E62331117785E64D6D1DA
D5DBE4D7DFE9696F78160D1621060E2C050D3106046D3E14D2A129CF8C21901C01AB0909
B6080ABA060FBB060FBA070EAF060A9F0103A00308C82C35C63038B524288B0000AF070A
CB0D0ECE0B0DD00E12D31116D81012DD0F10DE110DE21210E1140FE0110FDB1111D20E11
C81115C01620B71F2AAF222FB02D38AE2E3BB13642C84C5AC44654C13846C02F3BBF2530
C5222ACA1D23D41E20D5181DD5161AD41517D01312D31315D71618D81519D71619D7161A
D41416D01317C7191CAE2225580A0C948889E4E8E8E8EBEBEBECEEE9EAECEBECEEEBECEE
EBECEEEBEBEEF4E5E7E3A3A6AC2327C81416C60D0EC0080ABA080CB3060AAA0108A50108
A101069C01049900029600019701029601039501059301078D01068B02088E0209910208
9000069101079001078E01068D01038C01018D01028D01038D01058A0107870005850004
8500048800068D020A8E010A91010A99060E9B020AA8060FAE060EAC040BA702099F0007
98050C7501045D00026A060C7302087B050B8E24286802036F0305700B0142920400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B81BBFA893CED1D3BFC8D2B2BFC88493998291939DA5A96C6368341218775C63DBD6DF
D1D9E2D7E0E95D626B1B0E1627070E2E050C34060589571AD5A325C1771A8E1301AA0A0A
B5080BB8060EB80811B207109D03079C0104B50710C00A13BD0912B10A0F8F0000A90609
CA0E0FCF0C0DD30E0FDA1014DA0E11DF0F11DE110FE0130FDF120DE01410D7110FCD0B0B
CB0B0ACD0E10CD1114D01417D11618D2161BD2191FCF171FD01921D2181FD51A1ED3181B
D11718D11515D71616D81918D51817D81D1AD31915D31C18D31D1AD31917D71F1CD6191B
D41518D21419CB1618BE1D227B1216614547E1E3E4E5E8E7E7EAEAE9EBEDEAEBEDEBECEE
EAEBEDEBEBEDF0E8E9F3C6C9AB373CC11719C60E0EC20A0BBD080CB6070CB0050CA8000A
A301089D00049900039801039802059400029301029201058801037C00018301038E0207
9102068F01058D01058D01058B00038A00018C01028E02068B0106880004880004870103
8600038701038E020890010A98040CA70B13A7050CA70309AD050DAA030AA301089F0007
99030A7C040A5C090C4C00046301067C050D810E156F0004700203720C0243930600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
29DB0DB59A84CBCDD0C6CFD89EABB3839297A6B4B7747D826A616836141B7A5E66DED9E2
D3DBE3D7E0E950555E1C0D1527060C2D0508360904A4741ED7A525AE5C138F0D00A60708
B1050BB3030BB0070D9F040B8D0002A8060CBD0710C4060FC0070CAD070A8C0000AC090B
CD1011CC0809CD0708D80D11DC0E11DC0E10DB0D0DDF120FE0140FDC1210D00C0BCD0E0E
C90C0CCB0B0CD00F10D21010D61411D61414D61918D21817D31D1AD31D19D61C1AD51B19
D21715D11513D01918C9211DC62D25C9372FC5382DC63E33C8463AC8493FD14F46D2433F
C61F1FD4181CD2171BC7171BA21F22451114D3CFD0EAECEBE9EBEAE7E9E8E8E9EAEAEBED
EBECECE8E9EAECE9EAF6DADCB65B60B81C20C40D10C30B0DBA0409B5050BB3050EAD030A
A702099E00059A01049701049400049100029200019200029002058501028501028C0103
8F01028E01028B00038E01068D00058C01048D02048D01058B01078900068C01058B0003
86000187000290060C93030AA30811B00811B0070FB1080FAB040BA80309A40109A00107
9B020981030AAE5C615D23255903077E040A86060D7C020674010370070044920700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC8F74C7C6C6C3CCD5AEBBC1AAB7BD7D8C91868F956C656A32141B7B626ADDDBE4
D6DEE7D9E2E94A4E561D0E1427060C2C0508340800B48421DAA5279B4009970E02A70608
B0040CB0040CA9090E8A0205880203B10A12BE060CC3050AC1090DA60407890000AE090A
CD0F10CF090CD10B0CD40D0ED80E0EDA0D0EDB0F0EDA0E0EDF1514D30D0EC9090AC8090D
C70B0CCC0E11D01013D01112CE1813C9211BC52D25CB4339CF5247D2554BCF4B41C73830
C52A23C9231EBA1F1D7D0908D98A83F5B4ABF1B4AAF3BCB0F5C3B7FCCDC4FECDC6FDBCBA
BA3E3ECB1C1FD11518CE171ABC22245608099B8B8CE8E8E7E9EAE9E7E8E8E9EAECEBECEE
EBECECEAEBECEAE8EAF3E2E4D28E90B12528C51215C1090DB9050BB4040BB4050FAF030C
AA020AA200089E02089901059500049401049400039500039201038E02048C01048E0303
8D01018C00008D01028F01069202089101078E00058C00058C00068C01068B00048C0105
8B01068900048E01069E060DAC080FB70B14B4060FB30810AC050CAA040BA60108A10108
9C01088C040C85232B954F565C030883040D86010881010678010371050044910600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00947452CCC9C6C2CBD1C0CBD492A0A884939896A1A76C686C31161B79626ADFDBE7
D6DEE7D6DFE63C3F471D0C1429070E2F06083E1000C6962CD79E278D2C019B0C03AB060A
B2050EAE050F9F080F790001890205B1070EC1070DC6070CBD080BA003048E0000B80C10
D00E10D50C0ED50B0ED60E0ED70F0DDA100EDB100ED60E0FD61011CF090DC8080CC80A0E
CC0E10CD0D11C71113BD1918A7211AAE493FD99085FECAC1FDD4CBFFD6CEFECDC5F9BCB6
ED9F98D17068A6453F4B100E98817DEBDFDBEEE2DFEDE4E1EFE6E4F0E7E5F4E8E7FDE0E0
C46C6FC5262BD3191BD11617C71E1E7911136D4F51E8E7E8EBEBEBECECEDEDEEF0ECECEE
E8E9EAE7E9E8E8E9E9ECE4E4DEACADA32B2EBC1316BD0B0EB8070CB4050BB3050BB1040B
AD030BA70109A201069D01059A01059800049702049601039201028F0202890001870101
8C01018D01008D01018D01038F00049101059201069001068F02078C01058A0004880103
8901038C0002960105A50409B1080EB5070FB1020CB2060EAC0209AC020AA70108A00106
9C010895020A91151D710C1473040B89030C890108810004790103730600655B0700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0084623CD0CCC8C5D0D5ACBBC2819299A8B8BC7681896A676C31151B816770D3CED9
D6DEE7D3DCE52E3038210C1429050C320604512000CA992BC98E26741500970A07AB060C
B1030CAE071193050C710001890307B2090FC3090DC5090FB9090E970103950102C10E13
D10E0FD40C0ED70D0DD90F0FD40D0ADA100ED9100CD91211D00C0DCD0A0EC9080CCD0C0D
CD0E0EC91010B41416780B08A86960F1D0C9F7E7E3F2E9E7F3EDEBF1EBEAF4ECEBF5ECEA
F6E6E2F7DBD5E6C5BE8D7671766D69DCD7D6E5E3E5E7E6E8E6E5E7EAE7E9EBE7E8F6E4E6
D49295B72A2FCE181AD41719D11E20991A1D4A1C1FDBD8D9EBEBEDEDEDEFECECEEEAEBED
E6E6E8E8E8EAE7E8E9EDE8EAEFCFCFA7474AB0161CB6090EB3040CB60711B3060EAD020A
AD040BAA0209A70208A203079B00049800029600029100028E00018D0101890000880101
8800008B01018B01018A01018E00029101059100059201078F02068C0104880104880001
8C0001950103A00105AB040AB40810B4060CB5070EB3070DB0060CAD040BAA030AA30207
9F01079B010991040BA5262C8F0E178B010A8B010880000476000173060085220600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F6C46C6C2C0BBC6CDAABAC1ADBDC4798990808B90716E7133151A816970DAD6DF
D8DDE8CDD6DF2B2C35210C152B060C360803693810CE9D2DAC721F6B0C01900708AB080E
AF050CA908118904096D0003810206A7060DBA0A0DBC0B10A8060B8E00029D0506C60C10
CF0C0DD40E0FD20C0BD0080AD40C0CD50C0BDA130FCF0B0BCB080BCB090CCC0B0CCE0E0D
CA0C0BC213148A0D0E612A28E4CFC8F2EBE7EFECECECECEDECECEDECECEDEAEAECECEBEF
EBEAECEDE9EAEBE6E4E6E2DDD8D4D0D3CFCFE6E5E8E7E7E9E7E9E8E8E8EAE8E7E8F3E8E8
F6C8CAB53D41C91B1ED11318D2191DB620274F070CADA3A4EAEDEDEDEEF0ECEEEEEAECEC
E5E5E8E9E9EBE9E9EBEAE6E8F2DCDEAC6266A41C1EB40D11B60910B4060EB2060FAB020A
AC030BAB0209AB0309A702069F00049900039701049302068E00018D01018B0202880001
8901028A01018B01018E01029001049101069301099101088D00048B00048C01048E0002
980104A20208A80208AC0209B40510B5050FB6060FB2040DAF030BAC0309A90308A70209
A30107A001089A030992030B8D020B8A00088902077E010373000073050089230900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0093714CC7C4C2BEC9D0BAC9D19AA7B07D8B9195A1A475737432151A866C73DBD8E0
D6DEE7C5CBD32220292007102C060C33050481511BD7A5349A5B1B760C02940407AC070E
AF060EA6060F820207650001760105920309A10409A1040A9002078300029E0607C90E12
D00C0ED40C0ED20C0BD20C0DD50D0DD50D0ED10C0FC60408C6060CCA090DCD0D0DCE0C0C
CD0E0FBB13156907077F5F5DEAE0DDF1EFEEEEEDEDEEEEF0EAEBEDEDEDEFECEAEDECE5EA
DECFD7E2D2DCEBE3E9EAE8E8EBEBEAE2E1E2E3E3E5E6E6E8E7E9E8E7E8EAE7E8E8ECE7E8
FBDEE0C4656AC12023D21A1FD3171AC51E226E0E147A6368E9ECEDECF0F1E6E9E9E7E8E9
E8E8EAE8E8EAE2E2E4E5E2E5EBDEE0CA92949A1F22B21014B1070CB0040BB0050EAB040E
AA030CAC030AAE0209AD040AA501079C01069701069400049100029001008E01018C0103
8A01028A01018B01018D01018C01038E01059100099100088F0005900104930005990104
A40106AA0108A90108AA0109B1020CB5050FB60711B3050EB2050EAE040CAB040BA40106
A202079F020899020993010A8E00088901078803077F010472010070040088210900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C6B46C2C0BDBECBD2ABBABF7D8990A9B7B97784886E6A6E34161C8E747BD9D6E1
D1DAE3B0B7C119131E21060F2E040A3506069F6F20D39E2E853A0E8A10079E0609AC040C
B0060EA9051088050A6400026C02067F02088701098602087F01057E0001A3070AC50C0F
D10C0DD30B0DD20C0BD30B0DD50E10D10B0DC70709C3040AC7070ECB080ECF0D0ECC0A0B
CE0F10BA171A5C0506917B78ECE7E5EDECEDECEDEDECEBEFEBECEEEAE7ECEDE3E7DEBBC1
9D56638C3D4DA26879D4B9C4E6E1E6E9E9ECE6E5E8E5E5E7E7EAE9E5E6E8E3E4E6E9E7E9
F4E3E5D79096B9272DD42124D7191ACC1B1D93191E50272CE2E1E4E9EBEDE6E7E9E6E7E9
E8E9EBE9EAECE6E4E7E4E2E5EAE2E5E6BDC19F363BAE1318B2090FB2060EB0040DAE040D
AD040DAD030CAF020BAF020BAB040B9F01089901069500029401029301029102018E0202
8B01018901018902018C03028B02028F01049301079301079200039601059C0105A10005
A70206AA0208A60208A40207AE060CB3060FB90A13B3060CB1050BAF050BA90209A40106
A000079A02098B01058D040A8D03098700038701057F01057401016F030080190400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B6A46B0AEACC4CED5AAB7BDB1BDC27E8D8F7D878D716C6F33151B947A82D4D3DE
CCD5DFA4AAB51C141F280A162F040A3A0A03B6852AD29C30711A00910C09A4060BAF050C
B3040DAC030E8F040D6400036201066F01087A040C78030A760105880105AA0409C60A0D
CE0B0AD20C0BD10B0AD50C0ED30D0ECC0A0BC7090CC5060DC7080FCB090FCB080CCE0B10
CD0E0EC0191C610708866F6EEAE8E6ECECECEBECEEEAE9EEEAEAECEBE8EBEEDEDFBB7A81
AC2A35B8202BAB2634822735956F7BDED7DEE8E7EAE6E6E8E7E8EAE6E7E9E3E7E8E7E8E8
EDE3E3F0BDC1BA373FD2242AD71A1DD0181BB01E244A080FBBB3B6E6EAECDEE0E3E8E9EB
EBEBEDE9E9EBECECEFE5E5E8EAE7E8E4C9CBA24F52A21519AF0A10B30810B0020CB1040D
AE040CAB0109AE020AB0020BAD030CA501089E02069A01039501029100019001018E0101
8C01028B01008801008700008A01018E00039200059500069B01089F0207A40207A40106
A501079E0206900102950306A6050BB3070EB6080EB5080EB1050AAF0509AC040AA40006
A001079902098600048001048803088700058701068100057701026D01007D190500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00856143BBB8B8C3CCD6C0CED69BAAB178888D959FA57A757A33181D947C84D6D4E0
D0D8E18F94A0150D192306122C0307411200C79735C48B2979180298090AA80309B2060C
B4050CB0040C9E08116D00055C01056B0C138A2E33882D337002089B070FBB0A10CA0B0C
D10C0BD20A0CD20A0DD70E11D30E11C6060AC10609C3060CC7080DCA090ECD0A0ED00B0F
D00E0FC2151A72090C705355E7E2E3EDEBECE9EAECE8E8EAE5E5E7E8E5E7EEDEDEBD7A7E
B02529C5171BC7181EB62029711521725761D8D6DAE4E4E6E2E2E2E4E5E7E4E7E7E9E9EB
ECE7E6F8D5D8B95257C6282CCF191CD2171BBC1B20610A0F7D6C6FE1E4E6E1E5E6E7EAEB
E8E9EBE9EAECE6EAEBE3E5E7E7E7E8EADADAB5767992161AAC0B12AF0610AF040EB20710
AE030CAD020AB0040BAF020BAA010AA8030AA502099E01079701059200048F01018D0001
8D01038C01018900008901018C02028F01039500049D0106A4030BA60109A60107A50004
A200059600038301027C0001940308AF0810B60810B5070EB2050AB00509A90105A60208
A101079C01088F01088200048401068801078600068201057901026F01007A150400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00896547BBB9BAC1CCD5B8C5CE77868EA7B6BB7D878F6D696E2F1318977F87D5D1DD
D2D7E07C848D110C1520050F2804054E2105D19F3BAB6A1F750C019D0A0AAC060BB4080C
B5060BB3040BAE0A12830307620204C97E85FEC3CAE3A1A8760F12AE1316C00A0CCB0A0C
CF0C0DD30D10D20D0FD00A10C7060BBF0308C00609C2050BC80A0FCE0C10CE090FD10A0F
D31013C815198A0E13532F32E1D9DDEBE7ECE7E7E9E5E5E7E5E5E7E6E3E6EBE0E0D09C9C
A62A2CC01619C81217C2151B9E1B243D080FB0A8AAE1E1E0E5E5E5E7E7E9E6E8E7E7E7E9
EEEBEBF7E2E2C97E80AC272AC92023CE171BC3191D8013194C2C30DADADCE1E4E5E3E8E8
E5E9EAE6EAEBE6EAEAE6E8E8E2E3E3E6DCDDCFA2A48D2327A80F16AE070FAB030BAC020C
AB020BAD040CAD030CAC030CA6010AA50109A502089D0206970109940108920104910104
9101049102049001038C00018E01019200019D0104A50107A60108A70109A60007A40104
A201059E020698050B840104880204A90A11B80C15B60610B3040CB0030BAE040AA80208
A100089C01099301078700058601068801068701048402057B010370010079130300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00967053AFACADC9D1DBB3BFC8B0BDC587969B7F8A906D676B3313199F868CD5D2DB
D2D8E267717A0F0B131C050B230203623715D7A43E9149137F0A039C0509A70207AD0305
B4060AB20108B5080F9F050B81080D8C343C934D557B2E32AE3C3BB91817C40C0CCD0B0E
C9080CC20206CD0D0EC9080EC2040AC1070AC3070BC5080EC5060ACB0A0CCD0B0CCF090D
CE0C0EC710139E13173F0B0DC6BDC0E7E4E7E5E3E6E7E5E8E5E5E7E3E3E5ECE6E6DFBCB9
9E3D3AB81C1FC41217C7151AB41B2057070C706061DCDADBE6E4E5E4E4E6E4E5E5E8E7EA
E7E6E6F0E3E6E2AFB1A03539B52024C31216C012189F1C233F080FBAB4B7E2E4E5E7E9EA
E4E5E7EAEBEDE8E9EBE4E4E6E6E6E7E4DCDEDBBABD983E42A41419AC080FAB060DAC030C
AB020BAA020BAC030DA9020BA60109A40108A10107990105940006980108980105950104
9201039101029001039101029300019C0104A50106A90108A90109A60007A50007A40105
A10103A100049F02069303078A0004A0060DB20910B70911B3040CB3050CB0040CA70109
A0010B9C010A9701079001068901058600018601038301047B01037201007A120200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956F4BBBB5B2C7CFD7C3CED8A8B6BE7C8B9097A2A8767376301319AD979DDAD8DF
D4DCE5525B65130C1420060D2504027C4F1DDAA43F8331078B0C04A2070AAC050AB0050A
B5070CB8060CB6050CA90107A41015BB4349BB5458D16464BF3333BD0E11C70B0DCA0A0C
BF0106BF0207C90C11C4060BC10609C0060BC40A0DC5070DC7090BC90809CE0D0CCF0C0D
CE0C0ECA0E13B41A1E4B020597888AE3DDDFE8E3E7E5E3E6E3E3E6E5E5E7E6E3E3E6D0CD
B26864AA2020C01616CB171ABE161B7E1017422325C8C5C5E5E5E3E7E7E7E6E5E7E9E7EA
E7E5E8F0E8ECF7D6D7B66669A62427C01419C11116AF1A2053060B88787BDBDBDDE5E5E7
E5E5E7EBEBEDE8E8EBE4E4E8E3E3E5E1DDDFE0CCCDA55F6198151AAA0911AD070FAE060E
AD040CAB0109AC020BAA020AA70209A50207A40208A3040A9F02089F010A9F01089A0106
9500039000018F00029601029D0003A50207AA0107AA0107A90108A60007A50107A30106
A00004A00105A001069E02099A0108A5030AB1060CB6080EB4060EB5050FAF030CA60009
A2010A9D01099800059401058B01038701038402048301047F02057400017B110300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805A32C4BDBAC3C9D3B9C4CE7F8D94A7B6BA8290946464672F171AB6A2A9DADAE1
D4DEE5454D57150B131E0509250503986C24CB9234771E018A0602A20409AE060DB3050E
B8070FB9050EB6030CB00108AC050BB0151CB52529AC1519B60C10C3080DCA0A0DC8080B
BE0005C00309C3090EBE0409BE0508C1070AC3080BC6060BC80A0CCB0A0CCC0C0ACE0D0C
D00F10CB0D12BC161D67070C62494CD9D2D4E7E4E5E5E3E6E4E4E5E4E4E6E4E3E2EBDEDB
CC99939F2B28B81615C81516C5171A9D191E3906089E9999E1E1DFE6E6E6E8E8E8E7E5E8
E6E4E5EEE8E9F3DEDDE2A6A9A53638BE1A1DC21016B8181E74111851363AD2D0D3E2DFE2
E4E2E6E6E6E9E6E6E9E3E3E8E1E1E5E1DEE1E5D8D8C48F908F1C1FA60B12AD0710AE040D
AE030BAE030BAC020BA9020AA70109A70109A9040BAA040BA8030AA6020BA3000B9F0108
9A0104980103990002A00104A40004A80107AB0209AC0109A90108A70107A50107A30106
A00004A00104A20107A6020AA7030BA90209AD030AB5080EB5070DB4050EAD010BA7020A
A001089C02099701079101068A01048400048100048201057F02067600027B0E02439002
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008E643DB4ABAACED6DFBFC9D2B0BCC38A9A9D828E916763662F181CB8A9B1D8D9E1
D2DBE22F3841120B131B05092B0C02AF8330B47A27690B01900806A6050BB0060DB2030A
B6050DB7030BB9050DB40208B6040ABF0A10BE0A0FBE080CC3080BC8080BCA080ACC0A0D
C40609C5080EBD030ABD0409BE050AC0040AC4070BC50609C80A0CCC0B0DCB0E0BCD0E0D
CC0D0EC80C11BF1216830E13401D1EC9C2C3E8E4E5E6E4E5E6E6E6E3E3E5E4E4E3ECE6E4
DDBDBA9A3F3DAD1618C81419C7141AB1181E57080C655658D8D7D5E4E6E5E5E5E3E4E2E2
E8E6E7EAE7E8ECDFE0F1C9CBB05557B91F21BE0F14B812198D161C380C10B4AFB0E2DFE0
E1E0E2E3E3E5E1E1E3DEDFE0E0DEE2DFDCDFE5DDDED4AFAF922F32A61016AC060EAE030C
B1030DAF040CAC020BAA030BA70209A6020AA7030CA6020AA60209A5010AA5000BA60109
A50107A50106A60206A50004A70106A70007A80108AA0108A80106A60106A50106A20105
9F0003A00103A40007A70108A60107A70106AC0209B50811B70A11B2040DAC010CA5010B
9C00099800079200068D01058700038201047D00047F01057C0104750101790B01418D01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00855A31B8B0AFCBD3DCCAD4DDB1BDC67081868D999E79767B321A23C0B4BCCDD2DB
C7D2DB1C242E110A101F0708371500C3943D99591D6B08018F0709A8060DB1070DB5060D
B6040AB90509B90509B80308BA0308C4070DC80B0DC50809C40907C7070ACA090BCA090D
C5090CBC0308B80206BA0409BD050ABF060BC3090CC00409C10408CA0A0ECA0C0CCA0D0D
C90C0DC2070CBF0B10A1141A3C0307AEA4A5E2DEDFE5E5E5E5E5E5E4E5E7E5E6E6E7E4E5
E5D3D1AF6967A92022C5161CC71318BE181E7C11183C1C21BFBCBDE2E3E1E2E2E0E3E2E0
E7E7E7E8E7E8EDE5E7F4D8DBC57E80AA2224C21617BE1114A51A1F4403078B8183DCDBDB
E2E2E2E2E2E3E1E1E3DFDEE0E0DFE1DEDEE0E1DDDEDBC1C29D4C50A0141DAE0913B0050E
B2060EAC0109AC030BAA020BA70209A7030BA6020BA60109A7010BA7010DA9000BAF010A
B3030BB10409AD0207A90006A90105A90108AA0107AA0107A90107A60106A50105A20104
A00004A00105A30108A50109A50105A60004AE040BB3070FB3050EB0030DAC020DA4000B
9D01099801089200068D01068801078100057C00037C00057A0105720002750A02428F03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF007A4B23BEB3B1C3C9D3C7D2DA7E8D959DACB2838E94625E61301922C7BAC5C8CED7
B7C2C8151B22160A0E2206054F280BD19F46803A0D750A038C04079C030AA8050AB1070E
BA080DBC080BBE080ABD0409BC0308C6080CC90B0DC30809C20708C8080CC6070AC1040B
BA0308B50208B60409B50309B9050BBC050BBE060BBD050BBF050BC1070CC5090CC3080B
C40A0CC0070CC10810B2141B570709796769D7D7D4E5E5E5E4E4E4E3E3E5E5E4E6E6E2E5
ECDFE0CB9998A32E2CC21B1CC81517C315199B192039030A8F878ADCDADCDFDDDEE0DFDF
E3E4E3E4E5E7E7E5E4F4E4E5D8A7A8A12B2EBE1819C01113B3181D610A0F584548D1D2D3
E0E2E1E1E2E2DFDFE1DFDFE1E0E0E1DEDEDDE1DFE0DECDCFA5686D92171EAA0A12B20810
B2060EAD030BAD040CAE050CAA040BA6020BA6020CAB050FA7010CAC010DB2020DB7020B
B9040AB8040BB3020BAD0109AA0108AA0108AA0107AC0309A90108A60006A40106A20006
9F01059E0004A10106A50108A50106A50106AA0108B2050EB80A13B0030DAA020CA4020A
9B01069700069300068D01068801088001067D01067C01067C0306740103730801438F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956A42AFA49FCDD3DBBFCCD3AAB9BF92A0A57B84885A5555341C23CEC3CCCED4DD
A5B2BA0F131D18090F2205046E471ECD9A437025047A08058E03089300059C0105A60107
B5070EBA060DC0090DBE050AC1070AC90C0ECA0C0DC90B0EC40709C7070CC5070CBC030A
B6020BB1020BB0030AAE010AB2060DB9060FB7020BB8030BBB050DBE060CBF070AC2090D
BF070AC40A0DC50D12BC141B790C1346292AC5C3C1E3E1E2E2E0E1E5E3E6E2E2E6E5E3E7
EAE3E3E1C1BFAA4B49C02322CA1618C9161AB0181E5A09125F4E54D5D2D5E3DEE0DFDEDF
E0E1E1E0E4E5E1E3E3EAE3E2E9CACAA54549B41A1FC01217BB161D7F11173A181BC0BEC1
E0E1E1DFE1E1DDDEE0DEDEE0DFDFE0DDDDDEE0DFE0E3D9DAC4979B8C2126A90E14B20810
B0060EAC020CAD050DAC040BA9030AA3020BA3040EA6010CAC020BB4060EBA040EBB030C
BD050DBC040DB8030DB3010CAD0109AB0209AA0107AA0107A80007A70108A60209A4020A
A10107A00106A10207A00107A00109A40108A80108B1060FB20810AB030AA60108A00006
9C00069800069301068D01058601078201077D0107780104780102750202740700418D02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF009B7048A79B95D1D7DFC3D2D9B6C7CE75858C8A92976D6869372228D2C9D0CDD4DE
8F9AA611101C18080C2106028B6529B48538530901800B0D93040B9C030CA3040BA90108
B4040CBA050EBF080EBD0409C1070AC80B0DC90B0BC9080BC6080AC50608C3080CBA050A
B5020BAE010AA702099F0108A00308AE060FB5040FB9040FB9040DBD050DBF080DBD060B
BF080DC0080DC20A0EBD0F16921016330506A5A09EDDDDDDE2E2E1E1E0E2E2E2E3E5E3E5
E6E4E2E8D4D3C07A7AB22627C7191BC51014BA171C7A0F1838191FBCB8BCE1DFE2E1E0E2
E1E1E3E0E1E4DFE0E1E5DFDFECD8D9B56D71A51D23BC1119BF141B9C181F3B0307A59C9F
DEDDDFDFDFE1DFDFE1DCDDDFDEDEDFDFDEDFDDDBDDE3DCDDD1B0B294373CA71318B2090F
B1070CAE050BAF050EAC020BA8040B970004950106A5040CB2070FB8070EBA040CBB030C
B90209B90209B9030BB4020CB1030BAB0006A70105A70105A80107A60108A50107A30007
A10106A00105A001079801069201089A0109AB050DB1060FAD040CA70107A60108A00107
9B00069901079502078B01058301067D0106780105740002740101740101750700418E03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805328C9BBB4C6CCD4CAD7DF80929A95A5AC818A91534C513B242BD4CBD2D3D9E3
767E8A130B1919050C1F0501A37B37905E245707057D0509900007A3040BAB0309B3040E
B7050DBA050CBD060BBC0309C0080AC7090DC9080BCB090CC8080AC6080DBB0509B20207
B0030AAB020A9D00048F00028B00019C0107B0060CB5040BB8030BBC050DBC070DBB060B
BD080DC20D12C00B10BE0C14A7141A4704067F7576D4D7D6E1E3E2E0E2E1E1E0E1E2E0E1
E2E1DFECDFE0D0A1A2A23032BC1B1CC51719BD181A951A1E3B070C978F91DCDBDDDEDDE1
DFDFE1DFE0E2DEDFE1E2DFE1EFE1E3C49193972429B11119BB0F17AE192254050A6E5D60
D6D6D9E0DFE1DFDFE0DDDDDEDDDDDEE0DFE0DCDCDDE0DDDDD8C3C2A3595A9C1419B00B10
B2080DAF050BB0050EB0040EAE050DA3040A9B0206A8050AB60610BA050DBA030BB9030B
B90308B90509B70208B5030AB20409A80004A20004A00004A60208A40006A20006A20107
9E01059E00049F01059802068900038C0003A9090FAE050DAC030BA80208A501069E0006
9900069401059101058901047F0004770104760205740103730101740202760A02418F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00825021B5A59DD0D6DEC2CED7ABBAC392A1A97F878E51464D462F37DAD2D9D2D8E3
5F6571180C1820080D2A0C00B28841743C1A63080587050D9C050DA8030BAF030BB4040E
B6050DB8050AB90409BA0308BD0508C7090DCB0A0DCA070BC6080ABE0409B20207A70004
AB020AAA010BA40208A003099E0408A20206B3080BB40408B40309B6040CBA070FB8060C
BA070CBD080FBE0912BB0913B01119660A0D493234CACBCBE2E4E3DEE1E2E1E2E2E3E2E2
E4E4E2E6E1E2D8BEBEA55756AA2D28B62D25B12F289B342E5E2B2780706ED5CFCDE3E0E1
E2E2E2E0E1E0E0E2E1E1E0E3EAE2E4D5B1B2973538AC141DB90D16B5131E710D15402729
C5C6C9DFDFE1DFDEE0DFDFE0DFDFE0DEDEDEDEDFDFDEDEDEE0D3D4BA838591191DAF0D13
B50910B3070DB1050AB00207B7060CB90910B1060BB00308BA070CBC050CBD050DBB0409
BB0409B90408B50207B20306AD0205A501049F01049C0003A10207A10005A10107A20207
A100059F0004A001059E02069A050A920107A5070FAA040BB00710AA030CA602099E0107
9600049301058F01058700047F01047500027201027100036F00036F02027B150C46960C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00814B1AA08D83D2D5DDC3CED9BCCAD676868E838C936C6369533F49DCD6DED0DAE5
424A56170B13230706472108BF90465C1F0967050591060FA7060FAF050DB3040DB7060C
B60509BA0609BB070ABC060BC0080AC8090DCC0A10CC0A0FC3080CB70309AE020AA70007
AB0209AD020BAD030BB0040CB3080DAF0407B7080AB80509B6060CB3040DB5060EB8070E
B8070DBB080DBE0B13BB0914B40E158B141832090CB4AFB2DFE1E1E0E1E3E1E3E2E1E1E1
E1E2E1DFDEDEDFD4D3C49F9BC58B80DA988CD99E91D2A296C7ABA2C8B9B5D1C9C5E5E0DF
E3E2E0DFDFDFE1E2E4E0E0E2E5E1E3E4C8C9994347AA1820BA0E16BA131A8A151A310A0B
B4B4B4DCDDDDDFDDE0E1DFE2E0DFE1DDDDE0DDDDDFDEDEE0E5DCDFCDA3A7922930AF1118
B70911B9080EB9080BBA060ABD070CC0090EBE080EBB050CBD060BBC040ABD040CBD040A
BA0208B9030AB60409B30409B1050BA90208A201059B0001A10206A10006A30107A60108
A50208A20005A10106A00006A2040B9F010AA8050EAE050CB0050EAC040EA6020C9E0007
9800059201068D02078601057E00047701047402056F01046A010369010273140D44980F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00834F1ECBB8ADC4C9D0CCD8E28898A18F9EA5899297544B525D4A53DAD6DECBD7E0
2E3741180C132107056A4421BC8B4454110070050790020AA8060DB0030CB3040AB8070C
BA070ABD0709BD0809BE070BC2070AC8070FCA0910C8090EBF070BB40209AE010AAB0209
A90007AD020AAF040BAD0208B20509B20407B6070AB60609B3040AB3030DB1030CB4030B
B8070DB7060CBA0B11B80812B50912A5171E4B020778636ACFCDCFE2E1E2E0E1E1E1E1E2
DFE1E0E0DFE0E3E0DFE7DEDBE9DDD6EEDED9EADFD8E9DED9E7DFDBE6DFDEE3DFDDE2E0DF
E0E0DEDEE0DFDDDFDEDEDEE0E2DDE0E5C7CBA0484FAD171FBF0F16BB0E149B1419380002
888284D7D8D9DEDCDFE1DFE4E0DFE4E0DFE4DEDDE2DDDDE0E1DCDFD7B7BC9E444CAA131C
B7080FBF090EC50D10C2090EC3090FC0090EBB050DB8050DB9050EB7040CB9030DBB040D
BC040DB7020BB5030BB2030BB1040DAB0109A501079D0003A10106A40007A50107A70106
A90108A70108A50106A40007A30109A6010AAB040CAD0309B0050CAB020CA6010C9F0109
9901079201088801077F02067A01057501037301046D01046800036401026B110C4D520C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B5323B8A49CC9CFD6C3D1D9A4B3BA9AA9B07E868B41353D6B5962D9D7E1C0CAD5
1A222D180C132007068E68309D692F5E0A017C040798060FA9080FB1040DB5050CBA060C
BC060ABF070AC0090BC1080CC1060AC6080FC3060DC50A10BA0409AF0006AC0109AD020A
AE030BAF020AAC0208AB0106B10408B10207B4050AB2050AB0020BB3030EB3030DB8060E
B7060CB5040CB80910B70711B60910B01017820E174B161FAE9AA3E0D9DEE2E0E3E1E0E3
E2E0E1E4DFE2E4E0E2E4E1E1E6E2E1E4E1E2E2DFE1E4DDE0E6DEE0E5DCDFE2DBDEE2DADE
E0D9DAE0D7DBDDD4D8E0D3DADFC9D0D89FA9982630B1111BBE0D13BC0911AA101955050A
5A4B4DCFD0D2E1E1E3E1E1E4E3E2E7DFDFE2DEDDE0DEDDDFE1DEE0E2CCD1B86F77A2161F
BB0A10CA1114C90D10C6090FC2080FBF090FAE0309A40207AA040CB3060FB2020CB5030D
B6030EB4020CB5030DB2030DAD020AA90108A502079F0104A30207A50107A60007A90207
AC0309B1050BAD0209A70007A50107A70208AD050CAD040BAD040BA8010AA6010AA00109
9901069001088100057601057600087601077101066A00046701026300016A0F0D5B0F0D
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00905323AD958ECFD4DBBCCCD3C0D2D974858D6A7379493F46786972DAD8E3B3BBC7
13182214070E1F0602AB8243743C1971120888060A9A040CA50209B1060EB4040CB9050B
C0090EBF060CC0080BC1090BC0090BBE060BBA0209BC080FB3040BAD0109AD020AAE030C
AC0109AD0208AB0205AD0208AE0107B00209B2050BB2050BB2050CB2020CB3040CB6050D
B6050CB7070FB5060DB80A12B5080EB60C13AB131A7E0D186C232FB1838FDBC1C7DECAD1
DECACFD6BFC8E0C7D1D9BCC7CEAFB8CAA7B0C9A1ACC89CA8CF9FABCA96A1C68F99C38793
BC808BC0808BBD7987B97080B76271A63540AB1721B60C13B9080FBD0A0FB40F15710B10
3A2122C6C8CAE3E4E6E3E2E5E0DFE4DFDFE3DFE1E4DFDFE1DFDEDFE4D8DACE9A9D9D2125
C11416CA0E12C6090EC6080FC3070EBE080FAF050C9D0106A00006AB020AB0040CAF010A
AD0009AE010AAC0109AB0109A90109A70107A40207A00005A40107A60107A50107A60005
AC0208B4060DB2060BA70104A60105A80208AA020AAB010AAA030BA80209A50108A10107
9901049303088302067600067801097300066E01066B01036501015F00016309095F100F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00874B1AB2978EC4C6CDCBD7E08FA1A8768A8E7884883B373C837680DBDAE599A1AD
0E101B1304092D1001B78B4A5B220A60060285030A9E050DA60309B0050BB4040CB7030C
BB060CBE070CC1080CC1080BBF0709BC060AB60308B4050AAB0108A90007AC0209AC010A
AB0208AB0307AA0407AA0208B0050BAC0109AF040AB2050BB4050BB3030DB3030DB6050E
B6070EB6070EB3050AB70A0EB70A0EBA0E12B70E14B0111AA21621931F2DB65864BD6775
B45F6CAB5160AB4E5CA84556A03A489E3140A330429F2A3AA02836A22735A62534A7212F
A81F2DA71D2AA71D2AA91B2BAF1A27B3141CB80F15BD0F12C00D11C51114BF12168F1217
310508AFB0B3E5E8EBE2E3E5DFDFE2E1E2E6DFE0E4DEDFE3DBDDDDE4DFDFD4AEB09F3537
BD181BC50E12C20A0DC2080CC0080DBA040BB3030CAB030BA70209A80108A90108AA0108
AA0108A80007A60006A60007A40006A50107A30107A10107A50109A60109A60108A70107
AB0208B5070DB4060CAD0106AB0207AB0209AC030BAD050CA90309A60108A70208A20106
9A01069201078901087F00077F02087802067001046D010467010260010261080664130F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00894A178E6C62CFCDD4CAD6DE9CAEB493A6A6828B8A292324978B92DBDCE67E8691
100D19170407492913B78A4B4D12015D010287060E9E030EAA050AB0040AB4040AB6050D
BB060DBD060BC1080DC1080BBC0406BC060AB8070AB20409AB0109A70107A70108A80108
A90209A80208A70208A70309AA0308B0040AAE010AB3040EB3030DB2040DB2040DB4040F
B60610B80811B4070EB5090FB70A0EBC0D14BB0C13BC0D14BD131AB5111BAE131EAC1623
AC1723B11926B21722B51823B3141EB2101BBC1823B91722B7131DBA131EBC121DBC121E
BB111BBA121BB61218B81019B70E16BB0F14C01315C11213C71417C91115C81518A6171B
4102058C878BD8DCE0E5E6EADFE0E4E2E3E7E3E4E8E2E3E5DCDDDFE3E0E1E5CDCDB15E60
AE191DBD0D0FC00C0EBD070ABF0A0EB7030AB20108AE010AAB0109A90006A70004A80005
A80007A70007A60107A50107A40107A10006A20107A30107A60209A70108A60108A70108
AA0209B1030CB4060DAF030AB0050CAE030AAE030BAC030AA80208A80309A60207A10106
9A01059200078B01088601078001067900047201036B00026800036201026103025F0A06
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4816886256D8D1D7BEC9D0C0D1D87E8E92767B7D2C2024A79AA1DADCE5626975
120B141B04046845259A69364D060174050C8F030DA0020DA80209B1050DB3040BB7060E
BC070EBF070DC0090CC0080ABB0405C00B0DB40407AE0107AC030AA90108A60104A50006
A70208A60208A001069F0004A60208AF0309B1020CB5040DB3030DB2040DB0020BB4030E
B4040EB80611B70711B4050DB60A10B5090FB70A13BD0D16BD0F15B80C13B80F15B20C14
B71217B61116B81317BB1418BA1316BB1218BD1318BB1319BA1318B91117BD1519BC1317
BC1517BB171BB61719B8181AB61415B81515BA1615BC1415C11517CA191BC61717B11D1C
5E0C0E5F4E51CED0D3E0E2E4E4E6E8E5E8EAE4E5E8E3E3E6E0E0E3E1DEE1E7D9DBC48589
A42123BB1010C10E0FBC090BBB080EB4040BB1030CAC0109AC020AA90107A60103A80104
A80007A70007A40004A40105A40207A00006A00005A30106A70208A60107A40007A50008
AB030AB1050EB1040BB0040BAD020AB0030CB1040DAB0108A80007A80108A70209A10108
9B01079400058E01068701067F00037701037001026B02026601026202016001015C0502
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F4A18A27A70C6BFC6CCD6DE96A8AF7E8D9384848B2C1D25BAADB6D8DBE5444A56
180C15200404916B3B784322620C0485080E9A040DA6030CA90109AE0209B3040BB8060D
B9050CBD050EBF060BBD050ABC070BB60409AC0106A80107A90209AA0108A80206A90209
A80309A70208A40107A30108A70209AF030BB4040BB4040AB20309B3040DB2040DB4040E
B60610B70510B80711B5070FB1080DB0090DB30D10B71212B71112B61213B61514B41513
B11712B01714AE1914B5211CAF1D19AE201CAD211DAE2320AB261FA6251FA82A21A92B25
A82E28A32D27A23029A33029A4312AA6312DAB3631AC3730AE342EB53531B83733AC3B36
732D294B3633C3C2BFDFE1E0E1E4E3E5E6E6DFE0E2DFDFE3E2E0E5E0DEE3E2DADECFA5A8
942829B31615B80E0DB90E0EB2070AB0040BAE040CA90108AA0209A80107A50004A80106
A80007A60007A50106A40105A20106A20107A40007A50108A50107A30006A30009A6010A
AA0209B0050BB4070DB2040CAF0209B1030CAE030BAA0108AA0209AA010AA9030BA4010A
9D01099401078A01078402067F01047C01037401036A01016100005F01015E02016C1813
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00934E188E655CCCC7CFCDD9E28D9EA58B989F82818A2E2028C2B8C2D2D5DF2C303C
190B12270902A87E475C230D5F070184060B9D060EA7040DAA040BAE050EB40810BA0811
BD0810BC050DBF070DB80209B6050CAF020AA70007A30005A60006AB0209A80106A90209
A90209AC0107AD0108AE020AAC0209AC020AAD050BAE0407B2060AB3060CB3060CB5050F
B3040DB70810B4080EB10C10AC110FA81610A51A12A41D13A22116A3261AA62E23A9372B
A63E30A44538A74F42B9655BB7675CBF736AC87F76CC867CCE8E84D4998FD79E92DAA59A
DFAEA2D2A69BD9AEA2D9ACA3DFB3ABE4B8B2E8BCB5E7BBB4E9BAB3E9B7B2F1BEB9ECBFB9
DABDB6CABFB8D9D7D3DDDCDCE0E1E1E1E2E2E1E2E3E0E0E3E0E0E3E0E0E2E3E0E2D9C1C1
975451992B27A1211BA11A15A117139F100FA00A0CA20409A30107A60107A70107A80109
A80108A60007A50106A40008A5010AA5000AA50009A40008A40106A40107A6020AA50108
A80308AF0609B30509B3040AB2040AAE020AAA020AA90109AB010BAC030EA8010EA4010C
9E010A9300088001057701027C01057C01047600026D01026300015E01015B02027E2E29
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00944D17895C50D1C9D2C1CED6BCCBD36C7A8168666E30202ACDC5CFC3C9D2191F27
17090A381707B185514B10005B03027E030899040DA3060EA1060B9C0207A20408AE070D
B7090FBC070DBD0810B2020BAD0109AC010AA80209A50106A70108AA0009A80108A9020A
A90006AD0107AF0207B1020BAC030AA601089B0103A00105AF070DB0030CB3060CB60610
B2040DB40A10A10A0E88100FA23F35AE5648B56858C47F71CC9080D59F90DDAB9DE5B7AC
EAC4B8E8CABDE9D1C6EDD6CEECD8D1EBD9D3ECD9D6ECDBD7ECDCD8EBDEDAEBE0DAE7DFD9
E3DFD8E4DEDAE5DFDBE4DEDBE5E0DDE4DFDEE5DFDFE8E1E1E6E0DFE4DFDEE6E1E0E7E2DF
E1E0DCEAEAE6E6E6E6DEDEE0E5E6E8E3E4E5E1E2E3DFDEE2E0DFE3E0E0E2E3E2E4DAD3D3
D3BCB6C99F97D09891C0817AAE6961A1544C9B3E3A9018179A0509A50108A50007A60007
A80108A70107A40005A50108A50009A50009A6010BA40008A70308A60107A50109A40109
A60308AC0509B20409B5060CB3050CB00309AF040BAD020BAC020BAB020DA8010DA4020B
9D010994010A8102057100017701057A01067601037001036701026002015A03027D302B
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00954D1883534ABDB2BCCDD7E0A1B0B86F7E836B6C71332730D4CED7AFB7C110161D
18080654301C98683B4806006305067F020898040D99030B9100068E00078E0005990005
AA040BB8060CB9070FAB0109A50009A9020CA8030AA70107AC030AAB0209A9020AA80108
AB0207B1040AAF0207B1020CAD040BA8030B9C01069E0006AE070EB1040DB4070DB4040E
B3050EB10911920B0F450201AE8B82E4C8BEECD7CEEBDAD5E7DDD3E6DCD3E6DDD7E5DBD9
E4DCDAE3DDDBE1DDDBE3DFDEE3DFDFE4DFE0E2DDDEE2DBDDE5DFDFE5E3E2E0E1E0DEE1E1
E0E3E3E2E1E5E0E0E2E0E1E2E1E3E2E0E2E4E2E3E6E0E1E4E1E2E5E0E1E3E0E1E3E0E3E3
E1E5E5E3E6E6E5E6E9E2E2E5E4E4E6E2E3E3E1E1E3E2E0E4E0DFE4DFE0E4DFE0E3DCDBDC
E4E0E0E1DADAE4DADAE2D6D6E1D2D1DECBC8DAB8B5A55C5C890A0E9E0108A60109A70108
A70007A60107A60107A40107A30108A50108A50009A50109A40208A50108A3020AA0010A
A4020BA70108B1050EB2040DB0040CAF030AB0030CAF040DAD030CAE060FA8020BA5010A
9E01099201088601087A01037801037C02067600046E01036500025F0101570100792A24
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0099511C78473DB2A7B0CFD6E0A1AFB78C9CA06E70743E373ED7D3DC9099A20B0F16
1706047650317746274D0A015E020483040D9A050F98020B9101088F01098F00059B0108
AB030BB6060DB5060DA70008A10008A50107A60108AA0208AD0208AB0109A70107A80108
AC0308AF020AB0010BB2030CAC0208AD030AAC040BAB020AB3060FB4040EB3050EB4060C
B5060DB50811A11117430103786767D3CBCBE4DFDFE2DFE0E1E0DEDFDEDCE2DEDDDEDCDE
E0DEE0E1DFE1E0DFE1E2E0E3E1DEE2E4DDE3E1DBE0E0D8DFE3DADFE0DAE0DCD9DDDAD5DB
D9D4DADCD3DBDED7DCDCD6DBDFDADDDCD6DADAD2D8DCD3DADDD5DCDBD4DADCD5DBDED8DD
DDD9DEDBD7DCE0DAE1DFDBE0E0DDE0E2DEE2E4DEE5E6E0E7E3DFE3E2E1E5E1E0E5DCDCE0
DFE0E4DFDFE3DCDCE1DCDBE0DAD7DCD9D4D8DDD0D2AB7A7C7E10159C030AA60109A70209
A60108A50006A50106A40107A30108A2010AA3010AA40109A40008A400099F010B980009
9D020AA40109AD030CB0050EAC020AAD010AB2040EB0050FAF050FAB040CA70209A40107
9C01069000068801088201067D01047B01057501036C01026301015E01025801016E1E17
2F880200FF0000FF0000FF0000FF0000FF00
00FF00954A165B291EB3A6ADB3BBC4BAC7D08B989F4E4F54494349D8D8E06A737D0B0A14
1B0705936B454F1F0C4807015B000180020B98040D9701089200069400089C020AAB040E
B5070FB90710B3050BA80107A50107AB020BA70107AA0107AF0309AC0209A90108AA0108
A80108AB0109AB0106B0040AAA0108AE030BB0030AB4050CB3050BB3040BB2050BB40710
B4060CB7060FB2121967070D503436C9BFC2E8E2E4E6E0E4DFDADDD9D1D5D9CDD2D3C6CC
CDBFC4D0C0C5C4B0B7C3ABB5C7ABB2C4A2ABC19FA9C29AA7C89DAAC799A7C0929EBF8C9C
C18C9BC78E9CD599A8D699A7D697A4CE8C9AD593A0D5909FD995A5D592A2D695A6D092A1
D69BAAD09AA8D39EADD1A1AED5AAB5DDB4C0D8B3BFD4B2BCD1B2BBD6BDC6D2BDC6CEBFC7
D0C4CDD4CBD3D3CED5D8D3DADCD5DCDBD4DCDCD2D8B591947E1E239A060EA60109A8020A
A8010CA60008A40006A40107A40007A3020AA3000AA3010BA3010CA4010CA3030D980109
980009A1010AA60108AD050CAE040CB2050EB2060EAF060CAD050CA9030AA7030AA30108
9A00068F00058801078301067D00057A01077400056C01026201015D01015701016F2019
2E870100FF0000FF0000FF0000FF0000FF00
00FF00924A185C2B23AC9DA2ADB5BC929FA8808B914F4D525F575FD5D6DF3C455007050D
1F0B019B724A400F014B030169020686010A99040C9C01099B0109A1010AAB060EB00610
AF0810B20912AD060BAB040BA90209AC020BAC0209AC0109B0010BAC0109AC020AAC020A
AC0208AC0109AD0208AE040AAE0509AF020AB3040BB3040BB3040AB3040DB3050EB4060F
B5060DB80711B40A14900A13520B0FD9AFB5E6C4CAE0BBC4D1A5B0C68F9DC28490BE7A85
B56A77AA5A69A34F5B9E4351A03E4B9F39459B343F9F31419B293A9B25379C24359E2133
A12133A51F30AC2233B22233B72433B61F2EBC2432B82130B92233B71F32B82134B21F31
B22233AF2332AF2638AC2A3AAE323FB23B49B54152BD4B5EC25465C55D6FCA6C7EC47183
C3798AC88495C18897BA8B98BA909DBA97A2BEA2AAB48A8F8F343996070EA6020AA7020A
A6000AA60009A50107A30006A50108A40109A2010AA2000CA1000DA3010CA3010B9F0109
A0030BA00008A40007A9020AAF050DB2040DB3070EB1070AAD050BA60108A6020AA2020B
9B02099100068901078001057B00047800057401036D01036501025D00015701006C1D13
31890200FF0000FF0000FF0000FF0000FF00
00FF00944C1A4D1B11A09295A5ACB06A767B838B91605D636E666ECFD1D9252C35050205
351F137F59373B05005903077D040C90030B9C030CA1010DA5020CAC040FAE050EA4030F
940107970309A10409A70308A90209AA0108B0030CB1010AB20309B00208AE0106B0020B
B2040AB00108AE0108AD0107AD0107B1040AB1040AB3030DB2020DB2010DB4060FB4040E
B5060DB60711B60811AF0D1699111AB84752B64A55AC3A49A42838A62132A51B29A81928
A61322A5101FA50F1CAA111BA90E17AE121CAF141DB1131CB1111AB2111BB5121EB40D1A
B70E19C2111CC9121CD0141FD3151DD31319D6151AD4131AD3131DD2121CD3131CD0111B
D0111BD2141ECB111BC60F19C20F18C2101BC41121C41122C91724C11221BA1425B11324
AE1526AE1B2CA61C2F9E20309927369C35459F414FAD515DAB343F99030DA6020AA60108
A50108A40007A30006A30106A30107A30109A2010AA3010CA3010BA4010AA40009A30009
A20109A20108A00005A50107AC020BB2050FB3060EB1060DAD050CA70109A301099E0109
9A01089201078900058000047A01047801047401036D02036301015B01005601006E1E14
31890200FF0000FF0000FF0000FF0000FF00
00FF00964E1B4D1611A492988A8F968F999D7A82853532397B777DC1C4CB14181F0C0102
593D286A432B3D020164030886050B95010A9F030EA5020DA7010CAE040DA9050E95010A
85000584000498050DA5020BA50007A80107AF0309B2020AB50309B30308B20208B5020B
B4020AB70309B60208B3020AB00106B20408B00509B1040AB3030DB3010DB4040EB4030D
B5050DB60610B60610B50710B40A14B8111BB9131DBB111DBD0F1BBF0E18BF0F17BF0D19
BB0A16B80813BD0E16BA0D13B80B13B70A13B70C14B91217B71115B71014BA0E14BF0C15
C40D14CD1017D21118D20E15D50F14DA1315DA1113DB1318D40D14D60F15D70F13D50E13
D30E14D00B12CF0C14CC0B13C90B12C60812C80914C80A13CE0E15CA0A11C50911C40913
C10712C10B15BB0714B50715AF0915A80915A006159D09179D0511A3020CA70209A60008
A40006A20005A50108A40107A20105A00005A00007A4020AA30109A20109A30109A4000A
A4020BA10007A00105A20004A70007AE040DB2040FB2060FAA020AA9030BA5020A9C0106
9601059101068A00058001037900027501027200016B01026001015A0100570100701D15
31890200FF0000FF0000FF0000FF0000FF00
00FF00974E184F170F927C828F9097727B7F5D65672221268F8B92AFB2BA0C0B11170403
805B3D471A104904046B020786000798030C9E010CA4010DA7020CAB040EA3050B8C0006
7E000380000591020B9F010CA20108A80207AB0004B20207B50208B40109B50309B7030C
B7020AB70208B70207B60209B10107B2040CB1040AB3040BB4050CB6050FB5030CB8040F
B8050EB90711B7070EB8050EB90810BA0A12BA0911BB0712BD0913C00B14BF0B13BE0A13
C00D18BC0811C20D15C00C15BF0E16C00E16BA0B13B70C13B70D12B60B0EBF0E12C91115
CB1113D21118D41217D40F13D71113DE1718DD1416DB1217D50E15D30C12D71014D60F13
D50F15CE0B12CC0913CA0811CE0C15C90913C70610CB0911CA0810C6040DC80811C50811
C2060FC3080FBE060EBA060FB1010AAF040BAA030CA9030BA6020AA7010AA70108A60107
A30007A40107A50108A50108A30108A10007A10108A3020AA10109A0010AA2010BA2000B
A20109A00107A00005A20006A70209AB010BB0040EB2070FA9010AA7020BA200099C0005
9801059001068A01078001057801027401017201026C02036301025C0100590101711D17
388F0800FF0000FF0000FF0000FF0000FF00
00FF00964E19481108947D8295999D596464535C5C26232899929B92929C0B070D1D0602
8F66463C0A0254060A73040C8A040A97030B9C0109A3010BA9020CA9040F9B040B860106
7E00068300088F030B99010A9E0108A50107AA0107B1020BB3020AB7020BB70209B8030A
B70408B60309B6040AB40409B2030AB2020CB3040BB20109B20208B5020DBA060FBC0510
BB060FBE0710BB070EBB070EBD0910B8050DB90710B90510B8070FBA0912BA0A11BB0C11
B70910BC0A14BF0B14BD0914BE0D15BF0B15BD0C14BB0B15B6080FBF0F12C71113CE1214
D11013D31017D41116D60F14D71113DB1415DE1718DB1317DA1217D70F15D60E13D20B0D
CF080DCD0810C8060ECC0813CC0915C80611CC0812CD0911CA0810C6040DC70711C40711
C1080EC2090EBE060CBA060EB4040CB0040CA80107A60107A80209A90109A90109A50108
A50007A50108A50107A50107A10007A00109A00007A001079E00079F0009A3010BA30109
A20106A00007A00008A10008A40109A9020AB0050EB40811AB020BA60109A201099D0107
9600068D00068700077F01067600037301017101016E02036702035F00015B020168120D
3A910A00FF0000FF0000FF0000FF0000FF00
00FF0067720E4610059881837375796A747562686A141115A29BA2636369070207260F09
82573E3401004D00046C010788020A9401099E040CA5030EA6010AA7030F920107800004
7F010883010A8A0109A3101AAD151D9D0007A8020AAE010AB2030DB3020BB50209B70209
B70408B40309AE030AA20207A00207AE020BB7060BB60309B30208B5020CB9050EBE060E
BD050DC1080FC20A0FC40A10C30A10BE050DBE070EC10A12BE0B10BE0D13B90B11B80B13
B2040DBA0A15BD0C14BD0912BE0C14BF0B16BC0914BF0A15C10D13C40D11C70F11CF1116
D21017D20F17D41015D71015DA1315D91214D81114D71014D91116D70F15D91116D71012
D40D0FD40D11D20C13CD0911CC0912CC0912D30E15D00A10CC0910C6070EC1060EBD050E
BB040BBD060CBB060DB6030DB0020BAC030BAA030CA70008A80109A80109A70108A50007
A50007A50106A50107A50108A10109A001099D0108A002099F0107A00208A5010AA50109
A30107A10107A00108A00009A10109A4000AAB020DB10512AB020CA50109A000089C0007
9600088E01088700078001087601046F01026F02026E02036701025F00015A0100610905
388E0800FF0000FF0000FF0000FF0000FF00
00FF0066700E490F07886D6D7472756C7275525757141113A9A3A8434348040102351F19
653D2A3B05034E00066D020A87050C8B010797020BA0020CA7020CA7040D8F0005800004
80010880010A7E010695061099070F950106A5030AAB020AAC0109AE020AB2020CB6040C
B7050CB30309AB03099A0103920000AC040AB9070AB90509B70308B7040AB9050EBB060C
C30B10C90C13C6080FCA0C12C90C13C5080FC50B11C50D12C00D10BC090EB90A0FB7080F
B80911B80712BB0712C00B14C10A14C10A16C10C16C60E18C60E13C90E12CA1013CB0E14
CD0E15D3111AD41016D81317DB1416DA1313D61112DA1417D81015D60E12D60E12D60E10
D81013D70F13D20B11D00B13CC0810CD0911D30E15CD0912CA0810C4060DBD040BBA030C
B9030BB70209B7030BB5030DAD020AA80109A8010BA8020CA60108A60007A70107A60007
A50106A50107A40107A10107A00107A00107A00008A001089E02089D0106A2020AA20109
A100089F00089D010A9D01099E010AA00109A5010AAE050FAA020CA6010AA2020A9B0109
9501098D01088700078101067301036600006901016D01026A01026301015C01015D0501
378B0600FF0000FF0000FF0000FF0000FF00
00FF003995015318107F63628B8788595D5D4244421C1717A5A2A526262A05000150392A
3F1B1337000359030C7A050F88030B84000492020B9F030DA5030CA2040D8F0107840005
8001077C020970000482071085050A880005A1020AAB030BAD030BA90108A60006AA0108
AF0308B5050AB2050CAC030BA60308B3040BBB050BB90308B90409BA060DB50109B50106
C30B0FCE0E13CE0C11D31016CD0C13C6080EC50C11C30C12BD080FBD0912B8050EBD0A12
BC0A11BD0C15BD0914C00912BF0810C40B16C70F17C70E15CC1216CD1114CC1011CC1215
CB0E12CE0D15D11116D41215D31012D91516D71213DB1618D91415D81113DB1416D91013
DA0F13D81013D50D11D30D14CC0810CD0B13C8050FC7050FCB0913C3050EBB030CBA030D
B9010AB7020AB8040CB3020BAE020BAB0209AA030BA6000AA7010AA60107A60004A70207
A40107A40008A20108A00005A10006A30107A201079F01099901069701069D02069F0105
A102089D01089B01079B01079B00079E0008A20109AB050DAB050FA6010BA1010B9A010A
9300098E00098800088101067802046B01016B01026D01016B01016602015E00015B0200
33870200FF0000FF0000FF0000FF0000FF00
00FF003B9701430A038163636B66675A5B5C6362612D2727A8A7A91212140600005E4433
2706013901055E010A8003108C030C8C000895020B9C010AA0020A9C020A8F0107870006
8501067D0106670103620104690001830105A2030BAC020BAA0308A10004A00004A40005
AC0207B5050BB30209B30109B5040ABA050CBE050DC0070DBE060BBF0810BA040BBE070C
CA0C11D10E12D51114D50F14D51118CB0B12C3090FBF0910BD0910C00D12BC090EC00C12
BC0B0FB90B0FBB0B10C20B12C70F15C80F15C71015C81115C81113CB1215C91014C81215
C51413C71517C71517C71416CA1616CE1816D21B18D41B19CF1513D01512D71919DA1719
DC1317DB1014D90E13D40B11CD060FCC0811C90712C6040FC80712C2050FBB020BBB020B
BB030BB7010AB5020DB2020CAF030CAD020AA90108A70108A60108A60308A50207A40107
A40108A20108A10107A00006A10106A10107A101099D01089401059200039700049B0004
A001099F01089E01079C01069C00069E0108A1010AA7030CAC0710A6010A9E0209900107
8C02098D020A8801088101057A01037202026E01026F01026D01016801016101025B0100
65100300FF0000FF0000FF0000FF0000FF00
00FF00399500460A027251536E68696A6A6C4544443E383A9B9B9D0708090B0401533D2E
1C01003A01065F030A7F010E8D010C92000A9B040D9D020A9A000997020A9101098E0108
8D01088A020A7A060E9F3B4295282C93060DA4020AAB020AAC0408A70104AA0306AC0308
AD0306B5060CB60409B8040BBB040BBC0309BE050DC0060DC0070DBE040DC0060CCB0D13
D00D13D41013D00E0FD20E12D41014D00E14C90E14BF0810C10F14C11214BD1111BB1212
B71412B71613B81614C11617C31415C51215C81316C70F13C91113CA1217C1121AAC161B
AF2C27B23631B13835B43B38B63D39B9413BBE443EC54842BF3F3ABE3D3AC33C3AC52A2A
CD161CD10B11D60D12DA0E16D30B15CF0913CD0912CB0811CA0710C60610BF040CBE050C
BD040CB8010BB3010CB1020CAD020AAD030CA9010AA70108A50007A40109A20008A40007
A50108A30107A00106A00007A00108A1010AA1010B9C00099902089401049601059B0106
A0020BA1010B9E01079D01079C00089C00099F020B9D0109A1040DA1030D970209820004
7D00048301098001067D02067A01047400027200037100026F01026901016302025A0100
64100400FF0000FF0000FF0000FF0000FF00
00FF003A95004A0B04714F51877F7F5E5C5C3835324D45477C7B7E0201021C130E432F25
1800003601045D02087F030E8E020D93010B99020B9C010C96010A93000B92010B92010B
93010B93020C950F1AB73B46A31D269F040BA60208AC020AB10409B20308B20308AF0208
B00209B30309B70409BA040CBA020ABC040CBE070CBE050DBE050BC4070EC70810D00C12
D20E13D41014C8070CCE0B11D00E11CE1113C41013B81015B4191BAF221DA92C25AD3C35
AA4138AF473EAF433BB03B35AD2C28B12320BE211FC21817C71515C81518A70D13590001
AC7774E1B6B1E5BCB6F0C8C4E9C2BDEFC7C2F3CAC5F2C8C2F3C7C2F3C4C1FBC4C4F1999B
B92A2DC60F14CE0A0FD50C12D60E15D00910CF0910D00C10CF0C11CA0A11BF040BBA0308
BD070DB5020CB0010BAE030BAB0209A8020BA7010BA6010AA50009A5010AA40009A40008
A50007A30106A10106A20208A2010AA1000B9F010B9D010A9C01099B01099800079A0108
9C01099E010A9D00099D010A9C000B9C010C9C000B9501099100089C061195030E840308
7A00057C01087300046F00037402067501047100036F01056F0105680103620202590100
630F0300FF0000FF0000FF0000FF0000FF00
00FF003B96004B0B017C58596D656452514F4742405952556160630401022F211C2A1714
1900003700015B00047C010A89000A92020B97010A99010D92010A91000A8F010A91010A
91010A93010B91010C95030EA1060FA40208A80307AC0209B0040AB2040AAF0307AF0209
B4050CB5020AB60309B6010AB9040BB90109BA0207C0050CBF050BC60910C6060ED00D12
D20E10D40C0FCB080BD00D11CF1215BF1314AB1B1A8B1A1B933E38BE7E75DBA9A1EEC5BD
EACAC0EAC9C0E5BFB9E7BCB7DCA8A3D08B85C06962B1413BB62A26BF2120A71B1C450204
665A5EC8C8CAE7E3E1EBE5E5EBE6E5E9E5E4E7E3E3E4DFDEE9E4E4E5DFDFEFE3E4F5CCCE
B5494EC1171CCB090FD50D12D50D12CF080ECF0B10D00D11CB080EC5060DBD040AB9040A
B9050DB2010AB0030CAD030AAA020AA7010AA7010AA70108A70109A50109A20009A10109
A10107A10107A10108A20209A20109A0010B9F000B9F010A9C00089A0106990007980007
9A00069C01089C01089C00079C01089C01099E020A9C010C96020D95030F88020A790104
7C02077F01077B03086C01036B00027301047001026E01046D01046801036202025D0200
67120600FF0000FF0000FF0000FF0000FF00
00FF003B96004B09006F4D4D6961636B6A6A353331706B6C404043040001402E26190503
2200024502056002057701078201058F020B94020A95020C8F00098D01088F020A91010B
8E010B91010B91000A98020BA00309A20106A60105A80106AB030AA80107A40005AA0106
B20409B7030CB20107B6020BB8030ABF060CC1060DC2060DC2080EBE030AC2050BCC0B0F
D00D0DDA1214D40F11CF1415BD191B8A13117B322CB68D86E0CBC3E7DCD7E9E1DFEAE4E4
EAE5E4E6DFDFE6DFDDE9E2E2E6E0DDEADDDAE8D4CFE1BAB5D2918CBD5D599F3835521215
2E252BB9C0C4E0E3E5E3E2E4E8E7E9E3E3E5E3E3E5E5E5E7E8E8EAE4E3E5E7E3E4F0DADC
C67478BD2128D41219D50D10D30C0FD10B11CD0910CB0810C5060DBF040BBA030ABA050C
B6020BB3020BB0030BAB0208AA0209AA030BA9030AA60107A80209A40008A10108A00008
A00007A001079D01079F01079E01079E010AA1020CA2010B9D0109990005990106990007
9A00079900059B01069D01089C01089D01079D01079C01099B030F91010D810108760001
82020789020A85030B7B02097300067503077001046C01036B01036902046201025F0301
6F190D00FF0000FF0000FF0000FF0000FF00
00FF003C97004C0A01664142857C7E605F601E1B1A8B868728282A070000412F26150100
2901014A02066101047101047C00038B010893020993020B8E01078C01098E010A91010C
90010E92010C94010B97010A9C020A9F0106A20106A90309A90209A50108A10004AB0209
B5070CB6040AB40309B7020BB9040CBD040CC1060DC2050DC2070EBF060CC40B0FCC0E0F
CD0B0CD30E11CC0F11B61418760A0C7B4544D9C5BFEBE5DFEAEAE4E2E3E1E2E4E3E5E5E7
E7E5E8E6E2E5E4E3E4E4E4E4E3E3E3E2E1E1E2E1E0E6DFDEEBDDDAEDD1CED7AFAB614242
131216A4ABAFE1E5E7E7E8EAE3E3E5E6E5E7EAE9EAEAEAEBECECEEE6E5E8ECEAECEFE3E5
D2969AB1292FD81C20DF1418D50D11D00A10CB060FC5040DBF030ABB030ABC050DBB040D
B9040DB4020AB2030BAE010AAC010AAC020BA80209A8020AA70109A50007A20108A10008
A10107A001079F000A9E010A9E0008A10109A1010AA0000A9C0108970005990106990005
9A01079B00079B00069B00079C01099B00079B010798010996020D8D020B820207830207
8B040A84010681010880030A7501066F02066A01046701046A01056801055F01025D0301
74201400FF0000FF0000FF0000FF0000FF00
00FF003F98004C0900754F50736A6B4F4C4D251F1F928D8F1413140E0806362520160000
2C00034E01056703077201047B00038A02088E02088B01088A00078B01098C010A8F010C
91010D92000B96030D97010B9801099B0006A10107A8020AAA0209A70108A50207AB030A
B1030AB6040CB7030CB6020DB8030BBD040CC0060CC5080FC3080EBD050ABB0407C70C0E
CB0C0FCF0F14BE1014820C0E4B1919C7B5B5ECE7E4EBEBEAE2E3E4E6E5E7E1E1E3E4E2E5
E4E2E5E6E4E7E2E4E3E3E4E6E2E1E2E0E0E0E2E2E0E3E3E3E3E4E2E7E5E4E9E5E3D5D2D0
6E72718A8F91DFE1E3E9E9EBE4E4E6E1E0E3EBEBEDEAEAECE9E9EAE8E8E9E8E8E9EAE6E7
E8C1C6B04149CB1A22DC1219DA1016D20B11CB070FC3020ABF030ABE040DBA010BBD060F
BA050EB6020BB4020AB10109B0030CAB020AA70108A70109A70109A60108A40107A30107
A20006A10007A0010BA0010CA10009A3020BA1010B9F020C9A0209940005970106970005
9900079C01099D01099D010A9B01099A010798010793000596020A90020A810004850208
8B030A8301067B00027F02067600046D00046801056501046902056501025E0101590100
66120700FF0000FF0000FF0000FF0000FF00
00FF003D98004D0A00744F4D655D5C5854552C26288D888C09070919100F241311190101
3101035001046902067401057B000484000784000784000785010988010A8800078B0009
8E010A92010A92000A94010A9600089B0106A10209A7030AA60207A40107A30106A80206
AF0108B5040CB3030BB5010BBA050BBE060BC2090BC5080EC6090FC1070DC2090EC4080E
C6080FC60D13B0181E4E03048E7877E0DAD9ECEAE9E8E8EAE0E0E2E6E4E7E4E4E4E1E0E3
E0E1E0E3E3E5E1E3E2E2E2E4E3E2E5E4E2E4E3E2E4E4E4E8E4E5E9E5E8ECE5E8E9E6E7E8
E6E8E7DDE0DFD2D6D7E7E8EAE7E8E8E4E4E5E9EAEBE9EBEBE6E8E8E6E8E8E7E9EAE7E6E9
F0D8DDBD6871B91B24D6131BDA0F18D70E14CE090FC6060BC3070CC0050DBF060FBD050E
B9020BB8030CB6020AB4010BB1020BAD020AA80108A60108A7010BA6010BA50109A30107
A40108A30108A2000AA1000BA10009A2010AA2000BA1020D9B030B920006940106980006
9A01089E010AA1010A9D00089C02099B00089A02099701099B030B9C040E93040B8A0107
8B00088D020A8701068601068202077301056601036301026401026402035C0202540100
5F0E0400FF0000FF0000FF0000FF0000FF00
00FF003F99014B0A00613C39756B6A6D69692B2428827C810501022A1B1B1B08071D0000
3300015401056C02077100057701057E01097C01077B00097E000B85010A8903098A010A
8B02098E010A90010A97030C9A010A9B02069E0007A40208A101069E00059B0003A10003
AE040AB4030DB2020CB5020CBA060CBE060CC0060CC5090FC1060CC3090EC60A0FC4070C
C80C13B90A10880C11360E0EC3BCBAE7E6E5E6E6E6E8E8EAE8E8E8E8E8EAE6E7E7E2E2E4
E0E1E0DFE0E2E1E3E2E6E2E5E6DAE1D2BAC5C7AAB9D0B9CADACEDEE4E1ECDEE1E7E2E6E9
E6EAEBE8E9EADDE1E2E0E2E1E7E9E8E3E5E5E6E8E8E4E8E8E3E7E8E5E9EAE5E7E9E7E7E9
EDE0E4D597A0AD242DCB1119D71119D70E16D30E14C9080FC2050DC10610BD030EBB010C
BB020DBC040FB6010AB6020BB4030DAF010AAA0109A60109A50009A5010AA6020DA5000A
A6010BA5010AA4010BA3010AA3010AA2010AA2010B9F01099A0209940106960208990108
9A00089E0009A000099F01099E010A9D01099D010B99020B9302079C050CA0050C9E040C
9B030C94020B90030A8E02088602087702076802036002035B00015B01025602034D0100
5D120800FF0000FF0000FF0000FF0000FF00
00FF004099014A09006E4A47766C6A534F4C392F306D666B0500002C1919140101230102
3D01025E03076B02047001047402047601067702077800097D010B83010B87020C86010B
82000681000788000895010A9B010A9B02079E0008A7030AAA040BA60108A10006A30005
AC0208B6050FB0000AB3040BB9060CBD060DBF050CC3090FBF060BBC040BC1080FC1060D
C1070EBA12186C080A3C2727CDCBCBE3E3E5E6E6E8E8E9EBE9E9E9E4E5E7E8E8EAE5E3E6
E2E2E2E4E3E5E7E4E8E8D8DEC38F9AA34659982A3E91294286354C925E74B09BACCACAD5
DBE0E5E4E6EAE4E8E9E5E6E8E5E7E6E3E5E5E5E8E9E3E6E8E4E7E8E4E6E8E7E8EAE5E5E7
EAE2E6E1B6BFA7343FC71821D7131BD40F17CF0C14C90911C2040DC1060FC0060DBE050C
BA030AB90109B8020BB7030CB5030BB3030BAD010AA70008A50007A40109A4010CA5010A
A7010BA5010AA3010CA1000BA2010AA2020BA000099C020A9203098801078F030A96010A
9A010A9C010A9F010AA1010CA1010DA1000CA1010C960108850002900206A80810AB060F
9F040E8801078402078E030B8101056B01026502045B00015400015800025802044E0000
62160C18C50100FF0000FF0000FF0000FF00
00FF003F9A014A0A007553516A625F5854514A42444C474B0801023522220E00001F0001
4705066003046A020270010271010373000574000779010A7C020A7D010B81010A82000B
80000680000689020896020B9D010A9F020BA00108A8030AAE040CAC030AA60107A80208
AC0208B3040DB10309B00309AC0106B30309BC070CBC050AB50105BA050DBD060FC20710
C60A15B40E175D0305493638D4D1D4E6E3E6E8E7ECE7E8ECE5E9EAE8E9E9E7E5E9E6E4E7
E5E3E4E6E4E7EAE3E7D1AFB79E3946BE1F2DCA1823CC1827C6212EA61D2E6F11226B394B
A89AABCECEDBDBE0E5E2E6E8E1E4E4E2E3E4E3E4E6E4E5E7E7E8EAE7E8EAE7E8E9E4E4E6
E6E3E5E9CED3AE555EB81A23CA0E15CC0C14C80910C5080DC3060EC4060DC4060BBC0208
BB0409B8030BB7020BB6020BB50209B10109B0020BAC0209A80108A7030AA40108A50009
A50009A20109A20109A3010AA3010AA2010A9F00099A01088500046C00007301058D030C
9801099B01069C00089D000AA0010CA5010CA6010D9F020D920208940208A70710A9050E
98050E78000372000188050A8503096D01026402036002045B00035B0103590202530100
61120A318A0200FF0000FF0000FF0000FF00
00FF003D9900460A006847477269696965675E595B2F2C2E110807251313100000250001
4000015B00016900016D02026D01037001077201077301077101077400077F020A84020B
8401078300058A01079A040DA2030DA0010B9F0008A50109A90209A90108A80206A90209
AA0106AF020BB0030AB4060FB0020AB30209BA060BB90308B70207BF0810C1070EC60A13
CB0C18BB101A660509412E2FD6D4D7E8E6E9EAE9EBE9EAECE9EAECE7E7E9E8E8EAE6E4E7
E8E8EAE8E6E9EAE1E3B5858CA82A33CA161FD01016D61215E01D1ED81B20C11922981625
5D0D1F69485BA7A7B3C4C9D1DEE3E6E2E4E6E4E6E8E2E5E6E5E7EAE3E7E8E4E8E9E3E5E7
E4E5E6ECDDDFC28089A91F27C10C14C70B11C6090EC70A10C3040CC8060DC7080DBF040A
B80109B7020BB7020BB6020BB3020AB1020AB5060FAD010AAA010AA7010AA7020BA6000A
A50008A50108A50108A50008A4010BA2010CA0000A9C01098F04097703056A0001800207
96020A9B01059D01089F010CA3020DA6010CA6010CA3020C9E030B9A0108A1040DA3050E
96050A7F01047A020584010889020A7802066B01026A0205630001590001550202510100
5D0D0632890200FF0000FF0000FF0000FF00
00FF003F9C03440B006C4B4B83797B4440466C676B1F1A1C180B0B1906071A0101350304
4B02025F02026A02036D00036B01056F01067201057201076D00037201057C010984010A
8201058500078B010897030C9F030E9D01099E0007A20008A40106A60107A60107A60006
A80007AC010AB0010AB3030AB5040BB8050AB9070CB4040AB8060EC20A12C1080FC10810
C1040EC0121975090C31181AC5C1C5E5E2E8E4E4E6E8E8EAE3E4E6E7E7E9E7E7E9E7E6E8
E7E7E9E9E8EBEFE6E8CC9CA3A82731CB161DD21014DC1417E01819DB1417D71618CA141A
B117227310203615256F6B78BFC3CADFE3E5E1E5E6E1E4E5E4E5E7E4E5E7E3E5E7E5E7EA
E2E3E5E7E1E3D1A5ABA02B33C3161CCA0F14CB0C12C90A11C4060FC3050EC4070EBF050B
BE050CBA030AB70409B60309B20209B1010AB0010BAF020BAC0009A90008A80108A80109
A70108A70208A40107A00007A0010BA1010CA0020C9B01099401078701057A0103840106
9602089C02059C0106A0010AA2010BA40109A4010AA0020A9801099B040C9E030C9B0107
A00A0E8F04098803098801078802097B01057100047101046D03055D01025000014D0000
580C042E880100FF0000FF0000FF0000FF00
00FF003E9A01460A007E5A5B7166673E393B767072100A0B2517151302021D0000390202
5302026503036C01026D00036C02067101077602077502087101057400057C0107830109
82000588000989010892000A99010B9C01099F0006A30106A50004A50106A50108A50008
A70209AC010AB2030CB5020CB3030BB00309A90206A40005A80107B80710B5030BB5010A
BE060FC01019890C122A0507B1ADB2DFDEE3E8E9EBE8E8EAE6E7E9E8E9EBE8E9EBE8E9EB
E9EAECE6E6E8EDE5E6E4B9BFA52E37C6141BD41216DF181CDC1519D60F13D30F12D20F14
CC1319B11A235306101D070F9D9CA2D8DCDDE2E4E4E4E4E7E6E5E9E3E3E5E5E6E8E5E5E9
E3E3E6E5E2E5DDC1C7AA4D54B7171FC60E13CB0D13C60910C0050FBB000BBC030DBF060D
C0070DBF060CB90308B70309B5030AB4010AB3010CB1010DB2010CAF010BAA0109A80208
A60107A60108A30109A00108A00109A0000B9F000A9C01099702078F00048901048F0106
9801089B00079C01089D0109A2020CA2000BA2010A9D01098F00069102099D060E9B0309
A0090F96040C8F020A8D02098403087903077402077302066F0205660304590100510100
580B0430890200FF0000FF0000FF0000FF00
00FF003F9B02480B00795455625657534B4E726B6F080102180A0A1101011F01003B0002
5802026802046B01036A00046C01057402087802087400087501087501067C010781010A
84020A8B010B8B010891010A96010B9E010BA20209A60208A60107A30107A20106A20109
A50107AB010AB1020BB4010CB5050DAF020BA80309AA040AAD0309B8050CB8030ABC030C
C1050CC30A12A6141A3A0102847A81DBDADFE6E7E9E8E8EAE6E7E9E6E7E9E9EAECE6EAED
E6E8EAE4E4E5E7E1E0EDCACDAC424BC71922D41118D8141AD61317D00C13D31016D41016
D01017C4171D7E0D142A00046B6269D0D3D6E5E6E8E6E5E8E5E5E7E6E6E7E2E2E5E4E3E8
E4E3E7E1E0E3E4D3D7B56F77A81B23C30F14CB0E13C1040BBE040CBC030DBC030DBD050E
BB030BBF060EBE060EBC040BBC060FB7010CB5010CB5020EB3020DAD020BA8010AA6020A
A60209A50108A10107A20108A20108A001079F010A9C0109990107940104900003950106
9901089B00089C01099C01099F010AA0000AA1010A9E020B96020B90010798030C99050D
91020995070F8B01088802097401066401026800036E01036C0103680203600201580100
5C0C05328B0300FF0000FF0000FF0000FF00
00FF00409C034809007B56548074743B31356A5F62090302180C0C110000280101460102
6003046901056901036801046A01057202077600067500087700097801097801077A0008
8401098E020B91020A9100099500099E030B9F0009A10109A20008A10006A30208A40009
A50108AA0109AE030BB0010AB2020CB2020DAF050DB0040AB7050CC1080DC90B10CB090F
D30E13D8131AC41C215B050748363CCFCDD3E6E7EAE2E3E5E5E7E6E5E6E8E8E9EDE6E7E9
E9EAECE5E5E7EBE7E7EBD3D4B75E63C31F26D11319D4121ACF0F17D10F17D20F15D31016
D31115CB131A9E131A470005382328C9CBCFE4E5E8E4E4E6E7E8E9E3E5E5E4E5E8E6E6EA
E3E3E7E4E4E6E7DEE3CD9CA2A12A2FC1161AC80D11C80B12C2060DC1060EBF070EB9020B
B8030DB9040DBA030CB9050CB60209B7030DB5040EAB020BA4040B9F050E9A040D9F0610
A2040DA4020BA4020BA50207A30106A101089F010A9D020A9A0108960006920004960207
9A02099B02089A01079B01069C01079F01099F010A9F020C9E020D96000A8D01088F060C
8F050C91050C92040C8A020A7702086001036401037104076B00026300006002025A0100
600E07338C0500FF0000FF0000FF0000FF00
00FF00439C044A09008B6663776A6A372C30584E4F0601010902021702023704054F0202
6102016701046302026201026701036E0104730105750108760107750108740005790105
8302098A010A8E020B91000A9400089A010A9C00079D0107A001099E0007A00105A4010A
A60108AA0109AB0109AF030CAC010AAB020AA90108AB0108B00109BC050ACD0D11D30D10
DB1013DF1318D1191D7E0A0E2B1013B6B5BAE1E2E5E6E7E9E8EAE9EAEAECE6E7E9E7E8EA
E9EAECE9E9EBEAE8E8EBD9DAB36E72B6252BC91319CF1118CF1118CF0F16D10E13D20E12
D31013D01218B6161D6D07102C050AA7A6ADDBDDE2E5E5E7E9E9EAE7E7E8E3E3E7E4E5E8
E3E4E6E0E0E2E5E0E4DEBEC3A34147BA181EC1070DC50710C50811C0060EBE060EBB030C
B8030CB6030CB5020BB2020AB2020AB0030BA7030B8B02057A0102A12129CC4B57A6252F
8C030B9E050EA4020CA40107A10207A1020A9F010A9C0008990106970007930006910106
9502089A01099D02099C00079D01079D01079E00079F010A9E010B9A020B8D0106880104
970A0F9703089F070E95040D85020A7101066B00027301066E02056100005E01015C0201
5E0C06328B0500FF0000FF0000FF0000FF00
00FF00419B034A0800886061604F52463B3F3C3437080101080001180000380101530203
6103016302035C00015F01036601046C00057102067301087300077401077401067C0108
83010A8701098B010892010A9401089800079C02079B01069C02059C01079C0006A00108
A50108AB010BAE030CAD030CA60006A40005A70107AF040DB10208BB050ACC0B10D91114
DE1215E01318D314189D12172D0002928F95D9DDDFE9EAECEAEAECEDEDEFE8EAE9E6E6E8
ECECECE6E6E8E7E5E6EDE2E2D5A4A7A92D34C3161BCA1116CC1116CD0D14D10E16D30E14
D10F11D21015C4171C95121A4201076F676DCDD2D6E4E8EAE6E7E9E5E5E7E3E3E6DFDEE2
DFE0E1E0E0E3E4E1E5E9D4D8B2666CAA181FC00B12C2070FC1060FBF0510BD040EBC040E
BA050EB6020BB5020DB3020CB0010BA9020B96060C7000017302069008149A101EAC2B37
7B01078B02099F030BA40209A100099E010B9F020D9D010A9A01069401068C0005850002
8C00059A01099D01089D00089E010A9E010A9D00099C00089E020A9F020B9A020B930108
9A080E9E060CA0060D95020A8600077B02067201027301057202056602025D01015B0201
5B050032880300FF0000FF0000FF0000FF00
00FF00449D054A0800855B5D7C6A6F4E41452A25260F05050F00001B0000380101530101
5F02025F01025B00005B01016201036B01076F0107700107700006740106780106800108
8601088801088A00078F010A9201079500079701069801069700059A00089D01099F010A
A4010AAA010CAE030CAC020BA90109A70108A60006B4050EBC0810C4080FD00D12DA1115
DD1317DA1014D31015B315194602035A5358D2D6D9EBEBEEEAEAEAE9E9EBE8E9EBE9E9EB
E4E6E5E7E7E9E1E1E2E8E2E1E2C0C4A64249BD1921C91218CD1218CC0D14D01018D00D14
D20F14D31015CA141AB1161F61050C3E2C31C1C5CAE6EBEDE2E4E7E3E3E6E6E6E8DFE0E2
DEDFE1E0E1E4E2E2E5E7DDE1C692979E2029BD0F18C30A12C0070FBF050FBC050DB9040A
B9060CB7030BB6020DB7030FB5030FAA040E8403096800018B09129F030EA1020E9E0614
87030B81010799050DA2030AA2010AA1020D9E010C9C010A9A01089400059101068C0205
9001069901089C01079D01089C00089C01099C01089C02099D010A9B010A9A010C9A020D
9C060F93010899071090030B8101067902056F02056C01056E02046801025F01015B0100
5E070234890400FF0000FF0000FF0000FF00
00FF00449D04510B00875D5F705F635045471510100C0101130101280202430202580202
5D01025C01015901005A00025E01016901076D01066D01056E01047301057A0105810108
8401078701088800088D010A9101099201069400069601079700079A00089E030AA0000A
A3010BA7010BAB020AAC020BAC030DAA020EA60009AF020BB40309BD030BCD0D13D41013
D71112D60E12D20F14C0151A680A0C2C1C1EB9BFC2E6E9EDE7E8EAE6E5E9E3E4E6E0E0E2
E0E2E1E2E3E5E1E2E2E5E3E2E4D3D4B86D73B01D24C8131BCD1017CE0C15D10F17D10F16
D10F16D00E15CA0F17BE141B820F1328060AA5A6ADE1E5EAE3E4E8E4E5E9E3E4E6E2E3E6
DFE0E3E1E2E5E1E3E5E6E3E5D3B1B5963139B20F19BE0811BE0811BD060FBC060DBB070C
B6050AB3030AB5020BB7020CB7050FAA07107301055B0002880910A0040CA5020EA2030F
91070E73000287040A9E040EA2020CA1010B9E020A9B00089B0008990108960106940106
9A02099B00079C01079C01089C01089B00079C01099C010A9C030C920008920109960109
9A050F89010785020988030C7900046F01026701035D00016403056402045F01025D0102
60080466140800FF0000FF0000FF0000FF00
00FF00459E03520D008B61615648495247480A07070400011000013002044C03035C0204
5C02015A01015801005900025C00016700046B00066B01056C0103730107780105800009
8401098700078801078C00098D00099100099200079500089801089A00089E020CA0010A
A10109A00006A60207A90108A60108A5000AA9020CAD010AB40207BA0207CD0C11CF0C0F
D00D0ED20E12CE0B13C00E167F0A0F200305888B8FD1D6DADFE2E4E2E2E4E2E2E2E2E0E1
DFDFDFE0E0E0E2E4E3E3E3E3E8E0E0CB969AAA292EC8161ECE1018D10F17D41219D10F17
CF0D16D00E17CE0F16C40E15A3161C3B00066C676FCDD1D7DFE3E5E4E7E8E4E5E7E2E3E5
E1E2E4DFE0E2DDDFE0E0E0E1DDCBCE9C5257A4141CBA0B15BA0611B9050FBB060DB70309
B6040AB3040CB3030DB3020CB6040FA90A126B01044700006C060B90050E9B040C9A020B
8B080E640001730307990510A1020DA0010B9D01099D01079B00069B0207960006950108
9801099B00089B00079C00069E01089E01099C01099C010B9A010D920109910007960109
9A050E8A02097C00048302097F010876010673030A6101035B01025B00016001015F0102
61080566160A00FF0000FF0000FF0000FF00
00FF00469F044F0B007953506A5C5B483D410402020600011401003201014B0201580201
5802015301005101005401015A01016701066B01066E01066F01047300077B010881000B
85020B88010A8801088C01098E010A90000992000A9301089401089700079B010A9E010A
A10109A40108A60107A90209A60107A70008AE030CB8040DC60C0FCC090FD10C10D00D11
CC0B10CB0B12C80B12BD0B139711163101025C595DC1C5C9E1E3E3E1E3E2E1E1E1E1E1E1
E1E1E1E0E0E0E1E3E2E1E2E3E6E3E2E1BDBFA73D42C51921CD1117D20F17D00F14D00E16
CF0D16CD0B15CF0F17CD111AB7151D5B040A3F2E35C1C6CBE7EBEDE6E6E8E4E5E6E1E2E4
E1E1E3E1E3E4DEE2E2E0E2E1DFD8D8A67477931A1FAF0911BA0812B8040FB9060FB6030C
B7040CB6050EB4040EB1020CB2020DA907107403073E000044010366030B7B050C7D060B
6A0408500101680207910410A0030FA0020D9E020B9D02099B0106990208930107910006
9501079901089B01089D01089E01079E01099E010A9D010C9A010C97010A97010A97010B
9D041096040E85000786020B84020B7E02087903096A0003630103630203610101610102
60080467190D00FF0000FF0000FF0000FF00
00FF0046A0064C090086605F695A5D433A3D0200010800002002023D0303500201560100
5201005101025000015101015800006400036C02066D01066E01047201077A01087F000B
84010C87010B8600088A01088E010A90000A92000A92010A9500099800079C020A9E010A
A10109A50109A9020AAA010AA70007AE010AB9050DC2060ECD0C11D20C0FD10B10CA0810
C3070EC40A12C30A11C00B12AA11174F030734272BB6B7BCDDDEE1DFE0E2E3E3E5E2E2E4
DFE1E0E1E1E1E2E4E3E3E3E5E5E3E3EAD1D3AF5B62BA1C24C91217D10F17D10E15CF0C12
CF0E14D00C15D21019CE0D17C2111C7D0A1329080C9EA1A6DEE3E5E4E6E8E3E4E7E3E4E6
E0E3E4DFE3E4DEE2E2DDE1E0E0DFDEB9999A8E2B30A80D16B40710B6060EB70610B6040D
B4030BB5030DB3010EB1010EB1030EAC050F8A060D4D01013400014200044C00034B0002
3F000240000367020B9405139F020E9D010B9D020B9C01079A01069600089001068E0004
9400059900079C01099C01089D01079D01089C010A9E020D9B000B9A010B96020A900107
91010A94020D8901088302097E02097901077501067001026D0103670102620001620202
5E020162110900FF0000FF0000FF0000FF00
00FF00459E054B08009169664E393B372A2C0300000B0101230100400201500202530201
5100005101025201005501015901006300036801056800036C01037100047A02087E000B
82010A86010A86000989000A8D010A9000099100099201089601089900089C0109A0010A
A20109A6000AAA020CAB010AAB0209B4030CBB030AC70910CC0A10CF0C11CB0A10C5080F
C0060DC10610C30913C00910B50F17700A1020080B9C9EA2D3D7D9E2E2E4E2E2E4E1E1E3
E3E4E6E5E5E5E1E3E2E3E3E5E4E3E4EDDEE0C5878DAF242DCA161DCF0E16D20F17D00D15
D00F14D00D15D20F16D41018CF131BA0141C380107747177D4DBDCE5E7E8E2E5E6DEE2E3
DFE3E4DEE3E5DEE3E4DDE2E2DEE0E0D1BEC191454D9E131EAF0711B4050FB3040CB4040C
B3030CB3030EB30111B20312AF040EAD040C9F060D7503094800026124276427293E0507
3300033D00016B020A9604119E020B9C010A9B01099B01099B010A9601099101068E0003
9300049800069B00079D01089E010A9E010A9D01099C010B9C010C98020C8F01098B030A
8C020A90020B8802087502076801066801056B01037202037303066601025F0001600202
5D030062100700FF0000FF0000FF0000FF00
00FF0047A006500900734744553F3D271A1B030000090000240203420202500101520100
5201005100015101005801025B01016200036A01066B00046F01017300027A02067E0109
80020B85020D84010A87000B8A000A8E00099101089502099801089B02079C0109A00008
A10008A6010BA9010BAB0009AF040DB3020CBA050DC50A10C90A0FC90910C3070CC2070E
C0070CBF060CBF070DBE080EB90D14890D132B00036B6A6EC0C5C8DFE1E3E1E1E3E1E1E3
E2E4E3E0E0E2E1E3E2E1E2E4E2E1E1EBE1E4DCB2B6A53138C51A1DCC0E13D21116CF0D15
D11015D20F17D10F14D20E14D11117B7181E55030941353AC2C7CCE1E5E7DFE3E4E0E3E5
DFE3E6E0E2E6E0E4E7DDE1E3DDE0E0DFD4D5A26971911723AD0C17B1060FB1020CB3030C
B4050EB1030FAF0211AB000EA9010AAC030BA70409990C10811E208D4B4DCD90937B3C3F
42000159010584050D9C030D9F010A9B00079800079B000A9B010A970109930107930106
9601079800089A01089B01089D010A9D010A9C01089B010899020B8D010A7E0005810108
8A030C8C030B8503096800025100015C00056D02057401047303056502035B01015D0201
5C030165140A00FF0000FF0000FF0000FF00
00FF0048A206520C0071433D5C4643160D0D0100000700011D0000410203550303550101
5302015401035302005700015E00046501046B01066E0105700103730105760207770109
7201077502097A020A83010B89010B8A010A90020A9501099801089A01069B00069C0108
9F0008A40009A60009A90209AD020BAF010BB00106BF070CC4080DC60A0FC1070CBF060B
C0070CBF080CBF090DBE0A0EB90B119F11194202063C353AA6ABAEDEE1E4DFDFE3E3E3E5
E1E2E2E2E2E2E2E2E4E3E3E3E4E3E4E6E1E2E1C6C7A74C52BC1E23CD1318CD0E13CE0C14
D00E16D00D15D10E16CF0C14D00F16C1131A780B11290C11A7AAB1DCE0E4E1E4E6E1E3E5
E2E4E7DDE0E2DFE0E3DEE1E2DEDFE1E4DCDDB98E9389202BA70C17B10812B1030DB2020D
AF020CAD030DAD030FAA010DA9020BA80109A9030BA2060CAB2E32B1565C8F464D7E2F36
811D2386070F9B040EA4010CA1000B9C01099B01099B0109980108950108910006950007
9800089700089900089C01089C01079D02099B01079A01079402098201077600057F020C
7E01097C010584040B77050A5D01045A00047004087501037002045F01015801005D0201
5A03016A1C1100FF0000FF0000FF0000FF00
00FF0048A3094E0C008E615F4029270F04040100000A0000210101410203530202550204
5201005201005201005701025E02056501056A01056C01066B00046B00046C01067A0E14
A33D428220296501057B020A86010A8A00098D01099301099701069A01069C01079D0009
A10109A50108A50007A90208AE020AB4050CB5040ABF070CC3090EC2090EBE060CBE070D
BD050DBE060FBE080FBE0B0FBC0C12AB121A5D080C1F1012868A8DD8D9DDE0E0E0E2E0E1
E1DFE0E4E2E4E4E2E5E4E2E5E6E4E5E3E1E2EAD9D9BB797DAD2025C71315D11317D00F14
D31018D30E15D20D14D10E14CE0D12C8131999141B33000579787FCDD2D8E3E4E8E2E3E5
E1E2E4E2E3E5E1E2E4E0E0E3DDDDE0E1DCDECFB4B88B3840A0121CAF0811B50812B1030D
AD020BAA020BAD030EAA020CA6010BA5010AA5020BA7040FA30815981321A12A39A12836
9B131E9F0610A5010CA6020CA101099B01079A01099A010A97000995020A920006960107
9901089A010A9B00099E020A9E01099F020A9D01099A00069703098701078100058B030F
88040F7800067D020A7B02096E05085D00026904086D03066702045C01015900015A0100
590200681A0F00FF0000FF0000FF0000FF00
00FF0047A2084F0D017C4F4A361D1C0C02010400011101012601004001014E01024F0101
4F00015101025201005500025A01026301066801056A010666010363010266010289151D
89161F760C165D000571020B86030A8C010A9000099301089601079701079B01089E010A
A20109A40107A50107A90108AE0309B8050CBC050BC1060DC3090EBD040ABB050CBC070F
BC0711BD0713BD080FBF0A0FC00C11B410157C0D132001046B6B70C4C5C8DFDFDDE2E0E1
E1DFE0E3E1E4E3E1E4E3E1E4E6E4E5E2E0E2E9E1E1D0A3A5A42C2EC6181BCE1314D01015
D00D13D10C13D20E13D00D11D10F13CB0F16AF151C4F020A494147C2C9CEE2E4E8E3E3E5
E1E2E5E2E3E7E0E0E3E0DFE1E1DFE2DFDCDFDACBD09B5E6696171EB00C14B3070FB2040E
AF050DAE040DA9010BAA030DA8030DA4010BA2010BA4000DA5010FA505159F04139F0313
A40211A7030EA7010CA5010BA3020C9E02099C01069B0008970009940109930007970108
9801079900079C01099C010A9E0209A1010AA1010A9F01099C010995010991010997030F
93030E8600097F020B7600057103066501045E01025D01015D01025D01015E01025D0101
5B020164130900FF0000FF0000FF0000FF00
00FF0048A3084F0D0171453C2813100801000500001701013202024702034C01014C0102
4C00015001015501015701025801015F01056501046801056201035A000163000382040E
8A040E83040F6401056401067E020B8A010990010994010997010A9600099901089C0009
A00108A10108A3010AA7010AB1030DBC060DC1080DC80D12C2090EBC040ABA040CBD080F
BA0610BD0811BD080EC20B10BF090DBD1117950F163401034D484DB2B6B8E1E2E1E3E0E1
E4E1E2E0DFE2E2E2E4E4E3E5E5E5E7E5E3E5E8E3E3DEC0C1A74548BE1A1ECD1317D11218
D21017D31019D10E15D31116D11015CE1016BD131A730B122A1218A5AAB0DDDFE4E2E2E5
E1E2E4E1E2E5E1E2E5DEDEE0DFDFE2E1DEE2E2DADEB1878B8D2127AC0E18B50B14B2070F
AF050DAF070EA80209A60009A8020BA40007A5010AA5010CA4010CA3010CA4010DA5010C
A6010BA8010CA8020EA5010CA4010CA2010C9F01099B010798010898020996010898020A
9801089800079B01079D01099F0109A10009A1000AA2010CA2020B9D020C99030D960510
90010B8E030B8A030B7E01087701076F00066B03076101025F0102640204650303600101
5B010063100717C30100FF0000FF0000FF00
00FF0049A4094D0C00825A5121120F0601000901011800003903034D03034D01014D0101
4F01015201015801015901005701005B00036201056701085C02054D000069020885020D
8D020A87040B6B02065C00047A020A8901098F010893010797010798010A9801089A0008
9E030B9E010AA4030BA80208B4040ABC060BBF060BC1070CBE050BBC060DBA060DC00810
BF0811C10A13BC070DC20B0FC00A0FBA0811A710194F04092F22279D9EA3E0E0E2E1E1E1
E1E1E3E0E2E3E2E5E4E3E4E6E4E5E7E5E3E5E3E2E2E5D2D5BB7076B51F27CA131AD2131B
D3111AD00C17D31018D00E16CE0D14CF1016C5111995131B30000875757DCBCED4E1E1E5
E4E4E8DFE0E3E0E0E4E0DFE4E0E0E4DEDEE0E4E2E4C9AFB18D363DA5131FB00A14B10710
AF060EAB040DA9030CA7010AA9030DA5000AA20109A3010CA2020D9F010AA2010CA3010C
A5000AA6020AA7030CA4010DA2000DA0010C9D00089D02099C02099A0108970108970109
98010A9900099C01089D01089F0109A2010AA2000BA6020DA7040FA1050E900108860108
89020A90030C8C01098601088102097C02087A03097001056C02056401035F01015F0203
5901006C1A132E860000FF0000FF0000FF00
00FF004DA70C5310037A4F491709070400000800001B00013901024B02044900014B0102
4D00005300005701005901005701005B000062000363020654020444000169040980030A
86020A7F040B6302055A00047B040A8C020991010A93010A94000898010A9701079A010A
9C01099D0008A10107AC040AB4030AB9040ABC070CBB040BBB050CBA060FBA050EBF0610
C0070FC00711C0080FBF080DC00B12BD0A14B1101A6B070F21070E8B8A90D5D5D8E1E0E2
E0E1E1E0E3E4E0E5E4E2E6E7E4E5E7E5E5E7E4E3E6EADEE2CF989EA7262EC6171DCE1017
D10F18D40F19D31018D00E17D00F16CE0F16CA1119AC161F4902084C424ABABEC4E2E5E7
E0E1E3E0E1E3DFDEE2E0DFE4DFDEE3DDDDE1DFDFE1D8CACD97585E94141EAC0A14B10812
AE0610AC0510A7000CA6010DA6020CA2010BA00009A1020DA0030E9D010B9D01099F010B
A1000BA5020BA50109A3000AA1010CA1010B9F01099D01099B00089B010A9A000A9A000A
9901099900089A01079B01079F010AA2010DA4010DA9040EA7050DA6081397040E870106
8C030B91010A8A01088601088601098002087E02097801057301046702035C01015E0202
58000075251E2E870100FF0000FF0000FF00
00FF004FA90D561303683D381204030300000800002401013B01014A02014800014B0102
4F01025702025902015C02015B01016202046500056202084C020437000057030773050A
73030A6302075101065601047A020B8B010992010891000995000998010A9B01099D020A
9F010AA00008A50208B1050DB8040CBA060DB8050BB8040DBA050EBF0A12BC070EBC040E
BE070FBD050FC10911C20911BF0A13BE0B16B50E18870D172A000769646CC4C4CAE3E3E6
E3E4E4E0E1E4E1E2E4E2E3E3E5E5E6E5E3E6E4E4E6E7E2E5E3BFC3A43A40C11A1FCF1319
D31319D31019D20F15D20F17D00E16D00E17CE1019BD17216A0810291217A8ABB1DCE1E4
E1E3E4E0E0E2E0E0E2DFDFE2E0E0E2DDDDDEDEDDE0E1D8DDAD7F85871A22AA0C16AD060E
AC050DAB040CA9030DA6020DA4010CA2010B9F00099E01099D010A9C010A9C000A9D010B
A0010BA4010BA4020AA2010AA0000BA1010C9E00099F020B9D010C9C010B9A00099A0008
9901089900079A01079B01079E0009A2010BA8030FA8030DAA050EA90512A2041095020B
90010991020B89010886000786020A7900057401057701067301046B0205630103610101
5A01007020182E870100FF0000FF0000FF00
00FF004DA80D521202754E4B1006050300001001003303044902035003034A01024B0102
4D01015402015801015C01025A000063020568020864030B4703062800003801014D0205
4E01054400034100025801037D020B89000790010892000A95010B9700099801079C000B
A0020BA3000AA8030AB2060FB6070FB8080EB6050CB6020CBB0710BC070FBD080EBB060D
BE090FBD080FBE0A10BB060FBE0912BF0A15B609149F121D45020C3A3139B9BAC1E2E2E5
E1E2E4E2E3E7E3E2E6E4E2E5E6E4E5E5E3E4E5E5E7E5E3E5E6D0D3AA5C60B81E25CE131B
D01218D31117D11014D10F15D41318D00F15D01219C313198D111A2E0109858389D1D3D8
E0E1E4E1E2E4E0DFE1DFDFDFDEDEDEDDDDDCDCDCDCE1DDDEBEA0A4842831A5101AAC060E
AD060EA9020CA7020CA5030CA5020DA3010C9F00099E02089D01099F020D9D000C9E010C
9F010CA2010BA3030DA0000B9F020D9D010C9E010A9F020C9E010C9B010A990108970006
9801089901089A00089C01099F0109A5020AA8020CA9040EAA0712A3020DA60611A0030D
97020C87010783020988030A88020A7B02087200047401066B01035F0102630305620102
5C02016D1C132F880200FF0000FF0000FF00
00FF004FAA0F521406724E4C0802020300001601013B03044C02024E01014C00024D0101
5001015400025801005D01015B00016201036701046302074C0206260000260000330102
3901043A00044600026803078101098A01088F010892000A95010996000997010A9A010B
9D0109A5020BAC080FA20309A10409B30912B70611B8040FBB0510BC0710BC070FBC070F
BB080EBB0710BB080EBD0912BD0912BD0814BB0C15AC111C640811231017A3A6ABDDDEE1
E1E2E4E1E2E6E3E4E8E3E2E6E5E5E7E4E2E6E4E3E5E3E2E4E7DCDEC28990A9252CC8191F
CE151ACD1418CE1519CE1519D0181ACE1518CD161AC6181AA91E2546040B594F55C6C9CD
DFE0E3DFDFE1DEDEDFDFDFE0E0E0E0DDDDDEDFDFE0DFDCDDD0BDC19148529B131FAE0A13
AD0610A8010CA9040EA7030BA5020DA3010EA1020CA2040EA0010D9F020D9D010C9C000B
9C010A9C0109A0030D9E010C9D010C9B010A9B00089C010A9B00099A0108980007990107
9A00089B00089B01089B01069E0007A40109A8040CA7030EA807139D010BA50712A6040F
9D030E8402067700048202088301077B01077A0208740205670203550000570101620204
5D0001600C0430880200FF0000FF0000FF00
00FF004FAA0F551709623D390900000400001600003901024B01024D01014C00024F0101
5301015900025900005E01025F01016301036501036301035803053401012901015C3033
8355583E05085D03077A03098701088D010A91010A92010A920108930108960208980108
9A0106A7050DA8050C9702038D0001A7050FB4040FB7030EBA0611BB0713BC0611BA0510
BA0710BC0812BB080FBC0811BB0A12BF0B14BA0A12B40F18810F162101047D7D84CDD1D5
E2E3E7E3E4E9E1E2E6E3E2E7E2E1E6E1E0E5E3E3E8E2E2E4E7E2E4D5B5B79A4042B32D2F
B72A28B72A26B52B28B42B28B22B27B32C29B5312CB02F2C9D2F2E5C222345393CB3B5B9
DEE0E3DEDFE2DCDFE1DBDFE0DDDFE0DFDFE1DEDEE0E0DEE0DED3D7A06A728C1520A90A15
B00812AD040EAB040CA9040CA8030EA5020DA3020FA2010EA2010E9F010B9D020A9C000A
9C010B9B00089D020B9E010C9B000A9700079900089B010A990109990109990109970108
9A010A9B00099C010A9F010AA10108A3020BA7040FA90411A8091499020B9A050EA20611
9B030D8F050C7C00047E03087901047300047803097201056B0204610305580000630203
630203630C082F870200FF0000FF0000FF00
00FF004FAA0E551607542C250D00000B00002202014103034F03024E01014D0101500102
5401005A01045B01035E01025E00016201026201026201026304064B0203380309996B74
8E6269621D24760A1285020B8B020A8D01098E0109920108910106900106940008980009
9D000AAA050EAA040CAA080EA40409AF060FB70610B90410B90510BA0612BA0410B9030F
BB0711BB0812B7060DBA060FBB0A14BB0712BF0C16B90E179C161D3701044C464EC2C5CB
E1E2E6DDE1E5DFE3E6E4E5E9E0E1E5E3E2E7E1E2E6E0E1E5E2E2E5D9D1D0BB9996CC9491
D89B97D59B96DFA8A1DBA39ED69F9AD8A39ED7A29CDCA9A3D1A6A1C2ABA8BCB8B8C0C0C3
DBDADEE1E1E4DDE0E2DCE1E1DBDFE0DEDFE2DEDDE1DFDDE0E1DBDEBD999F87222DA50B16
B0050FAF030DAC030CAE0911AB050FA8040EA3020CA3020DA1030E9C01099E030B9E020C
9C010C9C000B9C010B9C010B9C010B9A000A9B010A990109970008980108980208950006
9901089B010A9D000BA2020DA4020BA2010AA4020DA7040FA807129C060F8F0109980911
9101088D03097C00047A02077C030A7300066F01056B0204690204680405600102630103
63010268100B31880300FF0000FF0000FF00
00FF0050AD0F591D0D5E3C370900000D00002C02014904045002024B00004D0101510002
5601015901045801025D01045E00015E01015F010262010266030461070C752D377C414F
8D4C5B7D202D7E030E89010C8C010B8E010A8F01099100089002068C00059302099A010C
A0010CA8020AAE030CB0040DB2060EB5050FB9060FB8020EBB0511BD0713BB0712BB0712
B90611B80711B80810B90611BA0913C00C18BB0914BA0B15AB131C56060A2B1C21B1B2BA
DFE2E6E2E3E7E1E5E8DFE3E6E1E2E6E3E2E7E4E4E6E3E1E6E4E4E6E3E2E4E2DEDEE7DFDE
E7DFDDEAE1DFE7DFDDE9E0E1E8E1E1E4DEDDE5DFDEE8E2E1E5E1E0E4E2E2E3E2E4E2E1E2
E2E1E3E1E1E4DEE1E3DCDFE0DDDFE1DCDEE0DCDDDFDEDDDFE0DDDFCDB5B88E3940A20F1B
AF0512AD020BAD050DA9040CAB050FA8020EA6020FA2020DA10611A20C159B020C9D010D
9E020D9C000C9C010C9B000B9C010C9D020D9C010C9A000A9A00099B010A99010A990009
9A01089C01099D020A9F020BA1000AA3020AA5030CA6030CA9060EA70A1292040B840208
90080F90030A8201057A00057E02097B020A6D01066200025F0001630103650102670203
6501016C120E358C0700FF0000FF0000FF00
00FF004FAB0E6026175B3C380800000E00012A01014601015002024B00014B0100510102
5C080A5B080A5201015901025C01035E0105630206640104640103620105680B16721827
6F0E1D7A051386020E8C010D8C000A90010A91020892010A8E01058C000592010699000A
A2020DAD040CB1040CB3050EB2050EB40911B90910BB0710BC0612BB0713BB0712B80711
B60610B70711B70812B60610B90911BB0A15B80712BB0A13B7111B7A0A142402098E8D97
D1D4DAE0E4E7E0E4E4DFE3E5E1E2E4E2E2E6E3E3E5E4E2E5E4E4E5E3E3E5E3E3E5E2E2E4
E4E3E3E3E1E2E3E2E3E2E1E2E1E1E3E1E0E3DFE0E2E3E3E6E4E3E6E3E2E5E2E1E4E0E1E4
DEDEE3DFE0E4DDE0E2DBDEE0DBDEE0DCDEE0DDDEE0DFDEE0E2DDE0D8C1C494444BA1121C
AD040FAB020BAC030DA9020CA7000DA90310A5020EA2020DA106119E05119D030E9C000B
9C000B9D020B9D010B9D010C9C010C9B010C9B010C9A000B9C020B9C010A9C010A9B0009
9B01099B00089C01089E020BA1010BA5020DA8020DA9030CAC070EA8060E9D061087020A
86020994040B8E02088501098002097402086B0309600106610204660103690103690102
6703016C120E358C0700FF0000FF0000FF00
00FF0051AC105A1D103F1E1C0800000F00002C03014604034E01014C01034900014D0002
5002064A01025202025701015A02035D020561030761010564010464010369010770010B
77020B82010F8A020F8E020D8E010C91010B8E010991010A8F01059100059601079B0109
A4020BAC040BB1060BAF050BAA0309A80309B40710BA0810BB0610BA0612B80711B7070E
B4060EB3050FB30811B4070FB5090FB3040EB6060FBD0B11BC0F179D111B4302094E404D
B9BCC4E1E4E9DFE3E3DEE2E3E0E2E2E0E1E3E3E3E4E3E3E5E4E4E5E3E2E5E3E3E6E3E1E4
E4E2E5E2E1E3E2E3E6E2E3E6E3E3E5E1E1E3E2E2E4E1E2E3E1E1E3E4E3E5E1E1E5DFE3E6
DDE1E4DEE0E3DDE0E3DADDDFDBDEDFDCDEDFDCDCDEDFDEE0E3DCE1D5B9C1903B44A3111B
AF060FAE030DAC020DAC030EAA020DA7020CA2000BA3030D9F020C9E010D9E020F9D020D
9D010B9E030B9C010A9B010B9A000A9B010B9A010A98010998010A9A010A9B01099B010A
9A00099C010A9E020DA0020DA2010EA3010DA6030DAA050EA8030BA8070EA507109B0810
8C010992040D90020A8A02097E03076400015801055701055F02056602056901046C0203
650200640B074B4E0600FF0000FF0000FF00
00FF0052AE125C1E1042221F0B00001300012B01014201014A01014B02024A01014D0102
661B1F530A0E4F01035002034E03044E02055303075702075F03066802066B0004740008
7E010B89010F8D010E8F020E90010C93010B8F010990020A9001079301069802089C0008
A60309AF040CB2030BAE010AA90208A50208AE040CBA0A14B6040FB80511B80711B5040E
B2030DB1030EB40812B0050DAF050DB60B13B80A0FBD0C12BD0C13B4111B820F19390310
7C6B79C6C0CDE0DFE4E1E1E6E2E4E7E2E2E6E2E2E5E3E2E7E5E4E9E6E2EAE5E2E8E5E0E7
E3DEE2E3DDE4E0DEE4E2DDE5E4DFE6E5E0E6E1DBE2E1DCE2E2DDE3E1DCE2DDD9E1DBDBE2
DBDAE1DCDBE2DBDAE1DCDBE1DDDCE1DEDCE1E0DCE1E2DAE1E0CBD7BD8693901F2CAA0D16
B1060EB0050FAD020EAD030EAA010AA7020CA2010BA0030B9F020B9F030E9D010D9F030E
9D010B9E010A9C010A9B010C9A000B9B010B9A00099A000999010A990109990107980108
9900089B0109A0020CA2010BA4020DA4020DA3010BAA050FA7040E9F010AA5060FA2050D
97030B8A01098703098101057C02066D02065B00035301025801025D0103600102680202
660201600702600F0400FF0000FF0000FF00
00FF0054AF136528194225220C00001800003402024B04054C01014D0101510201500103
5F10145404094C01054300023C02035B1F226223274C080C4C01036001046D0002790109
85010E8C020F8E000C8F020F8E010B8F01098D01078C01088D01089201079501079E0107
AA040CB2030DB4030EB40410B1040EB2060FB4060FB1030CB60710B80612B70610B60611
B0020CB1050EB3050DB0040DB0050DB60B12B70A10BB0C13BB0A11BD0F18B1121D890D1D
5B081C773F56B389A0D1B2C6C7B3C1D1BFCBD9C4D0D5BDCADBBECCDAB8C9DAB7C6D7B1BF
D5AAB8DDADBDDAAABFD7A7BDCE9CB1D7A4B7D19EAFD6A3B3D9A5B5D8A5B7C596A8CB9DB1
C095A7BA92A3B78FA0C59EAFC9A4B4CAA4B4CDA2B3CC98A9B66B7D9C2C3DA50F1BB20710
B2030DB0030EAF0510AA0109AB030AA60108A5020CA4030FA0010C9E010A9D000B9D010D
9E030D9D010A9D020A9C010A9C010B9D020B9C010A9B010A9B010B9B010A9A00079A0107
9A01089E0308A2040CA2010BA4020CA2020BA2010BA6030EA60510A0020CA5040FA6040D
9E040D8701057E01037F01067C01067302066B0006660205620003620306590001620203
6704046A100C691A0F00FF0000FF0000FF00
00FF0054B011672D192F14100D01001A00003801014E03044C01014B00024F0202500104
5102045103054A01024901038030389B4854A4505E9C48554C01035900036F010682020D
89020D8B010F8E020D8D010E89000A8800088B01088C00098D0209910109940106A20208
B1060FB4030EB50510B50512B50510B5040FB80711B70610B70711B80711B6050FB0030B
AD0209B0050DB3070DB3050EAD020CB50710B80B11B80910BB0A10BE0C12C00E17BB121D
AE14239D142A9319349E354FB1556CBA6076C05F75B9546ABF5268BD4A5FB84458B53D52
B6384EB7374EB33149B33049AF2C44B12E44B02C3FB02B3EAF2A3DAC293DA9273DA7273E
A6273FAA2D44A52A40A62E43A73246A83248A83047A8253CA81729AE0B1AB60811B80610
B4040EAF020BAF040DAE030CAB030AA60109A6020BA6020DA4010DA1010C9E020D9D020E
9A000B9B010B9A010A9B010B9C010A9D020B9B010A9B010A9A01099700089A01079D0209
9B00089E030B9E020BA1020DA2020DA3020DA2010CA4010DA90710A7050FA8040FA7040C
A0020B92010A8A020889030A7E02057200037503097303076F01066B03075A01025C0102
640304650D096E211600FF0000FF0000FF00
00FF0054B1126229122A0F0A0D00002101014304044D01024A00004B01024B00014D0103
4B00014901014E000262040871040D7804137A06167A05156D040D6001046E000781010D
87010C89010D8C020F8D020E8800088901088C00098C00098C0108900007960005A40208
B0050BB4050DB3030EB4020EB90611B8040FBC0712B9050EB7070FB4050CB3040AB2060C
AF0709AF060DB1060EB1060FAF040DB2040DBB0D16BE0F16BE0B11C00B14C20B15C30E19
C00E18C0101BBE111FBB1322B91528BD192AC2192AC71A2BC91928CD1828C91825CA1725
CC1725CD1724D01926CD1524CC1522CB1421C91420C9131FC8151DC5141DC2101CC00E1C
C00F1EC00F1EBE0E1DBF0F1EBC0E1CBB0C1BBA0D1CBB0B1ABB0915BB0612BB040FBA0610
B3020CAE030BAC020CAA010CA9010DA6020BA4010BA4020BA4020CA0000A9E010B9C010C
9D020F9C020E99010D98000B9D020B9C01099B01089901079700079A02079D03099C0108
9C01099E020C9D010AA1030DA2020CA3020EA2010DA4020DA8040EAA050FA7040FA4030E
9F020B9801099402098F02098501077801047401047501057502067102056201035D0001
660405660A07701F1600FF0000FF0000FF00
00FF0056B2146C3219260B070E00002702024703045002014C00004D01034D01014B0102
4701024500015A02046E02057401047D01097F010A81010B7C030B6C02066C010881030E
86010D8A020D89010B8D030D8800078B00098D010A8A01088C00059300079C0108A80309
B3060BB4050BB5050FB5040EB6050EB6020DB90510B90510B4040CB5080EB5080DB1050C
B1070EB20710AD030CAE030CB20610B5050FBA0A12BE0E18BF0D13C30C14C20A13C40D16
C20E14C30F14C00D12C40F17C51019CB141BCB1217CC1017CE1119D0111AD01218D01217
CF1218D11218D3141AD3121AD2121AD11119D01016CF0E15CE0F16CA0E14C80F14C90F15
C60914C70A15C90C16C30912C30912C10911C10811C00712C00714BF0614BB0411B6030D
B2030DAD020DAA020DA6000CA6020EA5030FA3020DA1000BA3000CA1000B9F010D9C000D
9E020F9C010E9A010E98020D99020B9B01099B01089A01079701079701089A020A990008
9A01089C010A9D020BA0010AA0000AA3020CA1000AA2010AA6050DA90710A6040EA4030D
A3030D9E020B9901099301078C01078202077701047201056F01046D0205670204630002
6501026506036C191000FF0000FF0000FF00
00FF0054B2137E482B1F0B070C00002801014B04045303024C01014B01024B01014C0102
4501034801026302047402057801037C000681020B84010982030A6C02066401057B030D
84030D87020D88010B8A010B8801078C00098D010A8C00089101089601079E0008AF080F
B1040BB2020BB4040EB90912B4040DB7030EB70610B60410B4040EB4040EB60610B4060F
B0040FAE020FAD030EAE030BB3050EB70711B70711BB0B15C00D16C20C14C30C12C20D13
C10E13C11017C00F16C10D16C61118CA1116C70E13CA0F16CB1117D1151BD01317CE1115
CD1013D21318D6151AD31017D41119D10E16D10F15D00E14D00D15CE0D15CB0D14CD0F16
C80911C80813C80A13C50910C2080FC20910C10711C00711BE0511BA0310B90410B4030D
B1040DAB010CAA010EA8020FA6010FA3010FA40410A2020EA5020EA5010CA1000D9C000D
9B010D9C020E9B020E97000C9A020C9B010A9A000899010998020C97010A950109940008
9700089900099E040D9F0109A2000BA3010DA2010DA3020CA5040DA6070EA60D11A50D13
A1060E9D030C99010A9701079000068700077E0106730105680003640103640103680103
680102650200630D0500FF0000FF0000FF00
00FF0053B3136B381A1905020F00002C00004E03035302014A01014801014B02014B0204
4001024A01036703047702067800037D000682010885010C81030C6802055D000376030C
81010D84010E88010D8B020D8A01098C00089000099202089201089300069B0106AC050C
B0040BB3020CB6060EB5030EB6040FB8040FB70610B5030FB70610B4020EB50410B2030F
AD020BAE020EAC010BAF020BB2040CB90914B70712C1101AC5121CC30B15C50D15C20E14
BF0D13BC0B15BA0A14BF0D18C40F18C91019C70E15C70E16C80F15CE141AD01317CF1216
D01215D41316D41115D61319D41117D20F15D20F15D41218D20F16D00C15D00D16D00E16
CB0B12C90A11C6070FC60A11C2080EC20910C0070FC10911BA040CBA050EB9050FB6050E
B3040CB1040DAC030DA8020DA3010EA1000FA2020FA5030FA6020DA5010CA0010C9B000B
99000A98010B98010B99010A9B010B9A020A980109970108940108930108920208920109
95010B99020C9C020B9D020B9F010CA1020CA3020DA2010AA2060D9D1213A12F29A63E3A
932222900B1295030C9601099200098A01088301087A02076F0104670103660104680104
6A03046A030169110800FF0000FF0000FF00
00FF0054B314622F121C04001800003B03045403035402014D01014A0002480101440202
3600014601026703057601067B010681020683000881010B78040C5E01055A010477040D
83030F89031188010F8A010D8E010B8E01099201089401099401079201069D0108AA030B
B0040CB5040EB6050DB5050EB5050DB8060EB5040EB60410B5030FB60410B5050FB0020B
AC010AB0020FAD020BB2040EB3030EB40610B60611BA0913C00F18C00C13C00B14C20D16
C10E17BB0B15BA0A14C1101AC20E17C50D16C70F16C80F15CC1218CF1218D11217D11118
CE0F14D00F14D00F12D00D13D51217D20E13D20F15D41118D31018D20E17CE0B14CD0B13
CE0D13CA0A11C5070EC60A11C3080FC3090FC20910C00811BB060FBB050EB9050FB7050E
B6060DB0020AAE040CA7030CA1010DA1010DA3020EA3020DA3020CA4030D9F010A9B0009
9B010A9A00099A010A9A010A9B010B9B010C98010A96010894010A92000992010894010A
96000B98000A9B010B9B010A9C020A9D010AA3040DA2040C9A0C10A53F3CE5A9A3E8B4B4
E09AA1A24249870B1290050C8E030A8701088300087E01087600066F0105670102610001
6702026A050379231C00FF0000FF0000FF00
00FF0055B4147341201C04001E01014303045704035401015002024C01014601023E0102
2E00014002036304057301057A01057F01087C020875030960020649000155010672020B
7F010C84010D86000E8B02108D010C8D00089201099201089401079500089E0108A80209
B0040DB6050FB4040CB3040BB3050CB90912B4040EB3030EB3030DB3020EB3040EB0030C
AD020EAD010DAC000CB0010EB3050FB50711B50710B80812BC0D14C00D13C30E15C40D17
C00D16BC0C16BC0D16C01118C10F13C40E12C70F12CB1116CB1014D31318D21116D10E16
D21114D31016D11015D21015D41116D51216D20F13D41118D10E16D00E17D00E16CF0F15
CA0B10CA0B12C70910CA0D14C70B11C4090FC1080FBF060FBC050FBC050FBB030FBA040E
B9060EB10309AE040CA9040EA3020DA0020D9D010A9C00089D010A9E010A9D01099C000A
9C010A9C010A9C010C9C010C9C010D9A010D97000A940109920008910008910107940109
96000999010A9C020B9B01099A00089D020AA1050CA2080F8E1115C98486E0BEC3A67380
802F42C86C7987252B89212383191B79050B7E02087E01077901067300036E0104640002
66010168040175201900FF0000FF0000FF00
00FF0056B4146A35141E03001E00004002035201035100024E0101480102410101390203
2300002C01015003036803066E030571040A6A04095B01074500023F000159020777030C
7E010B83010D87010E8C01118D010D8D010A8F0109920007950006990008A2030AAB030B
B2050FB3030DB2020CB3040DB3060DB50610B2040DB4040EB7080EB1030BAF030CAF030E
AD030CAE020EAD010DB2040EB20310B50711B3050EB4060FB90B12BE0D13C20E16C10E18
BE0E18BF101BBB0D16BE0F15BF0D11C60E13CB1115CC1215CB1012D51318D41116D41117
D41115D61319D31017D10F17D21317D31418CF1116CD1119C91218CC1519CC1318CE1418
CB1015C60B12C60B14C50A13C50A10C3080EC30810C30A12BD050CBD060EBB040FBA0410
B9050EB2030BAD040DA9030EA4010EA0010D9C00099B00079B000A9B00099B00089D020A
9B01099A01089B010A9D020D9D020D9A010A96010792010791000793010893010896010A
97000A9B010B9C020B9B02089A00099B010A9E020A9F0911841318DAA3A9DDBBC67F3747
8B15298C1D2BBE6F75D4999ABD7E8197444872070C7D050A7A01057800037601056D0103
6B0202680201741C152C860000FF0000FF00
00FF0057B4145B22031E01002201014203035001035001024C00024300013D0000390204
2001011E00003701014A01034F01035200074C01083F010535000244000567030B7C020E
80010C84010D88010F8C02108E020E8D000B8F01099301099701079D010AA6020CAE030D
B1010BB0010AB4040EB1030DAF010AB2040DB0020BB3040BB4070CB2050BAF030CAD010D
AE030CAE020EAC010DB0020EB2040EB2030FB0030DB40711B60C13BB0E16BD0D15BB0B15
B90D16B90E17B50912BB0C13BB0B11C30C13C90F14C90F13CE1014D10F16D31117D41217
D11115CE1015CE1219CC141CC8181EBF1C1FB01B1EA81D20B2302FB5332EB22C28B42421
BB1D1EBD1218C10D14C40B11C60B11C50910C1060FC0070FBE050CBD040DBB040FB7010D
B7040EB2030CAF040EA8020DA3000BA2000CA1010A9E01099B010A9A000A9C010A9D020A
9B01079A01079B02099A00089C020A990108950107920006930007940006970108980109
9801099A00099901099900089B01099F010AA1010A9E070F831319DCA6ACDAB3BC792432
94101D8C0F18AF6168DCB2B9683A42B8797F7427297D2023700509780206790104720103
6E01026901006C130B2E870100FF0000FF00
00FF0059B6145A24021B00002600014602035001024B00004601014301014001013D0303
2201011800002501003505033905043903083601092F000436000254010772020C7D010D
80010D83010D86010C8A020C8B020B8D010C8E00099301089801089E0009AA040CAE020A
B00108B1020CB5060EB50510B2040DAC0109AF030BB3030DB5050EB1020AB40610B1030F
B0010EAE020EAC010AAB010AB20710B1040EAE030CB0050EB50C13B80E17B90C15B60711
B70912B80C15B90E15B80A10C31118C50F17C50E14CB1116CF1115D3121AD11318D11419
CA1619C2191CB31C219F1B1E8D1D1F8B3434A46160C38C8AE2B1ACE8B7B2E4AFA8D79992
C77571AF4341AA1E1FBB1518C30D12C30910C0070FC0070FBE050DBC040EBB030FB9020E
B5020CB3040EAE030CA9030CA3010BA1010BA1010A9F00099B01099801099A010A9C0109
9B01089A00089B01099B010A9C010A99000997010A960109960009960108960107970208
96010798020997010999020A9D0109A00109A3040D9C040B881319D79CA2DDB4BD7C2331
950D19900B13974148DEB0B85F2D37935960A37273C48E8F691C1F6D0A0C720305710101
7101036A0001660C052F870100FF0000FF00
00FF0059B7155D28061D00002B01014C04045202014F0102490102460102460101440305
2C02011901003A2120A9908DA9929032161A2902092E00044701056B040D79020C7D010C
7F010C80000C84000B8C030D8A01098A01098D01089101099500089D0008A80109B0040B
B10208B3030AB60610BD0C17B3040EB0020CB1030CB4040EB6050FB5040EB4040FB1020F
B0010EB0020FAE030CAB010CAF0510B30811B40A12B60B13B60D14B50A13B70912BA0C15
B70912B80A14B90A14C00F19C20F19C50D18C60F16CD1419CB1217CA131AC4151ABB1B1F
9F1A1E841B1F883C3DA87173C9A5A4DFCCCAE5DBDBE6E0E0E5E1E0E7E3E1E7E2DFE6DEDB
E6D4D1E1BCB9C37D7BA83334B01217BE0B14C00710BF070EBE070FBC0610BD0612B7010E
B9040FB4020DAE010BA9020BA3010BA1010B9E00089D01089B01099701099A020C9B010B
9A00099800089900099E020B9E010C9D000B9B010A990109990109970108950107920107
9301079401079601099600089700079E030C9F020DA005118B0C17C67E86E4B7BF802B38
920C189309138F3038E4AFB768323D7E464FBA979BB4979B6F4447B5777A6716196B0509
7102056B010270160E2E870100FF0000FF00
00FF0059B8175726071D00002F01014B02025101005000024C01004A0102490201490102
3E02022501025A4247CCBDC6C3B7C038242D2D010844010762020B76020D7D010B7D010B
7E000B80010C83000B89010C8A01098C00098D010A92010B9500099C0009AA030BB4040E
B4030BB4030DB5050FB4030EB3050FB2040DB4040EB6050DB7060EB3030CB3030DB1010C
B1030CB0020EAE030CAA000BAD030EAF040EB1060FB40911B60C13B50812B50710B50A13
BA0E16BB0B16C00D19C3101CC20D19CD1420C81019C8151BC0181CAE1A20921B1D7F2626
8D5654C9ABA9E1D1D0E6DFDDE6E3E2E6E6E6E1E3E5E0E2E5E1E3E6E1E5E7E0E3E5E3E3E4
E2E1E2DFDBDAE2CFCED29D9DA2383DB0161EBD0C16BE0811C00812BB030EBB0410B6010D
B5010CB2010CB0020EAB020EA6020CA2010A9E00099D010B99010A94010995000997000A
9A020C9B010B9A00099C010A9D010B9C02099B00089B010A990109960106940007950009
9601089601079601079501089300089B020D9F020E9F020F950917A44753EFB9C28F414C
900F1B960611841721E09FA9773E497A434DC9AAAFAD9B9E8A7577BA9C9FA97D81722C31
69090E690204741A122E860000FF0000FF00
00FF0058B8175120031E00003201024F02035201004D01014700004800014B01014D0102
51060B481215290811462D3F371D2E37101D601C2463050C70020979010A7D010B7E000B
7E010980000A84000B89010D8A010B8C00098E010A92010B95000A9C000AAC040FB4030F
B3030DB3030EB60811B3060DB1030CB0030BB4040EB5060DB4060DB0020BB1030CB2030E
AE020BAD020BAD030BAA0109AC020BAE040DB20810B60A12B70C12B90B14BA0C15B60B14
BE101AC10F19C41118C30E19C5111BC01019B9161AAA1E21881C1B7E3534AA7F7CD4BEBA
E1D9D5E4E1DFE4E4E4E3E3E4E4E4E6E2E3E6E2E3E6E1E4E6E1E3E6E1E3E6E3E4E7E2E2E4
E0E1E3DFDFE1DFDDDCE4D6D4C29191982B2FB21118BE0912C00612BE0510BA020CB8020E
B4010CB3020EB00210AB020FA6010BA3020A9F020B9B010A99020B94000A94000998000B
9B000D9C010D9C000A9B00099B020B98010898010999010A970108940105940108950109
97010A94010994010995010993000A9A010E9F020EA3030EA009148D1924E49FA8AF6772
87111E970813870C19B6636F985C657C4A52C8ACB1A5949AB9A6AC8F777DB598A0AF8089
782B306203037319112E860000FF0000FF00
00FF005ABA195828092000003701025504055601024F0101480102490102480100500103
550108681D267B424F7341547D46577D34436D0D1971020C7501077901097E010C7F020C
7E010881000A86010C8C03108D010C8D000991010B92000B95010B9C010AAD040FB2030D
B4040EB4040FB4060FBD0E17B1050EB1030DB4040EB4060EB3060CB1040BB4070EB3060F
AD020BAD020BAD040BA90209A80109B00610B30811B40912B50A10B60912BC0C14BB0C15
C0121BC31319BE1217B9161CB51F2495181881231F864740B28E87D8C7C2E4DFDBE5E4E2
E4E4E3E2E2E3E2E3E5E3E2E7E3E2E7E5E4E9E0E1E4E3E4E6E2E3E5E2E3E6E3E4E7E2E3E5
DFE0E2E0E0E2E0E0E0E1DFDDDECECEB172749B1A1FB70D14BE0712BD040FBD050EB9020D
B8040FB2010CAF030DAB020CA8030BA6020CA1020C9C010B9C010B9A010B99010D9C020E
9C000D9D010D9C010C99010A9601089500079701079A0109980208920004910005920007
94010993010A92010993010993000997000B9E010DA3020DA30711940B16A4434FE59CA6
7D1E27871118A83940791B26BD747FA4717BBC9AA4A48C96B69CA5705158BC98A16E3A44
7F2F37610203670C0630880200FF0000FF00
00FF005ABA195E2D0E2500003E03035302025601024E01014601004800014B0001520102
5A02045F030C620D1B671626680D1D6F041376030E7500077400067801097A010A7B0009
7C010680010A86010C8C02108B010A8E000892010994010B98010A9F000AAE050FB3040E
B3040EB3030DB3050FB1030CAE030CB3050FB2040DB4060FBC0E17B5080EB2050BAE030B
AB0209AA010AAA030AAA040AAE040DB20612B10610B30912B20A11B10910B50C12B81117
B31316B11C1A9D1E1B87211E853934A27169C9B1A8DFD6CFE5E1DCE5E4E2E1E2E2E4E4E7
E1E1E2E3E3E7E3E4E7E2E1E6E5E5E9E4E5E9E1E3E7E1E4E6E1E5E6E1E3E4E2E4E5E1E3E6
E1E2E5E0E0E3DFE0E2E0E1E2E3DFE0D1B1B4993740B0111DBE0814BD050FBB030CB7020C
B8030DB4020BAE0109AA020BA8020CA5010CA2010E9D010C9C010A9B00099C010D9C000D
9C000A9C000C9D010D9B010B9901089901079B01099D020A990208940207910106930208
93020A92010A92010992010993000997010B9D010DA1020DA3030E9D0510900E1AB7535F
CB757F924247DB8C9273121E7E1726A24A5C7D3A4AAA7E8A9A76806F474EBE929B6D2F39
610A1066020366080331860100FF0000FF00
00FF005BBC1C5624092A00004503025602035201014A00014601004800014E0101530101
59010162020564010867020B6F010A77010A7A0109760006740107770109790208780107
7B010780010B86010C8C020E8E010A8F000993010B99010C9B020A9F0008AC030CB4040E
B4030DB4040FB1030CB1030CAF040DB1020DAF010AB50510B50710B70911B0050BAE040C
A7030BA4050DA0090CA20C0EA60A0DB10F16AF0E15AD0E13A60D11A81417A418199B1C19
90221C8B382FA16E63C8A9A2D9CAC4E3DFD8E4E4DFE2E3E1E3E4E4E2E4E6E1E4E5E4E3E8
E5E3E8E4E3E8E2E1E6DED9E0DDD6DED3CAD3C3BDC9CACBD5D8DEE3E1E5E7DFE3E5E2E4E8
E1E4E7DEE0E4E0E1E4DFDFE3E0DFE2DBCBCFAB676EA31823BA0914BE0610BB030DBA020C
B9040DB1010AAC010AA70009A6010CA6010FA2010DA0000B9E020A9C000A9C010D9B010A
9C01099D010A9D010C9D010C9B00089C01089D020A9B010A9B030C970108940006930107
93010892010891010890010791010795010A9A000B9E010CA3030EA0020CA00913940C1A
992736B65867C86E7C80111E8604138406176F091AAE717D8E666E895E67AA7E858B545A
5C0A1065030571130D33870300FF0000FF00
00FF005CBE1D4D1A042B00004703025603045001004A00014A02024E02024F0101530002
5A01015F01026001026400036D00077600087B02097500087400087900097A0108790109
7901077E010B85000E8C010D91010A94000B97010B9B010B9D010A9E0008AC050EB4050E
B4040CB1010CB0020CAF010AAF040CB1030DB1030CB50510B5040EB3040EAE030BA9030A
9B030A810409903230953F3B902F2B95292592241F942822912D27963E39984E48AC7269
C59D93DDC9C0E3DDD5E4E3DFE1E4E1E1E4E4E0E4E4DFE3E5E0E4E5E1E4E5E1E2E6DBD8DF
DCD2DADDCAD4DFC0CCE4B7C9E0A5B6C67F93652A414A3445ACAFB8DBE2E5DFE3E5DFE3E5
DFE1E5E1E1E5E0E0E4DFE0E4DDDEE1E2DBDDBD929695232CB20B16BC0710BD070FB8020D
B80410B2020EAB000BA7010CA6000DA6010FA2000BA0000A9D01079C01079B01089A0008
9B01089D01089F030B9D010B9D010A9C010B9B010A99000999030A980109970108960008
9501099401099201079402089301069701099B020B9E010CA2030EA0020CA206119F0511
9706158C06188905178D04128C010D8A020E76040EAF6A72956771A6727F96656F8A5860
722C3260050772150F4B4D0500FF0000FF00
00FF005EC01F4D1C072900004302015301025201005002024C00004E01014D0000520002
5800015C01015F000164010370010878010A78010A7400077400087D020C7C0109780007
7600077E000B85010C8C010D92000A97000B9B020B9D01099D020A9E010AA50109AE020B
B2050CB1020BAF010AB2040EB0020CB0020DB1030CB2020CB2020CB40510AC020AA70209
98050A6401034517178E7576D2B7B6D8B7B2D5B1A8D7B2AADDBDB4E4CDC5E7D8D1E8DFDA
E5E0DEE5E3E1E2E2E1DFE3E3E0E4E6E1E4E8E0E2E7DFDEE5D8D3DBD8CBD5DEC5D3E2B6C7
D792A5C86B80BE4D62B7364DB5253BB51E2FA11F2E44040F686066D2D8DBDFE4E5E2E5E7
E0E0E4E0E0E3DDDEE1DEE0E2DDE1E2DFE1E0CFB8BA9B434CAA111DB80811B8030CB8040E
B5030EB0010DAF020FAD0311A80110A6010DA4010CA001099C00089C01089B0108990007
9B01089C01089C01099D010B9E020D9B000A990009970108970008990109970108960108
95010B9300099401079702079800079B00099D010C9E010CA0030EA104119C040D9A040F
94030D8E030E91031092010C92010A8D010A79030CB66872A86B787429397C34429C666E
8A4B515A040671151061120700FF0000FF00
00FF005EBF1F501D072E00004503015502025401015302014D00004D01034E0101530102
5A02015D01016402046A01057101077501087500077401087400097A000A7E020C7A0108
7800067F010A88010B92030D95010B9A010B9C010AA1010B9E01089D010AA30109AA030A
AD020AAD020AAF010AAF010DAF010BB1030CAE0108AE0207AF0409B0020BAC0209AB030A
A1030A84060D4B010442202A887B88BCB8C2D8D7DBE1E0E0E2E0E1E3E2E2DFE1E0E0E2E4
E3E4E7E2E4E7E2E4E7DEDEE3DAD7DDD9CFDAD6C2CFDCB7C9D69EB1D4869CBB546CB6364F
B91F38C4182EC81225C80D1DCE111DCD1018BF161C70090F351D1FC3C6C9E0E4E5E2E4E7
E0E1E4E0E1E3DFDFE1DCDFE0DCE1E1DCE1E0D5CCCDA867709E1421B70A14B9060DB7050C
B4030CB0020CAF010DAE030FA8010CA5010BA4010CA2020D9D010C9B00099C01099C0109
9C01099C010A9C010B9E020A9D010A9C010A9B010A99020998020899020A970109960108
94000A9201099501089801089800089B010A9D010C9E010C9F020D9E020D9401098E010A
8701087D000481010A8A020B8F020A8B010982040C8D2532AB4B5B7507176E0613A3535E
9347505E04086B0F0A63130800FF0000FF00
00FF0030E0104E19053200004B03025903035901005601014D00014B01024C0000550101
5C01016101016701036C00057102057500067602067500077400067A000B7D010B7D010A
7D01058401098B020A93020C96020C99010A9C01099E010A9E010A9D010AA20209A9030A
AF040CB1030DAF010BB0020DB1020DB1030CB0020BAA0105AC0207AF010AAE030BAD020B
AA030CA2050E8F06106C0714520D206B3F5794778DB19EB1BAACBDCABFCCCDC7D0D1C8D0
D6C7D2CFBCC7CEB8C5D9B6C6D9A4B6D2889EC86982B8435BB3293EBC1D33C71A2CCB1424
D21422D6121FD20E18CE0913D00D13D00E12C91217971017320106939298DADEE3E2E4E8
E0E1E5DFE0E4DFE1E4DDE1E3DBE0E1DCE1E2DDDADBB78A90921C27B20D15B7060EB5040C
B3020CB2020CB0010CAC010AA80108A50009A4020EA1010E9D000C9C010A9A0107990106
9C010A9D000C9D010C9D020A9C01099C010A9B000A99010897010897010998010A960108
9301089301099701089600079500069800079A00099C010C9D010B9D020D95020C8B010A
8A060F7C01097A01098201098602097C020777030979030D8003108803107F030D71060F
700C136A030665060263110600FF0000FF00
00FF0030E0104A16033500004F02035C02035B01015901015101014E0101500102590203
5F02036302046500026A01056F01067601067800057800057801077C010B7C010B7F010B
81010887010B8C020A93020B96010A9B010B9C01099D020B9B01099A00099F0207A70208
AE030BAF010CAF040DB1030DAE020AAC010AAC020AAC030AAD0307AE0208AD020AAD020B
AA0108AC020CAC050DA50813960C1A840C207911297D213A7E2A448F4059AC627ACD8097
C8738AC86B82C15B71AE384FB0273FB61A30C1172CC91526CD131FD4151FD2121AD31119
D51219D30E17D20E17CD0A10CF0C10D10E11CC0F14B0131B50030964575ECACDD3E0E3E6
E1E3E7E0E2E6DFE1E4DDE0E2DCE0E2DCE0E2E0E0E2CDB2B68F3039A80E18B3030EB6030E
B6020DB3020DAF020BAC020AA80108A50109A4020D9F010C9D010C9C01099B02099B0008
9C010A9D000C9D010D9E010C9E010B9F020C9B000997010795000696000998010C940109
9100079201089401089601089600089701089801089B01099E010C9E010E96010C850005
87040B81020A7F040B83030C7C03096300015A00017003098101098A020B830108780105
7201046E0103640100600B0300FF0000FF00
00FF0000FF00521C073A01015202025E01025E01025A0001530000500102500100560101
5E01036000026401046500036A00027700067C02077A01087802087D01097D010883020B
83000888010D8E020D92000B96010A9C030B9E020B9E0209980008940008980008A8030D
AC010AB0020DAE030BAD020AAD020AAC020BAB0209A90107AB0207AA0106A90108AB010A
AA0209AB0109AD030BAF050FA9030CA70410AA0A17AF1422B11728B1182CB2192DB61A2F
B9192DBE182DC11628C81525CB131DCD121CCD0E19D21019D11016D21018D10E16D31018
D10F15CF0C14D10F14CF0B11D10D11D00D0ECD0C10C4171C73090F391D21C5C7CBE0E5E7
DEE2E4DFE2E4DEDFE3DFDEE3E0E0E4DBDCE0DFE0E3D0C0C49A535A9F121EB20512B6030F
B6020CB4010DAD000AAA0009A70108A40108A0010A9C010A9D010C9C010A9B02089C0209
9C01099C01099C01099E020C9F010C9D020D97020B94020892010797020A97020A920108
92000892000A93020A9301089600089600079700069901079D0109A0010D9D030E8F0108
8F050C8001067300037C030A7701076C03065B010264010579020981030A800308780204
7201026D0201640200610B0300FF0000FF00
00FF0000FF00511D073B01005D05046402025F01015A01015301005301024F0000520102
5D01056301046401036700036900027501067B02097500057300077E020A80010A84000B
83000A89010F8F011092000E95000A98020A9C01089C0109950007920009950008A4030D
AA020AAE020BAF040BAF040CAB030AA80208AC030AA70007A60107A90007AA030AAA0009
A80108A60107AA040CAC050CAD040BAF050CB60B14B70D15BC1018BE0F19C5121CC7111B
C8121AC8121AC71016CF1519CD1016CF1118CC1015CA1217CA1517CC161ACB181CCB171C
CA171CC71418CC1A1CCB1617CD1316D01014CF0C11C911179613183203069D9BA0DADEE1
E0E1E4E0E0E4E1DFE4DEDDE2DFDEE3DCDCE1DDDEE1DBD3D5A8747B901723AE0814B4040E
B4030DB2010CAE010CAB010DA8010BA6020CA2000C9F020D9C010B9B01099B01089B0107
9B01099A01099C01099B010B98030D8E030C83030A7E010687030992030C94020B940108
9200069201099201099101079300079601079701069901069C010A9E010C9C010B99010A
99050E90050E7F01067D02077D01057D03087004086000026A03076C0104710205720103
6D0101690201620200630D0400FF0000FF00
00FF0000FF004C15014100016907086702025E01005A0101560000560102510100520001
5B01036101036501036801046900047501067E020A7B010879000780010A84010B86010C
86000989000C90021095011099020E99020B9A010898010A92000991000994010A9D010A
A4010AAA0209AE050AB1060EAE050CAA0108AC0309A70107A70208A80007A70007A70008
A70209A50007A70209A70108AE050CB50A12BB0E14BB1016BA1217BC141BBB171BBC1C1E
BA1D1DB91D1DBD1B1AC51819C9141AC91319BB1113A71717B03630B6423CB64440BA4949
BE4F4EC05450C55A53D15D58C63B3CC4181ECC0A12CB0C13AD131A490204645B5FCBCED2
E1E1E6E0DEE4DEDDE2E0DFE4DDDDE1DCDEE2DADEE0DFDDDFBD9DA188262FAA0E18B3030E
B3030DB1010CAF020DAC010CAA000AA8020AA4010D9F000D9D010A9D020A9D020A9B0109
9800079801089A010B95030D84020973000693262C9C353971060A83040B900109930107
9301069300079301099201099201079401069801089901099C020C9D020C9D020B9C0109
9C020B9A050F90020A8E030A8401067E0206790408660002650104650203620101660102
670101680102630200630D0500FF0000FF00
00FF0000FF005216044E01016F06076801025C00005B0000590100580100540000570003
6002076101036602046800036E00047A010883010986010A84010983000B85020A85020A
8600078A010B90010D97020E9B020D9C010C9A020994010991010791010A90000A99010C
A3020BA80208AE070AAE030AAF040CAA0009A90209A60006A60105A60104A60107A60107
A70109AB040CA80108A90009B0070EB50A12B60F17AF151AA11A1B941E1DA7433FBF6761
BE6F68BC6B66B15451AB3B3AAE2929B11E21971415510303CBA19CE1BFB8E1C2BADFBFBD
E3C3C1E3C5C1E8C9C2EBC1BDE4989BAE2029CB121CCD0B15BE141C6B090E372125C4C4CB
DEDEE3E0E0E3DEDEE2DEDFE3DEDFE3DCE0E3D9DDE0DCDEE0CBBABE8D4048A0121BB0030D
B4020EB3010DB0010DAE000BAD020BA9010AA4010D9F010C9D010B9C01099D01099C0109
99000896010895020B88030A710002760108890D18A22D37A2343B7901078E030B940209
9501069401079301089100069301089300089601099801089E030D9C010A9C010A9C030B
98060E95060E99040D98030B8703077A01047F04097501047201056C02055D0001570001
60020266020263020165100700FF0000FF00
00FF0000FF005415045402016E04046701025E02015F01025901015301005601015C0103
6503076401036601036A00047201057E010786020A88000C88010C82010B800109830108
88010A8E030E8E010A95010C9D050D9C010B9801089401099101079001078D0006950109
A10309A90207AA0404AD0409AC030AAD030BA80108A70007A60106A80108A80107A90108
AB010AAE040DAC050CB0060EB0060EB00B159E1219720F116A2825AA7E78D2B7AFDCCBC5
DDD2CADDCECADAC3BED6B3AFD7A39EBA736D85433F270A0B7A7A7AD9DBDAE1E2DFE0DFDE
E1E0DFE3E0DFE3E0DDEBDFE1E7BFC4A83942C3151FD00F17C6111A8C10162D0307A09EA4
DDE0E4DFDFE2DFDFE3DCDEE1DEDFE3DEDFE3DCDFE1DBDDDFD2C9CD9A626B931420B00712
B4030EB2010DB0010CAD010AAC020AA70009A4010DA0010E9D010C9B010A9B00079C0108
9A010997020A8D030C7601077501068B040D92010D91030E8C08117B0005890309920108
93000794000695010795010897010A96010A9300079600079C010C9C000A9B0008950108
8200037C010490030B99040E8304086B02037604067E03057C0103760205630203510000
560000610302620200630E0500FF0000FF00
00FF0000FF005413025703016D03016601025D01005C02015701005300005600015B0101
5E01025E00016601036F01067401057E010786020C8A020E86010C81000A7D000682010A
8A020D8C010B8F010A96010C99020B9A000B9701079401069101079001078F0107950006
9F0107A80407AA0608AE090DAC050CAC030AAB0209AA0109A60007A80108AA0108AD020A
AC0109AB020AAA030AB30811B20711A10C1962060C442121B0A39EDDD9D4E0E0DBDFE0DE
E1E2E0E2E1E0E1E1DEE3DFDEE3DED8E2D8D1CBBEB8817D7B6C7273D2D9D9DEE3E2E0E2E3
E0E4E3E2E3E4E1E3E2E5E2E3E4CDD0B7626BB51922CB1018CC1319A7131B440206716A70
D0D5D9DEE1E4DEDFE2DDDEE1DDE0E3DEE0E4DADDE0DADDDFD9D6D9B08991881C28AB0B18
B30510B2020FAE010BAC0109AA0209A70108A3000AA0000D9F010C9D010A9B00089A0107
9A000895010A8002096400017D080E91020B96010B96010B90030B7F0105820206900209
9401099501099502089400089401099401099601089701079901089B010A9C010A98020A
8C030B7B010587030A92050E7601045500005A000077020688050A800307680002580000
5901006002025F02006310072C860000FF00
00FF0000FF005311005803026F05046802025D0000580001550101550101580101590100
5900006101026901027201057300007E010683010888000A86010B81000A81010884000A
8C010C90000C94020D99020C9C030C9801099702089300069101078E01088D0005930105
9B0206A50509A50207A80208A90209AA0108AB0209AB0009AA0108A90007AA0109AC010A
AE050CAC040BAB030AB40A12B00D15870C152F00027D7578D3D3D1E0E1E0DFE1E1E1E1E2
E1E1E3E0E0E2E0E1E2DDDEE0DFE1E2DEE1E0E1E3E1DEE0DFC9CECCC7CDCBDDE3E1DFE3E2
DEE4E2DFE3E4E0E3E4E0E1E1E4D9D9C98D92A42028C41218CC1217B5131A61080E3C2B31
C4C9D0DDE2E6D9DBDFDEDFE2DCDFE1DBDDE1DBDDE1DADCDEDDDBDDB99FA3872E39A20E1C
AF0613B20411AE010BAB0109A90108A70209A4000AA2000CA2010C9F010B9D010A9B0008
98010896020C7B050B59000175070C8F030C96020D96010B91030A7B01047901048E0308
9300069401079300069101078E02098E02099302099601079901089B010A9D010B9C020B
98020C8B030A8601068F050C82040A6802055700006E01068A050D850308710102680202
6502026101015B010067160F2A850100FF00
00FF0000FF005514015D04026F03026601015C0000580100540100530002570102590101
5C01006400026C020373010677010480020685020689020989020B85010C84010B87000C
8C010C93020F95010D9B030E9A030B9801089701059400069101098C01088B00068D0004
9401049D0207A00004A50107A80108AA0108AA0108AC010AAB0209AC010AAB0109AD020A
AA0008AB030BAA0108B10710A80A13700810200707A09EA2DFE1E1E0E0E2DFE0E2E0E1E4
E1E2E5E1E2E4DFDFE3DAD7DFCDC3D1D7CDDCDFDEE7E0E4E9DFE3E5D8DBDEDCE2E2DEE2E3
DEE4E4DDE1E4DDE2E2DFE1E3E3DEE1DCB5BB9E3239BE181ECA1215BB11157D0E1526070D
9EA1A8D8DDE1DCDEE2DBDCE0E0E1E5DEDFE3DBDDE1DCDCDFDDDCDECBBCBD934F5695101D
A90613AF0412AE020FAB010CA80009A60109A5010BA3010DA0010DA0000C9F010C9A0009
9B010B97030C79040A5000015D020681050D8D020A9001098A03097101036F0104890209
9201079501089401088F020980010575020481030791020999010A9D010D9C000D9D000B
9B020C91030A87020884010687020A82050E6801046C010484050B7F02067402046E0303
6B02026301015B010066160F2A850000FF00
00FF0000FF005A17016003027003026701015E02015902015401025101014F0001590101
6502026901046D01047201057601057F010884000788010884010B7C020C7B020C83020C
8B010B92010C95010D98000C98010A9B01099701089402078E01068A01058800028B0103
9301069C0107A10006A70209A70208A80108AB030AAE030BAE020BAF020DB1040DB1040A
AD0208AC0209AF040CB30711A6091469070E220C0EA7A6AADDE0E1DFDFE1DEE1E3DCE0E3
DBDFE2E0E1E6D8D1D9C39DAE904A63782F4D8C617AC2B7C8D9DCE5DDE0E5DFE3E6DEE2E5
DDE1E4E0E4E7E0E4E5DFE4E4E2E4E5E0CACEA55158B31A21C61114C00E139A151C330005
6F6D74D0D6DADDE1E4DADCE0DCDCE0DEDFE4DBDCE0DCDDE0DADCDCD6CED1A4727A891624
A60917AB0310AB020FA8010CA8020AA6010BA5020EA1010D9E010C9D010D9C010C97000A
9A000B98020C7C030A4A000143000362030A79030B82040B7A070C5E020463010485030B
91020994010896020A9102098202076C01026D01018802089601099C020D9B010D9C020E
97020D8A01088303097E010685020889030B7B04097301057D0408710001640001600100
6801026702015E010067160F2B860100FF00
00FF0000FF006119016503017604046801015D01005900005501015001014E0001580101
6702056B01066E02066F00027300057E010A84010A86020B7702086100035D010477020B
8A020D93010D96020D9A010D9B010B9B010B9601099001078A01058800068801058B0103
9101039B0006A60209AA020BA9020AAB010AAB0209AC0108AF010AB4030EB5060EB5050F
B10309B1040DB1070FB10711A609156E08111F070C9B9BA1DADEE0DFE0E2DCE0E3DBDFE2
DEE2E3E2E1E6D9C7D09B4D5FAA2035B11C358C1730601F38907E93D5D6E1DDE2E6DFE3E6
DEE3E6DEE3E6E2E6E7E0E4E7E0E4E7E4DBDEB77A82A72029C41217C40D12B0151C520308
4A3F45C0C8CEDAE0E3DADDE1DBDDDFD9DCDEDCDDE1DCDDDFDEDEDFDEDBDCB2919882212E
9E0A18A80410A7020BA7010AA7010BA6010CA4010CA0010C9E020C9C010A9B010B9B010B
9B000B9B010D8B060F5402053100013F00055201075802084E02054000005B010584020D
91010A91000794020896020A93030B86040A79000489020897020B9A010B9C020D9B010C
98020E8601087D01068304098702068D03088001057E030589080E7801046601015E0001
630101690203620201620C062D860100FF00
00FF0000FF006C1F066E07027703026800005D00005A01005601015201005201015A0103
6502056A01066A01046C010375000680020B87020B89040D7602085D01055200026D0109
89020C96010C98020B9B020A9C01099A010B9601078E01068801078900078A0206880002
900104970105A3030BA9020AA80108AB0209AD030CB0030CB2020CB70511BB0A14B4020C
B4050DB4050EB30911AD030EA808137E0D17210004838489D5D9DBDFE1E3DBDFE2DBDFE0
DEE2E3E3E2E4DECACFA6545FB31825C5121FBF1621A0192C4E0B206F6475CFD5DCDDE2E5
DDE3E3DFE3E6DFE4E4DFE1E5DDE0E3E2DFE1CFA7AC9C2931C3161CC80F15B91016750C10
291013A6ACB1D8E1E3D7DDDDDADEDFDBDEE0DBDCDFDCDDE0DADBDDDBDADDC4B1B7873B46
960E1BA4030EA9050EA7010DA7000CA7010BA4020AA1010C9E010C9B000B9A010B9A020C
9C020A9D020B92050E6704093801014212153A070B2E000429000233000160010789030C
93010B9100069201059501069501069001078B01078F01079601089801099C030D9B010B
9A020D90030D7E00048102068A02078702048002048102058B070C8002057202016A0101
680101670001630201610A052D850100FF00
00FF0000FF006C20066F08017704026A01015E01015A01015701005400005301005B0101
6301036601036700016D000177000381000887000A8B020C85030B7B040D6F0208770108
8D020C97010D9B020C9D020C9C020A9D020C9602098C01078700048901078D02058C0104
9002069300069D0107A6020AAA030AAC0209B0040CB3030EB5040EB5040FB60410B3030E
B3030EB2040EB20710AD030EAC09118D0E18310106625F67C8CDD0DDE1E3D9DFDFDEE2E5
DDE1E2DDDEE1E0D5D8B26F78AC1B28C40F1AC9121ABD151F8711212D0918A7A9B4E0E4E9
DFE3E5DFE3E6DDE3E3DFE2E5E2E3E6E4E2E4DEC3C7A3444DBA1820C70E13C00E13971419
3100037B7B7FD2DBDCD9DFE0D6DADDD8DCDFDADCDEDADDDED8DCDDD8DADCD2CACD945E66
8C1421A50715A6020EA4010CA6020BA50208A2010AA0010C9D000B9B000A9A0009980108
9901089C010A96030C800B10540B0DB58689A4808424070923000041000270030A8C0109
9101099000059301069501069401049301059401079601079701079A010A9B010D9C010E
9A020C94020C8401068001048602077E01027900027B0104770103790305750203710202
6C0101690101660202650D082B830000FF00
00FF0000FF00631B027108037A03026D01015F01015A00015500015301005301005B0101
6101026501026901027101027A01038000078601078D020D8B010A85010A82020A85010C
90020E99020E9B010D9B010B9C000B99010A9201098B01088801058800048A00028D0006
9101089400089A0007A60209AE030CB0030DB2040EB4040EB80410B8040CB7060FB4020E
B3030DB2030FB1050FB50B14AF0A11981019430207413940B9C0C4DEE3E6DCE0E1DDE1E2
DCE1E4DBDEE3E0DCDFCA9CA2A42833C5141ECD121BC8121DAB172243020D635A68D7DCE3
E0E4E6E0E2E6DDE3E4E2E6E9E1E4E6E3E3E5E5D6D7BA7278AD1C25C60F17C30B12AC121A
4F020853494EC9CFD2D8DCDFD9DEE1D6DADDD7DBDED6DCDFD7DCDED6DADBDAD6D9A9838A
811926A00917A3010EA4010BA30109A3010AA1010C9D000B9D010A9D020A9B0108980006
96000799000A98020C8B0710A2434B793C4585555F420F154901046C030887030A910109
92010890010790000694000696010696010597000597000598010799010B9B000C9C010C
99010B95020B8402067D02048102067C02047900047F03097401047302047102026D0201
690101680100630100670F092C840000FF00
00FF0000FF00681C037006017B03026D00006100015C00015701005401005201005A0100
6101026401026901027002057601037E01078601078C020C8D010A8700078600098A010C
8F010C97010D9C020E9E010E9F010D9B020B9401098E01098C01068A01048800048E0209
910009940109980007A6040CAD040FAE020EB1030DB4040EB8040CB90509B5030AB2010A
B1010BB1020CB3050FB2040FB0080FA20D175D060F24141BA3A8AEDBDFE2DDE1E2DDE1E4
DAE0E0DBE0E3E1E1E4DCBEC3A8454DBE1B24CD121CCE111CBD161F6B0A133A2430C8CDD4
DFE5E7E1E4E8E0E4E7E3E4E8DFE2E4E0E3E3E6DFDFC49296A1252CC5141CC70D14BB131D
6F0912321B21B1B4BADBE0E3D9DDE0D8DBDFD7DBDED8DCDFD6DBDDD4D9DBD9D9DBC0A7AD
7F2B36990C19A4020FA4010BA4020AA2010A9F020A9D010AA0030D9E010A9C00099A0008
9901099A010C9A010C95030E90121EA3404CA44A588825327C050F8C040C910109920108
91000591000693000793000695010797010899010898010998010A97010B9B010C9C020D
98000A9201078001047300027902057500017E020584020A7E0108710104650102630101
660100660100620100660E092D850100FF00
00FF0000FF007223057909017E03016F00006201005E01015900005800025801005E0101
6501016701016800016D01037200047C01078501088C020C8E020B88000A8700098C010A
91010B98010D9D020FA202119F010F9D020C97020B9100098D00068B00058B00058E0008
910107930109950107A0020BAA040DAF050DB2040DB4030DB8030BB8050BB7060CB2040B
B1010BB4050FB3050FB4040FAF030DA3061175091421020A84878ED2D7DBDDE1E1DCDDDF
DCE1E1DDE2E5DDE0E1E5D5D8BC757AB22029CA131AD01219C6151B8F121A2F0610A8A7AE
DBDFE3DADFE3DDE2E3E1E3E7E0E1E4DDE0E1E4E2E4D7B6BB9C343CBF1821CA0F16C01017
870D162A020984848BD4DBDEDCE0E3DADDDFD8DADDD7DBDED8DCDED7DBDDD8DBDEC7BBC0
89485191101CA30511A5030EA2020CA1040C9D010A9D01099D020A9D010A9D01099C010A
99010A98010A98010B99010D95020F8D05138A08178D061492030E93010B93010B930109
9300079300079501099301069200059501099801099901099A000A9A020B98010A9A010B
98010A93010A8A030A7901037C03077901037C02048202088102087603065F01025C0202
6903026A0202620100630A052E860200FF00
00FF0000FF00701F047B08018104017301026200005D01005B01005C01015D0101640101
6902036B02036801046B01047101067C01078501098C010C8C000B87000988010A8F000D
93000C98010CA00311A0010F9F020E9A000B9401098F01078C00058C01088C0108900107
92010A95020C94010A9B010BA6050CB0060EB3040EB70410B8030CB7030CB4030BB2020C
B3040DB2050EB1050EB20610AC030EA706128B0E1732010850505ABDC5CBDBE2E2DDE1E2
DDE1E2DADFE2DDE2E3E3DDDED5A9ACA62D35C81B21CF1218C81316AC1A1D4503096F676F
D4DADDDBE0E2DDE3E3E1E5E8DFE1E5DFE0E4E1E1E4E4D0D5AD5D66B31A26CC141AC61117
A4161F3E0107625C62D0D7DADADFE2DADDE0DADDE0D5D9DCD6DADED7DBDFD7DBDFD3CED3
996B74861520A20814A60611A3050FA1030DA1020DA1020E9F010B9C01099C010A9B0109
99010C97000998010A99010A98010B95010B95010C95010B96010A95010993000894010A
92000893010895020A9201088B01058C020893000999010899010797010797010998010B
97000B9300088E02098201058002068003067702057001067603077503065E0102550000
6602026A0202660101610702550A0100FF00
00FF0000FF00701C037C09018102027000006301015E00005C01005C00015F0202620202
6802026901026501016900047200067E020885020889010B8B020C8B000B8D010C93010E
93000A98000B9E010B9E020D9B010B94000B9101088E01098D02098E01098D000691010A
92010893000A94020C97010C9D020BAD050EB3050EB5030DB6020BB7030EB3020AB3030D
B1030CB0040AB0060CAD030CAD040FAA0411970B164A050C2F262EA3ABB3DAE1E4DBE0E3
DBDFE2DCE0E3DFE4E5E3E2E4E0C8CCA94D54BF1E25D0131ACF1419BF1A1E6D0C13402A34
CCD3D8DCE4E5DCE2E2DFE3E6DEE2E3DFE2E3E1E2E5E7DEE2C88F99A7242EC6141BC71015
B1121B5B050C403035C0C5CADBE0E4DBDEE0DCDDE0D7DBDED6DADDD8DBDED9DCDFD8D7DB
AA8C9380212E9D0C19A30611A2050FA2030EA3020FA3010EA1010C9D010A9B0109990109
99020B9901099A00089B010A98010994000793000895010A94010B93000A950108960107
9401089401079200059002088200027E00028F020999010A98010796000597000897000B
98010B9501089002088101057A00047D03086B02045300005A01016D04056602035B0001
650203690102660001640904590B0100FF00
00FF0000FF00771F028009018203037300006500006301025D01015B01015900005D0101
6501036600026300006801017201047D01078200068700088D020C8E000B8F020B92010C
93000A9B020CA0020B9E020D97010A93000A9102088F010A8D01088F020A8B0005900209
91010894010897010A96020C970009A20209AE030CB5040EB4020AB3020BB4040BB4040E
B2040DB2060EB1060CAC010AAC020DAB030F9A061064070D1E080D8B9099D7DCE1DCE0E3
DBDFE0DDE1E4DEE2E5E2E2E4E4D8DAC68589B32429D0161ED11219CB171E97151E310510
ACACB5DCE3E6DEE4E4DFE3E4DEE2E3E1E4E4E0E3E4E5E3E5D6B2B7A0343DC21923CB1219
BC10197F0E172D0C11A5A9B0D8E0E3DBDFE2DADDE0D8DCDFDADCE0D7DBDED9DDDFD9DBDE
BBA7AD813340970D1DA40613A2030EA3050FA0000FA1010E9F010B9C01099C0109970009
98010B99010B9A020B98020A97020993000794010A94010B94010A940209930007940107
9401059200049201059101058C02078601058D0106970109970108960107960107970109
98010A97010A8F01058301047500047201057206096204075500016303056A0306630102
6802046A0103660101660B065D0E0400FF00
00FF0000FF00792003830A028403027500016901006802036202025C01025B0101610102
6701046B02046701016800017000027D000687020C8A000C8E010D90030C8E010A91020C
93000A99020BA0040D9E030E95010992000990010891010A9000098F00098F0107920007
94000799020B9C030D9A020E98020B9B0007A7030AB2050EB1020AB2030AB2030CB0010A
AF040CAE050CAB030AA90109AC040CA70209A1060E83101826000563626EC2C8D0DADEE2
DBE1E1DEE2E5E0E2E3DDE0E1E1DDDDDDB2B6AB333ACA1921D4141AD2171CB71C234D030B
726771DEE2E4DFE5E5E0E4E7DFE3E5E1E5E6E0E4E5E2E4E5E8D2D6AE5862BB1F2BD11620
C8121C9D141D36000784858CCED8DBDBE0E3DADEE1D7DBDED9DDE0D4D8DBD9DEE0D7DADC
CDC2C791545E901321A50615A5030FA5030FA1010DA4040F9E010A9B00099B000A9A000A
98010A96000A93010994000895000895000795010B920009920008940006940006910006
9100069100059101059101069001078F0107900107930108930007930006930106960107
9801089701079201068C02067C02046E00027301057505085F00015B0001640103690004
6C01026D0202680202670D0860120900FF00
00FF0000FF00792104830C028603027801016B00006701006200005E01015F0101660103
6900046D01046B01026C000375010680010A8A020C8C010E8C010C8F020D8E010C90010B
92000B97020C9B030C99010D92000A92000A91000A93010B92000B93010B93020993020B
96010A9A010B9E020D9E030F9D050E9D010AA5030BAF050FB1030CB1010BB2020CAE020B
B0080FA9030BA60108A40007A50107A70208A203098D0A123B0207322C38A6AEB7DBE1E6
DDE1E3E2E4E7DEE2E3DBE0DFE0E0DFE7CED1B75962C5202AD6161ADB191ACE1F237A0E16
4B333BD8DADFE0E4E6E3E7E8E0E4E5E4E6E8E1E4E5E0E2E4E7DDDFC48690B32833CD161E
CF1219B81A2254040C61565EC8D0D5DCE2E5DCE1E4D8DDE0D8DDDFD9DEE0D6DCDFD8DBDF
DBD4D8A47981841624A40918A70310A6020EA5020EA4040E9E00079C01089C000A9D020C
98010896010995000A97010B98010A97010A95000A93000A9100089200089200078F0005
910006920106910105900106910108910107910208900209920209920107950209970108
9802099401079101068B01038303057A01057C01067E04066F01016502036602036C0304
6F02046E01016A010266090663120A00FF00
00FF0000FF00782403850D028A04027E0103700100690101650101600001600001670105
6A01056D01056F02057101067400057D020985010C87010C87010A8C020E8C000B8E010A
91010A95010B98020D94010B91000992000A92000A93010A92010A93010B94030A92000A
95020C98000C9C010C9D030D9B010B9C010B9F0109A8020CB30710B2020CB4050EAC010A
AC040DA9030CA40208A40108A80209AC030CAA050DA00D165D070F201019929AA4D9DFE5
DEE3E5DEE2E3DBE0DFDFE4E5E0E2E2E9DBDED49197BC2A33DC1E21E51C1EDC2025A61923
3F0A15C2BDC2DFE3E4E2E3E5E2E3E5E3E4E6E5E7E9E2E6E7E6E2E4DFB4BAAA343ED01E25
D9151BCA191F770C133D242BD0D6DBDCE3E5DEE4E5DBE0E1D8DDDED9DEE0D9DEE1D7DBDE
DDDCE1C2A4AD872936A30D1AAE0814AA0310A6010FA3010CA2010BA0010C9C010B9A0008
9A00089801099700099B010C9B010B98010A96000A94000B930109920109910107920005
9201069201079000068F00048F01059000088D030A83010586010691010A96010A950008
9400089401099203098502057601027A02048302078402087A0103700203650102630101
6D01037002036B0101640301630F0700FF00
00FF0000FF007B2304860D038903038002047301016D0101670101630102610102640003
6500036D020570030671000672010578000680010A82010B80000887010A89000A8E000B
92010B94000A94010B91020B8E010992010892010892000A92010892020B910208900109
94020C97010C9A020B9A010A9C020C9E010C9F010BA6020CAE030DB2030DB3040FAC0209
AA040CA8030AA6020AA40106A80108AF040DAD030DA909157B0812240109727682C8CFD8
DDE2E5DEE2E3DFE5E3E2E6E7DFE4E1E9E3E1F6CBCEC24B51DE2A2FED2729EA2B30D02F3A
67111DA18F97E4E7E8E6E8E7E4E7E7E5E7E9E6E7E9E6E7E9E6E5E7F4D9DDC1616AD82D34
E61D22DC1C219D161A3A0A10C5C5CBDDE4E7DEE4E6DBE2E3DADFE2DADEE2DADFE2D7DCDE
D9DDDFD3C2C7934751A2131FB10812B1030FAD0410A7010EA6010CA4000D9F000B9D0008
9C01099A010A9B010A9B000A9B000998010997010A97020A96010A930209930008930108
9200079100069000069000069101088F01078C02087F01037E000490020C9A020C9A010B
96010A9301078E01068101046D0001730103840207820105780103710304670204620001
6C02026E02016B0101660201600B0300FF00
00FF0000FF00822809890B038C03048301047601016F01026801026400036101025D0001
6101016A01056C01036C00056E00037600067E020A80010C7E000884010988010A8E010E
92020C92010C90000C8E010C8B0109900009900009910009910207910208910208900009
93010B96010C99010D9700099D020DA2020EA3010CA5000BA8010BB1040EB30610AD020A
AE050DA80007A70108A80108A90108B1030EB1020EB208159B101B45030E4D4552BEC3CD
E0E5E8E2E6E7E0E6E5E3E7E8E2E5E6E7E5E6F6E2E3DA8F91D34F51E15050E65D60DC626A
A95D65B19DA2F4F4F4E6E7E9E8EBECE7EBECE7EBECE7EAECE6E6E9F7EBEEEEACB2DD454B
F53133ED2728C9262854030CAEA2AAE0E5E9DFE6E9DDE4E6DDE1E4DCE0E3DBDFE2DBDFE2
DBDFE2DDD3D6AD6F79A11A26B70915BA0612B70511B50511AF050FA8000DA6020EA2010D
A0010C9D000A9B000A9B000A9B00099B010A9A000A99020B970109970108960009930108
9201089201089101079101079201089101079001078D02088B000894020B9C010B9B010A
9701089200058C00048702077C02067901038201057D02047001036501016903036A0002
6E01016D00006A01016605026A170E00FF00
00FF0000FF00862A088C0C038E03038502037601016F01026901016101015E01015B0000
6202036A02066A01036B01056C00057401087D020A7E010B7B00078100098401098A010B
8F020B90000C8E010C8F020E8901088C01098E010A90000990010891010A8F020A91010B
92000A94010B97010A99000A9D010BA2020EA3010EA2000BA4020AAC050EB0070FB2060D
B3070EB1040BB1030BB2020AB8050EBD0711BB050EBD0B13BA18217D132040202DC5C5CD
E4E8EBE1E5E7E5EBEBE4E8E9E7E8EBE9E8EAF0EBEBFBE7E7F9D1D1FFD7D7FFE4E4FFE6E8
FFEFF0FFF8F8FDFCFDF0F1F3EFF0F2EFF0F2EFF0F2F1F2F4F1F1F4F2EFF1FFDADEE7696C
F64340F73831E73835780C158C717CE1E4EAE1E6E8E1E6E7E0E4E6DFE3E5E0E4E6DEE2E5
DDE1E4E3DEE2CF9CA6A32230C20F1DC60916C20614BE0612BB0610B2030CAE030DA8010C
A4000CA1000BA0010B9E010B9C01099A00099B010B9B010B9901099A010A99010A970106
96000697020B93010992010892010791000693010794010996020A99010C9C020E9C010C
9A010A9600079301078F02098601068301068402057B01036C0001630102670202700203
7201017001016801016003016D1E1500FF00
00FF0000FF008125048B0C018E04018302027400016C00016901016502025F01015D0001
6101026502036600016B01046E02047702077C010B7C000A7900077E0009830009880008
8D020B8F010D8E010E8C000C8800088A030A8E020B8F010A8F020A8E010A8E0109900009
94000A9600099A020C9D020DA0020DA3010DA5020DA1000BA1020BA8040BAD030AB70A0E
BC080DC60D13C70C11CD0F15D11117D7171CCE1115D81B1FD72127B9252F651927C8B6C0
F2F2F5E7EBEEE9EDEEEBECEEE9EAECF1F2F4EDEEF0F6F4F4FAF7F6FCF9F8FEFCFCFFFDFD
FFFDFEFFFEFEFEFEFEFEFEFEFDFEFDFAFBFBF7F7F9F5F6F8F0F1F3F6F5F7FFE8EBF08383
FD5951FD4F42F84843A12029916571F8F7FCE4E8EAE3E6E7E6E8EAE1E4E5E0E2E5DFE3E7
DFE1E6E3DFE3E6BDC6AA3441CC1926D00D19CC0816C80714C10511C00712B7020DB3040E
AB010BA9010BA6010BA0010A9C00079B01079D010A9E020C9D010B9C010B9B010A9A0008
9B010A99000B95010A9201099000079101079301089600099A010B9D020E9D020F9B010C
9A00099801079500059001088400058001048302067C03057302046A02046401026D0203
7201017001016801006003006B1A1314C200
00FF0000FF008426078C0D038D03028001027101016B0101680100640101600001610103
5F01016001016401016D01017101027500067B01097900097A01087F010B83010A87000A
8A010A8D010E8D020E8A010B88010888010A8901088900088D02098E010A8F020A8F0008
9701099D010C9F010CA4020DA6020CA9000AAD030DAD030DA90109AE020CB4040DC40C13
CE1016DC171AE0171AE2161BE81D20EB2023EB2225F32A2EF33034ED3C43B03040BE8096
FEF7FEEEEDF0EFF1F3ECEDF1F2F3F5F1F2F6F5F6F8F0F1F3F5F7F6F5F6F8FAFCFBFBFBFD
FBFDFCFCFCFCFCFEFDFBFBFDF8F9F9F6F7F7F5F5F7F2F3F5F0F1F2FAF6F8FFD8DFEC7176
FA514BFC453BF43C37C332397F4451F4F0F6E2E6E7E4E7E9E3E5E8E4E7E9E2E4E7E0E4E6
E1E3E7E3E0E6F5D6DFB54A58CB1F2CD10F1AD10C19D00C18CC0915C60510C50712BD050E
B7030DB2020BAD010CA9020CA300089F0007A10109A2010BA4030DA0020CA0020D9D010B
9C010B9B010B97000993000891010791010995010A99010A9B010B9B010B9C010D9B010C
9900099901089700079301088701077C02057603066E01036F02026D0205600001660001
7201027001016801015F02016F1D18298400
00FF0000FF008D2B0C8F0D038A02017D02026D0100690101640101610101610001650105
6501056601036901037100057401047A01087B02097A010A7701097C000A85010D89010C
8D020D8C010E89010B8A00098A02088900088800088C01098F010992010A900007940006
9B0006A5020AAA040BAC030AB4060FB6030DBD050DBC050DBA030AC20710C60A13CD0B15
DB1319E71B1FEF2023F11F22F52225FA282CFD2E32FD2F34FF3B3FFC3D44F14554B93552
E39EBAFEEAF8F4EFF2F1F0F3F0F0F2F3F1F6EEEFF1EFEFF2F4F4F4F7F6F8F8F8F8F9F9FA
F7F9F8F7F8FAFAFBFBFBFBFDFAFAFAFAFAF9FBFAF9FAF7FAFCF6F9FFE9EFF199A3ED5559
F7463EFB4036F63733CB2F34692431D3D0DADFE6EAE0E4E7E1E5E8E0E2E6E0E2E5DBDFE1
DFE3E6DCDCE1E8D1DAB05363C4202ECE0F1BCD0C16CC0C14D00F18CB0D14C80B12C10910
BE0912B9050FBB0A15B0020EAC020DA9020DA6010DA5010CA5000AA7020CA8040FA5020D
A2020D9E020D9B010B97010A95010993000894000999010D9B010C9C010C9E020E9C010A
9C010B9B010A9900089501078C02077601055E00006101026D03046B0204650103690101
7201026F01016500015A00005F0E072B8601
00FF0000FF008B27098C0B018803017A01016A0000680100640101640001670102660003
6501016801026C01027101057501067C010B7901087501087001087A010A85010C89010D
8B020C8A010D8600098A01088C01078E000991010A94010C96000B9C020D9E030CA10108
A70107AF0208B30307BF080CC5090DCB0C0FD00E11D31014D00C13D20E17D31019D7111B
DA111AE71A23F11F25F52024FC2729FD2729FD292CFC292FFC3134FA2F35F9353DEF384A
D4405BE989A2FFE4F2FFF2FCFFF5FDFFF3FCFFF2FBFFF0FAFFF0F8FFEEF7FFF1F7FFF3F7
FEF9FBFEFEFFFEFBFDFBF5F7FEF2F5FEEBECFEE5E6FFDEE1F9C8CCF0969BF16C6DFC5851
FC4C3FFC4538FD423ADE373A701B26C6BDC6E1EAEDE1E6E9DDE2E5DFE2E6DEE1E3DCE0E2
DFE3E6DEE0E4E3D3DCB56675BB2132CE1321CF111BC90C13C80D14C50B13C10812BF0712
BB0511B80510B70612B50612AE020EAA020DA7010DA8010EA8010EA9010DAA020CAA020D
A5010EA1010D9E010A9C010C98000B96000996010999010B9E020EA1020EA2010CA3030D
A0020E9F020D9D010B9701088E02087F02076902056400036F04066801016501016E0102
7301027101016901025C01005F0D062D8601
00FF0000FF00822506880B028502017800006A0000680102670001690102690102640002
6401016801026B02037001047600097D010B7C01097200056B000479010885010A8C010C
8E020E8B010B8800088B000892010A96010D99010D9B010DA2020CA7010BAB030AB0020B
B5030BC00810C4080CCA090ED30F10DF1817DB1513D81012CF090FCD0812CB0711D10C16
D00A14D30A15E4161FF01C21F11A1DF82223FE282AFB2729FA2C2AFC2F30FC3336FC363B
F63A44EB495BEE7286F38EA5F497ACF492A7F290A2F292A1F295A0F8A0AAFDB0BAFFC7D3
FFE2EFFFEBFAFFEAF8FFDFEAFFC9D2FCAAAFFD9F9FF99090F97F7DFD746EFF655CFF594D
FF5146FF4940FE413BF140447E1724C3AEB8EBEEF3E4E8ECDFE4E7DFE3E6DEE2E5DCE1E4
DBDFE2DCDEE2E7DCE3BF7D8BB12232C91320C90E19CA1017C60C13C60D16C10915BD0614
B90411B70512B50411B2020EB2070FAA0009A8000AA9010EAB0010AD0210AD020EAB000D
A7010DA3000BA101099E000B97010A9202089402089801089E010CA4020FA5010DA6030D
A80611A606109F020B9A01098D01058402057B04086C01026F03056E02046F0103760203
7701027101016A0102610100630D062E8500
00FF0000FF007E2306870A008401007A01016B0000670000670001690102690102620102
6000016700036C01057000067801077F010C7F01087A01057600067E01098601098E010D
90000D8D00088D000791010797010A9D020EA1020FA4010EAA030EB1040FB5050FB8030C
BD040DC2060EC7090ECF0D11D10D0ED00A09D6100DD20A0BCB050BC4000AC6020CC9040E
CE0912CC050FD60C15E7151DF51D23F82125FE2B2BFF3030FF3530FF3631FE3838FC3536
FE393BFB3E46F84C5AF55264F35566F85B6CF75B69F45B67F7646CF5686FF36D7AF2798A
F389A0FE9CBAFC97B3F4879EF07686F26870F76567F8615FFB5B57FF5953FD4D47FC433F
FE3D3BFF3B39F93334EE383F821424997D8CE5E8F0DDE3E7DEE3E7DDE2E5DDE2E5DADEE1
D7DBDEDDE0E4E3DBE2C58B9AA72334C21221C50D1AC60E18C60E18C60E1ABE0714B80312
B80413B60511B3020EB1010CB2050EAC010AA9010BA7000CA9000EAC010EAE030EAB010C
A8010BA6010AA40009A1010C9100078500048D02089801089E010AA3000DA70210A80210
AB0714AC0C15A5080F9A020A8D00068700058202077200026A01036B0204730306790203
7902027001016900016201006811092D8500
00FF0000FF007F2204890C028503017B01026D00016A0101670101670102640102610101
6101016800036E01057300057C010784020B84010783010882010887000A8B010993020D
97061196030D9401099B030B9F020CA3020DA5010BAA030EAF040DB4040FB4040DB4010A
B8020ABE0309C0040AC6050AC90508CD0607DA1512D40D0ECC080DC9060FC9070FC8040E
CE0913CF0B13D50E18E61621F31D28FA242BFD2C2DFB2A2BFC2D2BFF322EFD3230FE302F
FD312FFE3436FD3A3FFB3B44FA3D46FD414AF83C45F93F45FA4449F64349F64651F14655
EE4B61EE4E69EE4B67F14B5FF14554F44149F64144F94342F53C3BF93C3BF83637F52F31
F42A2CF62A2DF0272CDC28308213235E4153CCCEDBDEE4E8DDE2E5DDE1E3DCE1E4DADEE1
D9DDE0DCDEE2DED9E0B18390972131B71120BC0C19BD0B17C4101DC00C19B90615B30313
B40514B20410B1040EB1020DB0040EAD020DAC020DA7010DA8010EAC010DAC010CAB010C
A8010BA5000AA40009A1020C8F01077C000185010698010B9D010AA1000BA5010FAB0513
AF0B19BC1E27A70A12A0060D9402098B02078502087A01066700016401016F0103760102
770102700101690102620101650E082D8500
00FF0000FF00862905860B018203017B01016F0100690100630101600000600001630101
6501016C00047201047A010582010788020A8701078801088A01098D010A92020CA20E19
B11D27A50D19A10610A5040DA9050DA9030BAA030BAC030BAE020AB0000AB00109AD0006
B10106B90107BC0208C80A10CB080CCC0A0DD31614C80A0CC80A10C3080DC60B12C10610
C30712C40712C90B16CD0916D80F1DEB1C29EE1E24F12024F72629F72429F9292AF92728
F82827F92A2AF62A2BF62A2EF42C2FF42C2FF42E30F63234F43333F02F32F33437ED3237
EB3539E7343AE9343DE73137E73236E83438E93738E0302EDE2E2CE02F30E02E2FDB282B
DA282AD9292ECC2327C129307E1D2A3A2030B0B6C1D8DFE3DCE0E4DCDFE2DADEE1D9DDE1
D6D9DDD7DADEDBDAE0A68590831F2DAA1321AC0915AE0813B00814AF0513AE0513A90111
A7010FA7010EA6010CA9030EA6000CA7020EA7010CA5000AA7010BAA020BAC010CAB010D
A6010BA3010AA1010AA0010B97020B8701058A010799010C9F020BA10109A4010CA60010
AA0415B41220AC0D18A60A119A040C8B02097E00047E03077403066800026F0103760103
7702036F01016700015F01006A140D2E8601
00FF0000FF00832504850A018002007901026F01006701016101005F0101610101650101
6700016E01037802067F000783010788000A88010888010B8B010991020C9F0C16B01924
BF2731AF111FA90814AA050EAB040CAB020CA90108A80108AE020AB20109B4020CB20108
B7050ABE070DBF060CC4070DC1050ABA0309B00102AB0103AC0107AB0007AB0209AA0008
AB000AAE020EB20410B2030DB90512C90A19D81620D9151DDC1B21DE1D23E02226E3272A
E32A2ADF2C2BDC3131D83234D43537D83D3CD63E3BD54340D84A47D84D4BDD564FDA5A53
DA6259DE6C63E1716BDF6E6AE0726EE57976E57B77DC746FD46F69C05B56DA736FDC7673
D26E6EC06060B55758A55051854C525F50588C9398D5DCDFD9DCE0D8DCDFD8DDE0D7DBDF
D7DBDFD4D9DDDADCE1AB99A16F293490192599141C990E149D0D15A10C15A20613A20412
A0010E9F010D9E000D9F010D9E010C9E010D9E010C9F010BA4010BA9030DA8010DA70210
A2010E9F000B9E000BA0020C9D020C9201079501089D010AA1010AA40109A30009A6010E
A60111A40111A103119C06108D030B86050E7904097702057F04077600027801047B0103
7B02037201026700015F0100650F082F8702
00FF0000FF008425058509017E02017601017002006901036202005F0101600101640100
6900027201037B01058101088601088801088701088700078A0008980510A50B18AE0F1B
AF101CA70614A90510A8030EA8010AAE020EB0030DB0030DB2020CB6030DBA040FBA050E
B9050DB20107BC0810B9060DB10209A90107A102049C00029C00049D01069C0206990006
9900079C010B9F010B9E000AA5040FA8010EB00915AC111CB2292DB53738C14A48D05E5B
DD706CE4807CEA9391EFA4A3FABCBAF7B7B5FBC1BBFDC5C2FCCBC8FCCFCAFAD0CAF9D3CC
F9D9D1F9DAD4F9DDD6F8DDD9F9E2DEF8DEDDF8DDDCF8DFDBF3DAD5EDD5CFF4DCD7F0D7D5
EFD6D6E7CFCFE6CFCEDDC8C6D4C7C6CBCBCAC6CCCFD7DDE0D7DBDFDBE0E3D8DCDFD7DBDF
D6DBDFD7DCE0D7DBDDB6B2B48467698D53568D46478B3C3D8A30348B282E8A1A22900C16
9A040F9B010C9A010C9A010B99010A97010B97000C99000B9C000BA2020DA2010F9F000E
9E010D9C010C9B000B9B010B9B010A9A010A9B010AA0010AA3010AA5010AA4010CA50110
A502119F000F9B020F8901087500027A030B78080F6A00017A03067D04067B02047F0205
7F03057501026B01016200015E07012E8701
00FF0000FF008223058108027C02007401017001006900025F00015B01015D0201640102
6D01047601047C01038301078801078801068801068A00078F010B99020EA90916AD0914
A70610A1000CA2010BA8030FAB030DB30512B50510B4020EB4030DB4030DB6040CB4050C
AE030BA80108AA010BA80008A101069D02099901079600069301059201059102038E0005
8E010692000A93000997000B9A010D9C0310950715650109864C53D0ABAAEAC8C3F4D4CE
F6DBD7F8E2E0F4E3E2ECE0E1EEE7E6EFE8E8F0EAE9EEE9E8ECE7E7ECE9E8EBE8E8EAE9E8
E9E8E7E8E8E7E8E8E7EBE9EBEAE8EAECEBEDE9E9EAE7E7E9E7E8E6E6E7E5E3E4E5E7E7EB
E7E7EAE6E6E8E4E6E6E1E4E4E2E5E4DEE2E3DBE2E3DDE4E6DADFE2DDE1E4DBE0E3D9DDE1
D9DDE1DBDEE1DCDDE0D7D9D8D3D0CDD1CAC7CDC2BEC9B7B5C5ADADC0A1A2BD8C8F8A2F37
8F08129B030C9C010B98010A94000793010894010A96010C99010C9C010B9D020D9C010C
9B010B9A000A9A010B9901099A010A9900099C01099F010AA3000AA6000DA7010FAA0312
A502109D000D97010B8A030976010578020879040A6E0105720509680203670203770305
8002057A02046B00006200005E0501444902
00FF0000FF008126067E08017801007401017201036901035A0000530000580101620102
6D01037801057F00048501078901068A01068A00048D000894010C9E0410A70612A8040D
A6040EA1020DA2020EAB0512AB030FAE0410AF030FB0030DB2050EAF040DAA030AAB060E
A1030A9B0008A1040C9F01089601079201089101079200088F01078C00038B0103870003
89000690010B94010C9A010D9C020E9F04129A0C1A5F0514442D3BCECFD7E5E8E8EBEBEB
E9EAEAEBECEDEAEDEEE8E9EBEAEBEDEAEBEDEDEEF0EFF0F2F1F2F4F6F6F8EEEFF1F1F1F3
EDEFEFEEEEF0EEEEEFEFEDF1F0EFF1F2F1F2F5F5F6EDEEEFEDEDEEEAEBECE8E9EBEBEBEF
EBEBEFE7E9ECE6E8EBE4E8EAE3E7E8E1E5E6DFE4E6DFE4E8DCE2E4DADFE3DBDFE2DCE0E3
DCE1E4DDE0E3DDDEE1DBDDDFD9DCDDD8DDDDD7DCDCD4D9D9D4D8D8D4D6D6CFC6C88C545D
8A0F1D9D020EA0010C9C010C96010993010793000896000A98010B9A020A9A000997000A
97000A99010A9800099600099501099600089A01099E010AA4020CA90210AF0515B20A19
A804109E010B9801098D01087600037502057E05087301046D03085300004D00006D0205
8002067B01036F01016501006006025B0D03
00FF0000FF007C24057B07017902017301017201016C01035A0101520000560000630101
7000027B00048101068600068901068C01078F010593010797020B9D030EA2040EAC0A11
AD0C12AC0D15AA0F17A70714AA0813A80410A5010EA7020CA7040CA1020A9D01099C040C
8F00078E00069601079601069200059100099101089200089000099100078F00048D0005
8F000797010CA10510A60411A7040FAB0510AB0C17860F20370F1FC4C1CDE7EBEFEBECF0
ECEEF1ECEDF0F0F1F3F2F2F4F1F2F3F2F3F5F4F5F6F6F6F7FBFCFDFEFEFFFDFEFDFFFFFF
FDFEFEFDFDFEFDFEFEFDFCFEFDFDFDFBFBFAFBFCFBF8FAFAF4F6F6F6F6F7F5F5F6F2F2F5
F3F3F5F5F7F8F1F2F4EBEEEFE8ECEDE8EBEDE3E7EBE1E5E9DEE5E9DCE2E8DCE1E8DDE2E7
DAE1E5DAE0E6D9DFE3DAE0E3DADDE2DADDE2D9DDE0D7DCDFD4D9DCD3D7DBD3D1D59B6F79
891424A60615A80110A4020E9B010999000999000A9B010C9C000C9C010B9C010C9B010D
98010D97000B97010A94000893000896010A99010A9E010BA4030FAC0715B6111EC01C27
B2101AA2030E9B010A90020A7801046E00027A04097201046F04066405075600006F0307
8103067C01027201016700006307025D0E02
00FF0000FF007D25067905017601017201017201007103036302025C00016301026E0103
7801038001058200058801088C01088B000791010796020999030997010AA0050EAA0B14
AE1117B41B21B62228A7121CA20814A10311A1030F9D030E9600099100089001088D0109
8700068800069101079400069600059B00099C020A9A00099901089D00099A00069E0109
A2010AA7020CAE040FB40611B70510C10D17C3111AB31C2A58091CCBB9C8F7F5FBEDEDF2
EEF0F3F9F9FBFDFCFFFEFDFFFDFCFEFFFCFFFEFDFFFFFCFFFFFCFFFFFCFFFFFCFFFFFBFF
FFFAFFFFF9FFFFF8FFFFF8FFFFF8FFFFF6FFFFF5FFFFF5FFFFF4FFFFF4FFFFF4FFFFF2FF
FFF1FFFFF1FFFFF2FFFFF0FEFFEEFEFEE8F9FDE6F9FAE1F4EDD9ECEAD8EEEADCF2D9D0E4
D9D5E7D4D3E3D2D4E1D2D5E1D4D6E2D4D7E1D5DAE1D6DCE3D4DAE2D5DBE2D4D3DAB98D9A
8C1829AA0615AE020EAB030FA3010B9F000AA0010BA1010DA2020E9F020D9D010C9D010D
9B010D98010C96000995000895000997010A99010B9C010CA20311AA0917BA1B26BD2029
B2141EA509139B040E8F030B8003087700057C030A6C00026B0103700508670002780206
8402058101017701026B0101670602610F03
00FF0000FF007B21057905017701017400017701027700026F01026A01016E0102760105
7E01058201068401058A01088D02088C01088F020792010A92010993020B9E0713A00612
A20A14A8121DB01F2AA3111E98051197010D96010B95020C8F01098C0009890107890007
8900068F00069801079F0008A40208AD050BAD040AAE0408AE0207B4040CAF010AB5040E
B8040FBC0712C00A13C60F18C60D18CF121FD0151DC91C288C1026A96A87FFE4FAFFE3FB
FFE7FDFFE6FDFFE4F9FFE3F9FFE4F8FFDFF4FFDEF3FFD9EDFFD8E8FED4E3FCD1DFF9CFDF
F6CBDBF2C5D7ECB4C8EAADC1EDABBFECA2B6EA9AAFEA94ABEA92A7EC92AAEB8CA8EA84A2
EC85A4E8829FE8809AE87B99E77797EC80A0E47898E47799E0799DD97AA1D37BA4D184AA
D28EB0D598B6D7A3BFD6A7C3D7ADC9D1ADC6CCADC4CDB2C8D0B9CFCCBBD2D0BCD1D299AD
94172AB20918B5040FB1040EAD050EA7010AA7020BA6010CA5010CA5020FA0010C9F020D
9C000C9B000B99000999010A97010999010A9900099B000C9F010FA60514AB0B19B0131F
A90D199F051191020B8000067F040C81040D81050D750106710103720305700002810206
8801048400027A01016F0001680401600C01
00FF0000FF007A20047805007701017801017E02018102037C02027501017301017A0104
7E01048200048500048A01068D02088B01088801068B01088A01078B01098F010D930210
95031299061798081796041694021293020D91000992010A8F01088E01098E010895010B
9B010A9E0008A70208AF030AB40509BB080CC61212D11918C50C0FC70C12C10710C50A15
BF050FC10712BE050EBF0711BD0511BE0512C40A16C20D1AB10F23AC284BBF517BB64B79
BE4D7CD15787D65A86DD608AE2698CE36A89E36D87E57085E37782E48086E2878CE18E96
E29CA9E5A5B6E3A0B0E398A5E59099E98287EB7478ED6B6DED6065F15B63F15562F04D5B
F14C5AF14C58F24753EF3D4EF03C4FEF394DEC3449EA3148E42D46DC2945D42445CD2645
C42443BE2444B92849B52A4CB12B4FA92D4EAE3B59AB405FAD4A6CB1597EBC678AC85E7A
9E0B1EB30513B4010CB2020DAB010AAB010AAA0109A90109A70109A8020DA7020DA5020C
A2010CA1010C9F00099D01099B000B9B000C99010B9B000C9F020FA30412AB0B19AB0E1B
A60A179C020F91020C7B00076E02066B03087201077901067C02067601037B0103880205
8A01038500027C01027201006C0401650D04
00FF0000FF007720037606007701017A01008201008801038801028001007900007B0002
7F00048601078701058700048D030A8A01088702078603098000057F010781010A85020F
85010F8D03129707159F0C1A97041298041096030D9401099301089601089C020AA6020D
AE050FB0020DBA070FBD070EBE080DBF080CC60F0ECE1614BD0407BC0309B70107B7010A
B5000AB4010AB5000ABA010EBA010EBC030FC10612C30713C60B1BCB132ACD1A36D72442
D92342E62D4EF44160FD536EFF5A6EFE626EFE6B71FF7977FF867CFF9689FFA89DFFB8B6
FFCED5FFD7E6FFD6E6FFCEDBFFC1C5FFA19CFF877EFF776BFF695EFF5C56FF5653FF514E
FF4D49FF4E48FF4542FE3C3DFE383AFF3537FB2C30FA272DF9272FF11F28EC1B28EA1C2B
E31A28DE192BDB1A2ED7172ED0142CCB142AC31225BD1125B71029B31231AC0F2EAC0A25
B30619B6020FB4020DAF010BAC000AAB0009AB0109A90008A90108A9010BA9030BA8020C
A7010DA5000AA30109A000099D010A9D010D9D020D9B000C9E010EA20311AA0B17AF131F
AA0F1BA0051295030E7E01086100014F00005F0206740308790409790205800203880205
8901038601017F01007601016E0300680F04
00FF0000FF007722027306007901027E01008701018D01029001018D0101870102830003
8101038802068601058301048903098801088000047F0007790004780106790007760008
720008840714A81D29AF1B28A20B179C05119A020E99000B9B0108A1010AAB040DB0020C
B3030DB2010CB6040EB7040DB8030CB50106B60203BF0907C00A0BBB0309B90209B50009
B8030FB6010DB9030EBC0410C20814CC101DCD1119CE0E18D8151FE51F2AE9222CE21C27
E82430E42232E32837EB3442F23E48F8484CF5494BF75451FE625CF7615AF66763F1686C
EF6C79EF6C82EB677CEE6578EE5F6BEF5356F54E4BF64742F63F3AF93A38F83636F93333
F93231F73030F3292AF02526F02425EE2223EB1D20EA1B1FE5191EE1161CDE141ADA111A
D20F17D1111CD0111FCD0E1CCB0C1AC80A18C50A16C10916BF0817BB0718BA081AB60314
B90514B70410B70511B1020EAC000CAB010CA9010AA90009AB010BA9000BA7010AA8010C
A7010CA6000AA6010BA3020A9F00089E01089C000A9C010B9E010DA20210A40413AB0D1C
A80B1AA3081695020E85010976040B5B01035801036100026200026E01047F0206870104
8801038701027F01017801017307026A1103
00FF0000FF007828077407007D01008601028E02039102029601029801039502058B0003
8401038602068202058102078101088201087F02057C01067A00057B00067D0209790109
75020A7E0410A31D2AA6131FA00A169C04119C020E9F030FA0020BA4010AAA020AB0010B
AF0009AD0008AF0109B2010BB4010AB80309C00B0BCE1814CF1A18C30C11BF0911BB0712
BC0814B90611B80510B80511B4030EB80612BC0812BE0711C50A15C80B16C70D18C20714
C40D1BBE0918BD0A19C3111DCE1925DC222EE62833EC2C37F4353DF6393FF83C41F73F42
F84046F93F4BF73C47F3363EF7383DFA3A3BF83835FB3632FA2E2EFC2C2DFC2B2AFD2C2C
F9282AF01F23EE2023EB1F20E71C1EE31A1DE0181EDA141CD31019D11018CF0F18C80C15
C60E19BE0A17BC0916BC0915BB0713BA0713B50310B20210B20312AF010FAD010CAD010B
AF030DB1040FAF040FAA020CA6010BA6010CA7020BA6010AA9030EA9020FA8010CA6000B
A6010AA6010AA30109A1020A9F02099E01089D00079E010AA0010CA0000DA20111A20213
A003129D021196020F8F000B8B040D7503076401026602046301036901037C0205850203
8701028501027F00017801017106016C1502
00FF0000FF007829097505008101008A01019001009200019902039C01049D0306960307
8701037C01037800027B02057B01057D00067B00037C000680010785010987020A900812
950E1988051295101B96071494020D95010C96010B9B010CA1010BA50007A90007B20309
B3030AB00109BB0810B8030DB5040DB7070EB6070AB40709B0060AAC0309A70109A8020C
A4020CA2000AA4020BA3010CA0010AA0010CA5010FA8000DAD020FAF0310B30815B40716
B30716B00615AF0614B40B15BC0E1BCC1626DB1E2BE7222DF02730F62D34FB3838FB3C38
FC413CFC3C3AF93936F93833FB3A34F93933FC3A35FB322EFC2D2BF82726F82724FD2D2B
F42424F12023F22225E71A1DE3181BE1191FDB161FD91621D0111CC90E18C80F1AC30D19
BD0C16B30612B10511B20711B30611AF0510AA020EA9020FA8010EA7010DA4010BA40108
A5000AA6020DA2000C9F010B9C00099C00099D00099E000AA1020DA5020FA6000EA5020E
A3010DA2020B9A01079301069701089C02089D00079F010AA0010BA1010CA20210A30514
9D020F9A000D97010D93010A91020A8203087101037303066F02046F00027A0103810204
8001017F01027D0102790201740A016C1600
00FF0000FF007B2A0D7B08018902028F01029401019501019903039E07089B0708940307
8702057700017300037601037901037C01067C01058001088601088A020C8D020B91040D
93060F8D020D85000989020B8B01098D0008910107990008A40209AD040BB00208B60609
B6060CB2030BB80911B1060EA50109A10109A000079B0007990007960007920007920008
91010790000891000794000B95010B99010E9D010E9F010EA40310A90412AA0411B10818
B20815B50815B80B17BB0C17C00E1BC81321D61A26E7262EF22F35F6383AFB4944F84D43
F64F45F54F46F45148F65149F34D42F64D41F94E41F13A2FF7382FFC3832FB3530FB3430
F8302EFB302FF72B2CF02326E91B20E61A22E41C26E11B25D5151DCF121BCC121BC50E16
C00B13BC0A13B80913B30511B10410AE040FA8010CA6010BA6020CA5010BA2010BA1000A
A2010D9F010D9B000B9900099800089800089701079700079900099C010D9F010E9F030F
9C010C9D010C9401088900039001069801099C01089C000A9C00099D01089C000B9C010D
9B020D97010A9200079101059000078501067700017601027400027600047A00047B0103
780101790101780002730201720D026A1900
00FF0000FF008231117C09018E04039502029A02049B02049705038D05057F02017F0306
7F02067500017200027701057B01047E0107800108810108840106870108890108890007
8B01098B010A8701078701078801078C00069301069B010AA5020AAE030CB7070FB5060E
AB030CA2010B9E020998000792010791000891010A90000A8E00088A0007880006870006
8800078B00088C01089100099300079A010BA1020EA4010EA7020EB30917B00412B70613
C4111CCA141CCF181DD51A21DB1F28D81F29DF262CEF3A3CF74D4BF76057F87364F67D6D
F38879F38F85F5978FF4968EF39085F48876FB846DFC725BFB5F4FFC5449FF4E46FF4A42
FD423EFD3E3BFC3A39FC3738F92F33F62A30F3262DED2227E92226E21D22DE1C22D7171D
D11319CC0F17C60B15C00713B90510B50611B0030FAF020EAF030CAC020DA7010BA6010E
A3010E9E000D9C000C9A010998000799000797010794000693000795000A97000A98010C
98010B9801099201088E000692010898010B98000999000999000999010896010895010A
95010A9201078E01038C01028D01048B02068201047F01047B00047B01057B0104750001
7200007401017401026D0100711205681B00
00FF0000FF00893A187C0B018D0201980102A005079B04058E0504800A0BAB43457B1316
7202047401037200017401037B01047E01067F01067D01057C0004810005870108880109
89010A8901088701078701068702048D01079401089D020CA4020DA8010DA9020CA80410
9A010B93000A8D00078F010A8901088801088A00078D00088D01098A00088B00078C010A
8E0008900009940208990209A00208A8040CAF020DB70612BB0711C10A14C80F18CF121B
DB1A21E9262CF02E31F7383DF73940F73F48FD4F53FF5F60FF736EFF978BFFAF9FFFBDAF
FFD6D1FFDEE3FFE1E7FFDEE3FFD6DAFFC1BEFFADA2FF907FFF786BFF6861FF5752FF554F
FF4E4AFF4947FF4647FF4446FF3A3DFF353AFF3236FE3035FB2E33F82C31EE2429ED232B
E72028E51F29DA1621D61520CE121CC20A16C00915BC0511BE0712BA0711B3020EAD010D
A9010EA5000DA2010CA0010B9F00099D00089A010697000596010797010999010B9A010C
99010B97010895010893010994010A95010C95010B98010B98010B97010C93010B910009
9000088D00058900018A01028B01038B01048901048501058001057B0003790102770102
7400017201017202016F05017216046A1C00
00FF0000FF0094471C7810018C05019C0305A70A0B9905058101019421239A29307D0C13
6E01027B02057A01037600017A00037E01057E01047900027A00027F0105840107850109
8501098701088803098B080E96141897101695061198020F9D020FA204129E020F98000C
91010A8A00078900068E030C8901088C00089000069500079700079800079A01089E0008
A1010AA3020AA50209AB030BB1030CBB0711C70D17CC0F19D5151EDD1D24E72329EE272E
F0292FF63138F7323AF7353FF63744F63948F7414DFB4B55FC5B61FA676BFB7A79F98081
F4858FF48698F38297F17B91F07285F06674F66066F14F4DF84846F43C3CF83838FA3837
FC3939FC3638F93134F92E33F92C31FB2D32F6272CF6272CF4262CED2027E81D27E81D29
E01822DF1823D8121EDB1824D1101BCC0E1AC70A19CA0D1BCA0C19C10612BF0713B80310
B4020FB1010EAE010EAA000CA9010CA50009A000079D00069D02079D01099F020D9D010D
99010B98000896000695010990010A88020B8B020C9A05129D03149B031594011091010B
8F01098C00058701028700028B01048D01048D01048A01058301047D01027C01027C0002
780103720000700200750C037117056B1F00
00FF0000FF00429D02751B02830A019A05059F05079303037C01017D030688050B810409
7000018001048803058101037C00027F01048101048300058100038001058001057F0006
81000889040E98121DA01C28AC2D37A11F29970F1B96061595000D94000C92000A8F0009
8D01078C00078D000593010A96020A9D030BA40209AB040BB1070AB70C0FB3070BBA0A11
B70811B80913B90A14B70811B3040BBD0B14C50F18CA0F1AC70A14C60914CE1019CE0E19
D1131DCF111CD31420D41323D31625D51525DA1A29E82533EF2A37ED2C38F33943F6434A
FA4C55F84B58F54453F33C4CF43948F73943F7373BF43030F82F2EFD302DF92924F92723
FB2A27F82727F42224F21E23F82429F21E23ED191FEC1A20E6161CE2151BDC131CD7121C
D00D18CF0E1ACD0E1BC70915C20512C30815C00614C20715C10713BE0511BB030FBC0411
B80410B7020FB60210B4030FB1020CAD020BA80109A50108A40108A40108A5020DA2010D
9E000B9C01099A01099601088C010A7500037B010A960617A1091DA0091D9C081995020F
9000098C00058801048700058B01058E02059002068C02058401027E00017E0101800202
7D010376010172040179150A671501349000
00FF0000FF004FAF0A9D56287C18078F08049102028902037701017A02038A0307820205
6E00008101059202058F000387000286000290030894040A90050A8602077E01047D0106
81010A8A0311970F1E9D1627A423329C1A28950E1C9106138F010C8F010B92010A93010A
95020899020A9B0109A1020AA7020AB0050EB6080FBF0E13C31214C61919BB0D11B5070E
AD040DA50308A30108A400089F00059F0108A5010CAB020EAF040FB00310B10210B50412
B60410BA0512BD0512C60B19C70B17CB0B17D8131DE1161DEF1F27F6262CF72B2FF62F31
F83736F93A3DF6393CF7383AF73637F93635F83531F7322CFC342CFB3129FB2C22FB2B22
FA2C27FB2D29FA2A28F52222F82324F72222EE1A1BEC171AE81419E61519DE1115D50D14
D00C15C80813C70B16C30814C00713BA0310B6010DB6010CB6020DB2000AB2000AB1010B
B1010BB2010CB3010CB1000BB0010AAF030BAB0109AA010AA90109A8010AA7010CA8020F
A5010BA3010AA0020C9A010992020A7F02077C00079404159D04199D04199B0417990211
96010D9101098B0107870005840105850203890004890104870102840102830202820102
7C010177010174070176170A621500369300
00FF0000FF002EDE0B7F410E6712018309038801027F0102730000750102870405830305
6E00008302069A0307A303089F04079801059902079B040A9202078501077E01047E0107
80010C8C0313950919990E1EA82331A11B29950B1A9003108B01088D000998030E9C020B
9D0208A10209A6030AAA040CAE050DAC020BAD040DAD050CA70408A10306990104970007
9400078E01038F000394010490010493000798010A9D000AA2010CAA0210AE020EB3020E
BA040FBD040FC90B14D5131CD61018E0181EE92022F22A2AF93331F73631F53834F13C37
F2463FF3504BF35955F15855F15652F4544EF65147F64A40FB4B3FF84234F83D2DFD4234
FC4036FD3E36FD3932F9312AFC312AFD302AF62823F82624F62122F31E1FEE1C1BE51517
DE1117D30C14CF0D16CC0B17C70A16C00712BC050FBB050EB7030DB4020CB4020CB3030C
AF010AAF000AAF000AAD0109AA0007AA0007AA0109A90109A8010AA8010CA8000CAA020D
AB010DA8010CA5010BA1020B9A01099101098E00099702109E04159C02169A01149A0111
99020E93010B8D01098502077501037402037E0105850104870104870102870102860102
7F0100790100750A036B1304671B0000FF00
00FF0000FF0000FF008548156312007F0B038101007E01027501017201018506087F0305
6E0001820306A5090DB1060BB3080DAE060CA202079B03088E01058101068002067D0108
83030E88020F920616990F1CA6202A9D14209206108F010C90020C92010A98010A9C0109
9B01069D00059E0004A00105A100059D00069900079600059300048D00038A0002890003
8B00048D01058A00028F00039401069D0108A6030CAA010DB2040FBE0814BF060ECA0A12
D30F15D91217E81E22EC2024EF2527EF2A2AFA3B37F94339FC5246FC5F54FB6C62FA7B72
F58881F59994FAAFACFAB4B5FAB0B0FAA5A3FB948CFD8174FE7264FD6859FD604EFF5F4C
FF5649FF5246FE4D3DFF4C3CFF4939FF4336FF3F35FE3730FD2E2BFD2C28FB2824F6221E
ED1819E6161BDC111AD9101CD30F1ACE0D16CC0D16CA0E15C30911C00710BC040EBB0510
B5030EB2010BB1010BAD0108AA0007AA0108AA0109A9010AA8000AA8010CA8020BAA010B
AC020CAA010BA70108A300079F00079E01089C010B9A010B9C010E9C011199021097010F
94010B9001098B00088201076B00026500027701067F00048401058600028A01028C0204
8702037D0201760B0467110050580000FF00
00FF0000FF0000FF004CAD0D6A1E00790E017E03018201017E03026F0000780505750304
6500007F0304A5080BAD0207AE0308B2070EA9050B9A01078D02077E00047B02067E020A
84040E880310910A1796101C900B148C040D8B02088D01098F020B91010A930208940005
9800069D00079F0004A10005A20004A100049F00069900049600039301009701029A0204
9D02059D00059B00059D0206A50209B2040ABB050DC70B15CF0E16D9121ADE1419EB1D1F
EE1E20F52727FB2B28FD3332FE3B38FF4843FF534AFF6057FF6F66FF827CFF918FFFADAD
FFCACFFFDBE4FFE3EFFFDEECFFD9E6FFD4DEFFB7BAFF9992FE7D73FF7168FD685CFF6255
FD574BFE5749FE5243FD4E3EFF4C3EFE4338FC3A30FF3830FC2D29FE2C28FE2B26FB2420
FB2322F01D1FE8181FE41722DD151FD50F19D4101BD10F19CD0C16CB0C15C30611C20814
BE0713B90410B6030CB4030AAF0008AD000BAD000BAD010BAC010BA90009AA0109AC0008
AE0109AD0009AA0008A50007A20005A10005A101089D00089B00099B010C97010A94010B
92010A8D01088A02068601077703076E00027801047F01048400048801048D01048D0204
8A0102810201780C036D15001DCA0100FF00
00FF0000FF0000FF0000FF00914C177111007C04008803028605047102026802036A0808
5F0000800304AA0F10A90407A50005A70108A9030A9E020A8C01067701036A0104720209
7E020C82010C83020C81010B8401098600078600068700058700068800068A0006900005
9C0109A7020CAF030CB2030AB7050ABA060BB9060BB00209B10709B20A0ABA0E0DBC0C0E
BA080DB8050EB80811CC2027C11018CB1016D00F15DB141BE0141AEB1C22EE1E22F72528
F62426FC2C2CFE2D2BFD312FFE3B36FE423BFA463FFB4E4DFC5758FB5B62F86169F76D7B
F4798AF6849CF2809AF17792EE7188F16F82F9707AF96668F85855FB5653FF5954FD524B
FD4E47FF4D44FD4A3FFB4037FC3D35FE3C34FE372FFC3029FC2825FB2522F31D1AF41D1A
F21B1AEE1A1DE4161DDC111BD8101CD40F1BD10D1ACE0D19C90B16C70B17C20815C00714
C10815BD0512BB050FB6010AB6010CB4010CB4010DB4000CB5010DB6030DB6020AB80309
BD060DB7020AB1010AA70107A20005A20106A301079E01069A0006990008970008930007
9101068C01058A01048901058002057B01027F01048101048301048701038900048B0103
8B02028404027B0E066F180000FF0000FF00
00FF0000FF0000FF0000FF004FAB0D751D007F09019007048F05037D04046A0D0C7E2F2E
5C06048D0C0CA6090AA70305A50006A50107A80108A8060E9402077300025900005E0002
7402097D0209830C11860C14830209820005830105810004810004860208850004920106
A30109B2030EBB040EC0030BC7070ECF0C13D21216C3080EC20C10C50D10C81012C50D11
C0070DBD060FBF0A15B3030CBA0811C30A12C3060ED10D15D00910DA1218DB131AD80E18
DF141CF12127F11E20FA2929FC322CFF3932FD3A33FD3F3CFE4142FA393FFB3C44F73D48
F53E4CF84656F64352F43E4EF63F4CF73E49F94146FE494AFE4645FB4240FC4543FD4543
FB3D3CFD3E3BFD3C37FD3733FC342EFD322BFC2E28FE2B28FA2423F61F1DF6211EF11B19
EB1517E8161BDA0D16D00A14D10E1ACC0B1AC40815BD0815B10713AC0915AA0613B10513
B6030FB90411B6020EB70410B5020DB8030EBB0410BD040DC20712C30611C70811CD0D14
D10F16C90A13BA040DAC0108A40006A50107A100059E02059A0004990106970005950105
9301058F00038E01038B0103860004860105870104850104840104840104840003870204
8B0608820604780D026F1A0000FF0000FF00
00FF0000FF0000FF0000FF0030DE0D782402800E01950D059405018E0709822124ECA8AB
6A1315930D0FA40609A70308A60208A50007A70107AE060DA7080D8500036F0103680002
7101077B01067701037B01058101068000048300058401058401038500048A0004970106
AC040CB7040FC30812CC0A13CF0A13D10C14CE0D14BF060DB7040AB5040BB1030AAF0208
AC0008A80009AA040DA5010AAD0710B90F19B4030FBC0410C30913C2070FCF0E18C80714
CA0511E71B21F21E21F92423FE2F2AFC2E29FB2D27FD2E29FC2F29FA2827FA282AFB2D2E
FB302FFC3132FC312FFD3330FA2F2EFE3333F62828F92D30FC3436FE3A39FE3B38FE3A38
FD3534FD3433FB312FFD312EFD2F2AFB2B26FA2724F62121F62121F21C1DF62222EF1A1B
EE191CE7151AD70D13CA0811C60815BF0715B40615A3030FA7121EDB515DAE26339B040F
AD0411AF010FAF020DB1040EB2020DB7020DC00711C40912C60810CB0A12D00C13D30C12
D40F14CE0B12C10510B2020BA90109A30107A001069C0104990003990104960003950103
9502059302059201049102048D01038D02058C02038700028501038301047E00027F0102
8607088009067D180854540000FF0000FF00
00FF0000FF0000FF0000FF0000FF007F3008871D099717079A08039A080B800D12701A1E
720A0D9207099D0204A00105A30105A60106A80207B3060DB6090FA20207940207870207
7B00037F00048001038402068601068901078E01099002098F01079001079802099F010A
AC060EAC010AB6030AC70A11CB0A0FC9060FC1040EB30008A90007A301089E00089D0008
9A000795000697010995000A9500089E020DA7020EAF020EB3020DBE060EC7080FCC0B14
C9030CE61A1CF01C1CF51F1EFA2523F5211DF7231DFA231EF6211BF8221FF92323F72422
F92622FB2A25F92A23FD2D26FA2B25F72824F32123EE1D22EC2023F32928FB332FFB322E
FB302CF92E2CF92D30FA2D2FFA2C2AF52725ED1E1FE91A1DE7181CEA1A1EE91A1EEB1B1F
E9171BEA191EDD1219CB0812C20512BA0513A704119000099C0A17A00E1FB126368F000B
A1020CA7000BA9030BA90108AE000AB8030FBA010CC10710C30610CE0E16D20F15D10D10
D10D10CE0C13C30812B0020BA80209A100069D0205990104980104980004970104960104
9101048901048E02069402069301049000028C00018A01018701028201047D00037C0003
7C02037B0901771804388F0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00883F0E8C2E119E23109B0A02970404901112962C28
89110C9304039902029B0002A30204A70106AC0107B5040ABC080DB30309B1060BA9050B
9801059001068C01058F02069101079501089801099C050D98020A9701089B02099D010A
A0020AA40108AC0309BD060EC4070EC4060DC70913BD080FAA00069E00049A0005970007
9300079000089101078C00078E000798010AA00008AC0109BB050BCE0E11D6100FE31718
E41615F0201DF6221EF3201CF2221EF72923F42A22EF271FED2921E82921E52C26DE2A23
DF2C24E1302AD52721D42720DB3028D32923D02723CA2220C5221DC4231BCF2C26D6322B
D42E28CD2722C11C1BC82325C82221C62120C11A1ABF1518C51B1FCA1E21C7181ACE1A1D
D51B1FD81A1ED3171DD0161EC50E16BE0C17AB0C158700088C06109A08189A071597010B
A7060EA90209AD0209B00209B9050EBF0711BE060EBE050CBF050EC60610CD0B14D00D12
D10F12CB0B11C10912AE020BA401099D0005980003950005970106960005970106980106
8E02047900018001039201089501079101048C01028B01018801018501038000047C0204
7903037D13076D170238930000FF0000FF00
00FF0000FF0000FF0000FF0000FF00965116792403901B059E1107910301870402961D17
910D079402019801019C0001A30104A90007AF0208BC070CC0090DB90209BE070DC30B11
BB0A0EA70206980004970207990109980108980108990108950107920006950107960007
9D0107AC060EAE020BBA050DC20910C50911C80C13C30911BE0B10B90D10AB0407A10007
9A0007950007920005900004970104A20307AF080AC10F10D61D1AE3261FE72920E5281E
E83024E32F24E03226DE362ED6382FD43F33D44437C63C30C9483CC85244BF5345BD594C
C66457C6685EC26A5EC77064C77165C47066BD6C60BE6E60BC7061B97061B66D61BD7165
BE6F63B6685BB06157AE5F57A85951A5554BA250489F4943A149429E423C9C39339B322C
9D2D27A029259F221DA3201CA21B17A319199A1A1A791312CF787AA240467D0A128E080B
AF1418B30B10BC0E13BF0D13C50E16C20B11C1090EC60D12C2090FC6070FD00D16D00D13
D00E13CC0D13C00910B0030CA3000A9B0108970106960008940007920006970107990107
9103077E01037F00039202099401088F00048C01028B0101890101860101810204790103
7607037E1E0E6D1F0300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A203762801871A03940F058B0201850001870200
9207039601029B0102A10003A90206AD0106B40408C40D0FC2090CBE050BC3090DD11013
CC0E0FC10B0DA801049F00059C01099800089300069300079201088F0007910008990109
A5030AB90B15B80710C10C14C0090FC20A10C40B11BF070DBD060CC61316C31214B50B0E
AE0D11A50C109E0E0E9F1211A81B17B2221CBC2D26BD2F25C13A2DC44033CA4D3EC65141
C65C4CC76757C56D5CC47467C47E72C3887BC18B7EC59588C39C8EC3A393BAA090C0A99C
C2AA9DC1AAA0C6B2A5C7B4A8C4B4A7C3B3A6BEAFA1BDAEA0BAADA0B6AC9FB2A99EACA398
B0A599ACA396A69C91A1968D9D93899B90859D8F879B8A8398887E948077998076987B71
96766C926F638F685A936555945E4E9256478C51447B4E44906F6AA07A785F282473221C
8C231B9218139C1613A31412AC1615AD1010B81213C01314C20E10C90F14CE0F16CD0D13
CE0E14CA0C13C60D14B7070FA5010B9C000B99010B96010B930009940108970107970005
9301068C01058D01069502099201078E01048E00038C0103890102860101800001780101
760B03751C0967210000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028D8067A36027F2203830B03860202870200910705
9606039B0301A10102A60103B00609AD0002B30204C91111C10809BD0409C50B0DD11011
CE0D0CCC0E0FBC070AAD0306A100059C010993010995040E96060D95030C97010A9F010B
AC040DB4050EB7070EB8070FB8080CBA0B0FB80E10B10F12AB1011AD1915AA1C15A51F18
A227219E30279E3B30A14A3EA85649AE6153B16D5EAF7466AC7C6DAB8071AA8575AA8A7E
A78E82A48E83AA988DA89A91A79D96ABA59DAFABA3B2B2A9B2B5ABB7BCB0BCC0B6C3C6BC
CCCDC5D1CFC7CDCDC4D0D1C9CDCFC6CDCEC4CBCCC3C7CAC0C3C7BEC1C5BEBEC4BDB3BBB3
ACB4ABACB4ADA9B2AC9DA5A29FAAA69AA5A1969E9D9097978B93908A918C8A8F88878C85
85888281857C84857C817F747F7A6C80786880796878756776766B747166796E60806859
8763548A5B4D88524487473A8C3F33852C218F251D9F241DA51B15AD1514B61214C01417
C51316C60F14C51017B70710B00612AA06139F010E97000C94000C96020C970108980207
9702099401089401069200059100059001039202049102048B00028801028302027A0201
78100567160133910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00925616782C04720C007F02018B0401960702
9C0702A20402A70301A80101B20808B20406B50304C81010BF0709C0070CC50B0DCA0B0B
CC0D0CCF0F0FCC0D0FC50C0FB8090DA9050B9E090F9D0E15A41418A40E14AB0D15AD0A15
AE0911AF0A11A90B0FA10E109D1310981613941F188F29228F382E964A3D9B5B4B9E6756
9F71629E7769A081709B837497847695837994867E958D8692918894978E95998F999E97
98A0989FA39E9CA39FA4A8A7A6ABA9ADB3AEB3BBB7BCC4C0C8CECAD2D7D1D6DAD4DCDED8
E3E4DEDDDCD8DFE0DBE1E2DEE2E3DFE3E4DFDADBD7DCDFDBD9DED9D2D7D2D0D6D0C6CEC8
C5CBC5C0C6C1BFC6C0ACB3B0ABB4B2A4AEAD9DA6A599A2A1969E9E939A988D938F8A928D
868F8B848D8A838B897D848178807A798279798277768276747F73767D71777A6F7A7B6D
787A6B7574667471647971637E6F617D68588262528A5B4D90514490433A91342E952723
9A1D19A41A17A61415A40C0FB9141BB80B17B50B19A705139C000E9A000C98010A950107
9602089400079301069101059001049201049403049102038C01028801038502037A0101
771206691C001BCB0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B61678390B6810017F0602940B07990200
A10401A80503AE0604AD0403B30606BD0B0CBA0608C40F11BD070ABD050AC3090BC90B0C
CC0F0DD0100FD11011D11013CE1315C51518B01113AC1A1EAE2023AD1D20A8171B9F1418
9414148F191887221E86342C8C4B3F955F54986E6198786B967F729180728F84768C8777
8A88798D8B7E8F8C808B89818C8E868F908C92928F939493929794939C9998A29C9BA49F
9EA8A2A5AEAAA6B0ADB0B8B8B5BEBDC0C7C5CCD5D3D5DBDCE0E4E4ECEDEDF2F4F2F7F7F6
FAFAF9FBFBFAFBFBFAFEFDFDFBFAFBFBFBFBFCFCFCFAFBFBF8F9F9F6F8F8F4F6F6EDEFF0
EEEEEFECEAEAE2E2E0DADAD8D1D2D1CBCDCCBFC5C1B6BBB6B5B9B6B2B5B1AEAEA9ABABA6
A5A6A29B9F9B969D9A949A978D928F868E89848C86848C857F867F7F847D7B8078798075
747D71767C75747A73737A7271796E72786C76786B787568786F617A6B607C655C846258
87594E8A4B438639358123209B2122AE1D21B5181FB7131DAB0712A5020EA0020C960006
9300059301089001068A01038A00019101049303049001018D01038A01038301027B0400
791605378E0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009056236B17028A11069B0C05A10302
A60301AE0606B40907B40707B20502C00F0CBB0808B60407B50207BB0308C80E10CB0D0E
CC0E0FD11012CF0F12CF0F14D2151ACF1B1CBC1D1CA724239F2D2E942E2D8F3330873B35
8D534998695F9A786F917E718D85768C877B89867B8B897E8C8B7F8D8C828B8D838B8E84
8B8E838E8F878F908A8E8F8A91938E959894969996989C9C9EA4A6A4ACADADB7B5B6BEBE
C4CDCCCCD5D6D8DFE0E3E8EDE8EEF3F1F5FAF6F9FFF7F9FFF8F9FFF5F3FBF4F2FBF3EFF9
F2EDF7F0EAF3EAE6EFEBE4EFE9E3EEE5E0EAE0DAE6DED7E3DED7E1DAD4DED9D3DCD3CBD3
D5CBD3D7CAD3D7CCD1D5CCCFCBC4C6D0CDCCCDCBC7CBCAC5C9C6C3CAC6C3D1CBC8CEC5C2
CDC3C0CDC7C3C7C2BEC2BEB9BAB6B2B2AEABADABA7A9A5A0A29C999D969197938C8E8E84
898D8283887F83877F7C81797B81787B83787B8277787E73747B6F767D73767B73757870
737469756C6577645E7C5D5586544B8C423D943230992122A51B1FAD151BAB0E149F0309
9B02079302068901038601028700008D01038F01048F01028C01028900018502027C0501
7D1A061EC90000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A4672D7B2707961E0BA21004AB0A03
B20A06B60907BB0B0ABC0C0ABC0C08BD0B08B80705B00203B40105C1080CCA0D0FCD0F12
CC0F10CE1113CB1314C81619C01C1DB32421A4332C94453F8E5953936D669579728D7E74
8882758B877C8B89818A8B82848A7C8B8D838A8C828C8C828E8F858F8F8791938D92948E
979B93989C959B9F9BA0A39FA5AAA5ACB2B0B4B9BAC3C8CABFC7CAC4CBCFC5C9CFC4C8CF
C0C5CDBFC1CBB5B6BDAEADB5A5A5ADA09DA99B99A79D99A69C99A4948E99948C98948898
9688969A8C99988A969487959589969B8F9B988B958F808891838895878C9284888E7F80
9583828F7C7C8E7C7A8D7C7991827F9086818D8780918983958A869185808E807B8F807A
94847D8F827B958980978B81A0918B9F918CA59891B2A29BB2A29CB2A099B2A299AEA197
A79E92A6A1959F9C8F9B968B9794899390868C8B8086877B82877A80857C7E847E767E79
757F7772787176797376756E76726A7667607B5D5883514D853C388A2C2891211E951313
9F121593090C8902058A01048801018800018700028801018A01018601018103017C0800
791A0400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0050AD0F782704901D04A41303B41006
BE1109C5140DC2110AC3100ABE0D08C30F0DBC0C09B80908C00C0CC60E0EC60B0DC90F13
C61314BF1816B01B189F241F99393298544D966E64917D738A837985837B84857C82877C
83897D888B82888C848B8E858B8E828E8F8692938A92948B9899939B9D999DA09DA3A7A4
A2A9A4A8AEABAAB1AFA8AEAAA8ADAA9EA0A19495978E8F9288898C88878A868585878485
8784858A8687918B898B83828F87858D8382887F7D90868491868191857D90837B968680
92817A9180789B8C869A8D86988D86A19590A0938B9A8B7F9485789B8C7E98897B99887A
9A8978998877988977928273988A7B9E9385A49D8FA69D909D92839A8C7D9A8A7C8B7A6B
8D7C6A8979668879658777628A78668C796A8A77678975658D78688C75658D75648E7765
94816F9586749C8C7CA29283AA998CA8988CA39689A4998C9D968B9A958D92908C8A8B86
868A8181867B7C81797C817B797F7B75787672706D70696571605A745850744A4072312B
751B1981151485080B970A0F9303068900018301028401018601018302017F04017C0E03
6E160300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B742B018621039D1703B71509
C21508C7160BD12017CF1C16C5120CC20F0CBC0C0BC71919BC0B0BBF0E0CBB110EAD1110
A31E1B9830299B4F479E6E64987F768D837C84867D83877E848A81878E84858C7F898E84
8B918690938C8F938990928B91938C93958E9899949598939A9B9898999794969490908E
8A8B898485848C8E8C9899948A8982918F87938C85938D84938D83989287948D80989184
9D96899992849E9687958C7E9B9383988D7F9A907F9B8F7F93887590846F8F836C978973
968871978A758C826F9388759D907F998D7E958977968973988B76978B76998D789C907A
998C769A8D77978E779B907CA29585A198879D968499917E9B907B9587718F7E678C7A63
8B7A608A7A5D8B7A5E8A775C8C7B608E7B628C785F8D785F8C775E8D765C8B73588A7056
8C7259896E578B715A8B725C8E74609077658E7A6A9584759A887CA19288A1948CA0948A
9B93859590808E8C8085877D7E817B797B7975787675767373736E6C6D666A6760695A54
694A4367322D6F1C198B1716960F0E8B03048100018001018101017F01017E06017C1407
34870100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007E3C05772200982108B2190A
C82214C3160CC6180FC81611C6130CC1100CB80E0DBA1B1AAD120FAA1B149A261B913C30
8F584C9071678B7B7289837C858882818A827E8980848D858A958B8D978D8E978A8D948B
91978E90948E90938A8C8E87898A8583857F80817C7D7C777E7B7687817A8E8A808E8A7F
93908599958D9A988FA29E959894879B9587999281968D7C9C94819C94829A937F9B9381
948D7A918A7698927D978F7EA29B889E9885A19A889E938499917F98907B98907B988D77
988D77908670989179A1957F9C907D988B7B958675948671968A77998D7C9A907E9D9581
9F9883A09884A199859F9684A29888A39C8B9F988698907C9B8F789080678E7B638F7C64
8D7B60917F62927E618F7B5F8B795D8B7A5F88755B8A785E8C7A5F8A775A897458897258
8A71588B70588A70568E74598C7156927960A08C77A392819789789081718D7C6D8D7C6B
8F7E6C988877998F7D948E7E918D8187867D81817B7B7C7677787373746F6C6D6A686865
62615B60544D62423A6B2E25791B1487120E8506067E00017C00017B02017D0C02751507
2E850000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009A59187A2E04871F03A91D0E
C6291DBC1D13C3251DC11A14C1140DBC140EA7120D9F261F8C281C9247378D6151806B5E
78736880807A85878083857F878D86838C848A958B909B918E9B918F99908E958D888B86
8588827F807977776A78766A8582778B887D929084959083968F81988F8098928096917D
9693829B9788949083949183908D7E979181999581928C7899927F98907E99927F9B9281
9B938298927C96907A99917E9B94819892809E97869C9284A19786A097859C94819C937F
9C937E978E7A99917C998F7D9C927F9C917E998B789D907DA39985A096849E97849C9783
9D97849E9785A09887A099889F998AA39D8EA0998999917F948973918067907C648F7B63
89785D897A5E8B7B60897B5F8A7B60887A6085785E8479628276607D725B7F715A7D6F59
7D6E5980705A86735C89785D90806297866D9A8A76978A77958976978A7695857191816B
8B7B6387775F85755E8576628B7C6B95897A91877B8E887C8A867C7D7B737575706F716D
666B6561645D615D55614F46623A2F6A22197B16137F07087E03017C0500801406671204
29860000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029D808803B077F2708A93729
A91F18B32523E86D6CAE1916B71A11A71B128C261B985B4E8663547A6B5A727162707569
797E76848681868882888B84898E878A90898F948D8A8F87858C827E82767C7D727F7E73
8381758A86788C88748C867397907F9189799B938498928097917E958F7D9A9581958F7B
928D79928D7B958F808F89798E8B7A98928194927D9994809D96839A92809A927F9C9383
97907F958F7B96917B9C9481A095849D9583A19B899F97879D95849C9281A29886A19886
9E9784A19C8AA49E8DA49D8DA39C8CA49D8AA69D8B9E96839E9783A19A889D98869C9986
9F9A88A39C8C9E97889F998C9D9B8D9F9C8E9F9C8D9A9585968E7C8C7F6B8A7C67887A64
847962847D65827F6683816A85826E84806F817E6E83837483847786877A8E8E80908F81
959285908C7C938F7C98927D97917A968E78988E7B988B78978B77998B769B8D78998B75
978A7096886D93836A8A796187755F84725D8575618B7D6B8F8574928A7B8B87797E7D72
74766E6A6D6662635E5E5D585B52495C43375E281F6F1712810F0A7E0B027E1B0E560B01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A6692F793717D18076
992B27A52324E06367A5201BA3281B933D2E875A4A7565586E6B5F6C70636F7969757C70
82867C8B8C848C8E86888A8384867D83827B7F7D747C796E8280708A8876948F7D96917E
9D98859A938098937E99937D9A94809C94839A93819A9380958F7A94917D99958198917E
968E7B98917F9A9382968F7D958F7C9994819995829A94819B94819E95849E96859E9885
9995819996819E9A86A19A889C95839C96859F9B889E99879F99899D95849D9584A79E8E
A09A89A09B8C9D9B8A9E9A8B9C998A9C9989A39F8FA19E8EA39F8EADA797A5A1919C9A89
9F9B8E9C988B9B988B9B988D9A9A8F97998B999C8E98998C98988B979587949584979987
949787999F8FA5AE9EA7B0A29CA499979D968E989186938E7C89857D8A877F8A877C8481
808782858A81888C818A8B7E8C8A7B928D7B948D7A9C917EA0947E9F917BA0907B9E927A
9C90789D91789B8D779687719989719180678C7B638B7B648D7E69857763897D6B8B8171
8C87797D7D726F6F686667605D5D5657524853423657291E68170C751709651204500C02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0066CB2F91603EB1746B
A74945AC2B27A526209B32258F4C3B80614F726958706E626F736671786A767F6F7F8376
85877A86867B8180747D7B6F7C7669867E6F948B7A938B79928D7894917A95917C97907D
97917E9A93809B948198907C9B948196907D99947F98917B96907C9A94819A95829B9481
99917F9B948297907E968F7C98907D9B93839F9A8799927F9A93809A93829B95829A9583
9795819A98869A98859B97869896839694829696839795859E9A8BA09C8C9E998CA09A8D
9B978A9D9C8E9B9C8E99998A9E9E919D9F929A9C8E9A9B8EA5A398A9A79CA9A89DAAAA9F
ACACA2AFAFA5AFB1A7ADB0A8ACB0A8A8B0A7A7AFA7A7AFA7A6AEA9A0AAA597A39C9AA69D
98A39B99A49C98A39A98A19791998F848D837F89807B847D77817C727F7D737F7F798584
7C88867A868477837E80888085867B8F8B7C928A789C907E9D917C9F917B9F907A9B8F78
9C917A9E937C9D907A9E917C9C8E789989729A8B739585708F7F6A9889739384707D715F
827968857F6E8A8577827D716D6B605F5D53575247554335552A195F1E0D500E00268601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C6966D7C4030
9033299E2A1F9837278C53437862506D6A5A6A6C5E7072627379687B81707E8472808172
807C6D807869827D6A8F8876948A789387738C7F6B9B907C96907B96927B908C76948D7A
99927F97907F9992809A9280968F7C97917E96927D97917E96907E9D96859B96869B9787
9D99889D98889E9A889E9988A09A8AA29D909E9B8CA49F91A39F8FA39E91A6A092A39F91
A09F909E9F91A3A294A6A6979E9F8FA2A395A4A798A5A79CA4A59BA6A89FADB0A7AFB2A9
B5B9AEB4B8ADB4BAB0B5B9B0B3B8AFAEB5ACAAB2A7B0B7ACAFB4ACB0B4AEB0B6AFB3B9B2
B8BEB8B6BDB7B5BBB7A5ADA9A3ACAA9FA9A898A4A195A09E8794937D8C8B778580758179
7E8780868D84898D818E8F818C8C7D8081707A7969777263706E5F696A5D68685F64645D
5F645F5B65625F6E686F7B75797E778382778F8878968B7A9C907C9E917CA1937C9F927B
9F937EA0927E9D907B9A8D77948770998C76A0917BA3937D978871988B75938876827969
746D5D6B6656726D5D807A6A827C6B777262655F50574F3F513E2B572F1C460E01248601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8BF59804527
782A18914433875645705A4C6B66556C6D60707363787C6A7C806C7F816F7B7967827C69
8A816C8E836C938871968B77978D79998E79998D78978C7A98907B908A71928D7499927F
9C95839893839C9888A09A8BA6A090A8A192A7A495A7A294AAA597A39F92A19E91A19E92
A2A0939D9C8FA5A4989E9C959999909F9F98A2A49CA3A39CA9A79FB4B1ABBAB5AFB3AFA9
A3A39C9899939B9F969D9F9793978E8F938C919590929995909895919E9992A19C9BA7A3
AFB9B3B9C1BCB5BFBAB3BABAB1B9B8AEB7B3AAB5ADAAB2ACAEB6B2A8B1ADA7B0AAA6B0A9
A1ABA5909A968189857C82817D8482727B7967726D5D69625A67605D69616B776B7E887C
8E9488A8AAA0BBBBB1CBCAC0CBC9BFBBB8ADA8A294958E7C847C688B7F6B82705D7A6754
695B49544E3F4D4F42575E566870697A7D728782749187769C917E9E927DA1927C9C8D77
9D8F7A9C8F7A9C8F79968971998C739A8E759C90789D8F78998C75958B77979080817E70
6A6A5D5D60544D5245535444736D5B887E697D735F685E4E584B3B5A402C451606248701
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003AEB1DB07D51
6C3E237F5D486E5B496D6252736C5C7774647A7A677E7D69797864726F5E76725E918874
958A7292856C988C75988D79978F7A958D799A927E968D7A9F9582A39A86A39D88A19B89
9D99889B988A9A988C99968A9C988D9D988E9A988DA5A196A4A095A5A195A6A497AAA79C
A9A69AAAA89CAEADA6B2B1ACB0B0ABB3B2AEB8B8B5BBBBB9D2D0D1E5E1E4E7E0E5DAD5D8
BFBEBEAFB1AFA0A6A4969D9D8C93938893918D9999919D9F8F9E9F8D9F9F96AAA98FA09F
92A09D949D9C96A09E989FA09CA3A29EA6A3A2AAA4979D98949996929893969D95A1A79F
A4ACA4A4ACA4A8AEA8AFB5B0BAC0BBBCC4BDC3CCC6C6CDC8CCD2CCCFD5CEC2CAC2C2C9C3
D6D8D6EFEEF1F4F2F7F5F2F8ECE7ECDAD4D3BBB1A89C8E7F9A8974A78F76A284689B7A5C
8E7153816A4E6F61495953425453486A685C888270918674958A749F937C9E90779D8F77
9E8F799E90799C90799D927B9B90799B90779E947B9C917B978C769289768E897C76766C
646961444E443A453B3E46394D4C3B6D644E8879628577636E604C59442F4E281600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C99D68
755A386C5C42695E47766A577F7462827966827C6478735E6964526864557A7866908976
938975988C76988D77978D79938B76A199869A948198927F968F7D98907F989281979382
989385999287A29B939F9A919F9B91A7A29BA4A198A39F94ACA59AA7A095A6A293A8A295
A49F92A49F92A5A094A09B92A49F95AAA29AAFA8A2B0A9A5B8B1AFC3BABBC1B8BDB6AFB5
ACABAE989A9D8A9396848F957D89907584896E808469797E6778796373745C6D6C657571
7D8A83939F989FA7A1A6ACA7B0B5B0B4B9B5B7BDB8C3C7C2CFD1CED4D7D5DEE0E0EBEEEC
EBEEEDE6EAEAE4E8EBE1E5EADADEE1CCCFD2B2B2B6A5A2A5969093888280736F6B736E6A
7B73738C8287948990978B9294868892827B8D7A698D775F8F75599070518F6E4B8E6C48
8A69438768438368457C65496E5E4660553C75684F9182699C8D75A597809F937A9E927B
9C8F789C8F79998D799B907C998E7A988E79978C77958A75958A77938D7C88867D6A6C69
4A555039483E3C4A3D414D3F474B3C54513D6D664C82765C83735A68553B5D3E2400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007D9D33
6E57306C5D3C786A4D81725A83775F7A6F5A665F496A6451696755666557787868878272
8E8674958A769C947E928B768E8971948E7A97927E999582938C7B958A7A948B7A97907D
9A918096887B9C91849E94889D9789A19E919E9B8D9D95889E96879E95889E98869C9685
9B95849994829994829992819A91819B8F81999080988E839A9087958B83938C85898484
7B7E8161696D5A676E5062694D5C6348595B4E5F5D4F5C5966706C79817C8F9791A6AEA7
BDC6BED0D7D1DBE1DFDFE4E4E5EAEAEBEDF2E9E9F1E7E7EEE2E0E8D8D3DCC7C2CBB8B3B9
ABA5AA9D979B938D928882867E76787B6F6D7D6D677C685F7E685C836C5C84705B8A7760
907F6892806D9B8879A08F80A18F7FA18F79A18E74A08F6E9E8A689B8664967E5D8F7756
8E735095754E98764D93724B8B6E48876E4879633F8C7657A5947BA3967F9E927B9E927E
A0937F9A8D799A8E7B9F97829E937E978B769487749B907F9791828C8A816A6D6B4C5654
404E484352464755454A55454D53455355466C6D587D775E84755A826E4F6A4C2D00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6025
755A3179684584755384765A6B6248504A354F4C385A594763655565675B7A7B6E888576
8A8371978C7998917B8D88728E8C759B96828D8875807A68978F7C9C8E7B9385708F816D
91836C8F7F6993836E918572938B7896917F9590809B938498917F968F7F97917E96907D
9A94809993819994819B93819B93809C95829A927F9A928099917F958E7C888778767871
5A61604551513748483445433F4D48545F5762695E83867A98978CABAAA3C2C1BBD2D0CE
DAD8DADBD9DECECAD2BDBAC2ADA9B1948C94837881776A717B6C6E7F6E6E7F6D68836F65
8C77688E7868957F6D947D68987F69997E63977959987955987852947854917A5A988666
9B8C6C99896B9E8D72A09177A2947C9D90799F947C9F957F9D947D99917D908A77807968
7A6F5C856F509B794F9F794C9D794B9978488E6F457F6443A8947AA59680A1937DA4957E
A1917E9D8D799C8D788E81688B7C628E7D65887866877C6F8C8A83686E6C4C5758475552
46544C4B584B4E5B4C50594B535A4B596253737B6B9394817D72588F7A5B7B5B3800FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0C7D551C
81643D897551887A586C61444D4A2E4A4A33484A364B4D3D55584A5B5E5374756B818073
86816F958B799C917E8C8571928E7998927F8B8572938A7691856F84755E8E7F669F8F78
8F816790806794846E998B78978D789089758D8774908776938C79908876958B78978B77
958974928873958B77988B779A917B9C927F998F7C9D9480948C79938C7B858677686E64
535953404742444E43545B4E646959979989837F6F92867791837484776C7D70667E706A
7D6F6E7C6F6F7D6F6E80726C81716B87756C8D7A6E8E7B6A957F699B8066A185659E825E
9F8461A99072A99074AA9072AC9370A98F66A284569D7C4C9E7F51836C4882765F877F6D
8D8571918872958C779A9581ABA695B1AB9B9B96889190858C8B8282847B787B7270746A
6D6C5E7261459C7A4F9F7644A37B479F7845967344876944A18A7097856E98856D947F67
927D658C775D867257816C517D6A4C796A50756A5877756B6268644B59594857544B5851
4F5A50505C50525F525662545C6759616D5F737F7393998B95927D8774578C6A4100FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310835F2B
8C6E488C785673694A5550354B4C314B4D364D4F3A4E4F3D4B4E3D5052466263597F7F75
8A877A8D84729C917F988E7C9993809D96849189759E937D958B738A7C639080669A8A71
9A8C7294846B8B7A638C7A6390806792856B968970988B7395897194876C96846999866B
99856B98856A98866B98856B99886F9D8F7A9F917D9F917D998C78988E7C8A85736D6D5C
5B5A4A6360526F6B59746F5B7B755E887D66817158826C538870548D7458977F629D856B
95836B8D7F6B948573AB9D8BC5B7A7CABCADB2A39192846B8A7A5D9A8361A289639A855F
8E81627E76627F7766867C68968971A99776A58B6098794A9C7E51816F4E69665671746B
76766B7F7E7286867A949288AEABA2BEB9B09B998F8F8E8786857D7C7C72787A6D6D6E5D
6660487C6743A68453A27A44A97F4AA37A45997342987B549C8467927B618E775A897154
877151826E4E7F6E4E7F6F537F725A7F7967707366555F584C5A554C5C544E5C53535E53
5861565961565763565B675A6570636E7A6F7480768D968BB1B0A1816F5494704400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047B110916E3D
9477518471526E684F53523E4A4D364A4E374D503D4F51414F50415153455355495D5E57
7979708683778A85759C958496907D948D7B9C94809D937EA59A858E816B95856D9C8C72
9B8D72988A70847157978167A38D73AA977CA1927395876B95866A958564948361958161
9681619881629781619781629984699A88719989729D8C769F8E799E8E78988B73766D54
7E73598274597D6E4F7F6D4C8874519B8361A48C66A28963AB8E67AF8F6AB0926DAA8F6A
968160908168A19581AFA391BCAFA1B6ABA0A19689998F7B94896E96886C938669928B6F
91927D6D7468787F7593978A736F5F796A50AB916B9B7A4C99784A96805B544F3A696D63
84867D807F738783778E887DA0998FA49D919993868E877B81796B6E6A5A62614E66624B
8576569A7F53A3814DA37B46A77F4AA07B489D7E51947E5A8976598B785E8C795E917F64
96886C9B9076948D75898573858378666B6257615A52615B526257536153535F52596656
5D685A60695E606B616772676A746A757F77737E768D948DACA99B836F5498724200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3742C987441
93775283755A7C7B695156474C52404E54424F54444F544550534555594B54594B515449
5659526F716A7E7F748685788F8C7B97907F938B779D9581A69A889D918090846E94876D
97896E9D8E769C8C728C7A609B8971998A71A5997DA2967D9C8F77988B6F998D6E9A8E6F
9C8D709D8B719D8C6F9B886A9B896D9B8A739A8A719B8B729D8E74A1917A9D8E74847356
8E7855896F468D70429C7F51B5996EB6966EB59770AD9069AD9069AC8D6CAB8D6CAD9170
AA9273A590789E8F7B9E92829E94839A938298917F9B957F99947C9490798F8C76949581
A5A8989EA3979DA29698978B746B5A847054AD9269AE8C5E987442A2845A78684C5D5647
736E60786C5A8776608D7F68968E79B2AB99A29E8E8C8779837D707771637E7B68857C62
8E7A569B7E509D7D499B79479C7D4FA88E66AE9C7DA89B81A69A84ABA08DAFA696AEA798
A29E8E9391838384786D71686067625C65605D69625C695F5E6B5C5F6A5A5E695A5F6D5D
626F61646F6468746B6A776D717C7376817979847E8E928B9A93848E76569F753C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB8169D7844
917753857C657F817462695C545A4D515749535C4B50584752594A555C4E565E4E555B4D
545A4E5A5E57686C648788819293889491838C87769B95829F9786A9A292A8A38F9D967F
988D77988D799F9581A99F8B9E937E988F7BA39B87ACA593ADA593A39A88A7A18CA69F8A
A49E89A39A86A29682A1947E9E927A9B907C9B917C9D937A9B93799F957E998E76857254
8B6F4891703FA3824EBB9D6DAF956BAB8F68B2926CAC8C66A88962A48866A088689E8568
A186699E866F8C80708F8A7E88887BA6A897A1A191A9A998BEBEADC1C1B1C0C0B0B5B3A4
A09D8E91918280807079725E8D7A609C825EAA8C5FAC89589F7944A581519F845F89775D
968771A59178AC9378B5A289D7CBBCFDF8F3DFDDDA928F8A7169606A6051746951897858
947B54967C519B8255A68F68B6A586B4A891B2A998AFA89AAFA99EA8A59D98989194958E
86898071766C646B5F626960636964636B64626C64616A61656E626971656B7569657368
63716768766D6E7B746E7A75727E797B857F878D8795928A897B6795774D7C9A2900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051B9169B7741
8D7853827B657E7F746E7369596055585E51555C4D51594A565F50555E4F535B4D595F52
585F52585F535A615963656074756F8D8D859595899493859A97879B98899895859C9586
A39C8CA59F91A8A393AAA494A09A88A9A291A6A090A49D8F9E97879D94869992829A9382
989180A1988A9990829C93839B947F99907F98917E97917B97927C99917E9E9683AFA08A
A68F6FA1835AB4986DAB916AA68F69A58D67A98B66BB9670B7926B9F8362978265937D63
9F8368A58A727368597E7C74868882A9ADA4B5B9AFAEB0A7BBBBB4B5B5AFAFADA79B978D
817B6E7671607B745D827356967D59A4875DA78859A78552A47D49A47F4DA384589A825C
947F5E9B8264AB8F72A68E79A9968DB6A9A99A908E897E738877658B785E927E5F9F8868
A89272AD9B7BBAAE92B6AC96ACA697ADA89DABA99EA2A199A6A6A18B8C887C807C6F736F
676C65666D636A73666A7167686E676E756E6C766E6C766E6D766E6E766E6D787068776F
6879716A7A746F7D79717C7A7B8482858A858D8D858A7F718E76599C763F2ADD0C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BF1A9E7840
A18C67877F6A7E807270766A626A605F665B5A6156575D53596256505A4D555F515C6357
5A62555A65565B67595E635A63645E66676273756E898B82A19F97ABA89FA9A59CA39E94
979388919084918E81969284989584A09B8DA39F8FA39D8EA9A393ADA596A7A190A6A08F
B1AA99B0A69BABA195A89E90A59D8AA39B8A9D9886A29E8C9B96849A93829891809F9685
94826C8D7254967B579E845FA28B66A08965A78B68C19A77BE9776967D618F7E65937C67
9B7E67B0917A9A86768C817AC2BEBBD2D1D1C6C7C4C8C7C5C5C0C0BBB3B4AFA5A392887D
8A7F6A88785D917B599C8057A18256B19469B3986EAA8E62A68659A28356A3885BA48D62
A089639B82619C83649B856A9785719786779A89769B896F9A846AA59277B5A38AB8A993
BEB19EB1A999B0AC9EABA9A0A3A39D9C9C9794958E888C84767B7570736D70746E6D726C
6F766D6F776C767E737980767F857D79827A737F786F7D756D7B74717D766F7D76677A73
6C7F7A72817D7984807F8683888A868A8A81857D7085735B98774B56BF2000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A1773B
9C845E9187707A7C6C73796B697267646E655C655A5F655D5A6357545F535761555D655A
5D685A606C5B636D5D676D626568606668626669636669646E6E697D7B788C8A869E9D96
A3A39BA2A197A5A397A19E91A19E909E9A8D9894889994869B96869A95859F9A899F9B8B
A6A090ADA598ADA498ADA499B2AB9DAEA99CAFAD9FB9B7A9B7B2A5B4ACA0BAB3A5B1A999
A699849681648F7853957D549781589C865FA08663B08F6FAE90728F7B628A7A628E7A65
947B649A7E679D8571978679C0B5AEBBB3B0A09893958B858E807A8C7A718B7667907B63
927C5C96805A987C539B7F53A0875DAA946FA89574A99677AB9677AE9A79B0A07CAD9E7C
AB9D7EB1A386AEA086AFA289B0A58CB9AB94B3A48CB4A58BA89A82B1A593B2A99BB6AEA4
ADA79EABA79FA3A29C9899958A908A7E847F7E837F787D78747B73797F777B7F777B8077
7A8176838B7F878E84898E87868C8478827B737F7A76847F71807B71807A75857D71837C
6F817D7787837F89858589838989808B857785745D94764E7F9E3300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA1A
947647AA9C807C786571736570796B6C766B636F65636E655E6A5F5E6A5F5B665C5F6860
626C60656F626870646C7369686E64676A62676D63686F66686D64696B64696B646E7169
797A7489888298958E9E9B929F9E93A7A39BABA69EA4A1979D9D8DA0A08E9E9D8A989584
9994849D95889D96899B9589979385908D7F9390829690839C9486988D819A90829A9180
989078968C6F998C6A9C8C6695835C98855F9884609781619A866893836884765C8A775E
917C61957D6297836897866D9E8E7A9E8F7DA2927EA79680A89780AA977FB19B82B7A384
B8A582BCAB89C2B190BEAF8FBEB092C3B99EB7AD97B2A994B4AA96B8AF9BB8B09DB6B09C
B4AD9AB8B1A1B3AB9CB2AB9BAEA593BDAF9FBAAA9AB9AB9AB8AA9DB5ACA2ACA69EA6A19C
9E9A9693908B8A8A86878984858A8480857F82858381848283888281877E80857C868B83
848B818E968C8C938D858B88828B8876827E74807B7884817884817C87827D89827A8882
7E8B8884908B8890898B8D85807A6D87775F96754E79982D00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9F75389A7F5B8C7F686F6D5C727668787D72717B736A756D626E66646F66616D64626E65
6672686772676973696E766E6D766C6E736A6E74676F776A6E7669696F636D70646D7065
6C70676F716B76777175766F7C7D75817E79938F8B999892999C91A0A297A5A69AA8A699
A9A799A9A499A9A498A7A296A7A396AAA697AAA797AAA595A59D8DACA292A79D8CA39C88
A7A289A5A086ABA58BAEA58EB2A68DB0A389B6AA8EB9AB91BDB095BCB397BCB598BBAF93
C3B698CBBCA0C7BB9FCBBFA4D4C8AFD8CCB5D8CDB5D9CEB4D7CCB3CDC1AAC5B8A1C6BAA3
C4BAA3C7BEA9C3BBA7C3BEAAC4C1ACBFBCA9B9B6A6BCB9A9BBB8A9BFBCB0B9B7ADB8B7AB
B6B5A9BBB8AEBCB6AEB9B1A7C3B6AAC8B6AABFACA3B7A59DA699929F96909A948F938F8A
98959195959192938E8F918C8D918B9295909192908F918F8F948E8A9089888E87898F88
888F8889938D86908E828D8D808D8B7A89857C8B857F8D86828D89858D8989908B87918C
8B93908D928F94958E8C857788745B95714786A33700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2CDF0F99713A987F5B887D687B79697E7F747E847D777F7B707B756C767063716966736C
63716868736B69766C6F7A726F7A706D7568707768787F72787F71767C70777B6D74786A
72786D72766F70766E75766F73756D74756F7979747577727C817B83878291938F91928C
9FA097A5A6A0ABABA5B1AFAAB3B1A9B8B8AFB5B7ADB6B7ADB7B7ACBAB7ABB5B1A3A5A190
B6B3A2B4B2A0B5B2A3B6B1A5B7B2A5BBB6A5C2BDABC3BDABC3BFACCAC6B2CAC6B0CCC8B2
D2CFB9D9D2BFE1DBC9E1DCCBE4DFCFE3DECFEAE5D6E8E3D5E4E1D1E1DECFDAD5C7D7D2C4
D5D2C4D8D6CAD1CFC3CACABCCDCEBFCCCEC0C8C8BDCACBC1C5C7BEC2C4BEBFC1BCBCBDB8
BBBDB6B3B4AEB3B1ABB2ABA2B8ABA2B8A89EAF9F97A69993A49B95A29C979C97929B9792
A3A39D9C9E98969A959DA09D9B9F9B939795969997959A978A928C8E97918E98918E9690
88918B87928D86949182918F82918F83948F84948D7F8F8784908B8C958E8D948D929790
93959094918A8E82728E7756A1794729DD1000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDF0F9B753B957C579A8D77908E8085898080878279837E75807B6C79726B7770
6B776E6D77726D7871707B74707D73737F71737B6C7D8377787E727E8176808378818478
84887E7C817A72786E73776F72796F7579727478717279726F7771737A76747876787975
7B7D797B7F7E7D8183828787888D8B8D94939BA2A1A6ACACAEB4B2B0B5B0B7BAB3B3B6AD
B4B6ADB5B9AFC0C1BBB9BAB3B8BAAFC0C2B4C3C6B8CDCFC2C8CBBED3D5C6D2D5C5D9DACC
DFE0D4E2E0D7EDECE3F4F2EBF8F6EFFAFAF3FAF9F4FBFAF5F6F6F0F0F1E9EDEDE6E8E9E2
E5E6DFE3E5DFE1E3DDE3E6DFDDE2D9D5DCD4CAD2CCC6CDCAC1C9C6C7CECDBCC1C2C2C6C6
B0B3B2B8B9B7BABAB5BCBAB2C3BCB3BCB3ACB7AFA9B9B6AEB7B4AFB5B3AEB1B0AAA9A9A3
AFB1ABA5A7A4A3A7A6A0A6A59FA6A59BA0A0979C9B99A09D939D99929D99939D9B919B99
8A94928894908C98948B99958B99948F9C98909C988A989386918D929792979A9396968F
958C808B796192734982A33700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE2107294289A7F57A498819898898B8F85888E87848D877C878078847C
77837A707975737D7979868076847B79857B717C707A81787F847C7E847C81877F878E85
8C91898E938D797E76767B74787E76747B73737D737682787580787C868178817E7E827F
7B817E767F7E7680817B85887783857C87898491928591938793948E999A95A29E98A3A0
9EA8A4ABB4B0ADB4B1B1BAB7BBC4BBCCD4C9CFD8CFD0D9D2D8E2D8DEE6DCEAF0E7F2F4EF
F7F9F4FCFCF9FEFEFCFEFEFDFEFEFCFEFEFEFEFEFEFEFEFEFEFEFDFEFEFDFEFEFCFEFEFC
FDFFFDF5F7F6F0F1F0EAEDEBDEE3E1D9E2DFD7E3E0D4DFDED8E2E2D2DCDEC4CDCFCDD4D5
CACECDC6C9C8D2D4D1D2D2CDCDCBC5CAC8C3CAC9C4C3C5C0C4C8C3BEC2BDB8BCB9B4B8B5
B4B7B5AAAEACA6ACABA6AFAF9CA6A59BA4A3A0A7A69CA4A2959F9D939E9E949F9F95A09F
8E9A998E9A97929E99929C99939E9B929C99919A978D948E8E938D97958E978F838F7C67
9476527A9C362DE11300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0050BC1E9B7C4DA59377A0988792908691948C8A938A848E86
838F85818B857E89867C8B867A8982808C8577817A7C837F7E85827F8883818B8587918A
89928A8C928C898F8885898380857F7A817A818C837D88808A958E929C98828C89878D8B
7A83817A83837C86877B86898693948B999A8B99998795968797968D9B9C91A09F99A5A6
9FAAA9A8B1B1B0BAB9B5C1BFC0CEC8C5D0CDCAD4D1D7E1DFE1EAE7E3EBE8EBF0EFFBFDFC
FDFEFDFEFEFEFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFEFEFDFDFEFDFDFEFDFDFDFDFEFEFD
FEFEFEFCFDFDFBFBFCF5F8F8EAEFF0E3EAEAE3ECEBDCE6E5E4EEEEDCE4E5D0D9DAD7E1E1
D2DAD9CFD6D5D6DBDBD8DADAC7C8C6CDCECBD1D2D1C9CDCBC1C6C4C0C6C5BAC2C1B5BCBC
B4BABAAAB2B1A1ABAAA5AFAE9FA9A7A2ACAA9FA9A79FA9A89FAAAA96A1A299A5A598A4A3
9AA5A395A09D99A19F979D9C9097959095928B8C868C877C8A816E88765B92744D7C9D38
2EE21400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002EE213799C359B7D55A6947AA299889A988B909488
8B958A8B948D727D757E8B8488948E87928E828E8A828B897D8786848E8B89948E8B9691
88938E8E98938C95908D938E939994949A95939C968D9794939E9B9CA5A49099989EA6A3
98A19F7D88877D898A8490908F9C9A919D9C939F9D94A1A094A1A098A5A49AA5A5A8B0B1
B0B8B7B7BEC0C6CFD0BECBCAC6D3D2D0DAD9D7DFDFDBE2E4E3E9E9E7ECECF3F7F8FCFDFF
FEFEFEFEFEFEFDFDFDFDFDFEFDFDFEFEFEFEFDFDFDFDFDFDFDFEFDFDFDFDFDFDFEFDFDFE
FEFEFEFEFEFEFAFBFAF2F4F4EFF4F4E8EEEEEEF4F4E2E8E8E1E7E7E0E5E6DAE0E2D6DDDF
DBE2E3D8DFE0D9DDDFDDE0E1D7DAD8D2D5D3D5D7D7CFD2D1BFC3C2C2C6C7B9C0C1B6BDBE
B8BFC0B2B9B9AEB5B5ACB5B4A8B1B0A9B1AFA6AFAEA3ADADA5AFB09BA6A7A0ABAB9CA6A5
9FA6A59A9E9E939395918F8E89867F8C847886776189724F95764452BF2500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DE113799A3498774F9C886A9E957F
9B9A8A98998D878B808A92888F98918F9793909A988F9A9888949189939286918C919B99
8F9B988F9B9A909B9A8C9695949C9A9AA29F98A19F9AA3A39EA8A7A0A9A98F9A9A949D9C
A1ABA787948F82928D8E9D9997A7A2A6B1AFA3AEABB4BEBDB7C3BFB6C0BFB5BEBEC5CDCC
B5BCBCC2C7CAD1D8DAD4DBDED8E1E3D9E1E0DBE1E1E5E9ECE4E9EAECF0F1ECF0F1FAFBFD
FFFFFEFDFDFDFEFEFEFDFDFEFDFDFEFDFDFDFDFDFEFDFDFEFDFDFEFDFDFEFDFDFEFDFDFE
FEFEFEFCFCFCF0F0F1F3F4F5F1F3F5EAEFEFE9EEEEE8EEEEE3EAEAEAEFF0DDE2E4DCE3E5
E4E9EBDEE2E4DCE0E2D5DADAD9DEDECCD1D1CACFCFC9CECFC4C9C8C5C9CBC0C5C7B4BBBB
B5BBBCBABFC0B5BABAB3B9B8B0B5B6AAAFB1AAAFB0A9B1B2A9B2B39EA7A89EA6A79A9FA1
9797978F8A858C7F788D79698D73589A78507C9F392CE11300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050BC239E7B4C
947C589D8B71A094809B95869C9A909A9B96999D9A929995949C99969E9E949C9B919A9A
949F9D97A4A3899797808B8C949F9E96A1A19BA6A4A0ABABA5AFAE9FA9A97B87867D8889
A1ADAAA2AFAA92A19A929F9B9DAAA6ABB6B4B9C2C3C5CFD0C8D3D2C5CECECFD7D8D7DFE0
CAD1D1D7DBDEDEE3E5D4D8DCD4DADDDEE4E4E1E7E7E7EBEEE8ECEDE7E9EBF1F3F3F7F7F9
FCFCFCFFFFFFFEFEFEFDFDFDFDFDFDFEFEFEFDFEFEFDFEFEFEFEFEFDFDFEFDFDFDFDFDFD
FEFEFEFAFAFAF7F7F8F3F3F5F2F5F6EBEFEFEDF2F3E6ECECEAF0F0E9EEEFE0E7E8DBE1E3
E6EBEDDBDEE1DDE2E3D5DDDCD1D8D7CED7D4C9D1D0C8CECFC6CCCEC4C8CBC3C9C9BBC0C0
BCC1C1BCC1C3B8BDBFB8BEBDB0B5B6AFB3B6AAAEB1A3A8AB9EA1A4A0A0A19A97938F877F
8B78698F73589D79534CB9255CC52900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB921A17C4D9A7C5B9D866DA1927FA2998B9E988F9A98929897969B9D9B9CA2A0
9BA2A0A1A9A88D9896818B8B9CA7A69DA8A7A4AFADA4AFB0A6B0AF9FAAA7838F8A7F8B89
A2AEACB3BEBCB2BEBBAEBAB7B7C2C2BDC6C7BDC6C9C3CCCFC7D1D3C8CFD2CFD7D9DBE3E5
D8DFE1D4D9DCE1E7E7DDE3E4DCE3E4E3E8EBEBF1F1EAEEF0F3F6F7F1F2F4FAFBFBFDFDFE
FDFDFDFEFEFEFEFEFEFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFDFEFDFDFDFDFDFDFDFDFDFD
FFFFFFFCFCFCFCFCFCFAFAFBF3F6F6F3F5F6F6F8FAEAEEF0EEF2F4E9EEEFE1E7E8E1E7E9
E1E5E7DDE2E4D5DBDCD4D9DAD0D6D5D3DBD8CED3D2CDD2D3C9CED0C3C9CAC6CCCBBFC4C3
BDC1C3B9BDC0B3B7BBB3B7B8B3B6B6AEADABA4A09D9C959091857A8E7A67967A5CA38054
52BF282FE31600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0062C92C51BB24A47D4D9A7953997E61A08B76A29184A1958AA49D95
A29E98AAA6A4A8A6A2A7A8A5A8ACA8A6AAA8A8AEADABB2B2A9B1B0AAB3AEA4AFA8A9B3AE
B0BAB7B2BABCB5C0C1B3BDBFC0CACBBDC5C8BCC6C8C1C9CDC7D0D2CBD0D4C9D2D4D6DFE1
D1DADCD5DCDEDBE4E3DFE7E6DDE6E4E7EDF0E8EEEEEFF3F4F4F6F6F7F7F7FEFEFEFDFCFC
FEFEFEFEFEFEFEFEFEFDFDFCFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFEFDFDFDFDFCFDFDFC
FDFDFDFEFEFEFEFEFFFCFDFCF7F9F8F8F9FAF4F5F7EFF0F3EAEEF0E7EBECE3E8EAE3E7EA
DFE3E5DCE1E2DBDFE1DCE0E1D8DDDCD2D7D6CDD2D0CDD1D1CCD0D2BFC4C5BDC2C5BCBFC2
B1B3B4B0AEAFADA5A4A79C959E8F7E99836A9B7F61A47F584EBC2A5DC73034E71900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC42982A23DA881559C7A559A7C5E
9F886EA5907CAE9C8BB1A397B1A89FB3ACA8B5B1AFB3B2B0B3B2AFBCBBB8B7B9B4B5B7B2
BBBDBBB8BCBDBDC3C5BABFC3B7BEC1BBC1C5BFC6C8BFC6C8C3CACBC9CDD0CBD4D5D0DADA
D0DADAD5DBDEDAE0E0E3ECEBE0EAE9E7ECEDE9EEEEEFF2F3F5F7F6F6F6F5FCFCFCFEFDFE
FFFFFFFDFDFDFDFDFDFEFDFCFEFDFDFDFDFDFEFDFDFEFDFDFEFEFEFEFDFEFFFEFDFEFEFD
FEFEFEFEFEFFFEFEFFFEFEFEFBFCFCF7F8F8F8F8FAF2F3F5EFF1F3E9EDEDE7EAECE4E8EC
E2E5E9DEE1E4D8DADED9DBDED2D6D8CDD1D3CACBCBC3C0BFBAB7B3ABA69FA0958DA19185
9A8673998067A07E5E7CA04354C12C63CC3235E71900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE315
57C1274EBB24A98151A27E59A18262A58A71AC9682B29F8EB8A598BEADA1C3B5AAC7B9B3
CABDBCC7C0BFC4BEBFC1BCBFBDBBBDC1BFC2C7C7C7C5C6C4C9CBC9D0D3D3D1D7D6D0D6D5
DAE1DFDBDFE0DFE3E4E6EDECE5EDEBEBEEEFF2F4F3F7F7F8F9FAFAFBFBFBFDFDFCFDFDFD
FEFFFDFEFEFEFDFDFDFEFCFDFEFDFDFDFDFDFEFDFDFEFEFEFDFEFDFFFFFEFEFEFDFDFEFD
FDFEFEFCFCFDFDFDFEFDFDFEFCFCFEF6F6F9F7F8FBF2F3F7EDECF0EBE9EDE8E6E9DFDBE0
DAD7DAD2CDCFCAC3C2C0B6B1B9AEA4B0A195AD998AA28B74A28666AB8A6282A54757C22F
61CB3468D03400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005DC52B54BE28BA8D5A7E9F3FAA8158AB8563B59075
B59380B49686BBA193C4AB9FC9B3A9CEBBB3D0C3BAD7CCC3D8D0C8D8D2CEDDD8D6DCD7D5
E1DFDEE7E6E9E6E7EAE9EAEDE7E8EBE6E6EAEEEDF1F9F8FBFEFDFFFFFEFFFEFDFEFEFDFF
FDFEFFFFFDFFFEFEFFFFFDFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFCF9FB
FCF8FAFBF6F7F7F1F2F4EDEEEEE5E5E4D9D7DBD0CCD0C2BDCDBBB5C4B0A7BAA497B39A8A
AF947FAC8F76AD8D6FB38E68BB916259C63262CC3768D1376BD23300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0037E81A6CD036
66CC345FC63159C22E55BF2D55C03052C03280A84DB3916CAE8E6DAF9075B2967FB79D87
B9A290BBA698B8A799BCAA9FC8B6ACC6B4ACD0C0B8D3C2BBD8C8C0D6C6C0D5C6C1D8CBC7
D8CAC8D6C7C4DBCBC6DAC9C4DBCAC4E0CEC8DECBC6D8C6C1D5C2BDCFB9B5C9B2AAC1AA9E
BBA393C0A492BB9E88B99B83BB9B80BC9979BF9973C0986D5BC8375DC93663CD3967D038
6CD3396CD23637E91B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0106283 0.488926 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF800000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0106283 0.732558 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE1152FE11600FF005DC32B
5CC42D5DC52F5AC42E88A645B8895CB8885C5BC533AF875FAF895FB08C60AD895EAF8960
B0885E59C533B18860B0875EB1885F58C43359C4335AC53400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002EE1165DC22C5CC52FBA8A5DBA8C60BA8B62BD8C65BC8F68
BC926DBC9472B89472B89676B9987CBB9A82BB9E8B988579887D73A194829889758F7E6E
A99686BDAA98BDAB9ABEAD9CC2AF9BC3AD99C6AD9AC4A9976ADD5767DC5466DB5361D64E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32C
5BC430B6885E89A84AB98F65BA9068BD9773C29F7EC6A488CEAD95D5B29BCDA991CBAA91
CDAF99C5AC9AC5B19EE0CFC1D1C6C2A8A0A1CCC4C75554632C364F76808DC7C9CCAFB3BA
9CA6B4B9C6D5BAC9D5778994CCD6D8D9D7D3D9D3CEDBD4CFDBD4CFD9D2CCD6CEC8D5CDC8
D7CEC7D1C9BDD1C5B8CFC2B49ACF8769E35F68E05B67DD5863D8525DD14957C83F51C136
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32D88A5445DC734BA9168BE9977
BF9B7FC8A68CD2B298C8A992C4AA93E3CFBBE7D5C8DAC6BBDBC7BBDCC9BBCBB6A7C8B3A5
E1D2C7E3D9D2D3CAC4D9D1CCB8B4BA676673B8B4BAC6C2CBABB2C6A6B4CCC8D7E8AABCD2
223D661B3C696683A75069858D9FB3CCD5DCD3D5D5D5D6D5D3D2D4D1D3D4D0D2D2D0D2D1
CFCFD0CECDCBCFCDCBCECDCACDCAC9CDC9C7CEC9C5CEC6C4CEC7C3CAC2BCC6BBB4C4B6AB
BCAB9DB3A08EB29B8A86B36758CB4150C13500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002FE1155DC52D5DC52FBA8C62BF936DC19976C7A386C6A68DE5CBB6EAD7C5
D1BCABCBB3A3E5D3C6E7D6CCD1C1B6DFD2C9E1D5CDD1C4BCC6B6ADDDCFC6E4D9D4D7CBC6
D8CEC9DFD7D3B9B1AEC7BFB9D9CFD0DED8DDCCCACEDCDADFC0C6DA364A714A6388A1B2CC
4E6082354E766F88A7C1D2E7A5B6CBB3C5D5CED7DDD4D8DBD4D5D9D3D4D6CED2D5CFD3D5
D1D2D6CFD0D3CFD0D3CBCECECDD0D0CBCECDCDCECDCACBCCCBCACEC8C9CAC7C6C5C5C3C0
C4C1BDC4BEB9C3BCB8D2CBC6D3C9C1CDBFB6C1AEA2AE968454C43D28DE1900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE116
5DC42E8CA747BC8F64C59870CBA17DCEA68ACEAB94E2C7B4EFD9CBCFB8ACD1BCAFD7C6BC
DCCCC2D2C2B9E7DAD1E1D6D0D8CBC1D0C2B7D9CEC5E3D9D1DBD0C9DED3D0E3DADADED4D3
CCBFBBD4CAC6DFD9D6D7D3CFDBD6D3E0DFE1A9ADB7ACADB8BDB9C87276936D7996BCC8D9
C7D6E7A6BCD46F8DA8A3BFD76B85A14B6B87C3D6E2D0D9DDD6D8DBD4D7DAD0D4D5D0D5D6
D3D5D9D1D4D5D1D2D6CACED1C9CED0CBD0D2CBCFD1C8CBCECACBCFC7C8CBC6C7C9C5C6C8
C4C4C7C7C8C9CBCCCDCACBCCCCCCCDD0CECED0CECDD2CACAD0C2BDC1ACA583AF6829E11E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42E8DAB4BC0926B
C69976CCA284D2AB8FD5B295D9B7A0E2C1AFD3B6A7D8C1B2DCC9BBD4BFB1D1BDB0DFD0C7
EDE1D9E0D2CAD6C7BEDBCBC4DFD3CBDACEC5DFD5CEE7E1DCE8E1DED4C9C8DDD3D2E0D7D6
DCD2D2DBD1CFE4E0DDDCDBD9CDC8C6D2CDCCAAA7B0ADA8B2D1CBCDDAD9E2B3BFD38195AE
ADC4DB4B6580183B642B4E739AB0C9657B94AABECFCEDBE0D3D9DCD1D6D7D1D3D5D0D4D5
D1D5D8CFD4D7D2D6D9CDD1D4CCD0D3CBCED3CBCED3CACFD2C8CCD1C9CBD0C6C6CBC8C7CC
C5C4C9C2C4C6CBCCD0CFD0D2CED0D4CDD0D3CBCDD0CBCED0CECDCECEC9CBCDC4C3C8B9B6
AC979048BE3A24DD1900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC22C5DC52FBA8C5FBB9266C19B77CBA588D3AE93
D3B098D3B29DD7B6A1D9B9A1D9BBA6E2C6B4DAC0ADDAC1ADDAC5B5EAD9CBDFCDC0DCCCBE
E0D2C7DDD0C7DACBC1DFD1CAEAE0DCE9E0DCDACFCCDED6D2DFD7D4DCD2D0DED4D3E9DFDF
E9DFE2D9CECEDBD3D1D0CBC8CDC7C4D3CBC8E7E2E2DEDBDFC9C9CCD4D4DC717C9720375E
6C819DA0AFC46E7F9B6C829DC4D5E7C5D8EA87A0B6B8CFDBD1DADDD5D9DCD5D6DAD4D8DB
D3D6DBD2D6D9D3D7DAD1D5D8D1D2D6D0D1D5CFD0D4CBCFD2CACFD2CBCED3CBCCD1CAC9CE
C2C3C7C1C5C8C7CBCECED3D4D1D5D8CDD2D5CACED1C8CCCFC9CFD2C5CACFC9CBD0CCCBCF
CAC6CCA6A2A9938B8B78675A5883301BD30B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF005AC42EB98A5FBE8F67C39A72C9A07DCDA889D0AE94D4B59DD0B39D
D2B6A1D5B9A4DABAA5D9B9A4D6B9A4D8BEA8DCC3ADDCC6B1DFCCBBE6D7C9DECFC1DECDBE
DDCFC3E9E0D7E8DED6E2D7D2E7DDDAE6DDDBE2D9D5E2DAD6E9E2DFE9E3E2E3DAD8E2D6D7
E4D8D9DDD2CFDBD0CCE8E1DEE7E3DFDBD7D3E0DBD9CED0D579808BB5B7BEB7BAC68692A8
9FADC0CBD9E5D0DEEB9BB0C75B789992AFCE28486A6989A3CCDBE6D4D8DDD6D7DCD2D6DA
D1D7DAD2D6D9D3D5D9D4D5D8D1D4D8CFD2D7CED1D6CDD1D5CCD0D2CECFD3CDCDD0CBCCCF
C9CBCFC7CCCFC9D0D3CED5D6D0D4D8CED3D7CDD0D5C9CDD2C5CBD0C6CED1C7CCD0C9CBD0
CCCBD58081933B425B3942526363637467533CAF2100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
88A44489A749B88E64BC956AC59D77CAA483CCAB8BCFAF94D2B39ACDB199CFB59ECFB5A0
D4B9A4D5BAA5DABDA8DCBEA9D9BEA9DBC3AEE4CFBCE0CDBCE0CDBEDECCBFE0D1C4E5D5C8
E7D9CDEDE2DAEAE0DCE6DAD6E3D9D4EBE3E2E8E3E2E1DBD8E7E0DDE8E1DEE0D7D5DCD2CF
E7DFDDE9E3E0E0D9D6E5DFDCE6E4E0CFCECACFCBC8D8D4D5C2C1C8C6C5C9D9D9DACBD5E0
7189A0668199ACC0D3566D8A11346454759A95AEC87490A7C5D9E7D2DAE2D4D7DCD3D7DB
D2D7DAD0D4D7D1D3D6D3D4D8CED2D5D0D4D7D0D4D7CED2D5CDD1D4CED0D3CDCED0CBCED2
CBCFD2C9CFD2CAD2D5CDD2D5D2D3D8CFD2D9D1D3D8CCCFD4CACFD3C1C8CBC7CACFC8CACF
CACCD1B7BAC6575D71838EA36F7A89878C8FA2989066944600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42F8AA84A
BB8E6ABF9773C29E7BC6A382CDAA8DD1AF94CDAF96CBAF97CAAF96CDB399D4BAA2D1B7A2
D4B9A6D9BEA8DEC4AFE1C7B5DFC8B6DBC6B4E1CDBAE4D2C0E6D4C4E6D5C7EEDFD5EDE0D6
EADDD2ECE0D8EBE1DBE9E0DCE6DDD8EDE6E2EBE6E2E4DCD8DFD5D0E2DBD6E8E4E1DFDBD9
E2DEDDE6E3E1E0DAD7D9D2CCD9D6D2DAD9D9D9D4D3E2DBD9E2DEE0CFCED2C3C2C4B2B6C3
304668223D637D91A8B7C2D67489A88CA7C3CAE0F494AEC57091AAC7DAE8D2D7DFD2D5DA
D2D7DAD0D4D7D1D5D8CFD3D6CED2D5D2D3D8D1D3D8CED1D7CACFD3CCD0D3CCD0D3CBCFD2
CACED1C9CED1CBD0D4C9CFD3CED1D6CED3D7CDD2D8CED3D9CAD0D6C5CACECACDD2CACED2
CACFD3C7CCD1AEB6C28E9CAD90A1B297A7B6A1A9B1ABA5A26E9C521CD20C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0059C22D86A646B58C61BA926BBE9774
C29C7EC49F82C6A386CAAB8DCDAF95CDAF98CFB29DCEB19BCFB29BD1B79ED9C1A6D6BFA8
D8C0ACDCC4B0E1C9B7E2CABAE4CDBDE1CAB9E4D0BCE6D5C0E3D6C4ECDDD0ECDCD4EDDCD4
EBDCD2EBDED6ECE3DCEEE8E2E9E0D9E6DAD3E1D8D0E3D9D4DDD4CEE4DDD7E8E4E0E4E0DD
D6D0CCDBD6D1E0DCD7D9D5D0E0DCDAE8E5E5E3DDDCD7CCCBD7CED093949B9B9CA1D0CED2
B1B6C6A2ACC1B0BBCCD0D9E4ACBED34060857191B26A85A425466CA2BBD1CED7E0D0D4D8
D0D5D8D1D6D9D0D5D8CED3D6CFD3D6D0D1D6CED2D7CBD3D6CAD1D4CBCFD2CCD0D5CCD0D3
CBCFD2CACED1CCD0D4CDD1D6CCD1D5D0D5D9CED3D7CDD2D6CED3D7CFD4D8CACFD3C8CDD1
C8CDD1CBCFD5999FAD293A513E5570364A654153677E8891958C8B8F74651ED41000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002DE117B3885EB88E68B8916CBD9876BF9A7AC29F84
C5A289C7A58CC9AB91CAAD93CFB39BCEB39DCEB49DD0B7A0D1B9A3D2BBA5D8C2AAD9C5AE
DCC7B4DAC6B2DFCBB8E1CBB9E2CCBAE4CFBCE7D3C0EAD7C5E8D9C6EBDBCCE9D7CCE9D7CD
EFDFD6EADBD1E7D9CEE7D9CFE3D5CCE2D4CBE7DCD6EBE3E1E7DEDBDAD0CBDFD7D1DED9D2
DAD3CDDCD7D2E8E5E3E7E2E2DAD1CFE0D7D4D5CCCBCFC4C3D4C9C7DAD5D7D4D0D3CCC8C7
DCDDE2BCC6D3697D948196AA7F92AC1C3B6737587FC0D2E88C9EB49CB3C5C5D8E1CCD6D8
D3D8DBD3D6DBCFD3D6D1D5D8CED2D3CED2D5CED2D6C9D1D3CCD1D5CDD1D4CDD1D4CBD0D4
CBCFD2CACECFCDCFD3CBCFD2CACFD2CED3D7CCCFD6CCCFD5CBD0D4CED1D8C9CDD5CBCCD5
CBCED6C9CCD3BCBECA5F697D7B8BA1576A7E8191A488949FA6AAAFBCB4B2A98E851ED511
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0058C12C57C12CB1885FB9926DB99574BD9B7DC1A183C1A386C5A88D
C7A78EC9A991CEB29BD0B7A0D0B9A2D1B9A5D1BAA7D6BFACD6C0ADDAC5B3E0CBB9DEC9B6
E1CCB9E2CDBCE2CDBBE0CDB6E0CBB5E2CDB9E7D2BFE9D7C4E7D6C4E8D7C6EBD8C9E8D5C7
ECDACDE9D7CAE8D6C7E6D6C8EBDED4EADDD4E7DDD4EADFDBE1D7D2DCD0C8DED3CCE8E3DC
E7E4DEDAD3CEE3DBD7E3D7D6DECDCCDACDC9E9E0DDE6DEDBD2CAC6E1D9D7D8D5D7AFADB0
C6C3C89FA2AF44516E5E6D86D2D6E6A2AAC18998B4B8C9DCB8CCDE496A8390B1C6C8D9DE
D0D6DACFD4D8D0D4D7D1D5D8CFD4D4CED2D5CED3D6CDD2D5CBD1D5CBD0D3CDD1D2CBCFD2
CDCFD4CACECFCFD0D4CDCED2CBCED1CBD0D3CDD0D6CBCED5CACFD3CACFD5C8CCD5CACBD5
C7CAD2BFC2C7CBCCD3ACB3BF8996A793A6B68494A68797A29DA5ACAAACAFC1B7B89A7F75
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0083A243B2885FB68E65B69067B99570BB9878BB997CBD9D82C0A28BC0A48DC4A68E
C9A992CFB199CFB49FD4BCA9D5C0ADD5BEADD6BDADDAC4B2DBC7B3DDCAB8DDCBBADDCAB7
E0CAB7E1C8B8E0C8B8E1CAB6E3CDB7E1CBB8E6D1C0E4D0C0E5D2C0E8D5C3EBD9C8EAD7C8
EAD7C9ECD9CAEAD8C8E7D6C7EBDDD2E8D9CFE6D7CDE1D3CBE9DFDAE7DCD8DDD1CBE5DDD8
E3DED7D6CDC6D6CBC5E5DBD6EBE0DEDBD0CDE9E0DCE7DFDDCFC6C4CCC3C2C5C6CE92939F
C9BAC3EDD7DFDCC7D5D9C2CFD9BDC6DEC6D4675F7C2E3E618198B53551724C6D8CC6DAE5
CED6D9D2D7DACED3D6CED4D7CCD3D6CCD2D5CFD4D7CDD4D6CCD1D4CBD0D4CBCFD2CBCFD0
CCD0D3CACFD2CDCFD3CCCDD1CDD1D4CBCFD2CCCFD4C8CBD0CBCFD3C5CBD1C6CBD1C8CBD2
CACBD3C2C5CCCCCBD39D9FAD2D37504C607B2B415A536779808F9B878F969C9A9FA19492
668E4500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C12C
86A749B68D68B8936EBB9672BF9C78BE9A7ABD9C80BD9E84BFA288C0A58DC3A791CEAF9B
D1B39ED1B5A1D0B5A4D7BCAED9C1B3D6BFB0D7C1B0DCC7B5DBC7B6D8C5B4D3C1ADDBC7B2
DFCAB5E1CBB8E1CABAE4CEBAE2CCB7E2CFBCE7D4C4E7D4C4E4D0BEE6D3BEEBD9C6EAD6C6
E6D1C2EAD8C9EAD9CAE7D3C5E6D2C5E7D6C9E5D6C9E0D3C8ECE2DAE8DFD9DBCEC6DACCC3
DED5CEE2DBD5D9D0CCE8E0DDEAE4E1DAD0CDD8CCC6D7CECAC9C0C0C7C1C771778E7F7B9C
AF7C96C47283CE7082C65F6FB74956B64C5A9F5066513B59959EB4B8C7DB8A9FB4B9D0DE
CBD6DDCFD8DACFD4D8CAD1DAC1C8D6CBCED9D3D0D6CFD0D4CDD0D3C9CFD2CACFD2C9CFD2
C8CFD2CACFD4CBCFD3CACED2CDCFD3CDD0D5CBCDD2CBCBD3CCCED3C8CDD1C8CDD1CACDD4
CBCBD1C9CCD1CBC9D2B5B0BD5E5F756C78904F60778798AA8998A5AAB5BDBCC0C7B9B8BB
B5A29F44B22B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002AE015AA8559B28E65
B8926CB7916EBA9776C0A07FC2A282C1A184C4A38AC2A48CC4A891C9AE98C8AC98CFB2A0
D4B6A4D6B7A6DAB8AAE4BBB0DBB0A4DFBBABD8BDAAD8C1ADD9C3B1DBC6B3D7C2AEDFCAB5
E1CDBAE1CEBEDECABCE4D0BFE6D2BDE6D4C1E8D7C7E9D5C5E7D0BEE6D0BCE9D2C0E9D2C0
E8D3C0EAD6C6EAD7C9EBD6C8E8D5C6EDDCCEEFDED2E3D2C5E1D1C6DCCFC6DCD1C9D7CBC6
E4DCDBE7E0E0E2D6D4DACAC7E1D2CFE1D1CFD7C7C3E2D5D3E6DCDED9D1D987849E463766
8F416CA3203CB6172ABB111EBF0F1CBA101BAB202EDC9AAC9894A8B7C5D96B839E496B89
BDD3E2CCD4DACED3DBB5BFD1464D6E806D8BCAA8BAE0C8D2D5CCD1CECFD3CCCFD3C8CED3
C5CED5C6CED8C8CFDAC9D0D6CDD2D4CACFD2CACFD4CBCFD6CACDD3CACDD2C9CED3C8CCD4
C8CBD1C8CBD0CAC9D2C2C0CA9F9EAE737C90919EB38A9BAA909EA9A1AEB5ABB5BAADB2B7
AEA6AAA68D8400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02DAC855FB18E69B49270
B69271B89376BE9D81C2A488C3A68BC3A68EC5A691C7AA96CCB09CD3B6A2D5B6A3DAB9A7
D9B1A0D5A598E1A89DCD867DBD7166E0A694DBB7A1D6BBA6D7C0ABD7C2ADD6C1ACDBC6B2
E4D0BEE4D1C2E1CEC0E0CCBBE2CEB9E1CFBCE9D7C6E8D3C2E6CFBDE7D0BEE9D4C1E9D3BE
E9D3BFE8D1C1EBD4C6E7D1C3E8D4C4E7D3C4E6D2C4E2CFC1DECDC1DDD5D0E5E1E1D5C9CF
CCB6BFDEBDC4ECBCBFEAB2B2F9C2C3FCCDD0F6C9CDEABEC1F0CDCFDCBFC4C2ABBE513A64
854673A22C4AB81425C50B14CA0B13C80C13B80C18BE4D62503056556285788CAD243F63
9AAFC7CAD5E0CCD3E08E96B138265182355A8B1F3BB0596DD8A0AFDFC0CCD6C5CFC4BBC8
ADAABD8B8AA36C6A83A9ACB7CACED3CED2D7CCD1D7CACED5CACDD4C7CCD1C7CBD3C5C9D2
C7CAD2C8CBD3C7CBD2C9CDD27E8291232F484C5D75394B6160728396A6B098A3AB9EA0A7
948F9497828042B02700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002AE017AB835EAE8867B08D6EB39274B79578
B89478B9947BC2A188B19176C2A38CC3A693C4A695D3B4A1D6B3A0DCAE9EE1AB9BD39787
DE998AB56959EC9A8DBB5E54CA6B5DDA927DDFB49CD8BCA5D3BBA5D8C2ADDBC5B0DCC7B3
E2CEBCE4D1C2E3CEBEDCC5B2DFCAB5E0CEB8E4D1BFE8D3C3E5CDBDE5CBBAE4CCBBE6CFBC
E6CDBAEAD0BFE9CFC2E7CFBFE9D0BEEAD0C1E4CFC2E5D6CCD6CDCDB9B4BFA18EA3AD768F
C16279C85062C7404EC83743CB3847CE4151D04858CF515DD76972DE838FECA4B79E6485
722B53BD5271B51A2CC50C15C7070FC90810C20711AF1C2C95516E5E5B78CAD5E9A4B5C9
95ACBEC3D4E3BEC6D94D45666E3455951C31A3091BA20B1F9A172DA2364BA74C628D425B
7A334F77334E6E30479C7D86D3CED3D1D0D5D1D2D7CECFD4CBCDD2C9CDD4C8CBD2C8CBD2
C7CAD5C6CAD4C8CBD2C8CDD49294A05C6173687386425062808E9D93A2ABAAB3BBBBBFC6
B3B1B7B1A3A891746900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB82350BC2A7CA043AA8662AE8A6BB18F72B19075B3937AB6967C
BA987EC09F87C6A78FBB9A83CAA995CFAC9AD8AFA0DEADA0E5A69ABC655AB64F43D36C5D
D2745FBF654EED927CB85545DD7767C87663E2B29BD5B7A0D5BBA5DAC1ACDBC4AFDEC9B6
DFCAB9E2CDBCE4CCBBDFC7B5DDC8B4E0CCB7E5D1BCE7D2BFE1C9B7E4CBB7E2C8B4E6CBB6
E6CCB6E9D0BDE9CEBEE8CFBEE8D0BEE9D1C2E4D1C7D4D0D58685A17F5A82B35476C03143
CB212AD21F23D21B1DD21B1CD31B1ED21A1ED11A20CE1A22C71823C41E2DC0263ABD2F49
B42C46DB4B5FCB2732C80D13CB090FCC0910C80910B20D15DC7B88A6889C87879F8A93AD
2E3E62757CA16852757A39589C263BA70917B0040FAF030FAB0311A60615A308189D0A18
980C1890151B852E30D3AEAFD3CCD1CECECFCFCFCDD0CFCECBCCCEC9CCD0C8CBD0C7CCD2
C8CDD4C4CBD3C4C8D2C4C7D0B1B3BC9295A07A818D858F98879199879198979EA5A6AAAF
A4A3A9ABA6A9B1A19D43B42B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0047B6267F634992745BA88668AB886BAC896FAD8B72B08F77B09076B5967C
BC9C83C1A38CC6AA95D1AF9CD6AB9ADDA899CA8477AC5448DE7C6EC35B4CC65544D8634D
C95D45D26F56E28069BF5944E27968BA6451E6B09BD7B7A1D9BFA8DBC2ACDEC6B4DDC6B6
DAC3B3E2CBBBE0C9B9DFC8B8DBC4B3E2CAB8E7CEBDE7CEBDE2C9B5E3CAB4E2C9B3E4CBB5
E6CDB8E7CEBBEAD0BFEAD1BEE9D0BEE7D0C0DFD0CC8C90A85B4D7FA94C79C62438D41D20
D21D17D0221ACD251DC92623C32626C42A2CC4282CC22229C21F28C21A25C21823C01421
C01420C2121BC81217CB0B0ECC080EC8050BC7060CBF0910B728349740585C2B4D805579
6432597E375C9C324EA5192AAE0915B3030EB3020CB1020BAF020AAD020AAD030BA90509
A00D0E91241DC48C85DCCCCACFCDD0D1D0CAC3BEA5CBC2A6D0CDBFCDCFCDC7CCD1C6CCD4
C7CBD4C5C9D2C4C6D2C4C7D0C1C3CF6368792E384A64738346586467767E9CA4ABA4A8AC
97959A938D9193878546BC3600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25DB11648D3C5C4D4A272429766C65A38974AA8971AB8A73AC8C76AD9079B0947EB69A84
BDA18BC3A792D1AF9CD39E8FB86A5EDA8272B45845C6604CC9624EEF8F7BD7735ED2614D
BE4C37E0705BC14F37BE5339F08F78AA5540E7AD97DCBAA5DABEAADBC1AEDBC2B1DBC4B4
DCC5B3E2CBB8E0C9B7E0CAB5DEC9B3DEC9B3E5CFBAE3CBB8E1CAB5E5CDB7E3CAB3E5CDB5
E7CEB8EAD0BCEAD0BDE9D0BCE8CEB9E7CDBCDCCCCC5A6183684E86AC3459CD2225D02E21
D04938E17364DB8074C97C76C98585BB787FB5717DB26979AF5F71AC4E61AC4252B03947
AE2A38B32430B41923C01218C60B10C9070EC9060EC4060EBB0A15B81C2CB02437A51C30
A4152AA80E21AD0715B2060EB3010BB5010AB4020CB00209B1050BAD0509A9080A9F0F0D
972A24C4897FDAC7C3CFCECECECED1D3D2C5B7AB7DB8A65DCEC392CFD0BDCACFCEC7CCD1
C9CDD6C7CAD2C6C8D4C8C8D2C7C8D6676A7C585C6F5B67783E505D80919A9DA9AFAFB8BA
C5C8CDB3B2B7B1A9AC85726800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0024DB13
816850403C400E19360A173569676EA08A7AA78973AC8F78AF937EAC927EB49B88B99E8E
BDA291C5A896D4AB99B16B5BBB5646B44835D87A61DF836ABE5942D26755C45743D56A53
B0432EB94C35CB6A4ED7896DEEA88FA45A42E5A891DDB8A2DABEA9DCC0AFDBC0B0DDC4B3
D9C3B0DDC5B2E0C6B7E0C9B6DDC7B1DDC6B0E6CEBAE3CDB8E0CAB3E2CDB4E0CAB2E6CEB6
E6CEB7E8CFBAE8CFBBE9CFBCE7CEBBE6CDBCE2D1D06D6F8F5D437CA3395BC63935EE8570
FDBFADFAD2C5E2C1B4E5CABEE7D0CADAC5C2D2BFC0E0CCD3DCC6D2C4A7B6A9829492697E
8458747C4B6A823F5FA83A4FB5121EC3070FC5040CC7050DC4060EBF0811BB0911BA0A10
B8070EB9070EB6040BB40309B40209B3030BB1050CAB0608A70B0AA0100C9B1F19A64E45
D5A39DDBC9C5CFCECEC9CED0CDCFD2CFD0C8C5BC98B8A255C0AB5CD2CB9DCED0C2C5CDCC
C6CDD3C7CDD5C4C8D3C6C9D3C7C7D59594A38887956C727D7C848A8C96988F979A999EA2
AAABAFAEADB3B6B2B8A496941AD10E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC12765F48
2D2E390D1E42011648031541595B6B9F8E82A88E7AB09681B29A87B69D8CB69B8DBEA294
BDA18FBD9F8ACAA28DAB6D59DD8673B14C39D6715BCE6851C65A45BA4834C0543FE48E74
D1896EDC9C7FDDA98CDAAE96DDAE99BC8770DDAD95D7B69FD9BEAADCC0B1DCC0B1DEC4B2
DBC1ACDDC2AFE2C8B6E2CAB9DCC5B4DDC7B4DFC9B4E4CDB6E4CCB3E4CBB3E5CBB4E5CAB5
E6CAB8E7CCBBE8CFBDE7D1BCE8D2BDE6CFBDE4CFC6A69CAF5547728E516CD27E78F3BBA6
E6C9B6E5D2C3D7C5B5D6C4B5DCCFC5E8DEDADCD1D1DED4D3E8E0E0D7CBCDCAB7B7CEBFC0
C9C1CE9D9AB646436D603C69A12B47BB0C19C70710CA0810C6030CC1040BBD0A0BB6110A
B2110DB0110FAB0D0DA90F0FA80E0FA5100FA01511971C159C332AAE5F53CE9A91DBC2BD
D4CBCACDCDCFCBCED1C9CED2CBD0D4CDD1D2D2D0C2C7BB8DB7A159BFAE69D0C9A3CACDC2
C7CBCEC6CDD3C2C9D1C4C8D2C4C8D4AAADBA52566A303A4D74818B5C6A71869197A6ACB0
A6A5AAA29FA6A09AA292848737A82400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0094725542393E
0A183F061D5601165604184E454E679C908CA79082A89181A89381B79E8FB99D8EB99E8B
B59A83B89C84C09F87C99B85C87E6CB34C3CCC5746AD3B26E57D66C15B46D8735FD4866E
DBA68AD4AA8FD0AC92D0AF97D2B09AD2AF99D6B69ED8BCA6DAC0ABDBC1B0DCC3B0DAC1AB
DAC1AADBC0ACDFC6B3E1C9B8DDC6B3DBC4AEDFC6AFE5CDB6E4CCB5E3CAB4E5CBB4E5C9B6
E7CCBBE7CEBBE8D0BAE4D0B7E4CFB7E2CCB7E4CDBDDBC9C7847784C3A7ADE7C0B3E4C6B1
DDC9B3D8C7B4DECEBED8C6B9DCCCC3EADED9DDD2CDCEC2BBD2C6C1DCCFCED5C7C5DBCFCC
E1DADEE0DDEC888BAD322A6195446DB01327C40912C7070DC8050DC00609BB1911D55846
B75344AE5044A447459F4A49AC5B54B1685DB97B6ECA9A90DAB8B1DAC7C3D3CBCCCECED0
CBCED1C8CCD0C8CDD1CACFD3CAD1D7CAD0D6CDD0D1CFCEC0CFC09BB8A666C1B071D4CDAF
CACCC7C6CBCFC3CAD0C2C9CFC5C9D2C0C4CE40425843455D595F6F525D688C98A1B0BAC0
B6BBC1C3C4CCC3C1CAB3ACB05A894500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC10A6835D937B6D4B475B
06164902175901185E051B5A333D6290878AA69184AE9785AF9783B59A88B49685B3947F
B79A7FB99C80BD9E85C59C84C47E69A43E2AD25B4AC85744E68570CA6A56A4442CBA6D52
D4A285D0AC90CEAD93CCAC94CFB09ACFB4A0D5BBA9D6BDACD8BEACDAC0ACD9BEABD9BEAA
DABFAADCC2AEDFC8B3DDC7B2DDC6B0DCC4ABDDC4ACE5CDB7E4CEBAE2C8B5E5CBB6E1C7B2
E4CAB7E5CCB8E8D1BBE6D0B8E4CEB8E4CBB9E4CCBBE4CEC0DAC5BBDDC8B9E1CBB8DCC8B2
DAC6B0DAC7B6E8D7C9DBC8BBD7C2B5D9C5BBD8C8BFD6C4BCE0CDC8EDDCDBEDDADCD3BCBD
E2CACCE3CCD4C7B0C6553C678A426DB12239C20A16C6070DC30409BF080AAD0D0CDB6B66
8F4C4C916266AA838E5A3D4EC8AFB7E1C8C8E0CAC8DBC9CAD4C9CBD3CDD1D0CCD2CDCED2
CBCDD1C8CCD0CACED4C9CDD1C8CDD1C9D0D2CCCFCECDCFC6D4CDB6D3C58DBBA854CABB7B
D0CBB2C9CCC8C6CACEC6CBD1C4C7CFC8CBD371717F72707F6E717A868C938D949C9398A1
9C9FA8A2A5AFB4B6BFBCBAC18C7B7900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006E973BAF957E917F7B54546B
06174A01155C011764031B6124305B968C94AC9689B19886B19583B0907DB08F78B39178
BA997DB8997CC09F84CA9D87CA806DBE5A44CE5C46A93A24B3563DD68E72D29679D4A587
CCA68ACBA98DCBAB8FCBAC93CCB39DDAC8B8E7D7CCE1CDC2D9C0B2D9BEACD8BDAAD8BFAC
D9C2AFDAC4B0DBC5B0E2CCB6E0C8B1DBC2AADEC7AFE4CDB9E3CBBBE4C9B7E1C8B4E2C8B4
E6CBBAE2CCB9E5D0BCE6D0BCE6CDBCE7CFBCE6D0BBE4CDBBE2CBBADEC9B7D9C9B7D8C8B6
DAC0B0DFBCAFE2BCB1E1B9AEE7BAAFEABBB5FAD0CEFACBCDE6B1B3F1B8BDEEAEB4DB9096
D48288E48F98E6909FAF516BB43A57C62739C10812C4060DC2050BC2060CB6050DBE2932
A32C3B953243B55D707E2E47B36E85D296A4D59FACD9A9B5DAB3BEDBB9C3DDBFC9DDC6CE
DAC7D0D5C7CED2C8D0CEC9CECCCCD0CACCC9C2BDACCDC49ED0C387C2AF51C0A82DBFA938
D3C582D1CBAECCCCC4C8CCCBC4CACDC6C9CE8C8F9D464D60616E7D81919E73828C97A0AA
AFB2BDA6A6B09E9EA69A979F7F6E7000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007CA44BAF98819484749D8F8B4D4D62
0D1F53021962011668031763192654968E96AA9387AE9383AD917FB3937FB49279B59277
BA987DB8997DBD9C80CD9B839A4832A8482DD57F60CF896CD59B7FD0A387C8A489CAA98F
CAA98FC9A98ECAAA91CAAD94CCB8A4E9DFD5E7E0DDEADED9D2BFB4D4BBA9DAC0AED9C1B0
DAC4B1D8C2ADD6C0ABDEC6B2E3CBB5DBC3ABDEC6B0E1CCB7E3CDBBE2CAB8E2CAB6E2C9B6
E4CBB8E2CAB7E4CEBCE4CFBEE5CFBFE6CFBDE5CFBBE3CCB8E2CAB9DCCABCB8B5AFB6B0AF
D5AFABE19590DE7F7CDD7272D45E62D05259D24E5ACB424FC4343EC32E38C22631C01D27
BF1921C31C24C21822BE141FC00F1BC20A13C4070DC3060AC1060BBF040BBD040CB6050D
B10813AA0914A70A17A40A1AA00B209C0D229C122898142B981D339924399D3046A34456
A95566B16877BF8290C599A5CFB4BBD4C8C1B7AB8AB39F57BDA43BBCA21BBEA40BC0A610
BBA528C4B45CCCC28EC8C7A7C8CBBCC7C8C5ACABB32B2E415E6577505C6C4B596895A3AE
AAB1BDB2B5BEAFB2B7B6B7BC998F9118D00F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0079A246A89480A99D919D9388AAA19C595D6F
172B61021A6702156501145D1524518C868DA28A80AA8E7FAD8E7CAD8E79B5957CB7947A
BA967DBA977FBD9A82C3987EC2886BC38666CD9A7CCBA289C8A58DC5A78FC2A690BEA58F
C5AC97C3A991C6A990C8AD93CEBBA8E7DED5E7E0DEE2D6D2D0BBAED4BCA8DBC2ADD9C0AF
DAC4B1DAC3ADDAC1ACE1C7B6E1C9B6DBC3ADDDC3AFE0C8B5E1CAB7DCC8B2E0CCB4DDC9B4
E2CDBAE1CBBAE3CCBCE3CCBDE3CDBDE0CBB6E2CCB6E2CCB5E4CEBADDCDC3787C8A4E5472
A46B82B12B37C92226CB1B1DCD181AD0191CD0181AD3171AD31518D31617D31516D21414
D11312D21513CD1310C9120EC81211C30D11C30C13C3070EC2050CC2050CC1030ABE030A
BC040AB7060AB6090DAF050AAE060DAC060EAD0611AA0611A90814A80714A90A19A00716
9C09179B0C1A950E208D1627842E3BDAB4B5D5C8B8C8BC92C3AE5FBCA228BCA209BBA202
BDA508B8A213B59F28B2A343C3BA77C9C297C2B99E6E665B7370737173797D8388888F96
8C8F97909197949298A1A0A6AB9FA435A82600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00769D40B4A28B9C9087A79D969489819D938E757485
09194D02166100115D0112540D1A457D7882A0877EA7887CAB8C79AE8F7AB5927CB8967E
B9977DB9967EBD9982BF9A80C39A7FC2997EC39F85C2A38EBDA28EB39D8D9C8B7D8D7F73
958A7DAEA18EBEA890C7AD93CEB6A1D8C4B8D9C6BDD5BFB3D1B8A6D8BEA8DABFAADBC2AD
D8C0ABD8C2ACD9C2AFDDC6B4E0CAB4DDC5ADDDC3AFE2CAB8E0CAB7DDC8B2DDCAB1E0CCB4
DFCAB5E2CBB7E3CAB7E0C9B5E2CCB5E1CBB4E1CBB4E3CDB5E3CEB6DEC9BCAEA9B6364066
996D90B22D3DCF1E1DD41912D51A11D31B11D21D12D11E13CF1E16CE2119CB2318C72318
C5231BBF2219C1281EBD291EB62722A11721A61325B80F1BC10710C2050CC1020BBF020B
BB070AB51711AB1B15A41B14A11B149D17139E14129E1212A01111A20F0FA50E12A40B0F
A50A0EA2080DA108119E0914870D19C18286DAC9C5CFCCC2D6CDAFBCA957BCA31ABDA304
BFA603BCA004B39904B19B0DB19D1CB2A02CB29E3A8A783A45423769727B8896A0818F95
A8B0B4AAABB09C99A08D898F8B7C8235A72600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0051BE2AAE9882B8ADA69A9491C1B9B699908DB8AEAE92909F
13204E0B206401155B0214560B18477A7681A38C83AB8D80AB8C7CA98A77B3937FB4947C
B29378B9967EB99781BA9B83C1A187BD9E82BFA188B99F8C9D8B7B82726686766B877A6F
766C65726B61A89C89C5AF98D0B6A0D2B8A5D2B9A8D1B7A3D5BAA5D9BEA8DAC0AAD9BFA8
D5BCA5DBC2ADD9C0AFD9C2AEE0C8B2DCC2ADDBC1ABDFC7B4E1CBB9DFC8B5E1CAB4E1C9B1
E0C7B1E2C9B3E1CAB4E1CAB4E3CCB5E3CCB5E4CCB7E3CDB9E4CEBAE1CBBBD5C7C667657D
81637FB5545CC03226C7331FCA3D27CC482FD2563DD8624DDA6D5DDE796BDF8474E28F7F
E6988BE49C90DF988CDA988AD49A957A4459742E53A82841BA0A17C1030DC2020CBC0208
AF0808D85F54D08075B1756DB27E7A9A69699D6A68AE716AAE6864A95B57A34949A03D3C
A034319928249720219116198B181D90494DDEC7C8CCCBCCCFCDC5C6BA89BAA130BFA50B
C0A402BFA404BAA00AB39D06B39C04B39D06B19B0DA39025332C084B5056505D6B62727C
A8B2BAB5BBC1B1B4BAAAA8AEABA1A440B63500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0026DC11AA8F70B3A49DABA4A3ABA7A79B9797ADA6A6988E8F938E9A
232C5303155502145B021459061448726F819E887FA68A79AA8E7AAB8D79B1917CB2937A
B4967CB6987FB79881B89A82B89D81B99E82B8A08A9E8D7B8274669D8D7EAB9886AC9989
94857B6E6861797368C3B19FCFB5A0D2B8A2D3BBA4D2B9A2D6BDA6DABFA9D8BDA7D7BDA6
D7BDA6D8BDA8D8BDA9D8BFAADEC5AFDEC4AED9BFABDEC4B2E1C9B8E1C8B7E2C9B4E2C9B3
E2C7B3E1C9B4E1CCB7E0CCB5E1CBB4E2C9B5E2CBB7E6D1BCE4CFBAE0CBB8DECBBDC3B2AD
C1A5A3DEAA9FE09C89EAA793E9AD99ECB5A0ECB8A2ECBBA6E7B9A9FDD3C7F1CAC1E1BBB3
F3CEC5EBCCC3CEB4ADBAAAA6D0C0C5B397AC622B51B3435FB60D1BC2050CC3040BBF0409
B2080BBB4140DC9EA255374968647C7A8397657080CDD0D7D0CCD2CFC1C7D7BEC3DCBBBB
D9B2B0D0A7A4C59795BA8482AA70718F6466D2C2C4CCCDD1CBCCCBCFC9ADB9A44BBCA511
BFA504C0A90E8F7B079E8F11AC9E10B7A40AB39B04B09B198B7C337B776474787A858E93
90959B8F949893959A908F94A69FA2806D6800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0078A045BCAB9EBBB3B39E9C9DC9CACC989799CDC9CB91898CBCB8C2
39406102124C01145A011459051348625F7298827AA68875A88975AA8B77AF917AB0917A
B2937CB3947CB7967FB99980BB9C80BB9F85B19D8A7D7164918577A99787AE9985AF9C89
9F9084766F6B69645FBAAA9DD0B6A3D3B9A3D4BAA4D3BAA4D7BFA8D4BCA4D5BBA4D8BFA7
D7BEA7D7BCA5D7BCA6DBC1ABDCC5AFDDC7B2D8C1AFDBC5B3E1CAB7E0C9B7E0C9B7E1CAB7
E4CCB8E1CAB5DEC8B3E0CAB5E1CBB7E1CBB9E0CCB9E4CFBBE4CFBAE3CEBBDEC9B8DCC6B5
DBC1B2DAC1B2D3BEB4C6B3B0B89D9EBF9998D9A7A1EDB1A7EDABA6F4B1B1EDA4A7DE8E90
D08080C48281E0B9BC6460757A7595A8708DAB3E56C32F3FBB0A14C4060DC3050CBD0409
B8070DAD131DB740527C2542572A4DA297B079859B899BB75C648271617D9A768ACCA4AD
D4AFB5D8BABDDCBEC3DEC3C6DCC6C7D3C6C7CCCBCDCAD0D3CBCFCFD1CFB9BAA858BBA414
BDA504BDA7127D6B183D38035B570C9E971BAD9F0CAF9E0EB09F31867F4397987D9AA295
A6ABAAAEB3B5ADB0B3A4A3A8928B9179646600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0029E015AC967EB4ACA9A8A6A9A3A5A8B9BDC0AAABAF9F9CA18E868C908893
40435E031146000F530211570312465B5A6E99847DA08472A38673A78A75AC8C77AD8C75
B2927AB4957DB6957DBB997EBB9C80B99E859A897A736961978B80AA9889A99887A9988A
96898278717068635FB3A496CFB6A0D2B8A2D3B8A4D6BCA7D6BDA7D2B8A1D6BAA3D7B9A3
DBBEA9D7BBA5D6BBA4D8BFA8DCC3ADDCC5AFD8C2ACDCC4B0E2C9B7E1CAB8E0C9B8DEC8B8
E0CBB7DEC8B3E1CCB7E1CAB5E2CAB7E0C9B5DFCAB5E2CDB8E8D3BCE6CFBDDEC8B8DCC6B6
D9C4B6C9BFBE8587977B6A80BA7C8EC86370C94A51C83A3DC93238C62A33C4232CC42026
BD1D23AB2227DC868E957E993E356590476EA9152ABD0A15C5060FC4030BC2050BBC0509
B7060BB3060FAB0614A10A1B931D32B67A879E94A920264C60436B86304D8E192E901826
91212F932E3D9A3E4DA15262A66976C5A7ADD1CCCFC8CFD2C9CECDD1CFB6B6A34DBAA211
BDA503BEA8117C691B100C001519013335028F8814A79A14A99916948614978931928B4B
81805AB2B3A3B4B7B3B7BABCAEACB1998C8F18D10F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A48862B5AEA3B1B1B2A0A2A5C7C9CEA6A9AEC5C6CB8E8A8EC1B8BD7E737D
7E7D950C184702104F01105206134955526A9B8582A28677A28671A78B76AA8E78AC8E76
B09175B3947AB6977CBA997DBD9D82BCA18B8C7C6F766E668F867E9E91879A8E848F8780
817C7A686868696660BEAD9DCCB29CD1B59FD3B8A2D6BDA5D5BDA5D1B9A0D4BAA2D7BBA4
D6BAA4D6BBA5D8BEA7DEC3ADDBC1ACDFC7B0D9C4ABDBC4ADE1C8B3E4CAB7DFC7B6DEC9B7
E0CBB8E1C8B6E4CAB6E4CAB5E2C9B6E2CBB6E0CAB3E1CCB6E4CFBBE1CBB9DDC6B5DBC4B7
D6C7C37E8699505479B57998B73242C81D26D2181ED6171AD71319D8131AD51014D51313
D01312C21815B93637D39BAA3F325E7E4C7BA31C35C10C16C6060CC6070CBF0709B8110F
A80E14A20716AD0717AF0310A60916A43B46966E851C123C7C4C70871127A10614A4030F
A405129E05119B06139A0B198E0E1C8B3943DDC1C7CCCDD1CBCECDCFCAABB39F3FBDA50F
BDA402BEA7127E6A1A1B140324280E33380A807C28575207898317A59B19AB9B14AA9A1A
A39228A092459791679392848D8B8794898831A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF004DB926A59384A6A7A8ABB1B4A8ADB1BFC2C7A7A8ADB7B6BB908A8FA2989D837780
7A7890091345010F5101115306154C504F689784809F8372A58770A78A71AA8C75AE8E76
AF8D70B59378B6967BB9987DBC9B82BB9C898A776C6D67637C7875847E7B827E7B797775
6D6F6E5F6260817C72C6B19FCCB29CD0B69FD3B9A2D2B8A1D4BCA4D5BCA5D0B59ED4B8A2
D5BAA4D6BCA6D7BDA7DBC2ACDAC1ADDCC6B1D9C4ACDAC3ACE1C8B3E0C9B4DFC7B3E0C8B5
E1C9B7E1C8B4E4C8B5E4C9B6E2C7B5E3C9B8E1CAB6E1CBB6E4CFBAE4CFBBDFC9B9DCC5BA
D3C7CA4755775D5F8EAE5E79C1232BD61719DA1312DC1412DC1112DD1315D5120ECF1A10
C61D11BD2012AE291DCB817F75617E4A37689C3A5BB9121FC6080EC5090BB70A07DA5951
B1565E690F2B8C0A28AB0517B104109D0B16AC53684221436A43618422329F0913AA040C
AB030CA60109A5010BA4020A9E070E861219CA959BD4CBCDCDD0CDC6BE9FB49F41BDA415
BDA405BEA60E8A72162D1C05343216141600847E3B302B001B1D00636414A2991CAB9A10
B09D11AD9A18AC9D3CBBB17B9F977F84776B31A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00729D45B0AAA6A3AAAEA5AEB0C3CACDA7A9AEB8B9BDA2A1A4B9B4B58B8383ADA4A7
66667B18255403135301105204124848476097857F9F836AA9895FAD8D5AAD8C5DB59265
B08E64B29171B5957BB8977EBC9982BA9A87967F7567605F6B6B6D7271736E6E6E696967
6667636E6A63AE9F90C9B09BCDB19BCFB59FD1B7A2D0B7A1D3BBA2D1B69FD6B7A2D5B9A3
D4B9A4D5BBA7D4BAA7D6BEAAD6C0ACDAC7AFD9C5ACD9C4ACE0C8B3E1C8B4DFC5B1E0C5B3
E2C9B6E2CAB7E3C9B8E3CAB7E2C9B5E2C9B8E1CAB9E1CCB8E1CEB7E0CFB9DCCAB7DCC8B9
D8CAC7656E8D444E7EB2809DB22D36CF1B1ADA1714DA1310DB1211DA1411D02216EA6753
E88169E1876FDC8C77D5A093B29FAB36335F824774A7172CC20A14C3070DB5090CD66160
C1848D5D3350630E38A00C24B50712AF080FA125309B65793C244081465C8E1622A0040E
A9020CA70008A8030AA3080A9A0E0D8A1718945154DBCBCCCED0CFCDCCBCBFB379B8A536
BCA513BDA70AB59B185F44063F2F052922008D823C3A3205181902292C0777722070660D
A69A18AA9B09AE9C14B6A73AB2A35CA798703FB42800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00967F689D9FA2949FA5AAB3B9B8BDC398999FB0AFB3A5A4A6B6B2B3888382A49B9E
6E6C7D16204B02114F021050020F45424058978377A58756BC993FC39D33BA922FC59D44
BC974FB79462B59374BC9982BC9985BC9B88AD9284726460646163636165656263736D68
84796EA08F7FC5AD98C7AB95CCB098D2B6A0CFB39ED1B6A0CEB49CD1B49DCEB19CD3B9A4
D4BCA9D2BBAACEB9A8C7B5A3CEBEABD5C4AFDEC9B3DDC4B0DEC5B2E2CAB7DEC6B5DFC4B3
E4CAB8E2CAB8E2CCBBE3CABBE2CAB9E0C9B7E4CDBBE3CCB8E2CFB7E1CEB8E2CDBADFC7B6
DEC8BCBBB3C1515D836B678EB67389B52E36CC1C1ED81514DB1412D71411C71F18FB8F83
F3AC9AE1B09BDBB39ED2B5A3C9BBBB5A5C7D5B42749C304EBB0F1DC5080EBC080CAF2225
D2888B8A6A7C42103B870D31B00518B2040D9E0C15B467727862773E2A437E3D4E8D131E
A0050EA60108A304079F1C17BB6058A36359895F5DC7BCBCCCD0D2CCD0D1CECCBDC7BE89
B8A941B9A415BEA50DBA9F179B82164936009A882F4F410E211E031D2200928F4359500E
6F650FA29919A79B0FB3A316AD9A20A08B3746B92000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
27DC13806E628F93999BA3ABBCC1CA9D9EA8B1B0B7A9A6AAA7A3A5B1ACADA8A1A2897F82
8F899711173C020C46020F4C041143434356978369B39440C3A11BC8A50EC7A017BD9528
BE9A46B79359B49170B6947DB7957FB8977FBA9984A1877878655E7A6B6593847A9F8D7E
AE9884C7AD97CAAE98CCB198CEB29BD0B49ECFB39DCDB19BCEB39CD1B69ECDB29CD3BAA5
CCB9A7B5A495AD9B8DAF9E8FA8998ACBBCABDAC5B3DAC1B0DFC5B4E3CBBADFC9B8DDC7B3
E1CBB7E1CBB9E0CAB8E1C9B8E4CABBE4CAB8E4CDB8E7D1BBE5D0BBE2D0BBE0CDB9DFC8B6
E0C9BAD9C7C1BAB4C0626687695F85B27993B3414CC42226D31618D71314D01416C82B2B
E0706AEC9E93E3AD9DD4B4A3DDCDC7A6A6B9332E5F914C73AA1526C00810C1070DAD0E11
D37274BE95A148244A6F0F3AA80820B50310A8050E9D2F35B1878D8579884B344B7F3B4F
89111D9D060DA2040A921310D58D88D7B7B2BEB2AFBCBCBDCBCFD4CACED7CBCDD2CECDC0
C8C08FBAA843BEA518BEA307BDA30CB49C12B59C1D6853102D24011B1B00807D36554E05
58520384801F756D09A59817B2A014A28C1848BB1200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
50BF309A928D858E98A5AEB8B2B7C19B9CA3B1B0B6A8A5AAA9A3A7B1ABB0A9A2A58D8286
A19CA8192042020D45010E4B0311444343549A8554BE9E29C8A70CC7A704CAA613BA922A
B28F4EB08E64B08E71B39279B4937CB5947DBB9882BA9984B69886AF9484B39985BCA089
C6A991CEB099CDB09ACAAE98CBB099CCB29BCCB19BD0B69FD2B7A1CFB49ED1B7A1CFB8A4
B19F8EBEAB99D2BBA8D4BCABC4B2A2AC9C8DDBC9B9D9C3B3DBC4B3DFC8B7DDC8B6DBC8B4
DECCB9E0CBB9E1CCB8E2CBB8E0C8B5E2CAB6E2CBB5E6D0BAE2CEB9E2D0BCE1CFBCE3CDBC
E2CBBADEC9B8DBC9BECEC3C58F8CA05A547393738EBB6778B62E35C91B1ED31418D01318
C61B1FC12E2ED6645FE7A299DCBAB2D1C6CD44466B6444709C2740B90B15C1070DB90B11
B93740B86F7F7B4A6A680F3AA10A25B2030FAF040D971017C3868AD5CAD0938F9F48324C
7D3D5287142399051099081090222ACC939ADAC7CBCCCDD0C9CDD2C7CED4C9CDD5C8CDD0
D0CFC2C4BA87B6A235BDA30EBBA203B9A103B7A008A68F1465510A2E22008A7F2F706510
665E0F7A74205F5704675D0BAEA11DA997127AA71800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
729B457C7A7C697581A8B2BF8A8E99B1B0B7ACAAB09C9AA0B7B5BB9B989EACA3A89C8F95
867D8B33375803104801104E02114342434A9E8742C19F1BC9A707C7A602C8A50DBF9826
B5904EB08E6DAE9078AF927BB1927DB59681B99981BF9D86C09F89C0A18BBFA08BBFA08B
C9AA95C9AC97CEB09BCBAC97CCB09BC8AE97CDB19CD0B49FCDB19CCFB59FD0B6A0C5B09C
AF9A88D4BCA8D4B9A5D6BCA9D5C0B0A49284D7C4B4D9C3B1DCC4B3E0CAB7DEC9B7DDC8B7
DDCAB9E1CCBADFC9B5E1CCB8E2CFBBE1CBB7E0CAB5E2CDB9E2CFBBE1CFBBE5D2C0E6D0C0
E3CCBBE0C9B7DFC9B7DAC6B8D7C7C1BCB1BA736E89665A7CAB7C97B74E5DC02128CE1317
D01013CC1114C11719C13D3BE0908ACFADA890899F362E5A944467AF1122C00710C0070E
B40C15C13C49BB4B63981B37AA0B1EB2020CB2030BA007138F36449A8892CFD0D99C9DAD
49385174395187192A9807129A07148A1B2AC48A96D5C5CACBCCCFC5CBD0C7CED5C5CCD4
CBCFD0CFCDB8B0A559B9A523BDA50EB8A002B69F02B6A108AF98148D780F917D17807012
615508665E1D696210716C0E9D951E9C90119F8A1352C10F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
B4997F9699A196A5B6A9B6C39098A1B7BCC2A8AAAF9C9CA3B6B7BC949298BAB5BAA69DA3
918A9555587803114501114B0710394C4633AF9533C3A40FC4A502C6A802C5A405CAA41D
BD9642AF8C68AB8E7AAB907BAF937CB3967EB89880BB9982C09D87C29F89C09F88BFA08B
C2A691C7AD9AC8AE9ACAAD9BC9AB98C8AD98CEB39CCFB19CD2B39FD0B49FD0B5A1C7B19F
AD9A8AD2BDADD3BDACD3BDADCCB8ABAE9C8FD9C5B4D6C0ADDCC6B4DEC9B8DDC7B5DDC5B4
DDC7B6E1CCBBDFC9B6E3CEBBE2CCBAE1CAB6E0CAB4E1CBB6E3CFBBE4D2BFE3D0C1E2CDBD
E3CBBAE1CAB7DFCAB7DAC5B3DBC7B5D9C6BCD1C4C9989AB3494F78886A8CD16D7CC11F22
D01211D10F0ECE0E10C41416B62E2BDD948CDCC5CE3C3A5F7547729F1D35BC0915C2070D
BD050DB60911AE0713AE0816B0050FB4030CB4020BAA040F931B26885A61CFCDD1C7D0D9
9FA6BB382D49783D528A13209D0512990614881B2AC6909BD3C6CCC9CCD0C6CCD3C4CBD4
C8CCD2CACBC4B2AD82C3B663C1AC38B8A110B8A104BAA403B49B03B19908AE950BA68E11
6550047465216D631D444000958F26867D0E28E20654C51000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
BCA99777808D697B8F6B7A8987919A9DA3A99D9FA6B0B1B695959AACABB0979298A49CA3
867D89393A5904114208143E1F20207B6822C1A31EC4A606C4A902C6A900CAA804C7A215
B48C35AD8A64A98A76A88C79A98F79B1937DB6967EB9987FBC9B84BD9D87C0A18BBFA08C
C5AD9DD2C1B3D6C5B8CFB8ABC5AA9BC8AD98CDB19BCEB29CCDB09AD4B5A0D2B6A2D4BBAB
A59084C6B4A7CDBBADC7B4A5AE9C8DCAB7A8DBC7B5D9C4B2DCC7B7DEC8B7DCC2B1DEC4B2
DFCAB8DFCCBCDCC9B9DECAB8E0CBB7E2CCB6E3CEB7E2CEB7E3D0BBE5D2C0E3D0C0E4D1BF
E1CCB9E1CCB9DEC9B5DFCAB6DCC9B8D5C6BECBC2C6AEACBE736B908F688DE38194C6282D
D01311D3100CD10D0CC80B0AB91511B95145DAAFAC776E8A42315F9C3F5EB10E1CC0070F
C0040ABC060BB40B12A80C14A30716AB0514B1010EAD020B980911A5565DC1B7C3ABBDD0
7783A2443956753E54A83D489B0510A0020B980813882430D2ABB1CECACDC7CDD4C6CDD7
C6CAD5C6CBCFCCCEC5CFCEAEC7BB75BFAB36B9A414BAA307B39C02B59C03B09802AF9707
A38C0C9B87148270184C40039E922E897D1054CC1400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
CBB9A788919D798A9D83909EB0B9C0A2A6ADA1A1A9BDBDC48A8A8FC5C3C98C8990C4BFC6
918A95454866132146282A26806E25B99C1EC2A00CC2A30BC4A707C7A802C9A903CAA614
C19A36AE8A58AB8A71A98C76AA8D77B1937BB6987FBA9B83BC9C85BE9E88BDA08CC4AD9D
DDCEC5E2D9D5DFD6D2E6DAD3D3C1B6C7AD9BCAAC96CEB29BCEB29CD2B6A1D4B9A4D6BEAB
CAB5A4AE998CAE9A8DB39D8ECCB7A4D7C1AFD9C4B2D8C3B0D7C3B0DEC8B6DBC5B2DDC7B6
DFC8B9E6CFC1DFCBBADECCB9E0CEBAE1CDBBE3CFBCE2D0BBE3D1BCE2D1BEE4D2C0E4D0BE
E2CCB9E1CBB7E1CAB9DEC9BAD5C5BEB2B1BB72758F907491C87B95C54C60C2242FCC1418
D2100FD00E0ACD1108C3160AB32412C06451D1A69BBAACB835315A854D75A4192EBC0815
C0050EB2080ACF524FC1666E6B122F880B2DA70519AD020CA5050F93253658385A232C59
4B3E6784435D902434990F18A1020AA60108A4050C900C13985255D9C8CBC9CCD2C5CDD7
C4CBD6C3CBD4C6CED1CDD2C8B9B286BEAE56C3B13BBAA51CB8A00CB49C03B59E04B29D03
B19B04B29A08AB94117B670B7C6A1292841781B52100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D5C3B0848A985B6B7E6D7D8C919CA591949DADADB59E9CA49E9BA29E9AA29C98A09A949B
847E8743465C131C21746A2CBB9C1EC3A10DAD910F7D6601B49A10C5A605C5A208BC9615
B79234AF8B4CAD8A61AC8C70AB8B76B3927DB99882B79982BA9B86BD9F8ABCA292DACAC0
E1D7D3C7BBB7C1B2ABD5C6BFE3D3CBBFA898CBAD97CFB09AD1B49ED2B7A2D3BAA6D3BCA9
D5BEACD7BDACD5BCACD7C0AFD9C3AFDAC4B1D8C4B1D7C3B0D5C0ACE0CAB7DDC6B5DEC7B7
E1CABAE3CCBCE0CBBADFCEBBE1D0BEDECDBDE2CFBEE4D1BEE4D1BDE3D2C0E5D3C3E5D1BF
E4CDBBE2CCB9E2CCBADDC8BBCFC5C8536180676892B56B87B62332CE1A21D51418D41112
D0100DC60E06C32011D1553CDA866BE7B8A1CAADA1D5C6C6646280543B69982E4FB30C1C
BE0811B00B0FCF6466EFC5D0493057590F429A0B29AB020FAC030E99101F80395B1B0D3B
6F4C6F7A14279D0915A5030BA70208A70208A5070B950F0F7F3130D6C0C0C7CAD0C4CCD6
C4CDD6C0CAD4C0CBD3C5D0D1C8C9BAB9B488BDB371C7B864B7A336B19B15B39F0BB19F04
B4A104B6A003B8A005BAA410A9950FA1911A998B1F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D3C0AA7F838D48586980909D8B959EA4A9B0B6B8BE8A898EC3C1C5827D83C7C2C7807B7F
B9B4BA494B54272708A59127C2A10CBFA011826906604D088C740CC4A50ACAA614AF8B16
B99430BF9B3ABA964DA98860AC8B75B3917DB99883B89882BB9C87BC9F8AC1AB9BE5D8D1
D2C6C2BAA79FC0A99CC4B1A7E4D2C8C1A89BCEB19ECBAC97D2B4A1D4B9A8D4BAA9D4BBAB
D5BBACD5BAACDABFB1DBC1B1D8C0AEDAC4B1D8C4B1DAC6B3D8C3B0DBC6B3DDC8B5E1CCBA
E0CCBBE0CCBBE2CEBDE3D1C1E1D0C0E1D0C1E1CFBEE4D0BFE7D2C1E3D0C0E3D0C0E4D1BF
E3CFBCE2CDBAE2CDBBDFCABECBC4C83D4F74656897A85A75C2232ED41519D71013D30E0D
CE100BBC1005E55948F49D85DBAB94DFC5B1C8B2A5C1ADA6A198A53830598A456EA31126
B90611B70A0FAC2B31E0A9B545365C3A124A850D38A80315AE020DA00514A13B5237173D
553D5F792337970915A4030AA70108A404069E15119B4033A2766FCFC6C5C6CCD1C4CBD5
C2CBD4C1CAD3C1CAD3C6CFD8CAD0D5CACFC9CBCFBFCFCFB8C6BF95B8AA5EB0A233B3A61E
B1A313B3A30CB7A508BAA807C1AC1596821284751700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C7AF9693959B6877886C7D8C7C8995A4ADB5A0A5AA979A9FA8AAAE918F93A7A4A8837D80
A0999B4E4A41564C0EB89E1EC0A00AAC8F10594404604A07A5870DC7A407C8A40EBB9713
C49E1FC8A221BB9738AC8C5CAC8E76B08F7EB79683BC9B87BF9F8BBEA18EC0AC9EE7DBD5
CEBFBABEA99DBFA799CEB9ADDCCAC0C8B2A3D0B5A0CFB39CD1B49FD3B8A4D1B7A4D4BCA9
D6BFADD7BCADDBC0AFD8BFACD4BDA8D9C3AFDAC3B2DBC5B4D7C2B0D8C2AFDDCAB4DDCBB8
DBCAB8DFCDBCE0CDBEDDCCBDDECDBDE0CEBEE4D0C0E6D0BFE6D0C1E7D1C3E0CBBDD5C0B2
E5D0BFE0CABADEC8BADDC9BBD9CAC88589A3394674A684A7B14251C31C23D31417D30E11
CF0E0EC8120EC11F1AD35D51E59C8DD6AC9ACAAFA0C4AEA2BEACAE5049695D396794233D
B40A17BA070EA90E14C56C72C4A2B74D2C596E0B3DA3071FAF020EA9050E9718285F2748
261A426C415C821928990811A5030AA005089A2521D59F95CEBFBBC9CDCDC6CDD3C4CDD4
C1C8D2C0C8D3C0CAD4C6CFD9C5CDD7C7D0D6C7D0D4C8CFD2CBCDCBCCCCB9909168969955
959640ABA63CB2A625B5A611BDA811B39C19826D1482B21E4FBE0F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C4A786A8A5A857647555657586939FA8B2BB878F93B6BABE929398BAB8BD8E888CC0B6B8
8678729C8B6890781CBA9D13BEA111806409664E0C876D0DC3A112C4A008C29F17B39216
BF9F1DC3A01FBC973DAF8D61AB8B73B18E7DB18F7DB99A86BA9B87BC9F8EBCA698E2D5CE
DCD0CBBEAEA6C8B6ABDFCCC1CCB5AAC9AE9FCCB19CCFB59FD1B6A1D0B4A1D1B6A3D4B9A7
D3BAA7D4BAA8D7BDABD4BCA6D8C0AAD6BFABD8C3B1DCC6B7D9C5B5D7C5B2DBC9B5DBC9B5
DAC8B4DFCCB9E0CCBBDFCCBBDECCBAE3D0C0E4D1C1E6D3C2E4D1C0E6D3C2E3D0BEDFCCBB
E2CFBEDECBBCDECBBCDDCABAD9C7BCD0C5C881859F505277A47F9BB45262B7232AC71619
CE0E13D00F12CC1113BF1515BA302BD97B71EAB9ADDBC1B4BEAAA38C83933425508B3A5E
A91020BC0911B2090EBC444BFCC1D0915B7B720F399E061FB0030FAE040C9809148F4157
766786443A5A75425B841D2B980A149D050C8E0C11A95E5FD8BEC0CCCACDC5CBD5C2C9D3
C2CAD3C0CAD3C2CAD6C4CCD7BCC6D0C0CAD3C4CED6C2CCD5C4CCD6C6CDD2A9B3B59EABA3
B3BDA5B5BB92BAB772B5AC41B8A621C0AA1BA4900BC1AB2283AC1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
94BD64C3BDBF6E7C8D677B8C9DADB99DA8B191969CACADB29A989EB0ACAF978E8AB7A798
8D784FB99E4CB39419B99A129A8008AA9230654E00B3971AC3A10BB99513A88728A68938
B4963CB89942AD8C54AC8A6EA98975AE8E7BB09280B39684B89B89BD9D8DBDA193C9B5AC
DDCFC8E1D3CBD9C8BECCB5A8C9AE9ECBAF9ACFB49DCBB09ACFB49FD1B6A1D2B7A3D3B8A5
D3BAA6D6BEABD2BDABD1BDA9D5C1AFD9C3B1D8C1AFDCC4B4D8C1B1D7C2B1DBC6B4DBC6B1
DCCAB4DDCBB9E1CEBFDFCCBCE0CFBEE5D3C4E8D6C8E8D4C6E5D3C4E6D5C5E4D3C3E3D2C2
E1D0C0E0CEBFDFCBBDDCC9BADCCABAD6C6B8CEC3BFA59FAE645F7D7E6883B77484AE373D
BC1A1DC81315CB0E10CC0E10C41011B51C1AC95E5AE1A79BC7A89AB9A9A94842616F3F69
9B1C34B80A16BB050EAD0F19BF3D4EA72B419E0F26AB0515B2030EAE020B9E060FAB4959
C2A6BCACAEC354496573455C832131930C189908118A0F189C505BD8BBC4CAC9D0C3CAD1
C0C9D1BEC8D1C2CAD6C7D0D9C5CFD8C1CBD3C5CED5C4CDD5C4CCD7C3CBD799A3B2344451
727E776C7362919780929261B3A84BBAA823BBA914C3AF18BB9E2200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
60CF40D5CBC95B66766173848695A379838DB1B5BC959499B0AEB0A7A098BDAB8DA9904E
BB9B35BB9817BD9B12A688125A44016A57128B7208AD8E09C3A10DB08C16B18C3FA78653
A2835AA58764A78A71A88978AA8B7BAD8F7EB08F7EB69685B99A88BE9E8DC09F8FBFA393
BFA698C3AC9DC5AF9EC6AD99CCB19CCFB69ECBB19ACDB29DCDB19CCDB29DD1B4A1D0B5A0
D3BBA6CDBBAABBAC9DB7AA9BCCBCADD7C1B2D8C0AFDEC6B3DAC2B0DAC3B1DCC6B2DBC9B2
D8C8B2DDCBB9E2CDBFE0CCBDDECBBCDFCCBEE2CFC1E5D2C4E5D2C5E5D2C4E6D3C5E5D3C5
E3D0C3E0CDBFDECBBDDCC9BADBC8B7D9C6B5D7C6B4D4C3B9C6BBBF8D84985F516A9C7185
AE565EA82B2DBA1C20C71214C90D0FC50F0FB91817BE4D44DEA193C8ACA583788C432B55
973856B0111EBC080DB6040BB30814AF0713B20710B1030BAF010AAE0309A9060F951424
844B61C5BFCEBCBCCE5F546E6F465F822C3C8E0F189708148B0E1E9A4E5BD3B9C2C6C7CD
BFC8D0BDCAD2C2CCD5C9D3DCC7CFDAC8CFD8C7CFD8C0CBD4C1CCD6C1CCD798A4B44C596A
586262828A7F8D9590949789AEAA76B1A73DB5A71FC0B027BDA43125DB0800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
59C632DED0C88189987E8EA081909D8D97A0AEB4BA98999DACAAA8ADA38ABCA75EB39820
BA9C0CBC9B08B29212705807533E02796007BA9A13C3A00AC29E0FB38B1AC29C46AC8A54
A082689F8273A28578A58879A88B7BAA8D80AB8D7FB49584B89986BC9E8ABD9D89BE9E8A
C2A491C7AB97C8AD98CBB09ACCB09BCBB19AC8AF96C7AE96CBB199CDB39CCFB4A0D0B4A1
D2B9A8B3A294AEA195AC9F92B5A596D4BEADD8BFAED9C4AFDAC6B2D8C5B2D8C6B2DBCAB6
DBCAB7DDCCBBDFCEBEDFCBBDE0CCBEE3CFC0E5CFC1E6D0C2E5D1C3E4CFC1E5D1C3E7D4C5
E6D2C6E4CFC4E2CDBFDDCABBDAC7B7D8C5B4D8C5B4D7C4B5D3C2B7D2C2BFB9ACB5796C80
6D576DA27587AE5D67AD262AC21416CB1011C71010AF1611D3776BD2AAA0B8A6AE4E3E5D
8245609E212CB31519AF100EAD1010AA0F0EAD1010A90C0DA90C10A7090FA80A119A0F1B
883B4CB9ACB8CDD1DBC2C5D4685F7967455D7F2E418B0E1C950616860C1BA15C6AD0BFC7
C1C6CEC0C9D2C4CDD6C7D0D9C8CEDAC5CCD9C5CED8BECAD6BDC9D5BBC8D2B2C1D09BADBF
9FB1BFA2B0B6A4B0B5B0B9BAB5B9A6AAA86FB4AE5BC6BF72A89B59628D2300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
2ADF14DCCABE8F96A64D5E725D708099A7B0899197ABACB0AFAA9DB2A36AB39B29B89B0A
BC9D05B6990D8F770D7C67187F6501BC9B16C39F07C4A009B69219A58031A7844FA28160
9F8172A08078A48378A9897CAA8B7FAD8E83AE8F81B09382B69987BC9D8BC09F8BC5A691
C9AD98C9AB96CAAD98C9AD98C5AA94C5AB93C6AC92C6AC92CBB199CCB29BD0B49FD1B6A3
D4BCABA39183C4B6A9BCAF9EB9A896D3BFAAD5BEAADAC5B3DBC7B5D7C5B1DAC9B4DAC9B4
DDCBB8DCCABADCCBBBDDCCBBDFCEBCE0CFBDE0CEBEE3D0C1E5D1C3E2CFC1E6D3C4E6D2C4
E6D0C3E3CEC1E1CDBFDECABADCC8B8D7C5B5D7C6B6D7C6B6D3C3B3D5C4B7D3C1B8CFBEBE
9D91A15650695D4F6CB17386AE252FC51115CB1010BA150FC35A4DD7A99EB4A3A4ADAAB6
C2ACB5B37273BE625BBC5F51B85E51B05847AA5246A84E46A54843A442429C383C8B333B
804C56B9B5C0C6D0D8C8CFD5C9CAD77772875C415B7D3045890B1C9307167D0F1EB88C95
CCC8CEC1CBD1C3CDD6C7D0D9C8CFDBC6CEDBC2CCD8BFCCD5BFCDD6BECBD5ABBACE49617C
3B547457708667798587939A88908E969A86A1A587AFB49F7B7B71604D3900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00DAC2B0ABADBA4B5A6D6E7E8C9DA8B38D939AAEAEACB3A886AF9A40B29810B99A06
B7980B9B81135644005441019A7F0AC2A00AC4A005BF9A13A7842C9D7C55997965997C6F
9C7C77A17F7BA4827AA6857BAA8A7FAC8C80AC8D7FAD907FB89A89BE9E8CBF9F8BC3A791
C3A890C8AA94C6A792C4A590C2A58FC3A891C4AC92C9B096CFB49DCCB09AD0B59FD1B7A1
D3BCA7B9A491A59484B3A491D3C2ADD4C0ABD3BEA9D8C3B1DCC7B6D6C1AED9C7B1DCCBB7
DAC9B8DAC9B8DDCCBADDCCBBDFCDBCE0CDBCE1D0BFE3D1C3E4D0C2E4D0C2E6D4C5E3D1C2
E3CFC2E3D1C4DFCFBFDCCAB8DDCAB9DCC9B8D6C4B3D7C6B7D4C3B4D6C5B6D4C1B2D3C0B2
CFBFBEBBB6C54B51735D4D6FBB5B6BB9191BC31710B52113C76D5DDFBCB1ABA4A85B6A7B
BCC5D1CDB7B9C99E96C39A8DC19F95B69B92D6C0BADDC8C7C4ADB0D9C0C7AE99A5564859
817F8F566877B9CDD6C6D3D8C9D0D5C8CDD862637D563A587C23378C071588081588414B
D1C3C9C3CAD0C5CFD8C5CFDBC6CFDCC6D0DAC3CBD7C1CDD6C0CDD6BDCAD5B6C1D42C405D
415776475C726E7E8A8F9BA1929B9C999D989EA2998C91926D6F7C4E404400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00D0B39ABCBCC64F5D70788697707886A7ABAFA4A08CAF9F58AF961CB69907B89908
A0840E5B45005B480E998320BA9A0DC3A005C19D0EAE8C2398794594776694776F967772
9E7B79A5817DA5827DA4827BA9887EAB8B7FAB8E80AE9284B5988BBB9B8CBC9C8BC3A390
C8A895C7A894C1A58FC4A891C5A993C6AD96C9B099CCB19BCAAE99CEB39CD2B8A1D2B8A2
D2BBA6D2BCA7CFBAA6D3BEA9D2BDA8D2BDA9D6C3AFD7C4B0DEC9B7D7C2B0D9C7B3DAC9B7
DAC9B8DBC9B7DDCCB8DECCBAE0CDBDE1CEBEE2D0C1E1D0C1E2D2C3E3D2C2E2D1C0E5D2C1
E1CDBFE3D0C2E0CEBFDDCCBBD9C8B6D8C7B6D9C7B8D7C4B6D5C4B3D6C6B4D7C6B5D5C3B5
CDBFBCB1AEBB4D5674766C88A86066AD352BBD442FCB6E56D49F8CD3B9AEC5BBBC6F7588
525A76907A8CA67378D09C9CEEC3C9BFA3ACAA96A3A999AA937F94877087725B764E3653
6E5D738D8B9CB8BCC6CCD0D5CBD1D5C9D2DB9BA5BD221F427E425A800C198A0C1475262A
D0BFC0C5CCD0C2CDD6C2CED8C5CFDBC5CFD9C6CED8C1CBD4C1CCD6C1CBD5BCC5D38392A7
96A8BEA3B5C49EAEB8A3B0B8A7B2B5AEB6BAB2B9BCB1BABF959AA8514C552FA01A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00C5A285D0CDD36371837A8999747C86B2B2A8A1955DAA9427B09709B59706B0920E
7860094D390377631690760ABF9E09C2A00BB1921C9A7C3C93776093766F9577749B7A7A
9F7B7B9F7C7AA07D7AA3817BA7857DAB8B80AA8C81AB8D83B49488BA998ABE9D8BC1A08D
C4A28FC1A08DC2A58FC8AE97C8AF98CCB39DCDB39FCCB39ECDB39ECDB19CD1B6A0D3B9A4
D3BEA9D2BDA8D2BDAAD1BCAACCB7A4D5BEABDAC3B3D7C2B1DCC7B6D8C3B1D8C2B0DAC7B6
DAC7B7DDC9B8E1CCBBDFCCBCE0CEBEE0CFBFDFCFBFDECFBEE2D3C1E0D0BFE3D0C1E5CEC1
E3CEC0E1CEBFE1CEC0DECDBBDAC9B8DAC8BAD9C5B7D8C4B6D5C4B4D5C4B4D7C5B7D2C0B5
BDB0AE77737C6E6E7EBCADB3CDA599D8A28EDCAA92D4AD97CCAE9EC8B2A6C1B0A7B4A9AB
6E667C7561798F55658E3241A33B4CA64053A34055A03D54A13A529E364C9D2F45962C3F
9331449E4F60AF7787D2AFBDD8CAD5CACAD658627B3B3D58825766751D217D1B1C7E4341
CBC0BEC5CDCFC3CCD6C4CDD7C7CFDAC8D0DBC4CCD7C4CED8C2CAD5C3CDD6C2CAD96E7C95
374F6E657E94687B8A7E8D9689939B8790978B949B969FA79098A748475533A72500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF006ADB50D7D2D3707E8F63748497A1A399956FA59232B0960DB29703B3980C846C03
6E59066B5400A28613B6980BC09F0AB795159A7C2E9074578D716A917572977977987878
9878779D7B799F7E79A98480AA847EA9877EAE8E82AC8C7FB49587B79987BB9D8BBE9F8D
C1A18FC4A694C4A894C9AE99C5AC95C8B19CC7B3A3CCBCAFD0BCAFCBB4A3CFB7A2D3BAA5
D1BAA5D0BAA7D1BBABD6C1B1D9C3B2DAC2B3D9C2B4D8C1B3DAC4B4D8C3B2D8C2B0DBC8B6
DAC8B8DCC9B8DFCAB9DDC9B9DFCDBEDFCEBFDDCBBCDECDBDE2D0BFE2D1C0E4D3C2E3CFC0
E5CFC1E1CDBEE0CEBCDFCEBBD8C8B8D5C5B5D8C6B7D8C6B7D7C7B7D5C4B6D5C3B7D1C0B3
D1C2B7C6BAB1CABEB9CDBDB1CDB9A8CBB6A3CCB6A3C6B29FC2AB9DC4AFA4C7B6ACDDCDC7
B7AAB1776C7C755D6EA066749A38439B2027A1161EA9141DAA0F18A80C14AA0D16A40B14
A10A179A0D1B9211248B2239A96579D9BAC7A9A1AE8E8995958386937370977771AB9D98
C7CBC9C3CCD0C5CED7C3CDD7C9D2DCC9D2DCC6CEDBC5CDDAC4CBD7C2CBD5C4CCDC6C7894
1E335653698257677A8B95A19CA3AD959CA49CA4AB9098A18288983D405066514800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0060CF41DBD1D0757E8E5D6C78949A8B958940AA9515AE9703B19804B399127F6700
A38B20A5890BB8990BBD9E07BA9C13A587298F72488E73668F7370907373957775967775
9A7B789D80799E7E77A3807AA8837DAA857EAD887FAE8C82B29386B59A8AB99E8CBEA18D
C1A291C5A795C7AA97CBAF9CC5AE9CC1B1A4D7CDC8E0DBDAE5DDDCD2C3BBCBB6A6D0B6A4
D2BAA7D2BAA8D0B8A8D1BAAAD9C2B4D7C1B3D9C2B4DAC1B3D9C2B2D5C2B1D5C3B2DAC7B6
DAC8B8DBCABADBC9B8DECABADFCDBDDFCDBDDDCBBBDDCCBBE3D1C1E3D1C1E1D1C1E2D0C1
E3D0C2E2CFBFE2D0BDE0CEBBDDCCBAD5C5B2D7C7B7D7C6B7D6C6B7D5C4B5D1C1B3D1C1B4
D2C2B6CFBFB2D0BEB2D2C0B3CEBCB0CBB9AAC7B6A6C4B3A3C6B0A3C9B5AAC3B1A7C9B8AF
BDAEA7BAACAAA0969D85768394707CA6676CA1484A9F2F2FA12220A41E1AA01C1A9D1E1A
9B1D1C981F22961D268D1A28811C2F894253D3B5BFCFCBD0C9C9CBC7C3C5C2C3C4C5CCCD
C5CFD1C3CCD3C5CDD6C5CFD9C6D2DEC4D0DCC4D0D9C4CDD7C3C9D7C0C8D3C0CBD7AAB9CB
8294AB99ACBDADBBC8A4AFB8A5AEB7A7B2BBB2BDC7B2BDC7ACB5C63F485C6C605D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0057C330DAC9C18488956B757A99976FAA9830B19809B29B06B19806B29710776003
7E6809AE930FB99B07B69B0F9B841B8F76408B715F8E736D8E726F927374947274947273
9B7978997A759D7F77A3837BA6837DA5837BAB8A7FAF8F82AF9183B39888B99E8CBFA491
C5A896C9AC9BCBAF9FC8B09EB9A898A79E96B4B2B3BDBFC4DEDEE0DAD1CBCBB8A9D0B8A6
D1B9A7D1BAA8D1BAA8D2B9A9D4BDADD8C1B3D6BEB1D8C0B2D7C1B0D8C6B3D4C2B1D8C5B5
DAC8B9D9C8B8D9C9B8DECDBCDFCDBEDFCEC0DDCDBCDDCEBDDECEBFE2D0C2E1CFC1E2CFC3
E3D1C2E3D2C1DFD0BDDFCFBEDFCEBFD8C8B8D5C5B6D5C5B6D5C6B7D3C6B6D0C3B2D0C1B1
CEBEAFD0BFB0CEBCAECFBDAFCBBBACCDBDAEC9B7A9C5B4A4C5B0A3C7B4A6C4B3A4BEB09F
C2B5A7BBB0A4CBC4C0DEDCDEB2A8AD9482849177798D6A6BB2827EC18F84C08E85BA8C84
C59B96C09699A0797F9369708E5C67824B5B795462C6C0C5CACFD2C5CDD2C5CBD4C4CDD3
C6CFD6C3CDD6C4CED7C3CED7C3D0D9C1D0DAC2CFD8C1CDD5C6CDD9C2CBD7C1CDD98DA2B4
5F7A935B768B70859376838E828C95848D96858D998C97A28B98A73A485B6E666A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D6C1AE9F9FA1737468908840AB9715B19804AE9608947B02AE92128F760E
715900B4980FB79B118E7D16534816847261886F6B8C726E907471927371977675987374
9A75759977739E7E79A2827CA6857DA9897EA9897DAD8E7FAF9283B6998BBA9F8EB89E8C
BEA290C0A491C2AA95BDA8959A8D7DC3BCB5DDDDDDB3B6B9D7D6D5CFC3BDCDB8A9CFB7A5
D1B7A7D3BBACD1BBACD3BDAFD5BEB0D8C0B2D7C0B1D8C1B1D8C3B0D9C7B4D5C2B2D8C5B7
D7C7B9D5C8B9D8CCBCD7CABCD8CCBDDACEBED9CEBCD8CEBCDDCFC1E0D1C1E0D0C0E1D0C1
E0CEC0DECFBEDFCFBEDDCDBEDFCEC1D8C6BAD5C3B6D4C4B5D3C6B7D2C5B6D2C3B3D3C3B1
CFBFAFCFBFB0CEBEB0CCBCADCBB9ADC9B9AACCBCADCABAAAC8B6A8C3B2A3C2B4A4BEB1A1
D9CEC1C4BAAFBAB2AAC1B9B5B2A7A4AFA59DC1B9B5C5C1BFBAB2B3D9D1D1DCD6D8AEB1B6
C6CBD2949DAD3E4D64AFBBC8B6B3BE857B89635A6D848791C7D0D7C5CFD6C7CED6C3CCD3
C4CDD6C3CDD7C2CCD6C2CED7C3D0DBC3D1DCC1CED8C2CCD6C4CED8C2CCD7C3CEDB6D8096
3852712B4660697F906C7C869AA4AD9DA4AD979BA6939AA389909E424E626B686F2C9E16
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D3B897BDB6A5827C4EAE9F37B4A00FB49B04B29912755B00A88E18B3960D
B39509B89A0C9B851A342F043A3A347E7072856E6F8E72729173749071709677759C7A78
9C79759C7B76A07F7AA5837DA28079A6857CAB8C81AF9183B49788B49888B89B89BDA08C
C1A58FBEA28CC0A790B7A39096897CB2AFA8B7B8B89C9C9CBEB7B2C4B3A7CDB6A5CBB49F
CDB5A2D1B7A7CFB9A8D3BEADD5BFB0D4BFAED5C0AED5C0ADD7C2AFD8C5B2D3C0B1D3C3B6
CBBFB5BFB7ADAAA39AACA49DC2BBB2D3CDBFD9D1BED8D0BEDBCFBFE0D2C2DFCFBFE1D1C2
DFCFC0DECDBFDECDBFDDCDC0DECDC0DAC8BDD9C8BCD6C8B8D5C5B6D6C6B7D3C3B4D2C3B3
CDC0B1CFC2B5CEC0B3CBBDB0CBB9AEC9B7AAC5B4A5C5B3A5C5B3A5C5B3A5C4B2A6C0B0A5
C0B1A7BEB1A6B9AFA6B7ADA4D0C8BFBBB7AFC7C6C2D8DBDCCBCED2B9BCC1BDC5CE495D6F
63768963748B132D4E7993A9C6D4DFCAD1DB949CAB516070BAC9D3C3CFD6C7CFD6C6D0D6
C4CED8C1CDD8C2CCD6C3CDD7C5CEDDC4D0DEC5CFDBC2CED9C2CCD6C4CED8C2CDD692A2B2
7C90A48DA1B2A2B4C2B0C1CAA8B5BEABB7C0ADB6C0B2BBC3A9B3BD5C697B6B6D782EA11D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D0AC7DCBBA8D93842FAB9816B49F0AAC9504B0960F7C62059F8515B59807
B99905B498186257140D13133E3F517D6E75866D6F8E70729272779474799575789A797A
9B7977A07F7BA0827CA5877FA5847DA7867FAB8A81B09084B5988AB69B8BBC9E8FBE9F8F
BC9F8DBFA38FBFA48EBEA7938D7F728E867F918A87817974AA9D91C9B5A4D0B6A3CFB6A4
D3BCAACFB8A6D1BAA8D3BDACD1BEACD1BDABD8C1B1D7C1B1D8C4B2D9C6B5D5C5B6BDB2A8
978F899E968EA89F959F958F807B789C9991D1CCBDD7CEBCDDD1C0E1D0C2DFCEC1E1D1C4
E0D0C2DFCEC0DDCCBEDDCCBFDDCDBEDBCCBED8CCBCD1C6B5D5C7B7D2C5B4D0C3B4D1C5B7
CEC2B6CDC1B4CDC1B2C7BAABCEBFB2CBBBAEC2AFA3CCBAACC9B7ABC6B3A8C6B4AAC6B3AC
C2B1A9C3B5AAC5B9B1B8AEA6DDD7D1D2D0CCB0AEABBFC2C3A8ACB294969CAFB4B96B7988
6A7788BFCBD998AABD99B2C5C0D5E2C4D3DCC8D6DDA7B8C0B9C8D1C3D0D7C6D0D8C6CFD6
C5CFD8C3CFD7C4CDD8C3CCD7C3CCDBC2CEDAC3CDD9C4CED8C0CBD6BFCBD7BFCCD79EADBB
7A8EA36F879B74899A7A8D9A818F9987939C89929C8089927F8895536376646A7963493D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00C79A58C9AF61A9951CAE9B0BAB970D8B7701A38C11866D0C8F780DB59908
B5970999852128290E0711294A4B627F6E76866D6F907273917274927476947677987879
9A787A9D7E7D9E807DA1837EA48580A88883AB8983AE8B84B19389B89B8FBC9E91BD9E91
BA9A8CC2A392BFA28FBEA5919785779A8C80A59589AE9C92A29082CBB6A5D0B6A5D1B8A8
D2BCAACEB8A7D0B6A7CFB7A7D1BBAAD6BFAFD7C0B1D5BEB0D9C2B4DAC5BAC7B8B089817B
ACA49EC8BEB3C6BAACC4B8AEA19996767471A8A89ED5CFBFDACFBEDED0C1E0D0C4E1D0C6
DFCEC4DFCEC2DBCCBEDACCBEDACCBDDBCDBDD6C9B9D3C8B8D2C6B5D2C6B6D1C5B7CFC3B6
CFC1B8CCBEB4CFC3B7CBC3B4CBC0B5CDC0B3C9BBADC9BAABC4B2A4C4B2A6C2B1A7C7B5AB
C1AFA5C6B8AFCFC2BBB9AEA6BBB1ACB2ABA8ACA8A3ABABA6CECFD0C3C4C7C1C3C7D1D7E0
B1BDCA9CADBAA8BDCF3F607C99B8CFBFD2DEC2D2DAC2D1D7C6D3DBC5D1D9C7D0D9C6CFD8
C6CFD8C3CFD7C3CED7C2CED8C1CDD9C1CDD9BFCBD7BFCDD6C1CED7C2CCD7C0CBD8A6B4C6
3F5571435F79455E7081929F94A0AAAAB5BBA3ACB499A1A88B94A05666795C66756A554C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0065CE21C8A83AAF9910AA980C8172056B5B009B87147E6A0E79660BB2980D
B59B1F867A390F151B08133653536C7F6F77866E718D707391737691737596787A98797B
9B797CA28081A17E7DA2827EA2857DA98B85AB8C86AF8E87AE8F85B5988CB79B8DBA9E90
BEA290BFA18DBC9F8CC0A594978274B5A596B7A796A89686B3A090CBB6A3C9B4A3CAB5A4
D2BDABD4BDACCFB7A7CEB5A6D3B9AAD4BDADD3BCACD2BDAED8C3B6D7C4BD9C918F86807D
B7AFA9C7BEB4C7BEB3C7BBB4ABA0A07E7C7B888880D5CFBFDDD1C1DED2C2DECFC1E0D0C3
E1D3C6DDCEC1DECEC2DCCBC1DDCCC2DCCCC1D8CBBED2C8BBD2C8BAD2C5B8D2C5B8CFC3B6
D0C4B9CCBFB6CBBFB4CBC2B6C8C0B3C6BDB3C4BAAFC3B8AABBAB9DC3B2A4C2B2A7C0B2A7
C1B1A7BDB0A5B7ABA3B5ACA5AEA6A2CCC9C8D2CFD4AEACAFD8D4D8DBD5DAB2ABB1B4B3BD
6371872F44617F92AA203D5B6E91A8BFD5E1C0CED697A5AAC8D4DAC6D0D9C7D1DAC5D1D9
C5D0D9C0CDD6BFCBD6BFCCD8BDCBD6C1CED7C2CDD6BDCBD4C0CED6C1CED6BFCBD7A4B2C3
879BB271899F95ACBAA1B2BBB5C2CAA8B6BCACBAC0ACB8BEA7B2BD697A8C54627270625E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00C39F19B39B0C95840A5A4E005143009A86168C750B8D7609B09712
B49F3D877E610A112B09123A605F757E6E75856E708C6F7491717896767C97757B9B787E
9A76799E7A7B9E7C7AA1807BA68883A88B87A98B86AA8A84AD8D84B4978AB89D8FBCA193
BEA290BFA28FC0A391C2A595AC9284998676A09080A49081C4AE9EC4AFA0B4A196AC9C8F
C7B4A4D1B8A7D5B9ABD3B8ABD3BBABD2BCABD3BDAED6C2B4D8C3B8D7C3BD877B7B878383
AAA6A3B8B2ACBCB6B0B0A9A79894967A7B7B898981D3CCBCDBD0BEDED2C1DFD0C1E0D1C3
E0D3C6DDCFC1DECEC1DACABFDAC9BFD9CAC1D4C7BED5C8BFD1C5BAD3C6BCD0C2B9CFC5BA
CBC1B7CCC2B9CDC0B7CDC1B6CAC1B3C4BBAFC2BAAFC2BAAEC1B6A8C0B3A3BFB1A6BBB2A7
BBB0A7BAB1A7B3ADA8CDC9CB9E96A3978B9FA48DA4936F83B58995C2949CB88F93B8A0A3
9292A24C5A71A6B5C5A3B3C49AB2C3C2D4E0C8D4DBBCC7CDC7D2D8C7D2DBC6D0D9C6D0D9
C2CFD8BDCBD4BFCCD5BDCAD3BDC9D5C0CCD8BFCAD6BCC8D4BFCBD6C0CCD6C1CAD7ACBACB
7D92AB758FA46E85957D8E9A7E8C957F8B94838E97808A947D8692606F814D5E6F786F6C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0092B80DAF9B0F7B6F025D5201796705A7910DAC9509AD960EB19C27
92844368665F0B15380A163E6765797D6D7189727390727794737D96747D99767B987478
9B797C9C7B7A9C7B79A38481A48784A68886A98984AD8B83B18F84BB9A8EBC9D90B89B8C
B99B89C0A18DBFA28EC0A38FC6A796BB9F8FB9A190C3A999C6AD9CB9A597A4948CA7988F
B8A597D0B7A6D7BCABD1B9AAD0BCAACFBDAAD3C1B0D6C3B4D6C3B7D4C0BA897C7B827D80
8F8E919896999998999290937E7F837475749E9B91DAD0BFDDCFBEDFCEC0DECEC1E1D3C4
DFD2C3DDD0C2DCCFC0DACCBFD7CABDD4C8BDD5C8BFD3C6BDD2C5BCD4C6BED2C4BDCEC3BA
CDC4BBCDC3BACFC2BACDC0B6CDC1B6C8BCB3C4B8B0BFB5ABBFB4AABBB0A7BAB0AAB7B2AC
B6B1B1ACA7AE8D8595826E888253719A4C6A9E334EA4263CA21C2DA21F2D9F2C35AE5B63
E5BCC7D7CCD99096A3ACBBC87D94A7B9CFDDC9D6DFC8D2D9C8D1DAC4D1DAC4D1DAC4CED7
C3CED8C0CDD5BFCCD5BDCAD3BCC9D2BFCDD6BFCDD8BECBD4BBC7D3C0CAD6BFC7D8A1AFC3
213A594D6986536D8470839395A2ADA2ABB6AEB7C1A5AFBA868FA13E516A44576D7B7778
2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005FD00AAB9A13706200716101A08B0DAE9706AE9604AB9512C3B35E
8A81638A8C941922481019426F697D8572758D747590737792737A94757A95787B997B7E
9A7C7E9B7E7E9C7E7DA28582A48683A58684AA8984AA8981AD8E84B7978CB6968AB7998A
B89B8ABDA18CBEA28CC1A58FC3A793C3A694C5A996CAAD9AC8AE9BB9A4959E8E83A9998D
C3B09FCCB49ECFB5A0D3BDA9D0BDA9D1BFAAD5C4AFD4C3B2D2BFB1D5C2B6AB9B96776E6F
7C7A7F7F7D847E7D81797A7D727170847E76C5BAADDBCEBDDFCEBFE1D0C2DECFC2DED0C3
DACDC1DACFC1D9CFC0D9CDBFD5C8BCD4C7BECFC5BBCFC5BBD0C6BBD1C6BDD1C4BDCEC1BA
CDC2BCCDC2BCCDC3BACAC1B5C9BFB5C6BBB3C2B8AFBFB7ADBFB7B0B9B2AFB4AEB4A49DAB
81728B7C5C7B925576A54663A5243BA80F21B20A19B40814B60611B60711B00811A00C17
A2303FB26D80523D5372798E5D7288ACC1D1C9D6DFCAD4DBC6D0DAC5D2DCC6D2DBC5CFD8
C2CCD5BECBD4BECBD4BBC9D2BCC8D4BDC9D5BECAD6C1CBD5C1CBD7C3CDD7C1CAD7B7C4D5
374C68839BB48DA4B7A0B1BFB3C0CCB9C3CFACB8C4B0BCC89FADBF2D415E344663797A7E
32A72200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005DCB0D9A8409776703907D0EAD9609B09803AE9504B09920AA9C5C
8B857A64677809143C182047787085856F798D74788B6F749173798F717594787B957A7C
997B7D9C7D7E9D7E7D9F7F7DA48482A58482A6847EA8887FAC8F85AF9388B29589BB9C8F
BE9F8FC2A691BEA48DBDA38DBEA38EC7AA95CAAB97C8AB97C8AE9AC6AE9ABEA896C0AD9B
CFBDA8D5C1ABD6BFABD4BEABD0BEABCFBEA9D2C2AFD1C1AFD2C1B1D4C2B3D1BEB39A8B85
7E757580797A8A848298908B9B9188C0B2A5DBC9BDDDCBBEDECDC0DECEC1D9CABDDBCDC1
DBCEC2D8CCC0D8CDC1D7CBC1D7CBC2D4CBC1D0C9BDD4CBBFD1C7BCD2C7BECDC2BBCEC3BD
CDC3BDCBC2BBCBC2BBCAC2B8C9C1B8C4BDB7BFB8B5BBB6B5B5B0B69E97A57D6B85815978
A05574AB3B58A71A32AF0E1EB70A15B9080EBA060EB6030BBA030DBB050DB70309B2040B
AB08169B16269B5062907E8DC2CAD6BFCED7CBD5DECAD4DDC7D1DBC6D0DAC7D1DBC5CFD9
C1CDD6BECBD3C0CAD3C0CAD2BFCBD4BDC9D4C3CDD9C2CCD6C0CDD6C0CDD6C0CBD6BAC8D6
74859A899EB37E94A47E909C8C97A387919B848E9A848E997A83962B3C582F3F5B74787F
4C7D3500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6F03806C02A18D0EB09905B09702AE9404AF9929978A58
B9B6B45D637A07133D22294F796F82836F788B737A8A6E738D6F749072749376799A7B7F
99787D9D7C7F9E7C7DA07E7DA28281A88886A6847EA88680AC8C84AF9186B09387B79A8A
BDA08DBCA18CC0A791C1A590C1A590C6AA95C6AB95C5AB93CBB09AC8AD98CAB19CCEBAA5
D0C0ABD1BFACD7C3B1D2BDACCCBAA7CFBEABD2C0B1CEBCADCEBCADD1C0B0D9C6B6D2BFB2
BBA89FB0A096C1B3A8C9BAADD3C3B3D8C7B8DCCABDDBCBBEDBCBBEDBCDC0DACCBFDACBC1
DACDC4D8CBC2D5C8C0D5C8C1D6CAC4D5CCC4CFC9BED1C9BED1C9BFD0C9BED0C7BECDC4BC
CBC2BCCCC5BECAC3BFC4C0BBC2BFBFBDBBC0B3ACB990859980668196637EA9526EAC324A
AE172AB70E1CBA0A15BA0B10BB0C0EB70D0EB30C10B10C13B30710B7070EB9050AB7040B
B5040EAE09149A1F2AC0868F9E959EC7D1D7CFDAE0CBD7E0C5D2DBC5D2DAC5D2DBC3D1DA
C1CED7BFCCD4C2CCD4C0CBD1BDC7D0BFCCD4C4CED8C4CED8BFCBD6C0CDD8BFCDD9A6B8C7
6D839B27445D6D8A9F7A909F98A5B29FABB4A9B2BCAAB2BE9CA3B7303F5E293A56697076
6B5B4F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6C02A38E0BAC9706B09A02B09804AB930AAA97379F9573
8F8D925C617B08133D2C33567A73828370778870768B6E768E6F7592737994757B99787F
9D7C819F7D81A07E7FA28081A28281A38380A6837DA9847DAE8B83B6948BB4948AB6998B
BD9F8EBDA08EBDA28EBFA390C3A694C5AA96C7AB96C5AB95C8AE97CBB19CCDB4A2CDB8A6
D1BDACD3BFAED3C0ADCDBBA7CFBDA8D2BFADD2BDADD3BDAED1BFAED2C3B0D6C6B4D5C4B4
D3C1B3D9C6B7D9C8B8DBCABADAC9B9D8C6B7D9C6BBDAC9BCDACABCDACABCDACBBDD9CBC1
D5C7C0D3C8C2D6CBC5D6CBC5D8CFC8D3CDC8CCCBC8CBCAC6D1CAC4D3C8C0D4C6C1D1C2C0
CEC1BFCBBFBEC8BBC0BAADB7A392A294788E9B6C88A9607DAA4059A72134B11523BB121B
BC0F15BC1113B71311AF1812A91F17A72B23A73733A5393DA2252EA91019B4060DB6040A
B60208B40409A50A11A138417A5863BCC3CBCCD8E0CEDBE1CCD8DEC6D4DCC2CFD7C4D0D8
C5D0D9C2CCD6C0CAD3C0C9D2BEC7D2BCC8D1C4CED7C2CFD6C5CFD9C2CFD9BDCAD6A4B7C8
6C849D435F7887A1B49AAFBCA1B0BCB1BEC9B3BFCCAAB5C3A1ACC0384B692337535E6A6D
6D635600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00709702AD9508B09B05AC9905B39F19AB9927998B42C8BFAA
7B7A818A8FA708143A363E5B78727D816E758970758F7177906F7795737B97757C99787E
98787B9A78789F7D7DA07D7EA38182A28180A7837FAB857FAC8880B3928AB7998FB99C90
C1A192BFA18EBFA38EBFA38FBFA593C6AC98C7AC98C5AA94C8AF98CEB6A1CDB6A4CBB4A3
D4BEADD0BDACCEBBA8D0BBA8D2BDAAD3BDABD0BBAAD4BFAED1BFAED2C1B0D5C4B5D7C5B7
D4C2B4D7C5B7DBC9BCDECDBFDCCBBDDAC8BADBC9BBDBCABCD9CABDD8CBBCD7CBBDD3C7BC
D3C5BFD4C9C3D4C9C3D5CBC4D3CBC7C5C5C78E9CA9A4B6C5CAC8D2D1B9BCDFB8BBE2B3B8
CF9BA4C08896B4768AB66A81B85A72B64359B42C42B31B2BBB171FBC1315BC1716B51813
AE2019AE3328B54D3FBE6F5FCA8D7DC89788B68F8A6D505B794E639A3849A70C18B3040E
B60309B50309B0050E9A101899545FB5ADB5CDD6DDCFDAE0CDD8E1C7D5DEC6D3DCC3CED7
C6CED9C6CFD9C0CAD3C1C9D4C1C9D5BFC9D1C0CDD5C2CFD5C5CFD8C5CFD9C2CDD9AEBECE
7C8FA6748A9E8B9EAD7F909D808D9A7F8B97808A987E88957683932F405E24395457646B
6C665B16CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF005AC906AF9606AC9803AC980FAE9F34B6AA5EA2986AC1BCAF
7879808389A20711393D42607B727E846F768C727890727A92717A937179926F76947177
9874769A76769E7A7AA17D7FA58384A78584A5827FA9857FAD8982B3948BB79A91B89B91
C1A095C3A294C0A38FBCA18DBCA491C2A897C8AB9BC8AC98C7AD98CBB29DCAB29FCCB4A3
CFB8A7D4C1ADD4C2AED2BEAAD0B9A8D0BAA8D1BEAAD3C1ADD0BFABD0BEAED3C1B2D7C4B8
D1BFB2D5C5B8D8C7BDDACABDDBCBBDD7C7B9D8C8BBD7C9BDD9CCBDD9CDBDD5CABDD4C8BE
D9CBC3D9CCC5D6CAC4D5CAC4D4CBC7CBCCD065788F446287AFB7D4957182A95D6CB44F5E
B94656B83D4FB63347B42437B81F2FBD1D29C01A22BF1A1AC01D17B72015AB261AAE4032
BD6A5ACE9182C99B8CC1A293B59F91B29F91B1A19A8D86922D2745935A75941020AE040F
B4010BB6030CB1030CA50A119F4048BAA3AACED7DECCD9DFCED8E2C5D2DBC6D2DDBECCD4
C0CCD4C6CFD8C1C9D4C0CAD4C2CAD5C2CCD5C4CED7C4CED7C2CFD8C4D0DCC2CDD8B0BFCF
435A756E8BA36E88998599A59AA9B594A1AA96A2AE98A4B08D9AAA293B5B2A3F5B54616A
69645E2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE503AE9603AB990BA69625B1A761A8A37CADA99595938F
8E8E9859617B08163C484E697C737E826F768971778F737A92727A917078947278967378
9874769E79799E7A7BA07C7FA38183A58484AA8785A78481AE8C86AF9188B79A90B79A90
BF9E95C09F91C3A393C0A292BCA090C2A896C7AB9BC9AD9CC6AB97C9AF9BCBB39FCAB3A0
D0B9A6D5BEACD2BFABCFBCA8D0BAA9D0BAA8D0BCA9D2C0ACD1BFADD4C2B2D6C3B4D7C5B7
D3C2B4D7C6B9D8C7BDD8C9BED8C9BBD7C9BAD4C6B9DACBBFD8C9BCD9CDBED7CCC1D7CDC3
DBCEC6D9CCC6D6CAC5D7CBC7D6CCC9D1CDCDB5BECC5E73945E6C93A392B1A56C829E4253
A6303DAA2834B62834BB252DBB2329B72523B62A24B33228BB483BC76858D48677D69E8D
CBA595C2AA9CB4A397AFA497AAA195AAA294ACA29BAAA8B0393E5E6D54768B2436AA0A16
B5040EB5030CB2020CAE081098242D9C7481C1C9D5CBD9E1CFDAE4CAD7E0C5D1DCC0CED7
C3D0D9C6D0D9C5CDD8C1CAD4C3CCD6C2CED7C5D0DBC6D2DDC3D0DCC2CFDBC1CED9BBCAD9
3F56735C7D994F6E8295AFBD99AEBD9CAFBFA2B5C7ACBFD0A2B4CB2035582D435F5B6870
645F5C32A61F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE603B19B09AA9A1FACA55EA9A990969693BDBEC086878C
ACAEBA515C7519294B5259707C737E806E75866F768B71768D707691727797757B9A767B
9A76799C7878A17C7E9F7A7EA38081A78684A78784A78783AC8B84B09086B6998EB99C91
BC9F94C2A297C09F93C1A094BFA090C3A592C5AA98C5A999C8AD9CC9AF9DCCB4A0CBB5A0
D2BCA8D7C1AED0BBA9D0BDABD1BEADD0BCACD3BFAFD4C1B2D4C2B3D4C1B2D6C2B4D6C4B5
D2C1B3D7C4B8D9C7BBDBCBC0DACBBFD9CABCD4C6B8D8C8BDD7C9BED6CBBFD8CEC4D6CBC4
D8CBC4D8CAC6D9CCC9D7CBC9D4CAC7D6CCCBD0CACBC5C5D29BA2BA717792857C94A98B9D
B3828FBA7B86BF767CC87777D2827CD68E81DC9C8EDBA597D7AC9ECDAE9FC9B3A7C1B3A6
BAAFA4B7AEA4B2AAA1ADA69BAAA398AEA59CADA6A0D2D0D27F859F3131588D4D65990F1B
B1050FB2010BB2010BAF040D970C179D5B6A9696A6CAD9E2CDD9E2CEDAE2C8D6DEC6D4DC
C2CDD7C4CFD9C3CED8C5CED9C4CDD9C1CDD8C1CDDAC3D1DDC2CFDDC2D0DBC0CFD9BCCCD8
8699B453718D7799B493B4D17796BA5E78A25C73A0586F9D4B6293102554364C695A686D
5A595236AE2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CE07AE970BA89C3AA7A5809EA3A09EA2A8A3A6AD94989E
818590535C740A18395D62777D727D816E75856C748A70758F727794727899747B99737B
9C777C9D787A9D787AA07A7CA4807FA68480A6847FA6847EAA8981AF8E84BB9C91BA9C91
BB9F93BB9F93BA9D91BC9E91BFA190C4A491C8A996CBAF9ECCB1A2CEB4A2C9B29ECBB5A2
CFB9A8D3BFAED2BFAFD3BFB0D2BDAFCEBAACD1BDB1D2BFB3D2BFB2D0BCADD4C1B3D4C4B4
D2C1B3D5C2B5D8C5BADAC9BDD8C6BBD7C5BAD6C6B9D7C9BCD6CABDD5CCC1D8CEC6D7CBC5
DACCC6D6C9C4D5CBC6D3C9C5D6CBC8D4CAC9D0C8C6D3CBCACCC6C9CAC8CFBEBEC7B2B2BD
B1ADB5B3AAB0B8AAADC4B2B2D2BFB8CEBDB2CCBCB1C6B9AEC4B7AEC2B8AEC1B6AFBCB3AB
B8AFA8B8B0A7B4ADA3B3AEA2B4AFA4B3ADA4A8A39DAEAAA79D9EAE2A345872577A861A2C
A70612B0010BB2010CB0030CA309149B3E48CEBBC3CFD9E0CDDAE3CFDBE3C9D8E1C6D4DC
C6D1DBC3CFDAC5D2DBC5D2DBC4CED9C1CCD7C3CEDCC1CEDAC3D0DDC1CFDABDCDDAAEC0D2
8297B558749A31507E132F68031C5E01165C01155E00125B02145C011452273E63576871
5F615A5F4E3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CD08B29916AEA24F999A82A6AEAFB2B8C094979FABAFB6
8286926B748D0C1A396468797B6F79806C74886E778E727A92727A9371779571779A757C
9C757D9A75799C797B9E797BA27F7EA78280A5827FA5817DAD8883AF8E86BC9D94BB9D93
B99C8FBDA191BA9D8EBB9F90BFA291C5A593C8A896CAAB9DCBB0A1CCB2A1C9B19ECEB8A5
CFB9A8D3BEADD5C2B2D3C0B0D2BEAECFBCADCEBBADD2BFB1D0BCAED4C1B2D4C2B5D3C1B4
D0C0B2D1BFB2D8C6B9D8C7B9D7C7BBD6C6BCD6C8BCD8CCBFD5CBBED4CCC0D5CBC3D5CAC4
D3C7C1D0C6C1D0C8C4D2C9C5D2C7C3D2C8C5D1CAC7D1CAC7D2C9C7CBC5C2CBC8C4CDCCC7
CBC9C4CBC8C4C9C3C0C8C2BECBC3BDCAC4BBC8C0B9C5BDB6BFB7B2C0B9B2BFB6B3B7B0AE
B7B1ACB9B0A9B7AFA6B4ACA4B2AAA2AFA8A0ACA69FA9A5A0B0B0B65864833839648F4A64
9A0E1CAE050FB3020DB2020CAA05108E171EDBB0B4D6D6DACED9E2CBD8E2C9D7E3C7D5DF
C6D3DDC3D1DBC7D4DDC5D1DBC7D1DCC3CEDAC7D2DDC3CFDBC4CFDBBDCDDCB9CCE48CA5CA
29447807216000175F00125E01125F01125D01115D01115C01115C011359031749394C61
5C62615F544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0030E504B0971DA39A4E9799819AA2A39FA5ADA0A3AB9F9FA8
7A7B89565E7814213D6B6C7B7B7076816D76876E798B6F7A8C6C769573799874799C747B
9A70789E767B9E7B7BA38182A17E7EA4807FA78382A98684AB8784AF8D87B4968DB4978C
B4978ABB9D8EBD9F90C3A597BEA090C3A491C6A896CCAFA0C9AD9FCCB2A2C9B1A0CDB6A5
D0B9A9D2BDACD1BDADD6C3B3D1BEAED2BDAFCFBDAED3C1B2D2BFB1D3C0B4D1BFB3D5C2B7
D4C0B4D2BFB3D7C5B9D7C8BBD7CABED4C7BCD7CABFD5C8BDD1C7BCD4CAC1D3C8C1D4CAC3
D3C8C1D2C8C4D1C8C5D5CBC8D3C8C3D1C7C4D0C8C6D3CBC9D2C9C7CBC4C2CCC8C4CCCAC5
CAC9C5C7C7C4C6C4C3C4C1C0C5BFBBC8BFBACABEB9C3B9B2C2B8B4C1B8B6B8B5B99FA7B2
ADAFB8BDB0B0C0AAA7C3A8A5BEA29FBCA4A1C4B5B0B5AFABBEBEC0B1BCCF25325D806285
8B1B2CAB0913B2020BB1010BAE040F970B17BF7880DFD5D8D2D9E1CDD8E3C8D4E2C5D3DE
C4D2DCC3D1DAC6D2DBC6D1DDC5D1DEC4D2DDC6D3DDC2CFDBBFCDE2ACC2E06984B2142F6F
01196401166601126300115E000F5C01115C00105901115901105B011258010F4A0E1D41
545E655F594E15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00B09938908D58A6AB9DB1B8BC959AA4B2B6C09E9FAA
9291A14D546E2029447371807D6F7583717786707A876C778F707997757C9570759B7279
A1777CA47B7D9F7A7AA17E7FA38081A48180A48180AA8684A98581AD8B85B4958DB79990
BD9C93B9978CA9877BBE9B8FC1A092C0A291C4A997C9AD9EC8AC9CCAB09FC9B2A3CDB6A8
CAB5A5CFBBABD6C3B4D3C0B2CFBBAED0BBAFCEBCAECFBEAFD1C0B1D2BEB2D2BFB3D2C0B3
D4C1B4D2C0B2D6C5B8D4C5B9D4C7BBD5C8BCD5C7BCD4C7BCD3C8BED3CAC0D2C9C1D1C9C1
D5CAC3D3C9C3D1CAC5D2CAC3D2C9C2D1C9C3D4CBC8D3CBC9D1CAC6CFC9C4CBC7C3C9C9C8
C0C7CEB7C3D0A6AEC0AB9FB0D3AFB9DCADB2DCABAED8ABACD1AEAFC8B0B2B1A9B7384768
8182A1A47787B56670BB6066B75861B86269D6A0A2BCA9A7B0ACABA9AEB75563843F3D69
8C3E57A10F1CB3050FB1010BB0040EA3081298363FE7CDD1D1D6DCCCD6E0C7D2DFC6D2DD
C4D2DBC4D0DBC5D0DCC3D0DCC3D2DEC5D3DEC1CDDBB9CBE096AFD3314D84031D64011868
011265001263001160011360000F5A011159011158011058000F58000F56010E4D020F3D
3E4C5B5D5C532BA01700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00CCB67A80816E8690939FA5B0989DA8A3A7B29698A4
8687974A4E68252B45756F7E7B6C738573788670788A6F77907078927077977278987378
9F777CA078799E7978A37F7EA58181A48180A88584A88382AB8684AD8A85B5948DB79790
BD9C94BA988EB69489BD9B8DC2A291BB9F8DC0A593C6AB9ACAAF9DC8AE9CCCB4A5C9B2A5
C9B5A7CFBCADD3C2B3CFBEB1CBB9ADCEBBAED0BEAFD0C0B0D3C3B3D2C1B2D2BFB2D2C0B3
D4C1B5D4C1B4D7C6B8D9CABCD2C7BAD5C9BDD3C5BBD3C7BDD2C8BFD1C8C0D2CAC2D3CBC3
D3C9C3D2C8C4D0C9C6D1CBC6CFCAC1D0CAC2D5CDC7D3CCC7D1CCC4CEC9C2CBC9C3BFC6CD
7C94B0485D82867CA0B46F8CB8495BB3343FB4343EB73E47BE535CC77279D59CAC7D6587
654B7194455EA61D2EB41521B91320B11721AA3E43CFA4A1B5ACA9ADAFB293A1B6202E5A
8961838E1428B00916B4040EB1010AAD061090121DCF9CA4D5D2DBCCD4DEC8D2DDC7D4DC
C4D2DAC1CED7C3CFDCC2D0DDC1D1DDC0D0DEBCCEE57F97BF17346F011A64011667011365
01126200116000115F01135D011156021554021553011154010F5502125502114E010E3F
1E2D435C605B32AA2300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D3BB979297958896A199A3AEB3B8C39DA0AA9597A1
9294A1474E6132364C766D7B7E6E748571778870778C6F76906F75957177977177997378
9D767A9C74769D7676A27B7C9F7C7BA3817EA88584A88383AC8685B18A88B4908BB7978F
BB9C92BD9D91BE9E90BE9F8FBEA08FC1A493C0A594C6AB9BCBB0A1CAB2A1CCB5A5CDB5A7
CBB5A7D2C0B1D3C2B4CFBEB2CCBAACCCBAABCCB9A9D0BFAFD1C0B1D1BFB0D0BEB1D4C2B6
D4C1B7D3C1B5D4C4B6D6C9BDD3C8BDD3C8BFD2C6BCD0C6BDD1C7BFD0C7BFD2CAC1D4CAC2
D3C9C2D2C8C5D1CAC7D1CAC7D0C8C2D1C9C2D2C9C3D2C9C6D2CCC8CFCAC5C8C7C59FB2C5
2A4C797681B1AD779BAC233BC61927CA161EC9141CC6141BC01921B31C26AA2A38B55167
AC5B74D16C7DAB1421C20E15CA0E16C40F15A41619DB9794C3B3B0AAACADC3CED94A5A7C
584E7689314AA60D1BB4060FB3020CB0040F9D0A179F505BDECFD7CCD2DBCAD4DEC8D3DC
C6D2DBC4CFD8C4D1DAC1D0DCBECFDEBACFE5738CB60C2768021967011462011161011160
00115F00135D03165A0217530D1F4E28385F3C4D7711235B06195025386319275104123D
0B19365A6468568E4700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D4BC9DA7ACB0768593949EACACB2BD9899A39697A0
9096A13E4A5B42485A766D7A7F6D76836E778970788C6E73906E74926E759772789C757A
9D757AA2787B9F7678A07A7BA48182A4807FA78282A88282AA8382B38B88B28E89B6948E
B5968CBA9D8FC0A395BC9E8FBE9E8FC3A495C2A698C9ADA0CBB0A2C9B1A1CCB4A5CDB6A7
CDB6A8D2BEAFD1BEB2CCBAADCEBCADCCB9A8CBB7A6CCB9A9CFBDAFD1BEB0D3C2B3D2C2B6
D5C3BAD4C3BAD0C0B6D5C8BED3C7BED2C8BECEC4BBD0C6BED2C9C1CFC7BFD1CBC2D5CDC4
D5CBC4D7CFC8D4CEC8D2C9C6D4CAC5D2C8C1D5CCC5D3CAC5D1C9C6CECAC6C9CACC7A94AF
28497BAEA9D7A1506CBF1C2ACD121ACF1015CE0F16C71414C22523B73337A82E3D9F2539
9D2035C53E4DBE1924C91017CC0D14C70D12B10F13C15D5FD1ADAEAEA7A8A8ACB17E8CA2
263158865875911224AC0511B0010BAD020CA60713861A25DBB7BFCDCFD7CAD3DDC6D0DB
C5CDD9C5D0DAC5D0DBC4D2DFBBCFE87590BB0B2669011A6801146501126000115E00125E
02155B051D572A416D4C60807E8DA48492A6627392061B48223A606A7C8F6B74882B3552
04112F4755606A625A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D1B498BDC1C7808F9F9AA4B39CA0AC9DA0AAA5A8B2
6F7886233247484D62796F7C816E78836D77876E788A6E74907176906E74967278997279
9A7176A2797AA07879A27E7FA27E81A57F81A27B7BA98181AA8382B08A87AF8C86B6948E
B9978FB99B91BFA096BF9F94BF9F93C7A89BC3A79AC8AC9FCAAFA0C6AD9CCCB5A5CAB4A4
D0BAABD5BEB1D6BFB1D4BFAFD5C1B0CAB5A5CEB9A9CEBBACCEBDAFCEBEAFCEC0B0CFC1B4
D1C0B7CFBFB7CEC1B9C3B8B3C8BEBACDC4BED1C7BFD1C7BFD3C9C3D0C8C1D3CCC4D3CBC3
D3C9C2D5CDC5D3CCC4D4CCC5D5CCC5D3CAC3D6CDC8D5CBC8D3CAC7D1CCC9C9CACE859DBB
254579A4A0CDA85671BF1D2ACF1119D21115CF1015BC1713E87972D49494A26F7F965972
943C579D2037B51321C70F18CC0C15C50910BD0C13A51F25D09092B9A8A8A8A7AABFCAD7
3043666253787E2037A10916AC030EAB010AA8040E8F0C18BB7A85D6CED4C7D2DBC6D1DB
C6CFDAC4D1DAC4D0DCC2D1E87A93C00A276D011A6D01176A01146401165F01175C021C5B
0C255D6C8BB289A3BDA5B9C9ADBFD08CA0B7324871041C475A71897A8A92727B83606878
0B192F36465263625C13CD0900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C6A785BABCC18E9CAC9BA6B5999EAA9EA0ACAAAFBC
59667C091A3752556B796B77806D76826C75856D768970778F73789472789671789A727A
9A747B9A7477A17A7CA67F829F7A7DA67F81A57F80AB8385AA8283A07A79AF8D89B2928C
B99A94B89991BF9F97BE9F93C1A294C3A797C4A898C7AB9CCBB0A1CBB2A3CAB3A4CDB7A6
CAB5A5D4BDAFC2A896BCA38DDCC6B1CBB5A5CDB9A9CCBBABD2C3B4CDBEAFCEBCAFCFBFB3
D0C0B8C1B6AEA59A92ABA19CA99F9D9E9794C8C1BBD1C7C0D1C6C0D3C9C3D3C9C3D1C8C1
D3CAC4D2CBC4D3CDC5D3CBC4D4CCC5D4CCC8D6CECCD4CCCBD2CAC8D0C8C7CDCACDA7B7D1
26467A6974A7B37797B41F2FCE141BD11014CD1013B81A18EB948FCEB1AEC1B6BBA49BAB
6A547184506F9E324BB31524C50D18C60910C10A10AE1117C76B6DE6C9C8A6A5A5B6BFC6
647690272D547F4260920E1FA70411A9030DA7020B9B09148D2F3DDEC6CDCAD0D9C5D2DB
C6D1DCC5D2DCC1D0E294AAD0142F72031D7201186F011569011763021E5C2745737591B7
1E3B617D9DB95E798EA3BACD7B95AD4C698F021A4A1B3456697D897182866F7C7F6C787F
222E3E2D3B466B6C682FA51F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C29C75C0BCBF7D89998A94A2A0A6B2A5A6B2828897
29385408163758586D7769747D6971806A72846B74886E758C6F77916D7799717B9C777E
9D7B819B787DA07A80A47B81A0777C9E7779AD86899F777AAE85889D7675AD8A84B3938C
B5958FBF9F98BE9D95BE9F90C0A290C2A593C4A896C1A593C6A99AC5A99DC6ADA0CBB4A5
CFB8A8D5BEAEC5AA97C9AF99D9C1AECCB6A5CBB6A5CDBCACCEBFB0CEBDAFCFBEB1D2C1B7
CCBEB7A39892C2B8AECFC4BACCC1BCB1ABA7B0ACA6D1C8C1D1C6C0D0C6C0D5CBC5D3CAC4
D3CEC8D0CCC7D2CEC8D1CCC6D1CAC4D4CCC9D5CCCBD3CCCAD3CBC9D4CDCCD0CBCEC5CCE0
3C5B8B2A447BAA8FB4A2263AC91720D01015D01117BE191BD46F6ED6B2ADC1B7B5BAB8BB
A9AABA575879704F77A63D59B81422C20A12C30A0FB80D12A82D31D09B9BA79D9D929798
8A95A424335771557A80172D9F0516A5020FA5010AA10512830C1BC4959ED0CFD8C5D2DB
C5D3DEC2D0E0ADC2DE27427C021E6F021A7000176A001A630B2862567399A3BCD48399B0
5E758B61788B728696778CA14964880520520A204D556B7F6B7C82717F826E797C6E797E
35424F28373F676C6839B22D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0065D344C4BCB97279889FA8B4A9AFBAA9ACB77D8192
1B24450C1739626276766A747C6973816B74856C75856A7290717B916D7997717A967279
9C7A80A17C84A27A83A57C839A7076A1797BA77F81A27A7DB28B8DA27C7AAA8681B4928C
B3928ABA9B92BD9D93BB9A8FBF9E91C2A291C5A796C4A797C7AC9CC8AD9FC7AB9ECAB2A2
CBB5A6CFB8A9D3BBABD2BBA9D1BCA9CBB6A5CEBAAACEBCACD0C0B0CDBEAECEBDAFD3C2B8
CDBDB8A69A95CBC1B8CCC2B7CDC3BBBCB6AFACA8A0CFC8C0D0C8C0D1C8C0D4CBC3D2C9C2
D2CBC6D1CDC9D0CDC8CFCBC7D1CAC7D5CCCAD3CCCAD4CCCAD4CDCBD1CAC9D1CACBCBCBD6
778DB21E3F73767BA9A64F67BE1A27CF1219D01118C7161BBA373BE6A9A7C7B3B0BEB7B4
B1AFB4939CB52C3768966793A01B33BC0C18C0070DBD090DAB1318BA6466BFA7A59B9B99
B9C1C75C6C873B38617E365394091DA20210A5020CA4030F9208159A4D59DBCCD4C9D1DB
C5D0DFBFD0E74F689703216B011B70001A6B0120651C3E707C9ABAACC3D5B5C6D66D8296
98ADBF7E93A3A6BACD6D85A4132C5F0621533D567496AAB3849095748082757E80707A7D
3C495525363F596360675C4D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC735CFC2BA7E84928992A099A0AB989CA78F94A5
202849131B3D6B697C766A737B6B75816D77867078876D778E707B916F7A96717A97737A
96737A9F7981A07A81A47C81A17A7DA68083A78084A78083AB8587A07B79AA8483B28F8C
B4938BB8998FBF9D93C3A295BF9E91BE9E90C4A695C5AA99C8B09EC5AD9CC4A99AC7AC9D
CAB2A4CCB6A7CDB7A7CBB7A6CEBAAAD2BEADCCB8A7CBB9A9CFBEAFCDBEAFCDBEB0D1C2B7
CFC0BAA49894C8C0B9CDC7BDC9C3BCA6A198C1BBB1CFC9BECFC8BFD0C9C0D4CCC4D4CCC4
D3CBC4D5CDC8D3CDC6D2CBC7D2CAC8D2CBCAD1CDCBD2CECCD2CBCAD0C8C7D1C8C7C9C4C7
B3C0D63A5883374F86B383A5AE2334C9131CD01119CB1017BC1C23DB7D7ED1AFABC0B4AF
B6B0B0B0B3C14E5F8A5D568A953859B41222C10911BF0A0DB30D139E2D31E7BDBCB7B3B2
A0A7AA8D98AC1C254D7D5679820E25A10516A80310A5020E9C0613831C28D8B5BDCECFD8
C6D1E397ABCE0F2A6B021E70001A6D04256735598898B8D2B1C7D8B2C2CFB0BFCF435B73
6A859F6E8AA46280A51B3569031B56213963788C9C7B8B906974796C787971797C737D82
394854283A4256615C5C544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C12ADAC8BCA2A8B5A4AFBE9CA3AEA1A6B1B1B7CA
242D4D1A21426B6979766B7373646E826F7A826D76876F778C707990707A96717A946F76
98757B9C797F9F7C819E7B7EA58486A07F82A07E829E797DA983859E7878AE8786AE8787
B5918CBA968DBD9B8FBB9D8DBC9F90BDA191BCA18EC0A793C7AF9DC7AE9DC7AD9DC9AE9F
C9AFA1D0B8AACFB9AACCB9ABCBB9AACDBAABCAB5A7CDB8AACFBEAFD1C0B2CEBEB1CDBEB2
D0C0B7BEB1AAA29892AEA6A0A8A29CB8B0A8CEC7BCCEC6BCD0C9C1D0CAC2D1CCC3D6CFC8
D3CBC4D3CBC4D5CDC4D3CCC5D1CBC8CBC7C5CDC9C8CECACAD0CCCACEC8C6D1C8C6CBC7C5
C2C9D4889EBD27487D8F87B3A63F54C11924CC1019CD0F15C6141BBB393CE7A9A7C2AFAA
BEB7B2B4B3B6909DB92B386C93628CA1192EC11019C00A10B90A109D1319BE7778AC9A9A
98989B9498A540486A56486F7C264099081AA60311A5020DA10410890B18B37882D4CDD7
C2D0E744608F02216A011F6D0627685377A1A6C4DBB3CAD6B7C8D3B8C6D1B3C1D05B7088
2B466559779C0420530019521B335E63778F737E886F797D717A7D6A76766D777A6C7A81
293A492F444D5865605D564600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D7C4B3ABB1BE98A4B499A1AE9EA4B09A9EB2
292F4E2327446D69777569715E50597C6C75826D75846C738B6F758E6E76916C76957079
9B757D9B757C9D797E9D7B80A483879172779173789C7B80A68084A57D7EAC8484AD8585
B28C88B49188B9988DBC9D8FBB9F91BCA18FBEA391BAA18EC5AC9BC5AD9DC9B0A2D1B8AA
D1BAABCBB5A6CCB6A8CCBAABCCBAABCEBCADCAB8AACDB9ABCCB9ABCFBCAECCBAABCDBCAD
CFBFB1CCBEB3CCBEB6C5BBB4C9BFBACEC5BECDC5BDCEC7C0D0C9C2CEC8C1CFCAC3D4D0CA
D2CEC8D5CFC9D4CEC7D4CDC9D1CBC9CBC7C6CBC8C8D0CDCDCFCCCACEC9C6CEC6C4CEC7C4
C7C6CABEC9DC5B77A0485C8FB47A99B22131CE141FCD0E15CD1119B81A1FD87879CBA9A5
BAB3AEB4B3B1AFB6C6465A8564588B933151B40F21BE0914BA0810AC0F16AA4548C9A6A5
B3ADAEA4A6AD8991AA262C54814C6C8C0F22A10411A6020DA603119607148B3340DCC5D0
AEB9D5122F6902236C082B6D5D80AAB0CCE2B8CDD9BBCDD5BCCBD4BAC9D5B0C0CF96A9C1
50678D0F285800194E1F3D6671879EA6B6C0939DA4808A8D8690936B767769767A61737F
12243B4155615A67645D584C15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D3BBA6BBBEC99CA9BBA2ACBAB0B5C187899B
4449652A2D466C677473676F74656B7D6A737F6A71836B708B6F748D6F7596737D97707A
9A727A9F767BA27B7F9D787D9771798A696F896A6F896B6FA38183A68080AD8685AC8483
B28B86B38E86BC9A91C1A197BFA295BC9F8EBC9D8CBCA08FC6AB9BC8AE9FCDB4A5BBA392
C9B4A1CDB7A8CBB5A7C9B6A7CBB8A9CDBAACC9B7A9CBB8AACEBAACD0BDAFCDBBACCEBCAE
CCBFB0CCBFB3CFC1B9CBBFB8CFC4BFCFC5BFCEC6BFCDC4C0D0C8C4D0CAC4CBC7C1D5D4CE
D5D1CED4D0CBD3CECBD2CBCACFC7C8CCC8C7CCC9C8CCCAC6CECEC9CCCAC6CBC7C3CDC6C3
CDC6C8C6C7CFA1B2CA2545769F8FB89F3247C41622CF1218D01118C11118B63337D99D9B
BBACA8B4B2AEB2B5BA8A98B5303D738C5582A0142CBA0A17B90510B1081196161DC78B8D
D1C3C599999E939AAA2A355B6853787C1D349D0818A3020FA3010F99020E7C0C1ACEA1AF
9093B008215F0325684B709EABC8E1B8CCDABACCD6BACBD3BBCBD5BCCEDEA2BAD56983AE
163267021B51112C5866809A8294A196A5AB717D836F7C7F6C777A63727461737C3F536C
05193D48617557696B5C5E552CA21B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00CAAF92B9B9C2929EB09BA6B5A0A5B285899B
3E45602D324A6E687574696F776A6F7B69707E696F81696E856A708D6F7890717995717A
9A72799E7278A2767EA379838E646F9E757EA07D81866A6CA18586A48383AB8988B08A88
B69089B7928AB59389BFA195BDA093BEA091BFA091C1A192C1A595C2A796C8AD9BBEA490
C8B19EC6B1A1C9B5A6CAB7A8CCB6A8D1BAADCBB6AACDB6ABCEB8ACCDBAAECEBBB0CEBDB2
CABDB2CDC3B9CEC2BACCC0B9C9BFB9D0C7C0CFC6BFCDC5C0CDC7C1CEC9C1D2CEC7D3D0CB
D3D1CED1CDC9D4CFCBD2CCCAD0CCCACDCBC9CBC9C5CECDC7CDCDC7CBCCC7CCCAC6CDC8C6
CDC6C6CBC8CAC4C9D74D6892546395AE6E89B41D2BC91118CD0F14C80F15B8191ECF7070
CBA8A5B9B0ABB6B5B5B5BCCC4658864D3C6F89203EB3101DBC0912BA0B14A50D15A5474C
B395959B97989596A06069863535607D3E5D910C229E0212A1000F9B020E8A0714A15666
7F7192061C571B40779FC0DDB7CCDEBBCDD8BBCCD7B8CAD7B6C8DDA1BADA486698042562
031F581C365F6E839E657585738189707E816B747A6B767A6774795A6E763E51690A1D48
011345132A4E4E6473585F5C41752900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0094BE69C5C3C87B889897A0AE9499A4ABB1C1
1E27423B41586C697571686D74676B7C6A70806B71816A71886B768A6975916E7999747D
9D757EA37980A0757D9E757E8B626C9E767BA28182A18C8BCABABBD0BCC0B2979CAC8A8B
B38F8CB28F88B49388B99D8DBEA292BB9D8EBE9F91BFA192B79D8DB49C8EB9A496BCA897
C1AD9CC3B09FC4B1A2C5B2A4C9B2A4CDB6A9CBB4A8CBB3A8CBB5AACBB7ADD1BFB5CEBDB5
CDBEB6CEC2B9CDC1B9C8BEB7C5BDB6D0C8C1CEC5BECDC5BECEC8C0D0CAC2CFCBC3D2CFC9
D2CFCCD3CFCCD1CDC9D3CFCBCFCCC8CFCDC8CAC8C5CBCAC6CBCBC6CCCEC8CCCCC7CCC8C4
CCC7C4CDC8C7C8C6CE96A6C429477CA391B5A02E42C31820CC1016CE1016C7161AB43234
DEA4A2C1AFACB9B4B4BBBEC58998B630396B93577CA3192CB90C16BE0B12B20B13941A20
C39091CDC5C7A2A2AC8D94A9232D5776567B7B10299703159F010F9D020D970511811323
784B6E0C1A504971A0B1CFE8B7CBDEB6CADAB2C8DDA5BFDE748FBB1E3C73011F5C02255A
46618672889D9DAEB985939BA6B5BA7E8C928B979F71818C6376882F4561061843010F46
000B46000F4224375656606655493D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0061D245D2CCCE909AAAA4ADBA9CA1ACA0A7B7
1B26403D4A635E637565626E71656D7D6B717E6970836B748A6C79886674906C789D7682
9D74809F777FA37A8199717A8B666D957779B09B9BDACED0DBD3D9DDD3DAD6C4CBA5898E
AE8A8BB5918CB7958AB99A8ABB9E8EBA9A8CB99A8BB4998BA58F839481788C7B7391847A
B6A69ABEAC9CC5B1A2C7B1A3CBB5A7C9B2A4C9B3A6CDB6AACBB5A9CDB9AFCFBCB6D3C1BC
CEBEB7CBBEB5CBC1B9CBC3BCCBC5BDCDC6BDD0C7BFCEC7BECFC8C1CDC7C0CFCBC2D1CCC6
D2CECAD2CFCBD2CECBD1CDCAD1CDCAD0CDC8C9C7C3CDCAC7CCC9C7CACAC7CCCBC6CCC8C4
CBC7C3CBC7C5C9C7CBBFC6D544628E596997A76580B31F29C91219CB0D13C90E14B4171A
D17475CBA9A6BCB2B0B8B6B9B6BFD23D507B72608D952E49B30F20BD0A14B205109F0D17
B15F67C8B3BAA09FAB999CAA4551744B456D752643940B1D9F02119E020C9B010D880512
8237531D1B4D33598E9EC5EEA9C8EB95B3D76382AF20417903266401215C1A3C6C688CAD
89A6BCA7BCC891A2ADA4B5BF93A4AF8497A36F8295415773142850011145000C43010A42
010A43020E44091A444A5A685A564E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0059C837D4CAC6848E9B98A1AFA8ACB8858A9C
2632501F2F56142148313654645E6D7A68717F69718368728A6B778D6D7991707A977380
9C73829F7580A37A829A727B836268857072D0C5C6CFC5CBA497A1A89AA4E2D2D9AB9196
AC8A8BB18C87B7958ABD9D8FBB9E90B29486B19585AA948784736A9B8A83A5948E746964
9B8F86B9A799C1AA9CC2AB9DC7B0A2C6B0A2C5AFA0C9B3A6CBB6AACAB8AECFBEB6D2C2BD
D1C3BDCBC0B6CFC6BDCBC3BBCAC3BACEC5BCCEC6BED1CAC3CEC7C1CEC8C0D1CDC4D0CCC5
D1CDC9D4CFCED4CFCECFCBCAD0CDCBCDCBC8C8C7C4CECBC8CDC9C7CDCAC8CDC8C4CDC7C3
CBC7C2C8C4C1CBC9C9C5C7CE8B9FBE254577A490B59D2B3CC1141ECB1015CB0D15C21117
B53439DDA0A1C1ACABB9AEB1C2C0CB818AA847426BAF6884AA172BBB0A16B5030DAB0912
98252CB78B8FAAA2A99B9EA5747E99222A54744668820C1F9B03119E020C9A000C91040F
7D1C30563E620D245C193D7C1D3F7D0B2C6802226103245F1A3A6A647FA55978988FAFC8
2F4C6191A6B55D6E7C7B8A95637381596E86223960031647000C46010A4701094200083F
000A40020E4402123F41546761646010CB0800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0051BF28DBCFC39199A5A3ACBAADB0BD858A9F
2B355B020E41020C440A123E605D757767727E6A718068718669748E6E79907079987480
996F7D9C717D9B717A9B727A9C797E988083DCCFD5AB9BA5A189939A8289DDC9CEAA9396
A88A88AA8881B19086B8988CB39488B09184AE90849884797D716A9B8D8A978A8A736C6B
847C76B4A599BCA798C0AA9BC5AFA0C1AA9BC4AE9DC7B3A5C7B4A8C9B8ADC9BBB1CEC0B9
CEC3BBC8BEB6CEC4BFCAC1BAC9C2B8CDC5BBCEC7BFD1CAC6D0CAC4CEC7BFD0CAC3CFCCC6
D0CDC9D3CFCED2CDCCD1CDCBCECBC8CECDCACECCC9CCC8C4CFC8C5CFC8C6CFC8C5CCC6C2
CCC7C3C7C3C0C9C5C5C7C6C9BCC5D73C5B876170A0A05E77AE1A28C60F18CE0F17CA1117
B4151CD86F75D899A0CE9CA4CD9CA9C99CAFA87793D37C93B01E2EBB0B16BA0611B30610
9C1118AF6C6DDED3D4C0C7CF8B95AA2A3A6056466C70152B9307149C020D9A010C94020D
760814B98B9D6F71932C3F701D33681D36683C57816E88A8A3B9CEB8C7DA4D6177647C8F
657D8E7C939F899CA58091988999A71F355901134A010D48010946020A4502094100093E
000B3D01103E02113B32455B63686827A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DAC9B9949AA89DA7B79DA0AF7C8198
0E173F020B40010843030A3D514F6D7365737A676F7B666F836974886974916F7A95707C
976F7B9B707D9A6E79986B759E767D9E8287DFCDD49F8892A6878F9F8389D6C0C5A48C8E
A88986A7857EAE8E84B29287AF8F84AF8E80B09184917D737065627C7376756F72686262
7B726CA39489BBA799C0AA9BC3AD9CC3AD9CC4AF9EC4AFA0C7B4A6CAB9ABC6B9ADC9BEB4
CEC3BBCBBFB8CBC1BACCC3BACAC3B7D0C9BECEC6C1CDC7C4CFCAC5CECAC4CDC8C3D1CDC8
D1CFCAD2D0CBD1CECAD0CCC8CFCCC8CDCAC7CECBC9CFC9C7CBC4C1D0C9C6CDC9C5CCC7C3
CCC7C3C7C3C1C7C4C5C7C6C6C5C7CF8C9EBC2B477B9C88AE9A3044BB1823C60F16CB1318
C31218BA2129B2303BA92F3AA72A38A82A3AA52635B12431B6141EBA0C15B50910AF0A10
9D1116974A4AC1B1B5979FA78C96A65768862D305A703550880A1C9A030E9B010B96020D
8307119A5862D5CBD6BBC6D7B1C1D5B1C3D8BACCDCBACCD8B9C6D1BAC5D0A1B0BF8AA0B1
AAC2D56D8CA29CBACF748F9C9DB2C122395F00124D010C49010B4500093F000A3C010E39
0E1E3F293B5511254122364B636C6F2AA52100FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00D4BCA99EA1AE9DA8B98C91A27F859D
02083001063902074102093E4545667467797765717E6A72886F798E6D7992707C916C78
97707C996F7B9669739E6F79A0767F98787FDBC6CBB29DA3A2888ECDB4B9B69DA2A7898B
A5817EAA857DAD8981AD8A81AF8C81AF8F7FAE907FA48A7F6E5B58695F5F655E5E7B736D
9C8F849F8E80BDA799BDA797C1AC9AC1AE9DC4B0A0C5B1A2C8B4A5CAB8AAC8BBAEC9BEB4
D0C2BCD0C2BCCDC4BACCC5B8CBC4B8CDC6BBCEC6C2CEC7C3CDC8C4CAC6C3C9C5C1D1CEC9
D3D0CCD6D4CFDAD8D3D5D3CED1CECAD1CECAD3CFCDCFCAC9CBC6C4CCC8C6CECBC9CEC9C7
CAC6C6CAC6C6C9C7C7C8C8C6C7C6C8C0C5D46B7EA44F5882A0718C9F303FB22025B71B1A
B81E1BB4201EAD2222A82122A71F23A92327A82627A92726A62323A52324A1242299231F
8B28269E6664A297999EA4A9A2AAB9788AA118284F6B4C6F7A0F269504129C010D98020C
9107127A202BD7BBC5C8CCD4C3CFD8C0CCD8C0CDD8BBCCD5B7C6D2B5C4D1B3C4D7486381
43618D0421571C3B6E385B78648090374E6D02134B000F4B000E45000F3D07183B26394D
475A634F60662F4352182C3F5D666D55483F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CAAE94A2A2AB99A0B37E8599424966
01062E01043401063E02083F3F3F637267797B69737F6871886C768D6D788E6E78906C74
9770789B7179956A6F9C7177A0767DA07E83B2999DD9C6C9D1BCC2B69DA2997A7EAB8986
A5827AA9857DA9837BAD867FB08C81AE8D7DAE907DB194859F877B927E759180778D7B71
9A8579B59E90BDA596BDA896BFAA98C1AC9DC5B0A2C5B1A2C4B1A2C8B7A8C9BCAEC9BDB3
CDC2BAD0C6BECAC3B9CEC7BDC7C1B7CDC7BECDC7C1CDC9C2CBC5C0CDC7C4CFCBC6D3D1CB
D7D5D1D7D5D1D6D6D2D6D4D1DAD6D4D7D2D0D2CECCD0CCCBCCCAC9CAC8C7CDCACACCC9C9
CBC7C7C8C4C4C8C7C6C6C4C0C5C2C3C6C4CAB9BCCD9098B1827C91AA828DC57E7FC77872
C87770C77C71C58177C4837BC88781C88B83CB9189CD9690CD9691C8928EC48F8BBA8883
AF8985B5A5A2949698C0CAD1BBCBDA94A9BE31456748436872243E8E07179A020F9A000C
96030F7D0B18B8838DD2CCD2C5CED8C0CCD8BCC9D6B8C9D5B8CAD79AADBE72889E455E80
05225C02196201175D1835616B889A5C728C01154801134B05164220324D465864566668
5866645460603E4E5914253558676C625C5500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0098C26CACA8AF84889B84899F141939
02062E01043401063D020A3F3C3D5E7868797F6672856975886A758B6C76916F788F6870
986F769A71769B71759A70769E767D9E797E9C797DA08287A5878CA281859D7678A57F79
A7847BA27F76A58075A9847AAC8A7EB19183AD9080B09685B89F91B8A191B49C8DB59D8F
B99F92BDA395BCA394BEA895C0AA97C2AB9CC4AEA0C7B2A3C8B6A5C8B7A8C8BBACC9BFB4
CAC0B7CDC3BBCEC5BFCDC5BFC6C0B9CAC6BFCCC7C1C9C6BFCBC7C0CFCBC6CFCBC5D2CECA
D9D6D1D7D5D0D5D4D2D3D1CFDAD6D5D5D0D0D3D0D0CDCDCDCBCACAC9C8C8CCCBCBC9C8C8
CBC8C7C8C6C3C6C5C2C5C2BFC6C1C1C5C2C3C4C0C4BFBEC3BDBDC3BFBBBCC4B7B3C6B7B1
C7B6B1C1B4ADB9AEA8B8AEA9B7ADA9B2A8A3B0A7A3B6AEAAB1A7A5AFA8A5B1A8A6ABA2A0
A6A1A1D2D4D5B5BCC2A1ACB76B7B8D7083976779951F2850784868840B229903149A010F
9A02108F09168D3D48DCC9CFC8CED9C2CFDBBFCDD9B7C8D3B7C9D696A9B8768C9DA9BFD5
1B326503186102155F041A4E59758D748CA0071C41172C4F3E516654666C5B68685B6663
576160535E603C4A5415253257686D79797410CB0800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065D549BCB4B48A8EA1696D87070C2E
00042E020533010639030D3D3F3F5E766475816674866A77896A778E6C788E69748F6772
976F789B71799E737B9E737BA078809F767D9D7277A4797CA57B7DA1797AA27779A47978
A67E79A07971A37D71A68374AE8E80B39688B19585AF9585B39B8CBAA192B8A08DB9A28F
BAA292BCA395BEA697BEA694BEA793C3AC9BC2AC9DC5B0A1C9B5A6C8B6A8C7B9ABC7BDB2
CABFB6CCC2BACFC6C0D0C8C2CBC5BECAC6BFCAC6BFC7C4BEC9C6C1CECAC6D3CECAD4CECB
D8D3CFD9D6D2D5D4D1D3D3D1D9D6D5D5D1D2D0CED0CACACCCAC9CAC9C8C7C9C9C5CBCAC6
C8C7C2C8C7C2C6C5C1C5C4C1C3C2C1C2C1C0C2C0BFC3BFBEC0BFBEBCBCB9BBB9B6BBB8B6
B9B7B4B6B6B3B2B1AFB0B0ACAEACA9ADABAAAEACAAADACA9ABA9A6A6A4A3B6B7B6B9B8B9
9F9EA3A3A6AA989DA3949AA199A0ACB9C6D295A6BC23345D654E777715319405199B0210
9C010F9305107A1420CFA8B1C9CBD5C2CED8BFCDD7B6C7D1B8C9D5B8CAD8768DA1AFC6DB
42567F01135600125901164A4A6580657B884D60705A6D755D6F715A6B685B69645D6963
5B65655763672B3D481C303C55676A8B8F8C239C1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005CCA39C6BBB7737B8C4A516B000528
03072E16163C22234A070D35494965746374816A778569778766768864728A66738E6A75
956F7A9D747F9C727B9C6F7A9E727BA0747CA4767DA6787CA6797BA4787AA17477A37678
A276759F7470A47C71AC8879B19082B59687B59889B69A8CB89D8EBA9F8FBA9F8EB9A28E
BBA292BFA697BDA496C1A797C0A794C4AD9BC3AD9DC7B1A3C7B2A5C7B5A9C7BAAEC7BEB3
CAC0B7CDC4BCCBC6BDD0CAC2C8C2BACAC3BFCEC7C3C8C4C0CCC9C5D2CFCCD5D2CFD4D1CF
D4D0CDD3D1CDD2D0CDD4D2D1DAD8D9D5D2D3D0CCCECCC9CBCCC9CACBC9C9CBCAC8CDCBC8
C9C7C3C8C7C2C7C6C2C4C5C3C0C1C0C2C2C0C3C1C3C4C1C2C0BFC0B9B7B7BEB9BBBBB7B7
BAB6B5B7B1B0B7B0B0B5AEADB6ADAFB2A8AAB1A5A7ACA4A2B0A5A5AEA1A1A69E9DB1A9AB
ABA2A79F999EC4C1C5BCBABFB1B0BABFC7D79AAAC64152793F37617B2F4B8F0A1D9A0311
98000D92020E810816A2646ED3CBD4BFCAD3BDCCD5BBCBD5BAC9D5A0B2C12D435B5C7289
6B7D990D2051041853051B4860778C6E81886F7E816878775F6F6D5E6C685B69645D6A64
5B6867526067112332253D474B60618C94922BA52300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02ACDBBB0868B9A343C5902072A
0A0D2C49415A4E455E0E0E2C57536C7A6B7C7E6A77806875866576866172835F6E886270
9169759B717C9B707B9E727CA0727C9C6E77A3727BA6767DA4757A9E7073A07375A07275
A27575A37876A88179AD8B7DB09081B29283B49586B39587B39587B59889B69C8ABAA08D
BBA191BCA294BEA496BEA393C2A997C1AC9AC2AC9EC7B0A4C7B2A6C7B6ABC7BCB0CAC2B7
C8BEB5CAC1B9CAC2BBCEC6C0CBC3BEC8C0BCCDC4C2CDC6C4CCCAC7D3D3CFD5D5D4CECECD
CFCECED3D1CFD6D3D2D4D1D2D2D1D2D4D3D4D2CED0CFCBCCCCC8C8CAC7C8CCCBCBC9C8C7
C8C8C5C3C3BEC4C4C2BDC3C3B8C2C4BEC1C5C4BCC2C7BABEC6B4B9C6B2B7CAB1B7CEB1B7
CFAAB3D2A8AFCCA1A8CA9DA2CA99A2C9939DC48D97C08993C18490C0828DB97D84B87D84
B97C87B27985D3A0ACDAABBAB07F949C728C724E70866888623C5A9F4C638B08199A0212
98010E91010C8804137B2633DBC1CBC5CBD5C1CCD8BFCBD6B7C2CF7E8E9B9AAAB9708390
B2C2D066778F2F43643348628697A46C7C826E7D7F6C7A78677172626B6A5E69675A6867
5363692C3D5002132C314B594961646F7D7C51474000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0052B920CFB8A68A8C9D1B234203092A
23243B5E5260564A5C15122A645C7279687777636F7B6370816271825C6E7E56678D6272
906571986D77966B789A6D7A9B6D799F6F7B9D6C77A27077A17177A071749A6C6EA07372
A07573A57A76A9827AAA8679A98879AF8F80B49686B19585B59888B69A87B89D8BBAA090
BBA091BCA193C1A698C0A797C0AA99BEAA9BC1AC9FC1ACA0C5B2A5C5B6A9C2B9ADC6BEB3
C9C0B5CCC0B9CCC1BCCFC5BFCAC2BCC3BCB5CAC4C0CCC7C5CCC9CAD2D1CFD1D2D0CECFCD
D0D0D0D2D1D2CFCED0CFCED0CECED0D2D4D4D1D0D1CCCACACACAC9C7C6C7C7C6C6C7C6C6
C7C6C5C1C1C0C3C7C99DABBA658096B4BACDBF9EABCA8894CA7884C56D79B75966B54E5E
B34154B13A4BAB3443A52D3BA326349F1F2EA01E2D9C1A2AA0192B9C17279C16239B1824
9A16259A17279B1A2F961A30971B3092172E901A33891A308A1D2F9317299706169C0210
9A010E93000C8F02127B081AB67086C4A0B8C5B0C7C9BDD0C9C4D2A4A7B2BFC9D196A7B2
9EB0BC8EA0AA70838D6D7E8569767C6A76796F7B7C6F7A79676F71626C6D5D6A6E50616B
293A51041234000C2F152A42435A645666675B554E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B71AD4B6A08A8B9A101A39050C28
3D3C4B60555D5449571C172E6F657878657278626C7E63707E5E6D7A56668057688C616F
966A74966A75986C7A986D7B976C7B9C717E9D707A9C6C749D6E729D6E709B6C6D9D7370
A07772A67C76A88078A78276A78577AA897AAF907FB09384B39787B69B89B69C8CB89F92
BA9F92BDA294BFA697BEA797BEA99ABCA99CC0ADA0C3B0A3C3B1A2C1B4A5C1B7ACC3BBB0
C5BDB2C8BFB6CAC0B9CBC2BBCEC6BEBEB8B0CAC7C1CCC9C7CBC8C8CCCBC9D0D1CDD0D1CD
D2D2D1CFCFD0D0CFD2D0CFD0D1D1D2CFD0D0CCCCCCCBCBCBC9CAC9C7C8C7C8C7C7C5C4C3
C5C5C3C1C3C2C0C3C89DAEC42143728592BA92586FA42738B61E2CB91C26B91924BB1822
BD1623BD1421BD1422B7121DB61219B31015B4141BB01219AF1118AD1217AC1116A71012
A71013AA1116AB121AAA121CA50E18A40F199F09189B09179C0A169B09159F0A1799040F
9A020E96020D960212900416850C247A163279223E7B314A87495E8A65729E99A273808B
61727F7284886273776E7C7E6F787B727C7D75807F707B7A697274616C7054667420304F
010D37000735010733000B2F22364A54656A59565100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B414CCA88E827E8C060E2C080D26
5B566262545A514653201A2E72677876636F79616B7C5E6B7655647C5A69845C6B8F6473
966975986D78956F7E86687E7C637C8B6E8298717D9B6E769C6C719A696C9C6B6C9D706D
A27773A67C76A77F77A68174A68475A88776AF8F7DB29284B29588B09587B19B8DB49F91
B6A294B6A092BBA596BDA799BBA499C3AEA3C2AFA2C1AFA1C4B3A4BFB1A4C0B6ACC5BCB2
C8C0B5C9C1B7C9C1B8CCC4BCD0C8C0C4BEB8CBC8C4CBC9C6CBC7C6CBC9C5CBCCC7CECFCB
CDCECDCFD0D0D1D0D1CFCDCED0D1D1CCCDCCCDCECCCBCCCBC8C9C7C8C7C5C9C6C4C5C3C2
C6C5C4C4C4C4BEC1C2BAC3D24E6B973C5588AE82A0A22A38B81F26B71D1EB21D1BAF221E
AC2120AD2726AC2A2CA5292AA62F2CA6352FA43931A03B34A13D379F3E379E3F379B3E35
9B3E35A1443D9E3E3B9D3E3A973836933333923035902D328B242A851E24881C2386171C
8812198810178A0C168C0C188B0B1A890A1A880B1D850A1D7E0B206B18278C6F77A1A6AD
7E8C9395A5A78392948996977A83866E78797581816D797A6C76795A6973263854010D3A
01093B010836000734010A340616334559615257560CC80700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C79C7B7B717F060B2A0A0D27
6A616D64535B4B414D2C26376E667472636E775E697B5C68795664805B6A89616E8F6471
936775926C7E7B637D352F5916164A3831598E758A986C7698676B9766689C6C6BA17572
A47876A67876A27771A88277A58373AF8E7CB0907EB09183B09388AE9489AA988CAE9F93
B4A394B5A193BAA496BAA499BAA49BBDAA9FC0ACA1C1ADA1C0AEA2C1B2A7C0B5ACC6BCB2
C6BDB3C6BCB3C7BFB7CAC2BACEC5BFCBC5C0CBC7C3CFCDC9CBC8C4CECDC8CACAC7CDCDCA
CCCCCCCDCDCECCCBCCCCCBCBCDCECDCACCCAC9CBC9CBCECBC9CBC8C8C8C6C8C5C4C8C6C4
C5C3C4C5C3C4C0C1C1BCBFC794A4C12A44719A92AEAB7077BE6A69C77471CC817ACF8A83
D08F8ACF9791CB9894C99B95CBA09BC39F96C1A098C1A39ABFA29CBA9E98BCA09AC5ACA5
AB948CB49D96B8A09DB49D99AB9492B69F9EA98F91B0989AAA8F93AB8D90A78284A77C7E
A775799C656894575C8D4A4F8A41478133397C262E761A227415226416207D5C60BBBDC1
A7B4BB86959B8B979B6E7C7D707C7D6974746C77786875776572793F4F6504103C00083E
02083C010837010733000835000E302C41504D585A17921000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C092688F848B050C29171A33
5C515E64515B49414F36374B5A5B6E615A6C6F5D6B7357647A5A66815D6A885F6C8E6472
8D6476826480342C570A124C0610530D134B706180956D7A95656A9A6A6D9B6D6DA27574
A17271A57573A27570A87F77AC877AAF8C7CB49181B19082AE91869F8A7F8879707F746B
A99A90B5A195BAA498B9A397B9A499BAA79BC0ADA0C1ADA1BFACA1C0B0A7C2B7AEC0B6AD
C5BBB3C8BEB6C9C0B8C9C2BBCBC4BECFC9C4CCC8C2CECDC6CAC9C4CECDC9D0CECBCCCBC9
CDCCCCCCCBCDCBC9CBCECDCECECFCDCACBC9C7C9C6CACCCACACBCBC7C7C8C3C2C2C6C5C6
C1BFC3BEBDC0C1C0C3BEBFC2B7BBC88B98ACA6ABB9C4BABCCAB8B7C8B6B3C2B4AFC0B3AE
C3B4B3BDB3B2B6B0B0B5B0AFB4AEACAEACA9ADABA7ADAAA8AFA9A9AAA3A3AAA4A4ABA8A8
9A9C98989B99ACADAFACAFB1A6ACB1CFD7DEC4CED9ACBAC998ACBBC5D4DCC9CFD5C6C9D0
CDCCD4C7C4CAC3BBC2BFB6BBB8ACB1AA9C9FA48F929980867C5F6B755963756A6F8C9499
87959D6C7881717B816C777A6773746371716473736372745D6D7A142446020D43010840
01073C010837010833000A34010F351C2E444C5A5F28632000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B686539B8D90090F29323448
685C6862515B3A36472D36510E173A222543685D70715A66775A65815F6C886270896071
86627A59456C14124139396A20235B060D435A4D6F916C7A95666C98686B9B6C6E9F7071
A27372A97A78AA7E79A67E76A68075AE897AB08C7DB39184B4978C8C776DA6988F867B72
8F8279AD9E93B7A397B5A094B8A396B8A698BEAC9DC0AFA1C1B1A4BFB3A8BFB6ADC1B8B1
C6BCB6C5BBB5C5BDB7C4BFBAC8C4C0CCC7C2CCC7C2D0CCC7CCCAC7CDCBC8CDC8C5CEC9C6
CECCC9D0D0CECBCACACBCACBCACBCBC9CAC9C8C9C8CDCECCCACAC9C5C5C6C5C4C6C5C4C6
C2C1C4BFBFC0C3C2C3C1C1C1BFBEC0BCBFC0BABDBDBCBEBDBEBDBDBBBBB9BABBB6BAB9B6
BCB9BAB4B4B7B2B3B5B2B3B5AEAFB0AAACACA8A9AAABA9ADAAA7ABA4A2A3A5A3A59E9F9F
9EA3A2949B9AC7CFD1D0DADEA4AEB9B2C4D794ADCA7C97B357748BC0D6E5C6D4DFC5D2DC
C7D1DEC9D2DEC7D1DBC7D2DAC4D0D7C5CFD5C7CED5AEB7C4374458515D6D87929A839096
8E9AA38792997B858C838D9068747562737061746F5F707344556904123F040D48010840
00083C000C35020E300917360314331121384C5B6338333000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005EC631A28D8A1113292C2B3D
5D515A5E505A2B283F0E173D0109370C1239554F646E58647B5E6A836270876371876275
7A607C221842393259827191463D68090B3F5344678C64739463699A6A6B9E6D6FA06F6F
A1716FA67874A9807AA58077A58177AD8A7CB19181B49485B6998C8A756A85776D807066
8B7C6F8C8073AF9F95B5A196B7A498B6A497BAAA9ABDAE9EBCB0A3B9B0A5BCB3ABC1B9B1
C3BAB3C7BFB8C8C1BCC6BFBDCAC6C3CBC8C5CBC6C3CBC5C4CBC6C6CCC8C7CCC7C4CDC8C5
CCC9C6CCCCC8CCCBCBCDCCCECBCCCDC8CACAC8C8CACBC9CBC8C7C7C6C5C4C6C4C4C7C4C7
C7C4C6C1C0C0C0C0C0BDBFBCC1C0BEBEBFBDBDBFBFBABBBCBABBBABBBCBABABAB7B5B6B3
B5B5B7B0B4B6B0B1B5B1B1B4AFAFB1AAABADA9AAADA8A7ABA7A7AAA6A8A9A3A3A5A2A4A7
D1D5D7A6ABAEA7AEB4B4BDC698A2B07E8DA5304A6B768FAAA4B9CBC3D4E0C8D4DFC7D5E0
C5D1DFC8D4E2C3CFDDC4D2DDC2D0D9C2CFD8C6CFDA919CAB95A4B5708291AFBFC9B0BDC6
97A2ABA8B4BB738087768185677575657571637571607176253551000D42000944010B3F
02123A12263F344757475A6524354708182E4A5B663B3C3A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BD25AB8E831F1B2B2C2835
6F65695F515B1E193401063102093C050B35554D66735D6A7A5F6B7F5F6E826070856679
58486917103971607D876F89352C570B0D415B486C8E637198656A9A67699D6B6C9B6A69
A47471A67A75A47B75A58179A7837AAC8A7CAF907FB29382B095839682748D7C70AA9688
B5A293918276A5968BB5A296B7A498B8A69AB6A799BCB0A1BAB0A5BAB0A7BDB4AAC0B7AF
C3BAB3C3BBB5C5BEB9C8C1BEC8C3C2CBC7C6CBC6C4CDC8C7CCC8C8CBC8C6CECCC8CCC9C6
CCC9CACDCBCCCBC9CACCCACCCACACCCBCBCDCBCBCDC9C8CBC7C6C7C6C5C4C6C3C3C5C2C3
C4C1C0C2C1C0BEC0BDBDBFBCC0C1C1BDBFBFBFC1C4BABCBDBBBCBDB8BAB9BABAB9B4B5B6
B3B4B6AEB2B3B1B3B6B4B4B7B0B0B2B1B2B4AAABAEABACAFA7A8ABB4B8BAA7AAAC9DA1A2
A6AAAE9AA0A392989D848E97ACB4BE949EABB0C3D7BCD5EBBAD1E2C4D7E0C2D2DAC4D3DE
C4D3DFC6D3E0C7D5E1C6D4E0C3D1DCC1CFD9C3D0DB9EAEBAB5C7D3A9BCC68A9BA7A4B2BE
7A879178858C707C816E787B68737467767262737160727A122246010C44010E4303163F
20364D4961664F62614F5F5F44525B06162A475A663339380DC80700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD10B28D76463E48443F4B
62585B584C55120D2801053103093E030735564C69745E6D785B6A7D5D6D8262727B647A
2E254A372F5489728A7A64811712440E0C436E57778D616D98646A9A656A9C696C9A6968
A27571A27772A27872A37B75A9837BAB887CAE8D7EAD907FAE96848C7968A89788B29E90
B5A0939C8A7FA29084BAA798B9A699BBAA9DBCAD9EB9AD9FB9B1A6B9B3A8BBB4A9C4BBB4
C4BAB7C5BCB8C5BFB9C6C2BDCAC5C2CCC8C4CDC8C4CCC8C5CBC8C6C9C6C6C8C6C3C9C7C5
C9C7C7CECCCDC9C9CACBCACCC8C6CACAC9CDC8C6C8C8C6C9C9C9CBC7C6C8C5C3C6C1C0C2
C0BFBFBFC1BFBDBFBDBABFBBC6C8C7C9CCCDBEC1C4B7BBBBBCBDBEB8B9BAB7B6BAB3B4B7
AFB0B3B0B3B5ADB0B1ADAFB1ADB0B2A9B0B0ABAEB1A7AAADA8A9ADA1A5A99FA3A69A9E9F
979C9DA6AFAE9DA7A9A8B3B8D0DCE3B6C5D096ABBD59799983A4C0BFD6E2C3D4DFC3D5DF
C2D1DCC3D4DFC5D3DFC4D2DFC3CFDCC0D0DBB7C8D88298AF6F889A6E85925C6F7E7B8994
717E8777868A7683866D787B6873736474705E716F5D6F7A09193D010C42011040223651
4D6368546763566660535F5E4A576008182B425A672635390BC80800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B68A685E525666626E
685F654E46510A082402053102083D050A3B494161705A6B7C5E6C8261718264776C5A74
1510355F517290769056476D0B0C441B1649795D7790626E97636A9966699C6B6D9D6D6D
A07170A27672A77A76A37974A78077AC877BB18F82AE9283AD95868A786AA49388AE9C91
B29F95928074AA9788BAA597B8A699BAA99CBBAC9EB9ACA0B8AFA5BEB6ACC2BBB1C2B9B4
C3B8B6C0B6B4C4BDB8C6C0B9CAC5BFCCC8C2CECAC5CCC8C4CBC7C7C9C5C7CBC7C7CBC7C6
CAC6C6C8C6C8C8C8CAC9C9CBC7C6CACCC8CDCDC8CDC8C3C9C9C6CBC5C4C7C3C4C5BDC0BF
BBBEBEBFC1C2BABDBCBABEBDB8BCBDB8BCC0BDBFC3B9BDBEB9BABBB6B7BAB5B4B9B2B4B8
AFB2B5ADAFB3ACAFB1AFB5B6AEB6B7ACB6B6A9B0B2A6ABAEA0A4A8A3A7AAA1A5A89CA1A1
969C9CCBD5D4C8D1D6959FA99CABBE7E97AA8399AE2745656988A5C2D7E4C5D5E0C5D4DF
C3D0DDC4D2E1C2D0DFC3D1DDC6D2DDC5D3DE96A5B7394F6A415A709FB2BF8D9DA98A98A0
AEBDC375878A8A9A9B69777967737163736B5F72705F6F7B07153C010E410F2247506371
596C6B596A64566561556464465562091A313852660D20310C8D1200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B92C6E5A5C5A5563
635D66453F4E030223020532030B3D070D3B3E3954644F5E7B5E6B81616F826679534664
1C173B7865838E76952B2456070C473B315D89667A91616A915E659968699B6A6D9E6C70
A37174A37272A47571A47973A98177A98477AD8C7FAF9183B09586A38C7F88766C98877E
938178A59285B6A292B9A495BBA89BB6A499BCAAA0BAADA1B6ADA1BAB1A8C4BCB4C3B9B5
C4B8B5C2B7B3C7BDB8C8C0BAC9C3C0CCC8C6CCC8C7CEC9C6CAC7C6CAC7C8CAC7C7C8C5C3
C7C5C4C8C7C9CBC9CDCBC9CEC6C4C8C7C5C9C5C2C6C2C0C5C6C5C9C4C3C5BFC0C0BDC2BE
BBC0BDB8BDBAB8BCBABABEBDB8BBBFBCBDC2BBBBBFB7B9BBB5B6B9B3B3B8B7B7BBB2B6B9
B0B4B7AFB3B6B4B7BAA4AAAD868C8E909798ABB2B3A1A8AAA0A6A9A0A6A8AEB4B7BBC1C4
959C9F9CA6AA9AA4AD9199A5717F93748DA0AFC0CE90A3B1B7CAD9C6D7E0C8D6DFC9D6E2
C1CDDCC3D1DFC0D0DDBFD0DAC7D5DFC7D4DE93A1AEABBECD9BAEBEA5B6C1BAC7D07D8B94
94A2AA77878A6F7E7F69777569787466776F62747063747E09173D02113D374D63586E71
596C6A596B6859676753646B2C3C510B193B0D2144031432088C1700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052B927826B676E6876
68606E3730450203250209310913400A11395F586F6C5A65795F698163707E667A382F4D
322D4E816F896E60830B0D46070B455A486D8D6574915F67915E619867679E6F709C6A6E
9B686BA06D6DA3726FA47871A77F75AC887BAB897CB19083B29485B39889A99283A18C80
A99488B8A294B6A090B8A393B7A495B9A79BBAA99FBAAAA1B7ACA1B9B0A7BEB7AEC0B8B0
C1B8B1C1B7B1C5BCB5C8C0BBC6BFBED1CBCEB8B1B4C0BBB9C9C8C4CACAC6C7C7C4C6C5C2
C5C3C2C3C3C4C5C3C8CBC8CDC8C4C9C7C5C8C5C5C6C4C4C6C5C7C7C2C3C4C1C1C3BCBEBC
BABEBCBCC0BCBABDBBBABCBBB8B9BABABABDB8B7BBB5B6B8B7B8BAB5B7BBB5B8BCACB2B7
AFB3B8B2B4B8B8B7BC9392968F91928E91919FA3A4A5ABAEA2AAACA1AAAC9BA4AC8A99A5
929EA98C949CB1B6BFC8C9D4ACAEBACED4E0D5D9E4A4ABB4CCD5DEC7D4DCC6D4DDC7D4E0
C4D3E0C3D3DDC2D2DEC2D1DCC3D3DDC3D2DF9DB1C197ADBCA8BBC877899884929E75818C
7A878F7D8A90737E7F6E7A7A68777565757063737167757E11204107173A4B626F576C6C
5B6E6D56686A54656D3B4D61061236010C39000D39020F3409122900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057BB24876C6166606C
67616F252138020526121B3B3841621317386960746D5B66725C6679616C79667C201C3D
4C46657B6B8834305B050D4718164A785E7D8C5E6C92606892606399696A9B6A6B9B686B
9A65689E6A6A9D6C68A1736DA87F78AD887EAF8C81B39185B49386B69788B69B8CB19A8A
B59D90B7A092B39D8DB7A292B9A496BAA899B7A59ABCABA3BAACA4BAAFA7BEB4ADC2B8B0
BFB6AEC0B7B0C4BCB5C7BFBBC6C0BECBC6C7C8C3C5C7C5C3C6C7C2C5C5C1C5C5C1C8C6C4
C6C2C2C1C0C1C8C7CBCBC8CCC8C3C7C6C5C7C2C2C3C2C3C5C3C3C5C0C0C4BEBDC2C1C1C4
BBBEBEBCBFBFB8BBBBBABCBBB8B9B7B8B9B8B8B8BAB5B7BAADB2B7A8B3BDA7B4C1A0A7B5
A8A1AFBBA8B4BFA0ADA3858FA58D93A09094ABA2A7ADA9AEA5A7AA9DA6A998A3B02B4361
5F72908D8296B792A6CA9CB0B7869AB7879BC094A8A37E90C9B5C4CED0DBC5D0DAC4D4E0
C2D3E0C0D2DCC6D4E0C2D0DBC2D4E0B0C7D84764815E7B927A8F9D637583899AA49EABB2
7A88909EACB1707E7F6C79796976766675726976766A767E22324C0A1C3B526B77566C6C
566B6F4C616E2F405908163C000836010938010A37010D330F162E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD119B7866524850
67626F16162B0308252E324B47486125233C6B5F7074606B735C6777616D6D5D75130E32
5A5275675D820C1145060F4A392F5C83607A8C5E6B905E66915F6497646A9C676D9C656A
9A63679D6668A2706DA3756FA77F78AF8982B28F86B19085B59487B49587B5998CB59E8F
B49D8FB7A191B7A191B59F90BAA496BBA799BAA89BB9A99FB6A9A0BAAEA6C1B5AEBEB1AD
C0B6B1C1B8B1C6BDB9C5BCB9C6C0BDC6C3C0C9C5C5C6C3C2CBC9C5C8C5C2C6C3C2C5C2C1
C3C0C0C3C2C3C6C6C7C9C9C9C7C5C6C2C0C2C4C3C4C2C1C3C1C0C4BFBFC4BFBFC3BDC1C3
BABDBFBCBFC0B8BABEBABDBEB9BAB9B6B8B9B2B4B9ABB6C393A8BF6A7D9B6A6A89967491
AA6781B0566BAF445995283C9D394AB05B69C07C89C595A0B4979EB4A8ADA8AABA384E75
273A6C765A7C771D3B8915318E132C8F14298D152E8718307E3349D9C3CFCACFDAC3D2DE
C3D4E2C3D3E0C2D2DFC4D1DDC4D3E09BB0C14D67835E7890ADBFCDBACBD48B9CA5B7C5CB
84929A818F94717F826C797B6976776777766775756B777C424F630618354660734B666F
42596D17284B020D3B000839010636010736010936020B321D243A148E1300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6346584A4E
6E69770D0C24090A264D495D453F543A334972637175606B6E586277616F5B4D69110E35
656085302E5D040D4A0C114A655177805A70845C6A865C678D616897656C9B646A9D666A
9B64689C6769A16F6DA47772A77F78AD8781B39087AE8E81B29284B49688B29789B29A8B
B69E8FB6A090B8A293B7A193BBA597BBA799B5A498B6A99EBAAEA4BCB1A8BFB4ACBEB4AE
C0B8B2C0B9B5C7BEBBC5BDBAC5BFBBC4C0BBC8C4C1C5C0C0CBC6C7C7C4C4C5C3C3C4C2C0
C2C0BFC1C0C0C2C2C1C8C8C6C3C3C2C0BFBEC3C2C4C4C2C4C5C3C7BEBEC2BABDBEBABEBD
BCBDBDBFC1C1BCBCBEB7B7BCB6B6BAB1B6BBA9B6C47490B136527E7A7099914D709D2845
A61329AF0E22B70D1FB80D1DB40D1DB11123A41326A5273AAB4657C88290C39CAD807A9C
17225777638B7B1D3897071BA40414A60514A204139F0719860D21C18C98D4CFD9C5D1DC
C5D3E1C4D1E1C4D2DFC4D2DEC6D3E1A1AFBFBACBDCB6CADB8C9EABAFC0CB80929C819098
808C9379868A727E826F7A7E6B797B69797868777567767664717D101F3A253B5C213658
04123F000C4100083E01063A010536010734010B35010D3030394A1E9A1D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AC815C77696A
5A566609092219152E5E51623F3448453E5272626F745E695F4753776171463B5914163E
565B870B124A040E4D211F507C627D7856666749586247537A5A6492676E9A676B9D6569
9D67699C6869A47172A47574A97E7BAC867FAE8C82B29183B69687B49788B39888B59A8B
B79C8CB89F8FB59F90B7A193B5A294B9A799B5A699B5A89EB9ADA4BBAEA7BDB2ABBEB3AD
C3B9B5C1B8B5C2BAB7C4BCB9C7C1BCC7C3BECBC7C4CCC8C8C9C7C7C5C6C4C1C2C1C1C0C0
C3C2C1C2C2C1C2C3C4C2C2C3C5C5C4C2C2C1BFBFC1C0C0C3C3C2C4BDBDBFBEC1C2BCBEBC
BCBDBCBCBEBDBCBCBFB7B6BBB6B6BAAEB7BF839DBA2045797D7EAD974A6AA4172FB70D20
BE0917BC0712BD0610BC070FBB0510BB0511BA0915B40817AE0D1FA013289B2B42A75D7A
54325E553B638C4057930B1CA40210A8020FA5010DA3020E970817903D4AE1CBD6C8D0DC
C8D5E4C6D2E2C6D3E3C4D1E1C1CFE392A5BB869AAB8A9EAC778B9B8496A380929A788790
94A0A77C888D727B806E7A7D6A787968787667797565777565737B2F3E5A000E3D000B3F
01074000094200063D01083B0106350009320110331F33492E3C4429A92900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC83B837574
7272820809232B243A615260332A3C514C606C5E6E725D6A735A677860723F3456151E4D
26356A010D4B050D49473E657B5E73694A586A505B5F4A55553F4988666C97686D9B666B
9D69699C6869A37072A67778AA7E7EAD8681AE8C82B29284B59585B29685B09682B49A87
B49A8AB49C8CB49E8EB6A292B7A596B9A89AB8A79AB7A99FBBAEA7BCB0AABFB4AFC0B4B1
C2B7B5C3B9B6C3BBB6C4BCB9C4BDBAC4BFBCCAC6C4BDB9B9C7C6C6C4C4C3C1C2C1C1C0C1
C1C0C0C1C2C0BFC1C2BEC0C1C5C5C5C4C4C3BFC0C1C1C2C3C0C1C2BFBEC0BEBEC0C1C1C3
B8B9BAB7B8BABCBCC0BABABDB3B6BBA9B8C7375D8B34538AA2779E9C1933B80A1CC00914
C10711BF060EC00710BD060EBB060FBC070FB90913B50C16AE0D19A50A199F0B1D971025
922644863654B55B718F0D1DA10311A6010FA6010DA4010B9D051280101DD1A4AFCECED9
C8D3E1C5D2E1C3D1DFC6D4E49FB2CA24405F5E789199AEBD7F92A2899CA9C0D3DC86969F
95A1A978858A6F7C807180826A797A67767567787666777663737C1D2C4A010A3F010742
01064100073F01083E01093A000B3502123222384C4C636C28393B47463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064D1448A797A
4C4C610407233A344661566129263A4B4F6A403F5B64596E745F6F766075392E550F174E
091653020D4B16194E6F60806F54667559657659616F5660533F4B74595F8E666999686B
9C696B9D696AA06E6FA8797AA97E7EAB8580A9887EAE8D80B29283B09482B09682B29884
B79D8DB39B8EB7A091B7A294B8A697B8A698B7A598BAA9A0BEB0A9BCB0ABBEB3B0BEB3B1
C3B8B6C4BAB7C1B9B2C3BBB6C4BDBAC6C1BEC4C1BEBCBBBAC3C2C3C5C3C4C2C1C2C3C2C4
C1BFC0C1C0C0BFC1C1C0C3C4C3C4C4C1C1C1BFC0C0C1C2C3BFC0C1C0C0C2BDBEC0BEBEC0
BCBCBEBDBEC0BBBCC0BABEBFAEB5BB9DB2C81640776273A5964B6BAE1229BF0917BF060F
C20811C10612BF0511BC0510BC0610B70D13A7161BA42F379A37438E303E88202F8C1424
971125941227A92A3D9E12219F020FA4010DA5010BA3010BA0020F910A189F5563DBCDD7
CCD3DFC6D4E0C6D3E0C8D6E698ABC06D87A087A0B4A3B7C4C3D5E18598A391A3AE81929B
828E96768188707E83697C7D6A7A7A6D7B7B69777766767763737C293956010B3E000741
010743000A42010D40000F380618352D44524D646A52666A2A3B3D51514A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0061CB3BA28D8D
4D4D65060A254740505B505D1D1F3B17224E030B3C3433566A5C7069586F2E2650040843
010949030A453C37617E6982685061775C697758646D546050404B6751578B6467916064
9865699D6A6DA27072A7797AA77F7DA8827EAA867FAF8E84B19386AF9584B19683B09583
B49A89B39B8BB5A090B6A093B9A599B8A699B6A499BAA9A0BFAFA9BFB2B0BEB4B3BEB5B3
C4BAB8C2B9B6BFB7B3C0B8B5C2BCB9C6C0BEC6C2C0C5C4C2BFBFBEC0BFC0BEBDBFC1C0C1
C1BFBEC2C0C0BEBFBFBCBFBEC2C5C4C1C4C4BCBEC1BFC1C4BFC2C3C0C3C4BBBEC1BBBEC0
B7BABDB5B9BCB7BCBFB7BBBCB2B9C092A8C1133B77737CAF984461B21126C00716C00612
C00712BF0511BF0713BA020EB50510A6181BC47070A87E857963706A596B68506881556E
893D54851C308F0F219C0917A0020FA5020DA504109E010DA0020D990612811B2AD9B6C2
CDCEDAC5D3E0C4D2DFC6D4E392A5B6A4BBC9ACC1CF7B8F9C8597A283939C85959D87949B
7E8B917681866D7C7E6779796C7D7E6C7C7D6A797C6675786270783A4A62010A3B010941
000942010D4103143F192E463F55604C62644F636353676831424451554E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC22E886F6A
3A384F0F122B534958574B5B0C1032020B400209451B1E4B62597066566D25214C020944
0009471012456B5D7E776074624C5E7059686E57635F4E5A4A3C486850578A6164925E63
9D686CA26F70A17071A37676A37A77AB847EAA847DAF8D84AF9185B19788B29787B69A89
B49A87B6A08EB49F90B6A294B6A297B6A59ABAABA0B9A9A0BFAFA9C1B3B0BAB0AFBDB5B3
BCB5B3BDB8B5BEBAB6C1B9B7C4BDBBC3BDBCC7C2C1C5C1BFBEBDBCC0BFBEBFBFBEBEBFBE
BEBFBEC0C0C1BCBEBFBCC0C0BEC4C2BFC3C4BCC0C3BFC3C7BEC3C3BBC1C0BFC4C6B7BEC0
B2B9BCB4BCBFB8BDC0B8BCBFAFB6BD98ACC4163E7A616FA5954968B11327C10918BF0512
BD040FBC040DB9010CBB030FB20812AA3336C39594A59DA299A0A696A0AA7E879B515873
4B4665735572813C54831525970A169B030E9600099501099C010C9A020D880A1CB37685
D8CFDBC7D3DFC5D3E0BAC9DD647D97738FA3657F8D6D8592879AA493A3AA829097A7B2B8
808D93798589707E7F6372736B777B6B7A7D6575766574766573794B5B6F010C3C000B41
020E3E0C1D41394D64566B725163655165645267644E6563364C4D47504C1E981200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE115B09284
3F3B4F1B192F5C4E5D473C5103062D020942020947101343665D77675B731B1A48030A47
030D47312F5977637C7E66765848585B505E5A4F5A50475346374473535C8C5E64915D62
996568A06E6EA27372A57778A67B7AA7807CAC867FAF8D83B19387B19488B29688B39887
B49A88B69F8EB39F90B39F91B29F92B4A398B8A99DC0B1A7C0B1A9BBAEA9BCB1B0C1B6B5
BDB5B2BEB8B5BCB8B4BFBAB6C3BCBABFBABAC6C1C0C5C1C0C1BFBDBFBDBBC1C1BEC0C2BF
BCBFC0BEC1C4BEC0C4BABEC1B7BDBCBBC0C1BCBFC4BCC0C4BCC1C1BDC1C1BFC2C3B9BCBE
B9BFC1B3B8BCB4B8BCB6BBBFB1B8C0A4B7CB214880415A969D6588A7162BBD0816C10513
BF040FBE050DBB020DB9020DB20713A73338C3999AA6A1A19BA2A3BAC4C5AEB6BD959EAD
75859C3C4B694542637B547281273E8C091895020E98020B9C020B99010B930617822939
DEC4D0CED4DDC6D5E29DAFC918375B58799297B2BFA3BBC5899CA5B8C8D08F9BA5838D95
7B868C728083758183717E7F6C797A6877786778776678756776795A697905143904153B
2638514C616D5A6F725F7373596B69546765516868425C6038505835434525A21E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B89683
352E402C273C5E505F342C44010630020A43030A470B0F3D655E794D45630A0C3C020B45
0B11445E55767F65797E6473554B594B4857484453433B49543E4A774E578B565E965F65
9B656AA16E70A47274A57778A77A7CAA8080AA837FAE8B82B19085B19286B29686B19685
B49A8AB39B8CB49E8EB19D8EB7A397B4A398BEAFA4C2B4ABC1B3ABB9ADA8BBB0AEC1B6B4
C2B8B4BEB6B1BFB8B4BDB6B4BCB8B6C1BFBEC3C0BFC3C2C0C0BEBCC3C1BFBCBCBBBEBFBF
BABCBCB8B9BDBBBDC1B9BEC0BBC1C1BCC1C3BDC1C5BCC0C3BEC3C3BDC0C2BFC1C2BABBBE
BDBFC2B9BDC0B2B4B8B4B8BCB2BABFAEBCCC4669971C41829A82AD941D35B60A19C10614
C20410C0050EBF0510B9030FB50815A3272EC69495A7A09DA0A5A4A9B3B2A3ACAE939BA1
8D9AA596A7B9798BAB25315C785C827B1D34980818A004109E030D9C010A990312800C1C
C28F9ED3CFD8CCD5E49CACC17B95AF95AFC38EA2AEAEBFC983919C7D8893838C977C858C
7B868B737E82747F816F7E7E6C7B7B697979677A78677876677777617277273B4A3E5261
566972586C6D5C6F6E6174725C6E6E52686C425B69152C4223394E27394244413800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C49F84
382F3D3D374A5D515F231E38030732020A400109420D123D63607E282547010639020A41
25254E76647D816172826170634F5C4A3D4E4F42515A455276515C8350598F565E996167
9F696FA16E72A27074A5787AA4797AA87F80A98380AE8A80B49486AF9182B09583AE9585
B3998AB4998AB49C8DB39E90B8A59AC2B0A7C5B5ADBEAFA7C2B4ADBAAEA9BDB2AFC1B7B5
BFB5B3BEB6B0BEB5B0BFB8B6BCB8B7C1BFBEC4C1C0BFBFBDBEBEBCC0BFBDBCBBBABAB9B9
BDBEBEBABBBDB7BBBCB9BEBDB8BDBDBCC1C3BEC2C6BABEC2B9BEBFBBBFC0BDC1C3B5B8BB
B8BABFB9BBBFB6B6BAB5B9BCB3BABDAFBAC2809ABC16407F7078AC93425CAE1121BF0815
C20612BF040DBD030FB90311B204119D121CC27E82AB9F9D9DA3A2939D9E9DA8AAA3AAB1
8D97A0B8C6D1C8D8EE415985283064804D6D880B219703119601099D030C9E0211900819
914152DFCAD6CDD1DF8C9AAB97A9B98B9EAD788A99808C9787919C7A848E9FA8B2838D93
7782877983876F7B7C717F7F7281826A7A7B6679776879786978776175715C716E546768
596B6E5C6F705D70705C7174586F7A364E63091D40000F38192C492037424D4E4800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BF9570
3F31374840515B4F5E15122C020831010A3E010941151B4955577A0C0D3802073C060B3D
574F6F7D6274845F6E8C64728862716B49596B4957774F5B875661864E5890575F996167
9C666CA06C72A37175A27576A57C7DA67E7EAA8480B08C80B08F7FB19381AF9282B19688
B19789B3988AB49B8DB9A499BCA9A1C2B0A9B9AAA1C0B1AAC1B3ADBBB0ACBDB5B0BDB4B0
B8AFABBEB5B0C1B9B3BEBAB5BBB9B6C0BFBCBAB8B5BFBEBDBDBCBCBCBCBDBABAB9BBBABA
BCBCBDB3B6B7B5B9B9BABDBDB8BCBEBBC1C3B9BDC0BABDC1BABFC0BBC0C0B7BBBEB1B6BA
B4B7BCB6B9BBBABABDB4B8BAB5B9BBB3B9BEA7B8CC32558A2E4B86A57E9E99182BB90A17
C10610BD030CBC010DB6010DB3020DA70A16B05057B49999A2A5A48F989AB7C0C6D3DAE2
A3A9B4A6B1C0B8CADD6A81A611255B715E877818318D05148D000696020A9F0211980516
7D1223D4AAB7C6C9D9687C947B90A3677B8B7B8D9C8C99A3B9C3CD84909A919DA588969B
758085768183707D7D7684846E7D7F6A7C7E6779796679776878775F736C60746F5C6F6C
5B6C6C5E7274576F764C647721385A041644000C3F010C3C0C193C2035444E504E10CA08
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0069D547
5B48484F4354594D5E0C0A2702083005103D010A3B202855383F6901063A02073E1A1B45
6D5E767E5F6E8059678B5E6E885A6B8554667543537C4655844D5A8A525C9159609A6368
9D676D9F6B6F9F6C6EA27372A57979A67E7CA8847DAD8A7FAF8D80AF8E80B29387B3968B
B09589B0968AB29A8EB7A298B9A69DBFADA5C0B0A8C0B1ABBEB2ADBAB1ACBBB3ADBDB4B0
BFB4B1BDB4B0BBB5B2BAB6B4B9B9B5BABAB5BBB9B6BAB8B8BBBABCB8B8BBB5B5B9B5B5B7
BBBBBDBABBBCB4B7B7B9BABCB5BABBB9BEC1BABCC0BBBEC2BCC0C4BBBEC2B7BCBEB1B8B9
B5BABBB6BBBCB3B6B8B2B6B8B2B6B7B0B5B8AFBAC57791B51136727F7EAE913750B2131F
BD0811BD040BBD030FBA030FB6010EB107129D2029C28E90D2CCCC9EA5A9A1A9B1B3BBC3
9CA2AE8592A4617A92ADC7E0324A783C41727C3E5E870B1C92020C94010A99020C96010D
890A19A7616FB9B0C23F58757D98B0A6BBCBB3C3CF7F8D9597A4AD808F977482897A898C
778488707E7F6E7D7D6C7C7C7382846C7A7C6A797A6576756977766374726274715E7070
586D70576D7A354C68091D4900124A010C4A010B46000A3C04103622364C424A4E209914
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064CC3A
735A5557495850465906042204082D3137591A234825325D161F5002084002073B322E52
74607280606E845E6C845A69875A6B8351617843537D4654824B588A535E935B63996268
9A65699C6869A47171A57574A47676A47C7AA6827CA9887EAE8D81AD8D80B09285AE9185
AD9185AE9589B19A8CB39E92B8A69BBCA9A1C1AFA8C2B2ADBEB0AEB7ADAAB8AEABBCB1AF
BDB1B0BAB1AFBAB4B2B9B4B5B7B4B4B9B5B3BDB8B7BCBABABAB9BCB8B8BAB8B8BAB8B7B8
B9B8B9B8B8B8B8B9BABBBFC0B8BDBEB8BDBFB8BBBFB9BCC1BABCC2BCBDC2B8BCBFB2B7B9
B6BBBBB6BBBBB1B4B8AFB4B7B6BCBFB2B9BBAFB8BBA1B4C72A4D83324B88A475989C1829
B70A13BD060CBE0510BB020FB7010EB40310A10D15B46568B4A2A1A1A6A996A1A88D99A1
BBC5CC96A4B25C758BBDD7EA7B95B911265A745B8376112695061594000A97020C97030D
950713831A28AA8191929EB199AFC180939F8B99A17F8D927E8B937B8990758389718082
7A86896F7E7E7181816C7B7D727D7F737F7F6C78786975736C78786676766073745D7379
465D721C3156021144000C48010B4B00094D010A49010A3F010C37263C56313E4625A21F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064C933
8264575C4C5742394C02021F0C0D2C58566D262948222E5B020B40020741010336373152
725D6D7A5A6884606F835D6B815865875A677A4955804C58834F5B8E5965915A64925C61
9965689B6968A1706FA67575A57577A67A7AA47E78A7857CAD8C81AF8F81AF9082AC9081
AF9486B19A8BB39D8EB8A596B9A89ABDACA3BCABA4BBAAA5B9ACAAB7ACA9B8ADABBEB3B1
BAB0ADBCB3AFBBB5B1BCB6B5B6B1B0B9B2B1BAB4B3BBB8B8B7B6B7BCBCBDB8B9B9B9B9B9
B5B6B6B3B6B5B8BBBBB7BBBBB7BBBCB8BCBEB9BDBFBDC0C2BFC1C4BBBCC1BCBEC3B7BABE
B9BBBEBBBDBFB4B7BCB4B9BDB1B8BBB0B9BAB3BABCAEBAC36681A7133677837DAE8A2D45
AE0E1BB9050DBA020EB9010CB9020EB7020EAD0810A13136BE9698AEACAFA2ACB18E9BA3
D1DDE4C9D7E08DA1B1A0BCD287A7C91B396D454678752F4C8C071B93010D95000A97010B
98030E8706108D434D9388927F8F9D7E929E8B9CA59FAFB67D8A93A2B0B788969D738284
7A8788718080717F806E7B7C6E7B7B74827F6976756A777766777763797D5A6F7D344B67
0A1D4C000E49000A4B00084A01094A020B4E020D4C010D4107183C374D61233139453E34
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0065CA30
9B786562505637304103041D242036625769252441111B4B010A43010842010638393454
745E707C5C6C805E6D886170845B698256617F505A7E4B55824C588A535F8C575F905D61
9664679B696C9F6D6FA47173A57376A47777A67E79A7837AAC8A7FAF8F81AF8F82AF9184
B29888B09988B29C8DB4A192BDAC9DB8A69BBEADA5BDAFA9B7ADA8B7AFABB5ADA9B7AFAC
B3ABA7BBB2AEBBB2AFB8B2AFB7B3B1B8B4B2BAB5B4BAB7B7B7B6B7BAB9B9B9BABABCBDBD
B3B5B6B7BBBAB6BABAB6B8B9BDBFC1B8BBBCBFC2C1BCBEBEC4C5C9BEBFC4BBBFC3B9BBBF
B7B8BDB6B8BCB6B9BEB5BABDB3B8BAB4BBBBB1B6B8AEB6BB9BACC521447C3D528D9A6786
9C1426B60815B9040FBB0410B9020DB7020CB406109D121BB87479D5C8CCCED3D997A0A9
A8B6C0A6B5C08496A927486D5882AD5C7FAD12245C78567B790C249505139B030D970109
97000A92030C8018209B777F5E6C7996B0BC899EA8BACBD386959D7A888F7C8A92738185
717F807382826F7C7D6C79796B7A7B6778776B7C7D64797B59727A4C677C1F345B021247
010C4C010B4E01094E010A4D010C4D000D4C0110490D1F473C51645367701C29304A443D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B28C706856592B26350505193933446053621B1836040C3F010A420D184B1018442F2B4D
715F737B5E6D7E5C6B865C6C8759698657647F4E587F4C5587535D8C55618F5B63966467
96656899686B9D6B6FA26F72A47275A37677A77F7AA58077AC897FAF8D81AF8E83B09185
B29889AF9789B29B8EB6A092C1AD9FB9A69DB9A9A2B5A9A2B4ABA6B6ADAAB6ACAAB8AEAC
B6ADAABBB2AEBBB3AFB8B2AFB6B2B0B8B4B4B8B4B5B6B4B6B9B9BAB5B5B6B9B9BAB6B6B9
B6B6B8B7BABABBBDBFBABCBEB8B9BCB6B8BABDBFBFBDC0C1C1C2C6BABCBFBABEC1BABCC0
B7B9BCB8BABDBABCC1B4B9BCB3B8BAB3BABAB5BBBDB1B9BCAEBBC85C7BA21335738C80AB
8C263DAE0C1CB60410B6030EB7020DB7030CB4030CA709129F3C42BF9FA4A9A7AE9AA0AC
7585989AAFC1BACCDF3F5C7E557CA1A2C1E3173063524B7B71233E90081A9D02109C020B
99010B97030D870711925059A3A0AAB1C4CD8091998393997D8B917E8A907D898F7A888B
707F81738382707E7E6B79796C7C7C67797A6B7E845B74813954710D235400104E010B4E
020B5000094C01094D000C4E01104E03184A21375C50657658687056686C222F35474543
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B18565735D602A223308051B4E45535C505D13113202093D020A412C325F1E2048211F40
7164777F6372825F6E83596886596785586283555D804F578957618C58638C5860946266
96656599696B9C6A709D696FA37174A47777A87D7BA9837CAD8A81AC8B81AC8C81B19485
B29788B0988BB1998DB39C8FBBA498B8A59BBEAFA5B3A9A2BAB2AEB7AEACB3A9A7B5A9A8
B8AEACB8AFACB7B1AEBAB5B2B3AFADB8B4B4BAB6B8B8B6B8B7B7B9B7B7B9B9B9BBB8B8BB
BABABDBABBBDB9BABDB9BBBEBBBDC1B8BBBDBCBDBFBCBEC0BDBFC1C0C0C4BFC1C4BFC1C5
BCBEC0BEC1C2BCBFC2B2B9BBAFB5B8B5BCBDB2B6B9B0B8BAAEB9C095ABC5173B774B5A94
9C5E7C9D1122B30512B7040FB8030DB7030DB3020BAF051097131DBA7E85B7ADB4C9CED6
7F8EA1849BB0CDE0EE97AFC188A5BBC1DAF15268931F2A6274486E7D0A209803129E020E
9A000D97010D92051282242F9B7E868E969C909EA67D8C92A9B6B9838E938793988E9DA1
7181846F8080728283697A7B697B7D63777E566E81263E6303164F011054010C54000A50
00094D010A49020B4A000F49091E4C3B536F5D73815F7277617274596C6F2D3E453E4042
1D961000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D6B436F555422192B120E22594E5A564A5909072B02093C070E3F55547B2B284D151739
6E647979606E7D5C6B855E6C8A606D855A658557607C4B538351598C5861905C62956166
9765679D6C6F9E6C729D6970A06E72A57778A37A77A57F7BAA8781AA897FAB8D7EAD9282
AF9585B19889B29A8BB59E90BAA59AB4A398C0B0A6B1A49DB9ADABB3A8A6AFA5A4B6ADAB
B2ACA8B7B2AEB5AEADB7B3B1B6B4B1BAB7B4B6B2B2B6B4B4B8B7B9B9B9BAB9BABBB8B9BA
B8B8B9BDBDC0B8B9BDBCBEC1BBBFC1B8BCBDB9BBBDBDC0C2C0C1C4C0C0C4BEC0C4BEC1C5
BBBFC2B9BDBFB9BEC1ADB6B8B0B7BAB6BBBFB3B7BBAEB4B7ADB7BDABB9C84C69991A3879
9983AC8A1E33B10B1AB6030FB7020AB6020CB4020DB10410A10914A0464EC3AAB3D8D8E0
B3BCC98EA2B591ACC087A4B64B687CB8D0E39CAFCF1529605143746916308F06179A0212
99020F96010D970410800D19956168A3A2A7B0BEC585969DA2AFB48994977B878C768387
7281846D7F826E81846C7F84647A8548617A122957021454000C55010953020B53010A50
01094D020C4A020F470A2049476177677D86657A7C5F73755C7171566B6D3C4F562F3639
229D1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB21F7E625A2119261F192A60525E4A3F5006062A0107371F224B6A6582312E510E1135
6C647C78606F7A5B69835E6C885F6E85596785546085525C88555C8D59618F5A62925D65
98646A9A686C9D696F9E696FA37074A57579A57B7AA47D7AAC8680AE8B80AC8E7FAB9181
AC9385B19787B09786B49D8FB6A097B6A29AB9A89FB8A9A3BBACAAB3A6A4B3A9A7B4ADAA
B0ACA7B3AFADB1AEADB3B4B2B0B1AEB6B7B3B6B6B3BEBEBDC7C8C9C4C6C8BDBFC2BABCBE
B5B6B7B7B8BBB6B8BCB7BBBEBABFC1BBC1C2BCC3C4BCC2C4BDC2C5BFC1C5BFC1C5B8BCC0
BBBFC1BABFC1B7BCBFB6BABEB4B8BDB2B6BAB7BABFB1B5B8AFB5BAB0BAC389A0C0143978
5B669D8C48669F0C1FB20210B7020DB7030DB4020EB1020FAA0612941B25B7848CAAA4AE
9DA7B3687F982A51778BB3D08EABBEC5D8E6C8D7EC3F537F262E63744262800A20910213
93000C94010C96010C8A071286353D9F8F91ADB6BC8593997E8B907E898B7C8688758083
7281846D7D806A7D846379883C5675081F53001258010C5701095401095000094F01094C
01094C010B48031242415B72647C846B8081687C7B6076755E7374596D6F4E60651F292C
27A32000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB61D7458471E17202E283363555F39304604072D040A34413F5F6E647B3A355506072F
665E7A7760717C5D6B815C6A88606E8559668451608856628857618C5863915C66945F69
925E669561669A646AA16D72A16F73A57578A67A7CA57D7CAE8680AF8A80AE8E80AE9282
AC9282AF9584B19988B39B8EB59E96B6A29AB6A59CB9ABA7B1A4A3B7AAA8B2A6A3AEA5A2
AEA9A5ADA9A7A8A7A7979998939695ADB0AED1D4D4DBDEE0DBDFE3DBE0E3D6DBDFC0C4C9
B7BABDB3B7B9B2B7B9B7BDBEBABEC0B7BBBEB7BEBFBBC2C2BABFC1B8BDC0BCBFC3BDC1C3
C1C5C6BBBFC0BBBCC0B8B9BDB2B5BAB5B8BDB6B9BDB2B6B9AEB2B6B2B8BEA5B4C936558B
203D7F957AA28B172CAD0716B7020EB6020DB2000CB3020EB1030F9D0A18A553628D808E
CDD9E593A9BF1D446B6E99B6C6DEEDCBDBE4CAD9E7889BBB0F215667567F6E142D8B0517
92010D95020A96010B9304107D121CA1777986878A8793967A888A8D9B9B8A97996B797B
7182826A8081607A87355173061D5700135A010F5C010C57000C51020E4D010E4903124C
010B48000D431F335559727D657A7D6A7E7E677B7B5F74775D73775B6F73596C70152227
463E3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
58BD217C5D4620151C3A2F3A675763261F3904082E0A0E325B556F726478433D5D060834
50496B755F727B5C6A7C5B66825C698257648758658656628C5B668C58638F5B64905C65
9563699766699662679F6B70A06E72A47578A57A7DA88081AA8280B18B84B29085AF9181
AF9381AE9381B09886B0998BB5A197B6A49BB6A69FB6AAA5AA9E9BB0A5A1B0A5A1B0A5A2
ACA5A2A29D9B949392A7A7A6AAABA9C6CACACFD3D7BEC0C7BEC2C8CFD4DADAE0E7D2D6DD
B6BAC0B7BBBEB6BBBCBABEC0B8BBBDBBBEC0B5B8BABEC3C4BEC4C4BABFC1BDC1C5BEC2C6
BCC2C4BABEC0C0C0C5BCBDC2B9BCC2B7BBBFB6BABDB1B6B9AEB3B7AEB3B8AAB4C1788EB4
103373696FA18A3C56A50D1EB70612B6020EB4010DB5020EB5030FA90613922234876473
C4CCD8C8DBE97D9AB4769CB4C0DAE7C9DBE3CAD7E5BFD0E72C417033396C70355782091F
8F010E94010A94000894030C860813934951908184BEC6C98F9DA08796968A989D607376
6A7F81637F89304D70041D5900125C01115E010F5D010E5601124C061B492E456A1F3563
020E47010F40425D725D767A65797B6A7E7F657A7E59727C4B6777445E6C5069721F3138
3C3C3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0087604425141941333F66596717143203072F1E1F406C62767464774D4467070B3C
3C39607461767D5F6D825F6C8057668358668A5D69895A648C5A64905E688D5B65905D65
93616797676B97666A9C696E9F6D72A27377A6787EA67D7FAB8482B18C85B29185AF9183
AE9081B09281B29888B39F90B5A296B6A59CB1A29AB3A69FB3A6A2BAB0ADACA39EADA5A1
ABA6A2908C8AADABA8B0B0ABAFB2AED3D7D89FA2A8B3B4BCB7B9BFB6BEC2D8DFE3DADEE4
B9BDC4B9BDC1BCC1C4BABEC2B6BABEB5B8BCBABDC1C3C7CABDC1C4C0C5C8BEC4C7B9C0C4
B9BFC3BCC1C5BDBFC3BCBDC1BABDC1B4B8BCB7BBBFB3B8BBAEB3B7ADB1B6ADB3BDA2B2C8
2D4E822A447E997394931528B10616B5020EB6020DB6030EB6010DAF0310960B1AA86472
9C96A89BB0C37E9AB130566FB9D5E4C9DAE3CBD7E3C9D7E96F82A90F1E576D517C6F0E27
8B031393010D94000993000A900411841C279F777E98989C8993997B898C7482865B6D72
657C8938547403195702156200105F01135F02145B021651172E5746607A506983081D49
02134A051743526D7E60787B6A7E7F677C7F627886334B6A08204B041D4338546B2C4550
2D31330EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AA7F5E2C171A4D404A5850600A0B2B04082E3D3953695B6C6E5E7253496F06093E
2726536E5D757C5E6D805C6C8159668458658759648957628B58628E59658A5562915D65
9462699A676E9B676D9E696E9C666BA47275A97A7EA3797AA9847EAD8C83B19085AE8E81
B19285B19286B2978BB49F91B6A497B5A29AB5A59DB4A79EB4A9A4AFA6A2AAA29EABA4A0
AEA7A58D8987B0AFACADAEABB5B8B6CED2D39B9DA3B2B3B8B2B6BAB3BCBED5DFE1D6DBE0
B0B3BAB8BCC2B5BABEB7BBC0B8BBC0B9BEC1B9BEC1B9BFC2BAC0C3BAC0C3B8BEC1BABFC3
BEC3C6BCC1C4BEC1C5B9BBBFB7BBBEB2B6BAB6BABEB4B9BCB3B7BCB0B4B9AEB3B9A4B1BD
6882A710346F77749F872D44A80B1DB60411B8040EB6040CB4010CB1020DA50715932D3E
745E7A647E9DA3C2DB638398C8DEEBC9D9E1CBD8E2C9D7E3B4C5E01D3162413E70682341
85061994020E96000C94010C9402108408169B58628F8387838B8E808B8F76858A62767F
475F7D061D5801136001136400115E011559061E53314C6D556F82577182294061001344
1A35660A1D46557081627A7D667D82617A8833496D05174F01115001124A13294F3B5467
1C262A1E981300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE815A2C18154E424A453F5106092A0C0D2F584D62695B694D43595B5779080C3E
101344695D7A7D61727F5C697D5964875E6A895A678956628B57628C58628D58638E5960
9461679A676D9C686F9B686C9E6B6EA57476A6787BA97F7EA9857EAD8C82B19084B08E81
B19184B09388B1988CB39E90B39F93B09D95B1A299B0A49BB0A7A0ACA3A0ACA4A0B1AAA5
B2AAA78A86859A999BB1B1B3ACADB0C2C6C9B9BCC0ACAEB3ACB2B6C6D0D3D9E1E5C7CCD2
B8BAC1BABBC2B8BBC1B9BBC0BCBDC1BABEC2B5B9BCB7BEC1B7BFC1BEC5C8BBBFC2BEC1C6
BEC2C6BDC1C5BABDC1BEC0C4B8BBBFB2B7BAB3B9BCB2B9BBB4B8BDAFB3B7B0B4B9A7B1B6
9AABC2224479334780956384961126B00413B6030FB6030EB4020CB1020BA903118F0C1F
8C56713F4C6BAFCBE1C3D9E4C9DCE6CAD8E2C9D7E2C6D7E3C6D6E85C7095152255704A6E
760A1E90021193000C93000B93010E8B04128329349B8082999D9F939FA26D7D875D748B
0E285B03176302136603166401145719305F4C67805F788361778149637A061D490C2251
3A55800316404B66805D7786557085254169021753010F54000C50000F4A0214423A536C
121E272A631D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00BA8E5C311C11574B51352F430407281C1A356456655C526222223B5D61810A0F3C
050A3C544D6F7A61737C5966825D68855A698A5A6A8756638C5B6585555E8C59618D585E
9360659B68709D6A719F6C71A06F729F6E72A5777AA87D7FA88380AC8B83AF8F84B19084
B19186B3968BB0968AB29B8EB39E93AE9B93AB9C93ADA199ACA39DA9A19DA9A09DB6AFAB
ACA4A2A49E9E8A878A8E8D918D8E91B1B4B6D4D7DBD1D4D9D2D7DCD3DAE1BFC6CDB4B7BF
B7B6BDBBBBC1B9BAC1BCBDC3BCBDC1B9BBC0BBBEC3BFC4C8BCC2C5BEC2C6BCBFC3BABDC2
BBBFC4BCC0C5BFC1C6BCBDC2B7B9BDB4BCBEB2BBBCAFB7B8B1B8BBADB4B7AFB3B8A9AFB3
A8B5C05B769B12316F8376A386233CA90A1AB20211B5030FB4020DB0010CAC0210A00919
98394C99879D92A6BBC9DFE9C9DBE4CCDAE4C7D7E3C4D6E1C6D5E3A4B5D1132656534973
6D1D3685041390010C91000A93000C91020F7C0C17A06E72898484818E916D7F90263F69
021A60011466021463041B5B29416A587085657A8164797D5C74831C33590116482F476C
455D7F001244183061374F7C162D6201175A02155F010F58000C51020D49001042283E5E
192735312B2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0058C22C402615564A5028223B0408282F2C426356624841560A0F2F5A6084161A4A
01073D3A385E725D727958667E59667F56658557668B5A698856638857618B5A618D5B60
9360669663699C696E9C686DA06E72A16F73A77579A77B7DA98381AB8983AD8D83B09084
AF9285B09488B59A8EB59C90B5A096AA978EA3948AA99D95A99F9AA19796AEA4A3ABA2A0
B1A9A7B1ABA8ABA7A5ABA8A7B2B1B0ABABADABABB0B0B3B7B3B7BDACB0B8A6ABB2A6AAB0
B2B3B8B8B9BEBCBEC3BCBEC4BDBFC3BDBEC2BBBDC2B7BBBFBCC2C3B8BCBFBABDC2BABEC3
BCC2C6BAC0C4BCC1C6BDC0C4B9BCBFB2B9BBB6BDBFB1BABAAEB7B8ACB5B7AEB6B9AAB1B4
A8B1B993A7C018377145548D9055749B1125B00314B50210B3020DB0010EAD0110A70411
92142595687C5F6E83C7DDE9CADAE4CBDAE3C9D9E2C7D7E0C8D6E1C4D5E742587E2A3262
6F3E607A0B1E8F021093010C95010B94010B8706108B3F439581817D868D576D89051C5A
011767001563051C5A365073627989697C81687B7C627880324B69021949112853576D83
52677F03154800135600115A00115D00106101105F021059010D52000E49000F4217294C
2736482F2D2E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF005EC42B5433205547511C1834070A2C4A43596557672D28450409324E537A212452
030940161845685A737B5D6C7E5D69805966825663875564824D5D8854628B5A658B5A62
91606596666A98696D99696E9E6C719D6C70A67778A67B7CA67F7DA9857EB08F85AF9184
AE9284AF9488B1978CB49C93B39E96AB978FA6958CAB9E96ACA29DA09795ABA1A0A69C9A
ACA3A1B5AEABB4B0ADB6B3AFB5B2B0A8A6A5A6A5A7A0A0A1A3A2A6AEADB2A5A6ABA5A9AD
AAADB1ADAFB3B1B4B9B7B9BEBDC0C4BDBFC4B6BABEB9BEC1B9C0C1BAC0C3BBC0C6B7BDC3
BDC5C9BBC2C7B9C0C4BCC1C4B8BCC0B3B9BCB2BABCADB4B7AFB5B8AFB7B8ACB5B8A7B0B2
A6AFB5A2B1C244608F1735748D79A1891D35AB0718B60412B50210B1010EB0000DAB020F
980818944B5CB1ADBDCEDDE7CDDBE4CBDAE4CAD7E2C9D7E0CBD7E0C8D6E296A7C2142451
634B7370142E8A041593020E95010B9200098D030D7A151D9E767C7F8595223A68021A65
02196905215E3D597B637A876A7E816C807F6B7D85496078081F4C051D4B455D786B7D86
657685132750021358010D5D020D61000C5F011060011058000F4C071A4B0719410E1D3C
3748572C2F310EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0067CA306D48354F414D13102E0F0F305B516660546915123903093840446B32355E
040A3E05093B4E48677661727A5A697C56647F53618553618A55658C5767905F6A8A5B64
8F606794656C996A719D6D759F6F749F6F72A37676A67E7CA98481A9847EB18E85B09085
B09489AF958BAF968DB39E93B09D93AD9992A8958EAB9C97A89E9BA79E9CA89F9CB0A6A3
B1A9A5B4ACABB9B5B4B6B5B3B4B3B1B4B2B0B0AFAEA9A6A7A09EA1B4B3B7A7A7AB9DA0A3
A3A6A9A5A7ABABAEB2B2B6BAB7BBBFB2B9BCB7BDC0B8BFC2B6BEC0BDC4C7B8BEC3B9C1C5
BCC3C8BAC1C7B7BEC1BCC2C4B9BEC1B4B9BDB4BABDB1B6BAB4B8BCB0B6B9AFB7BBA9B3B5
A6B1B4A7B4BE8298B9133573525C918E49679E0E20B30513B60210B4020EB1010EAF0210
A40516922A3AEEC6D5DCD3E1D8D1E2D7D2E4D5CFE1D2CCDED4CCDFD3CADFCDC5E0494168
583A5D84334A8404168E010E93000C92010B8F020C7D06108E505D77758E0A1F5B011867
0721643D5C80627B88667A7D6C81826D8389596D8510265200154826405F657B876E8183
6D7E883F5471031551011059010D5B010E5C01115B0217530F2651445A7534475E07172D
42555E2A31321C941100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007F593E5448530B0A281C1A3665596B50465E070833030A3936395C474668
02053401063B262850695F75765C6B7A55627F546181505D8854638A55648C58658E5D66
93626B9A6871A06E779E6C75A07074A47478A5787AA57C7BA98380A98580AF8E85B09188
B0938BAF958CB0998FB29D92B09C93A9968EA99791AC9B96AC9E9BB1A6A4ACA39FAFA7A2
B5ACA8B3AFABB4B3B2B5B7B6ACADACB4B3B2B0ADAEACA7AAACABAFAEB2B4ABAEB0A3A6A8
A9AAADACAEB1A6ABADB3B9BCB3BABDAEB6B9B5BBBFB3B9BCB7BFC1BCC2C6BBC1C5B3BBBE
B6BEC1B3BBBEBABFC3BEC3C6B9BDC0BABFC1B4B9BBB2BABCB0B8BBAFB7BBADB5B9A8B1B4
ACB3B7A8B3B89FADC23453861935739578A089162CAE0A18B90613B3020FB1000EB20211
AF04179C0C21B44C66AA57749E5170974C6A9548679145669043668E41648D3F637C2C4F
862E4A8B1E328903138F010D92010D91010B8F010D8806147A2435624E7008195C031E64
37537F678091697E83677C7E678188567289142D5800164B142D535871816B7E836D8080
6D7D82697C8B21365C01144E0012550112560218511C395E4E687C5369714D5F6B041626
485C632B3536219C1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00946D4B4539430607242F2842695A6C332D48050C35050C374B4A68595370
05063102063C080D3E4F4B6B6F5C6C7A5A647C535D804F5C804B59854E5D8A55618F5C65
92616996656D9B6B739C6E759E72779F7578A6787CA97E80AA8281AA8682AE8D87AD8E88
AE928AAB9289B19A8FB39E94AD9991A7948EA8968FAE9F98ADA19CA79C9AB2A9A5AFA7A3
B1ABA7ACA9A79D9E9F9B9CA0AAABAEADADAEB7B5B6ABA7A9AAA9ACB1B4B6B1B4B4AEAFB0
B0B1B3A6ABAEA3A9ACACB2B5B2B9BCB3BABDB7BBC0BABDC1B8BCC0BBC1C5B9BFC3B8C0C3
B5BDBFB6BEC0B8BFC1BAC2C4B9BEC1BBC0C2B4B8BCB3BCBEAFB9BBB2BDBFADB6B9A9B1B4
AEB3B8AAB1B6A6B1BC798FB112326F6267998A415D9F1021B40715B2020FB2020FB0030F
B20212AD0417A70720A00B26990823980B249507229407229005229007238D04208D051C
8E05198F021390010D92010B92010B90000A8F000C8B0310780E20643F630B1758112D65
65809A6F848D6D8286677F88527089123160011D540C28534D677B667A806D7E7E70817E
6B7B7B6F7E83607382263E5B0C234D1029512E4A66607D895F787C536B6D495E67071B28
485F6533424126A31E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0072943B3A2D35070823423B51675A6E1A1936020B3414183C5F5771685D76
0B093101053B01073E191C485D536E795D6B7E556181505C84505C8954618C5865905F68
906268986A719A6E75956D758E6A71967378A47C81A47B7DA88080A78280AD8B87AC8D87
AF938CAB9489AC978AAD9A8EAB9A91A8978FAA9A92AC9F99A69C99ABA19EADA5A0B2ABA6
ADA8A68C8C8A92949695989C828489AEB0B3B2B2B4A1A0A2B2B4B5AAACAEBCBDBFAEAFAF
B5B6B7AEB2B4A2A7AAA9AEB1B6BABEB8BCC0B3B7BCBABEC3BBBFC3BABEC3BBBFC3B7BCC0
BAC0C3B9BFC2B6BEC1B8C2C3B6C0C2B6BEC1B3BABDB2BBBEAFB8BBAFBABCACB5B8B0B9BB
ACB5B8B2BBC09DA6AFBCCADD425F8F203B778C779F86273CA51020AE0714AF0410AC0410
B00511AE0511AC0512A60411A306119E07129B05119604109806139404129203108E020F
90021190031090020C90020B8F030D8D020C8F020E8B030E7A0A196F42600E17521B386B
67869E69828E667D903F597B0C285B001F5A0D2C5B4B687E60797E677A7B6D7E7C70827C
6C7D7B6F7F7F6A7B7D5F767B5B747F5D747D60767B6279795B7172536A6C425864071C2C
485F663C4B4B41393000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052BF2F281C200A0C24514C5F5C5468080C2C030B322D2D4C66596C6A596D
1C163A02053901064102073D27264F6C576E78536182566183535E83505B8A576190616A
93646B96696F996F7687636A896B747C616A95777D9F7C7EA47E7FA68281A98785A88984
AB9086A99185AD988BAB9A8EAA9A91A99C94A79B94A69C96A09693A59B97ACA5A0AAA5A0
9B99979A9E9DCDD3D2CACFD191959BA3A6ABABACB09397999EA2A4A6A9ABABADB1A3A6AB
AFB2B6A6A9ADA2A6AAA2A6ABB3B6BBB4B7BCB2B6BBB3BABDBBC0C4BBC0C4BEC3C7BCBFC4
BEC1C7BABEC4B8BDC2BAC2C6B9C1C4B7C0C2B5BDC0B4BCBEB0B9BBAFBABBB1BABEB0BABC
BBC6C9D1DDE2A3ADB7A9B5C08AA0BA2E4D7E32477C8A70968A374F921A2A98111F9C121C
9D12189C1618961618961B1C911A1D88161A8B191E86191D851A1F7F171D7B131879141B
79121C760F187B12197C10147D0F157C0C12810D157A0C126914198566761924550A2661
3B5C8C416088213D6D031D5A021C59163260536E85687F86687E7F667A796D807E6E807D
6A7D7C6D7E7F6D7D7D697A7A6B7C7B6978766977776678775A6E6E53696E2E45550E2337
4D626B49595C43413B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0058C3303321201310255D566747435902072B060C315049616F5B69715C6C
3126460304370105410105410708385343617452637C525F7F525C82525A8A5B6291636B
94656E966A7190676F936E7795767F755E677D686E9E7D81A78184A88284AB8787AA8A86
AC8F88AA9186A99489A9978CAF9E95A2948BA0968D9B948B9F9791A0969297908B9E9A94
A8A8A4AFB4B5D9DFE2D7DDE2A1A5ACA9AAAFAEAFB39DA2A5A3A6A896999BA4A6AA9FA2A8
A0A4AB9B9DA39DA1A79FA4AAB3B7BDB3B7BBB1B7BBBAC1C5B6BBBFBDC2C6BCC3C5BFC4C7
BDC1C6B9BDC2B9BCC2BDC2C7BBBFC4B9BFC2B4BBBEB4BBBDB2BBBEB6C1C2CED7D9B3BDC0
ABB5BBAEB9BFAAB3BBA7B5BCA9BAC5B9D0E8415F8D2E42726B658589677D87576D986373
A56E71A56E6DAB7774AB7A77AA7D7CA67A7BA67A7DA37A7DA57E809D7A7C97787E94747B
8364707B626D8C6A6E895F5E8B5F5E8D5B5B8E57598453538565638480844B5A760B2259
021F5E01205B021F58082357334C7260788B6E82887080836D7F816D7E7E6E7E7E728282
6E8081697B7D6D7C7E6D7C7C6C7A796C7A776674746373735D7072566A75152C421F384C
4F676E4E616040463F0FCB0700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF005BC32C52392F1B1223665D6D36324D050A331B1C3E615668715C67735C68
4D3C5A0602330307400206400A0A395E4D69775364794E5B7C4D5881535B8C5E679C6E78
9C6E78976B758E646E936C77896A7677616B7A64699D7C7EA78082A98285AA8687AA8987
AD8F8AA88E86AA968CAC9B92AB9A91A6998F9B92889E968C9A938AA19993968E8A9D9A95
BDBDBAB7BBBDB6BCC1B7BDC4B6B8C0ACAAB0AEAEAF9EA2A39A9C9F9192949C9B9F98999E
989AA094989F90969B989EA3B8BEC2B3B9BDB2B8BDBCC1C8B7BBC0BBBFC3BEC3C6B7BEC1
B5BDC0B5BCC1BBC1C6BAC1C4BEC5C8BCC2C5B9BEC2B7BEC1B5BCC0B2BBBFB7C0C3B3BABE
AEB5BBB3BCC2CED9DEA7B7BF9CACB7C9DBE6A9BED47F98B87D97B2A3B6CB617595425A79
C0CED8CDD2D4D1D3D4D2D4D6D3D3D6D2D4D7CFD2D8D0D3D9CFD3DAC7D0DE7389A1ADC0D6
5362754155658B959D7E8182868A88A0A19F8785878B8D8D9CA2A07985867A8892576A84
334A6F2C466B405A785D75896E838D6E82857081847181846F7F7F6E7E7E6F7D7E6E7F7E
6E80816D8082697A8064757A6576766273706476746274745C6F7745596E03163A27415E
48656F506665424B43209B1300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE01361412D271C246860701E1E3C040B3131314B6B5D68705B62755E69
5F4B620D063103063D01043A12103C6A567076506180536183545F885965936571986A76
996A779A6B77956B7687626D836570775E658B6D70A07A7BA67F7FA88282A78484A68785
A88C88A38B84A8938BAB99929E8E869D9187A2978EA1978E9F978D9D958C98908A93908B
ADAEADD6DADCD1D6DAD5D9DFBCBDC4A9A9AEACADAFA3A8A8A0A4A5A2A3A3ABABADA0A1A5
989B9F93979D888F93969D9FB2BABCB0B7BBBABFC7BBBDC6BCBFC5BEC1C7BCC0C5BEC4C7
BDC2C6B9BDC2BABFC6BBC2C7BCC4C7B6C0C1BBC0C4B5BCBFB5BDC0B2BABEB4BBBFC2C8CC
BDC2C8B0B8BFD2DCE2AFBCC798A6B3A0AEB9ADBFCB97B2CA5F84A7B7D9F46384A45B809F
C7E2EECEDFE5D0DDE4D1DCE3D3DBE3D0DAE2CCD8E1CAD7E2C9D6E2B4C5DC223E655F7D9A
74899A6B7E8BADBDC5A3B0B688959BC5D3D994A1A77B898C808F917787897B888D76848B
73838E6F828C7084897183867484877083837385867284856F7F7F6C7D7B6D7E7C6F8280
6E82816B8182566B76364F5B5B72775E72705E72715870754E657A12244A000D4001123E
233C554E686F4755522F6A1E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006F4929342225695F700F0F2F080C304D485C6F5C61715C5E755E65
6C586A1B133702043503063A19174169546D7753627F545F8355618659658E606C92636F
9969759A6B76986E78946D77906D759A787D9D787BA57D7FA67E7EA67F7DA4817FA48683
A18681A18A83A8948BA39189A6978EA4988EA1948CA2968E978D85958C839A918997918B
989594B5B5B7C0C2C6B1B3B7A0A1A4A0A0A4A6A8AAAAAFAFA6ABABACB0B0AEAFB3A5A6AA
9B9EA2999DA2888F929DA5A7B0B7B9B2B7BBBABFC4BEC2C7BDC0C5BBC0C6BAC0C5BBC1C4
BDC1C6BDBFC5BFC1C7BCC2C7B9C1C5B9C1C4B8BFC3B7BFC1B6BCC0B4BCBFB4BBC1D2DBDF
CAD0D6AFB6BDAEB7BDB1BBC4AEBBC995A9BCC8DDF0728FB50D39735982ADA3C2DAB2CDDF
CDE1EAD0DFE7CFDCE4D0DEE5CFDDE4D0DCE5CDD9E5CDDAE6C9D7E4B1C0D3596D8AA1BBD1
B8CBD9899AA8A8BBCABFD0DE7E8E9B83949D808F9678888A798A8D79888C7A878D768286
7785887585887284857385857386866F84836D81817688887282816F827E697B796F8281
6E81806A7E7F3F56650E273E57747D566E71556D763B546A11254E020F45000945000B41
03143C3B576848595B3C372B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00875A31422A2763576B09082B131435655969715C5E6F5A5A715C60
6F5C6934294703033103053A1B17416C566F7854638157638458648D626D91656F93646F
9969749B6D77996F789970789D747B9F777BA37B7FA67E80A67D7EA57E7DA3817EA58582
9D807CA3898299837BA6948BA3948B9E9389978C839A8E869A8E869D928A9F958E9C948D
948F8B9995939998989A9A999A9A97949493A3A6A7A4A9AAACB1B2A5A9ACAAADB1ABADB1
979A9F95989C8E92969BA3A5B3B9BBB3B8BBB6BEC1BAC2C5B5BDC0BDC5C8BCC4C8BCC4C7
BAC0C5BAC0C6BAC0C6B8C0C4B7BFC3B8BEC4B8BEC3B5BBBFD1D5DAC2C8CEB2BBC1B5BEC4
B2BAC0ACB7BBA6B2B6CBD7DEAABDD5415F81A6C0DB9CB5D343648E6489ABA5C1D2CCE2E9
D0DFE8D1DEE6D0DCE5CEDEE5CEDDE4CBDBE3CCD9E5CCD9E4C9D8E2C3D4E399ADC55D7D9B
98B7D19AAFC45B6E828393A47B889476848D88969A8191927B8A8D99A8AB768588798789
7583857382847584847383847283836F81826F82847283857181816D807F6C7D7E6E8182
6D7E81697E7E4F6573051B354E6C7E4D6A7B2B4262051643010B44010A45000944000B40
000D3C243C564B60633F3E3400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006986254D332954495A0606282626426B5E68725F60705D5F6D5B62
715C6A5647620604300104371C1A416C59707955647F54618459658C626C906670946973
956973986C769B717A9E757D9D747C9E747AA2787CA07678A47B7CA37B7DA47D7DA58181
9D7B799B7E799B857CA08E83A6968DA4978E988E85948A819C9389A39A90A0978F9D968E
95918A9B9891989691A09F9A93938E91928E989B98A3A9A8A9AEB0A7ABAFA5A8ACABAEB3
95999C8D8F938E9195959C9FB4BABDB8BEC1B0B9BBBAC3C5B6BFC1BCC4C8B9BFC3BCC2C6
BBC2C8B1B8BFADB5BD9FA9AFB4BCC2BDC3C7C2C8CCB7BDC1BEC5C8B8C0C4B8C1C5AFB9BC
BCC8CCCADAE0A4B7C1C1D3DDB8CCE2607A9A92A9C29FB4C4B6D0E56388A4A6C4D6CAE0E7
CEDFE7D2DFE7CFDBE4CEDDE5CDDDE5CADBE3CCDAE4CDDBE5C9D8E7B2C6DAA5BCD61F3E63
40617F8298A9798895909EA9B4C2CA808E969BA9AF9FACB17C898F78868B768589758384
7683857684867681837583847583846D7D7D6F80837080857281856F81836B7C7F6B7D7F
6A7C7E667A7B5E7280081D3C314B6F102851011145000945010846000842010B42000C41
010E3C10223E496062484B3F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0047AF195B3D2D453B4C070829403C536E5E676F5E63594F5A544B5D
6C5C6E64546C110E3604083919183F6E5B737C5967835B678C656E8B636C8C646C936A73
966C769D737B9B72799F767F9D737C9A6E779F757A986F71A0777AA57D81A47F829E7A7B
987876A38984A08D84A4948AA18F879C8C85988D849A91879F988DA1988EA39B93A29A96
95908B9E9B949D9B95A09F9A9B9B96999B96999C97A3A9A6AFB6B6AAB3B59EA5A7B4B6BA
A0A1A694959A8C8F938D9497B2B8BBB5BCBEAAB2B4B9C1C4B9C1C3BCC4C8B9C0C4BFC5C9
B1B6BDADB4BBB8C0C6B3BCC2BEC7CCBDC5C8BDC6C8B7BFC4B6BEC3B8C2C4BFC9CDADBBBF
BECDD3CBDDE6899DAAA5B7C2AEBEC9B6C8DB8EA9C793B3D0AACCE42A5474B3D1E7CDE0EA
D0DFE7D2DFE7D0DDE6CEDCE5CCDBE6CBDCE6CDDBE6CBD9E3CBD9EA677C948498AE768DA0
7E96A6BFD4DEA6B5BE909EA8BFCED98D9EA67B8A907D8A8F7A878D7A888C7A898D798889
7686867283827182817283837482837383826F81836E81847382866E7F816E7E816C7E7E
6A7E7F61767D556C830D204B011148000B48000846000846000845010943010D41010F3D
020F3C041533465E634C564A10CC0800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB41A6B4936372D3E080728524A606855605F5364171837101534
5A546A675A6D2E284904083614133E6D5B747D5C6C825D6A8E67728B646C936A73976D76
9970799C747C9B717A9C737C9D727C9E737C9F767BA0787B9D7579A0787DA17C7F9A797A
A08381A58F8A9F8F889D8D859C8A839C8C859A8E859A91879D968C9F989199928D9D9792
96908B99948EA2A099A09F9B9A9B979A9B99979997ACAEADA2A9AA9BA5A799A2A4B3B4B8
A7A5AB94959A8E95988D9699A7AFB1B4BBBDAEB6B9BCC4C7BDC4C8BDC3C8BCC3C7B9C1C5
BAC3C6A8B2B5B1B8BEB2BBC0B6C0C3B6C0C2B1BABEBDC5CAB5BDC2C6D0D5D2DEE6ABBAC2
AEBBC4B0BFC6B2C3CCAABDC9B0C5D2C1D8EE2C52831C4A808BB0D381A1BACBE0EFCFDDE6
CFDCE5D0DDE6CFDDE6CEDDE5CEDBE5CEDCE7CBD9E6CCDAE5C7D7E77A91AABCD4EABFD4E3
879CAFAAC2D3B3C5D27986957583917B8B947A898E86959794A1A77281859CAAAF8F9FA1
7486867286846F827F70817F7583847180826C7E8172868778878A7484866F7D826C7F82
687E87536C811B315B010F46000949010847010847010846000843010D4102153D142D4A
1025440113303D565F505D55219D1400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057BB1D7B563D2E202E0D0C275E54646A5B6639344E040B35030D36
464761675C6D4F455E0608320C0E396C5E7B7C5D6E86616F9269788D6571926872946A73
997078966D76966C75996E789B7079A4787FA3797F996F72A07779A2797BA27D7E987978
9F83819E88839D8D869D8F86A2948C9E8F889D8E889C90889A918CA9A29E9B979298958E
98948D9A968EA4A39AA4A39F9A9A99999998989898AAA9AA9A9B9D8E94968A9092ACAEAF
B1B0B49FA2A68B9396929B9FA6ADB0BCC2C5B6BCBFBAC0C3B6BDC1BABFC5BBC1C7B7BFC5
B5BFC4AAB5B9B0B7BDB9C1C6BEC7CAB6BEC2BCC5C9D5DDE1BDC5CDB6C1C9BECBD4ABB9C1
B1BDC3B2C1C6CCE0ED87A8C47598B7B2CEEA42648E2E588587A4C1CDE0EDD3E0E7D4E0E7
CFDCE5D0DEE6D0DEE7D1DFE6D2DCE5CFDDE7CBD9E8CBDBEBC6D7F15B749B5B729EA5B1D5
707696464B66969AAB9398A47D85917C8A9277858D8D9FA3BCCBD27E8C947B88917B898E
78888A7386847484817382817381836F7F807184847083847587897486886E7E86657B89
3F57780F2556011350000C4A01094A010848000845000940010C3D0B1D40324B604C6773
4A617105172E38515E4F5F5A336F2300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007C53342519211B182C675D69655968181736020A37030B38
34345465586A68596C1E183C070A345E55757A5F72866373916A7A8F6675916873946874
916770916870956B73996F789D707AA0737BA1757B996E71A07578A4787AA17A799B7A77
997C79A087839E8A849D8C84A5958EA3948D9E9089A09390988E89A59C97A39D97918E85
98958B9490889A98939999979A9A9A919190969595A8A7A79A999A9E9EA2929495ACAEAE
B5B7B6A2A4A4999FA299A1A59DA3A8BCC1C5BEC3C6BCC2C5BDC3C7BBC1C5B2B9BEB5BEC2
B2BCC0A6B1B4B3BCC1BBC3C9C1CACFB9C2C8BDC6CBCBD4D8B6C0C7B2BBC2B8C2C9CDDAE1
C5D6E0ACC0CBC5DBEC4165854A6F9298B1C9A6BED791B3D086A4BAD1E3EDD3E0E6D1DEE4
D2DFE7D2DFE7D1DFE8D1DEE7CFDDE8CBDEEEC3D6EFACC0E17880AE3C356C4F2F68683462
733256753754A16C84C8A4B69A889783858D8188917C8991818E9A74838B717F87758388
79878B7584847585847182816D7D7D708181708282718383748688728589637886253E63
03195601145A000F57010B4E010748000845010C4102143C1C304B475D6953686E586C6F
5D6F78142738364E5B50605F4A453700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00845B3524181F2822356C5F6B51475808092C030B3A020A38
312E4F6E5C6C6D56644E405B08072F45406379647889697795707F956C7A926673946773
916672916870986E769C727B9D727B9D737BA1787D9C74779F7578A4787A9D75759D7A77
9C7E7BA08682A28A86A28D879F8C869B8C859B8F889C928B9A90899F9590A49B95968F88
948E86928D8893908E9999989293928F908E9B9C99A4A6A49E9FA2A2A2A79B9B9FAFB1B1
B4B5B4B0B2B3A5ABAE98A0A39FA5AABABEC2B6BCBFB9C1C4B6BFC2B8C0C3B5BEC1B7BFC3
B9C1C4AFB9BAC0C9CEC1CCD1C9D5DCB1BEC6B4BDC3B6C0C2C2CCD2C0CAD0BFCAD0D2E1E9
8DA1B398AEBFAEC2CFA6C1D1A7C6DE92B1CABDDBF5486E8F7C9FB7CDE1EBD2E0E7D2E0E6
D2DFE7D1DEE8CFDEECCADDEEC6D9F4A2B6DB656C9B5B497C6A376B75214E7D0E35870726
8C06228807218209267D15317B2E448F677493898E81878E79848E91A0A67B898F788389
7C878B7A88897A8A89798A8A778688738484697A7A6B7E7D707F8272848A54687E02194E
00115D00105F020F5B000A52010849000C41081A3D2D46584F6A6E576D6C576869596A6A
5E6C74182938364F59526264514E4600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008D61362112143831416E606A3C324604072D030A3B030A39
312B4D6D58696E525E70596D20173A27244875657A816372906C7B9268759265718F636E
916672906670966B759C727B9E767EA17A819E767D9870759B7275A178799871729A7776
A0807FA186839E8581A18B859E8A839A89839B8E89998F899C928CA29894A49B979C948F
9C94909A94909997949B9B9A969796929492979997A2A4A59C9EA19B9DA1A9AAADAFB0B2
BFC0C2B0B6B8A6ADB0959DA1A9B1B3B3B9BCB9C0C2BAC3C5B6BEC0B9C0C3B6BFC3B8C1C5
BAC3C6C4CFD0C5D1D4B4C1C7B2BEC6B2BEC3B7C0C7BDC6CAD8E3E9D1DEE6B7C4CDBBC9D3
A9B9C7AFC3D0A4BCC6C2DDE9779DC12B5A8D769EC96E91AEBBD5E6CFDFE8D1DEE7D1DFE9
CDDCEACBDCF0C4D7F599AAD363639763497F783B6E801E478A0B2D94061E970115970211
95010F9301119201148D021786071B731526B88E97C7C2C7869198A8B6BC8C99A078848B
7B878D7C8A8B7B898A76868678878A77868A76858873858674858771848962758B04184F
01105D00105E010F5D010F55000D48152A50465F6C566E6F58706C5A6F6A576B69576C68
586A711525353A525C5366685555510FCA0700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006988271F0D0A413B466C626C262037050933010A3C030938
3931516F56687254606F536052425B1811326A5B737D606F8F6B7A916776916470936671
9265719468739569739B71799B737A9E777E9D757C956B729C73769F767A9770749A7778
987B799C817E9A827D9A847D98857E9B8A849C8E889A8E88988E889D9591A29B969C9691
97918D958F8C9E9B999999989A9B999294929C9D9D9C9D9FA1A3A5999D9FA8ABADAEB1B2
BCC1C3AAB2B3A4ABAE939A9EA4ACAFAAB1B4BBC1C4B3BABDB9BEC1BEC5C7B9C1C5B8C0C4
B4BEC0BBC6C7BDC9CAA9B5BCB6C1C8CFD9DCCBD4DAB6C1C6C2D0D7B2C2C9B3C0CAADBBC3
C7D7DFBCD5E787AAC4ACCEE93E66930D3B78416B97B9D5E7CCDFE9CDDEE8CEDEEBCCDEF1
BDCFF08C9AC6625E9367447D7F356A881B47940D2C9C061C9F02159F02119D020F97010C
94000C92000B91010C91000D90010F880619832D3DD0ADBA95949D7E8A907D8B907C8A90
7A888E7B898B7A888A78878B78888A76868978878B76868977858B75868C7083960B2052
01125A01125B0115560C215807164837506A577074576F6A5A70675B706A5A6E69576C68
50646D05172B425966566C6E5359561F981200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0043AC19250F06493E48685E6A13102C040935030C3C040A35
3C324F6E546272535B74555E6F57673628424F3E5880627386616F8F65738B606D956874
996B779C6F7B996C779C707A9B717AA078809E757B9B72749C7376976D7392696E977374
987A789C807C937B749E88819A88819E8D869D8E87978B849B928C9F9794A09A969C9792
958E8B8E88879D9A9990908F9395929394939A9B9C989B9CA0A6A69FA4A6A3A7A9A9AEB0
B5BCBDA9AFB1A0A4A7A5A9ADA3A8ADADB2B6BCC3C6B2B9BCB9C0C3BCC3C7BBC2C6BCC4C7
B5BEC0BEC8CAC6D0D2B1BCC1B6C0C6CED8DDC9D4D9B3BFC5B4C1C7C0D0D6C8D9E3B6CAD5
C4D7E4819DB81A426A84A6C28FADC886A9CE89B3D4BEDDF0C5DBEEC2D7F0B0C1E2898EB9
67568B6940787A2E6286173F960B2C9C061E9F05169E0512990511960813940B15890813
8805138C030E8F010A91010B93010D92021185081A7F303F9B808A808489808D91808F92
7C8D90798A8C79878D79888D78868A78868A7A868B768487738187738388738696152C55
021853051D532942695A728D1C2F502C445E5971765A716D5C716A5A6F695D706C586C6C
31465603162F4A626F586C6E53605B24A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004BB21C2A110451444B5D52600907260309302F345A0C0D2F
473B5272576376555D73545B775B66715B6C4E364A7E607085606E8C6370926773976977
966977976A77966A74986C769B707BA0777F9C7277986F71986F71966B6E966C6F95706F
967874947B749B837C9D87809A87809F8E87998A849A8E889B938F9E97959C97949F9996
968D8B968D8B9995918B8B879293908C8D8B979A9B959A9A9AA0A19CA0A39DA1A4A6AAAD
B2B6BAB5B7BBA7A9AEAEB1B6A3AAADA4ACAFBAC3C6BDC4C7BBC1C5BEC5C9BDC3C7C1C8CC
BBC1C6B9C0C4D0D7DCD1DAE1B6BFC5B6C1C6B5C0C5C0CCD2B5C1C7C8DAE4ACC8E07EA2BE
A9C0D39FB0C48CA0BAA2B7C8ABBED0A2BDDA4A6C95A0B8DD8F93BC7E719E7953867E3D71
802353841138910D2B980D209409168D08108D101784121880202685363B8848527B4153
7D374E7713258A041291020D95010D93000B9002107F0B1B965A648C8487858E91879598
7E8C917C8B907C8A9178868C7584887684897883897784896E7E8372848872848E29425A
1F385A4E6680657D8A687E882D42591D364E59727B5D72725E716F5A6F6A5D706D596D70
12263712273B4F696F576D6C58666135732700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0054B92031140355484F5A52640506260E11315C5A74171229
4F455470596275565D75545C755761785C677B5D6A7E5C6A845E6C9066748F64728F626E
976975986975986A749A6E78996E78A0747E9A6F769A727699717493686C93676996706E
93736F967C769D857F9B857F9A867FA290899B8A859A8E8A958D879994909D9894999390
938A8898908C96918C8A87828989848C8C88979997929797959A9C989B9FACAFB2A7ABAD
AFB3B7B8BABFA6A9ADA7AEB1A3AEAFA5AFB1AEB8BABAC3C6BDC4C8BFC4C9BCC2C6CED3D7
C0C4CAC1C8CCC0C7CCBCC3CAB9C1C7B5BEC4CBD7DDD4E3EAC5D3DCB2C6D7638AB14073A4
9DB9DBB2B2C7DAC8DBBFA7BD997D9B85678D7B59878653817F38668429548B1A40921234
99122B930C1E94111F8D18207F1D207A2C2B7E3F3E8053539075797B727E595E774A5476
2C2851693B5D780C2390041594011194010C94010E8D05168026349B8083818687808B8E
7F8A8F7E8C917D8B8F7D898C7C888B79898B77858A7381856F8083728586738588687D85
687D876B7F866B7F836A7E85455B6E0E263F57727C5D72736174735E736E5C716C5A7070
182D37385059546C6D5A716D56686146463800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDE103A1806594A52453F5504052522203A685F721B1325
5E525E6C555B72555B76575F7456617A5B677C5C687E5C6A896473936B7A8D6471926672
936571976874976A74996C77996D779B6E77966B73966E73956D7390666A92676997706F
95716E9576719E847E9F888299827D9C88839D8A86998B87988E8899928D9E9995999490
8F8885A29B988B86838B8884908C8893908C9898948F949291989999A0A2A9AEB1AEB2B5
A9ADB1B2B8BBA3A9ACACB5B7A1ABADACB6B8A7B0B2BFC7CBBEC4CABBC2C6BFC5C9C6CBCF
BEC2C6BEC5C8BBC1C6C4CACFD3D7DDC1C8CFC3CED4BDCCD4ADBDC6B1C5D27D9EC01B4C84
567AB38081A9774E6D823A5A872C4C8B24438D193694173395142D9213288F13238A151F
881C2380232884393D8954538A6967978683ADA5A5BEBFC5B0BCCA5E728A092247627EA0
2E436E3B3463681D3F85051A91011192010D93000C9003107C0C1A9D6A6E8B8787848E8F
818D8F7F8D8F7B8A8B7E8B8C7C898B7889897585867385856D7E7F6F8281718383718484
7184876F82856E7F826A7C815A6F7D0720375570795D72745E71715E726F5D726E576E6A
4258594F6766536967596F6B5A6D654D524700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004C220B57434B39334B040727363349685B6A1F1322
6B5A656F565C75575F72545D6E515B7657637959627C5A66825F6C8A6271916775926774
90636F946773946974986D779C71799C7079996E76966D74956C718F6367956A6C946E6D
9A75729B7875987B77977F7A9A837E9986819E8E88A2938E978D88968D899F9895938E8A
9F9B97A7A39F908C89938E8B918D89989694999B998E9392969B9C9A9EA1A1A6AAA0A4AA
9EA3AAB2BBBEA2ABADBCC3C6A8AEB2ACB4B7ABAFB3B0B6BBC8CED3BFC4C9C1C5C8C3C7CB
BDC3C6BDC3C7B8BEC6C9CFD6DCE0E7CAD1D8BAC3C9B8C4C9C8D7DDC3D5DDB4CADD779CC8
0E397E3B56937F79A7926C908D4D6A89364C892A398827338628338330377D383B7F4745
8E62609A7D7C9B8D8DB1B1AEC1C9C7CAD7D7CBD8DCC1CFDD49627594ADC0768CA49CB4C8
7C94B6131D516137617508218C021492010F92000B90010B850511863A40968283858A8B
808B8C7C8A8B7B8A8B7C8A8C7C898C7B8A8C79898A7284847485866F80806F8080708082
6F80817081827281836C7E816577821F38465772785C73755D72725F72715C706D5A6E6A
5B6E6D516866455C5B596D6B5C6E69575E541E960F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006032155842472C2640070A294E475A64545F291A26
6B586170575B7053586F51596B4D5670505A75545E7756607B586386606C8C636F8C606D
8E616D9669759268729970789970779B7077946971966D74956C7293686B9D73759B7676
9B78779977769B7D7A9A807B98827C96847F9E9089998F87978D88958B8899918E999590
9E9C97A4A19D99959299959191918C989D989CA2A18B909195999C959A9EA1A7AD999FA7
828992848C9299A3A6BEC7CAB5BCBFB5BABEB6BABFB4B9BEBFC5C9C5C9CEBFC2C8C5C9CE
D5DCE3D7E1E6C3CDD3B8C1C8BEC6CDBEC8CEBDC7CDBCC9CFCEDFEAB1CBDCADC5D996AFCA
4667946183B552719E596E95535C7E7E778B8A76818A6F799C838A9885899E9496ABA9A8
C3C5C4CAD1D2CDD8DACAD9DAC9D8DDC6D8DEC9D7E0BBCCDE658296BDDAE8C0D5E27994A6
8AA7C7152A5C4233646B173686031990010F92000C92010B8D040F77141C9D757988878A
7F8A8B7B87897D8B8E7B898B7D888E7B898C7382846C8081748589738184738284738084
7482837180807281836E7C817180876B7D8365797C5F77765D73725F73715E726E5D716C
5D6F6E586C6C33494B5268685B6D6B5A635B229D1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0076461C533D40201C370E0F2D6156675A4A56332637
5A4E5F5C4A556950556A4C536D4C56724E5974525D75545E7D57628259658A5F6A926570
946572956672966A74966D76966E769A7177976D73976D75976D75966D72986F729C7577
9A7879997B799E827F9D858098827D927F7A9E918A978D86948B848F86808F888197938E
A2A09BA4A19D9E9A9897969391938E989C979BA09F8E92968E95988F979B9DA5A97C848B
949DA39DA7AA889395B2BABDB7BEC1B7BCC1B9BFC4B6BDC1B2BABDC4CACFC4C8CFC0C5CE
C7D1D9C8D3D9BEC8CEB8C2C6BAC5C8D4E2E6D4E3EBBAC9D1AEC0CF516C8397AFC2B0C2CF
BED5E8A9CBEE739DCC8CB5DC7094AEC1D7E5CAD6DCCFD5DBD0D6DBD1DADFD0D9DFCEDADD
CDDADFCBDAE0C9D9DFC8DAE1C7D9E1C7D8E0C8D6E3C2D4E94968897092B294B0C5486178
37526F536A911C1F516C375A7A071E8F021292000C92010B8F020B7D070E9252588F8687
828C8E7F8A8B7E8A8B7C8A8B7B898E7A898C778688748588748388758386748386737F84
778286748284728084728084717E83707E836B7E80657B7B5F74755E72715E73705C706D
5C6F6D5D70702A41463E585E54696B59655F356F2600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002E970649343316162F1E1D38685C6A4A3E4C302C45
1818371C17315A4B5A674D566F4E586F4A56744F5B78525E7C5460835765895B678B5F69
8D616B91626D946772926772956D769B737A936A6F9B7176986D7592666C9B71739A7274
9B777A9F807F9D827E9D86829B858098847D9A8B83978B849188808A827B8B867D96928A
9C979398928EA49F9C9897959395919A9C9AA2A6A88A8F937B80837C83858F989A798286
8F989D8C969B949DA0B7BBBFC0C3C7B8BDC1B2BABDB4BDC1ADB6BAC6CFD2CAD1D6BEC5CD
B7C1C7B9C4C9CDD6DCCAD3D8BEC8CCC8D7DEAABCCAB5C6CFB7C6D0B7CBD8C5DDEDB4CEE0
B7D1EC3862950B408443729CC1DEEFCCDEE6CFDCE3CFDAE2CFDCE3CEDDE3CEDAE3CCD9E0
CCDBE2CADBE3C6D9E5C2DAE7C4DAE7C6D8E2CAD7E6AEBDD6142C59062250859FB7AEC3CF
90A2B3AABED7152451513C656C112D8A051692000E90000A90010A87050E7C242A9C8183
8287897F8A8C7E8B8C7C8C8D78888B78878B79868A77858878858A738387728185727F85
738085728084717F84728183707E827181866C7F85687D806276796074745F73725C716F
5B706F5A6F70324A5219343F465D645A69674E483C00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF003BA40F3B26220E0F292D2C43695F6A3931420F1131
04083005062B494157634C56694A526E4955724C5A76515D7A535F7F54618558638B5E68
8B606A8F626D9467739469749970799A727A997176976E7390646B94676C9A6E719C7376
9C777B9C7B7C9B817D98837E9A86809B8B829889819B8D869689859187838C847F958E8A
928A87928B88A2A09C92928F9599959BA09E909798838A8C828788888B8C7B7F8294989D
7E8488878F94A5ABB0B5B7BCC4C4C8BABEC2B9BFC4C1C9CDB6BCC0BFC5C9BDC5C7BCC3C9
B4BCC3C0CBD1D6E1E8D8E1EABBC4CDB9C5CFABBBC7C3D2DBBCCBD3C5DAE985A6CC5481B1
8DB3DB48709C285488779EBDC9E0EFC9DDECC9DDEECADBECCFDAEAD1DAE6D1D9E4CED8E1
CCDAE2CAD9E8A8BDD67D9EC1ACC6E5BEC6DFC4BFD7BAAFCB584D74373356AEB6C8C5D5DD
A5B7C48299B13349732322536C325580091D91020E92010A93010C8E030C7D0C159E6A6D
8883867F8C8C7A8A8A798B8D7A898C7C8A8D7C898C7B878B79878A708085738287728183
7281836F7D80738185728081707F806E80836C8082677D7D687B7E6276775C72725A7172
596E70556B6D415A603A5760415A615B6B6A56524900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BB119341C14090722403D537065722D253A030528
01042D0204293D344C644D5867494F6C4A53714D5774515A754E587D525E835561895A66
8A5C688C616D936874926772956B76946E76956F77966C7593656E95686E986F72997274
9C787B9B7B7C9E83819E8A849C8A839E90879A8B85978885998B899388868B828099918D
8E88848C898494938D8F908B90938F9FA5A37C858592999B7F8484919496777A7E95999D
959B9E98A1A2ACB4B8B9BDC0BFC2C5BDC0C5BBC1C7BCC4C8BAC1C4B9C1C4CAD4D5D6DFE2
C5CED5C0C9D2BDC7D0B4C1C9BDC7CFBAC4CCCDDCE6C6DDEFBFD7EBB0C7E0325789174A83
78A1C6A6C5DDB4D3ECC1DDF1C3DCF49CB9DC7186AE908DB1AD93B2AA86A3BC9BB7C9B3C9
D2C9DDD4D5E999A6C6122E623E4C7F563A64692A4F7126446B1D3B611E37826273A8AAB4
8494A23E5469647A9C0F1A4B6245706E0E268E051392010B94010C94010C8D09158A3B40
978586808C897B8B8B798A8B7A898B7B898C7B8B8B7A8A8B77878A75868A748285728383
7483846E7D7F6F7E816F80807082826C7F7E6A7F80697F7D687D7E6378775D7673587271
5A6F71566C6B4E64691A353F415B6358686963615C20960F00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056BB1E4428190E0920585067706273221934020229
01032E0304293A3047644B556B4D506C4D5170505572515777535C7F56617F525F855461
8E5F6C8C5F6B90666F8F6470936874946A75946B75976A759666719568719C73779A7577
A07E809E7F7F9C817F9D87849D8B869D8D88978884988B87948B85918B8788827D918C85
8F8A858884808C8A859693908D8B899B9C9B8186878E9497818589818588818588929699
949B9DA3ADADA9B2B4BAC1C3B9C0C2BABEC3BBC0C6BBC3C6C0C9CBB8C1C5C5CED1D1DADE
C2CBD2C0C8D1B9C3CBCAD6DCD7E2E9C9D3DBC0CFE15F82A4587EA3A6BED890AACA8EB6DE
9FC9F08CB2CF8EAEC4BBD8F26484B230497F614D817C37618623488B1F41841B3F7E2449
874062A26E8CB897B94032634331636B2E55780B2C81041B8204187A081B6B1F2F95828B
BEC9D099ABB8A6B9D02E436B38346268264385071994030F93000B97010C9405127D141D
A0787A8689867F8C8C7B8B8B78878A7B8A8D768889778A8B76888B77878A768587778484
7482837182826F81836D81816E82826C80806D81826D82816B8081657B796077745B7470
586E6D596E6C586C6D243F441F3B43546969626963229C1600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00583620160B1B6F63766E5E6F140C28020329
00012D0201273B2E45664D546A4D4F6C4D5170505672515977545F7E57627D525D825560
865A64895D678D626B8E636C956A74946872966A74956771966570986B749F747A9E767B
9E7A7D9D7D7E9C807E9A8382978382978683968985958D88C4C0BBCAC8C69D9B99888480
908A8687827F8D88859792908B86869796949799998081847C7B817C7C7F90919395989A
9A9FA29EA7A9A9B3B4BBC5C6BBC4C5BEC4C7B6BABDC4CBCDD9E0E3C0C6CEC3CAD1C5CDD3
CAD3D9CAD2D9BBC5CBCFDCE2C2D3E0C2D3E1B5C4D5809CB797B7D5C0D7F0AABFD97295C4
17498A245488A9CDEA99BBDD0F316D60629573284D90112C98081F99081D990C248F0B25
840E2B811B3B7117396E23477D3A5E9745607E0C228B061689010F83020F700816946771
CED0D6C1D1D97B8DA04960820F1A4A664263750A208F021194010C96010C950210820612
9552599286887F888B7A898B7B8A8D7C8B8F748688778B8B758788778789728081778585
7382837183847183867084856C80816E83847084857084837082826A7E7D667C7A5E7672
5C716F5B6F6C596C6B49656529484D4D6A6B5E6C6942382900FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00734A272412176F606E6A5B6C0B0521010327
00032A020225392E43654D54674B4E694C506C4E5570515974545D7A565E7C535C7F545E
875C688A606A895F688F636D9569739468729367719A6C7590616A9669719C7178A1797E
9E787D9F7D809D83819A848095807E9D8B87978B87B3B0ADD5D6D6D4D6D8BEBDC1817D7E
867F7E837D7B8A8582938F8C8A87859291909C9D9A8F8E8E8F8A8D8783868E8F91909397
91969B97A0A2A7B1B2B5BEC0B7BEC0CCD1D5B9BEC1C3C9CCC9D0D3BFC6CCBDC3CAC7CFD3
D9E2E7D9E3E9D0D9E1BFCAD3899BAAABBECBBECCD8B7CCDAAFCFEE89B0D88CB0D73A6193
0E3C80225082BAD9F47597BA0F316B7D729D7919369B0C1F9F0817A10C1B9B0B1C900F1B
84212C7223356C1E386E173378143290243E890D238E07168E03108A010C880C1A7A2C3A
A9959FA1A8B06F7D8A5667821928544538606A193488051792010C93000B93010D8F0513
80222E9E7E8483878A7D8B8F7A8B8D7A898D78888C798A8A778989778889728183738284
7281847081826F80836D81827083836E81836F82827083816E81806E82806B807E667B79
6376765D6F6F57696B476166193640415E625B6C6A47453600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008D5D303F2520705E685A4D6105021E030426
0206280202203F3345654D52694D506A4E526C4F5671555B74565C77555C79535B7E545E
825664875A67895D678B5F698D626C92677097697497697294666E91646A996D739C7478
A17B7E9F7E7EA186839A84809F8A86998782948884B7B4B4D3D5DAD4D5DEAFADB4817C7C
887F7D867D7B847F7B908C898787848989889998989392919492938786888A8C90898D92
8C93978F989BA6AFB1BABFC3B8BDC0C8CDD2BAC0C5C3CACDC4CCCFD3DADED8DDE2C6CED2
CBD6DCBAC9D2C5D0D9BDC6CEBFCBD5D0E3F0CDE3F5B0CBE0466E9B0E4380406F9C7FA1C0
7B9BBDA5C4DECAE1F37D99BB0D2C666C62907B1E3B9A0E219F0A1AA51222970B1B82191F
B98387A189926750664C2A476122456D11307E061E8F09198E02119103109005137A0E1D
8F5E6ABFBCC2BFCAD27D8B9C3F4E73191B486C3A5C7B071D91030F94020D92000B910210
7B0A189A666E8A86897D898D7A8A8E7B8A8C7A888A788789798A8C748589748487768588
7583867483847381847282827584857181826F81817185836D81816E82826E81816B7F7E
66787A5E7273586D6F3D545B0B2531415E625B706D4E524510CB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0046AF1C78594C735D6543374A03011D080722
2D2B4405021A473A496950566B4D506A4C526C4D556F515772525977545D7A535D7D535E
825463885966895A668C606A8D636C936970986B74956771936670946870966B729E777B
9F797BA17E7DA186829E89849F8D889B89849587849B9293BDB9BFB2ADB48A8285837A78
89807B877E7A807B788D8C888B8C888989869795959393948B8D8F86878B878B908A9094
88919497A1A3B9C1C3B8BEC1B8BDC2BABFC5B9C0C4C3CBCEC9D2D4D7E0E3D7E1E4C3CCD1
B8C4CAAAB9C0CDDAE1D4DDE5BBC8D698B3D15A83AD90B4D46E90B4416C9893BCDDA7C7DB
B4CBDCC0D2DFCFDEECA1B8D50F2C6756568B752948931023A30D1FA10C1F9107187A1C25
DCBEC2D5D7DCCCD2E18C92AB3D355A502D556213337A061A8701108E0110920312870917
7C333EC9BABFCAD4DA97A6B2657390101B4757406870142C8F051496020C95010C90010E
850515873C469282847F888A7A888D7C8B8E7A898B7685887384887284886F8283728484
76858676828475808475838579898B7485857183837185846D81826D81836E81816E8382
677C7D5D7274586D6E5267692A4248365052596D6950574A0FCB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049B11B84614E71585C2F2233030219221D2E
584D5A1006174F3F4D644C50694D4E6C4E536E4F576C4D5570505876515C7A535D7E535F
8354618959648B5C678B5F6990656E91666E93676E93666F9268719369729870789D767B
9C75779D7A7A9E837F9C88829D8A879D8A8A9786869183838B7E80887B7B887B78877B75
877D77867D78827C7885807D878581908F8B9797948B8E8D8C8F917F818683888D838B8F
8A91959CA0A6A1A7AAB6BCBFBFC4C9BAC0C5CFD9DAD2DCDEC0CACDCAD3D7CBD4D6C9D2D4
C1CBCDC5D1D6D2E2ECD4E5F3BDCCDF607E9E3260899CC1DCA9C3D9AFD0EF7DA8D55C8AB6
8EB3CBCADFEBD0DDE9C5D9EF2D4B803846817E4D728C162DA10E1EA60F2098091B7E1727
C3A0AAD4D8DFCBD9E0CAD8E4A7B4CE262E59422B576D1F3A860B1E9004129302118F0513
7913209C777E93999E83939B69798C323F652824506E314D80061690010B94000C91010C
8C031079171E9A76798083857B8A8D78888C7586887385877383867385896E8183728585
7786867584857282847184856F81857284857082837386866F81847083856F83846E8583
677B7F6175795B6D6E576B6A536968485E5D5C6D695B625720991100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B81E835D446C55552016270402163F3741
57484D1408135947526B4F556C4F536E51556C5157694C536E4E57714C5779525D7E545F
84576382545E8658638659658D616B92656F94676D94686D946870976D759971789D7479
9F77799C7A799D807D9D85829C8787A08B8D9A898990817F8C7E7B8E7F7B8B7D77867A72
877D76887E79847B77877E7D8B86848B8A87959593898B8B898A8E88888D82848B8A8F94
8D9197979BA09DA4A7B1B9BBBFC3C8B6BABFCAD3D5C5CFD3BBC5CAC0C8CED3DBDFD7E1E4
CFDCDFBDCDD4A5BBCB748DA4B5C6D7AAC0CEB3D4EAB5DBF7ABCFF07BA0CB114083083E7F
79A3C3CCE1ECD1DEE6D1E1F06682AC152D6C735F8C76173296091CA20D1C98081B830E22
945A6ADBD5DECDDBE1CBD9E1CCDBEA6B7E9F1E295C6E456C780E268F0615940111960414
83071785454D9E989CC3D0D3A3B3BF5E6D8A0D144268486D6E0D218A031091000B92000B
91020D7F07109252588E83867D888B76878977888B74868974858875888C73868A738588
7485866F80846C7F816C81826E82837083856C7F81708385748487738585708585708885
6C7F8364777B5F7172596D6C586D6B576B695F706D5E6661356B2100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002DDE108C6444604B49130C1B08051652454B
5342441B0D15634B566D4E556A4C516C4F536D4E556B4B53714F58734F5977525D7D5560
7C515D845664875867895A688D5F6A90646D90646C93666C94686E986C72976D72997072
9D75769F797A9E7D7B9D837F9C88869E8B899989858D7E798E80798F817C8D8078857A71
877D768A807C857B7A837A7A8781828E8B8B8F8F8E88898C84858A888990878990899093
8C94979BA3A59BA4A6C3CDCFD4DCE0BBC0C6C2C8CCC2C9CDCDD6DBC3CBD1CDD7DFD0DFE6
C5D5DBB6C6CEA5B8C6A1B9CCD0E2F1C3D6E19FBBD6356498285B97739CCC395E92385F8C
B0CDE3D1E0EBD1DEE6D0DFE9B0C3E219346D575D907333528F12259E0B1D9704188E0B1E
792032C9AEBAD0D8DFCDDAE2CAD9E1B6C7DC25386744396C6E1D3F88061C960215970415
8A0314731926A68C93C9D0D4BCC9D46F7D951B295240386368244080071790010D93000B
92010B8A050F7F252D9A7F837D82857B888C78858B77868D74878B7084877285896F8185
6E80846E81877084886D81826E82826D80836C80826D81837282867184866F84846E8685
7083856B7D806476785E72725C7070586D6B5D706E606B69433A2C00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008E65405D46430C051219121F5A4B4E
50404124131B664B566B4B516B4C526D4E556C4A536E4B54734E57734F5877525C7B555F
8057628257648457658457628B60688E646C90666F92676E91676C946B6F956C70996F72
9F77799D787A947472967C7899837F9B888499878396868091827C8F837D8A8078857B75
887D788B817D8A807E847B7A85807E8D8A898C8C8C88898B838589878B908A8F93858D90
90999BA7B1B29CA6A9A6B0B6B0BAC0B3BBC2BCC2C6CFD5DAD7DFE4CDD7DDC2CED79CAEB7
C2D3DAC6D6DCBDCAD4C0D4E7AFCDEAABCBE883A0C418447B24548F98C0E48EABC2BFD7E8
CEDFE8D3E0E8D2DFE7D1DEE8CFE0F44C69951F37717F648B841E3595071A9D071A9B0B1D
7F0A1D905764D9D4DCCFD9E1CCD8E0CEDBEA66779E19205B62315E7D0925930418950113
9002127B08178D5562949198919EA67C8A9B3C4D6F131A466B4464710A1D8C030E910009
93000A8F030C790C1598696D8885867F8A8D7E898E78868C74858975888775888C738689
7385896F82876E82866F83847183856D81836C7F837082867181877284896D83836E8685
72868670828466787C6376775F72725B706D687B7B6170704A463A00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009A6F46533E390A030F2A202A604D4E
453436322027664A4F6E4E516B4C516C4D546D4B526F4C53734F5777555D74525A78555E
7D58617F58627E5660835A63885E668D636B90666F9268718E656C90676D976F72997174
A1797C9C787A937272997D7B9E88859A86849E8B899583809587819086808B827C8A807B
897F7A867E7887807B87807D837F7C8A8787918F918A8B8C898B8D878B8F8F94998F9398
9AA2A5A5B0B298A4A5A5AFB3B6C1C6D3DDE0C4CDD0C5CBD1C0C8D0BEC6CEC4CED5BAC9D0
CEE2E8CFE3EACBDBE69BB2CC28518347739FA8C5E283A5C79AC6EE9CC8EF89ADC7C6DDE7
D0DDE5D4E1E8D3DFE8D3DFE8D0DFEC9AB3D213336D5E61917B334F9612269C06189C0918
8D0717701625C9ADB7D3D7DECCD6E0CBD8E5B0BEDA1F31674F3F7570193A8D071D950112
9501118C06167A23318C777EBFC9CFC0D0D96E809912214C55456C68172E88041393010B
94010B92020B860611883E4295848381898A7D888D79868B7A898C788A8C74868A718586
7386897184886F82866F82857382857486856D80826F82866C7E857386896E83836E8382
708484708283677B7B6477766679775F74726B807E6A7C7D4F514A0FCA0700FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00719032412D2807010C3D3035644D4B
3B2729422B2F6B4C4D6E4C4D6B4B4F6C4C516E4E546F4D5474535B74555C74555C78575E
7A535B805A627A556076515B845A658A5F688E636D9066708E646C8C6269926A6C987173
9772749C787B916F729C7F8098807F9D88869B88869483809A8C86958B839189828C827D
8B827C837D7687837D868481817E7F8683838C89898A898A878A8D858C90A5ABB0909399
8F979B8A96999EACACA7B3B3B5BFC3D3DEE3BCC5CAC3C8D0BABFC9D1D9DFD4DCE1BECBD4
AFC7D89CB8CEB5CBDEA6BAD05271978EB3D9C5E5FD89A9C93F6FA30F44883D6D9AC7E2F2
D0DFE9D2E0E8D2DEE7D3E0E8D1DEE7CADDF03A5B892B41788F698B85162C9C0D209C0A19
990B19850E1E9D5E6CDDD3DCCED5DECAD7E1CAD9ED5B709A232963703C65800A23940214
9A03119404137B0A1A90606AB4B4BDC2D1DB899AAE35496E2225536D39567F081B92010F
97010C97010D8F040F7A161C9D797C8485877E888C78868976858875888A7386886B7E7F
6F82847184877082866E81856D80837284846F82827082866F82887085886E83846E8282
7386866E8381687F7C607674657A786279776A827F687D7D575E581D960E00FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004FBA2937251C08030A493B3E604B48
301C1E533C406848486C4A4A6B4B4E6E4E536A494F6E4D5471525972525B73515C78545C
7A525A7C555F6D4A566C4A567B5561875D688C616B8F646E8E626A8E626891676B926A6D
946F719C797B9373759C7F809B83829F8A889784839A8B889A8D89948B85948C878D8380
918784857F7A87827F87848285828282807D8888868B8D917F87916975808B959B92989B
929A9D98A4A6D3E0E1C0CBCFA5AEB6A3ACB3B3BDC2BBC4C9B3BBC1D5DFE4D5E0E5C6D5DE
738A9F4E6C85AEC5D8CADBE7B1C7DD84A7D35D89BE719BC92C588F0B3D7C4C79A2C9E3F3
D0DFE9D4E0E8D2DEE6D4DFE8D2DDE6D1E0EB85A0BF133066746C95792942910E209A0C1B
9B0A1B960E20832237D3B3C0D3D5DFC9D7E0C9D8E79FB4D016295F5846777115348F0519
97011095010F8705138536428F7D87848E998294A15C708C0F1E4D6751766E11288E0515
96020E96010D94030F7E091193585D8B84867E898C79898B75868776898B7588896C7E7F
7382857282847385886F83856B7F816C80806D807F6F82836E81846F84876F8486708584
7085836C8280667E7B647A77607674607977728C89778C8B5F6A641F9B1400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C12E3520150E070C5142415E4A45
2716175B4648664B496749486A4B4E69494E6B4C516D4E53704F5875505C785260764F5B
7A535C77515C6F4F5B72525F7A5460855B658A5D6792636C9161698F5F66906368946A6C
9A72739B7878907271947B7A9C888695828094827F978884998D8898918A98918B918583
9186838A84808C87858C8786878281868381828384878F98516072687887828E94A4ADAF
9BA3A78C969BB0BBC29EA9B1A3ADB3A8B2B5D2DCDED6DEE2C0C8CFAAB8BFB6C6CBC5D5DA
B5C6D0B6CBDBC9E1F2C8E0F59EB8D61C457D0A3C84628FBF94B6D87D9FBCB6D5E5CFE4EB
D4E0E8D4DFE7D4DFE8D3DFE7D3DEE5D1DEE7C5D6EB2D4A784655877A4F6F8111278F0515
990819960818830B1F9C606FDBD4DCCCD6DFC7D7E3C4D5E84D648E252A61703A5F810921
90011093010B8D030F77101C936B75A1A6AEBFD1D99BAEC12A3E653A38636C2B4884081D
92011193010F93010D87060F7F2D349B83887F858A78898A778A8975898A738686738585
75858876878778878A7083867084866F83827183846E82826C7F836F83867285876D8381
6E84826E8382677F7C647B785F77736078756F88857A908E63716C346E2400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0061C83340271A190D0F5946435F4944
2616165D4D4D644D4F62484C67484F6A4B516C4D526D4D55714E57754E5A78505F784F5D
7A515D7D55626F4A566F4B568058618659638D5E6791636B8F5F698B5B648F646A956C6E
9A74759E7B7B937574997F7F97817E93807B93837C94858090857F99958C9A958D938785
8A807D8B8480918B8A958D8F8D8587807D7E7F81886B7A8C394F647B8A988D969DC8D0D3
B1B8BD8E969C8A939BAFBAC0C1CBCEABB5B7C7D2D6CAD5DBB6C1C8AAB9C1C2D4DBD0E0E6
C5D4DEA9C0D46E91B54673A38BB1D65E81AA4B72A59FC9EEB8D7F19EB7C4CFE2E8D2E1E6
D5E1E8D2DFE7D2DFE7D1E0E7D1DFE5CFDDE5D0DEEC748DAF132F67625886711A38890618
960515980717910B1A761B2BD2B5BFD1D5DDC7D5E0C7D7E59DB1D11225595945736C122E
8B051692010E90010F7E051383434E948D94BAC9D1A6B7C45A6C8C131C486B476A760D24
8F031492011091010D89040D720D179F727883848979878976898A778B8D75898B728688
75888A7286857384876E80837285867084837084857186876E81856F81847082846D8180
7084846F84846A7F80667D7D6076756279776E85847A8E9067767447413500FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0031E3174D2E1A251512604A43604640
3925234C3A3D5B464F3B242F5E444C694A516B4C536C4D5370505874515B744F5B744C59
784F5B8258638156617E545E7F545C8659618C5E6792636E91626D8C60698F666C977174
9A75779F7C7E9B7C7D987D7D947A798F7A768E7C769A8B849B92899B988F99938F948B89
89807D8B84818985828A8484878283828084788390324761667A8F89959E929A9E9AA2A5
989EA391979C8E979BD0DBDFD6DFE4ABB5BBA5B3B8B1C0C4C8D6DAC0CFD6BBCED9C8DDEB
BDD1E1A5BDD54266911F508597C1E2B5D3EC81A3CC4875AF3A659A95B5CFCDE0EAD2E0E7
D2DFE7D2E0E7D2DFE7D1DFE6D2E0E7D1DDE5D3DFEABDD2E82340732F3B71713D5D841025
920415940311960714871020A56A77D9D2DACAD6DFC6D6E38DA0B9364B762C2D5D6C3150
80091B90021091010D880410731A2497778080868D8D9BA58090A61A2B53504770681B33
88061790000E91010D8C020D79051188464E8B83857D8A8A78888C788B90788B8F738789
75898A7587877385877386887082857184866C7F826D80826F83847083857384866E7F7F
6D7F81697D7F687C7E6A7D7E66797A6176756C80837B8D926D7A7C53504600FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00563316331D18624A3F63483D
5C423D462F332B18233D283260484D674B4E6D4F536E4F556C4E536E4F5671505974535A
7E5F66A2848A83606B825864805360845964895F688F656E9267718B616A8E656D936E75
9672779D797E9D7B7E9576779073728F7773907D769588809D938A99928B9C9693918A88
88807E8F8A868884808C88848884857E838A51637D1E385698AABA959EA4929A9F919B9E
B3BABDCED2D699A0A6A8B2B9B9C3CAA6AFB6A6B1B8BFCDD1D2E0E4C6D6DF92A9BB4B6B83
A5C2D3BFD7E49DB7CD90B6D8ABD5F99FC6EA476DA10938870737807A9FC1CDE2EDD2E0E7
D2DFE7CFDEE5D3DFE8D2DDE6D2DDE6D1DDE4CFDCE3CCDFEC6881A510295E725F876C132C
880619920311990714930A1A7E2032D8B8C4D2D3DDD0D7E7717891979CBF312B557F4E6C
7B0E238F021193010D8D020D7707138E5961858185C6D2D6BDCDDC455A7D2229586D3B5A
7E0B208E010F91010B8E010B82030F721B2393787C7F868778898B788B8E788A8D76898B
75878A78878978898D74878974868A728286718386728486718483708385748386708181
6E8081687F7D687D7C6B7D7E6B7C7C65787A6A7E817B8E92738184585A530FCA0700FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00643B1841251A664B3D684C3D
6A4D444E373638252A5D494E5E464A694D526C4D526E50556D4F546D4C526F4E566B5258
A99A9ECBBFC4A089947B5365835566875B69845B668C636B9168708E656E8D656D97717A
98747B9D787F9572768C6B6C8D6E6E8C726E927F799887829E918B958B869B9390938B8B
8D86838883808C86838F8885868284767D8E182F51435A7782909B8991958F969B99A2A7
B8C2C5D1DAE09DA6AE87919AB6C1C7D3DCE2C5CED7A2AEB9B8C7D2A3B3BD9AAFBE7794A8
BFDDEAC9E2EDBFD7E75F83A921508E1C4D88769DCA294F854970A0B4D1E8D0E1EAD0E0E7
D1DFE6D0DFE6D2DEE6D2DCE5D1DDE4D0DDE4CEDDE3CCDDE6B3C7DE193362373D6F62304F
76081C8E0414960412940312850A1EA35266B37F97A475938655788D547889486B963F59
880D2191021194020D91020E810715925058ADA1A8A3AFB7AEBFCC6A8099172753685378
6C0F2889041390010C90010A8B020D74070F8F595E8883847D8A8C798B8D798B8D798B8D
76868B73838975848B76878C7584887281837283857587887284866F83856F82846E8282
6C807F69817E6C807F697C7B687B7C677B7C6D8285788C8D78898C5B635F219B1400FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075461C4B2A1E6C50416C4F3E
6B4D425C413F45333A362832463339664C517051566B4B506D4D53704E55714F58675059
B4ACB2C6C1C8A18E9C81596D865569875768865B688F64718D626E8A616B8C676E936E75
9872799C747B8F696F8B696B8F706F8F75738F7C799988879A8C8A938783968C898E8583
89837F86817C8D89858F8B8888898F505D7A132B516C7F96869096A3ABAED0D8DD9FA8AF
9DA5ACA2ABB2ADB7BF9DA7B0AFBCC4D3DFE7B8C3CF8897A47C8D99C8D8E0CBDAE2A1B6C6
A4C4E197BCDD92B5D64C709C0A377A21528BB4D8F788A9C87195B2C9E1EFD2DFE8D3E1E7
D1DFE7D0DEE4D4DFE7D4DFE8D2DDE4D1DEE5CEDDE4CDDCE4CCDDEC677F9F1228595D527A
631933820A1D9309189204148E0617870C2280112D80123282113384113089122D880B1E
8C07178D08128F09138908117E0D19753540998D967B858F818F9B8D9EAF33476B3B3C65
6B2A4781061990011092010D8E010C8305107E2E36978384808A8B778A8C77898B7D8F90
7A8D8F76898E79888F7A888E788689758486748387708284697C7D6E82836D82826D8283
6E82826F82816A7B7B687D7B6A7F8064787B697E81778B8C74878A5F6B69209D1800FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00299101522E1F6E51456C4D3F
6D4C41684A491F101827212E4F424B634C4F6B4D506B4B506A49506E4C546F4E56684F58
A2939EC3B4C285697C82566A855565885867895B6B8B60718B606E8B626B8A646B926E73
956E749A7178946C728F6C6D927573917977917E7F928283968A89998F8C968C88908681
8C857E88857D8988839090907A8396172E56324B6F8594A38A929899A1A8B1BAC39BA3AD
99A0A8B6C0C5D4DFE5C8D5E082909C9AA9B399A7B09CAAB38E9FA9CDE0E9CEDFEA8EA4BF
274E800E3F795A87B4B1D1F05B7FA889B4E393BBE75E88B64F7897CBE3F0D3E0E9D3E0E6
D4E0E8D4DFE5D3DFE8D0DFE6D2DEE5D0DDE4D0DEE5D0DEE5CDDBE5C4D5E5556B8C2C3B61
5A44626520337718247E161F8018207B1720801F2C7C1F2D7C2130802A3981303B873539
83323883383C81383B7D383A783D44856A71A7A8AE87919A9FACB5C5D3E07E90AD16234E
704A6E770B228D021491000D8F010B89030E740F17956D7183868878898C78888B7E8F8F
70828478898E78899077888D78898B77888B74858A7285876D81816E82826E83836C8183
6D7F83728184707F7F6D807F6B7F7F697D7D6B80816E84856F83845F6D6C453C3100FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00369D08532E1C6E5142684B3A
6C4B3F6B4C482E1B21180F1B261B24654E526B4C4E69494C67464C6A49526E4B546E4A57
7353617C5C6E7D5769805665865863885866895D6D865F7085626E855F67845E66946F76
9A7578956D718D6568906D6D917371977D7D9C87899585869B8D8C9C918F9A908B938984
9189828C87828D8B89959AA34A5D7F092957627C98C3CFD69BA1A58C939A8D959DB6BFC6
ACB5BDA0AAB3C4CFD9A4B0BC77879292A1AACFDDE4D2E0E6A3B4C0869FB38CA7BB94ADC3
47688D3F659198BCE1C6E4FE9BBBDC2C5892083C881D55919EC6E4CBE1ECD2E2E9D1DFE6
D5E2EAD3DFE6D1E0E7D1E0E7D2DEE6D1DEE6D1DEE6D1DEE5D0DBE4CFDBE4C7D6E597ABBF
6C798C776E7A927579906C6E90696C9874759C7D7EA1888AA9939B6D6273827B8A9E969A
9B9094928C918C898EACA7A99B9A9F929EA7C4D5DEB9C9D48A99A5B0C0CD899BB421345C
4E40686A193588051990010D90000A8C020C7C051086474C8C85847A89897B8A8F7B8B8E
7A8B8D7D8D917B8D92788A8F7A8B8F76888B72858974888A7185877488897286876D8284
7284866F80837081836A7E7E6D82816B807E667C7A6D82827386876470704B453D00FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A8105129146D513D6B4F3B
6C4A3E6B494260464643323B3A2C35654F53684A4B66464A66464C68454E6C46536D4551
71495579505E7C505E7E535E8256628459677D59686E536264505C6F58627F6067946F74
9A72769A7276936B6D957071917070957A79937F7F8473749788869A8D8A978C88978D8A
9289878F8887918F92858FA4102D5D193B6A7990A49CA6AB8C9295898E939DA5ABD4DDE5
C7D2DC87939F8C98A3ACB8C1BBC8CF9DAEB6C2D3DCC0CFDA9AABBC46647C7290A8CCE3F2
B3C8DD87A1C1799BCA537BB2709ACA204D8A073986376CA2BEE0F6CEE1EAD1DFE8D1E0E7
D1DFE7D2E0E8D1E0E7D0DFE6D2DEE7D2DFE7D0DDE5D0DDE3D4DDE5CFDBE2CCDBE3C6DBE0
C6DCE1C7D7DBCBD4D6CBD0D1CCD0D1CBD2D4CDD5D7CCD8D9BFCBD66B8299617E997992A6
9FB1BD6F8397617990C0D4DFBACDD78194A3A5BACAA3B7C57B8A977787938EA0AF586C8A
2227536933558008208F021092010D90010B890510772025967C7D80898A7E8E91798B8F
7B8E907B8E8F778A8B798B8D778A8E76898C74868A71848872858976898A728587738688
7486867185846F83836A81806D83826F85856D828270848576878B69757654504900FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B51951280B6B4E3A6C4D3C
6C493C6C48416347472C1B252E1F2C5F484D6A4C4D67474B67454C67444D6B45526C424F
7349547C4F5C80525E825662815763765160614453634E5C5B4C5A50434F6C57608A6A72
977078926770946A6F926B6F917274947A799985838C7C7A988A87988E8999918C958E8A
97918E9893938F919D4C5D840A2B673E5C8795A4B399A1A5B4BDBDBEC5C98C949DA2AEB7
8E9BA48A969F8B98A0CEDCE3D1DFE5A0B0BA8294A29FAEBAC2CFDC98ACC09DB9D2BEDAF4
A2BCDA7595BC15407E083D886495C892B8E0537DB279A8D2C2E1F3CDE0E9D2E1E9D1E0E7
CFE1E6D1E0E6D2DFE7CFDDE3D1DEE6D1DFE7CFDDE5D0DEE4D1DDE6CCDAE3CBDBE3C8DAE0
C7DAE0CBDBDFCFDAE0CED9DDCBD8DCC7D7DCC7DADFC7D8DEBFD0DC728AA523447234557F
B8D3EA6A839C344C6BA0B7C8B3C6D48395A47082929DAFBAA5B2BB818F98C2D2DCA9BBD1
19275361436B770F2A91051795010E92010A8D020E770A1296646A8787898090917D8F91
7B8E907A8D8D7A8B8B738685788C8C7B8E916F818477898C73858875868876888B76888A
7183857085856C81816A807E6E828371868973888A718586788A8E6C797B5B5B561F950F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005B2F056848346C4D3D
704D3F6B473E55383919050F39262F61464C6B4A4C6C484C6A464D6A434C683F4C704652
754C57784D5A7F525F7F55617C58656043516C5260785F6B75616C594E59544653826874
916B768F646E936A73906D758A6F758C767A968483988986938883938B85948D88958F8C
98938F9B999A858FA6142C640629666B86A69AA5B09FA6A9C8D0D3C3CCD2919AA4808B95
BCC8CECED9DF98A3ACA6B5BFABB9C3909EA9758690C0D0D9D3DFEABDCBE06A87AF2A5588
618DB69FC7E94972A02D5D9497C6EEA1CAEE5D87B4306089C1DFF1CDDFE7D1E0E7D1E0E7
D2E1E7D2E1E7D3E0E8D1DCE5D5DEE8D1DFE6CFDEE5CDDDE5CCDDE7CBDCE6CDDCE5CBD9E0
CEDAE3CED9E1CDD7DFCDD7DFCCD7E0CAD7E0CBD9E3CCD6E2C9D1E2939FBE182B6113275C
97A6C5B8C2D79699B2898CA09DA2B3B7BBCB8E91A3CACADAD3D1E1A1A0B1A9A6B8ADABC3
4C4B7150375C791F3A8E051997010F95010D91010D860612883A459785898890937E8D8F
7F8D938190928392937C908E7A8D8D7F91936D8083798C8E728485768A8A758989768989
7285866F84866C82836B82826B818273878A6D808473868876888B6D7D7F5A615C219B15
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B3B0C67472E6E503D
6F4F3E6C483D5A3A354327286245456847476B49496A47496A454B6D444D6C424D69414C
754D58794F5B7C525F79505C70515C5A44507359667E626E7B66716155614D4351796471
8B69738E677086616C7B5D67775F69806B748E7C7E988887968A879A908B988F8A928B86
95918C9A9DA257698B062665193B6F90A7BABFCACEA2A7ABA9AFB4959FA5A1ABB287939B
C8D5DCD3DFE79DABB68495A1A5B5BED1DDE4BDC9D38E9FAEA8BBD09AAEC65977A10D3A74
5E8CB6C2E8FFB1D1EB6D95C24274B1356CA86091C05D88A8CAE3EFD0E0E6D3E1E8D4E0E8
D4E0E8D2DFE7D3E0E8D2DEE6D2DDE7CFDEE4D1DFE5CCDEE9C3DAEEC3DBEFCDDAE9D2D8E5
D4D3E2D8D2E3D4C8DDD2C3DAC8B5D0C6AFCBC2A7C4BE9DB9BD95B6AE83A96F447170436E
8957798953708E506F8A4A68915370955976874869904E6E9A57788C4869874262884563
8543628C415F92223C91021698021194010C93010E8F04107F121FA76E75977F8790858D
8D868F87888D828A8C7C8C8B7D8E907D8F9274878B778C8D798D8D798E8D788D8E738988
73888972898B6D8685677F7F6B8282748A8C5C6E727284877B8D907082845C6865336C23
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00834D166844266C4D38
6C4D3B6C4C3D6B483C67443C6946416C4A446B4B4767474768454969434B6B444E6C454F
764E597B515D7C525E79545E614651604C58755D6A7A616E72626C5E576147414D75626E
8B6A748A656E7E5C659070798C72797D676E927D80968383958685998E8B9C928E8E8782
8F8B898C93A2223A6C0326693958839CADB9B3BCBEA9AFB3A1A7ABB7C0C4D4DDE2ABB8BF
8A98A2A0ADB4AAB9C196A5B0AFBDC8D1DDE7BDCBD87990A843617EB5CFE7B9D2EC6C8EB4
9AC4EB9EC7EA96BCE0406B9F073E920C489495C3E9BCDAEBCFE0E8D3E1E8D5E1E9D6E0E9
D6DFE8D4DFE7D3DEE5D1DEE5D2E0E6D1DFE4D2DFE7BED3E24667905D7DAC979BBE8E6D8D
955B7D934E6F883B5E8631547A22447E21447E1C41811A3E84173D7E0E347F0B2E810B29
8109258509268808268807248808258807278C0A2A8C09288D08298D09278B0724890721
8B08218B071D93041998021496011092010B93010E91020C8D0614841523822637853548
843E51854D5B87666F8A888A7E8C8E798C8E76898D768B8C798B8D7A8E91788C8F758A8C
74898B73888A6E84846F83836F838375898A65787A697D7F7D9193708486637071474035
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DA1086A4221704F3B
714F406C4B3C6C493B6A463B67433B6846406748446748486846496A454B6A464E6B4851
734D5779505B7B515B7A565F58414C584A556A5A656B5C66665F6854535C47424C79666F
88656D89626A83626891737890767A7E686C957E83937E82958585968C899B938E948D88
979799667391032162163A7D6883A7A2ADB7A3A9ACB7BBBFA2A8AEB7C0C7CCD6DCA4AFB7
8D98A1B1BCC2D5E1E7C5D2DC94A2AF93A4B099ABB58EA6B754748AC2DBEECCE0F295B4D7
2857940E45894275AF83AEDB2251923A70B1A1CEF3C9E2F3D1E1E9D2E1E8D2E0E8D4E0E9
D3DFE7D5E1E7D4DFE5D2DFE5D1DFE5D1DDE3D1DFE7CADEEF4869951035747170A367244B
871538971836930E2B971029950F258F0C208F0A208C0A1F8C0B1F8E0D218D0B1F8B091A
8F0C1D900D1C8C08198D0B1B8A081A89091B8809198709188A08188C0B188A09178A0916
8C09168E0B178F08178F08168D06148B06118C05118C05108A030F8A04128C05178A061A
86071A7F0B1E6B142296777B858C8E7B8E927B8E92788C8D788B8C72868875898C73878B
768A8E768A8B7084857084837385857589897286876C8183758D8E798F906C7C7D4C4A41
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047A90C72441F724D3A
7551446E4C3D6A49396C483B69443B67453F69484666474667474A6A474D69474D6C4A51
714D5676505A79505A78546057414D4D44505A54605C57625858624A4B56524853836771
8C656D8861698261688C7074816A6D867076947B83957F859786889A8D8B9A918C97918D
8B8F98293D6A03236D1232708DA0BCA8ADB4B2B5B8D6DBE0BEC5CE9AA3AE909BA4B8C3CA
B6C0C8A5B2BBC7D4DEB2C0CB8A9BA97C8F9BCADDE4CFE2EA9DB3C394AEC698B3CD85A5CB
184687073E8B376CAABDE3FF97BAE64C7CB92A5B93B1D3EDCFE2ECD4E2EAD2E1E8D2E1E8
D3E2E8D2E1E6D2E0E6D2E0E6D1DEE4D1DEE6D0DFE8CEDEEB9BB4D4153A7455649A6C3E5C
7E1A2E8C19268C18238E1E26861D2781202880232F7A232D81303881333B883C438C4348
8A434889464F8B485386434A89474E84464D86494F85464C84454987484B834247844147
864145864043873E42843B4181363C7C30367C2932792429741B1E75171B7710167B0F15
820E17800C176E0C1883565B8B8C8F788A8C7D90937B8E8F748789758A8B73878A778A8E
75888C73868970848672868770848474888872878973898C71888C768E91758989585C55
0ECA0700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B211724219724C39
744F42714F406A49396E4A3E69463B63423A67474566484863464863464967484B6B4A51
6E4A53714D54764F5A734F5E634958463C4B4A48564F4D5B51505C4C48546B5865896572
8B616B8C636B7F5B62795B608266698D7578937D81947F83978587968888988E8D999596
767F960B225E02206C2B4477A5B0C4B3B5BAABADB2BEC2CAA4ABB59DA5AF9FABB4D2DDE5
D1DDE58D9DA890A0AAB4C1C9B3C1CB8D9DAABDD0DCC5D7E47E94AB35587F4C749BC3E2FE
86A6CF4972A8699AD277A5D78DB7E71545841A4C8EB3D4F3CEE1ECD3E0E9D4E1E9D3E1E8
D2DEE4D4E0E8D2E0E7D1E0E7D2DFE5D0E0E6CEDFE7CEDFE7C9DCF143658E28497879768E
7C545F936064986869986E709874779F8286A68F92A79496B8A6AAA89A9EADA4ABA6A5AB
B2B2BB7E849A6E7791ADB2BCAAAAAE83858985878C888689888789828183ACACAEA6A4A6
8D888AB3AEAEA89FA1928A8C8E85878F8587998B8D928180957E7E9277748D6B698E6462
8C5A5B814B4E6F3E42745D5C848B8A798C8C7A8D8F7B8F90788B8F768C8D6A7F8174888A
788B9074888B6C8086697D816E818372878772878974898B73878C73898E788E915D6562
1F981400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774618704B36
724F426E4C3F6C4A3D6C483B6F4C3F68473D6545426648476246476146486446496A4950
704D55754E57764D5A77505E7353614E3C4A48404D4B44515C535F675A65856D788E6976
8F68738F676F8E696D8E6B6D947575937777957E7F958183908080958A889A94928F8F9A
46537A051E67031F6B50648FC1CBD8C7CBD0A6AAAF9FA3A9C4CAD0C5CED494A0A9B0BDC8
9FABB692A0AB92A1AAD0DDE3D5E1EAA3B4C27D94A493AABBAFC5DA46678B4F779CC1E2FA
A9C6DF7FA2CC1C4C900B4494598FCB517DAC426792C4DEF2CFE1EAD3E1E8D4E1E8D4E1E7
D3DEE3D4DFE7D5E0E9D2DFE7D3E0E6CFDFE2D0E0E6CFE0E7CBDCE9A9C4D87E9DB69CADBA
B0B6BCBEC0C1BEC2C3C4CACCC6CFD2C7D3D6C9D6D8CAD7D9CDD8DECDD8E18598B0527396
B1D0EF3455821236688BA9C2B4C7D28D9FA781949A9FB0B3B5C5C88D9FA5BFD0D9BFD1D7
8999A2A2B2B89FADB3919DA297A4A78E9B9D909EA28896978E969A8C97978891908D9392
909294888B8C8285877D84827C8B8B788C8D7A8D90798D8F7A8E92758D8E73878C74888C
768B8F72878A6E8286677B7E697D7F6E828274898A768B8D73878C728A8D758A8D5F696A
31682100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C4A16745035
7151406F50406B493E6C493E6D4B4068463E64433E64454262444464474A66454B6A4750
6C4750714854764B597C53607E586571535E5C45506A576179646E8870798F707893707B
8F6A758E69718E6A6D9674749876799173748F7776998683988A86978F8A9A97978E93A7
1629600220720B2E726B83A1919CA3A6AEB1AAB1B4A9AEB3D3DBDFD1DAE09BA5AF8A95A0
B1BDC5CCDAE1A7B5C0B0C0CBB4C4D19FB3C15772859DB8C8CCE0EEBED5EB6D8FB4608AB4
8BB6DD76A2CD114288064095528BC6AED5EEB2CCDFD0E3EDD3E2E9D3E0E6D4E2E8D4E1E7
D4E0E5D3DFE5D3DFE8D3E0E8D2E1E7D2E1E5D3DFE5D3E1E6CCDAE3CADEE5CCDFE7CADDE1
CDDCE0CDDCE0CCDADFCDDCE2CBDBE1CCDCE1CBDBE1CCDDE2CDDCE4CDDDEA89A2C50E3874
7198C97697BF4C6D95819FB9A0B7C6B6CCD68DA6B0B3C8D0C5D7E09EB1BD9AACB9ADBEC9
97A6B199AAB4A6B5BDA6B5BB9FADB4B6C6CC92A2A991A0A78B99A18C9EA28A9B9F8FA0A3
87969C80909885959C8090927C8D9074898C788D90798D9175888C778C8F74878D758A8D
71898B728989718689667B7C6A7E806C808173878B768A8D71858B72888D7A8D93677375
443D3400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00825117745030
72533E7051406D4C406D4B416B4A416B4A4166453E67464266474667484C65444C6B4853
69444F724755794D5D7F536480556480596682616A886A718F707790707894707B98727F
936D79936E768F6B7198767A98767C97787C987F7F978582998D889B928E9C979C727B99
061D6104267A1F44818399B1929B9FB8BFC1D2D9DDABAEB6A7ABB5A1AAB3AAB3BC8E98A0
C8D6DBD3E0E9AEBCCA94A6B4AFBFCACCDDE6A8BCCC87A0B3ADC6D796AFC5426693083B7E
4579AFB4E2FF83ACD84C7BBB4578B77FAFD9BAD9EED1E3ECD4E1E9D3E0E7D3E2E8D6E3E9
D2DFE5D4E1E7D3E0E8D4E2E9D2E0E7D2E1E8D4E1E7D3E0E5D2E0E7CFDEE5D0DFE6CCDDE3
CDDDE4CCDEE2CFDEE6CCDDE4CFDDE6CDDDE3D1E0E7D0DFE6CEDDE5CCDDEAAEC6E2315687
779EC99BBAD2B4D1E881A6C3A7C8DFC1DEEC748FA294AABABACAD89AA8B698A5B1ABB6C0
B5C2CBAEBBC6C4D2DCC2D1DA9BACB5A5B8BF92A5AC93A4AB97A7AF95A6AD8E9FA78C9DA4
85959E80919984959C899B9E84979B7B8F93758A8E778C8F77898F778A8E70828972858A
71878A718788708487697D7F697C8162757A6C80856C808472868A71858A788B906F7E80
48463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C5A1A74502C
71533C7053426E4E3F6E4C416E4D436E4F466A4A456848466A4A4C68494E694950694952
6A4651734A58794E5F7B4F627E51648459678A636B8F6C728F6D74926F78926F7B967380
99768198747C96737A9B797F9A787E9B7C819981839D8C8BA093919B91919996A0394671
031C6C01207727447B9AA7BB9EA1A7B5BBC0D0D7DDA7A9B19FA1AABBC2C9D3DCE3B2BDC4
9DADB49DADB6A6B4BF8F9FACAEBEC9D3E1EBB8C8D9728BA6597A9AACCCE67593B91A447C
5E8BBBB7DDFAADCCED648BC30131841E5BA49DC9EBCBE2F0D3E2EBD4E1E9D5E3EAD5E2EA
D4E1E8D3E1E8D7E4EAD5E2E8D5E3E9D4E1E9D5E3EBD2E1E8D1E1E8CFDFE6CFDFE7CEDFE7
CFE0E8D0E0E9D1DFE8CEDFE8D0DEE7D1E0E7D3E2E9D1E0E7CDDEE6CDDDE8C2D8EC9BC1E9
70A0D1A1CCEE9EC5E42255866090B8B0D1E798B2C69FB2C1B1BECBC0CAD4AFB9C3BDC9D1
C7D5DDB3BECBB8C4D1B3C1CF99A9B6A1B3BDA3B5BD9EAFB696A8B293A4AD91A2AB93A2AB
8B9CA48C9EA48C9EA3889B9F7183896F8388788C92819498899AA17D909474878E6F8388
6A8083687E806A7D826A7D8166797E5063695B7177617A7E667E8170848971858A708183
51544C0FCA0700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A60A744E27
6D51386F55406E513E7050416F50457053496E514B6F524F6D50516A4C50694B506F4F56
6947506D4753744D5A79505F7E5364855B688D646F906B75926E78906B7794707C977580
98767E9B767F9C787F9E7F83A081859E8184A0888B9E8D8E9C8F909D94988C90A5162863
011C7502207348608ECBD4E1AFB2B79DA1A6A7ADB2B6BAC0A3A8AFBAC3CBD1DDE6A8B5BE
9AA9B1A6B8BFD1E1E8C8D8E37D909E92A4B296A6B86882A1183E659ABBD8C9E1F897B5DA
6E99CB6090C493C1EF5B89BE0A3E8E1856A197C5E9CCE4F2D2E1EAD5E3EBD5E2EAD7E4EC
D7E3EBD6E4EAD7E4EAD6E5EAD6E5ECD5E2E9D6E3ECD6E4EBD4E2EAD2E0E8D5E2EBD1E1E9
D1DFE9D2DFE9D2E0E9D2DFE8D5E1EAD3E0E8D2E0E8D2E0E8D0DDE9CFDDE9C7DEF35D8AC0
0E4C9E437EBC9DCAED4877A375A1C5A1C2D6B4CBD9A9BBC8B7C8D1CBDAE0BFCCD5B7C7D0
CAD8E4BEC9D6B8C3D0ADB9C6A1AFBB96A8B2BACBD4A3B4BD9CACB897A7B195A4AF94A2AB
93A3AB8E9EA48E9EA286989E879AA17B8E9476898F788C91788C91768D906A8085637A7E
6A8084687E80697D836B7F826A7D8153686E556B735D7679657C7F6A7F836E86896C8082
5E605D1F961100FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A90B744C24
6E4F366E533D6D523E6C503F7053447255496D514A7155536F5454694F516B4F536E4E54
69464E714C5578515B7A515D805664865C6A8C63708D6876906C7A8F6A77936E7A97727D
97737C9C777F9E7A819F80839C7D809F8184A28A8EA28F919D90939C959E656E91061D69
011E7D01206D6D84A9B6C1CBA9AEB39FA6A9B1B6BAD6DCE2C9D1DA95A0AA8E9BA4B5C3CB
A9B9BF93A6AEC1D3DDB6C8D48296A690A5B5C9DBE9BFD2E76A85A4A2BEDEB1CAE399B8E0
164C930B50A32E71B4A8D5F76F9AC67FB5E4B3DFFCD0E6F3D8E6EED9E5EBD9E5EBDDE7EC
DCE6EBDEE8EDDDE7EFDCE9EEDAE7EEDBE8EED8E5EDD8E5EDD8E3EAD8E2EAD6E2EAD5E3EC
D5E1EAD6E3EBD5E2EAD3E1E8D6E2EAD7E2EBD6E2EBD2DEE7D0D9E8D1DDEACADEF5658EC5
134FA44683C2B5DEFABCDEF7BFE0FABADBEEC6DEECB4CBDAB7CCDBC1D4E0BCCCDAB2C3D0
B5C4D0C5D1DCC5D0DDCCD8E4BCCAD690A1ACA8BAC5A1B2BDA7B5C2A4B2BE9FAEB99AAAB2
99A7B1919FA797A4AD8B9AA380909971848A70828971858A7084896D8488687E83657A7E
6B7F82697E80667C80667E81687D804E666B4159605A727664797C677F806A8384697E7F
616867229D1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB01077491F
704E377054416E54416B513E7155457153476E514B7153546D5153694F506A50526D4E54
6C49516D495279525C7B535E825966865D6A8C65728D6874916C79906B79946F7A97737C
99777F9A7980A08085A18084A18185A4868CA0888DA190929E91969894A63A487B051D76
06268824468D798EAD97A0A6ABB3B4B3BABDAAB0B5C7CFD8ABB4C08B99A399A9B0D1E0E4
CDDDE376879390A1ABACBEC6AABCC7798E9BC7DAE7C6D5E899B0CF7899C789ACDAA7CAF4
3465A43773B95E98CCCEF1FFDBFCFF7CB4D786BBDCD0E7F6DEE8F0E0E8EDE4EAEEE7EEF0
EAEEF1E9F0F4E6EDF4E1EAF1DFEAF0DFEBF1DAE6EDDBE7EEDCE6EDDAE4ECD7E3EBD5E2EB
D7E3EBD6E3E9D5E2EAD2E1E9D5E2EBD4E2EAD4E0E8D1DFE7D1DEE8D1DEE8CDDEEDA9C9E8
79A9DD8FC4F4ABD4F1B9DAF45E86AF83ADCEB9D8EB9DB6C89EB4C8A6B9C9B1C1D0A2B2C0
C4D3E0C8D7E4ACBBCABCCBDCBCCFDEBBD0DDB5C8D3ADBEC7ABB7C3A0AEBB9DAEB8A4B5BF
A1AFBC9AA9B394A3AD90A0A98A9AA3798C92768A8F7284887083887084886D82866A7D81
6A7E7F6E8384697E82677F8362777B526B6E5B747A566F735F777A647D7C6279776B8082
64706E433B3000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A4917
704E336E513F6E53426C513E70524273524770524B6E504F6E50536E53546A50526C5156
6B4C566E4E5874515C77515D7E5561845B688B616F906974936D79956F7C936E7997757D
98787F9E8086A18388A5858BA4848AA5898EA0878FA08E939E929B9191AD182A6C031F80
0223841233758B9DB799A1A5CDD5D6D2D8DDA6ABB3969EA7B8C0CAC7D2DAA3B2BAB4C4CD
AEBFC883939D95A3ACCBD9E0D3E2E9B8C8D3A5B7C67F92A78EA6C7183E762D558CBBD7F8
C6E0F6C9EAFCBEEBFEA4DFF3AAE5F97FBEE197C9E8DAF0FBEAF0F8F7FAFCFBFCFFFCFEFF
FAFDFFECF2F7E8EFF6E2EBF4E0EAF2E0EAF1DEE8F0DAE6EDD8E4EBDAE4ECD7E3EBD6E4EC
D8E5EDD9E5EBD7E2ECD3E0EAD4E1EAD2E1E8D3E1E8D0DFE7D0DFE9CFDFE8CEDFEBC4DEF1
94C0EB326EB06BA3D6B0D9F647719A7DA5C7ADC9DCB2C7D6AFC1D1B7C9D7C9D9E8B5C7D5
B9CCDBBBCDDDA6B7C8A2B3C6A1B6C49DB6C2AEC5CEC0D1DAABBAC4B0BEC9A8B7C0A6B6BF
A4B3BE94A6B090A1AD8EA0A98C9EA47D9195798F936D82856F83866E8385708587708487
7387877286866C7E82697D8164797D566E706881825A7376637A7B617877667A7B657A7C
66757447473B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00814F18
704B2E6E523E6F54426F514273504476534872534A6D4F4D6E51537153556D52546B5154
694E566B4F5973545D73515A7C55618257678C61718C6471926D79926E7A96737E977580
9C7C86A1838AA2848BA08188A08088A3858D9D858B9E8B909D939E757CA108206D032288
0122812A4882A9BACD9EA5AAB7BCC1B4BAC0A2A8AEA0A8AECDD6DCD4DFE8A5B3BE8C9CA6
AEBEC5C7D4DCB0BCC3C5D2DACCD8E1C0CEDAB4CBE3A5C1DBC8DFF6849BBA93AAC8D5E7F3
EFFEFFE2FDFF88C1E34CA8D86BB9E1C2F0FFD4EFFDE7F5FCEEF4FBF5F9FCF7F9FCF3F6FA
EAEFF5E4EDF4E0EAF2DFE8F1DCE5EEDEE7EFDAE5EDD6E5ECD2E1E9D7E3EBD6E2EAD5E4EB
D5E2EAD5E2E9D6E2EBD4E0EAD1DFE8D2E2E9D1E1E9D1E1E9CCDBE6CFE0EBCEDFEBC7DDF3
6F9ACE1051A53777BBABD6F4AFD1E9AAC9DFB6CFE2C6DBEBBBCFE0A9BFCFC2D3E4A7B9CA
99AABEA1B3C4A0B3C29CAEBBBED1DDA8BCC69EB3BEB4C8D298AAB6A6B6C0A2B1B8A8B6BE
A2B0B998A9B37D8E998699A08EA0A67A8F95798E93768B8F708789708788748B8C768C8F
768B8C788A8B808F946F80866A7E82597072657D7D546C6C62777A61777763777963777A
6375744D52480ECA06
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00865317
6E482A6E503C70524173524774514874514973524C6D4F4D6D4E516D4D516C4E526C4E54
6B4D566A4D586E525D71515B7C55638458698D61708D6471946F7B93727C95767F987B83
997D859D81889F828AA2828BA08088A4858CA3888C9E898F9D95A64F5A89041F75001F87
0425834B689EC9D9EBA7AEB4A2A8ACBFC6C8D1D8DAB3BABFB2BBC3AEB8C2929DA896A2AB
CBD7DCDAE1E5CED5DCCCD6DDD0DDE5D3E2EEA6BED59BB6CBDCEBF5EDF6FBF0FFFFD0F2FF
AEDCF4B8EAFF92CDED7FC7E7ACDFF3EAFFFFE8F3F8E1ECF2E6EFF6E7EEF3E8EDF3E4E9EE
E6ECF1E1EAF0E2EAF2DFE8F0DFE8F1E1EAF1DBE7EED5E5ECD4E5EDD5E4EBD6E3EBD5E4EA
D7E4ECD6E4EBD7E2EBD5E2EBD2E0E9D2E2EAD0DFE8D0DFE8CFDDE8D2E1EBD3E2ECCDDEF0
9EBDE25887BF7EB0E4A2CCE9BFE0F88FB5D692B6D9BED8F09DB2C895ADBFA7BAC9AFBFCF
9DADBDC4D5E2C3D5E19DB1BDC6D7E4B3C4CF95A7B494A5B095A5B095A5AD94A3AB99A6AE
9BA6B094A2AC8696A07A8D94788A937D9199788B92768A9070858B71888C738B8D768F90
788C90788A8D7B8E9273868B6F83885A70745C7275506667677B7D667A7C64777B637678
607272565C551C950D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00657E0F
724B276E4C3873514075504475524875524B70514D6A4D4D684C4E6C4F506C4E526B4D51
694A52674954664B586D505C795764855D6A895F6B8F6670916C7594737B987A82967A84
987B859A7F889E838D9A7E86A2848AA28389A68A8E9F8C939B97AD28387205217F05258D
072A83516DA09DACBC9CA3A8A1A8ABC6CCCFD5DCE0C0C4CBAFB3BDB0B6BED1DAE0CED4DB
CBCFD5DADEE5D4DAE4D9E3E9E4EFF5D9E4EDD8E4F0EFFCFFF7FFFFF2FCFFC4E5F9559DD0
4495C994D1F1CFF4FFDDFBFFDBFAFFCAEBF8D1EAF9DAEBF2E1EBF1E8EEF4ECF1F4F4F6F9
F6F9FBF3F9FBEEF3FAE7EFF7E4EDF6E2EDF3DDE8F1D6E5EDD4E3EBD7E5EDD4E2EAD1E1E9
D4E2EBD4E2E9D4E1EAD5E2EBD3E1EAD1DFE8D1DFE8D0E0E8D1DFE9D2E0EAD4E1EACFDEEA
B4C9DDBCDAFB729DD16696C8B1D9FE35608B5178A3A2BCD6A6BACC9DB1C0B8CAD5CBDCE6
B9CAD6C2D3E0C3D4E39CAEBD9CAEBC9DACB995A6B19CADB69BA9B1909FA593A1A79CA9B1
99A4AD8E9CA4899AA2889BA1798D93667A8172868D788D93677E836E868A748B8C788E91
798E92768C9072888B748B8C72878963787D4D65695D7275667A7B647778647577637676
5D706E5D655E1C9610
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042A809
734A226F4B32734F3C74504275534673524874544F6C4F4E684D4C6C50506A4D50684C51
684C536245506147546549577B5967845F6B86606A8C676F916D7492717993737F9A7C88
9E808C977C87856E79836B76967B84A4868DA4888FA290989090A9112566021D80082A92
0B31885E79A7A2AEBAD0D5D8CACBCFB8B8BFB9BAC2B8BAC1BEC0C6CFD0D5E2E3E8E2E3E9
D4D6DDE1E5EED7DFE8DCE5EDEEF6FCE6ECF3ECF1F9F2FDFFCDE5F6BAD8F3B1DAF96FADD9
8CC6E7D1F7FFEAFFFFE3FCFF96CAE26FB7DAA6D9F2DAF0FBE8F3FAF4FAFEF8FCFFF9FCFF
F5F8FDE9F0F6E3EBF2E0E9F1DBE5EEDCE9F0DAE8EFD5E4EBD3E1EAD7E5ECD2E0E9CFE1EB
D0E1E9D1E1E8D2E0E9D2E0E9D3E0EAD1DEE7D1DFE8CEDDE6D0E0E8D2E1E9D3E1E9D1E0EB
B0C3D69FBCE316478E134B947CA6D28BACCC94AFCCA6BED2CCDEECC3D5E2B6C8D6C9DCE8
B2C4D299ABB99DAEBD96A7B496A7B3BACED5A2B5BEADC0C9BDCCD59FAEB493A0A68D9B9F
909FA48E9EA583979E83979D879AA06F838864797D6B83865F787A738C8E7B9093798E91
738A8D6F898C6D86876E8786708787708689677F816A8081677B7B637675627272647775
596E6B606D64336C20
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0046AA0B
754B1E6C4B2F6F4E3973524078574876564B7454516D4E4E694A4B68494B65484B65484E
684C545D434D644A566C4E5C7D5A6987617187626F8C67728C6A7291727993737E9A7A86
977A868B727E836D798E7985836B769D818CA286919F8D9A797B9E051C67011E8401228D
042A80748CB7AEB2BDD9D6D9D4D0D5BEB8C0C9C3CBDCDAE0DADBE0D5D5DAD9D9E0D8D9E1
E0E3ECE5EAF4D8E1EBDAE2ECE7EDF6EDF2FAEBF3FAD3E5F7749ABD8BB2D3D6EFFFE7FEFF
E3FFFFCFF5FFA8DAF4B7E8FE95D4ED80CDEBA7DBF2D6EDFADFECF4E0EAF2DFE6F0DDE6F1
DBE3EED9E5EDD7E4ECD9E5ECD5E2E9D7E6EDD6E5ECD4E3EAD3E2EAD4E2EAD1E0E8D0E2EA
D0E1E9CFE1E7CEE0E7CDDEE8CCDCE8CCDCE5D0DEE9CFDDE6CCDDE6CFDEE7D2E0E9D3E2EC
B2C4D78BA6C7486FA4406CA48EB0D5BFD8ECBFD9F08EAECBC0DAF0B7CBDD94A7BA95A8B7
9EAEBB99A8B5B8C9D4BFCED998A9B3C2D4DDB1C4D08C9FAB95A7B292A2AA99A8AE9AAAB0
8F9FA682939B85999F7F939A879AA175888F687D81647C7E5973746B8387798E917A8D91
768B8F718A8D6F878969818270888A738B8E6E8487677B7C68797A657676617474667B79
5D72705B6B6346402F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB111
764B1C6E4C316D4D3971503F70534372564A72544E6D504F6A4D4F694B4D684B4E65484E
674A52654A5360444E7254607F5E6B83606E84606F8A65738C6A7491717A94737D957580
9577828E75817F6A767C6A7478646E937D87A58E989E8EA15B629006227801248F022793
0C35889FB7DDBDB9C3CDC0C6CBC0C6CEC8CDD6CFD5E5E0E7DDE0E4D7DCE1D2D4DCD7D9E4
DBDFEAD9DFE9D7DEE6E0E7EFE6ECF5ECF4FCE1EBF4D1E0EFCBE0F4E6FBFFF1FFFFE5F9FF
A8D7F54F9BD2368ECE93D2EFCBF6FDC4F0FCBDE4F9CEE4F4D8E5EED7E4EDD8E4EED5E2EC
D6E3EDD6E3EBD4E2EAD5E3E9D3E4E8D3E4E8D6E5ECD5E3EBD3E1E8D3E1E8D1DFE7D1E2E9
CFE0E8CEE0E7CEE0E8CDDFE7CDDFE8CBDDE7D0DEE7CFDDE6CCDDE7CDDEE8D0DFE8D3E0EA
CDDDEAACC1D4B8D4F0AED4FA86AEDBB2D5F689AACD2E59839EBEDC97AEC39EAFC29EB0BE
CCDBE6B9C9D3BBCDD8CADBE8A5B5C2A7B8C2A6B7C491A2AF8F9FAB92A3AB8799A099ABB2
86959E7C8C947A8B92768A907A8D9671858C677D83647D805D767963797E72858B778B8F
778B90738A8E6D83886C848771878B768A916D80866C7F836A7D7F667978637876637C79
5D73715A6A634C493A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B714
774A196D4A306D4C3971524073584874594D70544A6B504B664C4C64494A66494C684B50
664B526B505871535B77596180616983616B835F6D8864728E6B778F6E78906F7896757F
9776819478846F58656D586486707A826B75A48F98A498AB4C578B072885012796012997
0E3A8DA3BDE2C1BDC7D2C3C8D6CDD0DFDDE0DEDCE1DDDCE1D1D4D9CCD3D7D8DCE3DFE0E9
DDE1EADEE2EAE7EBF0ECF1F7DEE5EECCD6DFD7E0E9DBE3EDE9F2FAEDFDFFD2EDFFBEE1FD
6FAADC2A7EC42781C6A1DCF6D4F6FFB6D9EB82ACCDCCE5F6D6E3EDD4E1E9D5E2EBD4E1E9
D3E1EAD5E2E9D3E0E8D1E0E5D0E1E8D0E2E7D3E2E9D5E2EBD3E1E9D3E2E9D1E0E7CFE0E7
CFE0E8D0E1E8CEDFE7CFE0E7CDDEE6CEE1E8D0DFE8CFDFE7CFE0EACFE0EACDDEE8D2E0EB
D2E2EEB7CCDCB6D3EE5E8CC31C529C7AABDE8CB2D848729B9BBDD9BED7E8BCCFDFA8BECC
CADCEAC5D7E7A9BECFB7CCDCA4B6C39DAFBAABBBC89CADBAA3B4BFB9CCD38B9EA59CAEB5
8E9EA686949D7C8B9383969C7B8E956D8188667E83657E8261797D617679687D806D8287
758A8F6D85896A82866F878B71868B788B9172858B6E8184788C8D667C7A647A78657E7B
5F73745868624C4A3B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A4A16704B306E4C3872533E74584876584C75574C6E524B654B48654B4B674D4E664D50
715B5E8B7579755A617D5D6583636C85636D86606E8864708F6F7991717993727C957680
9879839476817E636D8E6F79A2808A8F727CA08A92ADA3B545548C072B8F022B9F012D9D
0530878DA6CFBCBEC9CDC6CCD8D2D8DEDEE2DADCE1D4D6DBD6D8DCDDE0E4DFE3E7E0E3E7
E3E6EDE4E8EDEBF0F5E9F0F8D8E0E9D7E0E9EAF2FAEEF5FDE4F0FAB2D0EE4B7EB97AB0E1
A3D8F974B0E177B4E7AADBFDBBE4FF76A8D25B93BEC7E5F8D4E3EED8E3EAD5E2EAD4E3EA
D5E2EBD3E2E9D3E2E9D2E1E8D2E1E9D1E2E9D4E3EAD4E1E9D2E1EAD2E2EACFE1E9CEE0E9
CEE1E9CEE2E8CEE1E9CCE1E8CCE1EACCE1EACDDFECCCE0ECCBE0ECCAE1ECC9DFEFC9E1F0
C9E1F3ADCEE793C0E92965B3094CAF5793D7AAD4F7A9D1EFA5CAE5BFE0F8C5E2F9A0BFD9
B3D0EDA7C3E28FADCB9DBBD4A8C3D797B0C3B9CFE2AFC5D69EB4C5AFC8D5899FAB8A9FAA
8FA1AD8EA0A9899BA3889DA17D949871888C667E826B83866B80826981815D7776657E7F
738B8F6F87896F848A71868B72878D758A8D778C91758B8E7287896D817F647A77687E7C
5D71725C6B674C4B3C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
824E15754F2F724F3A72533F75574974564A75564A6F52486B514C684F4E684F525D4A4B
978C8CC0B6BA76636B7C5C68805F6A85646F8A66728C68748F6B75926E7892727B977783
97778393737E8F6E77AA8089B38791B18D97A9919AB3ABBE3A4986062A910431A90434AB
0432927E9CCDC9D1E0D5D4DCCFCCD6D4D4DCCED0D9D1D5DDDCDFE5E1E5E9E0E4E9E7EAF1
E1E8F0DBE5EDD5E0EAD2DDE9D4DFEBD9E3EDD8E2EFD0DEEFD1E2F89EBEE53368A56FA6D9
A9D5F4AED9FA90C0ED2565AF3C7FC87AB4E56C9AC0CBE4F5D4E2ECD3E0E8D3E1E9D3E1EA
D3E0E9D5E2EAD5E2EBD5E2EAD4E2EAD3E1E9D3E1E9D0E0EACADDEACBE0ECCBE2F1C8E4F1
C4E2F3C2E3F4C0E2F3BFE3F7BFE3F9BEE3FABBDFFBB3DDFBAEDAFCA7D6FCA5D4FF9CD0FB
96CDFA79B5EE4E94DC2C7BDD0754C64C96E675B3EC71ACE8649FE268A3E369A3E4457EC4
5187CC5588CB598BCC78A9E38AB7ED6691C68EB5E78CB2DF7096C2769CC181A4C57F9DBC
85A1BD7F9CB3819DAF829EAB809BA7718C95647C84687E836E85886F8A8A6F88896F8789
728A8C758A8D6F83896E868A71858C6C7F85768B90778C8F778A8C728686677E7D677D7D
596D6D5A6965545345
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8B5418754F2B73533C74554473544873544A7354487153486F514B694E4E6850525D4B4E
A0989DBCB7BF7967737B5C697E5E6982626C8664718C68748F6A7493717B94747F987985
987A859E7F8893707AB88B97C695A2B18D98A7929CAEA6BE314281032890012EA60334B0
03359C6789C1C6D1E4DEDDE6CFCCD5D1D1D7D6DADFDBE1E7DCE0E7E0E4ECDADFE7D2D9E2
CCD7E1D4E2EBD5E2EED0DCE8C9D6E0CFDCE5CCDEEF7791AE9FBAD8BDD8F39CBCE284ACD9
90BDE6ADDDFF6296CC0D51A7175CB09DD0F8C1DEF5D1E3ECD6E2EBD6E2EAD8E3EBD9E3EC
D9E2EBD7E2E9D6E4ECD3E4EBD2E5EFCDE5F2C9E6F6C1E5F8BCE5F9B4E5FBA9DEFE9CD8FE
8DD0FB7BC3F473BEF45FAEF056A9F04697E8408EE93586E42D7CDE2572D61D69D11865CF
1561CF115ACD0F54CF0E4FCF0B4ACC0C4AC5124ABE1249BB1044B91348BC1145B91041B5
0E3CB0113EAF0E3CAC0E3CAB0E3AA70B369E0E3A9F103B9C0C3795113E951643951D4695
29539F325DA13D67A34E74A85B81AC567C9F5C7C9864819668869461808A6B89906D888D
738B91758B9071858C728A8E71868B63787D73898D6D8589778C90768C906F84886A7F81
667B7B5F6E6B525047
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
40A60B754D2976533F74534373554972534875544A72514971514D6D514F654D4C5C4A4B
83787FAA9DA8735B6A7D5D697F5E6A8562718965738B677493707B95727E9473809C7C89
A3838FA8869197727FB9909EB7919E957A86AD9EA8AEAFC6283F80062E96012CA40332AD
083CA1799ED4BEC9DDD0CED8D0CFD5D0D2D7D0D4DBD9DDE5D1D5E0C6C9D7D2D7E2DBE1EB
D5DCE7BECAD5C4D1DFC5D1DDBFCBD4CCD9E4CFDEEF93ABC58AA5C0A2BAD1B2CCEC305A96
114B94437DBA94C7F34D84B865A2DCA7DFFFC1E5FDCDE4F0D1E5EED4E6EDD8E7EEDCE8EE
E0EAF1E3EFF5DEF0F6D2F2F9BEECFDA4E2FF86D4FA66C4F552BBF73DB1F42DA7F12098EE
148BEA127FE71B7EEA176DE11A69E21A60DE1E58D92457D4254EC92546C02B46C22D43BF
3446C03944BB3D3CB44037AE4436AC4635A4462F9C4F38A4462E9C49309C4F339F4A2E97
4327934128913D28913927903827943627913328912C278D26268C22268D1F29901A2990
14278E11288D1029900B278908268207287A0D2C76193A7B274C81395E89567A9C6486A0
7291A3728E9B718A93718B90748A8E697F836D85886C86876D8388788D90788D90718A8C
7286896C7A7B545049
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
45A90D764C2673543C74574472554775564A75544874544971514C6F534F664E4A634E4D
6750557258637658657D5D68805F6A8663708964728A677493727D9A78859C7B88A2828E
A98894B08B97AF8A95A4828D9D838CAB99A1BCB1BABABED5314B8A052D96022EA90234B1
0A40AC527ABBB8C5DEBFBFCAD6D7DFD4D8DFC2C5CFC7CAD5C7CCD7C3C9D5CED4DFDDE3EF
CDD4E0AFBAC6AFBDC8D0DDE6C6D0DBAEBAC8BACADAA0B2C79BB4CC9FBDD2C4E0FC436BA0
245A9B477BB0AAD3F3BEE7FE72BCE63598D471C5EFB0E9FEB8E8FBC0ECFCD2F2FDE1FDFF
E3FFFFD5FAFFB4ECFE7ECEF458C0F52EABEF1BA3F00F9CF20C98F80691F50790F90383F4
107FF4286EE55164DA6559CC6F54C4774BB78544AB923D9F9833919C2C86A02A82A02379
A11E72A41E6CA71D67A81A5EAA1A5BAA1856AA1551AB1652A81652A61951A51452A1124B
9F104998114995104A900D49900D4A8F0E498C0F4D8511508212587F175F7816666F1A69
651D6C561E71481F793A1C7D30207F231C791817731217730E1A73091D720723710F2F75
244983416792597A9A67889D6D8A976C868E698288697F84677C80687E81688082718A8E
84989E7D898D524947
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
49AD0C764A1D73543872574173574475564676554770534771534C6E5250634C4B624B4C
684D5275575F7556627D5C6985616D8A616F8D6472946F7D9B78859F7A86A3808CA3838E
A88A92AE8F9AB0909AB99FA7BEACB2CBBDC5C0B6C1B8BAD2425997072E95032FA9012FAD
0333A52D569EACBFDAB9BDC9D5D6E0CFD2DCB5B9C3B2B9C1D5DCE5D8DFE9BFC6D1B5BDC9
B6BEC9BAC5CDAFBDC4D1DFE7CAD7E0A1B1BC9DAEBAC2D5E596B4D0507697C2DDF6BBD3EC
BCDAEBD2F4FFC5EDFDA9E6FF4EB5ED2DB4F335B9F841BAF552BFF669CDF785DCFD78CDF2
59BBF134A4E51F9AE61297E90C96EE0496F00292F2008AF1018BF60089F50086F7067FF5
2A6CE68350BFBD368CD33074D92C68DC2B5EDD2652DC2047E02045DE1B3DDB173AD81539
D20D33D20F2FD00E2BCC132AC61A31BD1B30BB152EBB0F28B81A31BE3148AD1733B10F28
AD1329A9192EA50E28AA0520AF031EAE051CA8071DA2102899132F961333971235931135
9211368C0F37880C3D860C437E0D4675114A6810505A11574A115F3817651F126616166B
0D1A6D081E6E0926701A3D7A345786547392607B8F5F788162797D64797A64797D667E83
8A9CA381888C3E7432
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28D90878491876523774544076564577554777564B74544B71544E6E5350674E4D674D4F
6B4F536F515773535D805D6A855F6D8B6270966C7A9A75829E7B889F7C89A58391A68792
A68A95AC909EAB919FB8A3AEC8B6C0CDBBC5C2B3BFB4AEC64C5D9906278D02279F0126A2
062FA12A529CC4DAF6C4C7D3B7B5C2B0B0BCC3C7CDB3B8BDCED3D9D5D9E3B4B8C4A3AAB3
D0D9DED6DEE4ADB5C0ACB7C3ABBAC6A6BAC6AFC7D3C7E1F2B5D7F09CC5DAD6F9FFCBF0FE
A1DBF37BC6F052ACEE32A3EF28ABF91CA8F60F9CF60D99F30A96E919A7EB2BAFEE24A1E6
1593DE1A96E21B93E21E99E61C9FEC19AAF418AEFA12A9F80DA4F80BA1FB0C9FFE1995FD
5978EABE449DEE2A5AF5233FF41D37F21A2FF01B2CE21320E51523E11220DC0E20D30A1D
CE071DCC071ACA0819BB121EE4737AEE9FA3CD6C789A1C2FCC6473FFC1CAB65D71911D33
E18995EFABB4AB4357A00921AD0416AC05119B0C16DD7F86CF8F99C0838FB97986B06977
A758689D435594273E930D2899042095031D9304218C0727880C327B0C3768093E5F114D
4811553216611F1565101667091A680B246723427641637F5573815F7B7E61797A5E7579
7D8D92787A7B2BA320
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007B4B197451347958447655427755437B5A4C7757507255516F545069504D684F51
6C52567053597958607F5B67885F6D8E6671956F7A9D7B86997B859F818DA28593A48994
A88E99AA929FAF99A6B69FACC2A7B5C3A5B3C3A4B2B8A2BC505491072282032293011F93
0324921C3F8AAAC0DFACB2BEAFAFB7BABBC2D8DCE1C2C9CDAFB3BBB2B8C1C4C9D4B1B5BE
D1D8DED5DCE4B9C4D1B4C6D6C0DBF0B8DFFB86BAE3A0D9FE83C1F274BAEE5EACED3895E9
198BE61C98F90B83EE0576E90277E80885EE087FE70A87E60CA1F313A9EF1CA1E551BEE9
81D9EFAAEDFEB3F1FFAAF4FF87E9FF62DAFE3BC2FA20ADF7109CFA078DFA0782F71175EF
4956CDB42E82E31B3FE61424E20E20DF0D1CD70B19D00915D10918CE0818CB0516C60618
C10114C00314C00516A90B1CE28C98F2CDD3ECC6D085394FAA6176F6D2DDAF798F833750
EFC5D2E8CCD8AD5F79960A26A70215A503108C0D1CE3A8B2DCC8D3DAC9D9E0CADAE0C8D6
E0C7D7DFC5D0E0B4C09033489509209802139304119219238C1F2D7E0E217C0A217E0A26
7B0C2F710B37660D434E0F4D32125916105A0A135C061F5B21436B4D6F845A7680577076
6F81836D6F6D239A15
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007D4E1875533578584376554375564378594A7C5C557658567255536C51516E5456
74585C795C617B5C637F5E688A6573906B7794707B997982997D889A828DA18895A38A98
A68E9BAA92A0AD93A1B394A3BB95A6CAA0AFCCA0AEC39EB94D47820B1F7C021B84021B87
011D8513307894A7C4A7AEB7BBBFC3B6B7BED2D5DCB4B8C0B2B8BFC3CBD3D2DCE5CFD9E6
BECCDEB5CDE5A9CEF19BCCF978B5F2418DE01974DA1375E40F6DE30C5EDB0963E00473EE
017AF30183F90283F90287F7038DF7099EFA20B6FE37C9FB3BCCFC4FD5FF70DFFF91E8FD
9FE5FD96DCF76DBDED48A6EE218EE81382E81077E9106EE61468E5175FDF1E58D92C4FCB
5F41B1A71B68D51136D90C1FD40917D10918C50211C20312C50516C50516C40415C40616
C30415BE0212BD0314B6071BBE4055E3A9B6EDD4DFA7778C935771F2D2E2BA91A582445F
EBCCDBD7B8CB9035589E0928A80115A30211860919D298A6D1BCCE826181935F859B678A
A6799AAD93AAD9C5D495576C860A259003157E0611CE878BD1A6AB7E4F56A86D778B4651
8731447E152C8507258308277309305B0E3F37104C1311520418580D2B5C395977516E7A
5F75785C5F5912CC09
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0082521775523174553F7555427859487C5E51795C53795A56785956755755745758
7A5B607E5F667C5D6582626C8565718C6B7891737D927A8299848C9B88919C87939F8796
A68B99A68C9AAB8D9CB390A0B991A2C79AAACB9BACBE97B3473D7708157001127901177E
041E810F2870828FAEBEC2C9DCDEE2B6B5BDB6B8C1C0C9D3C2D1DFB6CCE1BDDAF9A1C5F0
7FAEE8518DDA2B74D31568D40B63D80461E10262E90267EF0060EB0865EE0470F00684FC
058EFF038FFC0699FF0AA3FF0BA7FF17B3FD22B6FA2BB6F81FAAFA1398F1168BEC1A7FE3
217AE12372DE2165D8235FD62D60DA395CD74951CD5849C16A44B7793FAD82349E933192
AB297EBF1450D20F30D60D1FD70B19D10B16CC0814C70512C80717C60413CA0815C70510
C70512C80614CB0815CB0C1CBE152BC3596CF6CFD9D5B3C386546AF0D1DFC7A4B6864B64
EECEDED1ADC18C2145A50724AD0216A402128A0618C68492D8C2CE876A7F84516C7F465F
743956704860D5BFD199677D830E2C8F03177D0514B98089C3B8BC827F83B6B1B6BDB4B8
CAB2BBA36A7A7A0D228904178A031782041C700A2E3D0D430D105402175B051E5333516D
566D775C605900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF006783157B583172553B70543D785B487A5D4F7C5E547A5C547C5D59795B5A795C5E
7C60657E626782666B81656E8468748B707C90798494808996868D9989939886929D8794
A18996A78E9BAB929FAD8F9CB593A0B6919FBB95A4AE8EA73F376E08156E00117501167D
031A7D11276E8A93B3A5A6B1BEC0CBB3BACCB1C0D9B7D4F895C1F15A91D73070C81359C1
0A54C80453D00356DB0257E0015BE70060ED0165F1036CF70574FA0A82FD0B8EFF0990FF
078EFF0289FC068BFB0286FA068BFB0886F60C77EB0862DA1262DC226CE42A5AD7435BD5
5451CA6246BC7946B5893EA79133999F3092A72986AD287DAC2474A8216FA624729F226F
9E206CAE1D60CC1542D91026E0101DDB0F18D80D17D40915D50A17D30914D40812D50913
D40814D50915D30713D40B18CD0F22B5283AF8BAC6EFD1DC936C7CE9CCD9D4B2C48B536E
EDCEDED0A5BA931F42AE0822B20213AB020F960516C37280E0C6D0D4C7D2D3C5D1D1C0CC
CCBAC7C0B7C1CFC8D5A5768D88133197041B8B0919A2606AC1B8BDAAB5B9AAB5BCAFB8C0
8D8A95AC8B9A6F13298404148C020F8B020F7F0419550C33160D4C04145A011555061D4A
3B5468535B5600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0044AB0D815C3373563A745841795B477D5D4E7F5E527E5E557C5D597D5F5D806164
816367816769826A6D81676D866B748E7581917A8795818D947F8B9A869298838F9F8996
A48D9BA48C9AA58A99A48997A58795AB8C98B493A0B295AD352F6705136D01157B011882
011C831939888DA5D199A8C492ABCE88AEE44E7FCA2763C00F53BF074FC70450CF014ED2
0250D70154DD0155E20158E60562F1066BFA056EFC0673FC0976FC0671F80571F6046CF1
0769F00B69EE1068EB1360E41E5EDE295AD4243BB32A269B4225977437A3923299A62F8C
AE2A82B62C7FAD2876AA2976A9307E9E307E903286873A8E773E966444A15852B34755B8
4155BC634EB1AB2D77E01C3EF11C27EE1A1FEB181DE8141CE6111CE4111AE5111BEA1722
E00F1ADE0F1BDB0C18DA0F1BD50F1FBF1B31E38F9FF2D7E1B097A4E5CBD9DAB7CA95617A
F0CFE1CA94AD9B1C3FB40820B80414B70613AA0A1AAA4052B78294AD8DA0A891A5B09CAF
B5A8BAC7C7D2CEC6D4AD738E890D2D990319930819984C57CBBDC5B6BEC4ADB6C1A9B1BC
AFAEBCB193A3731A3184041788000B88020B8004135D0C301C0F4B04105601115401164B
11274647525200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0048AE10865F367E5D447E5D487F5E4A81614F83635385635883625A836260866667
8568697E6465846D6F887075896F778B747F8F7985967E8D93798A987E8F9A80919C8192
A48A999D82929D8091A18392A88A97B493A0B6909FB495AF35306B061A77041F8A02208F
022493042E904671C23A68B71C57B51456C70445C00344C40145C9014AD30050D90253DC
0659E4055CE9055EEC065FEE065FEF055DEF0259EA055DEA0A59E60D50DB144ED51C46CA
2D42C43C42BD5145BB603BA97D38A0852D8B7313697516667D1A6A9226729C28769C317D
9739868F44918152A06556A45562B24067BF2F6ECD2676D91F7CE01A81E71685ED1588F0
1585F43876E9944CADE12C5CF5202FF11C20EE191EE9161CE7131DE4101CDF0C1ADC0E1A
DA0D19D60915D60917D30B16CF0A1ABE0F24C75E72F5D6E1C5B8C3E0D0DBD4B2C5A4758B
F5D0E5BB77969F1638B00319B50111B50410A70A19CB6A76E2B6C2CAB1BFBDA7B7B39FB0
A294A4C7C2CCCFBACB883C5B960C2B9D01179507189D4D5AD4C2CAC3C5CEADAEBB91909D
AEA5B3946D8078183389051B89010F85010B77010F5A0929230F4807135501125801134E
04163D3C444D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0050B315875B32835E47815E4A815F4B84645286665587655A87655D886965866967
856B6A836C6C86707387707889727D8A73808F77859379899376889C7E8F987989957485
9B79899D7D8C9D7D8CA1818EA98894BB97A3BA90A0BC9BB8403E7C061F8003269501289B
052FA50130A50434A90235B1033EC10141C90145CE0248D0034ED90657E4065CE70659E5
0655E10251DE014FDC064EDD094BD90D45D11340C82240C33337B3472DA065319A74288A
8925808D1F7295237095216B9A25709B317B7A2A784F21763C2D874C53AD455DB5456CBE
5481C97CA2D69AC2DE97CDE48AD8F068D0FB3FBDFF1FACFE0F9FFD0C9BFE098EFB0884FA
0476F81866E96A4ABAC42662E0122CE5121FDD0E19D50914D80B17D50916CD0111CD0613
CA0610CE0812CE0513CE0714CA0617BF0A1EB4384EF5CAD5CFC8D3DBD3DFC4A7BCBA90A7
F3CDE2A55274A51134B10317B30110AF020E9E0A18CE7684DEB7C6D1BECBD2C4D3D3CAD5
D3CAD5D2C8D5E6C5D89B42609E0B29A30216950817994752DBC5CBC2C0C9B5B3C0B9B7C2
C5BFC8AE8D9E7A1C3889051D8A010F83000875020C5E031A380B38120D4909165702124B
021239252D3600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDB0C895B2D836046825F4C83604E8865548C6B5B8A695E8A6A628B6E69866C69
826969826A6C846A73816674856B788E73818A6F7F90738590718391718291707F93707E
9B79879B7E8AA08490A48694AF8E9DB694A5AB8DA5AA9DC23C4A9007298E032CA0022DA7
022DA8002FAD0030B20034B9023BC30646D0054BD60650DA0551DA0450DA044DD80547D3
0842CD0C3EC71237BD1E33B53130AD4A2EA2612A94782583881C72951E68901B5F8E2064
82216579266D682B77583A8E4B4CAA3956B62D68CE1A70D6167EE12598EA47B9F078D9FF
A5F0FFB8F0FFADE6FE7DCBF040A5EE1D95F50886F30281F6027CF60279F6006EF10067F1
015FED0B55DF3834ABA22067D40F31D90B1DD50718CE0411CF0511D20714CE0412CE0915
CC0510CB0410CB0411CC0715C80A17C11523A52939EDBCC8DDD4DFDACDDDBB93ACCA98B0
EDBAD1983959A50F2EB20517B30210AB0410A01D28C275829C7284BDA3B4BAA7B6B6A5B5
B39DB0A6859CBF829E9D2D4EA60A26A704168F0B17C6848BD2C2C9A9A5AFBEBAC8B0AEB9
C8C7D2CAAFC28026458C06208E020F8802087A01066C020E5606223D103B1D1449050F44
05153B1F242E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008A5B28825F4284644E8665528A6956906F5E8F70638F726891766F8C746F
846C6B80656A765B657A606D886E7B876F7C8469788A6C7B8465758867788B65778D6879
9776859C808DA38A97A68F9FA390A69D94B17A7CAE40559D0E3293022C9F012DA8032FAF
0232B40234B70237BC0742C70540C7033DC60340C90442CA0741C8093BC21137BB1B31B1
2A27A344269A5F248D731D7B85196D8A17618A195C871E5F7C2167702E78512D7F34338C
2846A42355B52067CB1872DB1684EA1591F21198FC13A2FF0E99FA1598F61999F6168EF0
1B89EB187DE41478E50E73E8046AEA016AF00168F20169F30060EB0063ED005FEA005EE8
015BE70553DC2E46C08D257BD0133CDA0B1DD90915D90B16D90916DC0C18D90915D60914
D50712D30612D50A17CF0C18C7222AD2565EB76872DDC0C6DFD8E0B8A5B5AC8196B48298
C08BA1C0708AAD2D48B0081CB40210AB0513B84350F6C6CFD8C9D3CEC8D4D1CBD8D4CEDB
D7CEDBC4B4C4D6A6BC9D3350A30822A40513911621D2A0A6D3CAD2C6C5D1C2C1CFC0C4D0
CCCEDAD0B3C987264995062395000E8F010885020772020D550318410728340F36151039
0B163627262D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008D5C2585604086634C8D69558F6C5795725E987A6891776A988177927D78
87727180696B7C626A7C626D7E646F7B616C7F64708062708363728766758F6B788E6B79
9174839A83959588A08D8BAE616DA228428C103592052D9B0430A90130AF0231B20237BB
053CC20234BC0232B70136BA073BBF0737BA0F3ABA1836B4222AA4382295531E87711E7A
84186A8C135E8C12578616587C1B60651D684C287934358D2644A8194EBB125BCD1773E6
0E7BED138CF81495FF078AF71399FD0787F90381FB017BF80275F6016BEE0068EE026DF5
0166EF0166F10164EE0169F10166F10062EC0061ED0064EF0067EE016CF1016FF3006FF1
0476F8036BED235FDB80399DD62155E91627E9131AEB161CE91219EC151AEB151AE40F16
E51019E40F1AE4111DD81620DC525AFDC6CCEDD1D8E0D5DFDCD6E3DFD5E5E3D2E3E2D2E1
E1CFDEF3CCDFBA5772B2102ABC0517B60719BA3249EAA8B9E1CEDBBDB8C7B6ADBEB5ABBB
BDB9C7D1CDDBE4C0D69A3452A60C26A4081892262FD2AAAECAC2CBA29EACBAB4C4BEBFCB
D1CBDCBD8AA8951E44A408239F010F9701088B01097004133C04231C03262A0B2D281633
19192C1F5A1C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00966326875E3E87614E906854916952947059987B6798817296807496807B
877270806A6E7D666E7961697258627359647A5F6B7F626F8564728968768E6E7C8E7383
8A79907A779B4D58901C3685092D8F042D9C032CA1002BA50436B50438BA0438BC063BC2
0438BE022CB00428A70B2BA414289E1F1F90381D85632583801F728E165E941255901351
8015546C1B615221713827812231941740AA1350C00D5DD11070E90C73F20B78F90A79FB
0370F50472F40577F70575F7016CF10069F20168F40063EF0469F5005FEB0061EE0066F2
0067F1026BF2026DF00577F40376F20677F1077EF30883F30788F2068CF4058EF6038EF6
038DF8058DF81C83EF785EC4D7346EF72739FA2328FC2324FB2125F91F22F41A1FF11820
EB121CEE1621EB1521DF1822DB4453FEAEC2F1B2CAE6ABC8E1A7C7E3A8C6E3A8C8DEA7C5
E1A8C7ECA4C5BF4568B70D2BBE0417BD0519B30B26B23B57F1BACFE0C9DDDCCCDFD9CDDF
D7CCDFD8C0D7A961839B1A3CA6071F9C0817AC565EDAC5CBC9CBD2C0C3CDA8A7B5C6C5D2
D7C1D79E4D729F1136A9071DA704119F020A91020D71071D2F08310C0A3D0C09331C122F
271B2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0043AA0E855B368B684F906E56936F558E6C559F8573A994869D8A80917C77
89727182696B775E636E575D765D657258627B606A82666F846772866C7C85728B726A8D
495083152973072584062B980129A00129A3032BA6012AA8022DAD0331B30534B60632B2
0C2EA80D1D921C168335167756166E751564830E51901350911754851E606C2571462376
2E2C861B34991340AE0A47BD0F5ED6106AE60863E70765EA0565E9096CF30162EC005CEA
015DEC005BE60060E90060EA015FEC005EEE0061EF0169F20069F1026FF60374F6057CF4
0981F00F86EC198DEB2294EA2D9DEC38A9F23DB2F443C1F33CC3F533C5F62AC2F928C4FE
1FBDFF12B0FF1B9FFD6682E5C04089F12A46FA222CF91E24F0181EEE151DEA121DE7111E
E20E1DE3101DE20F1FD80C1DD2152FCC254AC82956C22556BE2054BC1F51B81E4FB62050
B41E4EB51A49B61036B80620B90417B80316B5041CAE102EB1375DB04F7AB4628CBD759B
CA85ABB86088981840A60827A60215970614C66F7CDDBDCAC4BAC9CFC9D6C4C0CFC4BECC
B690AA952E53A50C29AD0817AC0610A3030C9203106E0B28270A3F07104E0310460C1136
2C1E2B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004CB112895D308C6B4B9273579E7F659C816BAB9787AD9B92A8989090807C
8975747E6566755B5E795E657457637458647D646E7E67727C6D7C6F6987464A7B142166
031B7003228601259402299F0128A10328A20125A00227A20427A50927A611269E181786
2F11744E1266690D567C0C4A830E467E0E4871135257155F43267E2C339A2043B60F41B8
0A45C1074ACA0851D40553D80455D90559DF0151DE0152DD0256DF0051DA0155DF0054E3
0054E30059E6005FEA0167EE0069F1006DF50174F70384FB0488F8088DF41295F129A4EE
54BDF180D6F1A2E6FAC0F5FFC8FCFFC2FFFFA7F7FF7FE7FC62DDFA32C0F61BB4FA0EA7FB
059CFC0393FB0682F6326FE58A41A1D1275CE51B35E41628E11427DE1328D40E26D2112D
CD102BC8112BC51030C00F31B90E35BB153FB61243B11245AD0F45AB1045A70E44A61043
A30F41A10E3F9F0C379D0B309C082B9F0729A1092B990729950831950B39970E3F971041
9A14429D0E37A4072BA6021CA401159C0317981B36C46F8AAE6D8DB582A1CFAEC7DEC6DA
DFADC7932645A80D26AD0613AD050EA2040C8D0313640F361D0E4F06155D021456061243
251D2E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADB0A895B288E6A47937558A489709E8773A39083A1928AABA09B9C8F8D
8C78787B6263785D5F7D61667B6069785E697765747069804D5278172562031566021A77
021F8402238E01249703269D01259D0121980521990D2297151A8B2D19824D1571711663
7D0B47850C407E0D41680C46511558361C6B2224801128921237AE0639B90D53DA0651DB
0247D30247D2024AD40149D30048D3024BD70048D5004BD9004ED90256E20057E30059E5
005FEA016AF20271F4037EFA0284FB008BFA0397FC0BA7FD1DB6FB3DC9F96BE3FE98F7FF
B4FAFFB7F5FFABEBFD9EE3F883D5F459BEF22DA2ED1497EB0F97F20690F5048FFB0289FC
017FFA0179F90272F81067ED434FC885328DAC2365B11D54AB1F53A522589E225E922062
8E256C81266F822D7D772C7E6A267A6C2D83642B84612B895927875325834F25814B247D
4B227C4A20784F21774A1C6C4D196B4E16644F146053155A5610535F0F516910516F0F4D
770E497F0D428409398C0A328D07288F0625910828900E319011388F163D9B3459C26A8F
B14C70A01737AB0A20AD0612AA040CA0040E87051B520E3C15135B04146403176304154D
1D1F3300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF008A5C228F6B45907355A28A72A692809E8E83A99F99BCB4B2A19494
8771727F65657C63637F686B7D6A72726275585475222A5F06145E02156B021978011B82
02208C011E8F011D91031E94061E930B188A19147E3713715E1164841359900D4689093B
74093B590D4938125D201C75101F870E2E9D0832A70837B30332B50031B80B52DA0552DD
0145D20244D10145D00146D10046D20149D7014CDA0154E3015CE90164F0026DF60272F8
027BFB0484FD058BFC0698FC09A6FF09AAFF0DAEFF12B3FD1DB6FA20B4F62AB5F82DB0F6
2AA2EE2399EA1A92EC168FEC118CF00987F20587F90384FB0180FB017AF9027BFC0174F9
016FF8026AF60366F30360EE115AE42C53CE4249B94848B13E42AA3843AD2C3DAB253DAF
233DB21F3DB41D3EB81A3FB9173DB8163CB8153CBA123ABA133ABD123AB91036B51039B4
1135B10F31AC0E2DA50F2BA10F289C11289812269410218C132088131C81171B811C1D82
221D7E291D782D197233166640155D4C10515A0E47670C4172093A7D0934880D368F1136
9C0F31A50A22AA0619AD0612A8030E98020F800A244714480F156102176A051D6E021757
171D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF009565258F6A419174569A846B9C897C9D8F89BAB4B3BEB8BA948687
846E6E856E6C836F6E7A6C746E697D3C3F690A155402105F01136E021778031B7F001981
001A85031C890518870D16821E12763C0F67620E57820E4A8D0B3F8A0E426F094448094D
250C5D1214730D1F8A062899042FA70732B00126A50029AA0A41C5033CC5074BD6044BD8
003DC9003EC80044CF014BD50254E0015AE8015FEC026AF20575FA0278FB0482FD0688FF
0890FF0794FF0796FE089DFF059BFD0294FC008FFA0494FC0592FA028BF70389F80489F9
0586F90383F9047EFB0279FA0176FA0178FB0277FC0072F90271FB026DF8016BF60169F6
0166F40161EF015AE80159E60258E30756DC0A51D40A4FD0084ACC084ACE0647CA0547CA
0443C80240C40342C60648CB0343C60341C30645C90441C70340C50340C2023DC0023CBD
0137B90235B50131B0022EAA022DA5032DA3022BA001279A04279A01249604269905269A
05249506249508249309218C0C1F85101B7F141A781A177126166832105B470E505F0E46
770D388D0F2E9C0B23A208199F0312920413740B2936134B081562021C70042173021B5F
141F3D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB0128E6437927052957A668773689B8B88B3AAAAAAA1A08F7F7C
8B77718A79768A8189636580202B5E03145801156501146C03167701157A01167B02157A
041475080F6B170A623A0C5B660E537F0C43830B3C760B426013543A105F1D0E6910187C
08208C04239604269D0228A1022AA7032EB00732B40131B5033EC50042CE054ED9034CD8
0044CF014AD40154DF0462EC0469F3026DF80371FA077DFE0683FF0685FF0584FD0380FC
017CFB017AFA027FFC0182FC0280FC007BFA017DFC017CFB017CFC017BFB0176FA0176FA
0276FB0173FB016DF90168F80269F9016AF7046CF90066F30163F00163EE0062ED0163ED
0260EA015AE30157DF0056DC0259DC0255D70354D40252D0034ECE054DCD064BC80447C3
0647C00747BD0645BA0745B80743B30741B00A42B0083FAA0B46B00B46AD0B45AC0B44A9
083EA3093D9F083A9B07369409359207328F07308F072E8D062E8D072D8C052D8E042B8E
032A8F032A9304299202258D01218B02218B021F8B041F890620870A1D800F1C78171A70
2818673C16575C10477A113A890C2A810720650B31280F4D061564021E72032477031F63
181F3F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0C956533916C4C9276608A7467A4938E9B8F8EBBB2B0928682
8F827E8D888E5F6686152763041B6C02187301167301147203167501147404147208106A
160D5C2703424C063A6D0B38750936690B3F470C5127116617197D0A1A85061F8F052296
05249A02209A011E9901209A00209D0127A60231B30039C00347D00251DA075FE90159E4
0259E4045FEA0369F40574FC0678FE0677FE0473FD0275FD0276FB0478FD0174FB0272FB
0270FC016FFB026FFB016CF7016EFA0272FA0375FC0374FC016EF80070F90170FA006EF7
026CF80166F70161F30261F2015FF0005CEA015EEB0261EB0362EA0262E70462E60360E3
055CDC065BD7085BD4085CCE0C5AC80C56C01058BC1357B71454B31A52AD1F54A82358A5
2858A22E5BA1315FA136639E4169A04368994C6A98516F9B4F719C4F709B4D6E9B4D6F98
496B934B6B9248688D46668A47658C43648845638A3F5D843957803656802F5380264B7D
254A801C427D193C7D13337A0C2C7907297906267D03257F042381021F7F021E83042085
0720850D2081161A752A196745165556124449124816105303176802227803287B06276C
1E234100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00758E249069438B6E558F7666917C748E807CC5BCB99F9997
9998A05A64830B205D052074031F7E021B8001177C021476010E6C070F651209562D0A4C
47083B58082B5C09294F07323506431F1061121C7F08239106269C03249B012198011E94
001B93001A94001C9600219B0126A3012DAB0339BC0243C9034ED70258E20766F10769F5
0464F00567F3036BF70471FC026EFB0168F70267F80166F70269F90269F80167F70165F6
0062F40162F40161F20060F10062F10267F20165F20369F40265F20063F00165F20265EF
0062EF0265F10462ED015DE50560E6055EE20860E00962DD0A61D60C60CD105FC71762C2
1E60BB2764B53269B23E6EAC4C73AA587DAA5C7DA45F7FA36582A26D85A26D849E70899D
73899C75899C748B9C748C99778C977C8D97808D967E8D977C8C967D8E987C8D977B8E97
788B957588906B7E87667A826578826A80886C7F886A7C8664768060757D60778159747E
5B75805F79855A7281556B804C637E435D7C3952782C487327437527437E113075062776
04257C02237E0323810826840E237F162176141E70071E7403227D032883042D81092A6B
24264000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002ADC0D94693987694A8E72618A706692817AABA4A1BDBDC9
535F841022600F1C6A0D1A75051B7C041D8302187D0816730E0D5B1F05464107395D0B2F
5A0826430424250231160B500B136C051983032295032AA30128A30126A001259F01249D
02249E0228A5032BAC012DAD0130AF0136B60343C6034CD30758E20459E6045DEB035CEB
015AE8015FED0465F50162F4005EF1015DEF035DED015BEC015BEE025FF00263F40261EF
015EED015CEB015CEA015CEA025EEB015CE6015DE7015EE70260E80160E80464E70766E3
0864DF0963DA0E62D4105ECA1860C42265BF2867B93871B84B79B8547FB06186AE6A8BAC
728FAC7892A77E96A48599A384959F87979F8C99A18B9BA18D9CA28A989D849295899A9B
91A1A390A0A38FA0A58A9B9F8B9B9E86959595A0A2929FA192A0A38E9C9F88979B93A2A5
929FA38E9D9D879496829193808F93899A9B8D9B9D8895988390927B8A8C7C8E90778B8B
768B897E94917F93928294977D909576899072858D6579825C6F7C5A6F8050667E3F5979
2D4A741D3D70113475082F7D082F89072F8F062E91032B8F022A8F012889042C820D2A67
2E263900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00AC814986654289695489706194847AA7A5AD6A779E
142464281B644A1B624316641A106D0A177B0B12731D0B5C39063E52072D5A08274A0528
28012C0E023C080C5A031672021E8503239502279E0127A30128A4032BA7032BAA022BAB
022DAE0230B40135BC0741C70541C4013FC20546CB0248CE0146D0034CD8014CDB024FDD
004FDC0155E20157E70157E80156E7035AE7035CE70157E4035CE9035CE9025BE80159E4
0158E30156E10158E30158E2025BE20560E10661DE055DD50D63D41165D11764C5236ABD
3170BA4379BA5A84BC698BB77590B47B93AE8197AD869BAC8999A88A9BA58D9FA48E9FA3
8F9FA49AA9AB99A7A897A5A49DACAC96A3A49EAAAB97A1A39BA6A99BA7A798A2A2929E9D
9CA8AA9AA7A9A0ADB099A6A898A4A69CA7A8A1AAAC9CA6A8A0A9ABA1AAACA1AAACA4ADAE
A1A9AAA9B2AEA8AEAEA6ADB0A3ACAEA6B0B0A5AFB19DA4A89CA3A59BA4A695A1A297A2A3
8894958D9C9B8A999A93A3A391A1A193A2A394A3A5879798879697879697819294778B90
687D86576F7A4B6376415D7D2343750C3579073489043291022D93022C8C052D7C172A5B
16901A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009DB84C966F4984614B8F7466998C8C6B7390202F6B
2E1C616A17508F0E39870F3E500F54270E61330A56590D44650A2F520628320330190742
06064D020B5E031775021F8600239001299A012AA10129A30128A4012AA9012CAF0233B6
063CC0033BC10139C3013EC60647CA013EC1013ABE013CC0013EC30141C90245CD0246D0
024CD60151DB0354E00455E40256E40153E10154DF0155DD0155DE0154DD0156DD0257DA
0458D80455D30759D40C5DD20F5DCA155FBF2367BA336FB54D7EB6618AB67697B8829CB4
8FA4B696A8B894A4B297A5AEA0ACAEA2AEAFA2ABADA2ABAEA5ACAFA3ADACACB8B5B2C0BB
B4BEC0B2BCBDABB5B6A7B2B0A3ADABA5ADACA8AEADACB2B3B4B8B6BDC2BCBCBFBBC5C9C5
C4CAC9CDD0D1CCCFD2CFD4D7D1D3D6D3D2D4D3D1D4D1D0D2D0CED1D1CFD1D2CDD0CBC8C9
CBC8C8C6C5C3C6C3C4C7C5C8C0BEC1BFC0C2C0BFC3BEBCC0C2BFC2C3C0C3BABBBCBBBABC
B9B9BBB0B5B5ABB1B3B0B7B6AAB1B0A8B0AEA3AAAA9CA4A4959F9F95A0A0949FA08D9D9C
7E9091788D8C718385687C815A727E415D75284A74123C7A073182053285082B6F202748
0CC70A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0035E617B38251856044927A6E80798722295A2E1E5D
6F1E519A0E2DA90617A5091E840731690A41690A3B66093048072F23063D0D0A53071166
02136E021676021D8301228E01279802299F0028A1012DA40130AA0333B30336B90339BB
0138BC043BC1023AC1013AC00240C20341C20338BB0236B80137B7013ABC013CBF003EC3
0248CE0555DA0254DB0150D90151DA0252D90355D90255D50355D20656CF0B58CB0E57C0
1B5FBC2664B9356CBA4B78B55F83B27491B27D96AE8AA0B096A7B3A2B2B6A7B4B6A6B3B2
AFB9B8AEB7B7A9B2B5ACB6B7B4BCB8BCC4BEC0C5C3BFC4C4BDC3C2C2C9C7C9D0CED0D4D4
D8DBDDD2D6D7DBDFDFE1E3E3E8E8E9E9E6E8E3E1E2DFDEDEDBD5D7D2CFCFC4C0C0BFBBBC
B4B0B2ABA4AAA199A298909C9489958F828C887A8384777D82757B82737A837178847276
817374786C6C7A6C70786B70776A6C736969776E70766D6C7E74757E7777837B7B867B7C
867C7D8783828D8988938F8D9996969896959F9D9AA4A49FA5A8A4AEB2B09DA4A397A19F
8D999781908C7E8D8B7788876C80806076785B7178435E702545681136640F2A56292636
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0060C52787603B8F79733C3A562B1D54631A4D
980F2FAC0816B40812AC050F9D021687062662072E3706381406420A105B04156C021775
01157501177B011E880224930025990028A0012CA5083AB10336B00232B40135B90136B9
0133B60134BB0238BE0239BE0138BC023ABB0032B30131B10234B30036B5013BBB013FC1
0248CA0048CC014DD10454D50353D00551C90A54C20F56BA1F60B92E68B44978B3668BB5
7792B3859CB790A2BA95A4B39BA7B1A9B3B99DA6ABA3ACAEACB2B4B5BDBDBCC4C1C0C7C4
C6CBC9CBD0CEC4C7CAC5C8CAD6D8D6DEE1DEE7E9E8ECECEEECEFF1EDEEF0EBECF0E3E2E9
D6D4DCC3C2C9B5B2BEA49FAC9891A08E85918376827F727B7C6E75766A7072666B716566
7164646E64636F6362706564726464716261756563766A62776A6073665C75655D77665E
75675F74675B75675D74675D796B6274675C71685C6F66596D64586D6358695F55665D56
645D53635D51625B50635B52645B56645D596B625E756F6A7A7572817D7A817E7B878582
868883868A828489837A837D71807B687975627370596D6C4C636639535B20333C139313
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0034E515976C427765662A2049541E50921837
AA0917B50A13B1040DB1060FA704137B0423360537120F51020C56021366011A73021C79
01187800177C01208B032999022BA1032CA6022FAB0330AD002CAB012EAF0131B20130B3
022FB50134B90338BC0136BA0135B7043BBA0239B70237B60239B7013CB9013DBC0242C1
0447C5084DC4084FBE0B54BA195DB72F69B2517FB67192B98BA4C09FB3C6A7B6C2AAB6BC
B1BBC0ACB5BAABB4B9ABB1B7ADB4B6B5BDBCB3B9B9BDC5C3C8CDCDD2D4D6DADDDDDFE2E3
ECECF0F2F1F3F3F0F5F2EEF6E9E4ECD9D4DFCCC3D2B3ACBC9F97A8908A99827B8B746F7D
6E6A756E6A716C667065616A67666C6D6B6A706B69776D69796D67776E65787066797167
786F64786F62797063786F63766C61756B5F7A6F647A71627A74627A7260766C5A7B6F5F
7A6D61766D5B776F5D796F5E766D5D756C5B776F5D766E5C786F5E746D5C746E5C6F6A5A
6A67576969576B69586D69586B6555696356645E53615A4F6058505D544D60574E625A50
6763596E6B5F75726676756973756D6F766C676F665D696251625B485F573D504427691D
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00809F425947503D1E4879193EAB1222
B70F15AE0D12A8080EB61017AC08177C06252F0A410C1A66031C7103207B022382012282
012084011E87012391032B9E032CA5032AA70228A60127A50127A6012AAA002FAF0231B4
012FB60335BB0235BB0336BB0035B60136B5023AB70239B6033DB6023FB50743B70A46B2
0D45A52657A54774AD6E93BB8EA9C5A1B5C4AEBCC3BDC5C8BCC1C4BEC3C5C4C7C7C4C9C9
C3C8C7C4C9C8C8CDCFCCD1D0CED2D1D4D9D7E0E4E3EDF0F0F2F2F5F1EFF5E7E5EDD3D0DC
C4BDCCACA3B39B8FA38B8195857B8D857A8B867B8A756F7C74707B74727C6D6E75717476
6F73726F7370696F6E626A6B636A6860685F6B6E63737164797265777160757361777563
76705F797260797260797160796E60776E5F7A6E617971607C7562766E5C7A71607C7361
7A705E78705C756D59736D57756D5B74705776705C726C5A756D5D766F5D76705D716D59
6E6A596E6C5C6C6A5C6C69596D6A596C695A6C66576D6859666154665E506A5E4E655D4C
625C4D5E58495E59495F5E4E6462566A6B5E6B6B5E676A5E5963584E6052465747434A38
12CF0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CA9A6F6243515A1F4990142EB8151C
AA1214CD5B5CBF4C50A8141CB10A179709235B14471C1B6906238202258B02278F022791
02299303289501269503299C0127A001239E00219D0227A30129A5032CA9032DAD012DB1
012FB50132B40031B20131B10133B30133B10236AF063BAC0A3FA513479F315EA55E81B5
8AA3C3AFC0D2BCC9D0C5CFCFC7CDCACCD0CCCED2CCD4D7D3D5D9D7CFD4D1D7DCD9DDE1DE
E1E2E3E4E4E8EDEDF1EDEDF1EBEAEEDCDAE1C5C4CFAEACBA9794A2867D8F766D7E6D6876
746F7C827D8797949DA4A5ABA5A8ADA2A6ACA0A4A9888E91737C7E697677687677667473
667473667473636F71646E6F636C6B5E686060675A65695A6F6F62777767767563787461
76705C78725D776F5F766D5E776D5C756E5B766F5B78715D79725F7A6F607C7062776E5E
797060776F5D766F5D756E5B726B566F6B53736E58736E5A756E5E736D5B746D5C77705F
766E61726B5F70695B6F69596C65556D66566F6A5A6D6B5869675768625169604F6B6450
68645165624E58594755594A494A3F4F504659584D6163546166565861514E57494B5040
37712300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065C836743F42721D399B1120B1191A
A12828F5ACB2DA8B99991928AC0B17A907188B113848185E13217E04278F012693002895
022A9801299801279902279E02269F0225A00226A00127A20127A2012AA5032CAA012CAD
0330B00130AE0031AC0234AB0537A708379F16429A30569A627FAF8CA1C1AFBDD2B9C3CD
C3CACDCCD1CFD1D3CED2D5D0DBDDD9DDDEDBD9DAD5E1E2E0E2E4E4EAEBEDEDECF1E2E0E8
D2CFDBC0BAC9AAA5B5928D9E7D7987706B7867636E66646C6C6C71797A7D8E8F92929699
909498878F907C8687717B7B6B7575687171697271626B6A5B6868596967586867586968
56686956696C56696D586A6C5D6B6C5D68645C665E5D655963665C696C61747264787160
77705C76715B756F5C766F5D726B59756F58756E57746E56746E59776E5D776C5C756D5B
7A725F756E5B746D5B756F5C726B586E6852736D57736E597B7565767061767062746E60
726C5E736D5E716B5C706A596F69566E67556E69566E6C596D68576C6553655F4868654D
676653666857565A4C50554A343A323239323F433A4F5242575A476163515F5E50535645
4D493312CE0800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF006BC82A8E472E8720279E171C9B1E1C
BB6767D097A0BC7B88B5505DA4131FAE0612A4081E7E13463619690D2488032896012597
02279801289A01289A02269C0226A002259F0127A10129A20129A20128A00129A3022DA8
032DA6052FA108329A143D952C5195546EA08798B89DA9BBADB5BEBCBFC6C1C4C6CACACC
CDCDCDD1D1D1D5D6D5D8DBD9DDDDE0E1DFE3D9D5DBD0CAD2BBB4C0A79FAD8F86967A7382
6C6573675F6D66606A63616866686C6E74728087857F8885798380737E796C757267706D
65696765696463675F64695E65675E66675D66655C67665A63645A5D62565A5E53575C55
5058554553544053544457594B5D605160605663605C685E60675B64675A6A685C756E5F
746D5B74705B746F5C777060797060776E5B746D57756F59776F5A78705C77705D79735F
756F5C746D5A726A55756D58746B58726954766D59756F5C767061736E607370616E6B5C
726D60756D5D716A596D68586D69586D68556E67546E68546E67576C67546A664F69654D
6362506B6C5F595A533A403B29342F28342D2D392E3C4535494E3D5254415E5D4B5C5E49
56533C29A31500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C0713A8D210C9D1E17B24E4D
D89EA2D9B5BDE5C0CBE3A2B0951C2CB10D19AD04119C09276E1752281B7509238F012596
01249801249902269A01259A02269D0127A00229A30128A000269A032899022799072D99
10329326408F4B5C97717BA1868BA19B9CA8A5A5ACA7A8ABB0B0B3BDBCBFC7C4C6C9C4C7
D0CBCFCDCACDCAC9CFC1BFC8B0ADB997919D8B808B80707A77666D7063676E6365716968
6D6C696B6E6C6E7474697474677272636F6B626C6B6169675B645F61665E67695F6A6A5F
6C6A5D6F6C5C6E6B5B6B6B596E6B5C736F5F77715F7A72607871617A75657D7464786E5F
746B5F5E5B54464A4439423D444D4A4854534D5C5857655D60695D6B6F62757168706B5F
706B5D6F6C5A746E5D746E5E766D5D756E5B736E58736F59756E57736C54756E5A756D5B
776D5C756F59736D56746C55786D5A7B705E776F5C706957726B5A746D5E7D7768898576
7D75697165567164546E65566E69596F6958716A577069576C65566E68586A645268634F
6B695A6465594D4D48373C37303C342F3E33314034424F414B53445355445354405A5B45
5D59412EA91B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007769079E2D18B8615E
A77278DAB9C2BE9EAAE1B1C0A34051AB101FB20410AC0619940E35511560161B82022192
02249901249B01259B01269B01269B02259D02249C01239803269208298B163286314386
585F8D7672918A8095928895968E94A0999CA09C9FA5A4A7ACABADBBB7BAB9B3B7B3ADB2
A9A1A8978F98837C88706773675D64655A5B75676183736983766A7D766B75736972756E
66706C6472715B6B6C54636457605E58605A5C615960635969695E6F6C5F736D5F726F5E
7877658B8B7AA8A59AC2C1BAD1CFC9D3D1C8D5CFC7CCC1B7BCAEA4B6A79AB2A193AC9888
A18E7F9181767E7466645F515A594E484C424651484E5E5458635A64675F7170687D7B70
767568686655736C5E766F60756C5B736C5A716C56706C56746B56766B57756958756858
756856756A56756D57756F56766E59716956776F5C746C58706956726B58756D5E746D61
7A7064796D5E786B5B776C5C777060726C5C716A5A70695970685B6F695A696454666554
64665B52554D41423B3B3F363842363A4737404E404855494D574D5961545F6251555540
5A573E2FAA1B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002CD506A04924CF8C85
E9BFC4EACCD5E1BECBF9C6D6AF475CAC1022B40512B30512A5071F78134A2B167108218E
02259702279903289C02269A0124970125940324910925861C33803E4B825D5D82746C84
8173828B7984917F8792818892848995898D9790939B959C9B959C958D93867F82767171
675E5C615451675A566E615A74675B7C6E607F71628076677F7A6B727067686C67586361
5162624C5F60495B5D4E59575F60576966586D6A5A6E6C5B7876678782779E9C8FB8BAAD
CBCEC3DCDBD8DDDADFCFCAD5BDB6C2A79FA8998F938D807F84726F7E6C647E685D7B6457
7865557A69587E6F5C80735F7C73616E6D5A4F5446414D434D59545B625B63665D6B6B5F
7C7C72817F74777367756E60786F5D766C58736E56726D55716952726B53756A58776A57
776854756955756A54746952776A57756B57786F5A756E59736B58706956726958746B5D
766B5F776B5D7C6F607A6D5D776F5E766F5F726D5F726E607772666F695D666154636255
5A5C53494C4342463943483B464C3F4853434D594C4E5A514C57525D6860696D635B5C4A
58543C2DAA1A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051AD19D19287
D9ADB4CBA4B1C88DA1B44E68AC1931B60C1AB7050FB7060FB108168C10393C15650A2089
02269501249401259602239203238C0726821B307D40477C635E7C6F62757D6C7A7F7078
84727889757B8E7A809181879085898D83868780857B72776C636364595662574D696050
7368547C6E597B6C597D6E5981725A84735C7F705D786F606D6B5F62655F555E5D485958
3A4F4D394C4849554E5D61556C695A7B78688D8A7BA7A497B3B2AAB4B3ADA7A5A29A9896
908B8F8781889187908A8187897F838881808A8180887F79847C737B7467695F516B5F4E
6C5E4D6C5C46746044755E417562487A725A6B6C5B4851453847404B59545B625B63675A
6E6F627D7E71858578807C6E76705D746E57747058736E55766B55776C53766D57756C55
766A54756953716753766E59776F5C78715E746C59756D5A756C5A746D5A756E5C746C5B
776B5E776D5E786E607E73657971607570607774667474676E6E63656156665D545C5A4E
4E4E424B4B3D4E4F40515445525848525C4B545F50525C52505C545D68616A7168676858
59553C2EAA1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C48370
B5838AECC1CFE19EB0A42132B60D17BB090FBA060ABF0F13AE0B1987123D3B1869091F88
02249201228E04268D072582182E79333F72525271685E6E74636C7D69707F6D727E6E70
807172857578847579817679756D6E6A6462605A5560564D695C4D796954806F5785765B
83765B7F73597E70577E6F5582735683735881715A776C5A686558595D56495350344441
33433C4553475B6354727466888579949187928D838A847C857C797F7976867E7B877F7C
87807C7F7C777F7D777F7E777F807A7A7D7478777271716B686C665C655D525A5350554C
515249514D3C6F6044856B4B7C5F3E7560426C624D686B5B464D443A464049554E556053
6367596A6C5E7070628481728784737C786477715E79705A756951796C547A6E59736B56
756A57736854746C57756E5A78715F776F5B706A54766F59766C5A76705B746E586D6652
756958766E5D756D5F7773617773637471647471667172686B6C6465655D5E5B51555045
5750445653435C5A48595B4B5E61525962535862575561575D675E6168616A6D656B6859
5E563C2CA71300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A96C4D
DBA8A9E0A6B6B54C61B71B27C71314C60E0EBE0A0CB40D1795102E5E19571E1C7907248E
02248B062581122B742E3A6E4746665F56676A5D666D5F62736565786969796E6D7A706D
796F6B756B686D6460675D5763594E695E4D72664F7E6F5686755A88765988755788755A
84745A8072597F70577F6F558474568272537E6E52776A536B63515555483D433940493E
5B64576A6F617274667E7B6F7A736A7A73697B756A7B776B7C776C828175808176797C73
777A72727A707079716B786F65716A646F67676D67656B64616A6359645C565D56545850
4D4F464B4A3C6D624B8671537E5F3F785B3974624477745C6265573F484037433F47544D
5961536367556B6B5D6F6C5D807E70878575817C6A7E7460786C54776B53776C57746D5A
766E5A766B57776D55746B54746C58746C59726A55756E57786D5A746A57716954746C57
796E5C78705E767160797766787468767468726F656D6F666869645A5A535352475B5649
60594A645D4D63604F67675964685D5C655A58635A5C665E5F655F5F645E696B636E6958
63573830A60F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0090A346
D39A97E092A1A62634C1181BCE1613CE1415BC121B95153261225D2423790A2989082A87
0D297724356B424765524C5B5E555A655A5D695C5F6D5E5F716362706661756C6570685F
665E535F5647675B4772634C7D6C518371558472548573558A785A8E7C5E8A76588B7556
87745881725A7F70597E6E558071528273517E6E4F776B4E71694F5D58435855446E6B5C
7774667571627672617972627774667473666E73677A82768C938A838E87717F7B677875
5F716D5C6C685C6B6557645C5A655B5A62556264586765566665546765536A66556B6558
6F685D726B5D84775F806B4D7D5E3B795A3679624174684B75726064675D4047423A453F
4C554B565E4E66685A6F6E5F7374647777667C7A677873607A725D7B715C776C58746C59
746955796C57796B53746A52746C58746D5A736B55776E56786C567C715D7F7463776E5C
7B6F617A72647975677777697674697372676E6D67656862565A5655564E5B584D655F50
6D6656716A5D6F6A5E6D6C6063675F5B635A5F69615F6A625F66605E645D65665C69614D
614E2840B11400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053AF19
C4796B95343EA61D24C41A17D11815C6171E9F1A3865296721257C0B2B8908297B1D326D
3B42634B4956554E516057576057555F5855645C596C625E6E645D6B6456665D4A665B43
6B5D417769497F6F4C847150867051856F508672548773558874568A775686734F88714E
86725383725A7E715B7C6E557D705387795A8374567C6D5074684B695F43766D537E755F
776E5A716853746E5C6A6A5D565E574F605B576D6B667D7B788B8D657B7E526A6F496062
485C5A505C575B5E566163536666536968526B6752706D557E7B648C877397918490897E
7E776C7C73617E6F577A6547796140836B48826B4A7B684873664E7673626A6C63454E46
444C44757B6F74766A6E6D60726F60726F5C706C586E6C57706B57746D5A7B735E807863
7B6F5C75665076634A76684D726951716953706650766B56786D5B82766880776B7A7366
7B73697771667370666B6C6167685F6868625F5F5C545753565B535F62556A675A716D5F
747162797669747367686C60636A63616C64636D67646F65636B6162655B655F516D5C41
76592627DD0D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D5226D6867CBE5051BD2221C31618AF203675336C292E800C2D84122F76293762454554
544C4D5A524D5C554E605852645C55666057686259625C4F645B476A5D4172613F7D6945
826D4B84704F8673528976568873548A73548972538872538B755687735384714E86734F
8673528573578072597F72587C6F547F70548371558270537361437E6D4F8473567B6A4F
796A50726751535041313832293B392E4946355254365359364E562E474D2D4346384945
4C554B5B5E4E656452706F5B7B7B68969684ADAFA0BCC1B5BFC0B8AEAAA59A908D837872
7B6D617B6A557F6B51877558806C4F7D67467A623D785D36745E3A7164497A7A686A7164
4E544B5D5E52706B5E756F5E756C59786D56766C55726A536E63506C614E706551756D58
8277657D6F5B77624874624473664B746952766C587B72617F74677B70647971647B7569
76746974756B72736A64675D575B53555853585B575F625B62655A686B5D6F6F63767669
7A7A6D7476686E71636A71636B74696C756D696F69686F63686B606561526E60486E5429
70932200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
23D003A6593DD47471AF2123B724328D386838348514368A1B336E3D415C50474B544A41
5F554A625A50635B50645D506E65576B634F695E486B5A4275603F79633B806840826A43
886F4D856E4F8573568A795F8373578473558573548B77588B7454887152846F4F887452
84714D83704E837051806F52807052816F50806B4D826D4F7C67498872537E69477C6846
807155655C454443333C413736413931443C2F443C2C403B2A3C392D3E3947534B656C5E
8284769E9F94B5B6ADBFC1B8BABCB7A6ABA58C918C7A7E7B716E6F74706E78716D7E756B
8275668878668B79658E7C63816B50745F3F785F3B795F34775D31705D36756A4E6C6C5A
7070675E5A4E706657756C55766A4F74654776644977664C77664F6B5C46756A53756E56
776E5B7E746082705977664A796C537971597C74607B7362746C5C716B596F67596F685C
6261555D6357575D53535A535159535A6259646B60686F616F766674776A7E7E737E7E73
76776C71746671746973776B72766D6C736A6B6E656A6B5F6C6B5B6A62496F5830678C1F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00807F1CA3321EA31A1BA134565A3C851E378D2036713F404F5B4D435D4D3A5A4D39
605843675E4C6D63536D62516B5F486D5E4075614078603E7A613B7B623A806845866D4C
886F4F87705289755888785B847558847657847655857252867154887356937E61897254
836B4B866E4D866E4C86704E806D4B7D6A4A7E6C4D816F53826D50856D4C7D663E7D6A44
827457787059716C5776705D7E7A69909382A5AA9CB4BAAFCBD2CCD7DCDACED1D0C9CAC7
B7B6B4A6A3A38A85897670706C68686D6E68787A71909389A8A7A29F9E9A84857F727268
716C5E8278678274649485729F907CB5AA9690826D7D6948796137735D30705E366F6446
6C68556A665471665075654775634077633E725D3C6F5A3F77654C76664C6C5F46787158
78725D79725F86776584745E7F705B776B567468536D614D675E49655F48605A485C594C
53574B4C594D525D5656625B5C686366716770776C727A6B797F717B7E757A7D74797B71
757770777A71787A7173766B6E71676F71676D6B616E685A756952735F37658C2000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009F390A91211E8545753B3D8A293A793F3C51594A3966513365503368563C
6F614772654C6E6049706046756345746340786542806B4A806C4A826E4C877352847251
8572538875568C7A5C8A795B87785A8B7C608473558370508670518D76568B7453866D4C
866E4A876F48867046836E44836F47816E4B7F6D4E7F6F5488775B8672508069417F6841
7C694B7B6C527B6D557F715980715B8C7F6D9A8E84ACA3A2BDB6BEB0A8B68F8894777277
7068686D645E786F647B7164756E6167685B929288BABCB2CBC9C4B5B0AC9B968F8F877D
7D73647D715E877A67877D6A8D8677BEBCB69D97958A7E718772547D66417761386F5B37
6C62457B745B70624677613D7B633A78603779603C745E3F6D5B3E76674873654B786E59
8076667D72628172607C6B5375644C71634B6C5F45655B41635E455F5E4A5B5E4F555C52
525F57586962596B656070696B7871737E76787F76787E73797F75797F76797E77767B74
797E78787D76777A707174676F6F63716F626E685974664F7B623A6A922400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ED608883825714C723F3F743B37505341366A53346D5631715A39776344
7766467164446D624277694A7B6A4B7C6C4B7C6C4B7F6F5083735684735784735786775C
89795F88755B8D795C88745593806088755886735486705188705088714C877049886F4A
836945846C43826B42826B41856D437F67417D68467D6D4C8070528A795A877150836B46
8068447D67457A6442755F3C77603F7D67497E6752816B607F6A667B6967766967706C67
82807B7C7B6F827C6B867A667C6E59837A648A816E8E8476968A7F968A7D9488778F8370
887A67827560877864857967857D6F847E77877F7A877C728E7F6A8E7B5E826D4B735B38
726142776A4F7564457C66437C633E79623A8068447A66466C5D3F77694C7667517A6D5C
8173667F71617F6D5977664C7162486A62466961476360486060515D64585F696057665D
59686261716E6A78776B7A7774807C78837B77817A7981797A81797B81797D807B7C7E77
777B7273776D74756B7371656F695C71685478684C7E633672962900FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0076892C6E4F524635424F3930644B2E7259327961397D65407B6643
786746685E3F6E674B766A4F7B6B4D7E6D4C7F6C4A7F6E4E81705484735A86755D82745D
82745B8A795E8B795C8D7A5C8D7A5D85745886745790795A876F4C846D44866E45866B45
846843876B44846B4285684084673E85693E7F663B7661367766408170509380628B7354
8B704F836845826741856A41856941856D44846C448269487E674C7A6A564B493E4B5552
838F8D868C88979589958B778C7C668A7B6491806992826B93836D94866E93846D8C7C65
8B7965897A638778628A7D6B877D6D867E728C82778E81728A7A68837358776343735E37
73613C7464457B6A4E8170537F6E4F806F508473567E7058796D557B6F587D705C7E7564
7E73637E715F7A6B577167516B66516A69566A6A5B666C5F6A716C6A75706B76736F7D79
6C79756D7B7772818072807F74817F79847F7A838178817C7F857F81867F80827B7C7C77
7D7C737B7A6E787569786F617B6B577E664789673650BB1B00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0F653C1B50341E5D412371552F7F633B8269407F67407E6A49
6F6247655E496A665075694F7C69497C67427F68428068447D6744836D4E837057817358
8274598475598B7C628C7C6084735585735585704F866F4C836A4482693F846B41846B45
876D48866E46826A3F836A3D83683B856A3C84693A7D6435775F3278633A846F4D90785C
8E7457917556896C4982663E856942846B41826A3D7F693C7E6943776A4D65685822322B
475654969B9BA8A29F978C80887A6A83725E86735B88775E8C7B648B7C65907E69907E69
8F7D698E816C897E6C857C6C857D708881748B82758B7F6F8B7A677E694E745E3B7C6A43
8776517C69487E6E537F735B817861897F69877E6A817A67827A67857C67857D697E7865
827C6B827D6D817C6E7A7A6C7C7D73757A72747D78707D78747F7A7F8A877F8989818C8D
7F8A897D88857785837383827A8888808C8B80888983888784868380827D7C7D787C7D77
807E787B756A7E72617E6C5084643C6E8F272ADE0F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00653D085B3B13674B227E6337856A407D663F6F5C3C63573D
6F6A585B5C4D6768556C634A7562427A633B7D633A7E623A7E633B7F66427A6748817156
8375597D705484765B87785E8775588771538169487F6841806A40836C42816A41846D47
846D4A826A44836C42856D41826A3C866E40836B3C876A3C8366377D63367D653F7F6A4D
8C775E8772558B7252876F497E643C7C61357C61327B63337B653B73674571715B828A7D
9EA49EEBE9E8AFA6A7877A7094826E9B83699C83649A846494816897826AA08770A28C73
95846F89806E8D86798E8B7F7F7B6F888478847D6F7E72617767517D6C508E7C5D948564
918363807152867860877E6B8A82708C85738B8676878371857B68887D678B826E8C8676
918E8190908492928B8A8B868B8F8D8A8E8F848C8E859191859190899495889294899294
83898B89939284908E7F8E8B808D8A828E8C83898C8285848385827A7C797979747A7871
7A756A7B6F5E7E65488A683650B91B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006B470F67481A7D5F3185693B80683D6959354C422B444030
5052445E64556269586F705C6F674D736344735F3C7A63417C66437D6A497A694B7C6E53
82745B80735986775C857458847154846F50816B467F6A407E6B407F6C44836F48836E4A
86714F856F4A867047886F45866C3E856C3C856B3A866A3A8569398367397C60387A6341
7A6648826F538D7A5B8C77548C724D8164397A5C2C795E2C795F3176643D72684B827D6E
8A878093908C8C827F8B7A68AF9375BC9B7AB99674BA9C7DAE967BAF977EBA9F84B89D84
9B8675877C6F888075857F737C7467756C5C74685482735A9282678F806386765B85775C
887C618E8769978F79938C7C90897A8B8475837E6E898370968E7AA79D8AB1A89AA9A397
A7A49BADACA5ADADA9A0A2A1969A9D9CA0A39A9EA1979EA1939A9D8C9596949E9F919C9D
92989A929B9A8E9797848F8D838E8D7D86867D85827D827D7C7E797777727A766C7E7461
7C6B4C846A3B72942700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0020D404704B157D5C2C89683884683B70613A59553A494839424438
3E4539445042576355656F626F7263706C5B746A55776B53786C517B6F557B6F567B6E56
7E705980735B82755A837157826D50816E4D806C46816B43867049866F4D846F4D857250
85735086714E89734E876D44866B3E84693B886D3F85693B896C3F85673A84683C7E663D
7B67407F6D4881714F8272518C77578F775181673C7E62347B613278633772613E766A52
80796A7F7C70847C6D9B8970C8A88AC8A485C7A489C2A68DB6A08AB09985B09682A98F7A
8D78677F70618174647C705B80715A83745B887D61887F648379628279618B806A958C76
99947C9390788C8777847D718B877A999789B0B0A2BEBFB1BDBDB0BBB8ADC2BCB5BFB9B5
B5B4B0BABAB8B5B5B5AEB2B2ADB1B4A4A8ABA7A8ADA1A5A8A4A8AB9CA4A7969FA399A4A6
97A0A28E989886908F838C8A7F87867D8383797E7A7B7D777C7A737C75667E6D5382683B
6F95272ADF0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA5067C531C89673388693B7A643E6A6248595C4B50574C4A5248
444E443F4B3E455245525D54676F6774776E7672687974647A776278745E76705B776E59
7B735D7A6F5A7E715B7F7057827055826F517D6A487F6B47856E4D856E4F8A76568C7859
88755387755387735287714C876F46866F44836C41876F44866D43876E45836B43836C44
836D4784714F8474538070518675589686679786648B78538470487C693E75623971613D
74654B776D567066507A6950987F669C816999816C94806D8574647F705E86736185735F
8373608779648578637F755E827861857C678C847096927E9C99859D9A8495907F8D8D7B
979985A0A591ACB1A4C0C3BBC5C7C3C8C9C5C8CCC7C2C6C1C5C7C4C3C3C1C4C3C2C7C5C4
C2C2C2BDBFC0B4B9BBAFB6B6ACB6B5ADB4B4B2B7BAA7ACB0ABAFB4A3ACAE979FA4919A9D
8B9396848D8E8088867C868078807E787C7978766F7E76677D6C558266426F942D28DE0E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA504875C218E6B3783683D72664868685660685C5C675D536056
535F554E5A4E49554948534A4D585260696380877F898F847B8173737668757466726E5E
75725F7B75627D745F796F5A776D567C6F567F715583725686735789775A8A785C87765A
87765A8574598574588675578674538876548877548979568979578979588B7C5D8C7F5F
8E7E618E7E628C7C6089795D85755B86775D8F80689589709B8F739A8F6F9488648E7F5B
9080608275567F7558807659887A608E7E6693836F95897598907DA59E88B6AC97BBB19C
B7AC98B2A994B1A997AEA898A8A394A19E919D9B8EA1A393ACAE9EBBBFAFC9CBC0D7DDD1
E0E7DCE0E7DDD7DDDACCD1D0CDD2D5C6CDCEC3CCCCBFC7C6C5CACCC3C6C8C7C9CCC3C5C8
C3C6C8BDC1C2BEC3C3BDC4C4BBC4C4B8BFC2ADB4B8A7AEB4A1A6AC969CA28E94998C9095
868A8E8183867878787579747979727972657A674E85673F7596302BDF1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0043A80593692A8E6D3A78633D79745E6B6F63687167657366606E63
616E645C695D55635655615855605956615C5A656263706C87948D8A938D7A7F78777B6F
797B6D8080707B79697A78667E7C69807B67867E68867D688A80698D836B8A80688E836A
8D846D8B836C8A836A8B83698E866B8E866C91896F90886D8C84698F876D938B71918B71
958E75988E769A8C7695887091846D8A7D67867863847961837860867E648A83698E876C
938A6F958E7299947B9C97809D9780A09783A49C8BA4A08CA2A18FA9A696B2ADA1BAB4AB
BFB7AFB8B1A8C1BEB6CFCFC8DDDDD7E9EAE3F2F3EDF9FBF6FCFDF9F6F8F4ECEFECE8EDEC
DFE6E6D9DFE0D3D7DBD2D4D9CCD0D4C6CFD1C5CED0C5CDCFC3CBCEC7D0D1D1D8DACED2D6
CBCED3C6CACEC6CECEB9C3C4B2BCBEABB6B9A4ADB19AA3A8979EA195999D8B8E92898A8E
8180837D78797F746E7B6D5C78634688693E4AB71D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AAF09956A2982613279674A82817170756E6A746C69766C6B796F
6D797069766D68746C68746F6A767163716C61706D60716E6471706A7674707C77858E88
8C948C8D938B888B82858A7E8B8F838C8D808889798786758785738987748A89778E8B7A
9591809493809595819A9A849D9B849B9884979681928F7A8D8A7289856D918C75939079
9B98819A978296907D9A947F9E98849F9B86A19D889F9B849E9B84A29F8498957B98967C
99937D98947E9A96819E9D89A3A38FB1B09FC3C1B4CDD0BFDEE0D3EBEBE2F5F5F0FAFAF8
FFFCFCFFFDFDFFFDFDFEFEFDFEFEFDFEFEFCFEFEFDFEFEFEFEFEFEF7F8FAEAEDEEE9ECEE
E0E4E6E3E8E8E0E2E5E2E3E6E2E4E6E1E7E8E1E7E7E3E8E8DEE3E6D5DCDFD7DEE1D1D8DE
CACED6BDC3C9BCC3C7B3BBBDACB3B8A3AEB1A0A8AA99A2A4969C9F8F9293858382807975
7C6F667968528265426D922E54BE2100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0029DA079C6C298564347F71537B7E6F7A857C6F7D766A79706A7972
717E7775807C767F7D7882817986847686847181807C8B8A7C87877C87837B8784778582
7C89867E8B8986928E97A29C9DA6A09EA49CA3A89FA6A99EAAAC9F9B9F929AA0939A9D92
9EA0959DA0929FA594B4B9A7C2C4B6BEC0B3BBBFB2BCBFB1B7B9A8B3B6A5ADAF9FB5B8A8
B9BDAEC2C5B6BCBEAFC1C3B4B9BAAAB7B7A7BEBFB0B9BCABBFC4B1C6CBB6C8CAB8CDCFBD
D5D4C8DFE0D3E9E8DEEEF0E5F4F5EDFDFEF8FEFEFAFDFFFBFEFFFBFEFEFCFEFEFDFEFEFC
FEFEFEFEFEFEFFFFFFFEFEFEFEFDFDFEFEFCFDFFFEFCFEFDFEFEFEFDFDFDFAFAFAFBFCFC
FCFDFDFDFEFEFEFEFEFEFEFEFDFEFDF8F9FBEEF0F3EBECF0E2E5EBDADDE2D3D6DDC8CFD5
C2C9D0BBC2C7B4B9BDACB1B7A9ADB2A2A8AB9FA3A69598998F8C8C857D767969587B6143
916D3F4EBA202BDF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF009E671F845F2C7D7151777B6A758076717E7874817D727F7D
7681807882827A8385818B8C838E8F8996968593938894958995968E9B99919D9B8B9996
92A1A091A1A28F9E9F9AA8A8A7B3B3AEB9B8B9C3C1C5CEC9CED4CEDCE3DBDAE0D8E1E6E0
E0E4DDD7DCD3D2DACFC9D2C7C6CEC5C4C9C4C3CCC5C7D0C9C6CEC5C5CCC3C7CEC5CAD1CA
CBD1C9D1D8CFD3D9D1D9DED6E0E3DAE2E6DDE7ECE5ECF1E9F2F5F0F6F9F1FBFCF5FDFEF9
FDFEFAFDFEFAFEFEFDFDFEFAFDFDFCFEFEFEFDFDFDFDFEFEFEFDFDFEFEFEFEFDFEFDFDFD
FEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFFFEFE
FEFEFFFEFEFEFDFEFEFEFEFCFBFBFBF5F5F8EBECF0E3E7EADEE1E7D7DADFD2D3D8C8CDD0
C1C6CABABEC1B6B8BCABADB1A5A7A9A3A3A296928C83796B79644C8B6D444BB8202CE011
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DB098F64287A63407F7D6B78817772807775857E778782
7B8987838F8F828D8C8A94938D98988E9B9C8D9C9C909E9E92A0A097A5A499A7A49FABAB
A0AEAF9BAAAE96A5A8A5B2B4B6C1C3B9C4C5C2CCCBCBD4D4CFD8D7DBE3E0DDE3E1E3E9E9
E5EBEAE8EFEBE7EEEBE3ECE9E6EDECE4ECE9E3ECE9E7F1EEE8F3EFE7F1ECE5ECE9EBF1F0
ECF1F1F4F9F6F0F4F4F2F6F4F5FAF9F3F5F3FAFCFCFBFDFBFEFEFEFEFEFDFFFDFDFEFEFD
FFFFFDFFFFFFFEFEFEFEFEFEFDFEFDFEFEFEFEFEFEFEFEFEFDFEFEFEFEFDFFFFFFFEFEFD
FEFEFEFDFDFDFFFDFEFDFDFDFBFBFBF8F8F8F9F9F9FAFAFAFBFBFBFCFCFCFEFEFEFFFFFF
FEFEFEFEFEFEFDFEFEF9FBFBF1F2F4EDF0F1E8ECEDE3E7E9E2E5E8DCDFE1D4D5D8CBD1D3
C2C6C9C3C4C5B9B4B49D9692877A6D846F578E6F49779A3558C12500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00748F1B8361307C6C527677686F7A6F79887E788881
7F8F8984939085929294A0A095A0A198A5A595A4A49AAAA99BAAA9A2AFADA6B1B0A9B3B4
ABB6B89DA9AB99A5A8A1ADAFB0BCBCBFCACAC6D1D1D1DCDDDCE6E6E0E8E9E2E8E9DFE8E7
E3ECEBE9F0F0E6EDEEEBF1F3E9EFF0E8EDEFECF1F3EDF3F4EBF4F3E9F1F3E9EFF1EDF3F4
F1F5F7F2F6F7F3F5F7F4F8F8F6F9FAF5F8F7F8F9FBF7FAFAF9F9FBFAFBFCFBFCFDFCFFFF
FBFBFCFAFCFCFBFCFDF9F9FAF9F9FBF9F9FAFAFAFCF7F8FAF8F8FAF9FAFCF6F7F9F5F6F8
F4F4F6F1F3F2F4F4F4F4F4F6F3F4F6F7F9F8F8F8F8FBFBF9FCFCFCFDFDFDFDFDFDFAFAFA
F9F9F9F7F8F8F5F6F8F2F3F5ECEDEFEDF0F1E9ECEDE7ECEDE1E6E8DFE0E1D7D2D6C6C0C2
ACA2A195847993775E9A764C4DBB242BE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00718D1E816135786C537A7D6D7D857C7A847F
828E8884938F8696948F9E9E98A6A69EACAC98A7A6A5B3B4AFBABCAEB9BBAFBABBBBC6C6
BFC9CABFC9CABAC5C2C0C9C9C6CFD0CDD7D8D6E0E2E2EBEDE5EDEFECF1F5E7ECF0E7EEF0
E4EEEFE7F1F3E6EEF2E5ECF1E7EFF2E8EFF3E9EEF3E5ECEEE8F1F3E5EEF1E5EDF0E5EEF0
E6EEF1E1E9EBE6EDF0E2EBEDE5ECEFE6ECEEE6E8ECE8ECEFEAEEF2E7ECEFECF0F4E4E8EC
DFE4E7E1E6E9E2E6EAE6E8EDE0E0E4E6E8ECE6E9ECE8ECEFEAEEF1EEF3F3F0F3F5F2F3F5
F9F9FBF7F7F7FAFAFAF5F5F5F9F9F9FCFCFEF5F5F5F8F8F8F6F6F6F7F7F7F6F6F8F7F7F9
F7F6F8F3F4F4F2F5F4F5F6F6F2F1F3F0EDF0F1EEF0E0DADDCDC7C5B5A8A1A1887E9A7A65
A47C5955C02B2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00708D1C8161337F71557D7C6B7F837A
8790898996928998968B999993A1A297A6A79AA8A9A5B0B3ABB5B9B4C0C3B6C4C6C6D0D3
C7CFD2C7CFD2C6CFD0C3CDCEC3CDCFC2CDCFC6D0D2C9D3D6CAD4D9CBD4DAC9D0D8CAD3DA
C8D5D9CAD7DDCCD7DDCED8DED0D9DECED7DCD1D9DCD1DCDED2DDE1D1DBE0D5DEE3D3DDE2
D0DCDDCFDADCD1DBDDD3DDDFD3DDDFD8DFE2D9DDE0DEE1E6D9DEE2D7DDE1E0E2E7E0E2E7
DAE0E3DDE5E7DCE1E4E2E7EAE3E7E9E4EAEAE6EBEEEBF0F3EAEFF2EFF5F5F2F6F7F3F4F6
F5F5F7F5F6F8F3F4F6F0F1F3F2F3F5F4F5F7F2F2F4F4F5F7F5F6F8F5F5F5F5F5F7F8F7FA
F8F7FAF8F5F6F7F2F3EFE6E8DCCED2C3B1B1B19A94A58778A9856684A5465BC32D30E215
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D90B88612B81674481755F
87847A8D938E7D8683848F8D8D9A9998A5A39EA9A8A2ACAD97A2A4B1BFC1B1BCC2B7C1C8
BEC8CBC0C9CDC4CCD1C1CBCEC1CCCFBFCACDC4D2D3C5D3D5BDCBCEC5D0D4C5CDD2C8CFD4
C6CFD4C5CFD5C6CFD4C5CFD2C6D0D1C1CBCCC7D2D3C9D5D5C9D6D7D0DADCD2DADDCDD7D8
D2DCDDD0DADBD5DDE0D7DFE1DBE3E5DEE4E7DCE1E4E0E5E9E1E6EAD9E0E2DFE3E6DEE3E6
DCE3E6DDE7E8E2E9E8E2E7E8E2E6E9E3E7E8E6EBECE8EEEEE8ECEFEAECF0ECEDF1EDEEF0
F0F1F3EEF1F0EDEEF0EBEDEFF2F3F5F4F4F6F3F3F5F8F9F8F6F5F6FCF7F9F8F1F3EBE1E4
D6CAC9C5B1ABB69A8FAC8879B3866EB889615DC53230E31700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B112876431
806C4C89806C8584767E8279858C8698A19C9FA8A5A2ABABA6B0B2ADB8BAADB8BBAFBABD
B3BEC0B6BFC2BBC5C9B5BFC3B7C1C4BDC7C9C3CED0C4CFD2C2CDD1C3CED2C5D0D2C9D2D4
C7D0D2CAD3D7C4D0D2C5D1D2CBD5D7C3CDCEC5CFD0CAD7D7CAD8D9CDD9DAD0D9DBCDD5D8
CCD5D8CCD5D8D0D6DAD2D7DAD2DADCD7DCE0D8DDE0D7DCDFD7DCDFD6DEDDDADEE1DBE1E3
D9E2E3D7E0DFDBE1E1DBE1E1DBE0E3E1E5E8E0E3E6E4E7E9E5E8EBE9EAEEE9EAECEDEEF0
EEEEF0EDEFF0F6F5F8F8F5F6FAF6F8F6F0F0EBE2E3DCCFCDCCBAB7BCA39AB69385B38A74
BA8D688FAB4A5FC52E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB517906B35866C4487785A897F6B918C7D9A9A90A4A49FA9ABA9A9AFB0B0B9B8ACB6B5
B2BCBCB1BCBBB6C1C2B7C5C6B3BFC0B9C4C5B9C4C6BCC6CABFC8CDC0CACDC4CDD0C1C9CE
C2CCCEC0CCCFBFCDD0BFCBCDC4CED0C0C9CBBDC6C9BEC8CABFCBCCC0CDCEC5CFD0C5CED0
C8D0D2C7CFD1C9D1D3C7CFD1CCD4D6CCD4D6D0D6D8D1D8DBD4D8DBD7D9DCDADBDCD7DAD9
D4D9D9D4DAD7D8DDDCD7DEDDD6D8DBD8D7DBDAD8DCDFDDDFE7E4E8EEEBEDF0EDEDF3EEED
EBE2E0DFD4D0D3C1BDC8B0A8C0A397B29380B59075B78D688BA9485EC63031E31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADF0E48B518906C358C6E448A7152907C66998A7BA79F93B0AEA4ACADA7
B0B3AEB4B9B5BCC1BFBAC1C0B3BCBBB3BBBBB6BCBDBFC5C7BEC6C8C3CBCDC1C7C9C0C4C6
C5CDCDBEC9CABBC8C8BDC8C8BEC8C8C0C8CABDC3C7BCC3C6BDC6C8C2CBCBC6CFCEC7CECE
C7CDD0C7CED1C9CDCFC9D1D0CDD2D4D1D6D5D1D4D3D4D8D7D6D8D8D7D8D9DADAD9DEDEDB
DFDEDCDCDBD7DFDCD8DEDAD7DFD6D4DACFCAD0C1BCC6B5B0C5B1AABCA498B29888B39582
B28D72B68C668BA9495EC73162C93031E31600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002BDF0F4DB61C47B31E95724390754F8C755A
907E689787759F9082AA9E94B3AAA1BCB4AEBBB4AFC4BEB9C0BDB9C9C6C6C8C4C4CBC8C6
CCCAC8C4C6C3C6C9C5C8CCC8CCCECBC6C9C7C4C5C6C6C4C5C9C7C6C9C7C5CCC9C7D1CFCD
D1CFCED8D4D4D7D2D1D5D1CDD2CFCBD5D2CCD7CECAD7CDC7CABFB7C4B9AFBFB1A9BAA89F
B8A195AE9584AA8E78A98C70AC8A6BB18B67B5885E88A7465DC6325FC82F61C82C31E416
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
56BF234FBA204AB61F47B4219D754A98754F95745293765695785F987B669C816D9F8470
A28977A08978A48E7BA48E7AA4907DA69280A5917FA8917FAA927EA78E7AA68D7AA38876
A38774A48771A98971A7866BA48568A0805FA3815FAB8660AE875981A33F55C02C59C32D
5EC62E2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0106283 0.97619 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF800000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 178.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000/R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooolR
003o000F01O`2@0]h140;^0A04C@6P1L`2<0M;<_08bS=P2bSdD0^hQ:0;f7C02mQdd0_HI<0;V5B`2F
W3/0Rj@f08ZT=P2;YCP0RjHh05g49`0^hA80;n8C02oR52000?l02OoooolR003o0003043P0020`000
P<000080P<0000<0`:000?n0003oP0002P3oP004083002000?l0cOooool000[ooooo7P00o`005@0F
k`T0F;lR08:M<@2]OT40[7e20:mm@P2cP4D0/X570;:0B02dPDd0]7m90;R0A`2fPT/0]H1<0;N1B`2h
Q4h0]85<0;B1B02ePDL0[ga00;:0A@020:mmA0070:]i?P2]O3d0[W`n0;60@P2aPdD0K[4]02cP4P0L
003o00Wooooo7P00o`000`20`000oh000?n0000K0?n001`00?l0cOooool000[ooooo6000o`00:@0R
j0h0EkdP05Jm8@21WC@0Oide08fE>`2bOdX0]H9>0;R4E02lQEH0`XEI0<^7G03?Qel0chEL0=>2F`3D
Oe`0eg]J0=QfE@3FME@0eG9C0=IdE@3EMEL0eGQJ0=AlG03>OEX0agmI0;V0F`2fQUl0]8MK0:n2DP2/
Odh0[Wm<0:QjAP2UN3h0YgHk0:Ug>P27Sbh0OYX[09B:<`1eXbL0:mh>01L00?l02OoooolH003o00<0
P<009@3oP0000`20`0000?l0003o000E003o0<gooooo000:oooooaD00?l001<0:]dA05Bk8P28T3D0
[GU50;=kB`2iOE<0aWeI0<UeE03=JTd0dUi70=M@?P3IAcT0f3d^0=Tb9@3L;B80gRXN0=lV6@3Q91D0
gb4D0080hQhF01T0halG0>@N503R7180iR4F0>4M503M71@0eadD0<0I4P2B3@/0RQHB08XL5@2>:200
ScDZ09=2=02FD3d0WF=90:UfE@2/OUH0Yg]?0:IiA02QMCT0XW8d0:Ec<`1_WQl0D;PE01D00?l02Ooo
oolE003o0080P<00:`3oP0000`20`0000?l0003o000C003o0<gooooo000:oooooa800?l00380:Md?
05>k802=Qc/0ZGQ:0;5gC`30MeH0bV]?0<aI@`33?2d0b2DJ0<hN503E6A80gAPC0>@H4@3V5`h0jAXC
0>XJ4P3[6Q00lAhB0>lN4P3d8AH0lb0D0?@O503f81H0lQhD0?@O503d81<0m1lC0?<N4`3b7A80k1`A
0<`>2@2Y0PD0Y@<70:011P2L10P0U0<708l42P281@T0N@L906l=3@1b6QH0PSP^0:5ZD@2ZO5T0Z7U@
0:=b?P2JJBh0UVDT07NB71@00?l02OoooolB003o0380oh005000o`3=ooooo`002_ooool@003o000g
00_g1@1C_2<0UH]10;9jD`2iJD/0_D`h0<4i;035:1l0baTB0=4B3P3G4Pl0h1<>0><D403U5Q40iADA
0>PH4@3Z5a00kQ/D0?4N503b7Q<0m20D0?@Q5@3d8AH0mR<F0?XU6@3k9QX0nRDG0?`W5`3g8Q<0nR@D
0?LR503e8180l1hC0<T91`2g1PL0]@L90:`11P2[10T0Y0880:822@2M0@H0UP<908X22P210PP0O0D9
07@82`1c4A40OBDN08@o;@2?EcL0VfLo09aZ<`25NQl0BK0:02g;0`0A003o00Wooooo4000o`000`10
h000`:000?n0000b0?n00080P<004@00o`3=ooooo`002_ooool<003o000n00[g0`1@^AX0OITb09^9
@02fLD/0]e8j0;8g:02Y6a@0`A<@0=0>303E3@l0fPh@0=h>3@3R4@l0ha<?0=`>3@3G2P/0e`X:0=L9
2`3K30/0i1<>0?4M503j8QP0nR@G0?/U5`3j9QT0oBXK0?d[6`3n;1d0oRhK0?h/6`3l:1L0o2DE0?/S
503j8a@0nB8C0>hM4`331P80`0X90<8:2`2h1@P0/@@90:l42@2/0`L0Z0870:@21P2G0@L0S`4908/2
1`290@L0R08708D220200`T0N@H906l92@1f7A@0Q4D[09EQ=`2DHB/0Jf4;03jU100Cj`<>003o00Wo
oooo3000o`000`10h000`:000?n0000i0?n0000308300010h0000?l000d00?l0cOooool000[ooooo
2`00o`00@00Ek`P0QY<a0;25@02gKC@0/2lJ0;TH3`363P/0b@X:0<l;303D3@/0f10<0=T?3@3P4140
j1DA0>/G3`3U4`/0e0L60=<7203E2@X0fP/;0=d>2P3N3PT0jQH?0?/X703f<B00lcHS0?8n;@3aAC<0
lT/h0?Hk:`3n<Al0oc0L0?h]6`3n:AT0oBLH0?`T5P3g9A@0h1lB0;T51@2o3@`0_P/=0;<8302Y10P0
Z`D90:X4202W0PT0Y`<80:43202K0PP0U08608X11@2<0PL0R08708@21P2810P0Q0<807h32@1j1@/0
L@L707DM4`27BbP0ReTX07AE400i/0<=003o00Wooooo2`00o`000`20`000oh000?n0000l0?n00003
0<2P0000o`000?l000/00?l0cOooool000[ooooo2@00o`00@`0Ue`80Rh4R0:Yi@P2gQcP0b9/M0<IV
4P2g4040`@P70<L9203<2@T0e@`<0=`A3P3C40`0jbl/0=TA3P3Y5Q00kAT?0?0L4@3O3`P0fP/80=T;
203J3@T0g@l80>0@203b7a<0g28H0>YkK03m/J@0olJl0?oCb@3of<d0l7U]0?`d803m;aP0oR`I0?hY
6`3n9aT0nRPH0=hn;03CF4X0[1LA0;XC402d2`d0YPH:09/4202L1@P0Y0D70:D21P2T0PL0VP4509<0
102F0`H0Q@4508@01@230@D0M`0207X00P1g00<0MP4507/11@1m0@H0OP@;06`91@1/8@l0TU`g07U3
4013Y@<03000o`09ooooo`T00?l000<0P<000?n0003oP000@03oP00<003o0<gooooo000:ooooo`P0
0?l004H0>LL=08Yn;P2UESH0V3@D0<=l5P3AX`H0b6T<0;XC0`3120L0b@/80=4<2@3G3@`0f`l>0<X=
303G9bD0ea<>0>`J3`3^6`d0lAd@0>dL403^81D0iadB0=TG3@3U7a<0lBDG0?XZ703E9Ad0WEYE0?_/
j@3hl>l0n??a0?Wbk`3b[ZT0mSLU0?d_6@3o;AP0oRXH0?dY603T:a/0_gAX0?cOe`3TYid0cFUP0:/]
:02E5a40RAD?084K4`2S=B`0Zb<P0:452P2L0PT0TP8808`11@280PD0Q`4408T21P220P@0O`4407X1
101e0@<0N@4507l21`210`P0O@<807851`1Q3`P0NC`Q07i5501<Q`807>032P00o`09ooooo`P00?l0
00<0P<000?n0003oP000@P3oP0000`10h0000?l0003o0008003o0<gooooo000:ooooo`H00?l004T0
4n`407V6:@1nCRh0L2<E09/=2@2/4@<0bgHB0=6U1034K@`0]a@20<<:1`3>2`T0e0`90=/?3@3N4@d0
gaHA0>@O6@3Y6A00jaT>0>PL403H8QD0fU530>MiK`3^TXH0mJZN0?J[W`3dX9@0lX]o0>AYGP20>380
hM7=0?Odl`3dlo40m?;a0?_Jf@3/@SL0oC4N0?`_703c<Al0ec<S0<MXF@3fi]l0m??b0?GclP3hl>h0
k]G>0>70]03L_:h0f[RZ0<>9OP2@8B00U`<:09H12@2@0@P0S`4808/11P280@D0R`4708T11`230@H0
OP4507l21`210PL0PP4708D22@250PX0MP4406@10@1K0`40H1X<07Pl6@1eC@T07=l200T00?l02Ooo
ool6003o0003043P003oP000oh0001/0oh0000<0j6Pl0?n0003oP0009`3oP0000`10h0000?l0003o
0007003o0<gooooo000:ooooo`H00?l004T0Q7dW05Xa6@101`80F08409X72@2a40@0bVlB0=FY103>
MPh0_AL30<`=2@3@2`T0eP`:0=/?2`3L3Ph0ga<=0=lB2@3V5`d0hQT?0<8P5@36I5X0o]gG0?[]j03h
l>/0m_7_0?Kbl03ilO00nNg[0?kZi@3hh=P0knKP0?Cbl03cknh0l_3^0?W[j03OHEL0icl`0=Y2=03@
HUD0jjnV0?k[i03elo40l_?c0?7bl@3_ko00iN3N0>KJf@3WeLl0[Wmf06lB402=1P/0W@<:09/3202E
0@P0UP8908`2202>0`X0S@4808`120270@L0P04607/11@1g0@<0N`44080120210`P0N`8506P0001P
0@40F0820506001e=aH0CH@100T00?l02Oooool6003o04T0oh002@00o`3=ooooo`002_ooool4003o
001=01kT2028PS00G38F03T7100n10L0E@<708l51`2/3@80bFL@0=NX103EP@l0_aP20<h<2P3A2`X0
eP`=0=P<303K3`h0gA4=0>0D3@3S5@h0^Q@@0:MFCP3eem40mNcZ0?7Wi03bgmd0ilc;0>?5a@3Wc</0
k=OF0?CWiP3fk^d0mO7^0?;bl03bl>h0l_3_0?Kal03fc/L0mLFk0?[Gd03kj^D0nO3_0?Kbl`3dlo<0
lo?c0>o_k@3Wi>40i=GA0=Rj]02eO7H0O1TF08841`2A0PP0W@8809X11`2F00L0U@8808l1202>0PT0
R@4708T220230PH0NP4407800P1c0@80MP4307X11`1l0P@0OP<607T31P1]0P<0HP4205P10@1H2`@0
MC8<05690`0:m@401`00o`09ooooo`@00?l000<0@>000?n0003oP000B@3oP0000`10h0000?l0003o
0005003o00Sooooo8@00o`004@0<n0H0;n8G06Vn=@1Z_SP0SJY<08^]D@2]V6D0Xj9W0:25J`2VSFh0
YXY]08^hIP2gVWd0Y:]b092hI`0ekR/0<^`Y02L00?l02?oooolQ003o0004043P0020`000`:000<2P
00@0oh001@3@D7P20?n00080D91h9`00o`0;ooooo`002_ooool3003o001>01C]1P2]WfX0`jnT03<A
3`0e10L0?P@805/4202D1@P0/@d80<QF3@3FYP@0ehX@0;PH0@392`P0bPP80=4:2`3E30X0f0d;0=`>
3@3P40`0h1<>08/=303?/Zl0m]kI0=:5P@3:EeD0`S@d0;lN7@306a`0_AdO0;/V9@2l?C/0bVEV0:Uj
NP3^inH0l_3a0?3_kP3aknl0m?;a0?Gcl03flo<0m_;c0?Gbl`3fl_<0m_7`0?W^k`3Pb/P0aYR?0:5@
B0297QX0RPL90942202?0@P0T@8609l22`2O0P`0V@4709D21`2>0@L0S@4608T21P270@H0N@4306l1
0@1^0@40M@8307T2101m0PD0N`8307H10P1h0`H0NP@806l20`1X0P<0G08105/=0`1^:0H0BY831`00
o`09ooooo`<00?l000<0@>000?n0003@D7P0BP3oP0000`30X0000?l0003o0005003o00Sooooo7000
o`00800Gl0`0>]/N07Fk@`2=/5P0]j9c0<2MO@3C]id0dkRU0=>gY03A^:H0d<6d0=77``2UX:H0OH2A
0:^ea026UJX0JX6O07Z@YP30bLl0emGB0=KCd@3Cd<d0d/g80=39`@2XdYh0VmB?09O=Q`2=_gH0G==;
05W=A@0hgb/05?0>7@00o`08oooooa`00?l000<0@>0008300030X000203oP0000`3XJ3`0X23`0:0P
l0040:0Pl0030;Ph]03oP000oh0000<0oh0000@0X23`0=1@N02h>;@0X23`0`1@T7P00`0Xb3`00?l0
003o000K003o00_ooooo000:ooooo`<00?l004l0K[Hi0=G8_@38_l40=1XL03031`0g0PH0C@4308d4
202Y2@P0a4/<0=RV1P3HS`l0/AX10<D;20351`L0bPP70=8;2@3F2``0gPlA0>0@3P3O4Ph0V@d>0:A^
J03GRGh0_aPD0<h=2P3E30`0ePh:0=P@303K4@d0gQ@?0?4S6P3b:b80VQlL0=S9a`3ck^h0k^_[0?7_
k`3dk^`0oN?P0?oNh`3ogn<0on3S0?oHg03/^kh0cHJ=08da=P2:4a@0U@H809L31P2E0P@0T`4409<2
202B0@T0V`4:09h1302G0@L0T`4709021`2A0@L0S`4708<11@1b0040K00006d10@1_0@40M04107/1
0P1k0@@0MP0507D11P1g2@d0K@@706L10P1P0P80FP<105/>0@1h<0<05>X200H00?l02Oooool3003o
0080oh0000<0X23`0=1@N03oP0007@3oP0000`3@D7P0oh000?n0000Y0?n0000308300000o`000?l0
00@00?l02?oooolH003o000W00ch1P0kfah0Q;A60:bVIP3=Z8/0dkNS0=k:^P3Ga;L0flVm0=g>a@3K
c/D0e/W10>7Fd@3Gc<P0dl_80=G>b`3=c=40`/;?05QWR@2M[<@0KXFU096Za024Vk80c]SN0=GGf@3@
e=H0dM?F0<k@d`3;cm00blg>0<[:c@36a/H0aL?20<O4``3?blP0c<>m0:VjTP1LcTX02oP801X00?l0
2?oooolH003o0003043P0020`000oh0000P0oh0000<0j6Pl0?n0003oP0000P3XJ3`00`3@D7P0^3Rd
0:0Pl0040:0Pl0050=1@N03oP000oh000?n0003@D7P01P2P8?001@3@D7P0j6Pl0=1@N01hF;@0:<Pl
01X00?l02oooool000[ooooo0P00o`00D00YgA00ak2L0=3>c`3DdM@0?2X/03462P0l0`P0C@<707X3
1`2K1`L0_DD<0=RV1`3FT@h0/1d10<8:1`3110H0b`L90=092P3B2``0e@`=0=492@3C2PT0_PX:0;H[
9@3>=2X0c``90=8<203C3@T0eA080=HC2P3G5@X0fQX<0>d]7@3^<b40`cDZ0;^OV03bk^/0l>o/0?7`
k`3il>h0gZNT0=mnO03TOG/0hg]f0=I/JP2fDDl0/d0m09lW7`2N7100W18709L<102C2080T0D30944
1P2B0PH0W08:09T22@2G0PL0U@8609D2202B0@D0S`8507l2101a0@40K@4106l10@1^0@40K`8107H2
0P1i0P@0N@4707811@29:Bd0W45706X;3P1L0P80F0820583001Y6@808Ld11P00o`09ooooo`800?l0
00D0P<000?n0003XJ3`0oh000=1@N00N0?n000030>QX?03oP000oh0002T0oh0000<0P<00003o0000
o`001000o`08oooooaD00?l002d05o0;04KD901f_D<0^jAe0<nXS03F]9X0g[n[0=Rn[@3Mb[/0flZn
0>OJd03LcLD0hMC>0>3Ec`3Tg=P0fm7@0>CJf`3MeM<0d/k;0<k9bP3:a//0]K_:06n5X@1fRZ80B6>4
0::gc02^`]40dmWL0=?Ff03Be]T0dMGH0<oAe@3<cm<0b/kB0<W9cP33aLP0bLc?0=3Ce@3<d=<0blk@
0<_9c033^KT0J[9R03Bj8`07m0<05`00o`08oooooaD00?l000<0@>0008300030X000403oP0000`3X
J3`0d51h0=1@N0050:0Pl0<0oh0000<0j6Pl0=1@N02h>;@0102P8?00103oP000X23`0;Ph]03@D7P2
0:0Pl00306RX?010h0000?l001H00?l02oooool000[ooooo0P00o`00D01fORh0dl[90<k?dP3De=L0
F4]>03052@0n0PH0B`4707L42P2E1@P0/CH<0=RR2P3FT`d0/2810<@;1`361P/0a`L;0</8303:20P0
aP@40<<20@350`<0d0/;0<X920343PH0aA/:0<LX4P3;>B80dE8g0=U/D@3QP6H0jIAm0?Zl[`3jb;d0
nM;:0?7Tg@3`kNX0l>k/0>o]k03cl>l0m^kZ0?W]j03ij^H0n>_U0?[[iP3jj^D0nNKO0?3Ca`3V`:d0
hKFM0=ZWT03BVH<0ah5/0<5[F@2C6AH0U`<909L21`2E0PP0U@4809H11`2D0PP0S@4807L10P1a0@40
JP4006h1001_0@40KP4107010@1d0@80M@430741101/1PT0WTI>0:ABFP1m:bd0EP8404h10@1S3@<0
<ih01P00o`09ooooo`800?l00P3oP0000`2h>;@0oh000;Ph]01:0?n0000308300000o`000?l000@0
0?l02?oooolB003o000a02;Y4@15dbD0M;Xo0<:GL03:YX@0d:nE0=6eW`3D^J@0fkbW0=VoZ@3Ob[H0
hM310>7A``3Re<P0j^3I0>GJeP3Wgmh0iMkK0>KNg03Sf=L0hMSE0>ORg`3Gdm00^K[00<?4bP2IZ;X0
VJfo09b_a01EM9X0IhBO0<kJi03Dem`0d]KI0=?Ef03@dmL0cm?F0<kAd`3<c]40bLkA0<[Ae03@e=L0
cm?H0<[>d`36bll0b/cB07=gRP1TK7T0MhmU01[U4P0F003o00Sooooo4P00o`000`10h000P<000<2P
000D0?n000050=1@N02h>;@0X23`0:0Pl02h>;@00P2P8?000`3@D7P0oh000?n000020?n000030>QX
?03@D7P0X23`0080X23`0P3XJ3`50:0Pl0030;Ph]00Xb3`00?l001D00?l02oooool000[ooooo0580
0?l002[H3@1b<al0bL2o0<o?e03Ce=P0OGEh02h62@0j0PP0B08706l420280P@0[Rh90=RO303FT`d0
[2<00;h80`2m1@T0Z`430;P21@310`D0`@830<<20`381@H0d0/>0;d:302=91/0iZfC0>c4/P3[c/00
j]K80>[KdP3/h]`0l^_W0??^j`3ajnX0l>WW0?;[j`3^k>`0l>g]0?;^kP3bl?80lO3a0?G_l@3gkO00
mNc]0?K/kP3dk>`0l>OX0>cQhP3UemD0i=K@0>;Fc`3Qe/l0h]O?0>cEcP2NCdX0S@L:08l<402910/0
T08909H2202G0PP0S@8807L10P1c0P40KP0106l20@1^0@40L@4107810@1b0P80L04206d10P1e4a<0
YE5G0:QNI`2CBDd0L24V04T1101G1`@0FDL11P00o`09ooooo`03003o0020`000oh000080d51h00<0
oh000;Ph]03oP000BP3oP006003o00Sooooo4000o`00=00hfQd0LkTo0;:KJP32Vg/0aZB50<j^U03>
/IX0c[>K0=JmY@3I_j/0hLRf0>3:^@3Td[h0imO80>gNe@3[gM80k>7J0>[Rg03Xh=X0hMSC0>KPg03O
fmP0hMcH0=_GdP3Pg=`0gMGE0;2`]@2IX;40HWFB0:jjc01kU;40Sj[4082L]03Ae]d0dMKI0=3De`3@
dmL0cm?H0<_@e03<d=@0bloB0<c@e03<dMH0cmCH0<gCf03:cm<0bLkB0;NmaP1RLhP0K7b=08bFQ@0c
ab4E003o00Sooooo4000o`000`20`000`:000?n0000G0?n00080^3Rd00<0X23`0;Ph]02P8?000P2P
8?001@3XJ3`0oh000?n0003oP000j6Pl00@0X23`00@0^3Rd0>QX?02h>;@0^3Rd1@2P8?000`2@L7P0
0?l0003o000C003o00_ooooo000:ooooo`1301O`2@2bNU@0HQhC0:29QP3@d=<0d]7G09>?T00Y1`/0
=@8804L3201S0PH0QPL80:4S1`3IWPd0eY<<0:XQ002o2@H0a0L=0;/42@2j0@D0`@<70<02103210D0
bPT80=4;3@312`h0L1HD0=k6^P3Tf=80iMSB0>_Hc`3afM<0mmgN0?gNh03nfm/0o<_<0?k6b02ePH@0
_:n_0?3/jP3ak^l0lNo`0?;_kP3abLd0jYVO0=>2RP3?Q8d0eHbC0=2@U`3>UIX0ciNI0<FBR03:W940
dZbU0=k3`@3UbLT0]W1^0:Dg=03FL6l0bf9U08T;4@2A0PP0T`4608T1101i0@80M@4107000@0206h1
0@0=07020@1c0P80M04207010@1]0080K@h@0;=]L@1T8b/0/g5i08Y0BP1C3a@0D0@306dI0`06003o
00Wooooo00@0P<000?n0003oP000X23`0P3oP0000`3@D7P0oh000?n0000L0?n000030=1@N02P8?00
oh0002X0oh001P00o`08ooooo`h00?l003L0;>0F09>QD@2jU780`9io0<FUR`38Yhl0cK6H0=2fX03B
^J@0eKnZ0=c7/P3Ob[L0hLbi0>;=^P3YeL<0jMW70>[Gb`3^gM80jMW=0>OIcP3Wfm<0j=kK0=gCc@3R
gML0hM_G0>7Fe@3Ne=80elk;0=[EeP38a/T0[[C106AeS@24U:l0SZ>n08^R]`2kcmP0d]KK0=7Ef03?
dmD0cM?E0<cAe@3<dM<0bloA0<k@e03<cm80cM7F0<c@e@3;cmH0b/cE0<C6cP24T:40O8jP09FOZ02d
ZZP0;]DR01@00?l02?ooool>003o00030830003oP000oh0001X0oh0000@0^3Rd0:0Pl02P8?00^3Rd
0`2P8?030?n000070=1@N02P8?00X23`0:0Pl03@D7P0X23`0;Ph]0080:0Pl003052@N000o`000?l0
01800?l02oooool000[ooooo04@0@]4O0:InI`1O6Q80UgEb0=7Ae03Ad]H0YZBW02L83P0c0`P0?`87
05L31`1b0@80Vb060=ZN3P3IU`h0ZRD00;l:1`351P/0`P@:0;/11P2o0PH0a0<80<L52@3?2P`0f@h?
0=DA3`2Y5180kj>O0>^ZY03DR7h0cW=W0=A^I`3PM7<0h6i/0>5^J`3OFUT0fT]80<IKE@2XQX40l^[X
0?7_l03al?40l>o]0>k3`P3FJ6H0_3@c0;<M802a7R80VRla0:MGE@2eI640ZeM<09m9?@2E@CH0VdU6
09M4@`2C;Bd0/DY:0;iVJ02bFf00Y3Q008d32P2>0PP0R08607X10P1f0@40L`8107020P80K`4100d0
LP8207<10P1`0@40K`4206L31@1[6Al0QCi609I@FP2XHV/0HA/R0584101/5@D07l/000D00?l02Ooo
ool02020`000oh000?n0003@D7P0j6Pl0?n0003@D7P0j6Pl7P3oP0000`3@D7P0oh000?n0000Y0?n0
000308300000o`000?l000<00?l02?ooool<003o000]03OJ7P2YTel0^YA^0;bIN@2mWX<0`JF>0<^]
U`3@/id0dkVW0=O0/03I`k80flRf0=[8]@3Qb[L0h/^i0>?=^@3Wdl80i]?00>_Ha`3Xe<H0jmW:0>SG
b@3Wf<`0i][B0>;Gd@3Qf=40f]7<0>WPg@3Ndll0e/g;0;>a^P2STJH0fJFa0=>GYP39QY<0HT]W086D
[P2F[/40cmOK0<kDf03:cmL0d=;F0<cAe03;cm80b]3C0080c<oC00/0c<oD0<_=d`37c=40b/cC0<W:
d@1hNX`0CEmh07V:V@2SZ:l0WYn=02;I5P0C003o00Sooooo3000o`000`20`000oh000?n0000J0?n0
00030>QX?02P8?00X23`00<0oh0000L0^3Rd0:0Pl02P8?00d51h0>QX?02P8?00j6Pl00l0X23`00<0
D91h003o0000o`004@00o`0;ooooo`002_ooool0D`1X/3D0XHEe06PW8@2_RXh0d=7F0=3BeP32`lH0
7PX>02P1100i0`P0E0<807P51`2J7PH0gJ4A0=bM402Y:040_`X70<L72`351P/0`0<80<T7303;20/0
bPP80=@<303L4@h0ga`C0>8]803?9R00]2`U0<ITF03QVX`0mKff0?_?a`3lf]80o>7L0?O1_P2=?SP0
mMoD0?O^j@3clNd0l^oa0>o^kP3_knl0l>cZ0?WZi@3je<d0a5mL07/O703Pa;`0lNGO0?;Wh`3ci=l0
m>;M0?;JeP3]c/P0j[Na09`c<`2R:2d0bg1f0=9hP@2Z>d@0SP8:09012@290@H0N`4307@10@1c0@40
L04106X10@1X0@00K@4107<1101d0@<0KP4206L10`1R0PD0G`<;06hE7`1j9c80Lb@]06882`1^4@D0
?I8000D00?l02Oooool01P30X000X23`0?n0003oP000d51h0?n00080d51hB`3oP005003o00Sooooo
2`00o`00>`1Z/cL0]I1Y0;VDLP31XH40`j:70<>VS`39[IP0d[BR0=JgYP3O^Zd0gKJX0=Ro[03JaK80
flJb0>7>_03QcKh0i]>o0>WFaP3Wd;d0jM;00>SC`03ZelP0j]K70>kMd03Rd/H0g=380=kDd@3UfmX0
g/k;0=c<b@3TfMT0/:^l06/lJ@2S83`0^A@T0;d@7034GFd0Z:g105YgU035e=h0`/WF06=MO@3E^<H0
d/kB0<[?d`36c]L0b<oJ0<_Ae@3:cm<0blkE0<[>d`38c=<0bL[A0;6__022SJ80SIfZ0:Jb^02^[;40
YXf401<00?l02?ooool;003o01l0oh0000<0d51h0:0Pl03oP0000`3oP0050:0Pl0030=1@N03oP000
X23`00h0X23`4`00o`0;ooooo`002_ooool0D`22Z4`0WH^106di=P2ON7l0c<gB0<kBe`31aLL060h?
01L0000^0PH0CP4506d1102D7@D0gZ0B0=VM3@2[;000_@T50<@72P361`d0aPD:0<d93P3=2@X0d``<
0=P>303L4`l0galE0>8e:02M7QD0ciB90?GOf@3ajnL0kng[0>k/j`3^kN/0mNo^0?SPg021BD00dkn`
0?7[iP3blO40mO7b0?WWjP3[gMl0k^_Z0?3]j`3`jnP0iKNd06@]:`3Yh]d0jNWX0>[ZjP3/k>`0j^[[
0>KVi`3ZjNP0l^GT0;9WJ@2F20h0U1@P09dT;`2=2A00TP8809@2202<0PP0O04207L10@1e0@40L002
06/10P1[0P40J`4206d10@1`0@40KP8306D11@1Q0@L0I@4906X32`1e51/0PbXa06H72P1Z3PH0>Xl0
00D00?l02Oooool0203oP000X23`0=1@N03oP000X23`0?n0002P8?00d51hB`3oP005003o00Sooooo
2@00o`00?P0;n0H0K;<m0;2=J`2gU7D0_IYo0;nPQP34YY80ck6M0=ZbX03JYiH0aHMi0=J:O`3AQGH0
f[VS0=O0Z`3KaK40i=300>3<^`3Qc[T0j=C30>K>_@3XdKh0j=2m0>[B`P3XdL40im;30=o@a`37_lD0
a9JV0=N3S@3NNH00i8RB0>6BV03JYK<0NTA/0;0oGP2n4Ql0b@XB0;XP;P1WD740PiJa0;32d`2JW[D0
L2]=0:0S>@2mK7d0]8BF08]WP01]CFD0^K:i0=3Be`3<c]@0b<cC0<O:d`38bm<0ZJbf04eHKP1GIgT0
VjRa0:VX[`2TTi@0=LTT4P00o`08ooooo`T00?l000<0:<Pl0<2P003oP000603oP0020=1@N0@0oh00
00<0j6Pl0:0Pl03oP0000`3oP0040:0Pl0040;Ph]03oP000oh000>QX?080X23`00<0^3Rd0>QX?02h
>;@02@2P8?000`1@T7P00?l0003o000@003o00_ooooo000:ooooo`1609B/H`2JSHX0MDU908eOI@39
b<d0b/oC0;g0`00U7Ah03`0002P21P170PP0H0<707hG0`3KWa<0fYh?0://002o2`H0a@P:0<L72`3;
2@/0c`/=0=092`3D2``0f0h>0=XA3P3L50d0cQLD08I2?@3ahMT0kn_Y0>k]k@3/k>`0kNc]0?3[j`3e
j>H0o>7K0:]/GP2[SGd0j=cD0>OShP3`j>H0f92D09@n@03@^[X0k>_[0>_YjP3cfm/0LS<c0<6a[`3X
j>H0jn_[0>_/k03ZjNX0jNOW0>ORh@3_hn<0bi>@09T;302O10/0V08:09H22@2D0PT0T04908/11P1o
0@<0N`4207X20`1b0@80K`4106h10P80K04200/0K`420782101V0@D0G@4506@11`1[0`T0K@L=06l;
4@1X20/0I0X407HW0@05003o00Wooooo00@0d51h0:0Pl03@D7P0d51h0`2P8?000`3@D7P0oh000?n0
000A0?n000030>QX?03oP000oh0000d0oh0000<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0oh000?n0
000P0?n000D00?l02?ooool7003o001001;]2P1/Tcd0WheO0:j<L02bTGL0^IQo0<BUSP3;Z9@0e::C
0=B9O02oFD`0dVUD0<UZDP3BL5`0dG=Q0=fdWP3I`:X0g/Nd0>3:^@3Qb[T0glVf0>O@_P3Sb[H0i<Ze
0>K=]`3Yckh0jM2n0>GAaP2ASJP0ZDQ[0<dS:P3A8Ah0cB4Q0</R9P377BH0`Qh/0;dQ=03?;cd0bQDK
0</83`312Q40]E]/07aWQ@1RBFl0RCIB0:T?7P2a0`h0[0@?0:H74P2G5AP0YEeK0=G5a`3=bl<0c/_1
0<[=d038c=@0aLWC0;o1b`1XKWd0KW^708VCVP2RXjP0WiZM07BVHA800?l02?ooool7003o0003043P
003oP000oh0001T0oh0000<0^3Rd0=1@N03oP0002P3oP000103XJ3`0X23`0:0Pl03@D7P70?n00080
j6Pl2P2P8?0B003o00_ooooo000:ooooo`150;VJO02GSXd0OUaJ07@o@@39`lT0a/W=0;:e]@0n=cT0
504202d32@130PT0G0<807lF103HWQ<0fid@0:TY002n2PD0aPT90<L9203920T0cPX:0=0;2P3D3P/0
f0h=0=X?3P3L4@h0e1DC07XR8P3B_kd0k>WX0>o_kP3^kNd0kng]0>K;bP3JOW`0gEmM0<Y1>P24Cd@0
iMS90>o/j03cl>d0i:FS0;Df<`2VMg<0l>[X0>_ZjP3ainL0/VEU084]<@2lX:<0j^OW0>[Zj@3Zj^X0
i^3N0<6BT`2aI6L0aVQY0:8?4@2Y10X0X@4709T21P2k82@0YA8H08d11@260P@0OP4107`10P1i0P80
M@820080L@4100`0L@8107410P1a0@@0JP4505l11@1Q0@D0H`8606H4201V0PP0J@H<06LB2`1i<@h5
003o00Wooooo00<0d51h0:0Pl03@D7P00P3@D7P30:0Pl1<0oh0000<0j6Pl0=1@N03oP0001`3oP000
0`3XJ3`0oh000?n000080?n000030>QX?03@D7P0oh000200oh001@00o`08ooooo`D00?l004<02OH5
05>R<@14C3l0ADA=0:J:M@2]SgP0/9F00;^OS03<ZiP0_W=T0<MWE03<J580f71M0<IG@P3=GTP0bFI;
0<]jH`3R/Y`0fl2]0=c3/`3Na[@0h<Vg0=k8/P3Uc[T0hlbe0>C<]@3Wc[P0jM2l0>W?^`3Sc/D0I5V5
0;TcA03SKeh0ij:E0=RWX@38W:00b9NT0;9_P02MBEd0V3Q=0:PY>`322a<0a`H>0;h=6@2c5B80/0dJ
0;<63P2d0P/0/@@;0:X:2`2S8Qh0`hR20=G;b@3=cm40b<>Y0<2^J03?ck/0algB0<K:e037bMD0MgV9
065/N02>VYl0[[>f0;6`]@2UVIP01o@401400?l02?ooool5003o000802S8?03oP000^3Rd0:0Pl03@
D7P0j6Pl0=1@N03XJ3`F0?n000030:0Pl03oP000oh0000@0oh000`3@D7P00`3XJ3`0oh000?n0000:
0?n000040=1@N03oP000oh000>QX?0T0X23`00<0:<Pl003o0000o`003`00o`0;ooooo`002_ooool0
7P2jVh40YYjN081UH`1O92X0bko70;o3a`2][[00D4Y;01L2100[0`/0?04805D22@1l5@H0eidC0=RK
3P2X9P00_PT40<H9203820P0bPP90<h92`3A2`X0dP`90=H>3@3I3`d0fa4=0=hD3`2l61P0JAHK0<Rc
]`80kNk^03<0kN_/0?OWi03XUXl0aC4U0=@U6`1m;BL0g<bn0>cYi03^k>`0j<700:<b<02CDTh0lnWV
0>gZjP3^jNT0d8j<0:dK7P1n5Qh0/YBG0>SVi@3[jnX0j^SV0>Jl^02J=C40Y1<F0:/62`2Z0`P0YP8:
09d31`2]6R00V@XA08l22@2?0PD0O`4107X10P1g0040M`4207<0001b0@00L@4107410P1c0@D0K085
05`10`1K0@<0H@8806<31`1U0@L0I`@;06HE4@3;ZI`01@00o`09ooooo`050=1@N02P8?00X23`0?n0
003@D7P00`2P8?0E0?n000030=1@N03oP000oh0000/0oh0000<0d51h0?n0003oP000103oP0000`3@
D7P0oh000?n0000N0?n000D00?l02?ooool5003o001305ej?00L8c`01QY>02XfF@2SSh<0[IJ30;RM
SP2kWhd0`:290<N3L032F4H0bUm90<EKAP3ITGL0f:>70=J]T`3@YI00fKJO0=_0[P3L`k00g<6]0>;9
]`3Ma[<0h/^d0>C<]03UbkD0il^j0>S?_03VdKX0i<jn09N9V`33SY80ilFa0=g<^`3Jb[h0hmSE0=[?
c03Ea/H0eL_>0;nld@1HCGT0ZB@m0<P840341@`0`B@K0;8b:P2V;2/0ZcTd0:mBBP30QGd0dkjk0<k=
c`3:c]40bm3E0<kAc`37^i40`kAi0<c=`P35bm40a<WB07n3T`1AF6T0L7f50:fb]`2c/[T0Zj>Y02G<
6`0A003o00Sooooo1@00o`000`3XJ3`0X23`0:0Pl0040:0Pl0030=1@N03oP000oh0001@0oh0000<0
^3Rd0=1@N03oP000103oP0020>QX?0030=1@N02P8?00j6Pl00T0oh0000@0^3Rd0:0Pl02P8?00^3Rd
0P3oP0000`2h>;@0X23`0:0Pl0060:0Pl003052@N000o`000?l000l00?l02oooool000[ooooo05<0
^j:809>CT`2@OWh0CA@I0<2a^02h^kl0[[:a06ESH00K1`T0:P@;03l33@180@T0I`l30=>L4`3HV`l0
YbD00;h91@3720P0bPP;0<`92P3=20X0d@X;0=<<2`3G3@d0g14>0=hB3@3Q4`h0hALD0</L7@2K;S@0
`:BZ0>[Zj@3/k>d0k>_Z0?GSg@3YZY`0d4m108LL5P2mXiT0k^OR0>o/k@3bh>00eIRD0<bNV@3ainD0
k^_/0>cYjP3U][@0]1/J0;TE602>92X0_:RX0>SVh`3ZjNT0kNGR0>S2_@2aBTH0ZPT;0:d4202X0@P0
YPP>0<Y;D02@4Q@0SP8709<11P260@<0NP0107T10P1h0P40L`0107<10P1a0@40LP4207810`1Z0P<0
G04205P10`1H0@D0G@8706011@1T1@P0HA0<0<JTU`05003o00Wooooo00@0d51h0:0Pl02P8?00oh00
102P8?0E0?n00080j6Pl1`3oP0000`3@D7P0oh000?n000020?n000030>QX?03oP000oh0000D0oh00
00<0j6Pl0?n0003oP0007@3oP005003o00Sooooo1000o`00A01kXdX0LFI/00HGBP025eh062UO09j?
R`2`UhD0/iB10;JGO@2lWH80b8ii0<5D@033G4H0aWEL0<bGN`3>Zhl0cJbC0=:hY03MakT0f[n^0=Vo
Z`3K`Zh0glVc0=k5[P3Rb[<0i<^i0>?9]03UbkT0i/nk0>K?^P3Vc[/0hL^m0=k:^03Ja[80hLJh0=o0
]03Va/00i/C20>o7bP3IYZX0i:jf0:edSP2^<Th0a0PA0<862`30:Rd0UT==08iCI@3<WjX0fkNm0=O1
b03Fb<l0dL[@0<k;dP3;c=40bL[60=39Z@35/EP0c;ej0<_<`P36blh0XjF`069XMP22SIL0WZ>]0:BV
/02ZZ[80@kXk4@00o`08ooooo`@00?l000<0j6Pl0:0Pl02P8?00102P8?000`3@D7P0oh000?n0000O
0?n000030=1@N03XJ3`0oh000080oh0000<0j6Pl0=1@N03@D7P00P3oP0001@3XJ3`0d51h0=1@N02h
>;@0X23`00<0oh0000<0^3Rd0:0Pl02P8?001@2P8?000`1@T7P00?l0003o000?003o00_ooooo000:
ooooo`1C0;^RQP2IV9T0UX^;04@B4`2ZUiT0^K^o0<?8bP2;SHl07@/@02X5300o1@X0A`4606D?1@3>
UA80eYD@0:PP002n2PH0b0T80<X92@3?2PX0c0P90=4;303B2``0f0d>0=/?3P3K4@`0gQ<?0><E4@3Y
6A80hA`G0:<U8`2WSHX0j>?Q0>_Yj@3[jNP0kNCP0?6n]02U;RL0K3`i0>_Rg`3[jn/0k>_[0?7Zj03a
jNP0kN[Z0>cZj`3/jn/0l]WI0:le<`2Z5a40WC0Y09miLP3Qem80j^KV0>OVi`3[iNH0j<G30:4V8`2Y
1@T0Z@@90:H22@2O0`X0WP@:09H11P2F0PP0U08708L1101o0@80N04107D10@1g0P80L`4107D10P1e
0P@0J`8405h1101G0@<0E@4305/21P1P0@H0I0@806D?303<Z9`01@00o`09ooooo`040=1@N02P8?00
X23`0?n000<0X23`00<0^3Rd0:0Pl03oP0005@3oP0000`3@D7P0oh000?n000040?n000030=1@N03o
P000oh0000X0oh0000<0j6Pl0?n0003oP0007@3oP005003o00Sooooo0`00o`00A@1X]dD0XiB407ag
O`0B9EX00QQV00dNFP2LSH/0[I600;>CO02hUG/0^iZ00;^1J034NU`0cY^10<RUS036ZI40aZV@0<V/
T`3KcKh0imgJ0=>m[@3J`Jl0f/B_0=c4/03Oak40h<Rc0>7;]`3Qb[D0hlbi0>?<^`3Tc[h0i<jj0>?<
^@2k/jl0X8RD0<mIF`3C@D<0dCDk0<hY<03;82H0bAPL0</I70365AP0a0lD0<@93P321P`0_@@<0;@7
3`2]2A80YPXH0:<=7P2Q5BH0Xb8c0:DeA02ZB5P0ZVEa0<nl[P2o[640_J<F0;fU4@30[TX0`[b80<2l
[01KFf80Hf]f09FMYP2QXj/0YjN]06FZF`0A003o00Sooooo0`00o`000`2XR3`0X23`0:0Pl0050:0P
l1T0oh0000<0d51h0;Ph]03oP0004`3oP0020>QX?0@0oh0000<0j6Pl0;Ph]02P8?001@2P8?0A003o
00_ooooo000:ooooo`1C0;jTQP2LVYH0UXj=058O7P2JOH00`l?80<gAe@2XZjl06a0B02X9300k10X0
D@D;05h<0`3AV1D0eY8?0:`O0P312@P0b@T<0<T92@3?30`0d@/<0=4:303D30h0eP`<0=T>3`3G4140
dPl?0=L@2`3L6QD0^bHN0=F<P@3ZfM@0jnKT0>_Yj@3/j>H0l>7O0?K0_P38=S80J`h=0<Nb[P3/j^P0
k>WX0>gCd`2/J6d0UG=c0>oYiP3/j^X0kNCQ0:aVH`1;2`L0fl>j0>_Sh03Yi^D0iNGU0>?QhP3Tgn00
iM7A0:94@02G0`L0V`4609h1202L0@L0VP4709@11P2A0@D0U04609011P280P<0O04307T10`1h0@80
M04207D1101d0@D0K@4306<10`1I0@@0E04505411@1G0@D0G`<606091@2IECX01@00o`09ooooo`09
0=1@N02P8?00X23`0?n0002h>;@0X23`0;Ph]03@D7P0X23`01h0oh0000H0d51h0?n0003oP000oh00
0>QX?03@D7PV0?n000D00?l02?ooool2003o001605jm>`2YWI<0YYbG09RBV00>7Dh011MP00LFCP2?
PH80ZXam0;2@O02fUG`0^YN00<2MP`31WX@0]Yb909J5M`28O740T8Ih0;fXTP3B^ZP0eKj_0=JlY`3J
`J/0fL2[0=[3/03Oak00glJb0>3:]P3Pbk<0h<Vc0>;:]P3RbkD0hlbf0>C>^03A`Kd0KUim0;he>03?
:A/0dCHT0=E3=@3FDD@0eUa@0=9OE@3>HED0ZTQ=09lO=@301a40`08;0;hR7P2eBd<0XdM30:91?P2W
>CL0XbPZ0:4L7@2L51T0TA8I0<>GV@3AcL40_ZY;0;nU1P2kX0H0/Yd=0;>N7`1ZGRP0Hfih08fIX02`
/kT0XZ2V06^OHA400?l02?ooool2003o00030:R8?02P8?00X23`00H0X23`00<0j6Pl0?n0003oP000
0P3oP0001@3@D7P0X23`0:0Pl02P8?00j6Pl00l0oh0000<0j6Pl0:0Pl03oP0001`3oP0020>QX?0@0
oh0000<0j6Pl0?n0003oP0001@3oP0000`3XJ3`0oh000?n000030?n000030>QX?02P8?00X23`00<0
X23`4@00o`0;ooooo`002_ooool0D`2nXH<0WY^H09VCU01J:R/0TW9f0<W:d03@e]/0^K_001hD5@0/
2Ph0>P@;05P:4P1L3@@0dY/E0=:;3@2^7000`PT60<P82`391PX0cPX;0=0:2`3@2@X0d`/<0=H<3@3H
3@h0f@l@0=TA3P3J5A40/a@C09iNFP3bi>00jnWY0>[Xj03Wi^D0j=3?0?:][@3IEEL0gRDR09dI5`2Q
P7`0k^_Y0?7]k03mh=l0]Da=07`d<`3^hMh0j^KV0>kYj037Ti<0B`l<0<Rl]`3XinL0inKX0>CRh`3N
eM<0c[J`0<>>Q`2B7AX0U@8409<00P2E0@D0U04609<01`2C0@L0T04409@21@2@0@@0R04507d10`1h
0@80MP4207@00@1f0@<0MP8506l10P1Q0@80FP4305D1101=0@@0D04605H1101N1`80QS4A00D00?l0
2Oooool01P3@D7P0X23`0:0Pl03@D7P0oh000:0Pl080d51h00<0X23`0?n0003oP0009`3oP0000`3@
D7P0oh000?n0000N0?n000D00?l02?ooool0B000o`00:=lF0;FUV02`[Jd0[:RY09nHWP0^=UX00aAF
00@DD@23MW`0Z8]h0:j?NP2bU7/0]YMo0;ZLP@2hWhL0S7i`0:RFQ@2TThD0LVaV09R=P@3B^:<0e;^T
0=NnY`3H_JL0f;jW0=VoZP3Na[00fl>`0>7:^03Rb[H0hlZf0>7:]@3QbkH0h/^h0>G@^`3Pc;/0ckR^
0=^bY03EZIl0gJbO0>bdZ03d_KP0hJJS0=RWXP2cWZ80ZY2U0:4gDP2n2A<0`@D;0;DI7P2JCf00MfZ5
08fIZ`2KUJH0ajF^0=Ja/P3AZj`0b:2P0<2^/03;cm00aKV30;fU302SSQ00NG0<0:jN3P2WUR<0Q89X
09JLW02OY:L0WIjS08eoPA400?l02?ooool00`00o`00P<000;Ph]0070:0Pl0030;Ph]03XJ3`0oh00
0080oh0000<0d51h0:0Pl02P8?000`2P8?0@0?n000040=1@N03oP000d51h0>QX?0@0oh0000<0d51h
0;Ph]03XJ3`00`3oP0001@3XJ3`0X23`0:0Pl03@D7P0j6Pl00<0oh0000<0d51h0:0Pl03oP0001@3o
P0000`2h>;@0X23`0:0Pl0020:0Pl1400?l02oooool000[ooooo0400_j>309jNW02FTID0Hcdm089M
HP3;b]40cmOL0<S;d00P6ad0:@T=03@32P130@P0G@h50=FN5@3AQa00[AP10<<:1`371PT0bPH90<h:
2P3?20/0dP/<0=4:2@3E2``0f@h?0=X>3P3N40l0gaDB0:`C4@27G5X0k>OW0>_Xj@3Zj>L0jNOT0>K7
aP3>KFX0f3@/0>PS6`3:9R@0ReEA0>cXi@3^jnT0n>KT0<1VI022:B@0dKbg0>cYi`3[jNX0iKZj08d/
:P27D540hM[J0>GQh`3Pfmh0g<k;0;fAQ@2C;b@0U0D409T20`2F0P<0T`4409811`2B0@T0T0490P2@
0@D04@2;0@@0QP0309H;3P2[;2h0R1DE07<10`1b0@40O@D80741101S0@80G00305L1101<0@<0C@04
05P21`1L1@80SCLK00D00?l02Oooool00`3@D7P0X23`0:0Pl0020=1@N0040:0Pl03@D7P0d51h0:0P
l1@0oh0000<0j6Pl0?n0003oP0001`3oP0000`3XJ3`0oh000?n000030?n000030=1@N03oP000oh00
02<0oh001@00o`08ooooo`19003o002<ZfL0[:Z[0;>e^@2XYZ/0V8nG05mPNP054d`0119?07U^MP2R
QW@0ZHag0:n@M`2eUWd0_9^00:NBO`24Ng80XiB709B:PP1`KF`0THMm0=2fX03E^jD0e;^T0=JjY03H
_:H0fKnY0=g4[`3Ka:h0hlZg0=o9^03PbkP0h/Zf0>?:]P3Qb[D0i<nj0>7:^@3Ja[X0R8VJ0:UUNP3;
>D80d2H[0<hM903:6A`0]adN0<1fP`1S?f`0/a8S0<H63@2n2@/0[PTB0:X75P2U=dH0G4m^07/eE02I
3ah0VQLT09/R<02L=T@0`9bR0<[>d033]g`0_JD:09j95`0J6@D0GUdB08b24`2OTQd0V8hj0:VSM02V
YIL0ViBD01?M300@003o00Sooooo00<00?l00=1@N02P8?00202P8?001@2h>;@0oh000?n0003oP000
d51h00D0X23`4@3oP0000`2P8?00^3Rd0?n000040?n000030>QX?02P8?00oh0000@0oh0000<0j6Pl
0:0Pl03@D7P00`3oP0020>QX?0030:0Pl03oP000oh0000D0oh0000D0j6Pl0=1@N02P8?00X23`052@
N00@003o00_ooooo000:ooooo`1C0;fSPP2RYZD0TYBF06Y?C`1R>ch0dloE0<oEf`3?e]T0:BP[02D8
3`0f10d0>`4805`A1@3FXAL0cX4A0:lE0@322@T0aPH90<P61`3;20X0c`T;0=8<2`3A30P0e`h;0=X?
3@3M40`0gQ0<0>4C403H5A@0VQHI0;6:T@3WhN@0jNOX0>WWi`3/j>H0m^CO0>n_Y@3J?cD0dB4N07/U
903Xg]/0kN_Y0?3Yi`3VaKh0ejVP0=K4^`3/inD0jn[[0??Lg02bDDd0YAXK08a5B`36/kD0g=GE0=cG
e`3Rdll0d9fB09HN5`2D0P<0T@4308l10`2@0@D0T@4809822@2B0PH0S08508@21P2?0PH0/@D:0:X5
1`2X4aL0M`4207@210263@l0LP4406X2101S0P<0FP8504d10`1:00<0D`4605l50P2=<QT01@00o`09
ooooo`030>QX?02P8?00X23`0080d51h00D0oh000=1@N03@D7P0X23`0>QX?00D0?n000030=1@N03o
P000oh0000`0oh0000<0d51h0?n0003oP0000`3oP0000`3XJ3`0d51h0?n0000M0?n000D00?l02?oo
ool0B@0`eA/0Z:BP0:nf^@2b];P0ZJJY09R>TP1`KhH02QM@00<CC`1bJ780XhI[0:^<J02aSf`0]IAh
0;^IP02VRgd0Kf]Y07YgMP1^KV`0IfIR0;2PS`3?]9h0d[RR0=BkX`3D^:80e[^V0=RnZ@3Ja:l0f/F/
0>79]03Pak<0h/Vg0>?9]`3SbKH0h/Zh0>;>^03PcKT0fLS205AMQ02eC5h0eaLG0=`C4P3H5a<0fTPh
0<mD@@3;MVX0JU]m0:0[A`342@l0ac@b08i7FP2?2bL0[@PB08]0E@1[=4`0WPXD0:T22`2W0P/0X0P<
09a4B@3Cc/h0`[N60;bU6@2_Ua80@34:05A>7P0X9@80JVLF09f>4P2/Va40/jE20:2CKP0LeQ804000
o`08ooooo`030830002P8?00X23`00L0X23`00<0j6Pl0?n0003oP0000P3oP0000`3@D7P0X23`0:0P
l0020:0Pl0030=1@N03oP000oh0000l0oh0000<0X23`0>QX?03oP0001@3oP0001@2P8?00j6Pl0?n0
003oP000j6Pl0080oh0000<0d51h0;Ph]03oP000103oP0000`3XJ3`0oh000?n000080?n000030=1@
N01@T7P00?l000l00?l02oooool000[ooooo05<0`:B30;Jj^P2BUiP0KEUI05<[:`3HdMD0cmCI0=GK
g`0i>cl08`L?03D22`0m0@D0Fa430=2N6039N@l0/1<00<0720341@T0a@L:0</82P3@2`/0d0`;0<l:
203C2``0f@h=0=d@2`3L4@/0gQ0>0>4A4@3L5QL0VaLM0:^1S03Qfmd0jNOX0>[Yj@3/k>/0lNWW0>FD
SP2o8Ah0QaHE0=?3_`3/jnP0k^cZ0>WVi03[i^D0kNSV0>k/j`3Xi^P0kn;Q0=bCT02e6AT0XQ0G05dB
5`2dXIh0f]OD0=[FeP3Qdll0_Wab08l8202B0PD0T04408d1102?0@H0T@4709421`270P@0M@4208L2
1@2`0PL0[P020:X210280P<0MP4408dI6`1`0@@0JP4305l10@1H0@80C`8504L10P1=0@@0G@@208H/
4@05003o00Wooooo00X0oh000:0Pl02P8?00X23`0=1@N03oP000d51h0?n0002P8?00d51h7P3oP000
0`3@D7P0oh000?n0000:0?n000030=1@N03oP000oh0001/0oh001@00o`08ooooo`19052c>02GWJ<0
[kBl0:VX[@2]ZZ/0V92A07mkRP0;5TP00a1906eSI02fUS`0a9dR0;nI@@2fTfP0^YN10;NHQ01lKFL0
MVeZ0963MP2dWX/0bJjH0<ncW@3?]9h0d;FM0=6fX@3:]Z@0_JZJ0<JfY03LaK80hLRf0=o7]@3SbkP0
h/^j0>?:^P3Sc;T0iM2j0>;>^P3ObKT0Z:>b07aXR@2j@Td0daTI0=8G5@3VMVd0ijNG0=VcX@2ZXjh0
Kc]V0;/=6@2g41@0_7n8060D?@2`1QH0YRXc07aTM01f<480W0PA0:<42@2aB480/H^60<O6b03<c/h0
a[j70;bV802dVQ00U7hH048f2@1CDal0GUH:09>=702MTA80ZIDQ02CM3@0@003o00Sooooo00<0T71h
0:0Pl02P8?001`2P8?050?n000050>QX?02P8?00X23`0:0Pl03@D7P01@3oP0000`3XJ3`0d51h0>QX
?00:0?n000030;Ph]02P8?00j6Pl00D0oh000P2h>;@20?n00080d51h0P3oP0000`2P8?00j6Pl0?n0
00020?n000030=1@N02P8?00^3Rd00X0oh0000<0P<00003o0000o`003P00o`0;ooooo`002_ooool0
D`2k[h<0Zjj^09VMX01dHf<0CAlR0=c@e@3Fg>@0dmSP04M9CP0V2140?@D>04l73@1Q4`@0dj0G0<Ib
3`2b4P<0_`L80<@72@341@X0b@P:0<d:2`3>2`/0d0/<0=@<3@3G3@d0f@d<0=d@3P3Q4Q00hQ8?0>DD
4P3M6QT0Z1`R08m;C@3:]kD0k>[U0>_/i`3]jnX0mLg;0;D`;@2e7a`0bhj;0?GPg`3bh>40m>3P0?GO
g`3fh>80mMkQ0?;Nh03cgMh0nlK60;HW:02n3Q80X0dB070Q8P2k[J/0fmGD0=gFe`3M`l40TbXW0942
1@2?0P@0S04308/10P2>0P@0S04708D21@1a0P@0LP440:D52@2Y0@80Z@8308h2101f0@D0N@860781
101Z0@<0H@4205P10`1>0@D0A`4204P00P1R10<0PbD<00D00?l02Oooool01@3oP000X23`0:0Pl02P
8?00j6Pl00<0oh0000<0X23`0=1@N03oP0005@3oP0000`3@D7P0j6Pl0?n0000B0?n000030>QX?03@
D7P0oh0001/0oh001@00o`08ooooo`1907JJH02?VJD0XZF]0:VW[02[Yj`0X9JK09B=VP0E7TX00Q19
071UC@35XaH0b:L:0;VC>`2`Sfl0/Y=l0;RGP@2lW8L0^Ib80<>US`3<[YP0cJnJ0<^`VP3?/ih0d;FO
0<jfX@2mZIH0e;^Y0;^XV@3IaKD0g/Ne0=g9]`3NbkT0hLbi0>;<^03RbkH0hlnj0>?A_@3Tc[d0g/Vj
0<Bh^027NY80XE]`0<DX;`3=5AT0ab0Q0=1GD`3G/:d0G55e0:HR>02o2100^Sa808h`D02/1aP0Y`PA
0;64S02BS9d0LC56090?7@2G3aP0_H2:0<k;c`37c]@0blk>0;ndM02lY140^:4409b73`1fIQH0KV<?
071Y7`1XH@`0YIPH05^m3`0@003o00Sooooo00<0^3Rd0:0Pl02P8?001P2P8?000`3@D7P0oh000?n0
00050?n000030=1@N03oP000oh0000D0oh0000<0^3Rd0?n0002h>;@02`3oP0000`3XJ3`0X23`0=1@
N0050?n000050:0Pl03XJ3`0oh000?n0003XJ3`00P3oP0000`3XJ3`0^3Rd0;Ph]0030?n000030;Ph
]02P8?00^3Rd00T0oh0000<0`:00003o0000o`003P00o`0;ooooo`002_ooool0E02Ib7L0`<?609jU
Z01kL700@Q8F0=C2a`3CfMl0d]_Q05]OIP0R2Q80=P<;04@2301O5`D0ej8F0<=Z302b3P80_PL70<46
2@2n10T0a0D90</82P3;1`X0cPT;0=4:2P3F3@d0fPh<0=/>3@3R4100iQ@@0>LF3`3Y6180iQTD0=LQ
7P208B80el_70>[Yi`3^jNX0kko20;P^<02`7AX0f8=m0<MXJ@36DUD0`dY<0;Y1@`2oB4P0_4Q;0;19
C02bDU@0a5=@0;`U802h30`0[`D809P:3P1H9R@0b;Zf0=kFf03Oe=80We9<08h31P2@0P@0S@8208/1
0P2:0@40Q`4208@10P1j0P@0G@4107410P250P@0S@<50781101X0@<0N`8707X11P1]0@80I@4305X1
0P1?0@@0B@4304X10@1]0`@0Pah802?<0P@00?l02Oooool0103oP000X23`0:0Pl02P8?020?n00080
j6Pl00<0X23`0=1@N03oP0005`3oP0000`3XJ3`0oh000?n0000A0?n000030>QX?03@D7P0oh0001X0
oh0000<0P<00003o0000o`000P00o`08ooooo`190:2GT@25U:D0Vj>Z0:FV[02SXjP0Yj6V08b4S`0V
;EL031Hi08ij:P34YPL0ajP30<6J:`2/S6l0Zi1k0;FFO`2lVh@0`9n90<:UTP3=]jL0c[NV0<R/V@3?
/Y`0dKBO0=2fY02kYiT0ck^[0;fZW03Ia;<0gLRg0=k5/`3NbKL0gl^j0>7<^P3Rc;H0hlni0>CA`@3S
c[`0h<^g0=g8]P3CaL<0PH2O0;=`R`3:71d0dQ0=0</?3`32Bd@0VhNI07deFP2l2Q@0_0L=0:h:502]
1A80/0<=09Le?P31aM00IFB007LnD`2K5b<0U`/H0;f:T`3:c=80a/cE0<C5]`37^g00^jDH0;NP102a
V@L0V84:08Qf6`1PE@l0THLM03CM2`0@003o00Sooooo00<0^3Rd0:0Pl02P8?001P2P8?001P3XJ3`0
oh000?n0003oP000j6Pl0;Ph]0X0oh0000<0^3Rd0?n0003@D7P0303oP0000`3XJ3`0X23`0=1@N004
0?n00080d51h1@3oP000103XJ3`0^3Rd0:0Pl02P8?030?n000030;Ph]02P8?00X23`00P0oh0000<0
`:00003o0000o`003P00o`0;ooooo`002_ooool0E02Lbg/0]KVk09^TY`2=QXH0@Q0C0;bX[03@em/0
d][P071dN@0P2Q40=@<;03l11`1S6`L0fj@F0<AR3@2e3@80_`L80<872P331@/0a@D:0<X72`3;1`/0
cPX<0=8;303G3@`0fa0<0=dA3@3S4@h0iQ@@0>HE3`3Y5a40iAH>0=PJ5P2@9R40im?>0>kQhP3df=X0
fWMl0<@L7`2]61T0`I:?0?kLe@3i_KH0hi^C0=26O03AS8<0hZ>K0>^g/03c`;T0m[R/0=^5N02]<2L0
YA8>08d51P1e>Rh0dKV]0>?EdP3Ob/H0USdg09820`2C0@<0S@4208h10@2;0@40Q`4008H10@240P<0
L@X806@F5@1N2`/0G@4405D00P1S0@<0O`8608821P1d0@80J`4306420`1A0P<0A`4204T10@1_0`<0
O1H202?;0P@00?l02Oooool01P3oP000X23`0:0Pl02P8?00oh000:0Pl080oh0000<0X23`0=1@N03o
P000B03oP0000`20`0000?l0003o0002003o00Sooooo04T0ZjJT0761TP2NY:`0ZjZb0:>QZ02RWZD0
RhB>02`cB`1fJ2H0^i`B0:jC2@37Y`D0`9XU0:j;GP2[S7D0]IIo0;ZKQ@2nX8`0elRn0=G:aP3Gb/@0
ck^^0<f_V@3A]J00eKbX0<ZcXP34[Ih0e/2]0=W4/@3Ka[<0gLNf0>39^P3ScKd0h<jk0>;>_@3TdKd0
i=?10>C?_@3Rc;T0f<No07QlV02aH7P0bbPc0=4B4P3;3PP0bBPH0<ibG03;/Zl0GDM^0:/G;02h2@l0
e7Um06HG?P2W1AP0X10M04H[D`1^>EL0UaLU0:863P2V10X0T2PZ0=38c035cML0`lcC0<G8]`2n/V<0
_JTa0;BN2P2cWP@0]9d60:N@3@2GQQD0Am0@01000?l02?ooool00`3@D7P0X23`0:0Pl0050:0Pl003
0>QX?03oP000oh0000H0oh0000<0j6Pl0?n0003@D7P00P3XJ3`30?n000030>QX?03@D7P0oh0000`0
oh0000<0X23`0=1@N03oP000103oP0000`3XJ3`0X23`0?n000020?n000050=1@N03oP000oh000:0P
l02h>;@0103oP000103@D7P0X23`0:0Pl02h>;@70?n0000308300000o`000?l000h00?l02oooool0
00[ooooo03d0WLin0<?8b@2PZZ/0Pgmn04XJ7@2XRi80eMOP0=?IhP22QH/080T@0383200o0`L0Jb<:
0=ZS5030EP`0^Ph50<882P361``0b0H;0<P620391`X0b@L;0<d92`3B2P/0e`d<0=T>2P3L40X0h18<
0>@E3`3W5Q00jAH@0>XI503C5a@0eUmO0>fFV03OP8P0dEEL0<`S903D5QH0cQPG0:<c>@3Q`<80mNSW
0?;Xi@3aj><0l^WV0?7Yi`3^j>L0k^WW0>gXh`3`hM`0i[fg0<UlM@2I;2L0[De40;U/IP2iLW40[5ME
094A3`2E0@80T`420080T08101D0S@4208P100270@40QP4108TF4`2ME500/gMf05hA4P1S0@@0M`85
08@31`2:0`T0O08406h10P1T0@80E08304L10P1:0@80LP<407hE100SbP801000o`09ooooo`0:0?n0
002P8?00X23`0:0Pl03oP000X23`0?n0003XJ3`0X23`0=1@N1h0oh0000<0j6Pl0?n0003oP000:03o
P0000`20`0000?l0003o0002003o00Sooooo04X0Zj:J06MhQ`2DWJL0WZ6V0:2NX`2MV9`0[JN[04I3
:`2hWAL0TWP;07eU2`38Y@d0^YDO0<2K>@2/S6X0]IB10;bLQ`2oYYD0flo90;bXWP35[j<0dkjb0<jb
W@3C]j<0e;^Y0=Jl[@3K`;00f<:^0=[5/`3Ia;40g/^g0=k;^P3Qc[d0h<no0>;@`03VdL00i=310>7=
_03Qc;/0f<W305QRR@2aDFL0dAHJ0=4?3P324@X0g5e>0=j_W036/:@0NW2608P]C`2h2A80_eAL06E6
KP2@2B/0ZP@@07@U@01I;dh0SA4O0:<4302O4A00^8Im0<W<cP33bm@0`L[D0<O?f039d<d0bl^k0;6[
K@2TWc80[jDT0;NW4P2bWAD0HZDC01C_10l00?l02?ooool00`3@D7P0X23`0:0Pl0040:0Pl0030=1@
N03oP000oh0000L0oh0000D0d51h0?n0002P8?00^3Rd0>QX?00A0?n000030>QX?02P8?00j6Pl00D0
oh0000<0d51h0:0Pl03@D7P00P3oP0001@2P8?00oh000?n0003@D7P0^3Rd00@0oh0000<0^3Rd0:0P
l02P8?000P2P8?000`3@D7P0j6Pl0?n000030?n000030<2P0010h0000?l000h00?l02oooool000[o
oooo01@0^k660<77bP2OZZh0S8n>04hT9027HFT0emGO0=7IhP2@TIX090XD03<22P0m0PH0KR/<0=^T
5@2kAP/0^P`80<062P361P`0b0D;0<X72@80b`T:03h0cPT:0=<;3@3G30d0gPl>0>0A3@3U50l0iAD@
0>@C3`3W5Q00jQPB0>PH503S71X0gQ/M0=0@503E51L0eA8B0=HD503E4a@0eQXL0;`X;P31Eel0eXZC
0>J^]@3`_/@0jKFl0>fe_`3X[KD0hJBZ0=^SZ@3:YJP0f;bl0=n_Z`2J81h0XPD;0:442P2N0`H0VP43
09L10P2F0@80U04309410`2<0@80RP8208L10`270@@0QP8608PE5`2A9bL0TQdO08H320290PL0T0@;
09442P250@H0M`4406X10P1H0@80C04205L10@1i0`@0P1<602O=1P@00?l02Oooool01P3oP000X23`
0:0Pl02P8?00j6Pl0:0Pl080j6Pl00<0X23`0=1@N03oP000:03oP0000`3XJ3`0oh000?n0000M0?n0
000308300000o`000?l000800?l02?ooool0BP2fYYL0EVEe09NS[@2OYJT0YZJ[0:NOXP26N780UX92
0;bO4P1cF@/0YHL@0<>P402iVAX0`9`^0:f<JP2aSgd0^Y^70;bST`3Odld0_ZjV0=C1]P3;/ZD0c[>N
0=6eX@3C^:D0e;ZX0=JmZ@3G`:/0f/Fd0=S5]03KbKD0f/Rd0>3<^P3Oc;/0i=710>GB`@3Ud/00hLjm
0=k;_03KbK/0ZJFd07YYR@2f>dH0ba8F0=0?4P364a@0bUI>0>>m/@2UUi/0H31G0;<=6@2g9bd0ahjV
08P;;02_10h0U2Df05eAL01e@U/0SQ@P09H93`31SY00bL_A0<;:d`31b]D0`<WD0<;<e@33c=H0^<34
0:VdY02e^i80^;9J0;bX7P2cWQL0@]H;3`00o`08ooooo`030=1@N02P8?00X23`00@0X23`2P3oP000
0`3@D7P0oh000:0Pl00D0?n000030=1@N02P8?00oh0000D0oh000P2P8?020?n000040=1@N03oP000
oh000?n00080X23`0`3oP0090:0Pl0<0oh0000<0P<00003o0000o`003@00o`0;ooooo`002_ooool0
E02Kb7X0b/cA0:Ja]025RH/0GcLk06/nAP3EdMX0c=CL08nEV`0P2Q<0=P<=04042@1d>0l0fj@D0;Dg
2@2k20L0_`H90<<62P351@X0b@P:0<h:2P3@2PX0d``;0=H=303K3Q00g`l@0>0A3P3R4Q00h18>0>DC
4@3W5Q40iQD@0>XH4P3W61D0e@l>0=0>3@3E4Q40da8B0=DC4@3I5A<0gALE0=lJ603L6a/0eadM0=@N
8@3?7R@0bATQ0<dI8`3;61l0bQLK0<4D602T3QH0Sa8K09@o@`2cC4L0X@@70:@1102O0@@0WP4509/1
1`2H0@D0V04709@00`2A0@<0SP4508P10P260@80Q`4508H11P2800@0SP8809032P2?0PT0U0<<09D4
30270@L0N`4406d10P1K0P40E@4106T30`1n0P<0NP`202K=1@@00?l02Oooool01`3oP000X23`0:0P
l02P8?00d51h0:0Pl03@D7P00P2P8?000`3@D7P0oh000?n000170?n0000308300000o`000?l00080
0?l02?ooool0BP2SaH/0IGB508nLY`2QY:T0ZJFV0:fMP02TRT80^IXT09Ej3021Ja<0^YX?0;6>9@2Y
RdT0[HiK0:Z:MP2_T7h0]iV70;nOS`39]:P0d/2d0<bgZ03</Yd0cK:L0<ndW`3B]j<0dkbY0<JeX`3E
`K00fl>b0=W3/@3Lak<0f/Vc0>3=_03PcKd0i=;30>KCa@3Ve<D0hm;30>3=_P3LbKX0e/Ji0:VOZ@29
KH<0[DI@0;PO8@374aD0`Q<C0<UKE@3:Z9l0H4U[0:LL<02g2A00/Qh^0:/85P2`0`/0XQ/W0:jH[028
PiX0LD5G090D802C7RX0a:>]0<?9d030b]@0am7J0<K>e`33c=H0[[S505=PIP1gOg40TIIo0;BYB@2m
[1d0J<LG3`00o`08ooooo`030;Ph]02P8?00X23`0080X23`00<0d51h0?n0003oP0001P3oP0020=1@
N0<0j6Pl1`3oP0000`3@D7P0oh000?n0000<0?n00080^3Rd00<0j6Pl0?n0003oP0000P3oP0000`3X
J3`0X23`0?n000050?n00080X23`00@0^3Rd0?n0003oP000j6Pl2@2P8?020?n000030<2P0000o`00
0?l000d00?l02oooool000[ooooo04<0V/Ig0<O:c`2OZJd0Ri6D060m@01H:2h0d<gB0<KBf02JXJH0
8@`C03D32`0i0PD0MSd=0=fS5@2a:@@0_PX70;d420341P`0a@D<0<H52P3<20T0d@X;0=<<2P3G3`T0
f0h90=X=2`3N40h0gPl?0>@D4P3T5100iaHB0>LG4`3Y61<0h1<A0=<<3P3D3`l0d`l?0=4?3`3F51@0
g1PE0=dG5@3M5aL0ga/J0=lJ5P3N61H0e18A0=DC4`3G51@0dQ0A0=4>3`3:3100]0H<0:`2202O1PX0
W@d@0:<21`2S0@D0W`440:011`2M0@T0V`8809X11P2F00@0TP4409011@2;0@<0R0420080QP4200l0
Q`4308h11`2@0PX0R`480984302E10`0R04707h10`1c0P<0GP4105d00@1c0@80O`8507X9000f/0D0
1000o`09ooooo`070?n0002P8?00X23`0:0Pl03@D7P0oh000=1@N0020:0Pl0030=1@N03oP000oh00
04L0oh0000<0P<00003o0000o`000P00o`08ooooo`0S093@L`1gPi@0PI2L09nSZ02_Yhl0]ih]0;^M
2@2]T0h0L5T90:f>3P30W0l0/H/i0:B4I02RPgL0Z8Yl0:f>P@2eUhD0_Yj;0<BVTP38ZiL0bZjI0<V^
V037[Y@0c;:K0=6eX@2oZi/0]jZL0<JcX@3I`Zl0f/Jc0=[9]03LbkP0g/bl0=o=_@3Scl000P3UdL<0
9@3Wd/D0hlk10=g9^P3Ha[D0eLBf0<fm^@2EQI<0O6=h09]BH@305a/0_a<@0=2:OP2JSIX0YV9^0;Pj
=@2`=Rh0Zbl[0:LX:P2K8BT0Wg^70<[AfP2_/;l0KdYP08XD9@2>82l0a[Nn0<?<e038d=X0aLgI0;o;
eP2fa=80L8FL07f@WP2AWZ@0X:>;0;>bO@1jO4X03`00o`08ooooo`050?n0002P8?00X23`0:0Pl02h
>;@01`3oP0001@3XJ3`0X23`0:0Pl02P8?00^3Rd00P0oh0000<0d51h0:0Pl03@D7P03P3oP000103X
J3`0^3Rd0:0Pl03@D7P30?n000030:0Pl03@D7P0oh0000@0oh0000@0^3Rd0:0Pl02P8?00^3Rd0P3o
P0000`2h>;@0X23`0:0Pl0060:0Pl0030;Ph]03@D7P0j6Pl00l00?l02oooool000[ooooo01`0VLIc
0<K8c@2[/kT0Q8V;06A8BP1761`0`Kg00<7<c`2NY:P08@hC03@42P0m1@T0PdX@0=fP5`2_80<0_PP9
0<872`351`T0b0H90<`92`3@2``0e0/>0=H=3@3G3@/0f@d=0=L;3@3J3@l0g`lA0P3T4Q80=P3U5140
j1DB0>DD503I3`h0ePh@0=PA4P3F4A80ca0@0=8A4P3F51@0fQDE0=`H5P3M5aH0g1LE0=dH5P3G4a80
f1DE0=HB4`3A3Q00d@dA0<H9402a0PT0[0470:X2202V0PX0Y@490:<1202R0PP0WP8609/11@2K0PL0
V@4609L11@2B0@D0T@86090210290@40Q@4208@10P2600<0SP4809822`2C10h0U@D<09@42`290PP0
O`4607H11@1X0@<0K`8307L10P1m0P<0MPL004RH2@@00?l02Oooool01`3oP000X23`0:0Pl02P8?00
d51h0?n0002h>;@00P2P8?000`3@D7P0oh000?n000170?n0000308300000o`000?l000800?l02?oo
ool0B`1[gE<0PHVH07f9V02RXj40/9i?0;NJ2P2/SPd0JUD9095h3`33X0T0[8TZ09QiI02KNgD0Y85l
0:R7O@2/SH00/iF60;jNS035Yi80b:VD0<BWT@35ZI<0bK2H0<fbV`3B^:40cKJR0;n/V@3C`:/0el>_
0=[5/`3JbKD0f/Vh0=c;^@3OcK`0h/no0>?A``3Td/<0hm320>;@`@3Lb[T0fLNg0=K5]P3FaKD0dL6i
0;Jb`01KFGP0/d=60<0k:`3DXI<0Si2J09^EY031TXh0bZRW0<:^]02^UjD0LEeb07EdQP2iaLh0b];F
0:BZ_01M<4/0R0XF0:QkP034cM@0aLoK0<K?f@31cMH0_<OE069eSP1eRI/0T9jW0:6YZ@2TZZX0JFI`
00cX1`0>003o00Sooooo00D0P<000:0Pl02P8?00X23`0>QX?0060?n000030=1@N02P8?00X23`0080
X23`00<0^3Rd0?n0003oP0001P3oP0000`3XJ3`0d51h0?n0000@0?n00080X23`0`3oP0000`2P8?00
^3Rd0>QX?0020=1@N0030;Ph]02P8?00X23`00<0X23`00<0^3Rd0?n0003oP0002`2P8?000`0Xb3`0
0?l0003o000<003o00_ooooo000:ooooo`0g09O2L@38bm80XZb`07b2Q01YDU@0?0hB0:nVZP32blh0
XJV]024<5P0d0`/0>08508aH4`3FUA<0/1L70;l72`331``0a0H60<X82P3;20X0d0`<0=<:3@3D2`h0
e0/=0=P<3`3K3Pl0fPh>0=d@403R4@l0ha8@0>PF4P3Y6A<0g10?0=H?3`3G4Q80d`h@0<l>4@3?4A40
dQ@E0<hB4@3@5AH0c1`H0<DT7P31=2d0e4m80=YBC03HAd<0cR@R0=HE5@3E4A<0b``A0;@32P2/0PP0
Z@880:L220020:<11P0K0:021P2P0PD0W@4409`11@2H0@@0U@8509421P2@0@H0T04408/10@270@80
Q`4308P11@2<0@P0TP8;09<22`2D10`0TP@;08P120210@P0N`4707`11@2<0PL0P@4307P20P1_1P00
BI/=00@00?l02Oooool01P3oP000X23`0:0Pl02P8?00d51h0?n000<0X23`00<0d51h0?n0003oP000
A`3oP0000`20`0000?l0003o0002003o00Sooooo04/0C=lf09nT[P1kQi80YIaZ0:nF402WS0T0Led8
07EN302bT`/0/Y4K09=fF02DMg@0VgYi09mmNP2XQ7h0Zh^10;2AQ@2kVhX0`Z6>0<>ST@36ZiD0bK2J
0<^fY03>]Z@0d[VS0=:lZ03C_Zd0e[n]0=W3/`3JaK@0f/Fc0=[8^03Ob[T0glfm0=o>_`3Pd;l0hm;1
0>C?`@3Qc[l0g<bj0=W7^03Ga[L0e/Bf0<fm]02OUiL0/JJW0=2^W@3A/9/0ajnR0<Ng/P25N8T0SE=S
0:0e@`2T:SX0YB<c0:4M;02K9SH0XDAF0;R1T@2ZX[80NFQg08M9B02_ViT0a<gD0<K?f@37cm/0a<gH
0<?<f@1<GW`0G7B;07>1S`2AVJ40U9bT06IZNP0W_Q`03P00o`08ooooo`0406RX?03@D7P0X23`0=1@
N0H0oh0000<0j6Pl0:0Pl02P8?00102P8?0J0?n000030>QX?02P8?00^3Rd0080oh0000@0d51h0;Ph
]02P8?00^3Rd1@3oP0001P3@D7P0j6Pl0;Ph]02P8?00d51h0;Ph]0/0X23`00<0D91h003o0000o`00
3000o`0;ooooo`002_ooool0E02B_fd0a<O>0:Ze^024S8`0GDY<03462`2/Y:P0bM;D0:2Z[00J3140
;@<903L71P2@HAD0ch/G0:d@1@3020T0``L90<P92P371PT0c@X<0=0;303A2P`0d@X;0=H=303H3@l0
f0/;0=/?3@3L3``0gQ8<0>@E403Z6180gA8=0=8<2P3A3P`0dQ0@0<`<3`3:3Q40b@h@0<hD50335A@0
]28N0:I8@03JWYD0n=;=0?[Qg@3lhMd0o]cI0?:YY033<2/0d1DD0<h?4P2k1`d0[0<:0:P22@2V0@D0
XP440:41102O0@@0WP4409`11@2K0@@0U`4308L0101m0@<0S@<608h10`2;0@40Q`4208P10`2:0@D0
S@8809<32`2B0`/0U0H=09443@250@H0OP0607X10`2>0PL0W04808h10P1i0@80K`@004RI30@00?l0
2Oooool01P3oP000X23`0:0Pl02P8?00d51h0?n000<0X23`00<0d51h0?n0003oP000A`3oP0000`20
`0000?l0003o0002003o00Sooooo04/0;^@M0:bX[P1nQG/0Yi@T0;6I1@2GOPX0TGXE0;:D2`2cUa40
U7U508mcK@2CM7D0V7Qf09enM`2UPg`0ZXMn0;2@Q02gW8/0`JBB0<NZV03:[i`0^ZZL0<_7a`3Le=40
c[NW0=:jZ03B^ZT0f<6b0=W1/`3H`k80elFd0=[8^@3JbKT0glfm0=k=_P3Ockh0h]720>?A`P3RdKl0
gljm0=O7]P3Fa[L0dlBe0=71/`3@_k40d;ja0<fl[@37]ZH0ak>V0<BcY`2n/:L0]:^`0:21Q`2HEeP0
[eE?0:iED02^G5`0Vd]C08`oC02FIW@0blW=0<G8c036c]80a<kF0<G@fP33d=X0a<cG0<7;e`27Vk00
NY6T08jMZ@2EWjP0WZRc06ehRP0g/C803P00o`08ooooo`0306RX?03@D7P0X23`00H0oh0000<0j6Pl
0:0Pl02P8?001P2P8?030?n000030;Ph]03@D7P0oh0001L0oh0000@0d51h0>QX?02h>;@0X23`0P2h
>;@0103@D7P0oh000?n0003XJ3`30=1@N0030;Ph]02P8?00X23`00/0X23`00<0D91h003o0000o`00
3000o`0;ooooo`002_ooool0E02D`F`0alcA0:Ba]P23SH`0I5=D03/=402h[;40cMKJ0:2Z[00G3140
:`@902`30P2GIaL0bGhF0;<@202o20T0``L:0<L82`3:20/0cPT:0<l82P3B2``0e0d=0=L<303L3Pl0
gPl<0>4C3P3P4Ph0hQ@?0>HH4P3V5Q40f0l>0=@?3P3G4a40da4B0<d?403=4Q<0aQHE0;XL6@2Y;BL0
]g5Y0>c@bP3`i^80knWX0>_Zj@3/jnX0k>SX0?GUh`3SUY40_RLS0<`B5@2o20l0[@<90:L1202T0@H0
X04409h1102L0@D0W@8509X0102I0080V@4408h21@1l0@<0R08708l1102=0P80R@4308X1102:00@0
SP4709<32P2A0`T0T@D<09053@250@L0O`4607h10`2J0`P0X`<809L31P1j0P<0JP<004FF2P@00?l0
2Oooool01`3oP000X23`0:0Pl02P8?00d51h0?n0002h>;@00P2P8?000`3@D7P0oh000?n000170?n0
000308300000o`000?l000800?l02?ooool0B`00o`00`[BS08f6C02bV`/0Vh870:J;4P2BM`D0/9DB
05A<6@24L6`0Sg=b09AeL`2KMgH0WGah0:B3O02YRGh0/9>40;NKR`2nXXh0_j>?0;jXT`2ZXIH0^KZk
0<_1^`3=]jD0dKRX0=:l[03F`;00el6`0=W5/P3E`kD0dL>g0<Jl[`38_[<0f<nn0=[?_`3PdL40hM31
0=o>_`3Nc/00f<Nk0=G6]`3DaKH0dL:a0<o1/`3=_[40b[V/0<VhZ@36]:H0`K:T0<Nk/02k/Z/0^k>/
0<[7a@36a<H0YJ^c08VEY@0Y?ET0ZKK409:AW`2FXJ/0a/oF0<G>eP32cML0a<oJ0<C@g033cMP0`lkI
06f1V01LM8T0RYfY0:>^]`2SZ[<0M7n?04b6A`0>003o00Sooooo00<00?l00=1@N03XJ3`01@3oP000
0`3XJ3`0X23`0:0Pl0060:0Pl0070;Ph]03XJ3`0oh000=1@N02P8?00^3Rd0=1@N0080?n00080d51h
3@3oP0001@3@D7P0^3Rd0:0Pl02h>;@0X23`00@0^3Rd4P2P8?000`2h>;@00?l0003o000<003o00_o
oooo000:ooooo`0o092lI`38c=00Z;Bj07Z7R01REUL0?`hA0;ZZ/03<dm/0VZ2V01d<4P0`10`0<0<2
0:ak7032JPl0]Pd90;l82`321`X0_`D70<D72P3>2P/0dP/=0=H<3P3H3Pd0fPh>0=`?3P3P40h0i1<@
0>DC403U5100iADA0=lD403C3Pl0eA4B0=DB4P3>5Q80`a`H0;DY8`2fH5P0bIVA0>SAc03/i^D0jn_/
0>SXjP3Yj^`0inSZ0>WZk03/k>l0kNg^0?3Uh`3`]kD0_Rd_0<@=4@2b1P/0Z0<:0:H32@2P0@D0W043
09P11@2I0@D0V04409T21@2J0@@0V@860080T08501<0S`4308X10@2;0@@0R@4408P1102=0@L0TP89
09H42`2D1@X0T@D<08H1201o0@H0SP890:832`2P0PT0T`8407X10`1T0@00@98800@00?l02Oooool0
0`3oP000X23`0:0Pl0020:0Pl0050?n0003@D7P0X23`0:0Pl03@D7P0B@3oP0000`20`0000?l0003o
0002003o00Sooooo04/00?l00<^/L@2VU1`0YY4809Im3@2VS0d0]iP707IX5`0W;3`0PVic095bM@2D
MGP0VWUj09n0O@2TQGl0ZXV20;6BQ`2jWHl0_Ij?0<6ST@2oYI40ThIk09Z>QP2hYiP0d;NU0=6jZ@3A
^JT0dkj/0=O1/@3JaKH0^JfS0::JU02e[:40XYVC0:>QV03Id;l0h=330>7@a03NcL00g<fo0=W<_@3C
akL0d/Ff0=33]`3=`;@0c<6c0<fo/`39^:X0a[BX0<JdZ`34]:X0`[J^0<O1_@2b/Jh0];Jj0:^b^P2N
ZkX0X;C608fX_@34e=d0^l[A0<KAf@36cmP0a<oH0<?=f@32cMT0`/kG0<7<f020TZH0FG>:06j2T@2B
WZL0TYZS06ejRP1TG5h03P00o`08ooooo`03003o003oP000oh0000D0oh002@2P8?00102h>;@0oh00
0?n0003oP0020:0Pl0030=1@N03oP000oh0000@0oh0000D0^3Rd0:0Pl02P8?00X23`0;Ph]00:0?n0
00040>QX?03oP000j6Pl0;Ph]080X23`00<0^3Rd0=1@N02P8?000P2h>;@C0:0Pl0h00?l02oooool0
00[ooooo0480T;YT0<75b@2/^;h0MH>3075XJ00n3a@0/9nV0<cCfP2JWJ807``C02X3200c1`@0]hPL
0;EG3P2d20P0_@H:0<0720311PP0a0H80<`92P3C30h0ePd?0=@=2`3J40d0f`l=0=lB3`3S4Ph0i1D@
0><D3`3R5Q40dPh;0<l@403<4a40b1dG0:`a9`2bI5/0hkV`0>kQg03Zi^D0i^GV0>OWi`3Yj>P0j^WY
0>SXjP3Xj>T0k>c]0>WYj`3[k>h0k>g^0?GTi@3?Kfh0`a4A0;D62@2/1@X0YP@90:411P2L0@@0VP44
09P11P2G00@0U04409L11P2F0@H0U04409@21@2@0PL208`1100@08P10`270@80R04408l2202D0PX0
UP@;09<42`280@P0R04609X2202E0`X0R`4508h21@1k0P80I`40051e1P@00?l02Oooool00`3oP000
X23`0:0Pl0020:0Pl0050?n0003@D7P0X23`0:0Pl03@D7P0BP3oP004003o00Sooooo04/00?l007g6
7P2YU0d0IUP2091l4@2JP`d0]Id^04Y8>00b=UD0Pfmd08maMP2FMWX0VgUl0:1mO@2SQ7l0ZXb60:j=
QP2gVXd0_J6A0;nRSP30Xi80YI210:VHR032[Id0_JZL0=2jZ@3B^:T0dkb/0=Bo[`3Ha;X0SHB30;6[
YP31^K40[jJU08>3OP3Hd;l0gm720>7Ba@3Ncl80g<_10=W:`03Cb;`0d/Fj0<o4^03<`KP0c<6f0<No
/P33^Zh0`;:T0<2bY`2m/JL0^kB_0:bT[02^WZ/0bk:i0;JTZ@1MJGl0TjBh07>=X`33dmd0^LG;0<OA
fP35dMT0_lcF0;k;eP31cML0_lcE0<7<e`2EYk/0LhbR08VMZP2GY:`0Uj>[07b9V01SIF/03P00o`08
ooooo`03003o0030X000oh0000@0oh0000<0^3Rd0:0Pl02P8?00202P8?000`3@D7P0oh000?n00002
0:0Pl080d51h1@3oP0050:0Pl0/0oh0000<0^3Rd0:0Pl02P8?00102P8?000`2h>;@0d51h0:0Pl00C
0:0Pl0h00?l02oooool000[ooooo05@0SkQQ0<G:cP2`_<@0QY2B06YSI@0h3AD0ZYZP0<oGg02=U9L0
6`/A02/32P0o3080aY<N0:e32`2h2@/0`0L<0<<730351PX0b@P;0<`92`3A2P`0dPd>0<h@3`3I6AT0
fa0@0=lB3`3L4`l0eS4Y0=Hk<P3A<RT0bC4Y0<]9@@3>I5/0eh^30>g<a`3bin<0k>SV0>WXj03ZiNL0
k>3U0>[@eP3W/kd0eY2K09aTL02k/KH0k>c^0>c/k`3]kO00k>g_0>cXiP3PY:@0^aHG0;/8302a1P/0
YP<:0:81202P0PP0V`4309T11@2C0@D0TP450981102B00H0TP4609011P2<0@D0R`4708/11@280@<0
Q00108P21@2?0PT0T`<;09H5302D1@`0SP4909/12`2Q0`/0P04508XF6P2310P0N@4206T1001OF@H4
003o00Wooooo00<0oh000:0Pl02P8?000P2P8?001@3oP000d51h0=1@N02P8?00d51h0240oh0000<0
d51h0>QX?03oP0009P3oP004003o00Sooooo04`00?l003gR1P2BPPT0NVX50:bE2@2cWbX0SX=C04I;
G@0l@5h0QW9d099cNP2FMW`0VWYl09amO02TQX<0Z8R50:j=P`2iVXd0^I^;0;nQS@30Xhh0`ZFD0<>X
U`30ZYT0YIF;0<JaW`3C^ZP0d;jZ0=G3/P3E`KH0S86108J4R02<Rhh0Ogn109NCRP3Mckl0glo20=oA
``3Ld<40f<^n0=?8_P3Aa[`0dlFn0<k3^`3=`k/0cL:h0<Vn]@31]jh0_KB/0;>/[P2HRYX0TVAn09/e
CP2Z6bh0[18O0:PW<035RYP0LFYk07j?XP2ncm/0b=;J0<GBf`34c]P0_lcE0;c:d`2oc=L0_l[E0<7;
f01/OiL0J8:M07bBY02Y]<00[;O206EdRP1KI7806=8?3@00o`08ooooo`03003o0020`000oh0000<0
oh0000<0d51h0:0Pl02P8?002@2P8?000`2h>;@0oh000?n000020>QX?0030=1@N02P8?00d51h00@0
oh001@2P8?0:0?n000030>QX?02h>;@0X23`00<0X23`00<0^3Rd0=1@N03oP0000`3oP00B0:0Pl003
052@N000o`000?l000/00?l02oooool000[ooooo05@0SKEN0<G9c@2a_<80Phf@07QdN00f3aL0[IbU
0=;Jh@1oQXd07@/C02h31`176040didR0:L[1P2k20`0``T=0<<72P3020`0/`D:0;<62@392`d0bPd>
0;hL70397Qh0g@l@0>0A3@3H4Q00Vb<S0<B=S@3cd]00nN7N0?OWi@3dj>L0ln_Z0>oYjP3^hn80kM;E
0>:X[P3ANH40d5aW0<@^>@367BD0cA/O0;@N8@1Z?440jNW[0>_[k@3/k^l0j^_]0>c]kP3eemX0_2/^
0<X>4`2l20`0Z`<:0:<01`2P0PH0VP4309T1102C0PD0T08809<11`2C0@D0T@4508l11P2:0@<0RP44
08X21@280@H0PP4208<10`2<0PL0T@<809L53P2G1@d0XP@=0:X32`2P0PT0N@4507/3201g0PL0MPP;
06L10@1KEPL4003o00Wooooo00<0oh000:0Pl02P8?000P2P8?001@3oP000d51h0>QX?02P8?00d51h
0280oh0000<0d51h0?n0003oP0009@3oP004003o00Sooooo04`00?l001Sb1028LPD0Y8l;0:nG102Y
UT00XYjG03DmF`1;BfP0R79i08e`MP2BMGP0VG]n09imOP2RPH00YhF10:Z;P`2`ThP0_9j>0;nTS`2o
YHl0a:NB0<R[UP39[iX0a[6M0=;0Z`3E`:d0ckfZ0=70[`3B`;40a[BY09f?RP2OUHl0]:RM0=C4]P3M
c;l0g<g00=_=`P3Hc<40el_20=?;`@3BbKl0d<Nn0<g4_@3<a;d0bL:l0<Bn_02`Z:l0VhBG09ECKP2/
;TD0/a0N0;T;402f2@l0^0H?0;L42`2[2aP0VcQ60:bIY038e=/0bMCM0<KBf`33cmT0`<cD0;o:dP31
cML0`/gG0<3=f02AX[D0F76807V@X02CWZX0Uj2/05eYP@1>FFX0;[HQ3@00o`08ooooo`03003o0010
h000oh0000<0oh00302P8?000`3@D7P0oh000?n000030?n000030=1@N03oP000oh0000<0oh0000D0
j6Pl0:0Pl02P8?00d51h0>QX?0080?n000030>QX?03@D7P0X23`00<0X23`00<0d51h0>QX?03oP000
1P3oP0020;Ph]0l0X23`00<0D91h003o0000o`002`00o`0;ooooo`002_ooool0:02:]5/0^Kfn0;C0
a`2?WJ80M75f03HA602YVJ40e]cV071fO`0L2a<0<0D906@e403BVRL0X1L50;P7302m1`l0^@L<0:@3
1`32;CD0`CDj0:L72@3=3Pl0fB<V0=PM7`3O4A00hQ8@0>8C3`3B4aD0[a4H0:dd@034IW80bWJ10=j<
UP3MPhl0eFMc0<i?F039<SX0d1lV0=4I7@3A5AL20=HF6@0E0=@F5P3:6A/0MAHI0:jWZ03Xj^/0jnc^
0>c]k`3]kO00l^OZ0<MIG0384QD0``/=0;@62`2X0@P0X`4809/1102F0@80UP4409D11`2?0PP0T088
0080T@4701<0S`8508d10P2=0@@0R`4608L01@240@@0S08808h12@2C10`0X0D>0:d5302X0PT0W@<:
06d1101a1P`0N0<907@;3P1/0P@0F4l300@00?l02Oooool00`3@D7P0X23`0:0Pl0020:0Pl0050?n0
003@D7P0oh000:0Pl03@D7P08`3oP0000`2P8?00oh000?n0000T0?n000@00?l02?ooool2003o001:
09>:1P2^VPD0[iTD0:^NIP25Q8X0?TIW05EFK@26L7H0SW1g09EdN`2JNGl0Wgen0::1P@2UPgl0[8R0
0;JES02lWXl0_Z6>0;nSS`34ZIH0aZbF0<^bW03=]Z@0dkj]0=2mZP3B_Z/0dkf]0=;1[`3FaKH0e<:d
0=W8^@3Lbk`0f/Rj0=_:_@3Ibkd0eLS00=G:a03Fc<L0_Ko10<?5b@3F`;h0eKFg0<JTZP2kTj40ZVYo
0:]5G@2c8c40^1HJ0;DM6`2g>S40^Ea@09aDEP2H;cd0/PL@0;H42@2[2100U3e70<?8d03>f^40a]?L
0<G?f@32c=H0`LWD0<3<e034cmP0`/kI08nS]`1LMH/0Rj2_09FR[P2GXZl0H6n7041@H00lYRl=003o
00Sooooo0P00o`030?n000030>QX?02P8?00X23`00X0X23`00<0d51h0?n0003oP0004`3oP0020;Ph
]080oh0000@0d51h0;Ph]03@D7P0d51h1@3oP0000`3@D7P0j6Pl0?n000020?n000030>QX?02P8?00
^3Rd00h0X23`00<0N5Rd003o0000o`002`00o`0;ooooo`002_ooool06@29/5L0c]7C0;W4c@23TYH0
QHB903@B602YVJ40e=gV05eRJ`0Q2a80<@H908UG6P3;SB00W0l60;L73@2h2140Z0D<0:T42P302Q<0
]`XA09`31@3=3@h0d`h?0=X?4`3O41000P3P4`l0>@3B3Pd0b`/:0<d@4P3A5AP0dQPM0<lG7`3A6B00
e1TM0=4G603D5QH0eaTH0=PM6P3C6aL0da/I0=LL703D5AP0caDI09dH701QADL0hnKV0>S[k03[k>h0
j^_]0>kZj`3?Oh<0`ALI0<@<3@2j20`0/0D<0:H12@2K00@0V08409@00P2C0@@0PP4208<10`2@0PL0
SP4508`1102:0040S@8408X11@2800@0Q`4308/21P2@0@X0X0P@0:L42`2/10`0X`4809`22@1/1`/0
C00407032P1h1`d0L08305]@1004003o00Wooooo0P3oP0030:0Pl0050?n0003@D7P0oh000:0Pl03@
D7P08`3oP0000`2P8?00oh000?n0000T0?n000@00?l02?ooool2003o001:07Zg1@2[V140/:EL0:ZU
T023Q8`0>dEU061NLP27LGL0TG=j09=aN02GLgL0WGUj0:>0PP2WQH<0ZhR20;BGSP2lWI<0`Z6C0<2S
T@2oYI@0bJbK0<V_VP3;]:40dkfZ0=:oZ`3@^ZT0d[n/0=;0[P3Fa;H0d/6c0=O7^`3Jb[d0elRj0=W;
_P3Hc;l0f<c30=S;aP3Fc<L0[[Bo06aoX@2RM8T0[D9B0;4c@P2g:SP0^R4Y0;XT8P2o?300`F=E0<JC
Q02lXI@0[j6C0:JMWP1JAF@0WQ4O0;H33@2b0``0XahV0;Z^^03>fN80amCN0<7>e`35c]P0`/_E0<C>
f034d=X0`loK07b?Y01UQ9h0MY2P09VZ]`2O[kh0Gg2;049CI@1<Pcd=003o00Sooooo0P00o`020?n0
00030>QX?02h>;@0X23`00/0X23`00@0d51h0?n0003oP000d51h4P3oP0000`2h>;@0X23`0;Ph]007
0?n000030>QX?03@D7P0X23`0080X23`103oP0000`2P8?00^3Rd0:0Pl00>0:0Pl0d00?l02oooool0
00[ooooo05@0Hl520<W:b`2f`LT0UJ>W07AeN`0d51/0[IfV0=OOi`1=DUX08PXA03471@2/O200_gXJ
09d;1@2b1@`0[@P>09021P2f20l0a0H=0;H72`2L1@H0cPd>0<l92P3H3Q00f`h?0=d@3`3L4a40c0`=
0<P<303>3a40dQ@B0<lO703?;RP0dSTb0=4_:P3<8A`0bA`J0;Xi=03OMVd0g7Y_0>68OP3XQh80`2l_
0=4H702m71l0CPd?0=3<c03Xj^T0j^_]0>_/k03Zj^/0gJZ/0;DQ90343A00^0D;0;@53`2/0`/0WP47
09L11@2C0@<0U00308h210290@<0SP8308d10P2@0@L0S`4608h11@2<0@L0S04508/1102<0PH0V@D<
0:h94P2b2100Z`D;0:D12@2O0PT0TB8Y07Ti?P1^10X0P`<907H10`1KC0@4003o00Wooooo00<0`:00
0:0Pl02P8?000P2P8?001@3oP000d51h0?n0002P8?00d51h02@0oh0000<0j6Pl0?n0003oP0008`3o
P004003o00Sooooo0P00o`00BP1l^PP0ZZ1>09nQV`2OXJH0UiZU038oG01[JGT0Q6ie08eaM`2FM7X0
VgIk09iiN`2ROGl0YhJ20:V8PP2eUH/0^ijC0;nQU@2nWi<0`Z>A0<R[VP3;/J00bkBP0=>nZ`3B_Zd0
dKf]0=>o/P3C`;80eL>e0=;1/`3HaKT0f/Zn0=O7^P3Hb[h0elg30=S<a@3GblL0eL_80=?:bP30_/P0
X9n`0;2LZ02gTi/0`I>E0=:TVP3C[Z80bk>W0<:dZP2i[jH0/Z^Q0;2YW`2f/Jh0GV>008PdBP2_10h0
/P4<0:L84P2WNhL0cM[R0<cIhP35d]/0a=3J0<G?fP32c]X0`m3M0<7?f`2M[lD0EW>D05AdV`0gD8H0
;T=n01P/IP14Ef/0E6i33@00o`08ooooo`800?l000<0oh000>QX?02P8?003P2P8?020=1@N1@0oh00
00<0^3Rd0:0Pl02P8?000P3@D7P0103oP000j6Pl0=1@N02h>;@30:0Pl0030;Ph]02P8?00d51h00<0
oh0000<0j6Pl0;Ph]02h>;@03P2P8?0=003o00_ooooo000:ooooo`1D04Je903>blL0_LW?092PYP1i
OH80<AHK0:^MY`3Fg^L0=CQ002@94@0m3`<0b9P/0:UL502R2@P0/0D?09T73P1o0P@0^PP>0<H83P2/
1PT0Z0L:0=<=3`3F30h0e`l>0=X@3P3H4100d@`?0<X:3@3=3Pl0aA4C0:8/9`3LYI`0n=[D0?SQg03h
fM@0l/>m0=FFS`1jGEX0i=_I0>[Ti03/inL0mNGV0<aoPP388B@0d1/L08TF602ORhd0k>c]0>c]k`3W
j>T0j>WY0>[Bd`2U>C`0^10D0;H63@2c1Pd0[P@;0:L2202N0PH0V00309H10`2?0P80R@0108T10@2<
0@40SP4309411@2B0@L0SP8608T1102:0@80UP440:P42P2d20l0/`H>0:h42`2Y0PT0X08809D83`2;
6B00QPH>08H11P1h0@80M2<41000o`09ooooo`030830003@D7P0X23`00<0X23`00@0d51h0?n0002P
8?00d51h6`3oP0000`2h>;@0oh000?n000060?n000030>QX?03oP000oh0002<0oh001000o`08oooo
o`800?l004/0OKT@0:6LJ@2U[;00X::Z07j1SP0iA5l0LVei08E^M`2>L7T0UW=h09]dO02MN7/0XWio
0:J2P@2ZQX<0]9B<0;RJS`2lWi00_Z2B0<:STP39Zi/0bk6Q0<bdXP3B_:/0e<6a0=:n[P3A_[00dl2b
0=C2]@3B`;<0eL>f0=S9_03Fb;d0eLZn0=C;`P3DbL<0dLS40=C9a@3BbLH0d/[80<c7``3<b/H0bLS4
0<O3`@39`[`0akfg0<6i]02d/K<0]k2`0;b/YP2gYZ40]:bW09jT/P1LAV/0X0hK0;<2302_10h0/5=K
0=KHgP3;en<0a]CN0<GBg036dMd0a];M0<??g@2S^=D0<df600@LH`0156000A9N004AF`014U/04bA>
05aLEP06l`<03000o`08ooooo`800?l000<0oh000=1@N02P8?003P2P8?020=1@N1D0oh003P2P8?04
0?n000030>QX?02P8?00X23`00d0X23`00<0:<Pl003o0000o`002P00o`0;ooooo`002_ooool08018
]R<0a/;00;?0a`2CXjX0NGf103<E6P2^X:P0dm[T02//=@0V2A40D20:0<jM;@2<?a00WPP;0:`73`29
10T0M`450;483@2l2a00V`<70;892`3B3@h0dP`;0=8:2`3H40d0c`/;0</9303=3@d0bP`;0:H@4@2S
OGP0lNcZ0P3/k>d0<P3[jnh0jn[/0>cXi`3OfmL0dlo?0>OVj@3XjNT0k^SX0?K8bP2o;300dQHK0;HP
9`1nEEP0k>k_0>_]k@3UiNP0jNW[0>kQh`2/HVH0[1DH0;D83`2b1Pl0[0<;0:/32@2S0@D0V@0309D2
1@2>0@40R`8208T10P2;0@40S`4309411P2B0@T0S00408`1102C0@<0Y@880:`22@2e1A00]0D>0:h3
2P2Y0`P0Y@8809d22@2B0`/0S04:08@21@1c0000OQ@51000o`09ooooo`030830002P8?00X23`0080
X23`00D0oh000=1@N03@D7P0X23`0=1@N00T0?n000030=1@N03oP000oh0002<0oh001000o`08oooo
o`800?l004/0Gm@]08nCOP2PYZh0XjJ`08b<W00h?UP0N6mj08EaN@2=KgP0UW9i09eeN`2QNWX0Xh20
0:F2P@2ZQX<0/I290;ZJTP2jV8d0]iF80<2QT@35ZYT0bJnN0<^dYP3=^JT0dl6c0<jk[`3@_[00d/6b
0=;0/`3D`KD0eLBf0=G8^`3Eb;d0e<Rn0=;:`@3Cb/<0d/[50=;;a03CblH0d/c70<g9``2a^lD0P92Y
0:>>Y`37Mh80b7=h0<R9SP2?OID0R6=n0;<oBP2g>T<0`h^<0:n^/01BG800TS580;874`2b0`d0WQHP
0=O5c03:e=l0a]?L0<C@f`33dMh0`M3O07ZB^@0>9fd00AAV000BHP014V000Q9H008BEP0145L00Q16
04I>D`0HdPl03000o`08ooooo`800?l000<0P<000;Ph]02P8?003`2P8?000`3@D7P0oh000?n0000C
0?n000040=1@N02P8?00X23`0:0Pl080oh0000<0j6Pl0;Ph]02h>;@00P3oP000103XJ3`0X23`0:0P
l03XJ3`40?n000l0X23`00<0D91h003o0000o`002P00o`0;ooooo`002_ooool0E018]bD0aL;00;W6
c@2@WJ<0O86403<F6`2bY:`0b<oH01hJ900W1Ph0HS<B0=FR<@28;@d0X`H;0:`63`2510T0J`4408l3
2@2D0`T0Q@440;@:3@3C30h0dP`;0=@=3P3@2`d0a@@90<T83P3>30d0cPl@08l>402jZJH0k^k^0>g]
l03/jnh0jMcP0;jCW@2oUj<0i=cO0>KUi`3ViNP0inWY0>SWj03hhN<0aU1D0=@K7P397B00Lbdb0>W[
k03Wj>T0j>W[0>OVj@3XhN@0f:R[0:LO8`2b1`h0/0D>0:d43P2^0`/0Z`<:09h11`2G0@D0T`420902
0@2<0P<0RP8108d20`2?0@D0TP4809811@2H0@D0XP860:T2202W0PP0/PD>0;H8402a1@d0ZP<:0:<1
1`2H0PP0T0<:08/21`240PH0L`4107XA10@00?l02Oooool00`20`000X23`0:0Pl0020:0Pl0050?n0
003@D7P0d51h0:0Pl03XJ3`0503oP0000`3@D7P0oh000?n000030?n000030>QX?03oP000oh0000L0
oh0000<0j6Pl0?n0003oP0008`3oP004003o00Sooooo0P00o`00B`1ZgD`0SINK0:J^^@2IW:H0TYBQ
03e2E`1jKWP0Qg5g08i_MP2FLGL0VgEi09eeMP2QO7`0YX>10:Z5Q02cSHX0^IZA0;fMT@2nWi00`::A
0<>XV03;/J40cKFV0<nk[03A`;<0c;Z/0<jl[03A`;40d/2d0=C1]`3D`kH0eLVm0=?7_P3Aakh0dLW0
0=C:`P3BbLH0dLW50=;9``3BblL0c<W506EoW`1fPK40[De[0<PH8`3851`0^Q/T0;0nD02oI7T0]a4K
0<L?5P30EeL0]k2_08NDZ`1a@600YPdK0;@43P2W1a<0_i2I0<_Cg@37dm`0a=3I0<3@g@2G[/h01b1X
004CHP014F0001=M00<GE`0K;5L09cQY01HYFP0?7DL0<cm?02_7900<003o00Sooooo0P00o`000`20
`000X23`0:0Pl00>0:0Pl1L0oh0000@0d51h0:0Pl02P8?00d51h203oP0020:0Pl0030=1@N03oP000
oh000080oh003`2P8?000`1@T7P00?l0003o000:003o00_ooooo000:ooooo`1D04Bc8`2f/k80_LS@
096PY020PXL0<aLL0;FX/@2d^lH06A4L02X63`1oCQT0bi@]08DB1P2/1P/0/@D=09L63`1T0@D0N10G
080H7`230`T0_PT=0=4<303B2``0e@h@0<L82`341Pd0b@T?0<h:3`3?3Pl0UQ0C0;:SY03/k>d0jNW/
0>WXjP3E[;00[RP_0;`N9P2@<cl0Z9NP0>?Ri@3Ui^L0i^SY0>gUi@3GQh`0d20T0=4H6`264aT0`;bn
0>CWj03Zj^`0jN_]0>OVj03Wd]<0Xce00;094@2`0`d0/0D>0:h32`2^0P/0Y`8909l21`2D0@@0T041
08h10P2;0@40RP8208l10`2G0@H0XP890:D21`2U0@H0TP4408T2102W1Pd0]PP?0;452P2[0`P0X`47
09<220210@@0Q`8708D11P1h0@80M@`31000o`09ooooo`030830002P8?00X23`0080X23`0P3@D7P0
0`2h>;@0X23`0=1@N00D0?n000030=1@N03oP000oh0000@0oh0000<0j6Pl0=1@N03oP0001`3oP000
0`3@D7P0oh000?n0000R0?n000@00?l02?ooool2003o001;06[LCP2GXJ/0WZFc09fOZ020Qi@0>dEH
07a^N@26KgP0SVme09A`M`2LM7T0XGQj0:9nP02UP800ZX>20;:<R02gUXh0^Yb@0;nQU032XiD0aZZM
0<Z`X03<]JH0d[^]0=:n/03?^j/0cKVZ0=2n/03A`[@0dl:i0=71^@3=`[/0d<Jn0=;8`@3Ab/80e<_4
0=G>a`3DblH0eL_50=?;a`3=bl/0E72H0:VUdP2b>4d0d18H0<TC5@3>FUT0X4MJ0:D_A0314ah0b@`C
0;DV:`33Y:@0Y:^f0518J`286Bh0Z`DA0:X43P2[EV40c]7I0<K@f`35dM/0[l;L02<nP0015fL00AAO
00@JG@0iE8D0JX2M08nP]@0X?FD0F6f305]TMP0T<T@0>J@`00`00?l02?ooool2003o00030830002P
8?00X23`00l0X23`00<0j6Pl0?n0003oP0002P3oP0000`3@D7P0oh000?n000060?n000030=1@N02P
8?00X23`00@0oh0000<0d51h0?n0003oP0000P3oP0000`3@D7P0X23`0:0Pl0040?n000030;Ph]02P
8?00X23`00`0X23`00<0N5Rd003o0000o`002P00o`0;ooooo`002_ooool0E015/R@0^kVj0;g9dP2?
WZD0MGQo02lC602fZ;80Yjjg014<5@0T1@X0T60P0:]Z7`292`H0/0L<0;@52`2^2Q80L`<60>BQZ03S
XJP0TQ4D0<H:303A3@l0dPd?0<`83P301@T0`PD;0</;403@2Pl0da0C0:TB5P2JQ8P0jNO[0>GUi`3V
i>L0g[jn0:HZ;03451P0/1PP03d83`39aLD0i^KW0>OXj03^jn/0h;2a0;/T9`3>5a/0XQHK09>3QP3R
i^L0iNWZ0>KZj`3Ti^H0i]cM0:iSIP2[2a<0Z`<;0:`2302]10`0Z@8;0:D12@2Q0PL0UP490981102A
0@@0T@8408d10@2B0040X@460:L12@2V00L0X`4509/42@240@@0V@H;0;L94`2b10`0[P@:0:D1202H
0@P0Q`0508L11P260PD0N`4307D:0P@00?l02Oooool00`20`000X23`0:0Pl0020:0Pl0040?n0003@
D7P0d51h0:0Pl1D0oh0000<0d51h0?n0003oP0001P3oP0000`3@D7P0oh000?n000050?n000030=1@
N03oP000oh000280oh001000o`08ooooo`800?l004/0H]4o0::X/P2HX:d0W:2]045?J00_>580O6]e
08=/M@2<L7L0UW5i09agO@2NN7`0Xg^00:IoP@2YPH<0Yh9o0;FFS`2lW9D0_inD0<:TU034Z9P0bJjO
0<ZcY03A^j/0a:VE0=BmZ`3=^ZX0cl2a0=2o/`3>_kP0/jRP0;bb[02b[:P0dLO10=?9``3CblD0d/g7
0=?<a@3EcL/0e<c:0=7;c01dRZh0BUbA0:eCKP3?4aX0aAHH0=VJU`2h/KH0O6Z509XeD0323QL0^`dC
0<YoP@2VYZP0Ce]h07Q<K@2F31d0Y`<=09<C803?_lP0a];L0;k=g`0eCh`00QY_00@LI@19II00GGNE
06n;XP1kTZD0AV6601lgG01^OhD0KWYo02`iA@1?S4L03000o`08ooooo`800?l000<0P<000:0Pl02P
8?003`2P8?000`3@D7P0oh000?n000090?n000030:0Pl03@D7P0X23`00L0oh0000@0j6Pl0:0Pl02P
8?00d51h0`3oP0020:0Pl0040>QX?03oP000oh000?n000<0X23`0`3oP0000`3XJ3`0X23`0:0Pl00=
0:0Pl0`00?l02oooool000[ooooo05@0BkPX0;Fa/032c=D0UjJ/07n2Q`0b4aT0_k:i09RPZP0A31@0
8@D80:Ad;02:?@d0TPT70:d42@2e1P/0]PL>09`83@2VAdd0YTU;0;TV9P3930d0``@80</=40351P`0
``P<0<D83P382@/0c``=0<h<3P2i4aL0NUEG0>KRi@3Vi>L0i>CW0>KFe02XDdl0^QTL0<4H701[3180
UXV:0>KViP3Wi^P0inKW0>oEe`2]>3`0`Q<H0;@G7@1eCe<0hnCU0>GUi`3Zj^`0iNGW0>?Mg`2oRH`0
Y@lE0:`73P2]10d0[0<;0:T22P2U0PP0X@<809/1202L0@L0UP4409410`2F0@80X@860:T1202X0@P0
Y@470:<11@2Q0PH0V@<809/32@2e2@l0]0D>0;04302T0@X0V`4809811P290@<0Q08407d2101g2P84
003o00Wooooo00<0P<000:0Pl02P8?000P2P8?00103oP000d51h0=1@N02P8?0E0?n000030=1@N03o
P000oh0000H0oh0000<0d51h0?n0003oP0001@3oP0000`3@D7P0oh000?n0000R0?n000@00?l02?oo
ool2003o000V037V7`2QWj@0Vj>_09BHYP0N9TL0?41J07UZM024KGL0Rfmh09A`NP2HMG`0XG^30:9i
OP2VOh40ZX>50:J1OP2dTX`0^IZA0;nNT`30Wi40aJRG0<R^WP38[Ih0cKJW0=2iZ@3@^jX0cKZZ0<no
/03@`;@0c[ni0;R]Y`3<a;/0]:nW0=39`03Cbl80dl_40=?=b03BblP20=?=b`0S0=79b@2`^<X0;4ak
089WS`316BD0cA8I0<iOH@36];00Zjbg05aEQ02Z7C80`0T>0:h]<@2n[J`0TI^Z02`_E`25:D@0Y@@A
09h54P2eNhD0bM7N06f4[P027Vl03bm`07VF]@2a`m<0KHBJ07J?Y01TOJ0042UK07:6U@1dOh<0Lgao
0351B`1MGE@03000o`08ooooo`800?l000<0J:Pl0;Ph]02P8?003`2P8?000`3@D7P0oh000?n00009
0?n000030;Ph]03XJ3`0X23`00P0oh000P2P8?001@2h>;@0oh000?n0003oP000^3Rd0080X23`0`3o
P000102h>;@0X23`0:0Pl03@D7P30?n000l0X23`3000o`0;ooooo`002_ooool0E@14[a`0_;Bb0<?<
e@2IYj`0M7Ym02lH6`38`<L0Qi2H01@;4`0S1`H0/Wl/070E0@2I1PL0/@D=0;P53P2h10d0/P@:0;TD
6@2e3a<0`PT=0<X930321@X0`0H<0;h52@331`/0aPH:0<X;3@3=3P`0cPh?0<@A5P1S7b<0gMOI0>KT
iP3UiNH0j>?R0=F[Y`2X9RD0aaHI0:LI7P1U@480hN7P0>OViP3WiNH0k^CT0<]oP@2l7Al0_1<I06<K
803Cd=80hn7T0>GUi`3QhN@0h=gP0=Vm_P2L6Ql0[@L?0:l43@2^0``0Z@<:0:L22P2X10`0Y`<;0:@0
2`2R0@P0X0450:D11@2X0@L0Z`890:P11`2U0@L0XP450:811P2W0PT0Z0890;463@2e1`l0[@4<0:82
2P2H0@P0S`4608H110200@D0OP8507P70P0Qa`400`00o`09ooooo`030830002P8?00X23`00<0X23`
0P3@D7P00`2P8?00oh000?n0000C0?n00080j6Pl1`3oP0000`3@D7P0oh000?n000050?n00080j6Pl
8`3oP0001020`0000?l0003o0000o`08ooooo`800?l004`05_0;0<2j^@2MY[@0XjRh02L^CP16Aeh0
L69[085^M`29KgH0TVmh09QcNP2MNGl0XX2309UiO@2SOX80Z8600;6;R02gU8/0_9b>0;fPT@2mXi40
aZjM0<^aX`3>]ZL0cKVZ0<fk[03<^:X0ckf_0<fm[`3@`;@0_[:Z0;ZaZ`39`KP0clS00=3:``3DclP0
eLk70=?<b03<b<L0d<c;0<o8aP39b<X0XkC=05MYV02d?E40cA4I0<8O903DWi`0^;Bb06ejW@2;@FH0
_@dH0;0=502hOh00XJ6W06E]RP1O>U`0W0PH0:D33`2H<3`0b<OI01LeM00L?G/0VKK>0;W;e@2faM80
G7:?03A@NP0995L0IWZC07j8SP1dOX00JGMm02/nC@1KGeH01_<32`00o`08ooooo`800?l000<0@>00
0=1@N02P8?003`2P8?000`3XJ3`0d51h0>QX?0090?n000030=1@N02P8?00j6Pl00D0oh0000@0X23`
0?n0003oP000^3Rd0P2P8?00103XJ3`0oh000?n0003XJ3`20:0Pl0040=1@N03oP000oh000>QX?080
X23`00D0^3Rd0?n0003oP000oh000=1@N00>0:0Pl00302S8?000o`000?l000T00?l02oooool000[o
oooo05D0@jdI0;R`[`3;e=d0TInV08>8S@0b6R<0al?<079kQ@0A2Q00:`h40:ig;@1[2040W0L;0;<7
3@2h1@X0^@D90;T320362@d0a@P90<H82@3:2@`0`@H:0;P21P2l1@X0`@P<0<042@361`/0bPd=0<T<
3@312@h0K``A0<S1`P3UiND0iNGV0>KUiP3Udm40[4E50<HE6P2n61h0G1LM0=7@c`3Sh^00inOW0>_V
j03MZjh0ZR8T0<0D5P1e3a<0]:j_0>;RhP3Rh^<0h=oQ0=kNh03Ncm00Wc0g0:h94`2a1Ph0[08:0:T2
2P2W0`/0YP8:0:L1302Y00/0/@8;0:l3202Y0@H0Z@480:X11`2X0@L0Y@450:41102R0@L0Y@490:H1
1@2a1Pd0/P@>0:`23@2Q0@X0U@4708d11P250@H0O00407X11@1d1@808LL200<00?l02Oooool00`20
`000X23`0:0Pl0060:0Pl1H0oh0000<0d51h0?n0003oP0001P3oP0000`3@D7P0oh000?n000050?n0
00030=1@N03oP000oh000240oh0000@0P<00003o0000o`000?l02?ooool3003o001;0<Fi/@2KYkL0
Ui^[0457H`1=C5l0MFQ^07iZL@25K740T75i09QbNP2QMgd0VW9j09EbN02EMgX0ZHF50;6;Q`2eT8P0
_IbB0;jQTP2oX900aJZJ0<B[V@3:]:<0b[JX0<jiZ`3;]j/0ck^^0<jl[`3;_[40c/:h0<c1^`3@a/00
c/O20<o;a03Dd/h0e<o;0=7;bP3=b/P0c/g80<c:aP3=alH0bLS=07J;Z`2AIHP0a1HP0<X@5`36EeT0
_JjZ0:Z`_@1DBW/0YQ@X0;T94P2Z?T<0[Z:T09BHY@1:BVl0RQ`c0:82402?1Q<0X7nF00/YIP2C/Ll0
^lgH0;W;e`2BZ/X08Smd00lYF01CJXH0OhnF06iiOP1ULgP0>deW01T^DP1GHf@07<HA00/00?l02?oo
ool3003o00030=1@N02P8?00X23`00h0X23`00D0d51h0>QX?03oP000oh000>QX?0080?n000040>QX
?03oP000oh000>QX?0<0oh0000@0X23`0=1@N02P8?00j6Pl0P2P8?001@2h>;@0oh000?n0003oP000
^3Rd0080X23`0`3oP000102h>;@0X23`0:0Pl03XJ3`20?n000030=1@N02P8?00X23`00`0X23`00<0
D91h003o0000o`002@00o`0;ooooo`002_ooool0E@14[AX0]jbX0<K?e`2FYJ/0Kg9e038K8`3;b=80
H6Ua01L:3`117`d0Y6LW07P9102C0`P0Y`@:0;X83@2o2@`0_`D:0<T;3@362P`0aPP;0<<62`2f0`X0
/`@:0;@42`2k1@`0^`@;0;l630332@`0`PT;0<<:3`2@3aD0Uh^;0>CSi03ThnD0iN?V0>_QhP2oMG@0
aA/L0<HF6P1h41L0Z:6T0>7Og`3Rhn80hnGU0>S?c`2S>3`0_AHI09@C6029O7h0h>;Q0=oQhP3Ph>40
g]kN0>7If`2RCU<0ZP`C0;873`2]10d0[0D<0:D22`2W0`h0[@<=0;H33P2j10`0^0@<0:h12P2[0PT0
Z`880:P1202U0PP0XP470:021P2S0@P0Y0480:h4302b1Pl0Z08:09l11`2F0@H0S@4608@1201l0@H0
NP8407D50P0Qa`800`00o`09ooooo`030830002P8?00X23`00<0X23`00<0^3Rd0:0Pl02P8?005P3o
P0000`2h>;@0oh000?n000060?n000030=1@N03oP000oh0000D0oh0000<0d51h0?n0003oP0008@3o
P0001020`0000?l0003o0000o`08ooooo`<00?l004/0Y<RA09:LZ`2OYK807BM1055FJP1_IVd0OV]a
08I/MP2=JgL0W7F00:9hP02DK7D0XX>50<Vj_03>^l40[Hb=0;B@RP2hV8/0_9j?0;^MS`2YThH0YI>7
0;n/W@36/Z<0bkBW0<^eZ03<]j`0dKnh0<jn]`3=`KP0bL6j0<o7_`3?al00cl[20=;?bP3Ccl/0dLk:
0<g;aP3<b/L0c<c80<c8a03<b<H0^[o=05]YUP2`<d<0c10G0;hL7`3?W9/0^kNi06aiW02@@600^PdG
0:H>5`33VYl0XJ6/06A/R01]=ED0V`DE09`33P219ch0:T1c0:c:j02I/]00D6jN00l_IP1?Ki<0SJ:c
09JV/02?X:P0Jgf=02XmH00244@00@e403A3FP0/Z2<02`00o`08ooooo`<00?l000<0^3Rd0:0Pl02P
8?002P2P8?001@3@D7P0j6Pl0:0Pl02P8?00^3Rd0080d51h0`2P8?000`3@D7P0oh000?n000030?n0
00030>QX?02P8?00oh0000D0oh0000<0d51h0:0Pl02P8?00102P8?00103XJ3`0oh000?n0003XJ3`2
0:0Pl0040=1@N03oP000oh000=1@N080X23`00@0d51h0?n0003oP000j6Pl3P2P8?000`1@T7P00?l0
003o0009003o00_ooooo000:ooooo`1E04Na702hZjD0b]CK092QZ01cM7T0>B<Z0=;Af@1;CEX06@L<
05`k6@1l?AT0O`P;09T32`2[10/0^0D=0;h73@2o1PX0b@X<0<X9303720/0^`H:0;032`2R0@L0U`85
0:`53@2g10d0^`D=0;d7302n20d0`@/@0:h@5`1XB4P0fM[J0>;RhP3Sh^<0i>?Q0=Vd]02f8bD0aA@G
0:8G6`1bFUl0h=kQ0>3PhP3PhN80jMkO0;eoPP2[6B00/AHM06U1A@3Jf]`0h=oQ0=kNg`3Pgn00h=gM
0;V1P`2R51T0/PT?0;053@2]10d0W@870:042@2g1`l0^P@<0;X32`2i10X0]0@;0:X01@2U0@D0YP88
0:@11`2R0@L0X04609P21P2A0@H0[@L>0:/32P2V0@L0W@4709D21P2:0@D0OP4507H2101d0@40M@H2
02770P03003o00Wooooo00<0P<000:0Pl02h>;@00`2P8?000`3XJ3`0X23`0:0Pl00F0?n000030=1@
N03oP000oh0000H0oh0000<0d51h0?n0003oP0001@3oP0000`3@D7P0oh000?n0000Q0?n000040830
0000o`000?l0003o00Sooooo0`00o`00B`2GbG/0UIj[09RL[@0Y=5H03Q]90411G@1lJG80QFUd091_
NP2JLh00WgEo09I`M`2cXJD0/:2Y0<6^]P2[SY00[XZ40;RGR`2dUXT0ZI2308ioN@29OGX0Y9J<0<2Z
V`35[j00ak6S0<Zg[03>_kP0d<>l0<g2^P3;`kX0c/Jn0=3:a03@b/80dLg80=C?cP3@c</0cL_80<k:
aP3>bLH0cLO30<S4`@38alX0Jh6U095SP`3151d0bQ0G0<QGF`39Y:T0]j6c09eXQP2d4b80]0L@0:M<
D034^kl0Uin^04HlHP282a`0W08=08L;601SF7`083ae01XgK@1<J900LHRT069nTP27WJX0NHZD05U/
PP0:74l00P]60049@@013D007S1?03n>>`0;003o00Sooooo0`00o`000`3XJ3`0X23`0:0Pl0090:0P
l0030=1@N02h>;@0d51h0080X23`00<0^3Rd0:0Pl02P8?00102P8?001`3XJ3`0oh000?n0003XJ3`0
oh000>QX?02P8?001P3oP0020=1@N0030>QX?02h>;@0X23`0080X23`00@0^3Rd0?n0003oP000oh00
0P3@D7P01@2h>;@0oh000?n0003XJ3`0d51h0080X23`0`3oP00?0:0Pl0/00?l02oooool000[ooooo
03@0@JL?0:^IT03:d]/0W:^e071`MP1==d00e]OP03Db?@0R20X0NE8T06LK302<1Ph0Y`D=0;@53@2h
1P/0^PH:0;d62P3:2Ph0b`T=0<062P2/0@P0[08;0:T32P2Y1@/0[`H90;H52@2e1@`0^0L>0;T73@2m
2A40]`dF05`G6P2o_Kl0h>;S0>;ShP3Shn80h=GE0;M/I`38HeT0_VUP09b0O03Le]D0hn;Q0>7QhP3U
hN@0gKfn0:8Y<02i4AT0G1DI0;fm_`3Og^00h=oQ0P3Ng]l07`3D][P0TR4W0;<<502f20d0^0H;0;d9
3`2g1P`0_0H<0;d53@2l10X0^0@90;44202W0PH0W`440:411`2R0@L0Y0880:411P2O0@H0W0<:0:X6
3P2^1@h0YP8;09/11P2A0PH0Q`4507/1101b0P@0K@43078<200Sb`L00`00o`09ooooo`030830002P
8?00d51h00<0X23`00<0oh000:0Pl03oP0005P3oP0000`3XJ3`0X23`0?n000060?n000030=1@N03o
P000oh0000D0oh0000<0j6Pl0:0Pl03oP0008@3oP0001020`0000?l0003o0000o`08ooooo`<00?l0
04/0K>5I09^S/P2:SZ80210h0089@00W:U@0MfIc089ZM02?KWT0UFmk09U^N@2MLW/0_:BZ0:N>U@2n
YZ/0YhR80:V5OP2_SH@0[hn20:F;OP1aIF@0L6UX09N9O`2nZ9T0`ZjL0<F`X039]jT0b;ba0<o3_03=
`[X0c<Bi0<o7`03>b<D0c<S30=;?bP3Edlh0d/o:0=3=bP3=b<H0c/[70<c8a@39aL@0b<O60;JmbP1Q
JY@0YC]=0;lH702k7Al0[BT_0:PV<02Z9Rd0[aXO0:PG6@2H>c/0/ZBW09VQ[016DgD0N2M109X33P2A
1A00/82;0;k9e`2kbmT0^/WE0;70cP1`RZD0>EMm05UhU@1GKhP00A5;004=@P0<6d00=4EH01lcB01@
L4l02`00o`08ooooo`<00?l000<0P<000:0Pl02P8?002@2P8?000`3@D7P0X23`0=1@N0090:0Pl080
d51h00<0oh000:0Pl03oP0000P3XJ3`20?n000080=1@N03oP000oh000?n0003XJ3`0d51h0>QX?02h
>;@40:0Pl0030>QX?03oP000oh0000H0oh000`2P8?00103@D7P0oh000?n0003oP00>0:0Pl0/00?l0
2oooool000[ooooo05D0@ZL?0<^h[@38dMT0S9^S06m_M@1MBU<0dmOO02<R:P0Q1`D0TfPc068;102@
0PX0[0D=0;H62`2l1`X0_@P90<072`392100b0T>0;X52P2]0PX0Z`490:l42`2`10T0]0H90;H62@2c
10`0/`<<0;P73@2i2@l0]`TB07P=4`1hHfX0fMOI0>7QhP3OhN00h^3P0>SNf@3^g]T0j]oI0>OOg@3S
h=h0h>3N0=kPg`3Pg^00iLO;0:L`=`2m3aD0JPX>08R2Q03Kf]`0hMoT0>3Oi03NgN40g<[>09i4C02a
3QH0`P/?0<<93`302@h0^PD=0;P53@2i0`d0_0@=0;H32`2b10`0Z`490:411@2S0@L0Y@470:P11`2V
0@L0Y0070:D12P2/10/0[P@<0:H1302L0@P0S@4807l21P1h0@@0L04406P00`1X2@L09jT600<00?l0
2Oooool00`20`000oh000:0Pl0030:0Pl0030=1@N02P8?00oh0001L0oh0000<0X23`0?n0003oP000
3P3oP0000`2P8?00oh000?n0000P0?n0000408300000o`000?l0003o00Sooooo0`00o`00C01Ig400
VifZ05ILMP021Rh00@Di020TD01iJ7H0QFYe08i^N02DKGD0VW1e09edNP2SPhL0_:>X0:B4R02WQ7h0
YX9j0:V4N`2_SH00/9>20:VBQ@2RSH40/YZ=0;jVUP31Zi/0a[6R0<NfYP39_K40c<6i0<k5_@3;a;/0
cLO00<_7`@3?b/H0e]?>0=OEdP3HeM<0eM3?0<k<b`3<b/X0blW80<S5a037aL80a/?50;Be`P2[WZP0
aYZF0<JHT02oVI40_iZD0<2OVP2nWY/0]iVF0;RYZ02UZJd0XZnl06MkU@1E=UP0TPHH09T23`2E=D40
clgE0<3=f@2hb]H0QY^]04AMQP036F8021mK06EoU@087DT0;T1I05ESIP1FHV40:CU606=ZJ@04lP8:
003o00Sooooo0`00o`000`1XZ3`0X23`0:0Pl00:0:0Pl0030=1@N02P8?00X23`00P0X23`00H0^3Rd
0>QX?03XJ3`0^3Rd0=1@N03XJ3`20=1@N0030;Ph]03oP000oh0000<0oh0000<0^3Rd0:0Pl02P8?00
1@2P8?070=1@N0050;Ph]02P8?00X23`0:0Pl02h>;@00P3oP0000`3XJ3`0d51h0:0Pl00<0:0Pl003
02S8?000o`000?l000P00?l02oooool000[ooooo05D0AjTB0;>MU@36dMP0WJfe05eLHP1bHFX0b/kH
01LD7@0P1`@0Tf@_07D:1`2I1@h0[0D=0;P6302o20`0`0T;0<4930311P`0`@T@0;<32@2^0`/0[P8:
0:`21`2^0`P0/P@:0;852`2b10d0]@D>0;L6302g1`l0]`TA0:D@5`1U4Q`0ZhN@0>3Cf03PeMP0h=;H
0=g<d@3Ga<T0e[o60=Zl``3D/k/0cZfc0<nZ/P3<W:L0_fYe0:/G802m2a40R@`B04Xf>03Gf=X0h^;V
0=oOh`3Ogn40h]SK0<>5RP2_5Q/0b@hA0<D93`2o2@l0Z0<90:X32`2a0``0/P8<0;422`2]0P/0Z048
0:<21P2U0PL0YP470:X2202b1@/0Y`460:L21`2/10/0ZP<;0:H12@2M0@L0RP8707H11P1f0@P0KP45
06H10P1T1PH0;hP700<00?l02Oooool00`20`000X23`0;Ph]0030:0Pl0030=1@N02P8?00oh0001P0
oh0000<0d51h0?n0003oP0003@3oP0000`2P8?00j6Pl0?n0000P0?n0000408300000o`000?l0003o
00Sooooo0`00o`00C00aj240X9nW02ldDP021Rh03a8m02DYCP1kIWH0QfUg08aXM@2CK7L0WG=l09ic
O@2QMG`0YWYl0:=hN@2TNGP0X7Ma0:N2M02bThD0/iR80;RNS`2iXHl0_JBD0;nVU`32ZYP0aJnP0<Re
Z037_;00b/2g0<g5_@3=akl0blK00<[6`@3Bcl/0eM7>0=GCd03GeM@0dm3A0<_:b`3:b/P0blW50<S7
`P36a/80`/;10<C1`@2n_K`0_;Vh0;Vf]02d/:l0/Jb[0:nYZ02/YJ@0/Zj^0:>PY@2^[k@0YjVb0:Zh
b`12@f`0QQD]09/240292AD0a:Vc0<3=eP2ibM@0Oi>V06n3W`076U@00aM@061fQ`1PLGP0GFi/05aZ
I01HIFL083A006ikN`0Dd0l:003o00Sooooo0`00o`000`1@T7P0X23`0:0Pl00>0:0Pl0030=1@N02P
8?00X23`00<0X23`00@0^3Rd0?n0003XJ3`0j6Pl0P2P8?00103XJ3`0d51h0;Ph]02P8?050?n001@0
X23`0`3oP0000`3XJ3`0X23`0:0Pl00;0:0Pl003052@N000o`000?l000P00?l02oooool000[ooooo
0480A:D=0:22N03;dMP0SZ2T05QKG@2=PHT0];S3018:4@0k7@X0QU<Y07<51`2N10h0[0D;0;H4302m
1`d0`@P=0<072P2j1PX0/`D:0:X1202Z0PT0ZP<90:T3202[10X0[`<:0;<53@2d10d0]0D>0;H73`2f
1`h0]`X?0;X>502f3aL0ZQLQ0;@kA`2`>dP0[cA10:d[>02X8Bh0[R<a0:dN:P2b6bP0/QPT0;0H8P2b
5B40]a8H0;hA50364AD0/1DH03T41`2o_l<0h^?V0>;Si`3Qh^D0h=oO0=fn_`2_<S@0`@d@0<093@2i
10/0/08;0:T2202X0@H0Z@480:L11`2U0@L20:<11`0A0:L22@2V0@P0Z@890;@63@2^0PP0[P@:0:d4
2`2X0`T0Y`8809h11P2>0@P0P`4707d21P1_0@@0J04306440`0aQ`H00`00o`09ooooo`030830002P
8?00^3Rd00<0X23`00<0d51h0;Ph]03oP000:@3oP0000`3@D7P0oh000?n0000O0?n0000408300000
o`000?l0003o00Sooooo0`00o`00C00ZgQ<0Zj>T01HL?00G6C@0DdUM03PdC@1kJGL0PFEd08=MKP2>
IG80VVmj09e`N`2OKgT0Y7=j09iaL`2QM7@0Y7Uf0:^6N`2_Sh00/iJ60;FHR02iWhd0_::C0<2UUP31
ZiX0`jfQ0<JdZ037_[80bKne0<_2^`3=aKl0bL6m0<g9a`3Cdm40clo>0=?Ad@3Ad=40dm;C0<g:bP3:
b<T0b<O60<;2_`2i_l<0Y;2k0<JW/037Ti`0`X>=0<9dP@2jJ7<0]UeY0;1DH@2`CU`0Zd]D0:Q9EP2g
GFh0[UQ/08`mF01o=e40UAd_09X2402?0Q00XUQX0<Bjc032a=80Wj^f09JW]01jS9d0D6=g07:0Q`1_
Ng`0IFi_05YXJP0[?5004RHn05EXJ`0[Yb@:003o00Sooooo0`00o`000`20`000d51h0:0Pl00D0:0P
l0040>QX?02h>;@0^3Rd0;Ph]080X23`0P3@D7P20;Ph]0D0oh0000<0^3Rd0:0Pl02P8?000`2P8?00
0`2h>;@0d51h0>QX?0060?n000030>QX?03oP000j6Pl0080d51h103oP00=0:0Pl003052@N000o`00
0?l000P00?l02oooool000[ooooo02<0AZ@;08QREP3;cM@0Wk2e055>D@2WVZ40WZ>]01L8301XABD0
M3PL08843@2P0Pd0[@@;0;D53@2n1`h0`0T<0;h6202j20X0[P470:/22@2V0@D0Y`880:011P2S0@H0
/0<;0;D43@2c10d0/P<=0;@43P2h1a40]@P?0;H:4@2m3AH0^`hD0;D>5@020;LB5`0`0;/D5`2k4QP0
_1<I0;XB602m51P0_1DG0;TG6P2g5QP0^1DE0;/E5@365aT0_1XJ05h<3P2GSi80h^CV0>GXjP3Ti>L0
hMoR0>OIf`2dDeH0_Pl@0;`93@2d10/0[`8;0:/22@2V0@<0Z0460:H01P2T0PH0X0060:811P2W0PP0
Y0070:P22@2a1@d0/0@;0:l32`2^0`/0Z0480:L22@2N0@P0T@4608L11P1k0@<0KP8206H10P1Q0P40
;X810`00o`09ooooo`030830003oP000d51h00<0X23`0P3@D7PZ0?n000030=1@N03oP000oh0001l0
oh0000@0P<00003o0000o`000?l02?ooool3003o001<02[K302[VYD02A4]04a9E`1JCeT0B41C07QS
K`1lGV`0OeUY099WL`2GKGX0SFYm09QaOP2MKG@0W6a^09meL@2VO7H0Z85g0:R7M`2`TX40/iN80;FN
T02iXI<0_ZNH0;nZW@32[j80`[>T0<>j[`37_k@0b/6h0<k5_P36`[`0c<W70<g=b@3@d<h0d=3A0=7@
d@3>c/d0b/_:0<W8aP36aL@0`lC30;Jnb01=IY<0XT]P0;PN9P2f7200]AdS0;8O9P2^8R<0ZRLW0:LX
:02S:2H0Y2TW0:DX:`2Q9RT0ValW09DI8`2B51d0T@`E09084`2;2Q/0PQ@Z088T>P28HVd0OHVC08BE
V01hQXT0Lgan079nO@1UL7D09cME004:>0012C<0<D=C02jN;0X00?l02?ooool3003o00030830003@
D7P0X23`0100X23`00<0^3Rd0:0Pl02P8?00202P8?001@3XJ3`0X23`0:0Pl02h>;@0j6Pl0080oh00
00<0^3Rd0:0Pl02P8?00102P8?000`3@D7P0oh000?n0000@0?n000030>QX?02h>;@0X23`00T0X23`
00<0N5Rd003o0000o`002000o`0;ooooo`002_ooool0E@19YP`0V71V0<_>eP2<Vj80F55I0;jc_027
RiH07`X<09ee@@1V7`h0T@H>0:L43@2/10/0]`L?0;`63P2o1``0^PD;0:l22@2V0@H0ZP890:T2202Z
0`T0Z@480:X22@2`10/0/@@90;<5302d1@h0]@D?0;L8402a30l0[18@0:hH4`2]6aH0[b@N0:`[8@2[
<BT0]D<l0;M:@`2lDd`0_EeE0<5VG@34KVD0_FeT0<1`J@35MG00bWUc0<igLP3AO7L0YgE`0:fTX03P
hN00hnCT0>3Qh`3Qh>@0hmgP0;EiN@2Z7AT0[18A0:P:3@2W1@/0Y`880:H11P2X0@P0YP470:@1202T
0@T0Y@480:D11`2U0@X0Z0890;862`2c10/0/@<;0:/22P2[0P/0Z@8=0:412`2=0@L0OP8407d11@1a
0@<0HP0105h20P0kT@l00`00o`09ooooo`030830003@D7P0X23`00<0X23`0P3@D7PZ0?n000030;Ph
]03oP000oh0001l0oh0000@0P<00003o0000o`000?l02?ooool4003o001;0:F9O00<42`0HeUV05M:
E@1;B5T0Kem/07UIIP25GV`0T6Ed075HM@0G6U40DDM/09MZLP2KJf`0XgEd0:IgM@2UO7@0[8Uj0;:A
PP2[THH0V8Yo0;:PT`2jY9P0^jNL0<6]X@31[jD0`[R_0<Jl/`38_kL0c<Bm0<g8``3=blH0c/g90<g<
b`3=bld0c/k=0<W;b@3;c</0alK50<G4a@32`<80_l34086?ZP2/VZL0aY>A0<RMU`38Y:40`:FR0;fW
XP2gYj40]JBQ0;JVX`2UVYD0/ZNV0:fSY02m]KX0Z:B]0;R]/P2iXZL0[hnD0:AlP@2CHVH0P4A>07=>
E@2NYjd0NHN>07J2Q@1YMWH0IgEf04IEJ00234000PPj0049=00C93l0=fXk00X00?l02?ooool4003o
00030=1@N02P8?00X23`00h0X23`0P3@D7P:0:0Pl080^3Rd00D0d51h0>QX?02P8?00X23`0=1@N007
0:0Pl0030;Ph]03@D7P0d51h00<0d51h00<0^3Rd0:0Pl02P8?000`2P8?00102h>;@0X23`0:0Pl02P
8?040=1@N0030;Ph]02P8?00X23`00T0X23`2P00o`0;ooooo`002_ooool0@@1;YP`0QUQ=0<O9d@2?
WJ@0CTM?0=7:d`1WKWH0;aL=0:EgAP1E2080S0@;09h53@2G0PP0WP<80;H73@2k2100[08:0:X32`2V
0@L0Z`890:T22@2]0PP0[`870:l3302R0PP0W`460;063P2e1Ph0/`D>0:L;4028=c80cIR;0=R]X`3L
^jh0i<No0>O@b@3Ve/l0j=cG0>SLfP3WfmX0jN3M0>GQg@3RhMh0hn3P0>?Qh03RhN40i>7S0>?QhP3T
h^80hN?Q0>OWi`3ShnD0hnCT0>7Qh`3Ph>@0hN7T0=cCdP3H^kP0cJFQ0<2@RP2[FeT0VPD:0:H1202X
0@P0YP470080Y@490180YP4:0:H2202T0PX0Y08:0:h42`2d1@d0/@@;0:l4302]10d0Z08<0:822P2<
0PP0MP4207X21@1c0@@0IP4205d20@0nUQ@3003o00Wooooo00<0P<000?n0002h>;@00P2P8?000`3@
D7P0X23`0?n0000F0?n000030>QX?03oP000oh0003<0oh0000@0P<00003o0000o`000?l02?ooool4
003o000O09FJJ00N8CH0HeMQ04Y0C`0C7400>cUD07EKI`25HW00Q65g03<YDP19@g00<2]F099WL@2K
Jfd0XG5a0:QiMP2XOgT0ZXIi0;>APP2PQg`0SGme09F7O02dXIH0^:FH0;j]WP2n/ZH0`;N_0<Fk]@37
_[T0al:o0<c8a0020<g9a`0Z0<k:a`3=cL/0c<c=0<W:bP3;blX0a/G50<K4aP30`<00`L710;no_`2l
_[h0_;bk0;Vj]P2f][P0/[:e0:f^[`2ZZJ`0YjJY0::SY02[/;40]ko30;2ja01mTjd0O9F]0<GEh@36
dml0am;N0<GAfP36cmP0PhnP07j=V@2GXj/0V:>Z07Z5R`1VMG<0HG=c01`[C`022d<01A<k028bB@0A
8CP0@dY=2P00o`08ooooo`@00?l000<0d51h0:0Pl02P8?003P2P8?020;Ph]0`0X23`0P2h>;@00`3X
J3`0^3Rd0:0Pl00@0:0Pl0030;Ph]02P8?00^3Rd01@0X23`2P00o`0;ooooo`002_ooool0>01=Z0h0
N4Lm0<6ob02GYZ`0EUAI0=OCg01>E5`0Ab/K07M69`1F1P<0S`D>09P22`2@0@T0U@470;45302e1Pd0
Y0080:H1202Z0PP0[0890:P1202^0`T0/04;0:l32P2]10/0Z`8:0;@53`2d1Pd0]@H=0:/=501N=3D0
g=GE0>;Oh03Pgmd0h=gN0>3Nh03Qgn40h]oS0>CMh`3Qf^00h][P0=_Gg03Ie=X0gMGL0=kHg03Le]X0
fm?I0=cEf`3Mem`0gMWN0=kIg`3Pg>00h]kR0>GOiP3Sh>@0hN3U0P3Ng^806`3KfMh0fMCH0<BUY`2=
2Q00YP490:L22@2U0@H0Y0480:812P2T0@X0Y00909l12`2K0@X0Z@8;0;053P2]0PX0/@D?0:d53P2W
0PT0X04708`11`220@H0O04507410`1S0@40F`4204mC3@03003o00Wooooo00<0P<000?n0003@D7P0
0P2P8?000`3oP000X23`0?n0000F0?n000030=1@N03oP000oh0001/0oh0000<0d51h0?n0003oP000
5P3oP003003o00Sooooo1000o`00<@1i[T`0=S4m06UOHP0j<D<00PPg02d[C`1gGV`0P61`069>JP1B
AFH0E4EZ03T_FP2CI6d0W6Q[09m`K@2TNG@0Y7af0:Z6O02`TH00X8Yi0:FBQ02VU8L0[Yb@0;VWV`2j
[Ih0^[:W0;ng[P34^[D0aKjh0<S3`03<b<D0cLS70<_8aP3;b<P0c<_<0<_9c03;b/`0bLS:0<O5aP33
`L80`L700;g0_@33a/D0_;o00;Zl_02g]kT0/;>e0;2b]02^/K800P2Z[:l06@2PY:D0X:JX09RPX`2Z
]Kd0Y;G409FabP33eMl0a=?O0<KDh034d]h0_lkJ096V]P20Tj00Pi6K07R6R`1aO800IgAc061bM@08
5D<02Q]504=IH01BHV009cI503U9D006i0@02@00o`08ooooo`@00?l000<0j6Pl0:0Pl02P8?002`2P
8?000`2h>;@0X23`0:0Pl00=0:0Pl0050;Ph]02P8?00^3Rd0:0Pl02h>;@04`2P8?000`2h>;@0X23`
0:0Pl00B0:0Pl003052@N000o`000?l000L00?l02oooool000[ooooo01@0BZD<05`Z8@2`[K@0UZ>Z
059>E03Gen00;S8l05Xl9P185`L0EP<308h3302J0@T0V@490:T53P2d2140/0H;0:T32@2[0PX0Z`48
0:h22P80Z`8903l0[0870:h42P2a10/0]0D<0;<5302d1Pl0]@H=0;H;501W5AX0g<G:0>?>e03D^<00
c:F]0<6EWP2iQi00/gJ10;9^N02`J7@0/V5a0:mIJ@2aEfL0_5]Z0<INK@32EV@0b5]Y0<QKJ`34FV/0
a5m_0<5QL031JWL0b7R50<QmR`3<R9H0cYFR0<ZLZ@3<Z[D0b[6k0<^f_`31Y:X0T1PN0:H22P2X0P/0
YP480:D1202T0PX0X`4;0:<13@2S0P`0W08:0:<12@2[10/0/@D>0;873@2[10/0Y`<:09l22@2=0@L0
PP4607/11P1a0@@0I04205X10@1?E0`00`00o`09ooooo`030830003oP000X23`0080X23`00<0oh00
0:0Pl03oP0005P3oP0020>QX?0@0oh0000D0j6Pl0=1@N03@D7P0d51h0?n000020=1@N0l0oh000P3@
D7P00`2h>;@0oh000?n0000F0?n000<00?l02?ooool4003o001<05_5=01RFV80J5mU02`W>`021cL0
9bI>07ILK022Hg@0@CEE07QTP@0a:UT0BSYP09ASK02KJF/0Wfm_0:9fLP2UNWD0ZXAi0;2AP`2LQgP0
ZIR=0::@Q@2bWY00^JRK0;Z/W`2k/jT0`[Zc0<>h]P32^[H0b<>l0<g9a03<b<H0b/K70<_7aP38alT0
b<S;0<g8c@39aLX0a<C60;bo_`2o`L80^[jm0;Rl_`2k_/40^;Vk0;Bd^@2^/K@0[[:d0:ff]`2X[[00
XZJY09nSY@2a^KP0b=7F09VU]021V:`0B6N50<CFhP34d]h0`m7P0<GBg@2^_</0?EE]09JX]02LZk80
MHN:07Z9RP1ULfh0Gg5f00@B?`0`@e`0FF]X05IUH`0X>4X08cU<00K62@T00?l02?ooool4003o0003
0830002P8?00X23`01/0X23`00<0d51h0:0Pl02P8?00:P2P8?000`1@T7P00?l0003o0007003o00_o
oooo000:ooooo`1004^V3P1=6A40WIRM07j8S01PG680b<_B01<B5`1N?RP0?0@107442P2I0``0X`8=
0:X33@2U10h0SP8709d52`2W0PT0[@8:0;822P2c0`T0/P890;@32P2b0PP0/0880;852P2b10`0/`8=
0;@53`2e1Pd0]PLA0:d<5@2h;SP0]2Hc0;8J:02c5240/@lL0;0>6@2b3QH0/`hH0;@B6P2e4AP0^@lI
0;h>5`3;4QX0da8J0=LC5`3H4aP0e14I0=@A603B41P0ca0H0<P=5P3431L0aPhK0<TA6`303a/0^PhL
0;DC8P2W5RD0XQl]0:<Y=P2Q41/0Y`8:0:H12080Y04701<0XP470:<22P2S0@X0Y0490:@12P2Q0@L0
Y0460:d3302c1Pl0ZP<;0:@22P2K0@P0SP460801101i0@<0L08306810@1I0@00D5@<00<00?l02Ooo
ool00`20`000oh000:0Pl0020:0Pl0030=1@N02h>;@0oh0004d0oh000`00o`08ooooo`@00?l004`0
:M`E06iQJ01VGfX08Ahg00@;>@0/;4h0LEYV085TM@0g;dl0OV^9014CBP1[DVh0TEmV09][K02NK700
XW1`0:AgL@2ZPgP0[Xj10:jDQ@2KQg`0Yi>70;RST`2iYYT0^j^Q0;V_Y@32^[80`kRc0<Bj]@38`Kd0
bLC40<W5``3:b<L0alG30<O6b@39al`0a/G80<G4a`32`/@0_<2m0;Zo^`2j_K`0^[^o0;Ri_02e][X0
/kJj0;6d^02YZjl0SI:C0:B[[02QZ:/0Y:fd09BMY02V[KH0WZBb0;:oc@2^_<P0amKN0<KCh032d]h0
`m?M0:nnc02R]/@0UjNb082>U`1jRHd0Kgal06QgL`1TMGP02APn04eSK01IK6/0Cf1X010M?`055CT0
1JL@2@00o`08ooooo`@00?l000<0P<000:0Pl02P8?00302P8?000`3@D7P0j6Pl0:0Pl00<0:0Pl080
^3Rd5`2P8?000`2h>;@0X23`0:0Pl00A0:0Pl003052@N000o`000?l000L00?l02oooool000[ooooo
01D0C:L=04`D302CRHh0GfUZ05aIG`2QXZ/04`L906Dj9P1?1@L0O0<:09/2302T0@`0Z@<>09@32@20
00H0T0<;09h12P2Y0PL0/P890;D22P2g0`X00P2g0`T0:02d0`T0/P@<0;<32P2e10`0^@D?0;X63`2k
1a00^`P?0;X84@2j1Q40_0TB0;d;4P2l2a@0_`/D0;l=5P303AH0^``D0;T<4@384A@0cQ4C0=@B603F
41@0gAHG0=dE5`3G3aD0ePhB0=8<4@3<2A40c0XD0<T84P3;2140b0H?0<P84@342100`@P>0;L53@2`
10`0Z@8:0:P22P2X0@T20:D1200D0:@1202Q0@P0XP890:012@2S0@/0X`490:011`2R00L0Z08:0;87
3`2Y0P/0XP4909X11P2<0@L0P04607H10P1`0P<0I@8305`20@1CE0h3003o00Wooooo00<0P<000?n0
002P8?000`2P8?000`3@D7P0oh000?n0001<0?n000<00?l02?ooool4003o001<027V3P1gHf40If9_
014B;00`=U<0@cmF079MJ01fHW<0=c5C04U3J`0H6Dh0QEmd099PIP2JJ6/0VfIZ09iXJ@2QLFd0ZhAl
0;:@Q@2eUHP0]I^=0;JOT@2fX900^jJH0;ZYWP2i[JD0`;F_0<2f/033^k@0a[nl0<W5a@38a/@0alG2
0<K3`P35a<H0bLO90<C3a@32`/D0`;o40;g0`P2l_l00^Kbm0;Rj^@2c]kd0UJ>d09:?Y02`PY@0ZVEe
0:E]M`2hUj00Zj>X06UhT01SHX@0UeQa0:MCJP2UDVL0WF1d0<k=f034e>00`m?O0<?CgP1hTJP0NI6S
08fNZ@2EXjX0T9jS06mlOP1XMWH0JWMj01d^B01?J780?eAV00lK@`0123L00P/e011b7`T00?l02?oo
ool4003o00030830002h>;@0X23`00/0X23`00<0^3Rd0?n0003oP0007@2P8?00102h>;@0d51h0=1@
N03@D7P30:0Pl0050=1@N03XJ3`0d51h0=1@N02h>;@04@2P8?000`1hF;@00?l0003o0007003o00_o
oooo000:ooooo`1E03Bi1`1640D0QW]n06I^L01KEU`0Hf=Y01L9201K;1l0C@0407X22@2I0`/0Y@<>
0:L23@290@H0P@4908X12@2X4a`0X`490:h12P2c0``0]P890;H42@2^0`X0X@870;<42`2f0`T0]08:
0;`63P2m1@d0`PT?0<@:402n1Ph0`@XB0;h<4P2i2a80/P@=0;`;5@2n2a<0_`/F0;h:5@333A80ba0D
0=8@5`3C41H0fA8E0=TB503H4A@0f10F0=PA503D3@l0d`dB0<d94P3<2A80dP`C0<T83`311Ph0_0D=
0;`63@2c0``0[0<;0:T22P2X0@T0Y`480:D01`2U0@L0X`490:012@2O0PT0X0880:D12P2T0@P0X@48
0:002@2S0@X0[P@@0:P22`2P00P0V@0808/120200@P0L`4306l20`1W0@80G@4104e<1`03003o00Wo
oooo00<0P<000?n0002P8?000`2P8?000`3@D7P0oh000?n0001<0?n000<00?l02?ooool5003o001;
089VE`1TH6l03PhW04a4E`1ICUl0KUQS06ACJ@0i>6004AM@04@iI01iEVH0O5QR09QVK02MIVX0W6QY
0:AcLP2[Pgd0/Hn40;BFQ`2dVHX0]in?0;NQT`2iYYP0]ZNL0;^_YP2n]:d0`[Vd0<>k]`36_k/0b<C0
0<[6aP35a<<0`l700<;2`P35aL@0`L720<?2a@2m_l40_;jm0;k0_`2j^[h0/kNl072;ZP1bHh`0XbM2
0;@=7@2j2QL0]`XI0:hC902a>d`0XVR204hmJ@24;dP0W@HG0:H44@2H21P0`YVU0<OCh035dn80a=;Q
09f_`@2AYK@0SInY08BAV@1kQh`0LGb006YiN@1WN7H0@e5S018SC@0234400@Lm0047=@095cT0:Vle
00T00?l02?ooool5003o00030=1@N02P8?00X23`00X0X23`0P3oP0000`2h>;@0X23`0:0Pl00J0:0P
l0030>QX?03oP000oh0000<0oh0000<0^3Rd0:0Pl03oP000103oP00B0:0Pl0T00?l02oooool000[o
oooo0300:<4404hD3022Lg@0Ee]K061LGP0e=CT091LB04HH4@1D0PT0OP@=08l22@2P0`d0YP@=08T1
1P1o0PT0M`4508h73`2I0PP0Z`<;0:d22P2^0PX0]0@:0:l42`2P0PH0]@D;0;T42@2i1@/0^0@;0<<;
403;3180c@dD0<H:40343A80_PX@0;X9402j2Q40_0TD0<0:4`332aH0aPhG0<X@503<41@0c0hD0=8@
5`3G4aD0fQ@E0=TD5P3H4A@20=T@4`0S0=H>4P3?2Q80c@XB0<`94P382100_0@<0;X3302h0`/0/@<<
0:X22@2X0P/0Y`480:L11P2V0@L0Y0480:411`2R0@L0X@4909/21`2P0PP0X@4809d12@2L0@P0WP49
0:T3302Y0`d0XP8;09P12P2;0@T0P@4607020`1/0@80J`4206420@19A`<00`00o`09ooooo`030830
003oP000X23`00<0X23`00<0d51h0?n0003oP000C03oP003003o00Sooooo1@00o`00B`1cXU`0Gemb
01dJ<P18?Th0DTmU071LK01JBFD05B5G00P@C01XE700L5AO05i8D`29I6T0W6Q[09eYJP2UM7D0Zh:0
0:j=P@2cUH@0/YR40;FLS@2gXI80^JNH0;VXW@2m/:X0_kBa0<>h]P33^[H0a;fi0<K2_`31_l00a<?3
0<;1`P30`L40`/C40<72`P31`/<0_ko10;fn_`2j^kd0^kbo0:Zf`P0iFHd0XCaJ0;h95P311a40_`H@
0;/84@2_5al0Wb0]09<D9P2A83X0[d=G09`:602V0@d0XP<>0:55DP3@dM`0a]?Q0;;2e@1NN980X;C2
09R[]P28UYl0Mh>906mnP@1ZNWT0IgQg04=CIP012D400@Q2004<?00>7c`0A5YS03]3@@09003o00So
oooo1@00o`0=0:0Pl0030;Ph]03oP000X23`01/0X23`00<0d51h0?n0003oP0002`3oP0000`2h>;@0
X23`0:0Pl00?0:0Pl0T00?l02oooool000[ooooo05D07L/104D:0`1dHF80Fe]L06aYJP0=3@l0<B8I
02h3101O0PX0Q`8>09@22`2M0PX0W08:08h120270PP0L@@9080I7@2G10X0[08;0:P31P2W0PH0/@D:
0;D32@2g10/0_@D<0<073@2o1`h0`@P>0<d=4P3C41<0eA0E0<X=4`2o2A00`0hC0;h>4@2j4140^A4B
0<@B5@374AD0b14E0<XB5@304aP0^R0M0;dW9@2o:BP0a2dY0</a;@37:RL0cbHV0=DE6P3G3Q<0e0/C
0<h94P3:1a40a`LA0;d3302m10`0]P8<0;03302]0`/0Z0490:H22@2T0@P0Y@480:81202Q0@L0X@49
09l12P2E0PH0U`4509h2202O0@T0W@4709d1202Q0P/0YP@>09/22@270@L0QP8907l21P1g0@<0L043
06h10P1V0P80H0T200<00?l02Oooool00`20`000oh000:0Pl0030:0Pl0030>QX?03oP000oh0004`0
oh000`00o`08ooooo`D00?l004`0NZ=I04A3FP0/:Sh0=c=:00PAA017@V40BCiN0089AP0_;5/0L5Y^
07AJI`1JB5@0NUYO09MSJ02PKFl0Y7Ae0:R0O02]RX40/9B60;>HQP2eW8/0]Z6B0;RUV@2iZIl0`;6]
0;fd/P30^;H0`;Vf0<:k^036`Kl0`/6o0<2o_`30`;l0_l300;k3`@2n`/<0_l?50;k2``2g_;l0]K^n
0;Rm_`2S/L40@5ZB0:D]AP311aD0_`H@0;`4402^5ad0]XV;08F0R`1^HWX0LciG08PV>`2F2aT0W`<>
09`2302@31X0cK?00<KCh02N/<@0Rj>b07fBW@28Uil0RiRN07R3R01ZNW/0K7]m06MfN01DHg400@/o
00@A@@0[?eL0C61T055VI@10CD/02>H52000o`08ooooo`D00?l000<0^3Rd0:0Pl02P8?00:02P8?00
0`3XJ3`0oh000?n000020?n000030=1@N02P8?00X23`0080d51h103oP0000`3@D7P0X23`0:0Pl00?
0:0Pl00302S8?000o`000?l000H00?l02oooool000[ooooo05D07LX004X;101lIfP0BdU706EPH`02
0@80<24J02L10P1M0PP0Q`<>09H22`2L0@`0U@4;09812`2C0P`0U@lJ0:d/=P2S0`X0[08:0;842@2a
0`P0/P<90;L42@2j0`/0_@H<0;h53@311Pd0c0XA0=8>4`3>3100c`dA0<TA4`2h41D0/QhL0:/d;@2Z
@CP0[dDm0:ld;`2a8b00`1dK0<PE5`201`X0[7Md0>>i]03]aL40klO20??9a03ca/80mZn`0;TZ;@3:
3A80ePdD0=09403@2a00c@/A0;l42`2l1@/0/`8<0:d32P2X0P/0Y`4;0:D12P2T00T0Y@080:811P2R
0PT0X@0;09h12`2L0@T0V00709/12@2N0@X0W@4:09`1302I0@X0U`<=09D33P1o0PL0N04606l00`1e
0PD0L04406l11@1U0P<0GPP200<00?l02Oooool00`20`000oh000:0Pl0030:0Pl0030=1@N03oP000
oh0004`0oh000`00o`08ooooo`D00?l004`0I/9803XeB011>4X081dm00<:A@0j>5`0=c9G00D=AP1R
Dg80JeQW059;F@1<?T/0PEIN09MRI`2QKVl0Y7Ef0:QnO@2]RH40/I>70;:GQ`2eW8/0/in@0;FRU`2n
/:D0_[2Z0;nd/P30]k<0_[Rd0;ni]`33_kh0`l6o0<2o_@2m`;l0_;k20;Zo`02m`L@0_L730;k2``2k
_/00][^n0;Bh_02^^/H0<UB<09e7IP2n21H0`0D?0;/43`2]6b@0]YbL0:R`/02OYjl0MHFI05mWQ`1W
@f@0SP`M09d33@2I0a00ZF=a0<gDg`1dRZD0QIna09RZ]02BWZP0OXR?07=oP`1cOh40JgUj06MiM`1S
LgP072i804QLJ01NLW80Ef][03]CG@0^@T`06kTF2000o`08ooooo`D00?l000<0Z8Pl0:0Pl02P8?00
:02P8?000`3@D7P0oh000?n000020?n000030=1@N02P8?00X23`0080X23`00H0^3Rd0?n0003oP000
oh000>QX?02h>;@@0:0Pl003052@N000o`000?l000H00?l02oooool000[ooooo00h07//004/:0@1a
Fe`0Cde;05]HFP040@80;A/G02h10P1N0@D0P04909@22`2G0Pd0T04:09022`80T@4;03P0W0@=0:D2
1`2Z0PP0[P@:0:`21`2e10/0]0880;P32`2m10/0`@H=0<873@392@l0d@h?0=@>403;51H0W1dK0:5D
D@37VI80ilg90>[HdP3Wd/h0iL[70=fd/03?ShT0`Dm;07PJ6`1:@4D0dmCE0>WViP3Vi>D0iN?T0>OT
i@3_fmd0_UmS0<PE6`3E3A40d0X@0<h;4@351Pd0_0@:0;T5302b0``0Z`<:0:T22`2X0PT0Y`890:81
2@2Q0@P0X0480:42202O0@/0X@4<09`1202I0@L0VP0709`11`80W@4800/0W@8:09H33P250PT0O085
08832P1d0PH0LP4506l1101/0@@0IP8306D=1P03003o00Wooooo00<0P<000?n0002P8?000`2P8?00
0`3@D7P0oh000?n0000Q0?n000030:0Pl03@D7P0oh0002P0oh000`00o`08ooooo`D00?l004`0HLdm
03``>P1@AUL0410b008:@@0g>V003Q0n024SC`1oHWD0Oei/05a5E01dCe/0Re=L09aUJ`2QKG80Y7Ag
0:ImOP2]R800/I:30;2EQ@2cVHX0]InA0;j/X`2o/:P0_k:/0;je/P2l/Zl0_kNa0;ji]`30_[`0_kjm
0;fm_02l_;`0]kZk0;Vn_P2l`L<0^[o10;^o`@2e^;d0^;Zm0;Ni_02c^[h0G7ZU07IQR`2`3ah0`0D?
0;/23`2[2A@0]H:409VPX02c^l40Y:jj0<3AiP0jC7/0OCAB09833P2M0`h0SQTZ0=;4dP22U:L0NXfL
09>OZ@2<Uj00OXZ?07R2Q@1bOh00KGeo06MiN01UMW<0Ffm]05a_L01GKWD0;D=O00<B?@0J;D<0:iXX
2000o`08ooooo`D00?l000<0P<000:0Pl02P8?00:02P8?000`2h>;@0oh000?n000020?n000030=1@
N02P8?00^3Rd00<0X23`00D0d51h0?n0003oP000oh000=1@N00@0:0Pl00307QH]000o`000?l000H0
0?l02oooool000[ooooo05D07l`004`:0@1eGUl0?CXj05MDE@0;10<0:AHB03`2101T0PH0M`4408h2
2@2?0PX0S04808l12`2B0@d0U@8<09T22`2P0@L0Z@<:0:P22@2W0PP0]@D;0;H32`2h0``0_`D=0<@7
3P311`d0a@/=0<`<3P3;41<0Oa4C0<:ZZ03[j>D0iNKT0>CTi@3Vi>L0iNCU0>CSi03QhN40i>;Q0>WN
g02nZZP0@D940;c0``3VinT0i>?U0>_Zk03YjN/0k>OY0=f//032:2l0fa4G0=4;4@381@h0_P@;0;/3
302k1@h0]0<;0:l22`2/0P/0Z08:0:L12@2S0@P0XP480:412@2P0@X0XP8:0:412`2I0@L0V04609T1
1P2L0@P0W04909`1202H0@L0T`8<08811P280`T0P@460803201b0@D0J04506X21@1S0@<0I0h800<0
0?l02Oooool00`20`000oh000:0Pl0020:0Pl080d51h603oP0000`3XJ3`0oh000?n000070?n00003
0>QX?02P8?00d51h02T0oh000`00o`08ooooo`D00?l004`0=>PQ06MAC`1DB5T01PPZ01DNA`0U;U/0
0PLm04a2H021GV`0R5]/07i;G020BEL0SUMP09]UJP2NJV`0Xg9b0:EkNP2YQWh0[hj10;6DQ`2_UHT0
]9fA0;bYX031/JX0_;2]0;bb[P2n/k40_;Ba0;Vf]@2k^KH0^kZk0;Rh^`2i^;X0^;Vj0;Vm_P2i_L00
^kk30;Zm`@2d^[X0][^l0;:e^02c^;/0WZjo03aDR`2Q=T`0_0L?0;d4402e0a00[DU>0;:_/02NZ;00
WJRd05mhS`26X;l0D45/08X96@2F0P/0T`HB0:A/N`1jT:H0VJ^g08FCVP1jR8l0N8F8071nO`1^OWh0
LWn006UhM`1XMgH0H7=d04EJK@0A8U000@e<004;@`0D94@0;g4b2000o`08ooooo`D00?l000<0J:Pl
0:0Pl02P8?002`2P8?000`3@D7P0^3Rd0:0Pl00K0:0Pl0030>QX?03oP000oh000080oh0000<0^3Rd
0:0Pl02P8?000`2P8?030?n000030=1@N02P8?00X23`00l0X23`2000o`0;ooooo`002_ooool02P0O
c000C@X006eFE@12?Cl0BdQ;01T@3`0O2PT0@@4406T21P1h0@D208@01`1908L12P2:00P0T04:0980
2P2E0@T0WP880:L32P2U0PL0YP860;832P2c0`/0^0<;0<082`3520h0a0P>0<<93P3620l0^a<I06hn
?P3Vh^40j>SZ0>?Ri@3Sh^@0h>7P0>;Si03Sh^D0i>;T0>CSiP3Uin/0i^SY0>KXi`3Hfm/0inSY0>CT
i@3Yjn/0i^SX0>OXjP3`f=d0^d9;0=PA6P3G3Q@0bPP=0<863@2o1Pl0^`@=0;L32`2c0P/0[@8:0:L1
202W0@/0Y@490:@1202S0@T0X@0:0:812P2R0@`0U`8909@11P2I0@L0X04:09d0202L0@T0V@8909`4
3@2C10/0R`4808X220260@H0N`8606D10`1T0@80H08305X80P03003o00Wooooo00<0P<000?n0002P
8?000`2P8?0H0?n000030=1@N03oP000oh0003@0oh000`00o`08ooooo`D00?l004`0<nDI08m^GP1>
@Tl03PdX048oF00>64/00PLm05I9H@1oGF`0QEe[085CGP21CET0SUQR09EQI@2KJFX0Xg5b0:EgN02V
PGX0[Xf10:nAP`2aV8T0]J2A0;^ZWP2m[JH0^:jZ0;V_[@2g[ZX0_;B`0;Vc/P2j];<0^KNh0;Zk^`2h
^KT0][Zj0;Vl_@2j_[l0`<740;fo``2h^kl0^K^n0;Fi_@2b^K/0/;Rm04iZV01iFH80[``I0;X33`2h
0Ph0Z1DM0;nPY02V[kH0^lSA08VL[@1ZS:h0=4Ul07dW@P2F0`h0V08;08XJ8`23OhX0RYnZ09RW[`28
UYh0MH>507:1P@1_O7d0KWak06UiN@1LLg/0;45R00@AC0012Td00@a=00DCB00dB5d0=3Lg2000o`08
ooooo`D00?l000<0P<000=1@N02P8?002`2P8?000`3@D7P0X23`0:0Pl00K0:0Pl0030;Ph]03oP000
oh000080oh0000<0d51h0:0Pl02h>;@00`2P8?00103@D7P0oh000?n0003oP00A0:0Pl0P00?l02ooo
ool000[ooooo02h08<`104/:001_F5D0BD=403li?00[6QX070<304T2101/0PH0M08507X2201j00T0
P@4;08P22`280@T0S04909T22`2M0@P0YP<90:@2202P00D0/@@<0;412`2g1@`0_`H=0<@93`301`d0
a0P>0<D:4@2J3140PG1_0>KViP3XjN/0j>SY0>KVi`3Qh^40hn?U0=k9d02kP8l0/Fj10;JAX`3?bmD0
hNGX0>CWj03Ui^H0hnGU0P3Uj>T09P3VinT0k>7U0<=ZL`3@51`0ePlG0<d;4P321Pl0_`D>0;`3302i
0``0]P<<0;422`2Z0@X0Y@490:D23@2V0@/0Y@4;0:<12`2R0P/0X08:0982202C0`T0V@4909l12P2P
0@/0X04<09`22`2A0`L0Y0L>0:453P2<0`T0SP<:07/21P1S0P<0F00105T20`1G2`D01_410P00o`09
ooooo`030830003oP000^3Rd00<0X23`603oP0000`2h>;@0oh000?n000060?n00080j6Pl00<0d51h
0?n0003oP000:@3oP0000`10h0000?l0003o0008ooooo`H00?l002P0/XU[04doB@0V8C<0>cA:00<;
@00J8Dh0CDAN07mPK`26FVT0Q5EO08ABF`2=FF80UVAW09UYJ`2OK740Y7Ef0:R0N`2^Rh40/9240;6H
RP2dW900_:RL0;R[X`2g[j/0]ZbZ0;N^Z`2j/Zh0]k>`0;Ve]P2h]kT0^;Rj0;Rh^`2j_;d0^[bo0;Zl
_P2n`<<0_Ko30;bn`@2k_/00]kbo0P2c^K/08P2DYk`0@E>;09dY?P2f1A00^0<=0;053`2/G6<0/K6i
08FHZ`34e^L0KHbW07B=/`1F>F<0T@HG09`23@2B1100UFE^09BSZ`2:VIh0PXfC07^:S@1aPX40KWen
06QjO@1AJ7/04bQJ004=D0012Td00@a<018WE@1<HG<0Ffa`03Hm@008i@@7003o00Sooooo1P00o`00
0`3oP000X23`0:0Pl00Y0:0Pl0050>QX?03oP000oh000?n0003XJ3`01@2P8?001@2h>;@0oh000?n0
003oP000d51h0100X23`00<0:<Pl003o0000o`001@00o`0;ooooo`002_ooool0B@0Oc@40B0X006mJ
F01KEUH09R0Q02dK6`0I0040D@<406X10P1_0P<0L`4707H12@1h0PT0PP8;08811`2:0PP0W0<<0:02
2P2W0PX0[0<:0:P2202^0`X0/@<:0;042P2g1@/0^`@90;X52`322140b@/G08d:402=PhD0j>OZ0>SY
k03XjNX0inKY0>OVi`3Yi>L0/fI`0<@K9P3?5Ah0bAhW08dO;@23E6D0[jRd0=[Nh@3Ri>D0i>GW0>KX
jP3UinP0iNCV0=:QY`2l5Ad0bP`C0<L93`351Pd0aPL<0;`32@2h0`/0]@8;0;422P2`0``0Z08:0:H2
2P2V00X0Y0490:@12P2R0@/0WP4:07h21@1_0@<0S`<:09`11`2N0@/00P2T0Pd02`2H0`T0Y0H?09l5
3@1i0@@0QP<907d31`1W0P@0G`0205T20P1I2@@06LD100800?l02Oooool00`20`000oh000:0Pl003
0:0Pl1P0oh0000<0d51h0?n0003oP000103oP000203XJ3`0oh000?n0003oP000j6Pl0=1@N02h>;@0
j6Pl:03oP0000`20`0000?l0003o0008ooooo`H00?l004`0M8la04dk@00k<T40;2I000/@@017A6L0
@3aI07]NK@27Gfd0QEQS08AAFP2?FV80UV9X09aZKP2NJW40Y7=f0:EmNP2/RH40[9210;2FQ`2cW8d0
]j>I0;VZXP2gZZP0/jZY0;6/Z02d/:h0];Ba0;Nf]02m_Kd0_Ko00;Ri^P2i^[h0^kk10;^o`@2n`/@0
`<750;^o``2j_/00]K^n0;>i_@2c]k/0[[S1045OT`23E7T0[PPG0;L33@2c0`l0X1dW0;n[]02BX[<0
GWnL07^K/02ic>80<ca^07`J<`2F0Q40UP8>08X[=@2XZZl0RiVO082;SP1dPXD0KGj106YnQ@0lE780
1QMG004:E0012U000P];01DXDP1PMh40I7Qi05]_L@0fA4T04m0>1`00o`08ooooo`H00?l000<0oh00
0:0Pl02P8?00:@2P8?000`2h>;@0oh000?n000020?n000030;Ph]02P8?00X23`00<0X23`00@0j6Pl
0?n0003oP000j6Pl402P8?000`1@T7P00?l0003o0005003o00_ooooo000:ooooo`1F023=0@152`00
N69R05UEF00L4Q805P@502X20P1I0`<0J`8306d11@1b0PL0M08807411@200@T0Q@4708X1202I0P`0
WP480:<11`2V0@H0YP480:X12@2a0P/0]0@;0;<52P2/0PP0]`L>0;/63@301@l0X0hD07ESI`3Ti>P0
j>SZ0>OWj@3Xj>X0j>W[0>_Wj@30Jg<0bADL0=TD603L5AL0dQ<F0;lE7P1/4Ql0NWEm0=cPh@3SiNH0
iNGW0>GVj@3ShnH0gl_?0;4Z<@383a@0bP`B0<453P301@h0_`H=0;/52P2f0`X0/`4:0;42302^0@/0
Z@490:P22@2V0PP0X0490:41302N0@X0T@860881102A0PL0W04709l12P2S0P/0X@8:09D22P2N1@d0
WPH<09042`2;0PP0P0<807<21P1^0`D0G08205@70P0Ha042003o00Wooooo00<0P<000?n0002P8?00
0P2P8?0I0?n000030=1@N03oP000oh0000X0oh0000<0j6Pl0:0Pl03oP0009`3oP0000`20`0000?l0
003o0008ooooo`H00?l004`0E;XO04`i<`1=@D`06QPg02/[C@1HCfX0<BiC07UOK`22GFX0QEMT08UH
H`2>FV@0Tf1X09ITJ02LJ6d0Xg9f0:MmOP2^R840/9630:nDP`2bVXX0]Z:I0;NYXP2aYJ80/:JR0:fW
Y02SX9l0Wj6O0<G9b@3=d=D0emcQ0<34b@2e^K`0^Kjo0;Rl_P2m`l<0^ko30;o3a@2k_l00_;g20;Jj
_P2d^;/0[kFi082C/`1<Ehh0VQX^0;L33`2d0Ph0Z`HC09=GIP2lbmX0CFn@09^ld03:f^D0HGBJ05hg
G02<11D0U@8:08/94`2CLWH0U:2S08ZIVP1ZO7h0Ih2503=>L@025E/00@iJ00<BC@0E9eT00Pi504IN
L01XO7h0HGMl059ZM00hBe408IhM1`00o`08ooooo`H00?l000<0oh000=1@N02P8?006@2P8?020=1@
N0030?n0002h>;@0X23`00`0X23`103oP0000`3@D7P0X23`0:0Pl0030:0Pl0050;Ph]03oP000oh00
0?n0002h>;@03`2P8?000`1@T7P00?l0003o0005003o00_ooooo000:ooooo`17023=0@182`00KUEF
06=KG`0@1PH04@4102d10@1P0P<0J`4306/11@1f0PP0M00807D11`1o0@T0R08;08/1202D0@/0X08:
0:H2202U0@L0XP480:P12@2a0P/0]@<=0:`32P2Z10X0/`@;0;X32`311@`0]@lF05ln@P3QhN@0j>SZ
0>KWj@3Xj^d0i^SZ0>KSh`3=QX`0aaTR0=HC6@3C41D0e10F0=0@5`2Q4QT0Bc4g0=3CeP3Vi^P0i^KW
0>?Si`3ThnL0hm[M0:m5C@333a@0aPT?0;d43@2l0`d0_0@=0;l63P2l1@d0]`4<0;D23@2`0P`0Z04:
0:H22P2S0@P0XP480:011`2N0@X0U`4609000`2G0@L00P2L0@T03@2P0@X0X08;09<22@2H0``0U@@;
090430280PT0K04406/10`1/0@<0I08205X70`0Ia@800P00o`09ooooo`050830003oP000X23`0:0P
l03@D7P06@3oP0000`3@D7P0oh000?n0000;0?n000030=1@N03oP000oh0002H0oh0000<0P<00003o
0000o`002?ooool7003o000W0653=P1CB5D02``_04e6GP1QE7007Ae<07MOLP21FfT0QeYW08]IH`2>
FVH0Tf1W09UWK@2KJ6d0XFmc0:MjOP2]R880/I640;6BQ02cW8h0]ZBI0;BVWP2eZZH0[:BP0:fWY02O
W9X0/K:_0;Nk_P2d][`0a/kA0<O;d@2i_/80^;c00;Vm`02m`/D0_<;50;_1a@2l`LD0_Kk20080][Zn
0280/;Bi0:Vc_`0dDXH0Rd]X0;865@2g10h0/`8>09hY>024RJ40TJk608JT]P3:fN<0[[kF03LhJP1j
3bD0U@4=09<23P2A?DP0SHnC07Z7R`1KL7h07cUV008EH0014eh03bEK04=LMP0Q=ed02am?05]dOP1V
OH<0=4U/00@IB`0]AUd07VlN1`00o`08ooooo`L00?l000<0d51h0:0Pl02P8?00602P8?00103@D7P0
X23`0=1@N03@D7P=0:0Pl0030=1@N03oP000oh000080oh001P2P8?00103XJ3`0oh000?n0003XJ3`@
0:0Pl0L00?l02oooool000[ooooo05H08Lh204T90020IfH0CD=600d51@0D0@40?P<306D2101V0P<0
I`4407<21P1e0@P0M`4907P11`280PX0T08;09<02P2M0@X0W`480:41202S0PT0Z0490:d22P2`0P/0
[P<<0:h32@2j1@`0c@`A0=L?4`3D5a`0E1HJ0=CCf03TiNL0j>WY0>OXj`3Yj^`0jNSY0=2NX@2m8RT0
d1<I0=0@603C3a@0da4D0;`D6`163180^;Vn0>?SiP3Wj>T0iNGY0>?Ti`3ThN@0_79g0;hG70362Q00
``L?0;l73P2i0`d0^0@=0;D32`2d0``0Y@<;09P;4P2c:380W@dF0:<33@2T0PL0X@8909h12P2I0@L0
T`0509H2202L0PT0W04709h1202O0PX0V`8<08d11`2@1P/0U`D<0903301d0PL0K@8506d1101Q0@40
G@P401[60`800?l02Oooool00`20`000oh000:0Pl0020:0Pl1T0oh000P3XJ3`<0?n000030>QX?02P
8?00oh0002H0oh0000<0P<00003o0000o`002?ooool7003o001;079A=`18?d`03@h^065EI@1:B6@0
2Plo06iKM01oFfL0R5]Z08YHI02;F640TEeS09]XK`2MJW00XFmb0:QkO@2[R840/I240;:CR02bVXd0
/IjD0:nQV02]Y9l0/:RT0:nWY@2ETI<0WinR0<74a`2o`lP0cMGJ0;^ma02j^l80_;g20;Vm`@2k`L@0
_L;50;g0a@2m`LD0_Ko40;Jj_@2b^K/0/KJj0:bb]`1`QjH0F5F609hA902e0a00/`8=0:875`1oFG80
XKW>0<SLiP3:f><0a]OT04YLQ@1Z;dh0S`8?09<130273a`0V8B607b;T`0U?V`00QIU00<GH`0W?VX0
GWF104UQMP0A:5@08CMQ03iGN@0U?V/00Q=H004=CP0I;U@08SDX00L00?l02?ooool7003o00030?n0
002P8?00X23`01P0X23`00<0^3Rd0=1@N03@D7P03`2P8?040?n000030;Ph]02P8?00X23`00<0X23`
00@0d51h0?n0003oP000oh00402P8?07003o00_ooooo000:ooooo`1F02;>0P1:2000NeiP03lf>@0<
0P806P0004H20P1Q0`<0G00106410`1^0PL0LP4807<11`1j0@L0Q`4908/1202B0@T0V@4709X11P2K
0@L0W`490:P12`2^0``0Z`8:0:L11`2b1@h0_0H=0=@?4`3N4aH0f18G074;3P2VYZX0j^_]0>_[k03X
jNX0j>WY0>KUi`3Tb/`0Z3Po0<DE6`3=41H0dPlF0=8?4`3=4aP0N``D05M:C`3Ffmh0i>GX0>;Ri@3O
h>40h^;U0=:[/02T72@0`@/C0<06402m1@h0^`D=0;L3302d0`h0ZP<=07d31P2<1Pl0WPTF09<>602A
0`X0X`8:0:02302N0P`0U`4708l11P2<0@D0W04909d1202M0@X0W@4909h22`2J0P`0V@D=09/63@2C
0`/0O`8707421@1`0PD0H`8205`40@0Ja082003o00Wooooo00D0P<000?n0002P8?00X23`0=1@N00J
0?n000030=1@N03oP000oh0000/0oh0000<0X23`0=1@N03oP0009@3oP0000`20`0000?l0003o0008
ooooo`L00?l002@0DgPT03`cA@0R8C`0D4IJ02hcF00?54L0Bd9S07aKJ@22F6H0QeET08YHH`2?GV@0
UVEZ09]YKP2OKW80YgUk0:V4P02`T8@0/9>70;BKT02`Vi<0Z9ZA0:JLV@2[XJ00[jJT0;:]ZP2c/:h0
ZZV[0:Z/[`2Z[;80ZZfb0;Fg_02l_/<0^kk20;Zo`@2j_l<20;_1aP0V0;c1a@2f^kh0/[Zl0:nf^02[
];H0XJjl02i9P@2A?e`0/P@D0;<23`2/0Q00UCA608R>X03<g>H0bmWS0<WGh@2IZl<0A3QR084:7@2D
0P`0S`<=08mCF01NKHD00aYT00<KH@0gD7@0JGf3061dO`0A:5<0AUaf03A7I`014EX00@mP008@G@03
4Dd031a302lg@007i0@6003o00Sooooo1`00o`000`3oP000X23`0:0Pl00Z0:0Pl0070=1@N03oP000
oh000?n0003XJ3`0X23`0;Ph]0040:0Pl0<0oh0000<0d51h0:0Pl02P8?003@2P8?000`1@T7P00?l0
003o0004003o00_ooooo000:ooooo`1802;>0P1A2`00O5iQ03<[;00@0@40:08204h20P1M0@80F@40
05`10P1[0@L0K@4507411@1n0@L0QP4808P0202?0@X0T`4609H11`2I00P0W`8:0:D12`2[0PX0[0<<
0:P1302_0P/0^@<:0=4?4`3G4A80e0lC09@@4`1cKW00i^W]0>OWjP3Rh^@0h>;Q0>;Si03Ufm/0^6ec
0;`H803>3QH0d@lG0=4?5P3=3aH0X18G02P62P33a/`0i>GY0>?TiP3Oh><0hN?U0=g:c@2F<CT0^0`E
0;h7402l1Pd0^@H;0;@32`2g10h0ZPL@06L1102D1`h0Y@8>09X53`1m0PH0X0<=0:412`2M0@T0VP48
09H11P2G0PP0W0470P2L0@P0302L0@X0U`8:09812@2H0``0Q`8808P3301d0@<0HP4206@31@1R0P<0
G`D303>:10800?l02Oooool01020`000oh000:0Pl02P8?0K0?n000030:0Pl03oP000oh0000`0oh00
00<0d51h0?n0003oP000903oP0000`20`0000?l0003o0008ooooo`L00?l004`0JXTc034Y?P0e<4/0
>c=A028WDP0K84h0:RUA07QNKP1nEF<0R5AS08iKJ@2=GVH0U6E/09]/L`2OKg<0YGYi0:V4P02aShD0
/9F:0;6JT02_Vi<0ZYVC0:RNW02/Xj00/JVU0;Na/02e];80/[6_0:FRY02^[K40X:>V0:R[[`2e^Kd0
]K^n0;No`@2k`LD0^l;70;[1a`2j`<<0]kbo0;>h_02b]k/0[;Fh0:Nc^@1;IiH0L5=l0:T:6P2e0Pl0
/08?09/H:03^a]D0f];R0=KAh`3Cc=l0d<SP054nH`247300T@4=09423026:cL0@DYe00@MIP0mG800
I7^306f2QP0eBV`04b]D06YnQ@1FJGd00Q=E004>G00255L0:T1S01h_AP0f@dP079@A1P00o`08oooo
o`L00?l000<0oh000:0Pl02P8?00:`2P8?080?n000030=1@N02P8?00oh000080oh0000<0d51h0:0P
l02P8?003P2P8?06003o00_ooooo000:ooooo`1F02??0P1A3000LEIF02XT9@0<0@40<@8305<30`1I
0P40E@4005T10P1Y0@H0K@4607411P1n0@T0Q`8:08P1202=0@X0TP0909@1202H0@P0WP8;0:81202V
0PL0Z0890:T22`2c0``0`0L;0=0=4@3>30l0c@`C0:D>501>>Sd0bLkB0>7Si03Rh^80h>3P0>7RhP3U
hn80eZZ]0;PV;03@41P0dQ0G0<l=5P3?3QL0^a<K04/2202?S980i>OY0>?TiP3Qh^@0gn;R0=oJfP2Q
HfL0ZA4I0;X64@2j1Ph0]`@;0;D53P2c0`d0Z@TA05X10`1Z10X0R`D<08@52`1T0P@0V`@?0:02302N
0PT0V`8709D11`2E0@P0V`4809d11`2N0@T0W@4;09P1302D0@T0VP<=08T22@250PX0OP8906h21`1O
0@<0H0420645100dS0H2003o00Wooooo00D0P<000?n0002P8?00X23`0=1@N00J0?n00080d51h3@3o
P0000`2P8?00oh000?n000030?n000030=1@N03oP000oh0001h0oh0000<0P<00003o0000o`002?oo
ool7003o001<04Fa8`0[9CT0AciD02@RA00S9dd0:RY@00dA@P1XFFh0O5IQ08=@GP2:EF80TF1X09QW
K`2NKGD0XG=g0:MkO@2ZQH40[hn70:jDR`2bW940[9R@0:^JU02]XIh0[jNS0;>/Z02]ZjT0ZZ^/0;>a
/@2/ZJ`0[k:d0:^][P2W[:l0/[Rk0;Bj_P2h_L00^l750;Jn`@2e_Kl0^l740;Zo`P2d^[d0/KZl0:^d
]`2[/kP0OI2^04UBQ`2I7C40]@DB0;82402[1QT0[RY30:4_C02G:TH0TRE408hS@`286S@0S@TJ0981
302@0@`0PPlO03L`HP0/B7T0Jh:?06UoQ019IWl02B9C04QPM01^P800K7f302/oHP087E<0:dIX05E]
MP0Y?4P0?4e@02BP6`H00?l02?ooool7003o00030830002P8?00X23`02/0X23`00<0j6Pl0?n0003o
P0000P3oP0001@3XJ3`0d51h0=1@N03@D7P0j6Pl00@0oh00402P8?06003o00_ooooo000:ooooo`1F
02??0`1<2@00M5QH020I6`0F0P40?`<205<20P1B0@40D@4105H10@1W0@D0J`4507011@1m0@X0Q@4;
08H02@2<0@X0T@0:09812@2H0@T0WP8:0:@12P2Z0P/0ZP490;H3303520l0c``A0</:40321`h0``TB
0;P=501541@0ZJ^_0=gNh03ShnD0hN?S0>?Th`3ThnD0k=SJ0;Q9D@3=4QT0d@hE0=0?503A3aL0cA4J
08l?601MAdd0gn?U0>;TiP3Phn@0gn?T0=kQh035[:h0VR@]0;@7402e1@h0]@@=0;@23`2a0`l0[@D>
07/42@182@`0F1@F03l2101D0@L0VP@@09d12`2L0PT0V@4909411P2A00D0V`4809d1202N0@T0W@8;
09/2302C0PX0S`8:08h22P1l0PP0LP870742101`0PD0I04206030P0aR0@2003o00Wooooo00@0P<00
0?n0002P8?00X23`6`3oP0000`3XJ3`0X23`0?n0000<0?n000030=1@N03oP000oh0000<0oh0000<0
d51h0?n0003oP0007P3oP0000`20`0000?l0003o0008ooooo`L00?l004`0<MDK01dH:01FCV802Plb
048nFP0o=U@00PHm02PXD@1gEfL0Pe=N08UEH@2AHVX0UfY`09A/L`2;Jg80X7]o0:N1P@2[RXH0[9>8
0:fIS@2ZVY80ZIfF0:JLV@2^Yj80Y:6O0::UY02MXJD0[:fa0:6TYP2^/;<0[[2b0:J[[P2^/KH0]KVm
0;Vn`P2l`<D0^l340;Zo``2h`<@0^<330;Bl_`2`^[`0/;Vl0;_5b@2Z]L40Af:@07AFO02L6b`0Y0/G
0:H=5@2Q3QD0W10G09<?5`2?41P0R@dF08D;5P252Q@0QPTA08L84@1k31D0AcUP039@OP1ELH/0<dae
00TVG015HGT0IW]m06j0O@1]OWh0J7Yl06=gO01UN7T0Efe_028hB017FUl0@Sdf1P00o`08ooooo`L0
0?l000<0P<000:0Pl02P8?00:02P8?00102h>;@0X23`0:0Pl02h>;@=0?n00100X23`1P00o`0;oooo
o`002_ooool0EP0Td0<0D0T006A3@@0E3@h05`4204820P1A0@40DP410541001J0@80IP4506/0101a
0@80O08808<230240@X0R@0;09012@2E0PT0VP8809h12@2T0@X0Z@4;0:d22`2g10d0a@X@0<T:4033
1`d0`0L<0;l73@2l2a40FPL;06]ZKP3@dmH0hN7S0>;Th`3Qh^80h^;S0>_Qi031LWL0bA@H0=4?5P3A
41D0dPlF0=8@5P2g61h0Ba`R0=;FfP3PhnD0gn?V0>3Si`3MhN80gmCE09Y0BP2_2A<0/@8<0;@43@2`
0a00ZP4<0:`32`2P20d0QcDg0<f@T`1O7R00K`<909h2302K00L0VP0909T12P2C0@L0U@4709T1202K
0@P0W@4:09`1202C0P/0OP0508H22P290`X0J00205L00`1a0PD0L`<506020P1M0`40<hX50P00o`09
ooooo`040830003oP000d51h0:0Pl1`0oh0000<0X23`0=1@N03oP0002`3oP0020=1@N0D0oh0000<0
d51h0?n0003oP0007@3oP0000`20`0000?l0003o0008ooooo`L00?l004d0;N4G02dO9P1ABel02`ld
06EFI`1IAed010Dk00H8?@1XCVD0OE1L08MHH02HJW<0Uf]c095ZL`23J780SG9f0:R2Q02[RHL0Zi28
0:^GS@2YVY00WYF<09nGT@2KUI00/k>_0;k3aP2j_/D0[Jfa09nRY02JW9l0W9nU09RLX@2Y[[@0/kRl
0;Vna02m`/H0^/340;Nm`P2k`LD0_<;50;Nm`02d_L00^lC70:nh_P2b_/H0//GC06InX`25Qj00LF=l
0;JOX`2nYJ@0_jRX0;bWZP2jZ:`0W9>O08IoSP1eKWP0Qg=b095fM`2=NWT0LGZ502HnJ`0G<f<0:TE/
05acQ01`PXD0KWmo0720O`1]Oh40JWYm06QhMP1TMG@0EVUd01P_BP1>IFT0@DU100cI1`05003o00So
oooo1`00o`000`20`000^3Rd0:0Pl00F0:0Pl080^3Rd5P2P8?000`3@D7P0oh000>QX?0020=1@N0@0
X23`00<0d51h0;Ph]02P8?003`2P8?000`1@T7P00?l0003o0003003o00_ooooo000:ooooo`1F02CA
101@3000IdE200X51@0D0@40@@8305D30`1C0P80D`8005/1101X0@H0K@4606l11@1e1@/0Q1PO0702
20240P/0S@8:09@12@2I0@L0W@480:<12@2V00P0[08:0;<32P2o1``0a0X?0<07302o1Pd0_`P>0;d<
4@1k3180;R<V0;Vl`03RhN<0hN7Q0>?Ri03Ui>D0iN7R0<bJW0306Ah0ca0E0=8?5`3B3QD0d0hD0<DC
6P1L2a40/kFk0>;TiP3RhnH0h>;T0=oPhP3Sg=h0YfM^0:X<5P2c1Q00/0<=0:d33P2Y0P`0Y`4:0:H4
3@2V:380V3Q308lR;02J1@l0X`8;09`1202K0@X0U`8909801P2H0@P0VP4909d22@2N0PT0V`4808h2
201l00D0Q0<=07h22@1i10X0H@8506l31`1/0P@0G04105/30@0eS@P2003o00Wooooo00D0P<000?n0
002h>;@0^3Rd0>QX?00K0?n000030:0Pl03@D7P0oh0000`0oh0000<0^3Rd0?n0003oP0000`3oP000
0`3XJ3`0oh000?n0000M0?n0000308300000o`000?l000Sooooo1`00o`00C@0<n0D0Bc8X040lD`0S
9D<0KeeS06iHI`0<2CL030dm075DJ@22EF00S5iZ09MYM@2JJgL0Tf]e08YZLP2LN7X0Yh200:J5P`2T
RXD0Z9F=0::DR`2RUhh0VY:909NAR`2SXZ40b<[=0;Vk`02WZ:/0YJZZ0:Z/[@2OXJD0SiFJ0:J][`2f
^l40_L360;c1aP2m`lH0^kk40;g1a`2j`/D0^;o20;Fl`02oal/0^/370;S3b`2O[kd0X;S?05n7[`25
YKl0cN7Y0=3Mi03AgN@0cm[T0<_Hi01iSJP0Rj>h09>T/@2JZK<0UjJ]07b;S@1jR8`0MXB:07:4RP1b
Q8L0LXF507:5QP1`PGl0KH1n06f1P@0gCUh0FW9f059YLP0M<5H00@e202a4F`18EeL06jPC00D00?l0
2?ooool7003o0003043P003@D7P0X23`01H0X23`00<0d51h0;Ph]02P8?003P2P8?000`2h>;@0X23`
0;Ph]0040:0Pl0040=1@N03oP000oh000=1@N1L0X23`00<0D91h003o0000o`000`00o`0;ooooo`00
2_ooool0EP0Td@@0C`d105<a;@080@40808104@20P1>0@80D04205@10@1H0@80I04606T11P1R0@<0
MPL=08@;5@1Q0@D0M`<:08h12P2D0@T0U`4909`12@2R0@T0Y0490:`22P2m1`d0a@X@0<07302l1`h0
^`LA0;d84@312a00XA0F02X1102<S900h^7P0>?Ph@3ShN@0iNCV0>CRi03Pb//0]2T/0=0B5`3A3aD0
dPhE0=8@503=41H0S0hE07MbN03RhnH0hN;U0>;Ri@3Pgn80h=gQ0<:SZ02P5Ad0]0TB0;463P2/10`0
Z0<<0:@12@2U0@`0Y@8@0:83402T0Pl0Z08=0:D2302P0P/0W@4809L22@2E0@P0V08909/1202M0@X0
X08:0:412`2L0P/0U@8;09D33`280`/0NP4706l21P1R0P@0GP4206820`1M0P40>7X50P00o`09oooo
o`040830003oP000oh000=1@N1d0oh0000<0X23`0?n0003oP0002`3oP0000`2P8?00oh000?n00003
0?n000030>QX?03oP000oh0001d0oh0000<0`:00003o0000o`002?ooool8003o001<061@:P0b;4L0
@ceC075MGP1`G6H09Ai300l??@1cEfX0PUQT08mTK`2FJ7<0VVeg09]bNP2NMG`0XgYm0:EmO@2UPH00
WX5m09n;PP2SUH`0V8f409jDR`2OUXl0UI2;09ZGU02JVYL0VIZI0:R][@2WZjl0XJBX092CU`2V[Jl0
]Kbn0;S1``2la<L0_<;70;Jl``2`^;h0^L350;[0a033bLd0];g20;W5bP2faLd0PIVe09fecP1aT[40
^M;N0=7Oj03@g>D0c]kU0<cKi03;fND0[L7G05EeU01lT:80TIn[08NEW026UIP0P8jB07N4QP1ePhD0
MH>40761PP1`PXD0L86206enP01ZOGl0;dAJ03QCK`0=7D`00@Y5004;@P0>7d<0BV1S02:R7@D00?l0
2?ooool8003o00030>QX?02P8?00X23`02D0X23`00<0^3Rd0:0Pl02P8?001@2P8?020?n000030=1@
N02P8?00X23`01H0X23`00<0D91h003o0000o`000`00o`0;ooooo`002_ooool0EP0Vd`H0D0h204db
;0070@40:P4204`3101<0@80D@4105P10@1H0@00G`4306D21`1A0@<0MP<;08L32`1W0PH0J`8708h2
2@2C0@T0U`4909T12@2N0PX0X`890:l42P2m1P`0_PH<0;`63@2m1`l0`0P@0<0940312a00]0dG05d6
301NEE/0g]kP0>7QhP3Qi>@0i>GW0>GTiP3Vg^00^UAK0<`D6`3B41T0d`lH0=0>5P3?41H0]A<K04l_
=P3CeMT0h^?V0>3Ph`3Pgn@0g]kQ0=[?d@2H;SL0[PXD0;07402Z10h0Z08=0:@12`2R0P/0X08=0:01
2`2R0@`0YP8;0:<13@2Q0@`0WP8909`12@2I0@T0V@4:09X12@2L0@P0X@4;0:H23@2V1Q00U0<;08T2
2@2>0PX0QP4808422@1h0PL0L08506820P1L0P80D5@=0P00o`09ooooo`040830003oP000oh000=1@
N1d0oh0000<0^3Rd0?n0003oP0002`3oP0020=1@N0@0oh0000<0j6Pl0?n0003oP0007P3oP002003o
00Sooooo2000o`002`1GNbH08ahg05Y?G`1@AeL0BdAK04<iE`0>3c`0MU]_08QQK@2>IVh0Ufeg0080
WGAl03l0WG9k09ieN@2QNGd0X7an0:25PP2QT8L0WXf509Z@QP2OV8l0WiRB09J@R`2NVi@0WYfI09VK
V02Y[Zd0X:RZ0:b//@2AU9P0WJFW0;6h^`2k`lH0_<?70;W0a@2[/kP0];c20;[4a`2i`LD0^lC80;_8
cP2jbM40XkG10;K9fP1KOjL0NIfj0<OLjP3Ag^L0d=gV0<kLiP3=fnL0bmWW08VO]P2?YKL0/LCA092N
ZP20T9H0QI:G086@U01mSHh0LXF30762P@1dPh<0Kh:407B4QP1^Oh40HWR1020dG00134T00@Q7004:
@`0764801QLi049JH@0dR2l01@00o`08ooooo`P00?l000<0oh000:0Pl02P8?009P2P8?000`2h>;@0
X23`0:0Pl0030:0Pl0050;Ph]03oP000oh000>QX?02h>;@0602P8?05003o00_ooooo000:ooooo`0b
02SD1`1F4`<0?B4N00H0000`0@40BP8104X10P1C0P80F@8105`20@1T0@D0HP8804810P1U10T0J`<9
05411P1X0PP0S`4909402@2G0@X0W08:0:012@2U0PP0]@D=0;T6302h10d0_@P@0;`63P2n1`l0_`L@
0<4:4P2j3AL0Q`dG04Xb>P3De=P0hnCT0>7Ri03Ti>D0iN?V0>KSiP34OH80b1LL0=<C6@3C41L0d@lG
0=0>5`3651d0BPdD0<;6b`3Qhn@20>3PhP0R0=gMgP3Pfml0VTeD0:X<5P2]1Ph0ZP@=0:D23@2R0@/0
W`4909d12P2L00X0W`4;0:@22`2Q0@/0X@4<09l12P2M0@`0VP0909X1202J0@L0V`470:012P2X0`h0
ZPD@0:84402C0PX0S@8:08H01`200@P0MP4607<1101W0P@0GP4104mD3@800?l02Oooool01020`000
oh000?n0003@D7PM0?n00080d51h303oP0020=1@N0D0oh0000<0d51h0?n0003oP0007@3oP002003o
00Sooooo2000o`00801DVB@07aPY06IJI`0F6C`082E9065EJ@0>3SL0L5ad08aVM@2@Ig<0UF]d09A[
L`2HKWH0Wg=l09icN02RN7X0WW]j09j4P02NSHD0XiB<09jAR`2PV9<0VYJ@09RES02KVI40WIbK09JF
UP2RXJ<0TYJH0;2a/P2JWZ40W:>W0P2k`L@0:P2i_l@0]Ko30:Rc]`2f_/@0_<G90<O@e02g`LP0_<W@
0;G6cP2G/lT0Pj;006Z<[`2[`mH0dn3W0=7Oi`3AgnP0dMkW0<[Kk02^_M/0DE>407eTR@1mHW/0WI>Q
07j8T02BXJP0N8J>07V7R`1dQH@0M8B20720P@1aPh@0M8N905M/OP0E:f000@m@0048B0013D4072i=
04]RK00aA5@0=e1M04QMA@D00?l02?ooool8003o00030<2P002P8?00X23`02@0X23`00<0^3Rd0:0P
l02P8?00102P8?000`2h>;@0oh000?n000020?n000030;Ph]02P8?00X23`01H0X23`1@00o`0;oooo
o`002_ooool0A@0We0L0DQ<4040Y:00;0@40@@<404l20P1<0@80DP4205P10@1L0@80IP8506@32@0i
0P<0>08304811@140080L08808d1202B00X0UP4:09X12P2R0P/0ZPH=0:/6302g2100]`<>0;`7402m
20l0_@T?0;d9402m2A80_0XE0:HB7@124a`0alS=0>7Ri03ShnL0iNCV0>GSi@3Ui>H0cjFY0;hL8`3?
51T0d1<H0=4D603?4QL0bQDJ06/>5@2NW:40h>7T0>3PhP3Ogn00gMgM0=oNgP2YM7/0X18M0:d7402Y
0`d0YP<=0:<13@2P0P/0W`8<09d1302N0@`0X@8<09l23@2L0@/0WP8:09`12P0209T1200?09/1202L
0@P0XP890:P43@2U1A00YPLB09l43P220PL0Q@<908422@1e0PH0J@8305`20P1P0P80C4h700800?l0
2Oooool01020`000oh000;Ph]03@D7PM0?n00080d51h3@3oP0000`2h>;@0oh000?n000030?n00003
0>QX?03oP000oh0001d0oh000P00o`08ooooo`P00?l004d0AJlK02XP:`1JCed01@Xd01XLA01^EfH0
>Ri=05M<J02<JWT0TfQe099VLP2AIg00VW1i09mfOP2MMGX0X7Ii09afMP2PPh00XHZ509f;Q@2KT8X0
WYB?09nGT@2HTH/0UY>?09NHU`2EUi@0X::T0:6RY@2e][L0Zk2c09jUZ@2h_L00^<730;S0``2i`LD0
^/C50;o:c`2ha</0^<760<_Fg@31c]L0X;?30:o7e01gW;h0Nino0;G=g@3Bh>P0cmk[0<[Kl@2T/M@0
NFZI07@[E`283Rh0T0DK08`56`2352X0U6E`09:HW`2AWZD0NXJ;07^9RP1jRHT0MhJ80721PP1bPhP0
;dAZ004AGP023UP01Q=903E<G@1GKV`0F6]Y03U9E@0hDE/0De]I00Cb0P04003o00Sooooo2000o`00
0`20`000X23`0:0Pl00U0:0Pl0030=1@N02h>;@0X23`00<0X23`00@0^3Rd0?n0003@D7P0d51h0P2P
8?000`3@D7P0j6Pl0?n000020?n000030;Ph]02P8?00X23`0100X23`00<0:<Pl003o0000o`000P00
o`0;ooooo`002_ooool0EP0Xe@P0EAL803<K600B0@40A@8304h10@1?0@80E`4205X10P1O0@80I043
06<10`1?0`@0ERP]06dg?01Z1`d0Q@<:08l12P2B0@T0TP4709L12@2S0`/0Z@D<09d41`2a1Q00^0@?
0;/74P2k1A40^`LA0;/8402k2A80_@XD0;L?601N2Pl0UiNM0>;Si`3PhnL0hn?W0>;QiP3RhnH0g]?E
0;IWIP38Hf00b6MR0<IVHP36J6@0aV]V0:=YI`2NVY`0gMgQ0=oPh`3Lh>40gmoR0=oNh@38[K80RQ`W
0:`9502]10d0Z`H?0:L33P2S0Ph0X08<09h32`2M0@`0W@4;09d1302I00T0VP4:09T12@2I0PT0V048
09`12`2Q0P`0X`8;0:L43`2R1Q00U@<<09X53P250PP0O0<807L11P1b0PH0JP8406430`1S0P<0Bd/7
0P00o`09ooooo`040830003oP000oh000>QX?0T0oh0000<0j6Pl0=1@N03oP0004P3oP0000`2P8?00
oh000?n000040?n000030>QX?03oP000oh0000<0oh0000<0j6Pl0:0Pl03oP000103oP0000`3@D7P0
oh000?n0000M0?n000800?l02?ooool8003o001=02_=400d9RP0A3a?00@:>00P7T@0LEER06YAH012
=E00QFAc08mTLP2EJ7@0V6ag09Y^N02MMGd0Vg9h09acM`2GLG@0VWik09Z3O02KRX<0Vhj709bCS`2O
VI@0UY2<09RDTP2FUiD0UiRH09jQXP2QYJL0/kRi0:J][`2PYZX0];Zm0;Jm`02l`lL0^<330;g7b@2h
`lL0`lgB0<3:d02jbM00^<SB0;?8f@1eV;L0FGjY096dd@39g>`0]L?N08N0[`1^AW/0PBME09H=:P2M
1AD0VPHB08l4402@0P`0TP4=08T@8@2POHT0OhZ?07f<T01jRX`0NXR<07R7RP1hQXX0MHB:045FM@03
5eL093]Z028gF01ILG40Fg5Z05Y^J`0S=TP0AUi[05EUI00AcP/01000o`08ooooo`P00?l000<0P<00
0=1@N02P8?008`2P8?000`2h>;@0X23`0:0Pl0060:0Pl0040;Ph]02P8?00X23`0=1@N0L0oh0000<0
d51h0:0Pl02P8?003`2P8?000`1@T7P00?l0003o0002003o00_ooooo000:ooooo`1002SF201I7@d0
=1hL01d10@1=0`<0B`0004l10P1H0@<0F04205h10`1O0@80HP4206@5201i=d<0QCI407h33P2;0@`0
S`4:0940202>0@H0U`8;0:@22`2^0``0/@D>0;L63`2h0Ph0_0HB0;/74P2i1Q40^0PA0;X84P2n2aH0
^P/E084=4`1^Ifh0gn;V0>;Tj03PhnH0hn;W0>CSiP3ThnD0iMoN0>OOg@3Yh=h0jN7Q0>CNg@3WhN00
iN;Q0>?Rh`3RhN<0h>7T0=gOh@3Lg^00gMgO0=O9c02>>D00Z@XG0:d4302Z1@h0Z08>0:@23P2R2A<0
V`8<09h23@80W04<01@0W@8=09/12`2K0@X0V@4:09X12@2M0PX0W`8;0:812P2V0``0Z0P@09842`2:
1@`0R@8807X01@1m0PX0J04405l00@1T0@<0IP82055?2`800?l02Oooool00`20`000oh000?n0000:
0?n000030=1@N03oP000oh000180oh0000<0X23`0?n0003oP000<@3oP002003o00Sooooo2000o`00
C@0Xf`l0@BdY038]A00X:T`0;bQ007AGH01eEf00KE=R089OK@2@IW<0UFQe09QZMP2HK7H0WG=m09Ya
MP2GKG00UVe^09EiM02LQGl0WX^409Z<Q`2JThl0WIND09F<RP2HTHh0SHb809:DTP2FVi`0X:>V0:b`
/`2_/KH0Yjja0:ff^02la<L0_/C80<?9c@2ma<P0b<oE0;O0aP35d]P0_LgH07BJ_@2V]ll0/[;709^H
]@1kMIl0Q5Z508D`F`2=5CD0T`lU08lC7P258BD0QCm307UDH@1L?U/0NAP^09<2402C0Ph0RB@c08b6
R@22SY80OHbA07b:SP1iQhX0MhB90762Q@1NLgh0DFMj06UnQ`0X?eH0Fg9h05ibK`1LL6l07C=1059[
KP1HJfL07jhH00@00?l02?ooool8003o00030830003@D7P0X23`0200X23`00D0^3Rd0:0Pl03@D7P0
X23`0;Ph]0030:0Pl0060;Ph]02P8?00X23`0;Ph]03@D7P0j6Pl0`3oP0020=1@N0050;Ph]03XJ3`0
oh000?n0003XJ3`04@2P8?000`1@T7P00?l0003o0002003o00_ooooo000:ooooo`0a02SF201M8Q@0
:aLE01d10@1;0`80C04204d10P1E1@L0DP8205X20`1P0`H0H`4506@1101]2Q@0N@HC08P23`2=0P`0
T@8:09812P2?0@D0U`490:P3302a1@`0/0D=0;<73`2k2100_0LB0;T74@2e1Pl0]@LA0;H8402g1a80
_0/B0:<?6@1A=Ch0aLS?0>7TiP3Phn@0hN;U0>CSi@3Ti>D0hn?U0>CSi03Sh^@0h^;T0>7Qh`3Rh^@0
i>?U0>7Ri@020=kPi00S0=_Nh03Lg^00g]kP0=g=dP2B@4P0Z0`F0:d33@2Z0Pd0Z0<>0:@23@2O10l0
WP<?09d1302N0P/0W04<09/1302J0@/0V`8;09`12P2K0@X0W@8:09l2302S0Pd0Z@@=0:T63P2Q1a00
S@@;09432`280PT0MP8705l21`1P0PD0J08406T30P1D?PT00P00o`09ooooo`030830003oP000j6Pl
01l0oh000P3@D7Pb0?n000800?l02?ooool8003o001=00_g101><R`08R0k04Y4F011=D<0LEIM07=E
GP1jFVD0PUm/08mWM@2BIW80UVQd09Q/MP2LKgP0Ufie09=YKP2EK6d0V7Eb09^2O@2KQH00WXj909R?
RP2KUI40Ui:>09ZDT@2@S8T0V9ND09:GU`2PYJP0YZZ_0:^b]@2]]KP0Zk>f0;k4b@2oa<T0`/K:0;k4
b031ald0cmGK0;g9c`2kc=D0LIBk04QSW023G800RSEB08dQ=P2=8300QRXa08a8BP2@HfD0XXj<0;Ng
]`2OZkT0GGB>06Z3X`16:UD0QPDI09<13@291Q80TVa^08><SP1nS8d0O8^<07^:S01eQXL0L8:20762
P`1`PX@0KWn203Y@H01JLWL0Gg9a05]`K01@IVD0C6=Q05Y^J@0aTR/01000o`08ooooo`P00?l000<0
@>000=1@N02P8?008`2P8?000`3@D7P0X23`0:0Pl0030:0Pl0040>QX?03oP000oh000?n00080d51h
00<0^3Rd0:0Pl02P8?000P2P8?001@2h>;@0oh000?n0003oP000^3Rd0100X23`00<0N5Rd003o0000
o`000P00o`0;ooooo`002_ooool06P0Ze`X0HB<E02LB4@0S0@80B@8204`20P1?0P80G0lC04h11018
0P@0F18F05852P1M0PD0LP4608L23P2>0@d0S`8>09012@2>0PT0T@4809X2202]10`0/`<=0:l3302_
1@d0]PL@0P2g1Q40>P2a0`d0/`H?0;053@2g2a80_0`C0;/>5P1n3AT0K3Y;0;FJZP3GbmD0f]7I0=gB
fP3Pcm/0gl_E0=c4c@3OaM80fl3?0=k2c`3K_lX0g/7=0=:jb03>^<@0b[K20=:obP3D`</0ekc80;aj
R@2K5b@0/0PA0:l43`2/0P/0Y`8:0:<33@2P0P`0W@4<09h23@2N0PX0W04;09`22`2K0@X0VP4;09X1
1`2J0@P0W`<;0:812`2T0Pd0YP<=0:@43@2U1@l0X0D=08H21`200@H0MP8606011@1M0@<0G`8406H3
0`1U4@T2003o00Wooooo00<0P<000?n0003oP000803oP0000`3@D7P0^3Rd0>QX?00:0?n000030>QX
?03@D7P0d51h0080d51h00<0oh000>QX?03oP0007P3oP002003o00Sooooo2@00o`00C01Q?Rl06ALd
05a?GP19>TP0JU9H06e>EP1cDE`0NEMQ08QOJ`2@Hg00UVQd09I/M@2JL7L0Ufad09I/LP2LM7H0VWUh
09f2OP2FPWd0Vi2909B;Q@2FTH`0X9jI0:2MV@2EU900VYnL092DU`2IX:@0Ri>J096KWP2g_l80]kc1
0;Nn`P34b<h0bLoF0=3Jh02mal`0`lkC0<;?eP2P]/L0Xk[>08BSb01[SKL0PI2W0:bT[@2f[k@0^[fo
0<[CeP3;fMd0bM[O0<SHh@2;XkX0XKgA065lU@0b>VT0MQHb09413`2@0P`0RCTo08N9R`1mRHX0OH^<
07b9S@1cQ8H0M8>707B2Q@1ePX@0LH24071oQ01UNg`0GgAc05ibKP1LKfh0;dE9051VI`13MCh4003o
00Sooooo2@00o`000`3@D7P0X23`0:0Pl00O0:0Pl0030;Ph]03@D7P0X23`00<0^3Rd102P8?000`2h
>;@0d51h0;Ph]0080:0Pl0040>QX?03oP000oh000>QX?140X23`1000o`0;ooooo`002_ooool0600Z
f0T0IbdI01h;200Y0@40C@8304/00P1@0P<0D@<504X10P1U6Ah0X4aI09a8E@1C0@<0N@8:08X23P2>
0Pd0R`4<08X1202<00T0S`8909/21`2c1@l0]@D@0;D54@80]`H@03`0^0LA0;<43@2]0PT0/PH=0;04
3@2g2A40^0T@0;d;4@2n41X0[Q@S09PG;`2XAEh0^V1f0;eJL02nCV@0]d5E0;HhCP2e=4`0/Bi70;4^
A02`;3l0[RXm0:PW?P2V9cl0Z2a20:L`A@2X<TP0Z2]20:/A8P2f2140]PD?0:l3302]0`/0YP490:H2
302S0@d0WP8=09`13@2K0@/0W04;09d22`2K0@X0V@4909X11`2L0@T0WP<;0:423@2S0Pd0X`4=0:P6
402X10l0Y0<<08h22@290`X0N04407@3201_0@H0H`8506020`1Z5a02003o00Wooooo00<0P<000?n0
003oP000D`3oP002003o00Sooooo2@00o`00C00lIQ/071`e05I;F@0G63P0<R]406U=EP1aC5T0NE=O
08AHI02<H6X0T69]09AXL`2ILGT0V6md09AXKP2KLW@0WG]m09b4O`2KQh00VH^40967P@2ARh@0Ui6=
09bHU02EUY<0VYnN08>9R`24RX`0QhjC09BLX02l_l<0^;k20;Nn`P34bll0^/;80;g8c@3Bfn80_l[B
0;C4c`2lc]X0UKGC076F_`0lJIX0b=o/0<gLj03@g>H0cm[S0<_Ki02gbmh0[<KM0<G=h01eNY`0GF^:
0:^mb@1MLY<0DbU?08`4502B0@/0Q0hG095nP01oRh`0O8b<07Z9S01jQh/0MXB807>1Q@1bP8<0LX64
0720P`1ZOh80HgMi05ebLP1IKW00>U9I03MAFP1GG5H4003o00Sooooo2@00o`000`3@D7P0X23`0:0P
l00Q0:0Pl0030=1@N02P8?00X23`00D0X23`00<0d51h0>QX?02h>;@0202P8?00102h>;@0oh000?n0
003oP00A0:0Pl0@00?l02oooool000[ooooo05H0:mT:06L^5P0K1`D0=@<304d10@1<0@<0C04204P1
0P1D0@<0KP<807`43`1n0a00KP<907L22`290Pd0R`8=08/22`2<0@X0R`4908l11`2P0PP0/`H<0;@4
3`2g1@l0^@D@0;T53`2f1`h0/`H<0;07302`1Ph0/@D?0;P94@2n3aL0`@`C0<<=5P313QH0`A0I0<0B
7`345b<0bAHQ0<hE8@3=5Al0cQDO0=4F7`3@51l0cQ<M0<dB6`3:4QX0aA0I0<<<6@343AX0`@`H0;h;
5P2n2QL0_PLD0;/4402f10h0[@<=0:P23@2V0`d0Y08<0:<1302O0@`0W@8>09/23P2J0P`0W04909/1
202H0PP0W0<:09/12@2M0P/0X@8<0:82302S0P`0Z@H?0:L43`2S0`d0V@8:094220230PL0M@450782
1@1Z0PD0H`8306XB30800?l02Oooool00`20`000oh000?n0001C0?n000800?l02?ooool9003o001=
04M/6P0/:3l0C49E0084;00P6cX0IdaD06m>E01eDEX0P5AP08YKI`2<H6`0TVMb09A[MP2FK7H0UFM`
09YcMP2NO7h0WXJ209j=Q`2IRXH0UH^70929Q02?RHD0SH^6096AS@2>U9<0R8j@08>7R@2EVYd0YJf_
0;_0``2l`<H0_LG80<79c03<eMX0`<WB0;g9d@36dMP0[L?G09bgdP1JPJh0TkWI0;3>i@1mVL40N6JA
09]GN02RI880]9B^0:VO`00e>6X0JBQ>07PC;@1c:Sd0X:>]07V=Y00f=V80Na0V09@23@2D1100T5AH
08>;R01lS8`0NXV<07V:R`1gR8/0MHB507:2P`1_PH80KX6106b1P01WOG`0GGEc05U^KP1CJ6/0:4=;
05eWI@0Ac0X00`00o`08ooooo`T00?l000<0oh000:0Pl02P8?007`2P8?00103@D7P0X23`0:0Pl02h
>;@70:0Pl0<0d51h0P2P8?000`2h>;@0oh000>QX?0030:0Pl0040>QX?03oP000oh000=1@N100X23`
00@0J:Pl003o0000o`000?l02oooool000[ooooo05H0:]T:07E08`0E10<0?0<304l20P1:0@80C082
04H10`1U0`@0M`85080120250@/0MP<906d22@250Ph0R04<08X22P2>0@X0S`4809@1202V10/0/P<<
0;D53P2f1@l0^0D@0;H4402e10l0]@D@0:l33@2^0Ph0/@@<0;P84`2n3QP0``hG0<<>50303Q<0_PhF
0<<?603:4AP0b0lE0<dC6@3@4aL0ca4D0=@C603E4QP0dPlF0=8@5P3@3QH0c`hF0<X:4P382A80a0T@
0<8940312140^`D?0;T5402d10h0[@<>0:L23`2R0@l0Y0<@0:H23@2Q0@d0V`4<09X23@2J0P`0V`8:
09T12@2F0PX0U08909D12P2K0P`0WP8:0:823@2S0P`0X`T?0:@N7@2P7B00U`D=09L1202=0@P0O087
06`1101V0@@0J@8406L910800?l02Oooool00`20`000oh000?n0001C0?n000800?l02?ooool9003o
001=03>P4P16>DH0?S=:0043:P0N63D0J4eB06e>E01dDe`0OEEO08AHH`2:GfT0SF9/09EYL`2GJW<0
UFM`09mfN`2NNgh0W8>109R6P`2NUI40c/g<09ZGUP2;QH80RHB1092<RP2HV9H0QhJ808V8R`2EVI`0
XZ^]0;W2``2oa<L0bm7D0<37cP3<eMX0d]_Q0<OAf@2_`<h0Zkk@0:C4h`1iV/806d^509fngP0oCX<0
QQPd09d9702E3B00Oa`b06lK>@1e8T<0S24i08d54`221Q<0XWn909>Q[@0b@fT0HbQ60903402E0Ph0
RR0/09R2QP1oRH`0Nh^>07N9R`1gR8T0M8>407:2Q01`PhD0KX:30724P`1^PH00IWai05ibL@1HJf/0
=E5G059XJ@0SWaP00`00o`08ooooo`T00?l000<0P<000:0Pl02P8?004@2P8?000`3@D7P0X23`0:0P
l0090:0Pl0030;Ph]02P8?00^3Rd0080d51h1`2P8?000`3XJ3`0oh000?n000020?n000050=1@N03o
P000oh000?n0003@D7P00P2P8?00103@D7P0oh000?n0003oP00@0:0Pl004052@N000o`000?l0003o
00_ooooo000:ooooo`1F02_J2P1[>1T070<104/4101B0P80B`4204@20P0k0@80I@@507P11P200PP0
N`8:06021P1W0PT0Q08?08L13`2=0Ph0T04909<12@2D0@L0Y0890;<53P2e1@d0]0D=0;L63`2e10l0
]@<?0;843P2]0P`0[P8=0;843`2f1a40^@TC0;l>5@333AH0`@hG0;`<5P3241L0a@hD0<T@5@3?4QL0
dQ4G0=0@503B41D0da4F0=@@5@3C41H0dPlG0<l=5@3<3180b0XA0<L;4P342@l0`@P@0;`63`2j10l0
^@H>0;042`2U0`d0X@8=0:02302Q0P`0WP4:09`12P2K0@/0W04<09/13@2G0@X0T`490981202E0@X0
V`8;09/12P2L0PX0XPH>0:Hi>P3S];<0_7f609hh@02=4aP0Q@T?0801201h0@H0KP4406D10P1`50l2
003o00Wooooo00<0P<000?n0003oP000BP3oP0000`3XJ3`0oh000?n000060?n000800?l02?ooool9
003o001=04N^601H@T@0<2Q000<59`0Q6c<0IdeA06]?E01cEU`0N5AL081EH@27FVL0RUiX091UKP2G
JG<0TfE/09]aMP2POGh0WXF209b9Q02VWY`0e=GL09REV028Ogd0QGik08b:Q`2ATI00U9:B08V9S02;
T9D0VjBV0;Vn`P31al`0a<_>0=KLh039d]L0^/WB0<7;e038en<0_mO[02YISP1PR:h0T;3>0:Bme`0m
Ag/0RaH^0:8>7P2=4Qd0[HJ=06M@IP1G9TH0MP`W08l65@2A1180QCI40;o3bP1NKHP0@b]B08H55P2C
0@`0QPHD09YVKP24R8/0NhZ=07V8RP1gR8/0MHF807F3Q@1cPX<0Lh>40723PP1^PX80KH20069eM`1H
KFl093e604iWJ00_SbH00`00o`08ooooo`T00?l000<0P<000=1@N02P8?004@2P8?000`3oP000X23`
0:0Pl00:0:0Pl0050?n0002P8?00X23`0:0Pl03@D7P01P2P8?030?n000030=1@N02P8?00X23`00<0
oh0000@0d51h0:0Pl02P8?00X23`0`3oP00A0:0Pl0<00?l02oooool000[ooooo05P0:mX:06Xe500N
0P00B@8305010P180@80?@8202P10@1@0`<0J`<606h42P1K0@L0@P0206P32P210@`0Q`4>08d13`2>
0@X0TP0709L01`2W0`/0/`@>0;82302c1@d0]0D?0;@43P2d1Pd0[`<=0:d3302^0Ph0/P@?0;@6402d
1Pl0_0`C0<8>5`2n3QP0_@lI0;l>4`363Q<0c18E0=0B5@3D4AL0e14E0=DB603B4AL0da@H0<hA603;
51T0cA@H0</@5@362a<0a@XB0<<83P332A40_@H=0;/43`2j1@l0/0@<0:L23P2P0@d0W00809/02P2K
00P0W08:09/12@2M0Pd0VP4:09@11`2B0@P0T`4809L12P2L0P/0V`8809/12P2O1Ph0[e]Q0=fkaP25
9SP0YDI@0=BIVP2ZHFD0N0H;07X11@1g0@@0K08306h?2`0/QP000?l02Oooool00`20`000oh000?n0
001D0?n00003003o0?oooooooooo00Kooooo2@00o`00C@0Tf0h0N5aG01hH;@0/9c`0:b4b06U>D@1/
CUD0L51H07UCG@21E640REUU08]NJ@2AIVh0UFQa09AXL@2KLgP0WgYk09n7PP2MRhP0UXV80:6HW027
OG/0R7mi08AmN@29R8@0TY6?08j@T@24Qh`0R92D0:B[[P2j_l<0_lO:0<SAe03Afmd0`/c@0;S5b`3B
h>X0W;;:06jG^P22Y<H0QJkA0;?<g@32e>L0<dEm08DW@`2S3R00RA4P0=?4bP3<e^40SiF^04LWCP1n
3B40T@<B08<E8P2aZ:h0NXZK034`F@1l5BT0U08<08d34020:S80Rh6407^:S@1gQhT0LhF80764Q01g
QHH0M8>507B5Q`1bQH@0Kh:406n3P`1SN7/0FVe^04YPH@1=HV40=hP_00<00?l02?ooool9003o0003
0830002h>;@0X23`01`0X23`0P2h>;@0103@D7P0X23`0:0Pl03XJ3`50:0Pl0030=1@N02P8?00j6Pl
0080oh0000@0j6Pl0:0Pl02P8?00^3Rd0`3oP0030:0Pl0040>QX?03oP000oh000?n00100X23`0`00
o`0;ooooo`002_ooool0A`0/fPX0Fb<302410@1:0P<0C04204<10@0m0P<07P4102h10@120`@0A089
03L11@110@@0M@<=08813@270@h0S08>08h12`2C0@T0V`490:/3302a0P/0]@D>0;843P2`0`/0/`@<
0;@5302a10h0[`8=0:d23@2`10h0/@@>0;86402h3AD0^P/D0;P;502h3AD0_@dD0<@>5@3941D0dA4G
0=<C603>51L0aAHK0;4J7P2U:2X0/4Y:0<ecK`39If40`DU80;HQ90333Q@0a0T@0<473`2n1@h0^`@?
0;L33P2a10d0YP8<0:81302P0@X0VP4:09/12P2L0PT0V`8909`22P2I0@T0U@4909D1202G0@P0V089
0080V@4900l0WP4:0:053@2`FV00g;Bm08PJ9`2I;cL0gK6i08E?E`2GDU@0KA4D07D41`1a0@<0JPT5
02n70@00o`002Oooool00`20`000oh000?n0001=0?n00080j6Pl1@3oP0000`00o`3oooooooooo`06
ooooo`T00?l004d08>D<07MIBP0@2a`0Cd9803/Z=01/Ce@0KE1E06e>EP1eD5/0OeEP08=EH@28FFH0
Sf=]09=WK@2FJg80VW5f09ihN@2NPWl0WXZ909F5PP2>P7/0RGee08MmMP27OGX0Qh20092?S@28RH`0
QhR?08bBUP2KXZD0`/[=0<36bP34cM80bM;H0<oMh@2jb]40V:o10;g@gP2?]=@0LI[802=?R@2bcN00
dMoZ055ZVP1]@VP0VPdO094:7@2]P8d0cm[P0<cJi01JJY00IR]@09445P2?1AH0Sf5Y0;_7c`0nBVd0
H2e=08/3402C0@`0Q@H@08mOI01kQhX0MhN;07B6RP1bQHT0L8:606j2Q01_PX@0KX6307>4Q`1`QXD0
Jgj1069dM@1KL6l0Ffi/04iNAP03003o00Sooooo2@00o`000`20`000d51h0:0Pl00K0:0Pl0050;Ph
]02P8?00X23`0;Ph]03XJ3`00P2P8?00202h>;@0X23`0:0Pl02P8?00^3Rd0?n0002P8?00^3Rd0P3o
P0020=1@N080X23`00@0d51h0?n0003oP000d51h0P2P8?001@2h>;@0oh000?n0003oP000d51h00l0
X23`0`00o`0;ooooo`002_ooool0A`0]g0/0FRL702D10@1?0`80CP4204P10P180P<0:P8204Xb=02i
YZT0<10G03T11P1S0`/0O08<0801302400/0R`8;08`12@2B0@X0V@090:h3302d0`/0]PH@0;H74@2b
10d0]@D>0;H53P2c0`h0/@8=0:l33P2]0`h0/PLA0;D:4P2f2a@0]`XC0;T<502l31H0`PlJ0<TA7039
4aT0`AHL0:@M802F>3T0[WEf0=2f]P3SfMP0hn3R0>CSi03Uh^40i=_J0=Zi^02cAdX0]a4I0;l94P2n
1a00_0DA0;L23P2a0Pd0Z08=0:812`2N0@X0V04:09P12`2J0@/0VP4:09h2302M0@X0V`4:09P1202E
0@L0U@480080UP4800l0V@8;0:033`2S=d80j[S108dR;P2@5R00hZN`07HoB@2jWJ40OEeO0:1ZK@1^
41@0KPd:02j70@00o`002Oooool00`20`000oh000?n000050?n000030=1@N02P8?00j6Pl04D0oh00
00@0j6Pl0;Ph]02P8?00d51h0`3oP0000`00o`3oooooooooo`06ooooo`X00?l004d0MUI101L?6`1D
@dD0BC<j06a=DP1]CE@0LDiF07IBF`1mEf40PEQS08=HH`2<HVX0TFM`095XK@2HKg80WgQk09IhMP2L
Qh<0VHN309:5O`2:P7T0RGii08V0O025Ogd0SXb<08R9S02:Si<0T9NJ0:2[[@2]]k`0`/[>0<_Bf035
cmH0^/cC0<_Mh`2ibm`0LiNn07:D^P1mZMD0Z<?G0=;Pj03CgnP0X[OB04A<O`2;6c40W@TJ08<P<03A
`LX0cmSP0:bkdP0k<FH0Q0`V09@24`248S40W9bS07Z:W`0j<UT0O0/L09<12`2A0``0R2lf08R8R@1l
R8d0MhR;07B7RP1bQHT0Kh>607:4Q@1_PHD0LH>806j4Q01aQ8D0IgYl06AgMP1TN7L0FV5M00Cb0P02
003o00Sooooo2P00o`000`3@D7P0X23`0:0Pl00K0:0Pl0050;Ph]03@D7P0X23`0;Ph]03@D7P01@2P
8?020?n000050=1@N02P8?00j6Pl0?n0003XJ3`00P3@D7P01@2h>;@0X23`0?n0003oP000j6Pl00<0
X23`0`3oP0000`3XJ3`0X23`0:0Pl00=0:0Pl00302S8?000o`000?l000_ooooo000:ooooo`1H02cL
301A80<0:04105420P1:0@40B00104`10P1=3100:@PA03lU=`1<5R40H`D<07D22P1n0@/0O`4:08@0
2`2:0@`0S@4:09812`2I00X0/0@?0;<33P2f2140/PD=0;843@2e1Pd0/P@<0;833@2^0P/0[@<;0:/2
2P2`1Pl0]PXB0;P<4`2h31D0_Q0J0<<@6@3441X0`10I0;8J7P23:BP0_inK0>7Ie@3Thn80i>CU0>;S
iP3Ri>H0hN?V0>?SiP3PhN<0gmkO0=>d/`2H:bl0^0dE0;l64@2j0P`0]P8=0;823`2Y0Pd0X`8:09d2
2`2G0@/0U00909X0302L0@`0V`4:09P1202I0@X0UP4709@1202F0@X0U04909D12@2G0@`0X@<>09LA
703TWjP0Vca808l:5P2fHfl0RU=L0;NPYP2iYZ`0XXR?09AFG@1[3PX0;XH0003o00Wooooo00<0P<00
0?n0003oP0001P3oP0000`2P8?00oh000?n0000M0?n000030=1@N03oP000oh0002@0oh0000D0d51h
0:0Pl02P8?00X23`0=1@N0020?n00003003o0?oooooooooo00Kooooo2P00o`00C@1>IbP09Q`S04`g
=`1K?d80K4]>06e=DP1aD5L0M5AL07UEG01nF640LdmJ08EKIP2?I6h0SV=Z09A/KP2IMGL0UgQj09b6
Q02HQhD0V8b60927PP2>QH00QX5k08F2PP27QX@0QhZ?08RAU`2AV9/0YK:d0;6k_`2j`lT0^l;90=CM
h`2Z_L/0MI:Z0;G:g026YLP0QjgD029CSP27ZlT0d^3Y0=?Oj03@gn/0@5b:0856I02I3Ad0U0dM0910
DP3Ec=L0b]SV04eNR`1_:Dd0UP<D08/6502GLW`0UJBa0350I`1a:D@0U0<@09L13@272Q<0T7Mj07b9
R`1fR8X0L8>407:3QP1aPhH0KX6206n2P`1`Q8L0KhB40725P`1WOg`0HgQf06R0OP1VMG403l`90080
0?l02?ooool:003o00030>QX?02P8?00X23`01T0X23`00D0^3Rd0:0Pl02h>;@0X23`0?n000070:0P
l080oh0000<0j6Pl0:0Pl03@D7P00P3oP0001@3@D7P0j6Pl0:0Pl02P8?00d51h0080oh0000@0^3Rd
0:0Pl02P8?00d51h0`3oP0000`2h>;@0X23`0:0Pl00<0:0Pl003052@N000o`000?l000_ooooo000:
ooooo`1H02gM3@1K:``0;`4205D20`1;0@40B@4204h10P1N2A00KbPe070[?01d4R00L`4:07L1201m
0@/0O`4908H1302<0Ph0T04:09<12`2K0@/0/@D?0;@43P2d1Pl0]0L@0;<43P2d1Pl0]PP@0;863@2/
0PX0[0<;0:/32`2b1a40]0TB0;@:4@2j3QD0^Q<I0;@H6P2O92D0W4E10:amMP3Fal80i>?R0>?Sh`3S
i>H0i>?X0>GUj@3RhnH0h^CV0>?TiP3PhN@0h>3R0>7Lg031TY@0Ya`U0;h74@2l10d0^0<>0;42302Z
0``0YP8<0:023@2L0@/0V`4=09`13@2M0@d0V@4:09L11`2K0PT0UP8709411P2D0PT0T`4:09<12@2E
0@X0X08=09h74P2J:CD0^F5[0:Q7C@1f5b80XE9P0:9hQ02XRI<0Ug5i06lY<P1V1P@0<HL2003o00Wo
oooo00<0P<000?n0003oP0001@3oP0020=1@N1h0oh0000<0j6Pl0?n0003oP0009@3oP000103XJ3`0
^3Rd0:0Pl02P8?030?n00003003o0?oooooooooo00Kooooo2P00o`00C@1<MBD0=BLX04<`;P1QBd`0
IdY=06]<D@1_CeH0Me1N07UAG@1jDel0L4iJ089HH`2?HFX0SemW09=XJ`2LMgL0UGUh09N3P02EQH00
Uhj809J=R02>Ph00SHN408j7R022PH<0Gfmo07f:U@2^]kX0UInV0:fg_@2la/P0a]3F0;?3bP34e=`0
/<KH09:bd01YS;D0EX:f09Zid`3:h>P0e>3X0=?Pj03AgnH0SZ?004i;N@233R@0V0PH08X;7@2`PXh0
bmKP09jac011=6<0P`TN09423P23<Cd0[;Bk07:4WP1:<UP0Q`LJ09<1402=0`h0RdaC07f7RP1gRX/0
M8N807F7R01cQ8L0LHF50764Q@1^PHD0Kh>406n4P`1YOgh0HgYh06R0OP1`PX007j`G00800?l02?oo
ool:003o00030?n0002P8?00X23`01/0X23`0P2h>;@00`2P8?00^3Rd0:0Pl0040:0Pl0060>QX?03o
P000oh000?n0002h>;@0X23`0`3oP000103XJ3`0^3Rd0:0Pl02P8?020?n000040>QX?02P8?00X23`
0:0Pl0<0oh0000<0d51h0:0Pl02P8?00302P8?000`1@T7P00?l0003o000;ooooo`002_ooool0F00^
gPl0DQl703T20@1D0P<0B@4104/10P1A0@80GP8306811@1Z0@P0N@8907H01`1f0@T0NP8807d12@26
0@d0SP8<09@12`2J0@`0WP490;053P2d10h0/@<<0;03302a0``0]@D@0;D7402^10/0X@<;09HB5@2L
8R40XQ/L0:4K6`2N8b80XCdi0:]PF02kU8X0f/o:0>;RgP3Ri><0h^CV0>7Qi@3Qfn40hMCL0>33d03=
YK<0SgZ90=3FfP3Pi>H0h>?V0>3Qi@3Oh><0gm?F0:Q>E@2j2A<0_0D>0;T33P2_0P`0Y`4<0:H13`2Q
0@`0W@8909`12`2L0@T0WP8;09d12`2L0@X0V`8:09T22P2F0@L0U@4909<12@2B0PP0U04909d1302R
0`d0X@PB09T@7P2U=DD0Q`/H08P44P2A>dH0TVM`09a]M`1i>Cl0J``:03mZ1000o`09ooooo`030830
003oP000oh0002/0oh0000<0X23`0>QX?03oP000103oP0000`3XJ3`0oh000?n0000I0?n000040>QX
?02P8?00X23`0>QX?080oh0000<00?l0ooooooooool01_ooool:003o001=03JA4P17<R/0Echh04Hb
>@1>=Sl0JTeB06i?E@1bD5X0N5AN099^M`21FF@0PeMQ08iRJ`2?Hfd0TV]a09]hN`2JNg`0TGQf09B4
O02KU8`0Ui2=08V0OP2;QX<0RXF407=kQ`1DJH40TIZP09jVZ@2RZJd0`/cB0:Rb^@33dMD0]LSC09jg
b@2bb]d0I8V_0:K<k@17L:T0EGb[0=3QjP3BgnL0dmoW0=;NiP3;g>T0<dYj07D`CP2@11@0V0LD090Y
>@3DcML0YK;504]@NP1j9Sl0T@8?080:5P2;MWd0YK?003DnIP1g6S80S`4?08l2301n6bD0Qh>507R:
SP1gRX`0MXR907F7RP1bQ8L0L8:40724Q@1bPX<0K7n006QmO@1ZO7d0Ig]m07J6R@0_WBT00P00o`08
ooooo`X00?l000<0`:000=1@N02P8?006@2P8?00102h>;@0d51h0:0Pl02h>;@70:0Pl0070=1@N03o
P000oh000?n0003@D7P0X23`0=1@N0020?n00080j6Pl00<0^3Rd0:0Pl03@D7P00P3oP0030:0Pl004
0>QX?03oP000oh000?n000h0X23`00<0N5Rd003o0000o`002oooool000[ooooo00@0;n0@04dL1`0f
0@40D`410P1>0@404@1@0040FP4105l00@1Z0@H0N04:07@01`1i0@X0NP4807X02@250@`0S`4<09T1
2`2M0@T0WP8:0:X22P2b10`0[`4:0080/@<=02X0/P8<0;<43P2Z0PX0V0D:05D<3@2`UYH0ekB]0=Nb
ZP3QaKd0j=cF0>GPgP3Thn40h>CU0>7Tj03Ph>H0f<oH0>2nc@3GTZD0`eaa0;H^A02e7Rl0La8O09fL
X@3QiNH0h>3T0=oOhP3NhN80gn7P0;EnP`2a3AL0^0<<0;L43P2`0Ph0Z`8A0:H13@2R0@/0W04809/1
202J0@P0W04909h2302K00X209P12@0C09L1202F0@X0U04809L21`2J00P0WP4<0:44402L10d0U`@>
09033`2B0@`0T04:09Pf?`2XJgP0N2ln09=IH01V3@/0HA87003o0009ooooo`030830003oP000oh00
01/0oh0000<0d51h0?n0003oP0003P3oP0000`3@D7P0oh000?n0000P0?n000030:0Pl03oP000d51h
0080oh0000<00?l0ooooooooool01_ooool:003o001=03NP3@1H>bh0Jdi104Xd=`1>>d40JdiC06e>
E01`CUH0S7Z10<W0aP2@LH40QUMY08YPJ`2>I6h0TF]c09]eO02?K700SW9`09F3O`2HS8P0UHb:08^5
P@2:QH40RhR903e=J`1^Oi00Xj^_0:B]/P2`^L00Xjjf0<WDg02HYk<0]LK@09nkc`2`cnD0P:3101]:
Q`1gW<@0SZk;0=;Qj03AgnH0dmoW0=;Ni@3>gND0P9Jc04<jI@1k3240U@LE08l65`2H?5<0RcaM08T`
D02=62`0T@HA08L8502DKGH0U:6/055SPP1O<e@0Q@DF09413@2510l0S6AW07b;S@1jS8h0MhR=07R7
S@1fQ8L0LhB606n2P`1^PX<0KH:106]nO@1YOGd0JGf007N:S00oPSd00P00o`08ooooo`X00?l000<0
P<000?n0003@D7P05`2P8?001@2h>;@0X23`0;Ph]02P8?00d51h00P0X23`103oP0030:0Pl0<0oh00
00<0j6Pl0=1@N03@D7P00`3oP000103@D7P0X23`0:0Pl02h>;@30?n000030;Ph]02P8?00X23`00`0
X23`0P00o`0;ooooo`002_ooool0AP0Tj0`0Ca/603`20@1G0P80D@4104`10`1A0@80G@8106H2101^
0PH0MP4707D1201g00X0O@8;07l1202:0P/0U@<=09/12`2P0@/0WP4:0:L32P2_0``0[`4;0;023@2`
0`/0[0860:l32P2]0`/0YP<;0805301R;3X0YI:Q0<Vob@3Cc=<0f=GI0=gFg@3IcmL0flC@0=J/_03=
RYh0ae]`0<4^@`366Rd0cA<S0<d=603?3aD0Y14G071NHP3PhnH0h>7U0>3Qi03MhN80g>7Q0<FVZP2W
4Qd0^0H>0;D4302a0Pd0Z`8<0:D12P2S0Ph0W@4;09/1202L0@T0W@4<09h22P2L0@X0VP8:09P22@2H
0@X209D12@0@09L1202I0@P0W@4<09h23@2E0P/0R`<;07h12@260PX0R089080<5P2F9cH0N`DB08H/
=@1V20L0Ha87003o00Wooooo00<0P<000?n0003oP0006`3oP0001@3@D7P0^3Rd0=1@N03@D7P0j6Pl
00`0oh0000<0^3Rd0?n0003oP0000`3oP0000`3XJ3`0oh000?n0000O0?n00003003o0?oooooooooo
00Kooooo2P00o`00C@0Hb`<0HD0a06a<?`19<C<0;R@_06Q=D01ZBDh0KTaD07]PK02PR9P0PE]^08MH
IP29GVl0R65/08eXK`2HLGH0TF]]09=hMP2FQ8D0VXj=09F;Q`2?Qh00RhR307^3T`0]B6h0W:J^09VQ
Z@2V[[L0_<K>09ZX/`2U];d0Z;S10:c2d@1TPZ@09e:509^oh@1[T[l0AWJ^0:71eP3ChNP0eN3X0=;P
j03Bg^H0dMkV0<gJi@1hRZD0JE=W08E7C`28@DL0S4Y@095GH@1mCUd0TFAX08URIP2@KW80XJ:Y09^X
/P2P/<@0?SUP074B;02>0a80SP8<08<b>P21R8T0O8^>07R9S@1iRY00N8V<07>6RP1`Q8D0KhB50762
Q@1`P840K82006YoOP1`Q8D0EEQC00800?l02?ooool:003o00030830003XJ3`0oh0001T0X23`00<0
^3Rd0:0Pl02h>;@00P2h>;@60:0Pl0D0oh0000<0d51h0:0Pl02h>;@0203@D7P40:0Pl0<0oh0000<0
j6Pl0:0Pl02P8?00302P8?02003o00_ooooo000:ooooo`1H00ch101>6@D0A@8205d20`1F0@40C`42
05@20P1Q0P<0I@4306/1101i0@H0N@4707/22@1o0P/0Q@4:08d2302E0@/0W@8;09h22P2I0@T0XP8:
0:l2302_10`0[`<;0:`22`2[0PT0[0<70:`22P2Z0PT0[@<<0:D84P2D2a`0UQ/^09`W?@2iAU`0`DIL
0<8nD`2m8S@0`QHV0</C8P3A4a`0da4I0=<A5`3B3QH0c``A0=4>40344QL0FB0V0=CGf`3PhnH0h>7U
0=kPh`3Lg^40f<g@09dY<`2c1100]P<>0;42302Z0@T0Y@490:02302M0@/0V`8909`12P2M0@/0W`8<
09h23@2H0PT0UP4909P22`2C0@T0T`8909D1202G0@P0V@4809l13@2J0Pd0R`<:07d220200`/0L@86
06<21@1m0PT0Q0<:07D2101Y0P40H@/3003o00Wooooo00<0@>000?n0003oP0007`3oP0000`3XJ3`0
oh000?n0000:0?n00080d51h9P3oP0000`00o`3oooooooooo`06ooooo`X00?l004D09]L;05lm9P1/
C3d0IdQ503HW<@1VC4h0IdM<06Y6D@1`Ae<0Ne1M07mCG`20EV@0K51O061>FP23IF`0V6me09A]K`2C
MWH0Sgel09V<R@2GShX0UHf;09:?T`0kDG/0FW>C09jVZ@2MY:T0/ko708^GX@32cmH0XK:l0:nnb`1l
Ujh0^=7X07jK_`0kIJ40HXjo04=cZ`37hO00d^3X0=7Pi`3AgnH0d]oW0=3Ni@3Ag>D0b]_R0<SJg`3=
em/0cMGG0<[GfP35dm/0FGBC08:K]01LLh`0]<SE08NJZ@2HZKD0TZ:^051NP@1U>f00QPPM09<13@21
3AH0SGao07f>T@1kSXl0N8Z:07V<SP1cQXT00P1eQhT0201bQHH0KX:206b2P@1`QXL0M8N:069WI@08
i@@00?l02?ooool:003o00040830003oP000oh000;Ph]1L0X23`00<0^3Rd0:0Pl02h>;@0202P8?00
0`2h>;@0oh000?n000030?n000040>QX?02P8?00X23`0=1@N0`0X23`0`3oP00>0:0Pl003043P0000
o`3ooooo00[ooooo000:ooooo`0L003o001?6@@0D@@406<20P1H0@40E@4205410@1O0@@0I@4306T1
101i0PP0N04707/12@240@`0Q`4<0902402F0@h0VP8:09X12P2C00T0V`8;0:X22P2_1@/0[`D<0:/3
2@2W0@L0Z0480:T12@80Z08903X0[0@;0;H;4P2i3aH0_18I0<4F7@3161`0`QLJ0</E6@3<4QT0_a<F
0;lY:032;c40a3<e0<Lg=P3<<C40bQ@I0<`=501`2`l0ZZV]0>7Qi@3Pgn@0gmkS0=cMhP3Mfmh0X5AL
0:`;5P2d10h0/@8=0:/1302W0P/0X@4=09d22`2L0PT0V`4809X12P2C0``0P@8908`H7P241@/0TP8:
09@11`2C0@T0TP4809@11`2I0@P0W@8<09d22`2K0``0S`@<08H32@200PL0K08506P21P1Z0P@0J`42
06H20@1S3@D00?l02Oooool00`00o`00oh000?n0000]0?n000030;Ph]03oP000oh0000<0oh0000<0
d51h0?n0003oP0007P3oP0000`00o`3oooooooooo`06ooooo`/00?l002H0ISlM06m??P1R@C/0?RH[
06Q9B`1[Ad`0Jd==0759E01iCU/0OE=O06Y=F@1fG6P0Je]V06QFH`2?J780RVI_08A/L`2EQH@0UXb7
09F>R@2GTXh0QHbL00l^J02FZ;P0[KBg0:>]]02S[kL0]/;:09n^^@2U/kd0/l?A08NN_P0nJiX0/MSd
06F>^@1/W<h0Dh2Z0<_Qk080dn7X02H0dmoW0=;Oi`3?gnH0b=c[0<kJi@3Ben<0dM3N0<g:f`38`]D0
a;O=07=US`1YFX80VX2K095cR`2IO9@0/Y2Y09QdS@22H7l0KSaN08/C:P2G0Pl0S`<@099@F@2<RHh0
QH^A082>S`1mSi40MHR;07N;R`1fRX/0LXN906f4Q01ZPX80KH2307J8R`1ULg805L8>003o00Sooooo
2`00o`020?n000030>QX?02P8?00X23`01H0X23`00@0^3Rd0:0Pl02h>;@0^3Rd1P2P8?000`2h>;@0
oh000?n000020?n000030=1@N02P8?00^3Rd0080d51h00<0^3Rd0:0Pl02P8?001@2P8?00102h>;@0
X23`0:0Pl02P8?030?n000030=1@N02P8?00X23`00/0X23`00<0D91h003o0?ooool02_ooool000[o
oooo05P00?l0058F101O10@0HP4105X1001H0@00EP0206421@1V0P@0J`0407l12@260@X0Q04:08D2
2P280@T0T04=09T23P2K0P/0U04909412@2E0@/0YP8:0:h72P2_10/0ZP490:H01P2V0@D0YP470:L1
2@2Z0`X0[@@<0;H=5@2_5AX0Va`L0;=ED02nKfP0]f1L0:db<P2a7R40M0`<0=J`ZP3P`K`0hl?10>K7
`P3X[J`0[R0Y0<`?6@2E3aD0OW=h0=kNh`3Ogn<0g]oS0=cPh`3Kg^00[7f30:0B6`2b0`h0/P4=0:h1
2`2Y0@X0XP4=09d12P2M0@T0V`4909H22P1m0PH0MP4809HM:02>6b40SP<;09D2202D0@P0T@0609<1
202G0@T0W@8<09`12P2J1@d0U`D>09P32`210PH0NP<707811@1U0@<0G04206D20P1U40L00?l02Ooo
ool00`00o`00oh000?n0000]0?n000030:0Pl03oP000oh0000<0oh0000<0d51h0?n0003oP0007P3o
P0000`00o`3oooooooooo`06ooooo`/00?l004h0IEdJ06m>?01/Bcd0JDDm06Y9A01XAdT0JdE=075;
E01jDE`0NeAN05e8D`1bGVT0He]U05mCGP2:IVl0RFU`08I^M02EP8<0UhZ809N?RP2CTI40AUV102m?
Q02U/;L0ZJnc0<C=d`2JYZl0]L780:Rf`@2__/X0J8>J0<3Gk@1aV<<0EXJj06NC``0LDY/0[mC_0=;Q
j@3EhNT0eN3X0=?Oi@3BgnD0bmcX03mQTP20J8l0TSIG08hUA@2<7CX0QaDb08PB;`263BT0Q`/R08/:
8@2:2B00RPTR08/98@2<2Al0R`TL08d96P2C1QL0T@@@09043`2:2AL0R1X/08@X>P25GfH0OXf?07R<
S`1hRhd0MXZ=07F:S01_Q8D0LHB40764QP1bQhT0Kh2102FR7P00o`08ooooo`/00?l00`3oP0000`3X
J3`0X23`0:0Pl00C0:0Pl0050;Ph]02P8?00^3Rd0:0Pl02h>;@01`2P8?050?n000030=1@N02P8?00
X23`0080d51h4@3oP0000`3XJ3`0^3Rd0:0Pl0090:0Pl003052@N000o`3ooooo00[ooooo000:oooo
o`1H003o001D50<0HP@206<20P1K0P80D`4005T10P1R0P@0IP4307011@220PT0R@4=08D130210@T0
R`8=08l12P2I0``0VP4:09@1202A0@L0TP480:D3202Z1@H0[@H;0:`32P2Y0@P0Y`480:X22@2/0@X0
[0@<0;87402E31D0FaPI0:V9Q03LdL`0gm[E0=oEdP3MaL40cZJO07iSH02UZ:T0h>;Q0>7Rh@3Sh^40
imCF0;1>E`3551d0/Q8J0654B@3Gfml0gn3S0=kOhP3Nh>@0fmkP0;jSZ@2>62@0/@LB0;423@2/0PX0
Y`490:813@2M0@/0V`0809/12@2?0`/0L`<708h3302D0Pd0QP@:08H3202C0PT0U@8809D1202F0@X0
UP4809`12P2L0@T0S`8808@2202F1@h0K`8407831@220`L0L@8505L1001Q0`40H`l600_Q00Wooooo
00<00?l00?n0003oP0007P3oP0000`3@D7P0oh000?n000030?n000030>QX?03@D7P0oh0000H0oh00
00<0d51h0?n0003oP0000`3oP0000`3@D7P0oh000?n0000N0?n00003043P0?oooooooooo00Kooooo
2`00o`00CP1ONAH0M4lo06e<?01[Ac`0IdI206I8B01XB4`0KT]C07A?E`1gDEd0E4=A05A@G@1@CeX0
Le]W08]SJ`22HVP0QVia09EnP`2HRHT0VI:@0867U`0?:FT0G7:J0:na]P2na<`0VZB^0<G@f02S/K/0
ZKS20:Fg`P2/`Ll0K8b/07ZMb00XF9X0MJCE06:=``1ZU<40d^;[0=?Qj@3ChNL0d^3W0=;OiP3?gnT0
Khbb05UIO`27>TH0TT160958C@2BEE`0UfAZ09Q/LP2LN7h0PF=d09YjP@25Ifd0QfIZ08m^L@2@K700
WGMi099YK@27GF40REMK08E:B`24?3h0Q30f07I0A@21S8d0O8nA07J:S01cQXT0MXV<06j2QP1_Ph@0
LhR907>9S01fS8l0>HTe003o00Sooooo2`00o`040?n000030=1@N02P8?00X23`0140X23`00<0^3Rd
0:0Pl03@D7P00`2P8?000`2h>;@0X23`0:0Pl0040:0Pl0H0oh000P2P8?0C0=1@N0030?n0003@D7P0
X23`00X0X23`00<00?l0ooooooooool02Oooool000[ooooo01`00?l005@C0@1U10<0HP4105L10@1D
0@80F@4205l10@1[0P<0M04408821`290@X0QP8;08D12`2?0@d0U@8=09/33@2H0PP0U00608l1202>
0@H0W@<70:<11P2X0PT0Z`890:`12P2[0PT0[08:0P2/0`X0>P2`2a<0DPL<08n:S@3Mg]d0h>7S0>7R
i03QhN<0fMOM0=_GgP3Ph^@0d]OG0=kSh`3Ni><0gn?T0>;Oh03CXJL0/AlV0<8B5`1@4QT0/KFl0=_O
h`3Ngn80gMkR0=_Mh03@aLL0SCm80:@;602`0a00ZP4:0:L22@2T0@`0X@4=09h12`2K0@X0R@@<05l3
1@2810d0T`8;08821`1d0@@0T08809D1202@0PP0Q@8708l3202K0@/0W@4<09`2302;0`T0RP<907d4
2P1W0@@0Q`D<07/31@1Z0`<0G`4106LF3`0E`P49ooooo`03003o003oP000oh0001d0oh0000<0X23`
0?n0003oP0000P3oP000103XJ3`0oh000?n0003@D7P70?n000030>QX?02P8?00oh0000<0oh0000<0
d51h0?n0003oP0007P3oP0000`20`03oooooooooo`06ooooo`/00?l004h0?J@<079??01^C3l0KD/o
06M6?`1TATH0I4M:06a9DP1cBeH0N4mM06e?G01GBE@0LV5[08i^N@2?JG80T6e_09AfM`2EP7l0UHV6
09FDV`0^?Vd01R=^08BDZ`2`][X0^;k30;:l``2S[kT0Y[Bn0<?Af`26W:`0Zl;C072A/P2F^]/0Nj;=
0115T@1[Vl/0X[kE0=;Rj@3Dh^P0e=oU0=CPj@3BhNH0d^7W0<?Fh`2/`/l0`lc@0<G>d@39e=T0b]WM
0<cJh02Z_=40HHFa049TT02H//D0UJZb0;?5b`2R/kd0XkBm09j^]P2P[K@0Wjfb08nNX`2=VYh0S9RJ
08RAU@22S8h0NHb>07V=T01gS8l0MHR=07>9S01`Q8P0JGeo0765Q`1dRHd0MH^?04mQCP00o`08oooo
o`/00?l000D0P<000?n0003oP000oh000=1@N00C0:0Pl080^3Rd0P2P8?000`3@D7P0X23`0:0Pl005
0:0Pl0030;Ph]03oP000oh0000@0oh008P2P8?000`00o`3oooooooooo`09ooooo`002_ooool0F000
o`00FQL106P30P1S0P40E`8205410@1D0@40I`8306d1101d0@D0PP4808P120200P`0O`8<08l1302E
0@d0V04;09T12@2D0PL0S04608X10`2H0@L0X@060:L22@2Z0PT0[P<;0:l2302a10`0[@880:h32`2]
21<0APX>0:NVZP3Nh>40gN7S0=_OhP3LfN00ZWB907P_C@2WS:40fmkU0=oSiP3MhN@0h>CV0>7Ti@3P
b/h0[3Hm0<<@501W2a40Kfed0=OLg`3Kg>00g]oT0=cMh03HeML0Y79j09P@7P2[0a00Z08;0:H12`2S
0Ph0WP4=09`1302I00/0RP<;04L00P1R0`X0OP@;06`5201S0@@0R`<:09D22@2A0PT0M`8507/21@2I
0P/0V`4=09X23P270PT0OP4608L32P1g0`L0O@@806/00@1T0@40H`8106LF3`0F``49ooooo`03003o
003oP000oh0001d0oh0000<0X23`0?n0003oP0000P3oP0030:0Pl0T0oh0000<0X23`0?n0003oP000
0`3oP0000`2P8?00oh000?n0000M0?n0000308300?oooooooooo00Kooooo2`00o`00CP14Z`d0Le8f
06m@@@1^C480Jd]306Q8A`1XB4h0JTMB07=9E`1kD640PEIV08UWK`2@L7L0UG9n09IbN`2GM7X0VGUn
09Z5Q02LTHl0NGbB00DMI`0C=7`0U9n]0<C;c`2VZK80]ko70:Zg_@2a`</0XK6m0<3AgP20Vk<0Oijn
039QV@2fh?d0N:3A03U][`2mf^h0e>;Y0=GSjP3DhNP0eN;Y0=CRj@3Dh^P0dN3W0<oOiP3>gnH0d=oW
0<oNi`3Ah>L0d=oW0<?Fj01]U/<0Y<OS06^E^@2P_Ll0Z;W80:Vd`02ia/l0/Kg90;g:eP2O/KX0VZbc
09JW[`2@XJT0QiVP08VKX01hRi00NXjB07f@U@1bQH/0KXB606f1Q@1YO800Gg=h06Z0Q01cQh`0GfMT
00Cb0PSooooo2`00o`001@20`000oh000?n0003oP000d51h0180X23`00L0d51h0:0Pl02h>;@0X23`
0;Ph]02P8?00^3Rd00H0X23`00<0^3Rd0?n0003oP0001@3oP0000`3XJ3`0d51h0?n000030>QX?1/0
X23`00<0:<Plooooooooool02Oooool000[ooooo03X00?l006LL101a1@<0H`4105P10@1A0@40E@42
06T21P1/0PD0L@4508<22`280``0J`8606D21`2@0Pd0U`8<09`22`2I0@X0S`4708T11`2:0PD0U@45
0:D32P2Z0PX0[0<;0:h22P2d0`h0]`H@0;<42`2c1`l0Z`LB04/83P2?T9D0g=oQ0=cPhP3Nh^<0h=KK
0:PgAP2k5bX0TaX^08UaP`3Jh>@0g^?U0>3TiP3PhnH0hmgP0;=KHP354AL0S@hC03XX;036c]80f]kO
0=[Mg`3LgN00gMcN0;^QZ02@7BX0Y`@>0P2W0@`0702S0P`0W@8<09/12`2L0P`0UP@>04X210112@d0
A@<803/10`1N0@H0S@8<09811`2F0PP0T0<908L21`2H0PX0W0<=09X23@250PP0PP<808X31`200`D0
RPP=07@20`1U0@40IP82068;1P0G``49ooooo`03003o003oP000oh0001d0oh0000<0X23`0?n0003o
P0001@3oP0000`3@D7P0oh000?n000060?n00080d51h103oP0000`2P8?00oh000?n0000M0?n00003
08300?oooooooooo00Kooooo2`00o`00;@0Qe0H0LDl_06mC?`1_DD<0L5=:06mCDP1ZCU80K4]B06m:
E01hD5d0PeUW08iWL`2AK7P0UW9m09YfOP2NOH80Wh240:6<S`2MTiL0A561004MN@0_BHH0]kk60:F[
[`2na</0[;O00:Vg_`2caLd0X;:o0:6c``1[QZD0[/[U06fEaP0fL;@0LZCG04Ei]`2jg?<0e^C/0=WU
k03Ji^`0f^O]0=SVk@3GiNd0e^;Z0=GRj`020=CQjP0O0=GQj@3EhNX0dMgY0<gNk`0iKK80Mj_J08jf
e`2fd^<0/lOD0<;Bg02kb]D0`/gI0;k:eP2Q/K`0Z[_50:2_^`2IZ;80Tj:Z08jMY@1mSiH0M8R=07>9
S@1WOH40JWn206QmPP1YOX80CVE/065hN`1[PXD0IW9b017=2`08ooooo`/00?l000@0P<000?n0003o
P000j6Pl502P8?020;Ph]0030:0Pl02h>;@0X23`00L0X23`00<0^3Rd0?n0003oP0002`3oP0000`3@
D7P0X23`0:0Pl00H0:0Pl003052@N?oooooooooo00Wooooo000:ooooo`1H003o001X7P@0M@H206H1
0@1H0@40E04005L10@1T0@<0J04207@10`240@T0S08=08@3301l0PX0U08>09/23@2L0P`0V08:08`1
20290@H0S@4509<11`2L0@L0Z@<;0;04302d10h0]`@?0;H43`2c0`h0/PD@0;094@1W2A00DTaD0=3E
f03MhN80gN7S0=kLg`2cE5h0aA8L0<LC7@1Y3A/0/K6j0>3TiP3OhnD0h^CW0>CSi@39U9T0_QDL0;8@
5`100@H0VibO0=WMh03Gfmh0fMgO0=SKg@3Fd=<0TdA>0:@54P2U0P/0Y0890:41302M0@/0V`4909P1
202I0P/0PAPN09MQI`1T>d40A`8407`32P2A0@T0T@4609D11P2E0@D0U`4609T12@2K0@d0V`8=08d2
2@1o0P@0P@8507/11@1f0@@0M@<406d20P1W0P40IPh901K200Wooooo00<00?l00?n0003oP0007@3o
P0000`2P8?00d51h0?n000060?n000030=1@N03oP000oh0000H0oh0000<0^3Rd0?n0003oP0000`3o
P0000`3@D7P0oh000?n000070?n00080d51h4`3oP0000`20`03oooooooooo`06ooooo`/00?l004h0
9mP807A<:`1_E440KU=2071BB@1_DU@0JU1A06e<D`1]BE80NU=M08AKJ02=Ig<0TFai09IaN`2JN800
XH250:>4R@2QS900Vi>N020cN@069XP0CfZM0:6Z[@2_]KT0^L;<09:QZP3?gn@0PiBO0:^ma`2P]<40
/<?L086Sd@1^V<`0=g>i09K5iP2/f>/0Zm7Y0=oXk`3Vk>l0j^oc0>C/l`3Ojo40fnO^0=_Uk@3Fhn/0
en?Z0=GRjP3Dh^X0e>7Y0=7Oj03?g^/0TKWS09g<l`2</=80W/?M09jeb02/_Ld0/l?@0<SGi02d`m<0
_=3N0;73c@2V/kl0XK:l09j/^02BXZ/0PY>K07B7S01`Q8P0K82406b1PP1YOX80IG]o05M`M01KLgL0
Hg]j06QhN00RWAP8ooooo`/00?l000@0P<000?n0003oP000oh005P2P8?000`3@D7P0X23`0:0Pl005
0:0Pl0<0d51h3@3oP0000`3@D7P0X23`0:0Pl00H0:0Pl003052@N?oooooooooo00Wooooo000:oooo
o`1H003o001X70<0MPD206L00@1J0@40E04005H1001S0@80J@4207<210220@L0S08<08X12@280@/0
T`4=09`23P2O0@h0V08:08h12@2;0@D0R`4709<12@2H00L0ZP@>0;033P2d10h0^@D;0;@22P2a0@/0
/P@>0;463`202Q<091@K0;o4b03MhN<0f^3P0=kQi032PXP0_Q/T0<hB702D41T0PGV20=oUi`3Qi>P0
hN?V0>3Sh`3E^K/0/adT0<4@6@1_2A80LVQ^0=[OhP3Hfml0f=cO0=GJg03IfM/0X6Ub09l7502T0P/0
XP4:09h22P2O0P`0W00909X12@2J0@`0T`/F0:=0C02F>4D0Q0D>09412@2B0@L0TP0709<01P2F0@P0
V@4909P12`2K0@`0VP4<08T11P1c0080M`430842201n0@P0J`4306D10@1T0@00IPh901O20@Wooooo
00<00?l00?n0003oP0007@3oP0000`2P8?00d51h0?n000060?n000030:0Pl03oP000oh0000H0oh00
00<0X23`0?n0003oP0000`3oP0000`3@D7P0oh000?n0000L0?n0000308300?oooooooooo00Kooooo
3000o`00C@1gCBD0Ke=1071A@P1cDdX0KU5A06iBE01[CeH0KDmI07EBG@20EfD0SFAb09A^NP2FLgh0
WGj60:>4RP2SQH`0WhZ@096=XP0:8gT00R>305aeW`2_][X0];[00:ng_`2ia/l0YkS10:Bb^`3<f^40
]LKF09ngd01GMj40d^Oi0=KdoP2>cN`0U]?_0<cXn03am_/0nO_n0>gcn03Sk?@0gnW`0=[WkP3Gi>/0
enC/0=OTj`3Gh^`0e>3Z0=;Rj@3@gnP0cn3[0:C6j00iMkX0UKgL0:?2f@2icMd0^lgM0:bnc`2^`=40
XK?30:Zob`2`aLh0YkK10:Je_P2M[KL0RI^T08FHW@1fRhl0L8F807>8R`1eRHX0MXN;06YnPP1PMgT0
GGEf06=iN@1UMgP0:ITS00Sooooo3000o`030?n000030=1@N02P8?00X23`0100X23`00<0^3Rd0:0P
l02h>;@00P2P8?00102h>;@0X23`0:0Pl02P8?020=1@N080X23`00<0j6Pl0?n0003oP0002P3oP000
0`3XJ3`0oh000:0Pl00I0:0Pl00307QH]?oooooooooo00Wooooo000:ooooo`0<003o001a8@D0O@L1
06X10@1L0@40FP4205h10@1X0P80J04306l11@210@P0S08<0P2;0@/0502E0@d0W`<@0:02402I0P/0
T04808d11`2>0@P0T`8:09D12@2S10`0/PD>0;H43`2h10`0]0@<0;83302c1@l0/@@?09<9500Z0PT0
VIfT0P3MhN80=03MhN<0ekBg0:`W;`3=5A`0/aDK06=6CP3HgN00g>;S0>7Si`3Nh><0hM?F0:la>`37
4QP0UQ8K05@i@03GgN00f]gP0=SKgP3Gfmh0f=_O0:n@U`2H3AT0Y@D?0:443@2O0P`0WP8;09d12P2K
0@/0V04;09P23@2A0`l0T@DA09@22`2C0@X0U04909@22@2C0@L0T08709P12@2J0PT0V04:09T12`2@
0PX0OP4407h31P1j0PH0O0<806/2101Q0P80I`820689100QY049ooooo`03003o003oP000oh0001h0
oh0000<0^3Rd0?n0003oP0001@3oP0000`3@D7P0oh000?n000060?n000030=1@N03oP000oh0000<0
oh0000<0d51h0?n0003oP000703oP0000`20`03oooooooooo`06ooooo``00?l004d0LeXN071@?P1e
DTL0M59<06a>C`1]CU80JdeD06U;EP1]D5`0P5UW08eSL02DLGX0UgZ309]nQ`2OPX/0XX>:0:::S`1/
L9@0126200HXP`21UkX0XZV]0<_Be@2f^l<0/K[20;o7cP3Fg><0en;X0<_Jj@3Hio00iOKm08K1i02V
g_P0/>7e0<oan`3Nk_H0i^kd0>_`m03/loH0i^ke0>;/l`3Iinl0eNG/0=CSj`3Fhn/0e^;[0=CRj`3B
h>T0d=oY0=?Rj`2ldNL0PJcL09k7jP1ZTKP0ZL3G0:Fib02daM<0`mCQ0;33d02]_/X0UjRc09JU[@2H
YJd0UZ:/08FFWP1fRI00MX^A06j5R@1fSHl0N8b@07N;S`1cQh/0FW1d05mdM@1UN7X0HGAd03]l=@08
ooooo``00?l00`3oP00C0:0Pl0040=1@N02P8?00^3Rd0:0Pl0D0j6Pl00@0^3Rd0:0Pl03@D7P0d51h
3`3oP0000`2h>;@0X23`0:0Pl00G0:0Pl0030;Ph]?oooooooooo00Wooooo000:ooooo`1H003o001d
7P<0P0H206/10@1O0@40G04105h20P1X0P<0I04106h110210PP0R04:08d1302A0Pd0U`4;09l22`2L
0P`0T`4:08l12P2>0PX0S`4809<12@2F0P/0V@8;0:d43@2e10h0]@<<0;@43@2b10d0/@H<0:d33@2R
1a80E`H=05mKHP3Kh><0fmoQ0=kRi@3SfM`0^6U_0<DK8P3;5Q`0GQDN0;c0a`3Mi>D0gn?T0>3Si03T
h^D0^VM_0<LD6`2g4AX0DQ@K0<O<d@3Kgn40f]gP0=SKg`3IgMl0a[Zo08hL:@2S1A40X`@?0:813`2O
0@/0W04909T22P2J0@X0V@8:09@01`2E0@X0U04;09@1202E0@L0T`4609421`250@D0T`8909L11`2G
0@P0V04;09<220220@D0N04606D31P1H0@40J0@506<20`1X0@80I@X502j60PWooooo00<00?l00?n0
003oP0007P3oP0000`2h>;@0oh000?n000050?n000030>QX?02P8?00oh0000H0oh0000<0j6Pl0=1@
N03oP0000`3oP0000`3@D7P0oh000?n0000L0?n0000308300?oooooooooo00Kooooo3000o`00C@1L
NQD0L4df07ICA01eE4d0Jdi=06U<CP1XBe80H4A?06I;F021GF/0RVA_095_MP2GMh<0UWZ608M`O02G
O8D0XX^E04QDQP048XT022j408VJ]P3Bd]H0_[c40<_<dP3HfMh0g=kU0=kTkP3Sjo<0jo7i0<;Ij`2d
eO00/]g`0=3fo`3;l?d0QlWV0<3Um`3WlOP0k?7h0>G]m03Mj>l0fNK^0=OVk@3Ehn/0dN7Z0=3Qj@3@
h>P0d=oY0=3Nj03?g^L0d^7Y0<;ChP1RQ[L0F8Bh0:S3g@2`bMl0/LCD0:bnc02IZ[L0Zkc80:^maP2T
]l40XK6j09FTZ@2<W:<0PiNN07f@U`1WOX40IWn107Z?TP1cRhh0KXN806j6Q`1_QXP0JGam06=eM@1P
MG<0CV5600Sooooo3000o`030?n00180X23`00<0j6Pl0:0Pl03@D7P01@3oP0001`3@D7P0^3Rd0=1@
N03oP000d51h0:0Pl03@D7P02P3oP0001@3@D7P0j6Pl0>QX?03oP000d51h01X0X23`2oooool000[o
oooo05P00?l007TP0`241`80K`4106D20`1L0@80GP4206T2101W0@40K00208812@2:00`0S`8=0902
2`2F0@/0X0@=09X2302A0@T0T@4:09002@2A0@L0U`4909`33@2I0Pd0X@890;853P2b0`X0/@8;0:l4
302]10/0Z`<;0:@4302341P0AC4j0<kCf@3KhN40gn;T0=oOg`3M/[H0^bH^0=<F6`2241L0LVMa0=oT
i@3Pi>H0hNGV0>7Ti@3;UI`0aQ/V0<PB701Z2Q80ZJnd0=_Ph`3IgN00em_N0=WNh03Bc]80TCA00:D5
4P2U0`l0X`<>09d12P2K00X0V@4:09D12P2E00P0U@0709@12P2C00L0U00609401P2A0@D0T@460901
1`2B0@P0T`0709<11P2G0@P0U@4708`21P1e0@<0M0<705l00@1P0@80J`4306/20P1W3@P0<8T52Ooo
ool00`00o`00oh000?n0000N0?n00080d51h1`3oP0000`2P8?00oh000?n000060?n000030:0Pl03o
P000oh000080oh0000<0d51h0?n0003oP000703oP0000`20`03oooooooooo`06ooooo``00?l002l0
I80G06i<=@1bE4<0LUI<06Y?CP1WBTd0Id]A06Q=EP1_DU/0PV5/08MSL@2?KWP0U7=n09AgP`1fHFd0
QFmi0:>AW`0^@HL00RND00dhR`2`^m<0dLG90=WEf@3Lg>80e=SN0=cOj@3Nhn/0i>_c0=cVk`3Hi_<0
i_Wo0:oGm00mSL/0IK3O0<O^n@2gen`0enC]0=KSk03Fhn/0e>;X0=;Sj03Ei>/0dn;Y0=7Qj03?hNP0
c^3X0<kPi`020<oOj00L0<oOj@3Bh>`0]LkT06bHcP2A]ml0K9:e0:c1e02gb]L0_m3M0;[=f`2T]L40
X;6n0:2a^P2BYJ`0QYFN07b>U@1eRI00IWj2065hO01`Q8T0LhZ>06b3Q`1`QhX0M8N=06n3Q@1UNWP0
HGQg05=JC`Sooooo3000o`020?n000030>QX?02P8?00X23`0100X23`00@0j6Pl0?n0003oP000j6Pl
0`3oP0020>QX?0040?n0002h>;@0X23`0:0Pl080^3Rd2P3oP0001@2h>;@0j6Pl0>QX?03@D7P0j6Pl
01X0X23`2oooool000[ooooo01800?l007TS10262@80M@4106H10@1O0@40I04306`11@1]0P@0LP46
08@22`2:0@d0S08=08h1302D0P`0VP<=09D12`2B00X209<12`1409@22`2H0P`0W@8=09d33P2P0P/0
[0@>0;843@2`0``0[PH>0:L32P2V0PP0Z0@;09L<500k4QX0^l;:0=kRi03Oh^<0gn;R0>SEf034CEH0
gA/M0;<J8@157bP0emSK0>;UiP3TiNL0h^GW0=foa02o92h0e1@J09@A6@2>R8l0g>?U0=cQh`3Ig^00
f=gP0=[JgP2MF680Z0TF0:P33`2U0`h0W`4:09`12`2K0@T0U`4:09X1302H0@X0U@0;09812@2B0@L0
TP4609811`2@0@D0T@4808d3202?0PT0UP8:09H12@2C0PP0R08407`21@210`L0M@4206T20`1[0P@0
K@8206D6100bR0D9ooooo`03003o003oP000oh0001h0oh000P3@D7P70?n000030=1@N03XJ3`0oh00
00H0oh0000<0^3Rd0?n0003oP0000`3oP0000`3@D7P0oh000?n0000K0?n0000308300?oooooooooo
00Kooooo3000o`009@0oYP/0LThe07AFA01eEd/0K51:06Q>C`1cH680YYJJ07YNI`24Hfd0RFEa095_
N02EMGl0UWN2099aNP2VPX`0Zi^X02@mS@03<:@01C6=0:FedP3Cc]H0emSN0=KIg`3Pi>P0hnO^0>3X
k`3Ji>h0gNK`0=gZn01dWLd0S/7Z0975kP1f[N00N[3P09Nnf`3Ehn/00`3Dh^X20=?RjP0S0<oPj`3<
h^d0bN?^0<ORkP36h_40aN7c0;oNm02hfoH0/]Sg08:fi`0JH<80LJgY08Vjj02F`nl0NjKF07jVe`20
Ym@0S:oD0:6oh02=[<P0QJ2f08VP/P25WJP0N96I06QoQ01]QHH0J8:207>:S@1_Q8X0LHJ<07B9S@1f
Rhd0Jh1o069gM`1FGE@02?ooool<003o00030830003oP000oh000180X23`0P3XJ3`70?n000H0X23`
1P3oP0040=1@N1l0X23`2oooool000[ooooo05P00?l007lV1`2:20@0O08306/10P1T0@<0H@4206P2
101^0PD0L04507/120210@`0P`4908`1302C0P`0TP4<08l22`2A0@T0TP0:09822@2A0PT0UP8<09X2
302K0P`0X@8=0:H1302_0`d0/0@=0:`53@2X0PT0Z0480;043P2^2AD0H0LB09:DW`3Oi>L0h>GU0>;V
iP3Xi>@0hZ:U0>0m?`3OAdd0R3M10<_2aP3VjNT0i^W[0>OYj`3^i>L0fV1W0>hW:`3<82<0PEiU0=oU
j03Ni>L0g>3S0=_OhP3Jg^40_9>J0:/@702f1A40/0@A0:T23P2S0@d0W`4;09`12P2K00X0VP4:09T2
2`2F0PX0U@0909<1202B0@L0T@470941202:0PL0S04909/2302I0@X0T04608@21P1f0@@0PP8607@1
0`1Z0`@0JP4206d10@1V1080<hP52Oooool00`00o`00oh000?n0000O0?n000030:0Pl03oP000oh00
00H0oh0000<0d51h0?n0003oP0001@3oP0000`3@D7P0oh000?n0000Q0?n0000308300?oooooooooo
00Kooooo3000o`00C@0c_PT0ME4d07AEA`1dE4T0LE9;06U@C`1hJVh0/jZd07UOK022H6d0RVMc09=`
N`2GN8@0XH6<0:N0S02aS9P0[::b01TfRP02<:X01SVO09VaeP3Dd]X0d]GJ0=WMi@3EfN@0e=cV0<_H
i038e=l0c]gZ08fW``2/anD0EXBk07R]g@1DSLP0L:cQ0<SSm03Ei>d0f^K]0=gXk`3Gjo80`NOh09kI
n020c_P0IKkg04bXl@17W^l0>XcY031hhP0[J]P09E[;02ADb00VC<<0:4:n02/o/@0^?Jh0;cb/02/e
Y00Y<j009C:O028`V`0P<IL06S6A01`gT`0Q@9L0:T^J035CTP0jFHP0Bfb;06F5U`1dSYP0LHR@07>:
SP1[PXH0L8N:07J;SP1]PhD0GF9N00Sooooo3000o`000`20`000oh000=1@N00<0:0Pl0030;Ph]02P
8?00X23`00<0X23`0`3oP0020>QX?0030=1@N02h>;@0d51h00H0X23`00<0^3Rd0?n0003oP0000P3o
P0000`2h>;@0X23`0:0Pl00R0:0Pl0_ooooo000:ooooo`0C003o0024:0H0S@P207d20P1/0@80H`82
05h10@1U0P@0J04206`11@1j0PX0O@4;07d020270@X0S`8<08h13@2<0@/0S@8;09012P0209022P13
09@12P2I0P/0W@8<0:@23P2R00/0Y`@<0;873P2h20h0_0T?0<<:4P383AD0ba<I0;8M9P2=KWT0jng`
0>KZk03Xj^`0kNg_0?C^kP3li^H0oo7b0?ofm`3oo?d0moSi0?Gfm`3cm?H0lo;d0?J/[`3jCTT0mD8k
08i1B`3]k_<0hnOX0>;Ui`3PhnH0gn;V0=o6c@2g82h0b`/H0<D7502l1Q00/`<=0:/23@2T0@/0WP4:
09/1202M0P`0V`4;09X12P2I0@P0UP4;09812@2A0@L0U04909X2302M0Pl0V`4;09H11`2@0PT0Q046
08021@1`0@<0I`8307420P1/0@40H0<103]o2P09ooooo`03003o003oP000oh0001l0oh0000<0^3Rd
0?n0003oP0003P3oP0000`3@D7P0oh000?n0000Q0?n000030<2P0?oooooooooo00Kooooo3000o`00
C@0Te@L0ME0^07=GA@1fETP0LU=:06Y@CP1VCU40M5QQ07YJI`26HFh0SFQf09YgQ02RPH`0[8^F0;2?
V@2eXZT0_;S90210U003<J`01cZY07VEa@39bmD0al[D0<K;e@3;dM`0a/gI0;:ob03=fN<0Z[W60:Fl
dP2N_ML0N9g508fhf02fi?`0BK3W06K9m`2=fOX0[NKk09;Fm@1I^o409ZKa00bGlP05T?H01HKg03Y[
h027CK<0X4>K0:hhQ@2j;Fl0_R=P0;/IEP2l5d`0^AU50;@H@P2b5T00[Qi80:PB>P2Q5C`0W@`g0:09
=02G3ST0SAA708DEC`1g5e<0I1EN058GH`0k56@09aQ[01<OKP0O>g`0<E2504UZSP1SOXh0IGb106Im
O`1jSiD0I7AU00Sooooo3000o`001020`000oh000?n0003XJ3`A0:0Pl080d51h0`2h>;@00`2P8?00
d51h0:0Pl0030:0Pl0030=1@N02P8?00X23`0080X23`0P3@D7P60:0Pl0H0d51h2P3oP0040=1@N003
0;Ph]02P8?00X23`00T0X23`2oooool000[ooooo05P00?l008@V1`2=20<0N@4206X10@1T0@40H@42
06010@1T0@40K`4207P1201i00T0O@4:08D12P2<0@`0S@8>08T12P290@T0R@0808h22P2?0@T0VP4;
09l1302U0Pd0Z`8<0:d33@2/0P/0_0P@0<h@5P3N5aX0iAXN0>/Q903c:Rh0l3Hl0;MHJ`3nmoh0knob
0>o`l`3al_H0loCf0?Ggm`3ko?`0nogl0?cmo@3jn_/0m_Og0?CdmP3em?D0mZF[0?YAB`3h@CT0XC]5
0?C`mP3SinP0i>KY0>;Ti`3Qi>L0k=_S0<0e@P3A3aX0d@`I0<T74`351a80^P@>0;02302V0@X0W`07
0:812P2R0`d0X08=09d12`2I0@X0T`080941202G0@X0V`4;09`13@2J0@/0V04809<120220PH0LP85
06l20P1W0@<0K04206`10@1O0P40C54<2Oooool00`00o`00oh000?n0000O0?n000030=1@N03oP000
oh0000h0oh0000<0d51h0?n0003oP0008P3oP008ooooo``00?l004d02_H207Q>:01gET<0N5M907AF
C`1/DTl0JU1C071BF01kFF@0RV9_09UcO`2NOHT0YHJC0:V?V`2bVjP0ak2l0;fZ_@0[?hl00RBJ00DZ
VP1]Rkl0][S30<;4b`2m`/P0`<G?0;k5c035cML0/lGD0:G7gP2XeOD0TL[]072kl@1<[oD09Y?]01BD
lP0<Snh04J;^032/j@1G_>`0I/Gb04S3n00R/_T039cj012;n@25D;H0jB==0>dI;`3W52D0fPlM0=H<
703;1QX0aPHH0<]8D`3WZ;00YTMJ0=NKZP2iJG/0k;c60:@^AP2Z11@0^U5K0=:Y]@3;WZ`0`HZJ0:I7
G02G1A`0T@XO08@B;P1a33D0FQ1704<AE00W5Eh052=U031>LP1JMgl0JGf204f:B008ooooo``00?l0
00@0@>000?n0003oP000j6Pl2`2P8?000`2h>;@0X23`0:0Pl0040:0Pl0030;Ph]02P8?00^3Rd0080
d51h0`2P8?000`2h>;@0X23`0:0Pl00;0:0Pl0030;Ph]03oP000oh0000P0oh0000<0j6Pl0?n0003o
P0002P3oP0000`3XJ3`0d51h0:0Pl0060:0Pl0_ooooo000:ooooo`1H003o002<:@/0S0P207@20@1W
0@40H`4106D10`1V0@<0J`4307<11@1k0PX0N04907P12P270@d0S08>08P12P2;0PT0S@4909012`2E
0P/0V@890:H2202_10T0^PL=0<@93`382a40b0XB0=0>5`3K4QX0k1hS0?HS9@3m:Rd0oB`b0?df?03U
>T`0g6n;0?OBh03hl_P0nO;i0?OamP3kl_L0o?Ki0?_inP3lnod0o?Oi0?ccl`3mk^l0n]3D0?=]K`3j
BCl0nd0g0:4Z<P3=am00hNOZ0>3Si`3Oh^@0g^;T0>;Hg`2j?dh0cQ4N0<d>5`3:3AD0a@XB0;l84P2i
1a80/0<?0:X23@2W0@d0Z08=0:T33P2V0Ph0W`8<09X12`2F0@X0U`4;09h23@2P0Pd0W`8=09`22`2F
0@P0Q08706@10`1^10D0J08307010P1/0@80F`4004I:10Wooooo00<00?l00?n0003oP000<@3oP000
0`3@D7P0oh000?n0000Q0?n000Sooooo3@00o`00C01kDRH0MUI207UJBP1jFeD0LeID07AHF`1lGV@0
OemW08]XM@2EMWl0VX>=0:29UP2WSY`0/96Q0<:HZ@37WK80:Rij008HP@037X<0CVBG0<34bP2m_lL0
^/?=0<?Di@2/a^L0MjOQ04fCiP0ILN802V_Y00UVi`04P?L00XWk00FBo00<X_`0:K_k02ninP1=]O<0
Gjc]03n:h`0WLn40<F3H04ACbP1H@kH0W2Mj0=@@<`3G31`0c@PE0<H55@371QD0aPHD0<@550306bh0
hjZg0:IfR`3I]lP0^H^P0=BcaP2H6S/0Z08D0:Y;F`2]TjL0SEQg08iTO`2gTJ@0R`PP0:55C`2URi40
ZXJ>09eIJP202R@0P`HR068;=P0I4U4052mQ04mYMP0cXbl8ooooo`d00?l00P3oP0000`3XJ3`0X23`
0:0Pl0090:0Pl0030;Ph]03@D7P0X23`00<0X23`0P2h>;@00`2P8?00^3Rd0;Ph]00B0:0Pl0030=1@
N03oP000oh0000L0oh0000<0^3Rd0=1@N03@D7P0103oP000103@D7P0X23`0:0Pl03@D7P20?n00080
^3Rd00@0d51h0?n0003oP000d51h0`2P8?000`1hF;Coooooooooo`09ooooo`002_ooool0F000o`00
P2@608L70@1b0@40J04106T10P1V0@80I@4206`2101d0@L0OP4;07H11@1g0@L0RP4<08h1302;00P0
TP4909`23P2P0@h0Z@<=0;843@2m1Ph0aPT=0=0=403I4Q00e@d?0</63P3;1a40c`XC0=L=5P3`6b00
nbHX0?d/;@3n<Rl0oCHh0?Xj@03cDV40m7>70?IgRP3dMhD0mX6:0?VHY@3i]/P0ol?H0?VZ^03gRI00
nWin0?aZIP3nE4`0odM10?hn>`2h:C<0[YJR0>GYkP3Oi>L0g^;U0=[OhP3Qg^<0]eAS0<HC8@383aT0
aPhG0<085@2j1A<0]P@A0;843P2[0@X0Z@4<0:`13`2^0`h0ZP4=0:@12P2P0@`0T04809D2202Q0@d0
YP8?0:T54@2V1a00VP8:08X11P1g0PD0K@8406l21@1h0P<0KP420681001:BP@9ooooo`03003o003o
P000oh000340oh0000<0X23`0?n0003oP0008@3oP008ooooo`d00?l004`0JWTR07=F?@1kG4`0OEiD
07aMF`1nHF@0P6EX089WK@29KgX0Tgj909R6T02KQi<0YHbJ0:V=V`2_SY`0]9>V024TK@015G`00Q^0
055VW`2T[l@0Sj[E066CfP0VJ<h025?=00=Ef`03G>P00fSf00Icn`08OO/01ggh00Mim@0;Mo405W?Y
01U?a@0kBkl0JTJe08LlXP2G=Y<0WS6:09/`QP2<<XL0NCbD07diS`2l8Ed0haHZ0>@D6`3N3aX0g@dG
0=d>6@3I2aL0e0hN0=ATM@3:ZkP0gl7@0<2EZP3=WK@0Y1<a0;<44`2/<D40ajNf0<2]_@33^<H0_9jb
094:9@2F<3d0^k_00:bf_`2WUZ@0LAL]08L34P250a80>@do00<CE`0E;5409j/Z2?ooool=003o0080
oh0000<0j6Pl0:0Pl02P8?00802P8?001@2h>;@0d51h0:0Pl02P8?00d51h0080^3Rd2@3oP0000`3@
D7P0oh000=1@N0040?n00080d51h00@0X23`0=1@N03oP000oh000`2P8?030?n000040;Ph]02P8?00
X23`052@N0_ooooo000:ooooo`1H003o001o8P@0Q`P207@10P1Y0@40I`4206<10P1U0@80KP4507P1
1P240PT0P`4808D12@2?0P/0U`D?09@12@2M0``0Y08<0:X33P2b10h0]0<<0;/32P3010X0b0D90=@>
3@3D3@h0b`L>0<T63`3>2A<0dPdF0>dJ9@3l:2`0nbX[0?h`;@3n<C00oC4_0?hg>`3k?4D0oD5:0?Tn
A@3hA4T0m4IC0>i;H@3^CFP0lDQJ0?A1B@3h@T<0mc`k0?Lc=03d:R`0lbT]0:lN:P1N@E<0eMWR0=gR
i03LhN@0f]kQ0=gLh@2TDV40]a4P0;d<60323Q/0^@HE0;@4502b10l0/@<>0:d23@2Z0Pd0ZP4>0:`1
302Z0@`0Y@0:0:4230260@@0S`4909l12`2U0@l0[@PF0;8D7@2P1Pd0T08808021`1W0040JP4207L1
0P1]0@80HP4104U:10Wooooo00<00?l00?n0003oP000<@3oP0000`2P8?00d51h0?n000030?n00003
0=1@N03oP000oh0001/0oh002?ooool=003o000<06Z79021GTP0PV5>08IUE`26IF00QVUY085XJ@27
L7@0RW=m099jR02GNh`0VGb=0P2OPI00?P2aSi`0^9BZ024ZN00399<012ZL01A1Z@0GCKP01dW800=8
cP04E=h01EOR00AGi007E^D02ToM01Y<dP0d@;/0DSJV06DaV01g<I00SRn606dNL01V<HD0LDVJ07iX
[P26S/80HYgG02fDj@0ES_4048Se01]fl01oBk@0gb570>TF7P3P41T0fPXH0=@:5P3B21D0c`TG0;l/
@@3Pb=<0eL3?0=:Y_`2`IHD0ZP`W0;<2402h?D/0ekS50<Jfa034^/L0]h2H09d78@2H:CL0c/C<0:^[
]`2^V:L0NAXf08X35P1m0P`0A@Xa00TBE00354@06I`Q2?ooool=003o00<0oh0000<0d51h0:0Pl02P
8?009`2P8?080?n00080j6Pl00<0d51h0:0Pl03oP0000P3oP000103XJ3`0d51h0=1@N03XJ3`20?n0
00030=1@N02P8?00X23`00<0oh0000@0d51h0:0Pl02P8?00D91h2oooool000[ooooo05P00?l008DW
1@241`40M@4106D10@1P0@40H`4106X10`1e0PD0P04708P12@280@X0S@8:0:4>602a6B@0Y@LB0:T5
3P2Z0`/0ZP8:0;022P2a0PT0^0@90;h42P3620d0``X;0;X6202i1@/0^0D=0;L43P2l1a80a@PE0=lG
8P3U6b40jb4V0>hW:@3^:BT0jbd]0>H`<P3V=CH0iSTh0>Do?P3VAT@0hda90>ABDP3TDE80ieMG0>=F
E03EBTL0gE1?0=I;C037@D@0VcU004dhA02k`/L0fmkR0=WNh@3Hfml0fM_P095JI@2M5R<0Y0dG0:P:
5@2X1Q<0Y@8A0:<13P2S0Pd0X`8>0:<1302X0P`0ZP4=0:L23P2Q0@/0X08<09@22@2F0@X0XP8:0:@1
2`2W0Q40ZPTG0:484@2?10`0O0<707X41`1b0@<0N@8306`10P1O0@00C4d72Oooool00`00o`00oh00
0?n0000a0?n000030:0Pl03@D7P0oh0000<0oh0000<0d51h0?n0003oP0006`3oP008ooooo`d00?l0
04`0D:@I08=QB@27IE<0SVeO08i`J@26KV/0PFQ[07iSK`29Kgd0RVin08a/O@2?K7`0Vgb90:B9U`2Z
TZL0Q7n]01DeU@03;ZP00S2^004c]@04?L<01DC>00I9dP09A<`05CVm034`Z`1B9i<0L2=m084QK`1j
9G00Fbmo04hnT@0nD:/0;6k?01^5j00HT^l0?:of06Bjm01DYnl06HC`00Afm001K_8006G^00EIi00c
?KH0]AYD0=T:6P3D21@0ePTE0=884`3@1Q<0ba0L0;a0C03Rb]@0_j:e0<^H[`2/EG80[A<[0;044@34
Ig<0`:Zh0<Jjb02mZ[/0]69n0:H77@2^DU/0a[k70;blb@3<_/h0Q2I709846@260PP0H`@F03@?>@0;
4c`04Y8G2?ooool=003o00040<2P003oP000oh000=1@N2T0X23`00<0j6Pl0?n0003oP0001P3oP000
0`2h>;@0d51h0?n000030?n00080d51h00L0^3Rd0>QX?03oP000oh000=1@N02P8?00^3Rd00@0oh00
0P2P8?000`1@T7Soooooooooo`09ooooo`002_ooool0F000o`00Pb@508060P1c0P40I@4205d10@1R
0P40L04407`110250@P0R04708T01`2C0`d0Z`/H0:P74`2V0`h0Z@<>0;84402b0`h0]0<=0;P53P2a
0`X0/`D>0:d32P2P0PL0V@0409P11P2F0@H0U04709P12`2N0Pd0X`DB08T94`2`EUT0g96>0>ZVXP3_
][@0lL[90??@c`3fem@0m=_I0??MfP3ahM`0lN;O0?;Th`3biND0lN?S0>cPg03/h=l0jmoP0>KKf`3M
e]D0eMOG0=KLgP3Kgn<0f]kQ0=SLh03JgN00^[6a0:n?S`2/Ogh0YfY]0:ACF@2A4Q`0V`8<09P12P2E
0@X0U`4<09d2302P0Ph0WP4=09/12`2J0@X0V`4:09h12P2U0@/0YP4>0:L24@2L0@h0RP8907P21`1c
10P0MP@807831@1n0`D0LP8206800@1<=`89ooooo`03003o003oP000oh000340oh0000<0d51h0>QX
?03oP0000`3oP000103@D7P0oh000>QX?03@D7PJ0?n000Sooooo3@00o`00C019/1<0Qf56091ZE@2G
MV80UWmb08iiMP20JVd0O6=/07QNJ@1oHVl0QVId08m^O02<NY40HfVI02I3U`07;id013Bb00@g^`05
>/000bnc00Xb[`0L;:<0B2ZD06`JM02266<0MQUR05LSM00g=Y<07U:l015Vg@0=M_4037of00Z3n@07
O_L00W;f009ZlP01J?400VSa00=]l@03K_4017;a00AjlP03OoD017of021ai@2Z?8X0lAdY0?<L803b
6Ah0jQ<K0>TC7`3L<C`0mkk<0>70e@3R_]H0hKgC0?2hdP2i;d`0_0HH0<=9H03L`m@0b;g>0=35eP2a
G7X0X`TN0;]kPP2n_<H0^[S60<6I]02J63d0Y@HH09D22P1D1R4060Ta024G;P08ePL8ooooo`d00?l0
00@0P<000?n0003oP000d51h4`2P8?030;Ph]1<0X23`00<0d51h0?n0003oP000303oP000103XJ3`0
d51h0>QX?03XJ3`20?n00080X23`00D0d51h0?n0003oP000oh000=1@N0020:0Pl00302S8??oooooo
oooo00Wooooo000:ooooo`1H003o00219PH0N`D107<10P1R0@80D`0005d10P1c0@@0O`0408L11`2:
0@D0S@0809T33P2X1A00Y0<>0:823P2[1140[`@@0;033@2a1@h0Z`D<09h22@2Q10`0V`480981202B
00P0SP4508T10`2900H0TP4<09/23P2M21H0G`DD08UnR@3Xj^X0jN[Z0>_]kP3Yj^`0j^_]0>k_l@3d
m?H0l?3b0>g_k`3^k_00l>ka0?;alP3al_<0k>c]0>[Zk@3[jnl0inW/0>CXj@3QiNH0gnCW0=_Qi03K
gn80g>7T0=gOhP3JgMh0f=gM0=KKf`3DemL0clK808/b?@2O0Pd0V@4;09<11`2E00T0V@8;09X02@2G
00X0V@4:09H02@2F0@T0W04:0:L23P2_1AD0[@LE09/12P2=0@P0MP4407T31P1]0`P0D00007L21P1e
0@80I@4005h:0`Wooooo00<00?l00?n0003oP0007P3oP0000`3@D7P0oh000?n0000K0?n000030=1@
N03oP000oh0001H0oh002?ooool=003o001<02CG202:Hd00UGAJ09f3K`2WUHX0SGUg081WJ@1eG640
M5UT07iUK`1nJgd0EE9o01T^O004:9@00RVR008YY005:j/03BVS01hPSP0i5GD0Ha9N07XBE01_6V40
D2n902@fWP0@A;X02ECB00QNh`04GN@00ekW005Ij000F^H00F;[005Ul@02LOD017ce016;l`0lYo00
J<3d07cAn01ZeOT0@L[g01nio00?Z?h04I7j07UM_@3Y9440k1PU0><B8`3K42D0eA4V0<T@;@327TT0
^1Y>0;8GB`2]64T0ZaA40:/<<02/1R40Z0XX0:<WD@2X?VX0[d9/0:8;;02P11H0`6j20;jM]03>_Ll0
/6F30:L=:02]1a80VP@?04H=>`054e806APe003o00Sooooo3@00o`001020`000oh000?n0002h>;@@
0:0Pl0<0d51h5P2P8?000`2h>;@0oh000?n0000=0?n000030=1@N03oP000oh000080oh0000<0^3Rd
0=1@N03XJ3`00`3oP000103@D7P0X23`0:0Pl000o`0;ooooo`002_ooool0:`00o`00OBD607T40@1c
0@40I`8305L00@1S0@80N@4408811P290@L0SP4709D2202I0`/0YPPA0:lB602`6B00Y`/F0:@3402R
0`d0W08:09H22P2;00L0U04709D11P2G0@T0UP0909H12@2F0@H0V@490:@43P2^1A40]``G09dF9@28
IGD0k^oc0>g_lP3emOP0n?Sj0?WhnP3jnO/0o_go0?omo`3no?l00P3nnol20?gio@0Y0?_en`3jm?/0
nO;j0?Wcn`3ek_L0ln[c0>oUl@3Ug^/0hmo]0=_JiP3Gf^@0em_R0=OJhP3Gg>40e=[O0=CBf02KBUT0
ZP@B0:@23@2L00X0WP4<09l23@2M0@`0V`4=09P12`2E00P0UP4:09/1302W1Q<0^1HR0;TH8P2P1@l0
T0<;07P11@1e0`L0K@<506D31@1l0`L0NP4206T10@1R2`<02Oooool00`00o`00oh000?n0000N0?n0
00030;Ph]03oP000oh0001/0oh0000<0d51h0?n0003oP0005P3oP008ooooo`d00?l004`02oH308eT
=P2KOf@0XXio0:fRW@2EQ8<0OFAT07aSI@1iHfl0FEAc01`XJ@036GH00R6<008RU`0589D06A^804XF
L`1f4EH0N@Y106D?BP0k5fL072R<00`cZ`08A<X014cH0097dP01B=<00T[H005Ch002H>/00F[a00=g
n005QOX01YSm00bXoP0V^oX0Em3k06k;mP1O_?@0?Z[b01>Bl`06ROL00h;l009en@03K?H06UgR06Pm
W`1i<X40JS:405/`S01@=9L0ACBK03leW`0h<Z80<RnM02h^V00]:I80;RJ;02lPP@0b77L0=aM/04<F
J@1A5V40GA5A06/=?`1i33T0Q0li09h`EP2U83l0Z`PM0:/5402@1QP0<1=@00@HJ00?6T@00?l02?oo
ool=003o0003043P003oP000j6Pl00h0X23`00<0d51h0?n0003@D7P06P2P8?000`2h>;@0d51h0=1@
N00=0:0Pl0@0d51h1P3oP0030:0Pl003003o0?oooooooooo00Wooooo000:ooooo`09003o001k8@D0
N0<107T20P1i0P<0L04107D110200@D0Q@450080S08800P0S`4908l22@2I1140W`XG0:@D8@2J21H0
U@8<09@22`80SP4903@0U@480:02202Z0`T0]`T=0<0?402l20d0^`H@0;`53`2o2180``XE0<T>6P36
5B40YBe70=fI^`3OV[d0jYo10?2U`P3aYKl0lZJk0?6Y]@3^[[T0k;C20>Z``P3XXK00ji:O0>b4T03^
N8L0kVf20>mYO`3]IWX0k5]d0>iMM`3XEG40ge=c0=A@M@3=EgT0bF:10<E[RP2mKHX0_GNB0;n6X`36
TZh0/dML0;@54P2_0`d0Z@4:0:T22`2W0Pd0Y08=0:423@2M0@/0V`4:0P2J0@/03@2R1140Z`/I0:/?
6`2H0`h0OP0707L42P1i0PP0M`8507D210270PD0P04207410@1W2@802Oooool00`00o`00oh000?n0
000N0?n000030>QX?03oP000oh0001P0oh0000<0d51h0>QX?03oP0006@3oP008ooooo`h00?l004/0
TVPc09IlH@2MS8<0_;Jg08ajN`25KV`0Ofia05EDL`064eX00QEc008JP0026hL02AN502dAK`1b3U40
S0e105`9B@0U35d041Yo00D/X004;:/01CFh00E4cP02A=40047<009@f`01GNX0173f00=mo007S?l0
1iCo00RJo`04V?d00Y;k00B?n@04ROT018Gi00=ln`01Mo/00GGk009_nP01J_H00FCb005Jj002FND0
2ECH00U=cP07BL`01DG900=1a@05A/T01D?600A1aP03?l400SZk008e]@02<:d00bfT008YW@039YP0
1BJJ00HTU@098i003Qf201LIM@0/4f80D`i;088><`2L2b<0X@HF08<87P0O55L00amb00/MCP00o`00
2?ooool>003o00030?n0003@D7P0X23`00/0X23`00<0d51h0?n0003@D7P0<P2P8?040?n000<0X23`
00<00?l0ooooooooool02Oooool000[ooooo05P00?l007LQ0`1g1040P@4108`10`270@40P04208@2
1P270@D0R08708L11`230PP0O@4607h12`230a00X18O0:8>6`2I1100U`4:09X12@2X0`d0/@<>0;P6
3`2k1Ph0_0L90<L@3P2n1@T0]`890;L23@2f0P`0_@@@0<H;5P392aH0e1DT0=`O<`3Q93T0jBm60?M8
FP3kEEd0nf5Q0?ehK`3jS8T0mifW0?JQ/`3gUJ40mgYi0?]UGP3lD4X0o4A30?a0?@3j>cT0mc0a0?L/
;@3c8bL0k1hU0>DH8@3O5R80eaHV0=0B903:3b40`PhN0;T=8`2c32@0]0LJ0;L4402^0@`0Z`4;0:X1
2P2Z0@/0Z08;0:P23@2V0@X0XP4:09h12P2M0@`0X08@0:L85@2[3ad0W0DA08812@1Q0P@0I08506h2
1P1j0PD0R@8408<10P1g0@40K@/32Oooool00`00o`00oh000?n0001E0?n000Sooooo3P00o`007`1V
UR80Tg=I09F2NP2]Y:80Sh1l08b1PP1IGGd02aeV004EKP025WL011Ae01<=H0132T`0L@a305X=CP0_
5Vh03aZ300LRT`038YX00RFP00@_/002?<<0157K009Ag003F^D01Fkg00Abo005Noh017km00=ho001
MO/00P02Mo/0:P02NO`00GKj005cnP02KoX00VKf009Tl`02IO400V?/009Rj@04GN001EWJ00IJe009
E/X035?3019@^`0FD;<075:_029EZ`0XEZD0;EZU02eKY00[F9h0:UBI02Q@TP0WC8h09DR;0213Q`0H
?XL04SR800d`QP069X8012>400HPPP0<7Gd07aaa03TEGP1M4dT0HPhh018CF`038gL0429D003o00So
oooo3P00o`000`3oP000j6Pl0:0Pl0090:0Pl0030;Ph]03XJ3`0d51h03H0X23`0P3@D7P30:0Pl003
003o0?oooooooooo00Wooooo000:ooooo`1H003o001h:0L0N@@008X20`2D0P80V043090110250PD0
PP85084220210PL0O04607/01P1k0PT0NP<=0:<M:P2S3a/0W0<@09l33`2R0P/0[@8;0:h02@2_0@T0
/`4;0;`72P3>61@0bA<E0;d84P2l21@0^@HA0;H4402j1a80_PLA0<L;5P352QH0a0dK0;h:6@395B40
g28^0>TZ=@3e=ch0n3i20?Q0AP3h?TT0mCLn0?Xj>`3j=c@0nbd^0?d/:`3i:2X0kb0S0>TN7`3S6Qd0
gAHM0=8@6@3?3aP0a`dG0;d:5`2l21@0^PLC0;@3402a0Q40[@4<0:h2302`10l0Z08<0:H1302W0P/0
Z@<?0:P1302V0@/0Y@4:0:422P2O0PT0WP490:013@2R0A40X@<C09X2402?00/0P0@:06D20`1S0@<0
L`8408H20`220@80N04106l>0PWooooo00<00?l00?n0003oP000E@3oP008ooooo`h00?l004/0:=X=
08i[A`2?MFT0Y9VD09:DX@0e@g802ai]00@MP0045gT03PaM03P:@`1@1bd0>PPg01TAI@098i800bJO
004RV`0189T00R>O004YY`02>;T014kF00ENj@04HNh016Kc009Xm`02Ho<00V;c009Um@02H_800Eo`
005OkP02HNd00V?^009Sk@04I^/01FCW00UPg@0BHM<07FO<02i_``0mMKT0C7Za05R0Z`1UQ:L0LX^T
07N>XP1kSId0P9BN08>FX@20U9`0QYBI08RFW@24U9/0QYNM08:CU`1gR8d0MhV?07^;T@1aPXL0Jh:7
06b4R01]PX/0HGN8051WO`12FG`0:TIi01DdN00:;7/02RZ300hWPP049X@00b^401XXD`00o`002?oo
ool>003o00030830003oP000X23`00L0X23`00<0^3Rd0>QX?02h>;@0?@2P8?000`00o`3ooooooooo
o`09ooooo`002_ooool0F000o`00NRX;07l50@2@0@80U`8209d41P2I10L0P@8307H00`1j0P@0O@45
07h11`260PX0SP@>09074P2=2180T0@>09<12P2J0@X0YP8:0;432@2c10/0^PTA0;443@2/10/0Z0@8
0:<32@2M0@T0V`8:09X12@2L0@`0W`4>0:@13P2[1140/@LE0;<85P2d21H0^`dI0<XE903P82`0m2le
0?]3?P3iB440n4I00?Q5?@3h@cX0nCde0?Xb;@3k<2`0mRXY0?HX:@3Y7B00i1XQ0=lI8`3@4Q`0bQ4K
0<8=5`2g21<0/`HA0:l5402Y0Pd0Y`8=0:<12`2T0@/0X@4=09/12P2J00T0V`4909l23@2S0@h0X@8>
09`22P2>0@D0U`8809h12@2O0@X0W`4>09h3402G0@/0TP4808/2201e0P<0LP4307L1101m0P<0O042
07H20@1_4P49ooooo`03003o003oP000oh0005D0oh002?ooool?003o000`09Z4B@2:K5X0T8ZA03<j
M0196EX0JAA@02LBJ00]3E/0D@Pa03`6<@0@1TD01AMb008TTP02:J800RZV008^[`04=KL00SNn00E2
a`02@<@00T;90098d`02CMP00UGR00=FiP02F>@00USS009Ih`03F=l00eKJ00IJf`0;G]<06FG903=e
a@1=PK`0Ihji07bF]@2=X;00Tj:]09NTZ`2O[Zh0Y;6c0::^[`2P[J/0XJZZ0:F][P2[/k40[[Nf0P2e
_Kl0602i_[l0^;bn0;Zm_`2g^[/0^;bi0;Ni^`2c]kT0/KBg0:nb]@2Y[[00X:RX09nYZP2NZJT0Uj>S
08jKW027UiP0KX>805icOP1:I7d084Ak00PcR@06;X005f/b003o00Sooooo3`00o`000`3oP000d51h
0:0Pl0020:0Pl0050=1@N02P8?00X23`0>QX?03@D7P09`2P8?040=1@N1@0X23`00<00?l0oooooooo
ool02Oooool000[ooooo00X00?l008Hf5@251`80VP<409L41@2720P0RALI07L2101b0080N@440P1o
0@L0C0220@H0R@4808X12P270@L0R08709411`2L0P/0Z08=0;053`2O0P`0UP4809412@2>0@T0S`09
08`12@2:0@P0R`0808l12@2H0@T0Y@<=0:h4402f21<0`0/F0=0F7`3M82H0j2/b0>P_>@3cA4L0nfiW
0?bGR03i[jD0n[Zh0?Zg]@3jYIX0oXek0?iUF@3oDT/0oTQ40?i2@@3m>S`0nc0e0?P[<03`9b`0iR0V
0=lL8`3E51h0b0dH0;`8502g1A40]@D?0:d23@2X0@h0X@4=09d12@2K00P0V04709H12@2H0@/0V@4<
09H12@2A0@P0U@4;09P12P2I0@X0U@4:09<12P2>0@@0R`4208`21@240@D0OP4507/1101e0@80L`82
06h30@1^60<9ooooo`03003o003oP000oh0005D0oh002?ooool?003o001:05?<902<KET0@cmS06LJ
B`2S2b80[0LF08D7;01K2CD08`U300LBI`025WH00R6<004XW@03;jL00c>a008g^P01=[T00cVo008k
_`03>[/00SFe004j^`02A<L00e3E00=BeP06E=003EW7029T`@12MKX0EX2h06Z;]`26W;@0TZ:^0:Nc
]`2c_K`0_<?20;Rn`@39cl/0eMSH0=OKf`3JgMl0dM;G0<S9c`32_lL0^;6h0:jUZP2PV9/0UXf>08^1
Q@24NGl0P75e07eaK`1lK6/0OFeZ07IZI01gJVL0MVYU07A[I@1fKFP0MVeY07E_J@1jM6h0OgYg08V5
P@2DU900Si:@08N?RP21RhL0M8>0069eMP14GF/07cYE00n^4`00o`08ooooo`l00?l000@0`:000=1@
N02P8?00^3Rd0P3oP0020>QX?1d0X23`0`3@D7P20>QX?0@0d51h00<0^3Rd0:0Pl02P8?005`2P8?00
0`1@T7P00?l0ooooo`0:ooooo`002_ooool0F000o`00U4LL088;0@2R1`P0S@<309@Q8`2<6b80M@84
07X10`1h0080OP4507T00P1m0@@0Q@4808H12@280`T0T@hC09H;502H0Pl0X0<A09/13P2>0@T0R@06
08`22P2>00L0U@0709P01`2L0@P0X@4:0:@22P2^0``0`@XD0<`?6@3I6B40jbD/0?0Y;`3g<ST0mcI2
0?HiB03iAU40nf5V0?YmO@3dQHl0m8BH0?5gR`3`IW@0m5QJ0?I2@@3i>3P0o3Ti0?/d=P3i;C80nbdb
0?HW;03a8bX0j1dW0>@K9P3L5B40eQ@P0<`>6P3931X0aPTF0;l74`2f0a00/04>0:X1302U00T0W`07
09d2202O0Pd0V`4<09L01`2E0@T0S08;09<43`2L0aD0U04@09012P2:0@@0Q`0208`1102<0@D0P`44
07d10P1j0@<0L@4007D<0`1^6`<9ooooo`03003o003oP000oh0005D0oh002?ooool?003o000g00gi
1P1jKTl0CQi80:PA8P2b31<0/@TA09<67@0Q3d`00aM[008OO@0178000RJE00</Y@02;:T00B^[008a
/`02;kH00cJk008f^@03>[P00cZg00<o^@08AKP085Zf04Ul_@1dUk`0W[320;>maP2i`L@0^;o10;_1
a032alL0d=GD0>3Qi03MgN<0e=3I0<>lb@2c[;T0WiNU08J1S`1fM7d0Kfmc06][K`1UIf/0JfaV07M`
I`1gLF@0N79T07UaHP1iKf80N6iQ07]cHP1hL5h0Ng1P07M_G00207I^F`0A07I_G01fKUh0LfiL06aZ
F@1]JUX0K6MH06QRE@1SFe40IEa>06IQE01ZIUP0K6]O06]_I01LIed0AeY>01nQ6000o`002?ooool?
003o0003043P003@D7P0^3Rd00@0oh00602P8?020=1@N0030>QX?03oP000d51h0080d51h8P2P8?00
0`1hF;@00?l0ooooo`0:ooooo`002_ooool0F000o`00BJH608DU3@2G1PD0Q08207`31@2610P0N043
08d31@250@<0QP8508`220260`L0O`4608H33@2H4Ah0Y24_09/F8`2D1Q@0TP4=09812P2B0PT0U047
09d22P2Z1@d0]@T?0;d@4P2h2Pl0/PH?0:l63P2/0`/0/PL@0;/9502k1a80`@TF0<@<5`3731P0cA0N
0=0@7P3O6bH0lBLa0?Hf?03i@TH0n45:0?Hi@P3h>3`0mc@b0?/b;03j:R<0nb/W0?TX9`3f8RD0mB0S
0>dJ7@3V5A/0gA8I0=<?603;31P0``PD0;l64`2l1140^P@?0;L23@2f0`h0]@8>0;82302^0`/0Z@49
0:L12@2V0Pd0Y08=09l22`2H0@T0Q@8808T3402O1a/0W0HH09D23P2=0@L0Q`0508T21@2<0PD0QP42
08420P1o0P80M@@107PF2P1=E049ooooo`03003o003oP000oh0005D0oh002?ooool@003o0019089i
C`1n6C@0[QXM0>64Q`2g@T`0Z0XK05<GDP0898L00RRB008ZU`02:9X00RJP008VX@02:ZH00Rf^008`
/`01<K000cB^00TiY`0YE:L0H86f09Z]a@33c=00cmCA0=GGd`3Lg]`0h>;R0=gMh@3BcmT0a/?>0:f[
]02@SYT0PGj8085oR024Q8/0RhnC08N>T01mQ8H0I75a061_K`1NKfl0GFa_05m/K@1NJ5l0IFUM07=c
I01hLUl0Mg5M07I]G@1fKeX0Mg1K07Y_G`1hL5l0MVmL07E_G01aJeD0LfiI07MaH01fKf00M6eP075Z
F`1^IeH0Kf]I06]VE@1YHdh0IfEC05MJBP19CD80AdY005YNC@1JGdl0BEPg00Gc0P08oooooa000?l0
0P3XJ3`40?n000030;Ph]02P8?00X23`00d0X23`00<0^3Rd0=1@N03XJ3`00`3oP0030=1@N2T0X23`
00<0:<Plooooooooool02Oooool000[ooooo05P00?l001O_1P1d;0X0P`H207X10P1d0@80Q0@607T2
102P1PX0ZPH:0:43202K10T0RP8707l21`260`l0U0PH0:0I9P2J4Ad0T08>08l22P2J0P/0WP870:82
1`2W0`T0Y08:0:832@2J0PH0T@4409001P2>0@@0TP4509`22P2T0@`0[`@@0;/53`372Q80dQ0G0>8K
803X8B@0m3<`0?]7@03gEe00m6MP0?ImN@3fQH<0mgei0?Y]HP3lFTd0oE0o0?i;@03nAS/0oChc0?hj
<03k<R/0nBLV0?DR803Z6AX0fQ0H0=0>6@372Q@0a0XC0;`63`2h0`d0]@<=0;412`2/0@P0ZP480:X1
2P2X0@/0Z04<0:/23@2X0@/0XP4909/12@2G0P`0W@<C09X24P2H0Pl0S`4:08@21`1_0@<0O`4508H1
1@280@80QP8307T70`1Y4P80;Yd02Oooool00`00o`00P<000?n0001D0?n0000308300?oooooooooo
00Kooooo4000o`00B@1_X2D0U1hJ0;UMG@3EYZl0chbI0:LA7P2K2RP0=aa_00@VU@029YT00RNK008V
X002:J800RRN00@[X00:<9d0842I04iUV`27TZ/0ZJjf0<71a@3=b/`0d<oA0<[9c`2g/[X0XIFO08Ik
Q01bK780JFM]06Q[K`1XL6l0LGYg06YcKP1ZKVP0JV]Q06UZG@1/JUh0L6aN06e/GP1ZIe/0FUeG04=?
C014DE00D5eK05eXG@1/K600LfeN07=_G01gKel0MFiJ07E_F@1fKeX0MfmM07E^FP1dKEL0MfeI07E]
F`1dKUl0NWIW07I]H01`IeL0KVUH071YEP1]IeL0JVE@06QXF@1CE4h0<c/f02hk<@15CSh0EUM505]J
@`0Fd``02?ooool@003o00030<2P003oP000oh0000@0oh003P2P8?001@2h>;@0d51h0=1@N03@D7P0
^3Rd02h0X23`00<0J:Plooooooooool02Oooool000[ooooo0P00o`00EP1KIPL0O0T108020P1_0000
M`@507820P2U20/0[P<80:h63@2J0@L0QP4607d2202610l0T@XG09<>602<0`/0S@4909022`2D0@L0
V`0709l0102R00D0X00509T0102E0@80V@8309d21@2L00D0X@880;L530372aD0e10H0>DI703^7R00
n2TX0?hg=@3oB4<0oeYA0?miL@3oWih0ol[?0?oOjP3og>T0omCN0?nXYP3oMfh0oVEI0?eGB`3nEDH0
oTdn0?i3>03n>C00oBdY0?h[9P3k9240k1/O0>4F8@3E3aT0da0J0<`<5P331Q40`0PD0;P43P2b0PT0
[@0;0:d12`2[0@X0ZP490:d12@2/00T0Y@070:801@2O0@P0V`4;09L12P2C0@/0S08708H11`1c0PD0
O04408@0102;0@@0S08307d70P1]5@003nD12Oooool2003o05D0oh0000<0P<00ooooooooool01_oo
oolA003o001807U]4`36R8P0h/?<0=ne``2[:S`0/PHD084@@00C7HD00RJI008WW0029IT012BC01Xd
R017D8D0KFV808QkS@2CQhl0W9BG0::OY02TWZ80ShR:07U_LP1_Hf@0MVQP089gJP1dLVT0HF]X05QY
J@1BHF80GV9J06IWFP1fM6L0Sheo0:^[W`36`l<0`[jo0;:XY02MSHD0UX9d08YhJ@1nLV40KfQH05=H
B`1>FU80IFQP07MfJ`1eLV@0MfmN07A]F01bK5D0MF]G07IYE`1eJUH0MFaE07E[F01gKUX0LVYG07A/
G@1hKF00NVeN07I_G`1bK5d0LV]O06MTE@1GFE00@T@j03m6>P14DD80C5Q?061WFP1IF4405mD>2?oo
oolA003o00040?n0003XJ3`0oh000>QX?080oh0000<0j6Pl0:0Pl02P8?00602P8?00102h>;@0d51h
0=1@N03@D7PR0:0Pl003052@N?oooooooooo00Wooooo000:ooooo`800?l005H0>;h907T?0@2<1@@0
M`<306lB4P1c1PD0Z0`=0:L21P2X0PT0X`@<08<21@1U0@@0O@8;08<73`241@d0Q@4608@01@260@H0
S@460:L22`2e10d0_0D<0<H;402j1@`0^`/=0<4>402m20d0_0PA0;l?603931<0eQ4H0=hC6@3W6Ql0
ja`Q0?PW:03m<Rl0ochg0?a4?`3lBdl0nE9M0?ELJ`3fI7P0leY]0?AGIP3kFEd0ndi<0?i>BP3lAT80
oTDn0?`k=03n=c00oC4[0?XT8P3e7a`0lAXJ0>DE6`3F3aX0d0dK0<T;602l2QH0]PLD0;/64`2j1A40
]`<=0;H23@2i0`h0_@D@0;l53P352Q40^`D>0:X1202T0@L0X08609X11P2G00L0T`4608d1102:0@@0
PP4508<110240@@0Q`4408X31@1o2P@0KaT0003o00Wooooo0P00o`000`20`000oh000?n0001B0?n0
0003003o0?oooooooooo00Kooooo4@00o`00B00Ej`L0bI:>0=bc`031Ig/0]@lM0;X93`2M3RX08aah
008TT`049Hh05Rio04I:MP1aI7@0Ofie089bM@28Mg`0QW]n07QaL@1]HUd0L69D07U]E`1nL5T0P75H
089bF`1bJed0EeeI03]<B@0oD4P0GFAH085nL@2ET8D0ViNB09B?S028Ph<0Qh6208>0O@1oNWH0LG5X
05iLD01OEdH0LV1407]SA@1bJ540C5A904]FD01SJ5/0N7Q[085mK01gLUd0MVeF07Q]EP1eJeH0M6UD
07E/F01hL5h0M6eI07I^F`1cK5T0MfaM07UaHP1gLV80MG=W06UXG`1NFDl0DTm205EEA01GFd/0EV1B
05IQE`1UK6@0Hem;01OD2`Sooooo4@00o`000`10h000j6Pl0?n000040?n00240X23`0P3oP0000`2h
>;@0X23`0:0Pl00J0:0Pl00306RX??oooooooooo00Wooooo000:ooooo`800?l005H03?L4080P1@2G
3@@0U0P:09Pl@0213@l0X@@70:D21`2W0PL0/@H=0:852P1m0PD0NP4507`10`220PH0Q`4708X21`2;
0@H0UP480:l43@2m1Ph0c0XB0</94P2i0`/0[P<:0:L22@2S00P0X08:09l32`2]1Q40]P<?0;h7403;
2Q@0bP@?0>`L7`3j9R@0nBPS0?/Y8`3i9b<0nRPX0?X[:@3l;R/0o2l[0?/^;03e9BP0mbh_0?dg=03l
<c00nc0`0?`_;@3h:BH0lR4Q0>lL7`3`7R00kAXM0>8D6@3821<0_@HD0:@4402`7bd0/2He09h33P2/
0Pd0[`8<0;P33P301Q00b@XB0=4>503C3Q80b0XB0;422`2V0PP0W@8509T1102G0@@0U@8508l21@2C
0PD0T04408/10P260@<0P@4408031@1l4@D0AW80003o00Wooooo0P00o`000`10h000oh000?n0001B
0?n00003003o0?oooooooooo00Kooooo4P00o`00A`2jUGD0h9b/0;DZ=P3;4a<0/A0M05hLE`0>9HH0
3bYl03DnJ@1KDf40K5iR07=VI@1fKFP0L6MO06YQEP1_HU40NFYB08EdF02:N5X0R7EI081aF@21LED0
P75B07=YD@1BDT<0H6=F071`HP1hMFL0N7AX07QiK@24Qgd0MGeg06UeKP1TL6T0H6YQ06IYG`1RIeX0
H65E05mLD01iKED0PFM707QO?P1aKEP0Adm804YDB`1SIeL0MG=T07mmK01jLUd0N6eH07E]F@1hK5L0
MVaD07A]F@1eKEH0N6iI07M^F`1jL600N7EV07IdJ@1]KFD0G5eG05aHC01YHU<0JFEG06MYGP1LIE`0
GfMP06=WG`1WG4807=H900Sooooo4P00o`050?n000030;Ph]02P8?00X23`00P0X23`0P2h>;@01@3@
D7P0^3Rd0:0Pl02P8?00j6Pl0140X23`0P3oP00K0:0Pl0030=1@N020`03ooooo00[ooooo000:oooo
o`<00?l005D0RCT>09XG202D10<0TAPE09491P2I0P80X0430:/2202i1P/0^PH;0;L83@2S10P0TP45
09@2202H0@T0V`<;09H2202I0PT0Y0<:0:d32P301`l0a`XA0<09402`1`/0X04709L01`2C0@L0T@46
0:<32@2g20d0dAHF0>8O6P3V8ad0jbTR0>L/9P3V=2/0h3D[0=Xl<@3@@CL0ddPn0=1;@P3@CdD0c4e5
0<I9@@30BSl0ae160<U?AP2nA3`0^T0l0;Hk=P2a<S00]34`0;8Y9`2g9B@0^b0P0;LH6P2a4aP0TPlC
0:Hb>P2<2A@0W`T?0;883P2l2A00`@TA0<493`341a00c``E0=4>4`372a80[`<<0:012@2G0@H0U@47
09L11`2E0PL0OP4309822@2C0@H0S04208T10@240@<0NP@407HJ1`0Lb@000?l000Wooooo0`00o`1C
0?n0000308300000o`3ooooo00Oooooo4P00o`00A`1^Wb/0]UeM0;X[;0336R40JBYS01<[P00U=VP0
CT]E05eED`1SFeH0IemH06YQC`1_HDD0MfE6085_CP27Le<0R79C08UdE@27M580Qg=A089cFP1nL5H0
PgAG07YZC@1iJdl0NfiF079XDP1IF4`0@55=04YTI@1AIf`0@EIH051KD`1UIEH0NGQU096AO`2NW8d0
TXV107eaH@1oKE@0OfY<07mXAP1gHd80Lg1N055HC`1^Kf<0LfiN07A]F01`JED0LfYF07ecH01iJeH0
MVA907=YD@1fK5P0OW9T07adJ01hM6T0KViT05mQFP1KGET0H6AH075_HP1gMVT0LG9U06Q_I01WL6T0
IVeS06MRDP1aIbd02_L400Sooooo4P00o`001@30X000oh000?n0003oP000^3Rd00H0X23`00<0^3Rd
0=1@N03oP0001P3oP0030:0Pl0030=1@N02h>;@0X23`00h0X23`00<0j6Pl0?n0003XJ3`02@2P8?00
0`3@D7P0X23`0:0Pl00>0:0Pl0030?n00010h03ooooo00[ooooo000:ooooo`<00?l005<0GFD208hE
102;0P40QP4109@40`2K0@80Y@450;431`343@l0`0L<0<X=40373@h0Z04409h11`2F00L0T`070941
202E0@T0[`L@0;P740312a80``/A0;l73@323A40_0lA0:h=4@2R3@l0Y1LD0;LX8@2m;bD0`cd`0<Q?
@036G4`0aVYJ0<AiK@33R7/0`i230<>PT@2mYIH0`ZZM0<B^X`36]:P0`k>V0;j_X@2h[J00[jJK0;2U
V@2YX9@0WiF;09^@Q@2LSHD0UXAk09V0MP2GNFl0TFaO09ARDP2BETL0Q51409QeL@1O:2@0P2<L09LG
4`2X5A@0[A0@0;`C50363a80cPlF0<h>50383A@0]`L?0:412`2H0@/0U04909L11`2E0@H0S@4609D2
2@2@0@H0S@4308T10P230@40M`H206hO1@02003o00Wooooo0`00o`0V0?n00080X23`0P3@D7P<0:0P
l0050=1@N03oP000oh000?n0002P8?00603oP002003o00Sooooo4P00o`00?`09m040Tf`]0;<i=02@
<eh08cJ403e1F01GBd00HeY;06UPDP1]HT`0LEm207UR?022JTH0R6m>08MbE027Me/0QGEF08UdE@2:
MEH0Qg5@08E_C`22L500Ofe=085/C`23K4X0Ofi>06mVC`1JFDP0GVEH06ejL@1oRXL0TINA0:2OV@2N
W9P0Si2<08B8P@2<RHL0NgQ`081eI@27MfD0TH1Y08ekH01jHST0Lf4k06iZE`1[He<0MVQ;07ES@`1e
HdX0LF=;07Q`FP1lLf00PG5J07Y^F01fK5T0KFEB06MQD`1HGE40EEiF05aVGP1/LfH0MW]^07anL`02
07EgK@06079fJ`1]L6H0KfYJ06eZ=00Jh`P00?l02?oooolB003o0004043P003oP000oh000=1@N0D0
X23`00<0^3Rd0=1@N03oP0000P3oP0000`3XJ3`0X23`0;Ph]0040?n000050=1@N03oP000j6Pl0?n0
003@D7P0102P8?020;Ph]0P0X23`00@0^3Rd0=1@N03oP000j6Pl0P2P8?000`3@D7P0oh000;Ph]003
0:0Pl0030;Ph]02P8?00X23`00d0X23`00<0j6Pl043P0000o`002oooool000[ooooo0`00o`00D`1=
V@P0O1X308<20P2?1@<0W0H30:@20P2/10H0/P<40<TA4@301`X0bPd>0<h>3P342Pd0/`L:09h42`2I
2A80W@/B0:@7402`2100/0T?0:`=3`2X51<0X1`J0:0[9@2S@3@0XDa209mIC02OJUd0XgIZ0::1MP2P
RWh0XI:70:2GS@2SW9@0Yj>N0:b/YP2d]k40`LJn0<g@b03HfM80emO@0=WJe03HfM80dmG>0<cAbP32
bL<0^L2h0;Fm]`2U[Z/0WjZW09RPW`2@V9D0S96<08R>R024RH<0OX1g07emL@1jOG00MGU^07QdJ01o
LF80OfEG08=JC@21BSd0Sd8g09da:P2T8b40[Q/K0;HD5P2^2Q00/`/F0:D54P2H0@d0V04909L2202D
0@L0TP4509411@2B0`@0S04208H20`1i2P@0B6@100800?l02Oooool3003o00030<2P003oP000oh00
01L0oh0000<0j6Pl0=1@N03@D7P00P3@D7P00`2h>;@0X23`0:0Pl0030:0Pl0030;Ph]03@D7P0d51h
00<0oh000P3@D7P00`2h>;@0X23`0:0Pl00<0:0Pl0040;Ph]03@D7P0d51h0=1@N1<0oh000P00o`08
oooooa@00?l004<0NU/F05a4NP0n?5D0IU8e06iI>`1cIDP0LF=707QXA`1mJdX0Pg5A08IdEP27MUT0
RgQK08]jF`28MUT0QW1A08YcD026KDX0QFi508A^A01oJdP0PG5D08IbC`20JTH0O6Y<07]YC021KU@0
TX5f09Z=T@1lM7L0Mg9]07mfI`1gL5l0VIF80:bTW02DRWd0PWES08MiIP28Ofh0VYB@08YkJ@22K4T0
L5ln07IYCP1kI3h0Nf<m079O@@1fId`0OG9Q07ibHP1mKEL0LF=:06QOAP1PH4h0FV=H05YYH`1TM6l0
Lgmh07V0M`1jP7P0NWih07MlM01fN6h0LG1S079ZE`1hLC/06n@900800?l02?oooolD003o00050?n0
002P8?00X23`0>QX?03oP0000P3@D7P20?n000D0d51h00<0^3Rd0?n0003oP000103oP0000`2h>;@0
j6Pl0?n000030=1@N0d0X23`00@0^3Rd0>QX?03XJ3`0^3Rd0`3oP0000`2h>;@0X23`0:0Pl00?0:0P
l0040>QX?010h0000?l0003o00_ooooo000:ooooo`<00?l005<05Nd607L^3@2530@0V`P40:P50`2a
20H0/PH50;d:2P2m2P`0^`D90<P<3P3?4100d10B0=0B5P3061T0ZQlQ0:@W:02H9bL0Tc/f095=A`2=
HED0TGM[09:1M@2@QWX0SHYn08^;OP2?SX@0SXn809>ETP2FV9P0VZ6P0:J_[02a^kL0_<G40<gCeP3I
g^00i>W/0>o`l`3dloP0m_Ch0?GbmP3dl?H0l>kc0>gZl03Zin`0i>7V0>;Mh@3PfM`0dlo@0<k=c034
a/40_knl0<2m^@2k]k<0/[:^0:RXY@2LWYX0V9^E092?RP29RX80PXIl07f2NP1gOWD0Mgib07UlL01g
MFT0NG1X07eZH020ETl0Od0k09Lf<`2W82@0Z@lG0:H8402I0PL0T08608P10`2<0@<0T@8308d10`27
0P80O0l401KF0002003o00Wooooo0`00o`000`10h000oh000?n0000@0?n000<0d51h2`2P8?00102h
>;@0d51h0=1@N03XJ3`;0?n000040>QX?03@D7P0X23`0:0Pl080d51h00<0^3Rd0:0Pl02P8?002P2P
8?000`2h>;@0d51h0=1@N00<0?n0000308300000o`000?l000Sooooo5000o`00@P0Xf@l0Fchd0657
;@1lHSX0OVM306iRAP1aJDl0OFY9081[B022KU00Q7AK089dFP29NEh0RgUL08IcE@28LDh0Q6a308I[
AP25K4<0Q6Tn08AY?01iHcP0QG5?08idEP2:Kdh0QFU308E[@`22JT80O6U=04Q?A@1jQ880ViB808Ui
I@2=O6@0T81Z091oJ@2=OFP0R7]W08MmKP2:PGD0S7e]07aXB@1kJ480NfY<081cF026N5l0OgEO085g
HP1oN6H0P7MV07YcH@1bLV<0KGE[079lN01gPh40MX9o07B3PP1jQhD0OXJ408:5P01mOgT0OG]a07]d
I@1nJe80J8l]01C^1`<00?l02?oooolD003o00030830003@D7P0j6Pl0080oh0000D0d51h0:0Pl03o
P000oh000=1@N0030:0Pl0030;Ph]03@D7P0oh0000H0oh0000<0j6Pl0?n0003oP0000`3oP0000`3@
D7P0X23`0:0Pl00:0:0Pl0030>QX?03oP000d51h0080^3Rd4@2P8?000`3@D7P0oh00043P0003003o
00_ooooo000:ooooo`@00?l00540T4LJ09HN2`2W3@@0]0X70;/;2P2l30T0^`T70;020`2k1@T0c0hA
0<d@4P3;4a@0a1TK0:`/9`2DACl0TF=M095lL`2:QGT0RhV108N;O`2;SH<0S8b208n?QP2BU8h0Ui^C
09ZNV02SYj80/;Je0<?8bP32bLd0aLW?0<35c@2j_<@0ZZVa0:2MZ@2LVJL0V9BO09B:V02FR9H0VH^H
09F8UP2KSi/0U8J?09>5RP2@PX@0UH>208mlN`2?Og`0T8J108n8PP2CR8<0SX1k09:2O02BQWh0W8j6
09nAS02/WIH0/Z6K0;:RV@2[X9D0XinB09VERP2CT8H0RHUn0866N`1nQ7h0MWmh07AiLP1fMFh0MVeU
07mGD`28=300TB4N09XC502>1PT0RP4408P10@280@80RP4108@20@1k4@800`00o`09ooooo`@00?l0
3`3oP0000`3@D7P0X23`0:0Pl00d0:0Pl0030=1@N03oP000oh0000P0oh000`00o`08oooooaD00?l0
03l0ID8B07YN<P1kICd0FDhf05mOD01ZJUD0MFA407YR?@1nId<0OFa@08=eFP22MEX0QWEI08A]C@1o
JT40PVe408E_B`25KTH0QVe008E/?@26JCX0Of@j081[C@25LE@0RgEC089W?P1kH300N6@l07YiI@2Z
ZZD0U8N00:N=LP2[Sfl0XXec0:fDN`2@PW40Rh=g08AoLP1nMVH0PgAM08QhF`2=Of40Rh1V08f6M@2:
Q7<0RhAa09^AO`2LUh/0WijE09^LU`2BUYL0SiNI08bFU`2>V9X0SIBE08JBT021S8/0P8J407enNP1k
Mfd0OVmD07Qm>00gb1D01@00o`08oooooaD00?l00`3oP000103@D7P0X23`0:0Pl03XJ3`20?n00004
0=1@N02P8?00X23`0;Ph]0T0oh0000<0j6Pl0?n0003oP0000`3oP0001`2P8?00^3Rd0:0Pl03@D7P0
oh000;Ph]03@D7P06@2P8?000`3@D7P0oh0008300005003o00_ooooo000:ooooo`@00?l00540FgL8
08/O102/50H0`a@;0<XI4@364`d0`0h<0<0A4@313@d0_Pl@0;4O702V=C00W5=;091cJ`2:PWT0QhQo
08J:O`2:SXD0S92708jAR02CU8d0U9J?09ZKU`2JW9T0UYZG09VMV`2MX9/0UYFA096>R`2?S8T0ShZ4
09:=Q`2EShL0Th^209>8P@2DRX00TXIi09B6M`2DQGH0U8Ii09V=P@2MTHL0VXam09R:N@2JS7X0VX]g
09V<M`2JSG`0X9J60:6IR@2JSW/0UHAb08akIP2:NV80RWUQ08ejIP2;N6<0SGMR08adGP2>Mf40TWeY
09Z5L`2LR7T0Vhan09fBR02JTX`0Ti2608R9OP21Q7`0NWej07AbK`1aIf00KeU@06lm=`1g6aX0TA4C
09061`220@80Q04108040@1W<0@00`00o`09ooooo`@00?l0303oP0000`3XJ3`0^3Rd0:0Pl00Z0:0P
l0040;Ph]03@D7P0d51h0=1@N0/0X23`0P3@D7P70?n000<00?l02?oooolD003o000n013Z0P1gE240
QfPj06EK>P16AST0@D/n05iYG01`Kel0MV]D07Y^D`1kKeH0OW1I085dF`23Ke@0PFe:08A^AP25Kdd0
QG=@08QbCP27K440QV/m08M[?@25J3/0OFLo07m]B022LU00SWMD081U>01jHSD0M6I8081kK@2@Pfl0
b:J80<FUR`2cWHP0[I=n08IdI021M6@0OW5K08IiGP26O6<0QgeV09N@N@2@S7P0R89f0:FTUP2n_[40
_kZa0;Zg/`2j^[P0/[Bd0:V]/02TYj/0X:JY09RRY@2CW9d0QHj=07j5Q@1jOWT0O7Q]081[A`1=^Q/7
003o00Sooooo5000o`001020`000oh000?n0003@D7P90:0Pl0030=1@N03oP000oh0000d0oh0000<0
d51h0:0Pl02P8?000P3oP00J0:0Pl0030=1@N03oP0000?l000H00?l02oooool000[ooooo1000o`00
7@16Y@P0NBP209lN2@3481D0aAlF0<DF402h4@d0[B4M09hW7P2?C3l0QW1V08R1N@26R840Phf508ZD
R`2=V8l0SI>;08Z=QP24QGX0QHAl08R8O`29QWd0SHMm09>>O`2ETX@0VIF:09RER02IU8<0U8ej0080
Vi>00380V91n09J@N`2LU880ViF309nFQP2MU880VY5m09Z@N`2GSWP0WI9n09Z>O@2HRWL0WI9o09fE
PP2NV8@0X9V60:6IR02SWHd0WIF309F6K`2?O6@0SG]R08imH@2<Nel0RWYP08MhG`26Meh0Q7=I08Aa
F@27LET0SGQL09F0I`2MSGX0UHQf0961K`2>OVX0T85]08f2L02>QgT0Qh=j07elM@1aLFd0J6YU069F
C`1V?cH0M2<K08092@1m0P40OPX304e=0`<00?l02Oooool4003o00030830003oP000oh0000H0oh00
00<0j6Pl0;Ph]02P8?00;P2P8?050=1@N0/0X23`00<0^3Rd0=1@N03oP000103oP003003o00Sooooo
5000o`00?@0PdP<0Qf4Z07iW@01SI580DeaB04YEBP1:ET/0HVYS07j0M01iNFL0MW1O07QcGP1mLeh0
OG1H07m_DP24L540RGEG08UgF@26MEH0Qg=@08McC028M4d0R7A@08UfD`29N5T0QgMI08YjGP2BPV@0
SWiK08=cCP20LUH0NfmE09=oIP2FQ700THEb09nAO@2MTG`0Vi5m09J?N`2DSgh0X:2>0:j^W@2g^j`0
`LNk0<S<b@37c<X0`lS60<G6aP34aLH0_L310;Rn_P2d_;`0[;:f0::X[02AV9`0QXb>07^0O@1iNW@0
OVmI06RB=`0Vg@l02000o`08oooooa@00?l000<0P<000?n0003XJ3`02`2P8?050=1@N0040>QX?03o
P000oh000>QX?0<0d51h00@0X23`0=1@N03@D7P0j6Pl0P2P8?000`2h>;@0X23`0:0Pl0070:0Pl080
d51h3P2P8?000`2h>;@0j6Pl08300008003o00_ooooo000:ooooo`@00?l005405N`4080k1`2D;aT0
[R8N0>Q]K02c6Q@0VR4G09QKCP20IeL0LG=V07n2O026R880RHf608fBR`2:ShL0PXMl07inL`27Q7L0
S8Qd09:;N@2FSWl0V9:009J@OP2HTWh0TXei09B>OP2?RWX0UY9o09VDP02LU880Vi>109N@O`2FT7/0
WYF309fEP`2PVHP0WIB30::HQP2NUh@0Xif<0:BMS@2TWHX0XYZ70:2IQP2MVHH0WiZ80:6JRP2NVXd0
Wib>09fIR@2AQg@0RWaW08IjH`23OVH0Q89/08B0K`22PG40QHIi08j>P02CTH<0TXil09RBO02FSWP0
V8ej09R;M`2KSGP0V8]c09F6K02:NF40QWAN08QiIP2AR7P0RhMi07UjL01VJ680GUeH05a;@01W81T0
P@l:07hC200[Q@400`00o`09ooooo`@00?l000<0P<000?n0003oP0001@3oP0000`3@D7P0X23`0:0P
l0110:0Pl0050=1@N03oP000oh000?n00020`0000`00o`08oooooa@00?l001<09=H408iY<01lL5H0
K7=Z06MeJ@1ULVP0GfaS05mZI@1PKV/0N8B007Z2NP23R7d0QHIj08>4M027Q7<0R8=_08^5L02@RGD0
T8af0080UI1h02H0ShYa08n9L02ETGP0VI=l09R>N@2GSGP0Th]e09>=L`2BSW<0Ui1g09bHPP2UXHd0
]kBS0<G5]`3Ge<h0g]WE0>3NfP3[jnL0m_Oc0?gnn`3alo80iNWZ0=cQhP3Ifml0e=_M0=?If`3AfM/0
c];H0<;7c02la<H0ZkFh09jWZP2EVY`0QhJ607edKP1kMdl0EJ<Z01?]20X00?l02?oooolD003o0003
0830003oP000d51h01h0X23`00<0^3Rd0=1@N03@D7P00P3@D7P60?n000050>QX?03@D7P0d51h0>QX
?03@D7P01`2P8?000`3@D7P0`:00043P000:003o00_ooooo000:ooooo`D00?l00500QYX_0:=SCP2U
<Bh0`dE409db9P24FDP0LfYM06mbI@1gOW00QhQn08N7O@22PGH0R89f08R2M02=RWH0UY5n09ZDP@2J
U800VY=o09ZCP02ITWh0Ui9m09ZDP@2HT7d0VY>109N@O@2KUX@0VY>009bDPP2MUh@0V9F109^HQ@2L
V8D0VIF409^HQP2OVXT0XIZ;09jIRP2NW8d0WI^=09fLSP2OWXl0Z:BG0:FTUP2VY9P0YZFI0:BUW02P
YIT0X:FK09jRV02FW900V9nB09bVV@2LY9T0SYF=08B?R01iQH80NHF307f7Q020R880QhUm096<O02H
Sg`0Wi9l0:2@N`2MTGT0WI5j09Z<M`2HRG40TX9[08n0J`2>PFh0QWe]07mlL01dLVT0H5iE05I0=@1O
8A<0HaH701jT0@<00?l02Oooool5003o00D0oh0000<0j6Pl0:0Pl02P8?00A02P8?00102h>;@0oh00
0?n00020`003003o00Sooooo5000o`008`0;mP80TFHZ07agH01dPGP0Kgeh07J1OP1kQ8@0Ohb<07n=
S@24T8l0Q96>08NET`2:UiL0WZVV0:Zc[@2i_[H0^l6g0;o2^@2j_k<0`/Rk0<36_031a[X0^l2c0<76
^`3:cl<0blo30<g?`P3Cel/0g>3C0>CUf@3/k>@0mOG_0?cln03nood0o_km0080o_kn01@0oooo0?kn
oP3nooh0o_ko0?gmo@3mo_h0o_kn0?gno@3bloH0i>O[0=KIgP35bm00^l340;6d^@2UZ:/0U9:>08Ig
I@1KVC<0><XH00_g10`00?l02?oooolD003o0003043P003oP000X23`00`0X23`00@0^3Rd0=1@N03@
D7P0d51h1@2P8?050=1@N0030>QX?03oP000oh000100oh001@2P8?00103@D7P0j6Pl08300010h00<
003o00_ooooo000:ooooo`H00?l001H0VgM808hc9@2@AcH0N5i>06e^G`1dMfH0Ngm]07moKP26Of`0
Rh=^09F;N02ERG@0VHik09F?N@2DSgT0VY>109^EQ02NUhH0X9Z909nJR@2PVh`0WY^=0P2PWHh0:02N
Vhh0XInD0:BQU`2YYY/0[ZVO0::QUP2MWi@0WYnC09VKT@2LWiL0Vj6J0:>[Y02b^K40][fe0;>j]@2^
][00[;F[0:jd[`2]]:h0[KF_09nWX`2AV9H0RI:A07f8Q01_OGP0LGif082:P02MX9H0[JbP09jMS`2<
QgP0NWET07E/GP1ZHeL0EeeC06YbJ`1oP7D0T8Mg09fBO@2QTg`209jAN`0=09R;M02IS7@0Wi5k09R;
M@2ES7/0NGAU069RD`1ZIeL0OWMU06UPD01EAC<0D2DD01;30@03003o00Wooooo1P00o`030?n00003
0;Ph]02P8?00X23`04H0X23`00<0d51h0?n00020`0000`00o`08oooooaD00?l00140C;@D07m/C01d
OG80N8R0086?S02:UID0TYjO09>RXP2JZ:L0XZj]0:Jb]02JZ:/0ZkRi0<3;b`3Bg=`0gnKU0>?[jP02
0>S_kP090>O^k@3Zlo40j?3_0>kcl`3cn?L0loKf0?Gin03io?`0o?gm0080oOkn01L0oOgm0?clo03l
o?d0o?cm0?_ko03hnOT0n_Wi0?SinP3inOT0o?ck0?knoP3moOd0n__k0??dm@3[k^l0i>SZ0=[Jg030
_l00[:BO0:6>O01QXSl0@/8P01K`2P0?003o00Sooooo5@00o`000`30X000d51h0:0Pl00;0:0Pl003
0>QX?03oP000oh0001h0oh000P2P8?020=1@N00308300010h0000?l000h00?l02oooool000[ooooo
1P00o`00@`1]`CH0M5Dj06aMB01fJeX0OWUV07]hI01_K5/0QGm/09F:L`2HSGH0Uhei09^CP02GT7d0
WIB209fHQP2KUXP0WYZ@09fIS`2QWI@0Y:2E0:NRU`2XY9L0Yj>F0:VVVP2ZYj00/ZfX0;Jb[`3=b<P0
c/O<0;Je]P2MXZ80RI:F07n<S@1nS8l0NXZ;07Z<RP28UI00V:6M0:>YY`2Y/:`0[K>^0;>g/`30aL40
b<g90<K;b@39c/h0a<[80;Vl^`2_[j`0VifG0::QWP31^l00`k_00;J[Y`2MSG`0VH1V09UiFP2AL4l0
OfM806IKA`1UGd`0R7eX09jANP2OTWT0WY1i09b@N@2LTG`00P2JSgT02@2ERgP0RhQm06AXHP0mBSl0
@4Xl05ID@@20M5`0NFYC05a0:@04003o00Wooooo1P00o`000`30X000oh000:0Pl00H0:0Pl080d51h
302P8?050=1@N080X23`00<0^3Rd0:0Pl02h>;@00`3@D7P01P2P8?00d51h0?n0003oP000j6Pl0;Ph
]140X23`00<0oh00003o0000o`000P00o`08oooooaH00?l002D0FIlL07e_DP1mPgT0QY:=08^JV@2I
YjL0Wjf^0:nk_@2jaLL0`lc>0<;;c034cLh0bmGG0=OPh`3JhNH0f>;U0=WTj03KhnP0g>CX0=cVj03L
i^X0g>KX0=SRi03Li>L0g^KX0>;Uj@3Qi^T0i>O/0=kTi`3Ri^X0i>OY0>S/k`3]l_<0l_Gf0?Ogn@3g
moP0mOGf0080m_Oh00X0m_Kg0?SgnP3fmOD0kNOY0=K:bP2o[:40SZMU05bf=@0[h1H03?P64P00o`08
oooooaH00?l000<0`:000;Ph]02P8?002@2P8?000`2h>;@0d51h0=1@N0020=1@N080j6Pl603oP000
1P3@D7P0j6Pl0=1@N030X000P<00043P01800?l02oooool000[ooooo1P00o`00CP0ocQX0KEXf07QZ
C@22MEd0L6MB06YTD@1XIUH0P7e]09:8M@2LU7h0T8Yd09J@O02IUH80U8]k09J>O02HSGh0W96409jF
R@2PWHl0WIF809jFR02MUhH0ViF409VDPP2JTX40VY2109R>P`2HSXD0SXR507]nP@1NJ6h0CemV04QI
F`1?GU/0L7Ud09^SW02ma[h0e]cH0>;Wi`3[kO80j>S`0=gJhP30^l80ZjFZ09RBU`23O7l0Nfm]07e[
H`21JU`0Q71K08ekI02GQ7<0XHn00:6?N@2QSg40WHQV09InG@2?ME<0UgI>08m`BP27KTP0Pfe;0:BE
O@2NTW/0Wi=o09Z>NP2OUh80Vhmj09R<NP2BSX80JVe[04IBCP15E4H0BUE5051DAP1eLU/0Q7EJ07IM
?P@00?l02Oooool6003o00030830003oP000X23`0280X23`1@3oP00=0:0Pl0L0oh003`2P8?000`3o
P0000?l0003o0002003o00Sooooo5`00o`00500/cPh0MGdj08R1L021Qh00TI^H0:6[ZP2W/kD0/Kc1
0;W3aP2nal/0_<K:0<7=c`33cm80aLoC0<SAe037dMD0am;C0<C?d03:emL0d=[L0P3>f=X05P3Dfmh0
fN3S0=_Ph`3Jh><0gN;U0=_Ti@3OiND0hNGW0>GYj`3Yjnh0k>g`0>o`l@3bl_@0m??e0?;_l03Vg]d0
f/S30<baX`2K[fd0F<@j04KC9@0<n0HF003o00Sooooo5`00o`000`20`000j6Pl0;Ph]00@0:0Pl003
0>QX?02h>;@0d51h0100oh0000<0j6Pl0?n0003@D7P00P20`0000`10h0000?l0003o000D003o00_o
oooo000:ooooo`H00?l004h0CZDD07iW@@26N5H0JV5504e;=P1CDd80GV5D07inL@2?QgD0VY5m08n:
M@2CSW/0RX9_09:6LP2DQFl0T85Y09B4KP2ERWL0TXej09J=O@2ESW`0Uhik09R?NP2GSg/0Vi5m09^C
P02LTh00UXil07]mLP1GGEX0@Da804]FC@1fO700Oge`09N?Q02TWIL0[:BT0:VQY02KTY<0SX6008If
L`2;Mf/0TGUU09InI@2NQVl0XHQ]0:67I@2LOED0U7M@08YhG@2BQVd0V8]b0::HP`2WWXX0ViB209:>
OP24PgD0MW=S08aaC@2PNDT0W7Q708]/A@2RSgH0WHae09^9L`2CPFX0R7MM08AdF@1oMFH0JFm/04YG
EP1:Ee00Cea?05=ND01KIEH0PhYk08V2J`28KD/4003o00Wooooo1P00o`000`30X000oh000=1@N00P
0:0Pl0030;Ph]03@D7P0d51h00<0X23`00<0^3Rd0=1@N03@D7P00P3@D7P30?n000030=1@N02P8?00
X23`00H0X23`103oP0040:0Pl0030=1@N02h>;@0X23`00P0X23`00<0oh00003o0000o`000P00o`08
oooooaT00?l002D0=lPD062O<@2>NUT0UX]j0:FQVP2^/jh0/KRe0;Jn_@2f`L40]l310;o7bP33bld0
`l[<0;k;c@30bl`0_lO:0;k8b@34c/h0alo@0<O?d@39d=40c]CF0=;Gf03FfM/0fmcK0=WLf@3LgMX0
f]GF0=C;bP3Fb/H0d/>j0<fdXP2_]H<0T[UY06O2@`1AcB`09>XB01/00?l02?oooolI003o00040830
003XJ3`0d51h0;Ph]140X23`00<0^3Rd0?n0003oP000103oP0000`3XJ3`0d51h0>QX?0030?n00003
0<2P0020`000P<0001/00?l02oooool000[ooooo1P00o`00CP1ZSB80S7AA075YC@1@CcL0C4lj04m@
?`1?DD<0IFIL08J2M@2CRgX0VI:009RAOP2NTgh0UHUb09N7KP2IRW00R7IM09J3J@2MSW<0UhU_09F7
J`2FQ6H0V8=V09R4IP2IQFX0W8eg09j?NP2LSWX0PW]V06eWDP1eK5D0OW9F09:0I02COEd0W85P0:B:
JP2FPVH0UHMb0;NZV@30]:L0X9B009B4I`2IR6L0T8Y`07UhJP29Pg40TH5S0:64F@2DNU80Ge]807Eh
KP24PWH0W9R>0;6[X@2ETHH0OGU]06e^GP1`JU80V7]>0:ImB02RNdL0VG]A095lH02=N5`0SW]N08eo
HP24NV<0NgMW05aUG@1@GeD0DEiC05UTE`1MIU/0HFeQ06ehK@21RX40[jfN08a`C0@00?l02Oooool6
003o0080oh004`2P8?030=1@N0030;Ph]02P8?00X23`00<0X23`00L0^3Rd0=1@N03@D7P0j6Pl0?n0
003XJ3`0d51h0080X23`00@0d51h0:0Pl02h>;@0d51h0`2P8?000`3@D7P0oh000?n000090:0Pl0@0
oh0000@0^3Rd0=1@N03@D7P0d51h2`2P8?000`3@D7P00?l0003o0002003o00Sooooo7000o`00700O
i@/0><TI04Nj:`1cWdH0M:9>096MJ@2YUH00[9^:0;:RV02fZ9h0]:ZO0;N^X`2f[J@0^JbR0;V[X@2j
[:80_ZjS0;n]W`2kZYP0_jVE0;2YP02:^6T0OKQH05G7>P1HaCD0D<`Y033T6@0Uja4Q003o00Sooooo
7000o`03083000D0d51h1`2P8?000`3@D7P0oh000?n000020?n000<0d51h00<0J:Pl08300020`000
0P20`00Q003o00_ooooo000:ooooo`H00?l004h0WW@g08]fEP1lNfT0CeA404mD@`1?E4D0DeI805=G
BP1SIEh0OWmd08^9NP2ESW/0WIF10::FQ02BQVh0VXab09b<LP2DPVT0Wi9g0::FO@2JSG<0VXi_09b=
L02MS700VhU/09^:LP2KRg80Wi1g0961I@2>N5D0Rg140:V<H02fUVh0/IA]0:f?J`2/Sfh0ZY9c0::@
NP2NTh<0VY>209ZCO`2GTW/0TY5l0:FXV02NXiL0QX5c08A`E02^Sf@0WGa>07QXC01XHU@0P75M09:7
L@2bZiT0Ui>407egJP1nNfP0RW]L09anC@2LNd/0Z8iV0:^LO`2YWHT0[jJF0:RST`2;Rgh0KG5X05iV
H@1MJF40Gf]K05iYFP1QKUl0IW9X06YgK@1dOgH0Q8^509ZCQ02GMTT4003o00Wooooo1P00o`000`3o
P000d51h0:0Pl00J0:0Pl0P0oh002@2P8?030?n000P0X23`00@0d51h0?n0003oP000oh00402P8?00
0`3oP0000?l0003o0002003o0<gooooo000:ooooo`H00?l004h0MYT]08YjG01oP7@0H6IJ05ELC@1A
FDT0EEe>05IMC`1HGU<0HFMO07anM`2ASh80V9B40:2JR`2OVHL0WiJ40:BLRP2UWHX0Xib90:RQT@2S
VhX0X9Z709jHQ@2PUXD0WYAo09ZAOP2JTW/0Vi=m09^>MP2IOe`0XhAF0:nEJ`2XSVP0/I1Z0:V:IP2K
PfL0X8EY095nJ`27QW`0Z:^N0:b]X02l_;40/:jS096<OP21OV`0R7QL0:25GP2ZRET0Y7i;0:64G02D
P6<0YXib0;NUT`3JdLh0YYnJ07a^GP23M5P0VHAR0:NBK@2`XXL0/JRG0:bWV`2SXIX0RXb707f0N@1Z
LFH0IVeT06Q^J01WLFT0Jg=Y06agK@1WMF`0K7Yd071kN01lQH00SH^208aiH01fVS44003o00Wooooo
1P00o`000`3oP000d51h0:0Pl00I0:0Pl0030;Ph]03oP000oh0000@0oh0000<0d51h0?n0002h>;@0
1`2P8?000`2h>;@0oh000?n000020?n000080=1@N03XJ3`0^3Rd0=1@N02h>;@0X23`0=1@N03oP002
0=1@N100X23`00<0d51h0?n00000o`000`00o`3=ooooo`002_ooool6003o001>06N/9P2FQVP0O7i_
06acJ01OIe`0Ff5H05IPE01JHUH0GFMI05mZF`1TIel0JVaV07QjL`2>SHH0WY^C09bJT02KVH`0WIV;
09nKS@2NVHX0Xif>0:>NS@2/YID0[ZFI0:bSU@2XXi<0[Z^K0:RRT`2YXI40WHih09=jF@2LQ5d0WXQR
0:n?K@2UR6/0SgaU09QmIP2QQg<0ZYnH0<O2`@2a[JT0YibH09N8N`2>OV<0TWaI09n3F02^U6`0[9E_
0:V?J02ZU6`0Z9E`0:JCM@2UUGd0Z9V60:RGO`2VUWh0]:JC0;N/W@2/Z9d0WIjH08f@R`25RH<0MGYc
07IjL`1eNg80O8Ai0867O`1nQWh0Lh1j071oN01bPGX0KH1j07V6PP22R8<0RXV008UgGP2<Rcl05^l8
1000o`09ooooo`H00?l000<0`:000=1@N02P8?006`2P8?001P3XJ3`0oh000?n0003oP000j6Pl0:0P
l080d51h00<0X23`0=1@N02P8?000P2P8?001@3@D7P0j6Pl0?n0003oP000j6Pl0080oh000P3@D7PG
0:0Pl0030;Ph]03oP000@>0000@00?l0cOooool000[ooooo1P00o`00C00Yg@d0WhUT07ahI@1aMVP0
J7=X06=^I@1NJUl0GFMN06A^H@1XL6@0JW5W06M/H`1XKfH0JFaT06a^I`21PG/0V9F>09nMT`2YYId0
Y:6G09nOSP2KVHL0VIB409fFR@2IU8L0TXn109J@P`2JTH@0VY6109R@N02HS6d0VHQQ09R5G`2HPf40
UhEX08MgG@2AO640UX1U09^:M02NSgd0YIAo0:VGP02dWh<0^:F20;n^S@2n/940`kVN0;F[UP2f[IT0
^;2M0;F_V`2f[Yl0/:RG0;f_W`2jZiX0]j^P0:bVWP2RWYT0Shf908J:Q020QGl0PXF308:8P020QG`0
QH^208fES@25RhP0O8N307J2OP1jQX80OHV207b:Q@26T8X0Rhf508AiIP28Qch6003o00Wooooo1P00
o`000`20`000d51h0:0Pl00L0:0Pl0<0oh000`2P8?000`3@D7P0X23`0:0Pl0020:0Pl0040=1@N03o
P000oh000?n001d0X23`00<0oh00003o0000o`001000o`3=ooooo`002_ooool7003o001;082A>02B
Of80NWMV07YoMP1aNW@0JGA]06=`J01WLfT0JGE[06mhK`1_MFT0M7]^079iK01bMFT0L7A/07=gL01g
N700PGmj08N8PP2?TXX0W9fD0:BTV02YYih0[JZP0;6_X`2`[Z40/JbN0:VSTP2_ZiH0[j^E0;B/VP2f
[IL0_KBN0<:kX`34_J@0bl>Y0=?9/P3IdK`0g]G20>7IaP3Ke<00d<Nd0<g6]03=b;P0b<Je0<K5]@32
`K@0`L2f0;bl]@2j^[40^;F^0;Z`YP30[j@0/j>K0:>JU02KUY40ViRC09NIU02EVI@0TiJC09>FU02=
U8d0Ri><08ZBR`27Thl0PXn>082?S020ShP0QY2;08^BS02>U8l0THn708enI`1jScl08^P>00H00?l0
2Oooool7003o00030?n0003@D7P0X23`01h0X23`00<0^3Rd0=1@N03oP0001P3oP0020=1@N0030;Ph
]02P8?00X23`00D0X23`00<0d51h0:0Pl02P8?004@2P8?000`3@D7P0j6Pl043P0006003o0<gooooo
000:ooooo`L00?l001002oL406F/9P2?Qe@0UI:308J;Q01oR880Lgmh071kM01`NgD0M85i07AoLP1l
PWP0OH9h08>7OP27S8@0MW]b0P1eNg<0=`1dOWD0MGii07UnNP1kOg`0NX200827R02;U9@0UYnP09fV
Y02V[ZP0ZJnY0;Bi/`2h_KD0a/^o0<cBa`3Eflh0h^GJ0>_]i03cl^`0n_We0?cln@3mo?X0nOWe0?Ge
l03alnh0jncY0>?Wh@3GgmX0cmWE0<gFe@30alT0`lO70<?4`P38aKh0`kjh0<2m]`2l_KP0]KJb0;6c
[P2WZjT0XJVX09^RXP2LXZ40U9jL09BNW@2@ViT0SIVF08nKU`2@W9T0SiVE092DS`2GUH/0U8Eb07:K
?@11dA`02000o`09ooooo`L00?l000<0@>000?n0003XJ3`07@2P8?020>QX?0`0oh000P3@D7P20:0P
l0030;Ph]03@D7P0X23`0140X23`00<0^3Rd0>QX?020`0002000o`3=ooooo`002_ooool9003o000Q
01C_201jY4<0WX]^09^EQ@2>U8T0Qi6907R3OP1oSHL0PHb607n7Q020RHH0Qi:<08^DSP2;TX`0RXn:
08VAR`25T8X0TijJ08jGU029TY00OHN708JBTP2?W9/0SY^K096NWP2LYjL0Z;6`0;Jo_`2oc<T0bmGC
0=GNg@3TjnT0m_Wi0080o_kn00@0oOgn0?knoP3no_d0oOkm0P3no_h0703loOd0lOCd0>K/k03Tk>`0
hNSY0=GMgP3Ggml0e]cL0=GGe`3@d/l0d=?A0<76a@2j`L40][fm0:^c/`2W/:l0YZn]0::/Z`2NZJT0
WJRX09bVY02GWI`0U9JE08j>R02:P6d0Oha=04Vj9`0[h1<:003o00Wooooo2@00o`000`10h000j6Pl
0=1@N00J0:0Pl0030=1@N03XJ3`0oh000140oh0000<0j6Pl0=1@N03XJ3`03@2P8?00102h>;@0d51h
08300020`00:003o0<gooooo000:ooooo`/00?l002<0;N4C08V9@P2MSgD0VYZ<08N;P02=UHd0T9VF
08nJV029U980S9JC08nKV@2@ViX0T9VH09VRW`2JXj<0WjVX09:LV`2QZjL0QI>>09>RWP2U/:d0];jm
0;O2_`2ma/D0]Kbl0<[@dP3Fg^40fN7P0>3Ui`3XkNh0loKg0?oooP3no_h0oOgn0?gmo@030?gmoP0J
0?knoP3fm_L0l_Ce0>[_k`3Yk^h0ing]0=gRi03Pi^P0gN7S0=OLg03<dM40b/o?0<G9bP30aLL0]K^l
0;Rm_@2b]kL0ZZna0:Z`/@2T[Jh0WZJW09VKW02>QGl0SGUY09AfE01D`2H=003o00Wooooo2`00o`02
0?n001L0X23`00<0d51h0?n0003oP000503oP00>0:0Pl080oh003@00o`3=ooooo`002_ooool=003o
000m03c>701P/3/0XHQW09b=N02NVHl0V9VB09NKV02HWY`0VZBS08^HU`2=UiL0WJRW0::][P2S[J`0
Oh^90::^Z`2W]:l0YK:_0;S1`P34c]00b=7B0=CLgP3Af=T0fn3R0=WOh@3Qi^P0j>g^0>g`l@3hnOX0
oOgm0?ooo`3moOd0o_kn0?gnoP3no_h0oOgm0?ooo`3kno/0mOOg0>obl`3]lO<0jo3a0>7Wj03Qi^P0
fn3R0=?If@3AfMH0c=7A0<K;c@35blX0_L;20;Vm`02d^KT0[k2a0:BSX`2HT8X0V8Uh08B@FP1G]340
9]`C01Oa2`0>003o00Wooooo3@00o`001020`000Z8Pl0=1@N02h>;@A0:0Pl0030?n0003@D7P0oh00
01L0oh0000<0^3Rd0:0Pl02P8?001P2P8?020=1@N0030<2P0020`000@>0000h00?l0cOooool000[o
oooo4000o`00=P0]hA@0D;dY07ZQA@2KT6@0Wh]e0:FGRP2[XIL0[JRQ0:j^Z`2_/[40/KFb0:ne[`2f
_;T0]ko00;[1a02maLP0`<S;0<S>d@3?f=X0dM[K0=SOh03PjNP0ing_0>cal@3fmoH0o_gm0?ooo`3n
o_h0o_gm0?gmo@3no_d0o_kn0?kno@3no_h0o_ko0?_mo03hnOT0m?Gg0>_^l03UjN/0hnKY0=cOhP3H
g=d0d=CE0<[<b`2l_K/0[jbY0:^SW02VUHH0QZ=Q07jXCP1M^CD0:n4G01[c3A800?l02Oooool@003o
0080P<0000<0oh000=1@N03@D7P03@2P8?000`3@D7P0oh000?n0000F0?n000030=1@N02P8?00X23`
0080X23`00@0^3Rd0=1@N03@D7P0`:000P20`00B003o0<gooooo000:oooooa@00?l001h06?4;05>n
9P2YPE40XX1N0:V@NP2bWhh0^jVM0<Fg[`3:_K`0a[no0;nl_P34`lD0aLK40<g?cP3AemH0f^7O0=gQ
hP3VkN`0jnk_0?GfmP3jno/0oOgm0?koo@3no_h0o_gm0?gmo@3no_h0o_on0?kno@3mo_h20?gmoP0=
0?Kfn@3em_T0k>__0>SVj@3MfMd0c/S90;fbZ`2`XID0Z99o0:N8I022YDL0G<Lb03CX6P0G003o00Wo
oooo5000o`001@20`000oh000?n0003oP000d51h00P0X23`00<0d51h0?n0003oP0005@3oP000103@
D7P0X23`0:0Pl02P8?030?n0000308300000o`000?l001D00?l0cOooool000[ooooo6000o`009P0]
hAD0GLH]04[89P21]4/0S[1J08Z`G`2>^6X0W;Yl0<F_V034/9l0bKV]0<g1]`3@al80e/g90=K=b`3S
f]P0jn?P0>_ShP3[i>@0k>CS0>gThP3`i^@0k^CR0>WNg03ReM40g<k70=c;`@3F`[H0d;VX0<^aV`2C
`7<0SkUX08jeG`1o]Th0G<Pc02gS6@0cia`06o@=6P00o`09oooooaP00?l00`20`0020?n000030=1@
N03oP000j6Pl00<0oh00103@D7P90?n000030>QX?03@D7P0oh0000<0oh000`3@D7P01@3oP000P<00
08300020`000@>0001X00?l0cOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {177.5, 0}} -> {-0.107233, -0.0446483, \
0.0105626, 0.0105626}, {{10.125, 98.1875}, {173.25, 4.1875}} -> {-17.1322, \
-6.21784, 1.692, 1.692}, {{107, 195.062}, {173.25, 4.1875}} -> {-181.044, \
-6.21784, 1.692, 1.692}, {{203.875, 291.938}, {173.25, 4.1875}} -> {-393.575, \
-30.3891, 1.93047, 1.93047}, {{300.75, 388.812}, {173.25, 4.1875}} -> \
{-580.589, -30.3891, 1.93047, 1.93047}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Coke\>", "\<Coke Light\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.0067664 [
[.27273 -0.0125 -14 -12 ]
[.27273 -0.0125 14 0 ]
[.72727 -0.0125 -32 -12 ]
[.72727 -0.0125 32 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15004 -12 -4.5 ]
[-0.0125 .15004 0 4.5 ]
[-0.0125 .28537 -12 -4.5 ]
[-0.0125 .28537 0 4.5 ]
[-0.0125 .4207 -12 -4.5 ]
[-0.0125 .4207 0 4.5 ]
[-0.0125 .55603 -12 -4.5 ]
[-0.0125 .55603 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -14 0 ]
[.27273 .63053 14 12 ]
[.72727 .63053 -32 0 ]
[.72727 .63053 32 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -93 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15004 m
.00625 .15004 L
s
[(20)] -0.0125 .15004 1 0 Mshowa
0 .28537 m
.00625 .28537 L
s
[(40)] -0.0125 .28537 1 0 Mshowa
0 .4207 m
.00625 .4207 L
s
[(60)] -0.0125 .4207 1 0 Mshowa
0 .55603 m
.00625 .55603 L
s
[(80)] -0.0125 .55603 1 0 Mshowa
.125 Mabswid
0 .04855 m
.00375 .04855 L
s
0 .08238 m
.00375 .08238 L
s
0 .11621 m
.00375 .11621 L
s
0 .18388 m
.00375 .18388 L
s
0 .21771 m
.00375 .21771 L
s
0 .25154 m
.00375 .25154 L
s
0 .3192 m
.00375 .3192 L
s
0 .35304 m
.00375 .35304 L
s
0 .38687 m
.00375 .38687 L
s
0 .45453 m
.00375 .45453 L
s
0 .48836 m
.00375 .48836 L
s
0 .5222 m
.00375 .5222 L
s
0 .58986 m
.00375 .58986 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15004 m
1 .15004 L
s
.99375 .28537 m
1 .28537 L
s
.99375 .4207 m
1 .4207 L
s
.99375 .55603 m
1 .55603 L
s
.125 Mabswid
.99625 .04855 m
1 .04855 L
s
.99625 .08238 m
1 .08238 L
s
.99625 .11621 m
1 .11621 L
s
.99625 .18388 m
1 .18388 L
s
.99625 .21771 m
1 .21771 L
s
.99625 .25154 m
1 .25154 L
s
.99625 .3192 m
1 .3192 L
s
.99625 .35304 m
1 .35304 L
s
.99625 .38687 m
1 .38687 L
s
.99625 .45453 m
1 .45453 L
s
.99625 .48836 m
1 .48836 L
s
.99625 .5222 m
1 .5222 L
s
.99625 .58986 m
1 .58986 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .23173 L
.72727 .23173 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .23173 L
.72727 .23173 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .10275 L
.45455 .10275 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .10275 L
.45455 .10275 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .47434 L
.90909 .47434 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .47434 L
.90909 .47434 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3oool/0?ooo`?o0000HP3oool00?l0oooo;`3oool00ol00000oooo
0?ooo`1O0?ooo`00M`3oool2o`0000<0oooo0ol000020?ooo`;o000000<0ooooo`000?l000000P3o
ool3o`0007L0oooo0_l000030?ooo`?o00000P3oool2o`0000030?ooool0003o00000080oooo0ol0
00080?ooo`Go000000<0ooooo`000?l000000ol000020?ooo`Co000000<0ooooo`000?l000001?l0
00020?ooo`;o0000EP3oool007H0oooo00Ko00000?ooo`3ooooo00000?ooool000030?ooo`06o`00
003oool0ooooo`00003ooooo00000P3oool00ol00000oooo0?ooo`1g0?ooo`06o`00003oool0oooo
o`00003ooooo00000`3oool01_l00000oooo0?ooool00000ooooo`000080oooo00?o00000?ooo`3o
ool02P3oool01?l00000oooo0?ooool000030?ooo`05o`00003oool0oooo0?ooool000000`3oool0
1?l00000oooo0?ooool000020?ooo`04o`00003oool0ooooo`000080oooo00?o00000?ooo`3oool0
D`3oool007D0oooo00?o00000?ooo`3oool00`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo
0_l000030?ooo`Go0000M03oool00ol00000oooo0?ooo`030?ooo`05o`00003oool0oooo0?ooool0
00000P3oool2o`0000<0oooo1Ol000080?ooo`03o`00003oool0oooo00@0oooo00Go00000?ooo`3o
ool0ooooo`0000030?ooo`04o`00003oool0ooooo`000080oooo00Co00000?ooo`3ooooo0000F03o
ool007D0oooo00?o00000?ooo`3oool00`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00?o
00000?ooool000000P3oool01Ol00000oooo0?ooo`3ooooo000007@0oooo00?o00000?ooo`3oool0
0`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00?o00000?ooool000000P3oool01Ol00000
oooo0?ooo`3ooooo000000P0oooo00?o00000?ooo`3oool0103oool01Ol00000oooo0?ooo`3ooooo
000000<0oooo00Co00000?ooo`3ooooo00000P3oool01?l00000oooo0?ooool0001H0?ooo`00M@3o
ool00ol00000oooo0?ooo`040?ooo`?o00000`3oool01?l00000ooooo`000?l000020?ooo`?o0000
M@3oool00ol00000oooo0?ooo`040?ooo`?o00000`3oool01?l00000ooooo`000?l000020?ooo`?o
00002@3oool00ol00000oooo0?ooo`020?ooo`?o0000103oool5o`0000040?ooool0003o0000o`00
0080oooo1?l0001F0?ooo`00MP3oool01?l00000oooo0?ooool000080?ooo`03o`00003oool0oooo
07`0oooo00Co00000?ooo`3ooooo0000203oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`1F0?ooo`00M`3oool3o`00
00L0oooo0_l0001o0?ooo`?o00001`3oool2o`000100oooo0ol000050?ooo`03o`00003oool0oooo
00L0oooo0_l000050?ooo`03o`00003oool0oooo05H0oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo000R0?ooool00000
G000000C0?ooo`008P3oool00`000000oooo0?ooo`1L0?ooo`03o`00003oool0oooo09X0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`006P3oool2o`0000H0oooo00<00000
0?ooo`3oool0G03oool00ol00000oooo0?ooo`2J0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool04@3oool001T0oooo00Co00000?ooo`3ooooo00001@3oool00`000000oooo0?ooo`3o
0?oooeP0oooo00<000000?ooo`3oool04@3oool001T0oooo00Co00000?ooo`3ooooo00001@3oool0
0`000000oooo0?ooo`3o0?oooeP0oooo00<000000?ooo`3oool04@3oool001T0oooo00Co00000?oo
o`3ooooo00001@3ooooo000005`000004`3oool001T0oooo00Co00000?ooo`3ooooo00001@3oool0
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000I0?ooo`04o`00003oool0oooo
o`0000D0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`006P3oool2o`00
00H0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo
00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`<000007@3oool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool0703oool00ol0000000000?ooo`0B0?ooo`008P3oool0
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?oo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo0`00000M0?ooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0L0?ooo`03o`0000000000oooo
0180oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP
8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP
8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000
003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`0o000001l0oooo00<00000oomo0?ooO`00
??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool0
4@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003o
ool0oooo05/0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003o
ool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool0
0`00003oogl0oomo000loomo00030000003oool0oooo05/0oooo00<00000oomo0?ooO`00??ooO`00
0`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool0
0280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo
05/0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003o
ogl0oomo000loomo00030000003oool0oooo05/0oooo00<00000oomo0?ooO`00??ooO`000`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo
0`00000M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0
oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool0703oool00ol000000000
0?ooo`0B0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M
0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000l
oomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A
0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?oo
o`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`03
00000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo0003
00000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`00
8P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0
F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?oo
O`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool0
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl0
03coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool5o`0000<0
oooo0_l000060?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000
oooo0?ooo`1K0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000C0?ooo`04o`00003oool0ooooo`000080
oooo00Co00000?ooo`3ooooo00001@3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl0
03coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`00503oool00ol00000
oooo0?ooo`020?ooo`04o`00003oool0ooooo`0000D0oooo0`00000M0?ooo`0300000?ooO`3oogl0
03coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool06`3oool3000001<0oooo000E0?ooo`05o`00003oool0oooo0?oo
ool000000P3oool00ol00000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`1K0?ooo`0300000?ooO`3oogl003coogl000<00000oj0P
l?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000B0?ooo`05
o`00003oool0oooo0?ooool000000P3oool01?l00000oooo0?ooool000050?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`1K0?ooo`0300000?ooO`3o
ogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0140oooo000B0?ooo`05o`00003oool0oooo0?ooool000000P3oool01?l00000oooo0?ooool0
00050?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`1K0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0140oooo000C0?ooo`?o0000103oool2o`0000H0oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo05/0oooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo05/0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo05/0oooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo05/0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo05/0oooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3o
ool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0
oooo05/0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00
003oogl0oomo000loomo00030000003oool0oooo05/0oooo00<00000oomo0?ooO`00??ooO`000`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo05/0
oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0
oooo00<000000?ooo`3oool04@3oool00280oooo0`00000M0?ooo`0300000?ooO`3oogl003coogl0
00<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool0703oool00ol0000000000?ooo`0B0?ooo`008P3oool00`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?oo
o`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo
000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3o
ool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3o
ool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00
003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003co
ogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_o
X23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0
oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool3000001d0oooo00<00000
oomo0?ooO`00??ooO`000`000000oooo0?ooo`1K0?ooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0L0?ooo`03o`0000000000oooo0180oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`1K0?oo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`1K0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP
8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000
003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`1K0?ooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`1K0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`1K0?oood000000?OnP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`<000007@3oool00`00003oogl0oomo000loomo0003
0000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0L0?ooo`03
o`0000000000oooo0180oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00
??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?oo
O`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003o
ool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool0
0`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool001@0oooo0ol000030?ooo`;o00001P3oool00`000000oooo0?ooo`0M0?oo
o`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool001D0oooo00Go00000?ooo`3o
ool0ooooo`0000020?ooo`03o`00003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`00
003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000B0?ooo`Go00000P3oool01?l00000
oooo0?ooool000050?ooo`<000007@3oool00`00003oogl0oomo000loomo00030000003oool0oooo
09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0K0?ooo`<000004`3oool00180
oooo00Co00000?ooo`3ooooo00000`3oool01?l00000oooo0?ooool000050?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00ol0
0000ooooo`0000030?ooo`04o`00003oool0ooooo`0000D0oooo00<000000?ooo`3oool07@3oool0
0`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000D0?ooo`;o00000`3oool01?l0
0000oooo0?ooool000050?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`00
0`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0A0?ooo`005@3oool00ol00000oooo0?ooo`020?ooo`;o00001P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`03
00000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl003
0000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool0
7@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00
>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`<000007@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0L0?ooo`03o`0000000000oooo0180oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`03
00000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl003
0000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool0
7@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00
>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003o
ool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool0
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool0
0`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool0
0280oooo0`00000M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01`0oooo00?o00000000003oool04P3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`03
00000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl003
0000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool0
7@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00
>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003o
ool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool0
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool0
0`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool0
0280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo
09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0140oooo000R0?ooo`<000007@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0L0?ooo`03o`0000000000oooo0180
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`03
00000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl003
0000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool0
7@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00
>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003o
ool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool0
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool0
0`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool0
01<0oooo0ol000040?ooo`;o00001P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl0
03coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01d0oooo00<000000?ooo`3oool04@3oool00180oooo00Go00000?ooo`3oool0ooooo`0000020?oo
o`04o`00003oool0ooooo`0000D0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000B0?ooo`05o`00003oool0oooo0?ooool000000P3oool0
1?l00000oooo0?ooool000050?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`004P3oool4o`0000<0oooo00Co00000?ooo`3ooooo00001@3o
ool3000001d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool06`3oool3000001<0oooo000B0?ooo`03o`00003oool0
oooo00@0oooo00Co00000?ooo`3ooooo00001@3oool00`000000oooo0?ooo`0M0?ooo`0300000?oo
O`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003o
ool0oooo01d0oooo00<000000?ooo`3oool04@3oool001<0oooo00?o00000?ooo`3oool00`3oool0
1?l00000oooo0?ooool000050?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`00503oool2o`0000@0oooo0_l000060?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`03
00000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl003
0000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool0
7@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00
>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`<000007@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0L0?ooo`03o`0000000000oooo0180oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooocl000007`3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3o
ool0n03oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`008P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0n03o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool3000001d0oooo00<00000oomo0?ooO`00??ooO`00
0`000000oooo0?ooo`3g0?ooo`03o`0000000000oooo0180oooo000R0?ooo`030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000003oool0oooo
0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000
oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`3h0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000
oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000
003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000003oool0
oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00
0000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000R0?ooo`<000007@3oool00`00003o
ogl0oomo000loomo00030000003oool0oooo0?L0oooo00?o00000000003oool04P3oool00280oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo0?P0oooo
00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo
000loomo00030000003oool0oooo0?P0oooo00<000000?ooo`3oool04@3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo0?P0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo0?P0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo0?P0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo0?P0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo0?P0oooo00<000000?ooo`3oool04@3o
ool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0
oooo0?P0oooo00<000000?ooo`3oool04@3oool001<0oooo0ol000040?ooo`;o00001P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0n03oool00`00
0000oooo0?ooo`0A0?ooo`004P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co00000?oo
o`3ooooo00001@3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`004P3oool01Ol00000oooo0?ooo`3ooooo
00000080oooo00Co00000?ooo`3ooooo00001@3oool00`000000oooo0?ooo`0M0?ooo`0300000?oo
O`3oogl003coogl000<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`004`3oool3
o`0000<0oooo00Co00000?ooo`3ooooo00001@3oool3000001d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`3f0?ooo`<000004`3oool00180oooo00Go00000?ooo`3oool0ooooo`00
00020?ooo`04o`00003oool0ooooo`0000D0oooo00<000000?ooo`3oool07@3oool00`00003oogl0
oomo000loomo00030000003oool0oooo0?P0oooo00<000000?ooo`3oool04@3oool00180oooo00Go
00000?ooo`3oool0ooooo`0000020?ooo`04o`00003oool0ooooo`0000D0oooo00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo0?P0oooo00<000000?ooo`3o
ool04@3oool001<0oooo0ol000040?ooo`;o00001P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`008P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0n03o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0n03oool00`00
0000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003co
ogl000<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0n03oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M
0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0A
0?ooo`008P3oool3000001d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3g0?oo
o`03o`0000000000oooo0180oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000
003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`3h0?ooo`030000003oool0
oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo@000003j0?ooo`030000003oool0oooo
0140oooo000R0?ooo`030000003oool0oooo0?l0ooooF03oool00`000000oooo0?ooo`0A0?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oooeP0oooo00<000000?ooo`3oool04@3oool00280oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04@3oool00280ooooo`00001L0000
01<0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?ooob`0oooo0ol0001R0?ooo`00o`3oool_0?ooo`03o`00003oool0oooo05l0oooo
001g0?ooo`;o00000`3oool3o`000080oooo0_l000000`3ooooo0000o`0000020?ooo`?o0000M`3o
ool2o`0000<0oooo0ol000020?ooo`;o000000<0ooooo`000?l000000P3oool3o`0000P0oooo1Ol0
00000`3ooooo0000o`000003o`000080oooo1?l000000`3ooooo0000o`000004o`000080oooo0_l0
001F0?ooo`00MP3oool01_l00000oooo0?ooool00000ooooo`0000<0oooo00Ko00000?ooo`3ooooo
00000?ooool000020?ooo`03o`00003oool0oooo07L0oooo00Ko00000?ooo`3ooooo00000?ooool0
00030?ooo`06o`00003oool0ooooo`00003ooooo00000P3oool00ol00000oooo0?ooo`0:0?ooo`04
o`00003oool0ooooo`0000<0oooo00Go00000?ooo`3oool0ooooo`0000030?ooo`04o`00003oool0
ooooo`000080oooo00Co00000?ooo`3ooooo00000P3oool00ol00000oooo0?ooo`1C0?ooo`00M@3o
ool00ol00000oooo0?ooo`030?ooo`05o`00003oool0oooo0?ooool000000P3oool2o`0000<0oooo
1Ol0001d0?ooo`03o`00003oool0oooo00<0oooo00Go00000?ooo`3oool0ooooo`0000020?ooo`;o
00000`3oool5o`0000P0oooo00?o00000?ooo`3oool0103oool01Ol00000oooo0?ooo`3ooooo0000
00<0oooo00Co00000?ooo`3ooooo00000P3oool01?l00000oooo0?ooool0001H0?ooo`00M@3oool0
0ol00000oooo0?ooo`030?ooo`05o`00003oool0oooo0?ooool000000P3oool00ol00000ooooo`00
00020?ooo`05o`00003oool0oooo0?ooool00000M03oool00ol00000oooo0?ooo`030?ooo`05o`00
003oool0oooo0?ooool000000P3oool00ol00000ooooo`0000020?ooo`05o`00003oool0oooo0?oo
ool00000203oool00ol00000oooo0?ooo`040?ooo`05o`00003oool0oooo0?ooool000000`3oool0
1?l00000oooo0?ooool000020?ooo`04o`00003oool0ooooo`0005P0oooo001e0?ooo`03o`00003o
ool0oooo00@0oooo0ol000030?ooo`04o`00003ooooo0000o`000080oooo0ol0001e0?ooo`03o`00
003oool0oooo00@0oooo0ol000030?ooo`04o`00003ooooo0000o`000080oooo0ol000090?ooo`03
o`00003oool0oooo0080oooo0ol000040?ooo`Go000000@0ooooo`000?l0003o00000P3oool4o`00
05H0oooo001f0?ooo`04o`00003oool0ooooo`0000P0oooo00?o00000?ooo`3oool0O03oool01?l0
0000oooo0?ooool000080?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo05H0oooo001g0?ooo`?o00001`3oool2o`00
07l0oooo0ol000070?ooo`;o0000403oool3o`0000D0oooo00?o00000?ooo`3oool01`3oool2o`00
00D0oooo00?o00000?ooo`3oool0EP3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -9.15519, \
0.00636706, 0.427719}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2d Gaussian classification (GB plane)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(which = {2, 3};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Show[gobj1, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Show[gobj2, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[g1, g2, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{g1, g2}], \ imSize, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.86275 .04706 Mdot
.71765 .09412 Mdot
.4902 .29804 Mdot
.43137 .22745 Mdot
.52549 .36471 Mdot
.72157 .10588 Mdot
.40784 .27843 Mdot
.42745 .31765 Mdot
.72157 .10588 Mdot
.25098 .17255 Mdot
.05098 .03137 Mdot
.48235 .31373 Mdot
.49412 .32157 Mdot
.07451 .0549 Mdot
.24706 .24314 Mdot
.42745 .19216 Mdot
.07059 .01569 Mdot
.08235 .05882 Mdot
.06275 .07059 Mdot
.43137 .2 Mdot
.01569 .00392 Mdot
.08235 .07059 Mdot
.02745 .02745 Mdot
.49804 .32941 Mdot
.01569 0 Mdot
.03529 .04706 Mdot
.02745 .02353 Mdot
.83137 .8 Mdot
.39216 .28235 Mdot
.01569 .02353 Mdot
.16863 .13725 Mdot
.01176 .01569 Mdot
.45882 .25882 Mdot
.01961 .02353 Mdot
.02745 .04314 Mdot
.03529 .03529 Mdot
.80392 .79216 Mdot
.40392 .27059 Mdot
.00784 .02353 Mdot
.0549 .03922 Mdot
.03529 .03137 Mdot
.65098 .61961 Mdot
.06667 .02745 Mdot
.02745 .03529 Mdot
.07059 .0549 Mdot
.04314 .04314 Mdot
.74118 .72157 Mdot
.0549 .02353 Mdot
.01569 .01961 Mdot
.06667 .05098 Mdot
.03922 .03529 Mdot
.82353 .80392 Mdot
.18039 .08627 Mdot
.01569 .02353 Mdot
.06275 .05098 Mdot
.51373 .46275 Mdot
.73725 .71373 Mdot
.84706 .04706 Mdot
.01569 .02353 Mdot
.03922 .03529 Mdot
.7451 .69412 Mdot
.02353 .01961 Mdot
.81176 .82353 Mdot
.01176 .02353 Mdot
.02745 .03529 Mdot
.11765 .09412 Mdot
.87451 .84706 Mdot
.84314 .82353 Mdot
.32941 .06275 Mdot
.01961 .01569 Mdot
.03922 .05098 Mdot
.90196 .89804 Mdot
.06275 .06275 Mdot
.83529 .84706 Mdot
0 0 Mdot
.02353 .02353 Mdot
.07059 .05098 Mdot
.89804 .90588 Mdot
.05882 .07843 Mdot
.81176 .82745 Mdot
.00784 .01176 Mdot
.01569 .02353 Mdot
.76078 .70196 Mdot
.90196 .90588 Mdot
.83137 .83529 Mdot
.62353 .59216 Mdot
0 .01176 Mdot
.02353 .03137 Mdot
.8902 .87843 Mdot
.88235 .88235 Mdot
.68235 .65098 Mdot
.6 .51765 Mdot
.01961 .01961 Mdot
.02745 .03529 Mdot
.8902 .87843 Mdot
.88235 .88627 Mdot
.67059 .62353 Mdot
.54902 .48627 Mdot
.05098 .05098 Mdot
.02353 .02745 Mdot
.89804 .89412 Mdot
.88235 .88235 Mdot
.11373 .10196 Mdot
.75686 .72549 Mdot
.0549 .03529 Mdot
.02353 .02745 Mdot
.8902 .87843 Mdot
.87451 .88627 Mdot
.01961 .03137 Mdot
.81569 .83137 Mdot
.08627 .03922 Mdot
.02353 .02745 Mdot
.86667 .86667 Mdot
.87843 .88235 Mdot
.04314 .04314 Mdot
.81569 .82745 Mdot
.00784 .00784 Mdot
.01176 .01176 Mdot
.75294 .67059 Mdot
.82745 .81961 Mdot
.85098 .84706 Mdot
.78431 .77255 Mdot
.00392 .01176 Mdot
.0549 .04706 Mdot
.07059 .06667 Mdot
.87451 .86275 Mdot
.86667 .86667 Mdot
.75294 .71373 Mdot
.14902 .08235 Mdot
.04314 .03137 Mdot
.02745 .03922 Mdot
.88627 .87843 Mdot
.05882 .06667 Mdot
.06275 .06667 Mdot
.83137 .84314 Mdot
.03529 .03529 Mdot
.05098 .04314 Mdot
.85098 .83137 Mdot
.07451 .07843 Mdot
.8549 .8549 Mdot
.80784 .79608 Mdot
.09412 0 Mdot
.04314 .03529 Mdot
.02745 .03137 Mdot
.78824 .78431 Mdot
.03922 .04314 Mdot
.02745 .03137 Mdot
.77255 .78431 Mdot
.02353 .02353 Mdot
.0549 .03922 Mdot
.84314 .83529 Mdot
.05098 .05882 Mdot
.84706 .84706 Mdot
.70196 .67059 Mdot
.1098 .00784 Mdot
.04314 .04314 Mdot
.02745 .02353 Mdot
.18824 .18824 Mdot
.03529 .03137 Mdot
.03922 .03922 Mdot
.81961 .83137 Mdot
.02353 .03137 Mdot
.05098 .03922 Mdot
.85098 .84706 Mdot
.07059 .05882 Mdot
.82745 .80392 Mdot
.72941 .69412 Mdot
.28627 .18824 Mdot
.03922 .03922 Mdot
.07843 .05882 Mdot
.0902 .0902 Mdot
.03922 .04314 Mdot
.19216 .1451 Mdot
.81569 .82745 Mdot
.00784 .01569 Mdot
.05098 .04314 Mdot
.83922 .83922 Mdot
.07843 .06667 Mdot
.00392 .00784 Mdot
.33725 .32549 Mdot
.47843 .47059 Mdot
.01569 .02353 Mdot
.06275 .04314 Mdot
.41961 .41961 Mdot
.03137 .02353 Mdot
.84314 .84314 Mdot
.62353 .60784 Mdot
.14118 .13333 Mdot
.04706 .04314 Mdot
.74118 .7098 Mdot
.07059 .05882 Mdot
.03922 .03137 Mdot
.15686 .13333 Mdot
.75294 .76471 Mdot
.00392 .01176 Mdot
.05882 .03922 Mdot
.85098 .8549 Mdot
.66275 .60784 Mdot
.00784 .00392 Mdot
.17647 .18431 Mdot
.29412 .27451 Mdot
.01176 .02745 Mdot
.07059 .05098 Mdot
.0549 .05882 Mdot
.84706 .8 Mdot
.61961 .58431 Mdot
.65882 .64314 Mdot
.62745 .63529 Mdot
.04314 .03529 Mdot
.88627 .88627 Mdot
.08235 .03922 Mdot
.04314 .04314 Mdot
.06667 .0549 Mdot
.77255 .78039 Mdot
.00784 .02353 Mdot
.04706 .03529 Mdot
.6549 .62353 Mdot
.88627 .87451 Mdot
.00784 .01569 Mdot
.22353 .21176 Mdot
.45098 .44314 Mdot
.00784 .02745 Mdot
.07059 .0549 Mdot
.05098 .0549 Mdot
.87843 .88235 Mdot
.77647 .75686 Mdot
.66275 .64314 Mdot
.48235 .50196 Mdot
.03922 .04314 Mdot
.88235 .89412 Mdot
.85098 .81569 Mdot
.23922 .19608 Mdot
.03529 .04706 Mdot
.80784 .81961 Mdot
.00392 .00392 Mdot
.04706 .03922 Mdot
.12157 .09412 Mdot
.87843 .86667 Mdot
.02353 .02745 Mdot
.01569 .02745 Mdot
.60784 .61569 Mdot
.00392 .02745 Mdot
.07451 .05882 Mdot
.11373 .09412 Mdot
.87451 .87059 Mdot
.83529 .83137 Mdot
.68627 .67451 Mdot
.75294 .72549 Mdot
.04706 .06275 Mdot
.88235 .8902 Mdot
.88235 .86275 Mdot
.52941 .48627 Mdot
.04706 .04706 Mdot
.83529 .84314 Mdot
.00784 .01961 Mdot
.04706 .04706 Mdot
.07843 .05882 Mdot
.88235 .87843 Mdot
.02353 .02353 Mdot
.04706 .05098 Mdot
.57647 .58039 Mdot
.00784 .01176 Mdot
.0902 .06275 Mdot
.25882 .20784 Mdot
.80784 .77647 Mdot
.81176 .80392 Mdot
.23137 .21961 Mdot
.6549 .27059 Mdot
.03137 .0549 Mdot
.85882 .86667 Mdot
.86667 .86275 Mdot
.23529 .21961 Mdot
0 .00392 Mdot
.82353 .83529 Mdot
.01176 .01569 Mdot
.05882 .07059 Mdot
.05882 .04706 Mdot
.19608 .18431 Mdot
.02353 .02353 Mdot
.02353 .02745 Mdot
.83137 .86667 Mdot
0 0 Mdot
.05098 .03529 Mdot
.17647 .1451 Mdot
.08235 .03922 Mdot
.55686 .47451 Mdot
.03529 .05098 Mdot
.21176 .22353 Mdot
.01176 .01176 Mdot
.87843 .8902 Mdot
.85098 .85098 Mdot
.71373 .68627 Mdot
.03922 .03529 Mdot
.61961 .61176 Mdot
.36863 .35686 Mdot
.03529 .04706 Mdot
.06275 .04314 Mdot
.10588 .08627 Mdot
.03922 .05098 Mdot
0 .01176 Mdot
.81961 .83529 Mdot
.01176 .00784 Mdot
.04314 .04706 Mdot
.08627 .06667 Mdot
.07059 .03922 Mdot
.03137 .02353 Mdot
.02353 .02745 Mdot
.7451 .76863 Mdot
.00392 .00392 Mdot
.5451 .49412 Mdot
.84314 .83922 Mdot
.82353 .82353 Mdot
.80392 .79216 Mdot
.01961 .01569 Mdot
.34118 .24706 Mdot
.00784 .02353 Mdot
.22353 .2 Mdot
.85882 .83922 Mdot
.04706 .0549 Mdot
.00392 .01961 Mdot
.63137 .61569 Mdot
.28627 .31373 Mdot
.03137 .04314 Mdot
.04314 .04314 Mdot
.17255 .11373 Mdot
.02745 .03529 Mdot
.00784 .01176 Mdot
.77255 .80392 Mdot
0 0 Mdot
.06275 .04706 Mdot
.84314 .82745 Mdot
.86275 .85098 Mdot
.50588 .44314 Mdot
.03137 .03529 Mdot
.56471 .6 Mdot
.00392 0 Mdot
.87843 .8902 Mdot
.14118 .11373 Mdot
.04314 .03137 Mdot
.03137 .03137 Mdot
.03529 .04314 Mdot
.73725 .14118 Mdot
0 .01961 Mdot
.61569 .55686 Mdot
.87059 .84706 Mdot
.07451 .07843 Mdot
.00392 .01176 Mdot
.60392 .60392 Mdot
.00392 .00392 Mdot
.03529 .03922 Mdot
.4 .31373 Mdot
.73333 .72157 Mdot
.03137 .02745 Mdot
.00392 .01176 Mdot
.83137 .8549 Mdot
.00392 .00392 Mdot
.68235 .65098 Mdot
.2902 .24706 Mdot
.81569 .77647 Mdot
.81569 .81176 Mdot
.01961 .02353 Mdot
.53333 .5451 Mdot
.00392 .00392 Mdot
.13333 .08235 Mdot
.76471 .71765 Mdot
.8549 .85098 Mdot
.00784 .02353 Mdot
.02745 .03922 Mdot
.36863 .37647 Mdot
.01176 .03137 Mdot
.84314 .83922 Mdot
.82353 .79216 Mdot
.07843 .06275 Mdot
.01569 .03137 Mdot
.6549 .65882 Mdot
.00392 .00392 Mdot
.05098 .04314 Mdot
.80392 .78431 Mdot
.86667 .86275 Mdot
.45098 .36863 Mdot
.00392 .01961 Mdot
.78431 .82745 Mdot
.00392 .00392 Mdot
.8 .80784 Mdot
.84314 .85098 Mdot
.85882 .85882 Mdot
.09412 .06275 Mdot
.01569 .02353 Mdot
.59216 .56078 Mdot
0 0 Mdot
.80784 .81569 Mdot
.78431 .72157 Mdot
.85098 .8549 Mdot
.00784 .01961 Mdot
.0549 .07451 Mdot
.11765 .11765 Mdot
.01176 .03137 Mdot
.04706 .04314 Mdot
.90196 .9098 Mdot
.05098 .0549 Mdot
.00392 .00784 Mdot
.69804 .70588 Mdot
0 0 Mdot
.04706 .03922 Mdot
.08627 .07451 Mdot
.86275 .85882 Mdot
.82745 .82745 Mdot
0 .01961 Mdot
.78431 .82353 Mdot
0 .00392 Mdot
.18824 .18039 Mdot
.08235 .05098 Mdot
.8 .78824 Mdot
.01961 .02745 Mdot
.02353 .03922 Mdot
.68627 .05882 Mdot
.01569 .02745 Mdot
.05882 .04706 Mdot
.8902 .8902 Mdot
.82745 .83137 Mdot
.00784 .01961 Mdot
.04314 .04706 Mdot
0 0 Mdot
.01176 .01961 Mdot
.05098 .0549 Mdot
.77647 .79216 Mdot
.20392 .1451 Mdot
.00392 .01569 Mdot
.78431 .81569 Mdot
.00392 .00392 Mdot
.05882 .03529 Mdot
.08235 .06667 Mdot
.09412 .08235 Mdot
.80392 .81176 Mdot
.00392 .01569 Mdot
.49412 .52549 Mdot
.00392 .01569 Mdot
.03137 .03137 Mdot
.8549 .8549 Mdot
.84314 .81961 Mdot
.00784 .01961 Mdot
.03529 .04706 Mdot
.4 .36471 Mdot
.03922 .03922 Mdot
.04706 .04706 Mdot
.38431 .4 Mdot
.06667 .05882 Mdot
.00392 .01176 Mdot
.55294 .51765 Mdot
0 .00392 Mdot
.00784 .01961 Mdot
.05098 .04314 Mdot
.08235 .07059 Mdot
.82353 .80392 Mdot
.00784 .02353 Mdot
.82745 .85882 Mdot
.00392 .01961 Mdot
.04314 .03529 Mdot
.85098 .8549 Mdot
.27451 .22353 Mdot
.37647 .35686 Mdot
.00784 .02353 Mdot
.4 .39608 Mdot
0 .01176 Mdot
.05098 .04314 Mdot
.23922 .23529 Mdot
.19608 .18824 Mdot
.00392 .01176 Mdot
.04706 .05098 Mdot
.08627 .08627 Mdot
.03137 .04706 Mdot
.03922 .04706 Mdot
.08235 .0549 Mdot
.0549 .0549 Mdot
.00392 .00784 Mdot
.41961 .40392 Mdot
0 .00392 Mdot
.01176 .01569 Mdot
.82745 .80392 Mdot
.07451 .04706 Mdot
.81176 .82353 Mdot
0 .01569 Mdot
.74902 .78039 Mdot
.00392 .01961 Mdot
.0549 .04706 Mdot
.36078 .35686 Mdot
.77255 .75686 Mdot
.22745 .19608 Mdot
.03922 .04706 Mdot
.67843 .07451 Mdot
.36471 .36863 Mdot
.04706 .05098 Mdot
.15294 .12941 Mdot
.42353 .38824 Mdot
.00392 .01176 Mdot
.05882 .06275 Mdot
.00784 .00392 Mdot
.01569 .01961 Mdot
.25882 .21176 Mdot
.04706 .02353 Mdot
.51373 .47059 Mdot
.00392 .01569 Mdot
.63137 .63529 Mdot
.01176 .02745 Mdot
.01961 .02353 Mdot
.77647 .77255 Mdot
.87843 .87843 Mdot
.81961 .82745 Mdot
.00784 .02353 Mdot
.64706 .67843 Mdot
0 .00784 Mdot
.03529 .03922 Mdot
.84706 .85098 Mdot
.84706 .85098 Mdot
.63922 .62353 Mdot
.05098 .05098 Mdot
.70588 .74902 Mdot
.01176 .04314 Mdot
.01569 .01961 Mdot
.08235 .06275 Mdot
.47843 .47059 Mdot
.00392 .01176 Mdot
.16078 .15686 Mdot
.01176 .01569 Mdot
.01569 .02745 Mdot
.83529 .81176 Mdot
.85882 .86275 Mdot
.83529 .83529 Mdot
.00392 .01569 Mdot
.66275 .68235 Mdot
.00392 .00784 Mdot
.01569 .02745 Mdot
.82353 .80392 Mdot
.85882 .8549 Mdot
.81961 .83137 Mdot
.00392 .00784 Mdot
.33333 .3451 Mdot
.00784 .01176 Mdot
.01961 .01961 Mdot
.16863 .11765 Mdot
.84706 .85098 Mdot
.0902 .08627 Mdot
.06667 .07451 Mdot
.7098 .74902 Mdot
.01569 .01961 Mdot
.03137 .04314 Mdot
.86275 .86667 Mdot
.07059 .07059 Mdot
0 .00392 Mdot
.04706 .0549 Mdot
.00392 .00392 Mdot
.01176 .01961 Mdot
.13333 .13333 Mdot
.84706 .8549 Mdot
.76471 .74902 Mdot
.00392 .00784 Mdot
.6902 .7098 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.16078 .17255 Mdot
.22745 .24314 Mdot
.83137 .83529 Mdot
.00392 .00392 Mdot
.51373 .53725 Mdot
.00392 .01176 Mdot
.01569 .02353 Mdot
.79216 .76078 Mdot
.84706 .86275 Mdot
.04314 .03529 Mdot
.02353 .04706 Mdot
.45098 .43137 Mdot
.01176 .02353 Mdot
.02353 .03922 Mdot
.85098 .85098 Mdot
.04314 .03137 Mdot
.00392 .00392 Mdot
.04706 .05882 Mdot
.00392 .00784 Mdot
.01961 .02745 Mdot
.03529 .03922 Mdot
.21176 .23137 Mdot
.04314 .05882 Mdot
.01176 .01569 Mdot
.07451 .0902 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.08235 .0902 Mdot
.65882 .61569 Mdot
.82353 .82353 Mdot
.00392 .00784 Mdot
.76863 .82353 Mdot
.00392 .00392 Mdot
.01569 .02745 Mdot
.83529 .84706 Mdot
.84706 .84706 Mdot
.5098 .5098 Mdot
.70196 .70196 Mdot
.60784 .0549 Mdot
.00784 .01569 Mdot
.03529 .05882 Mdot
.7451 .75686 Mdot
.84706 .84706 Mdot
.00392 .01176 Mdot
.03137 .0549 Mdot
.08235 .1098 Mdot
.01176 .03922 Mdot
.03529 .04314 Mdot
.09804 .06667 Mdot
.07059 .07843 Mdot
0 .00392 Mdot
.03529 .06275 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.06275 .04706 Mdot
.86667 .87451 Mdot
.05882 .05882 Mdot
.00392 .00392 Mdot
.76471 .80392 Mdot
0 0 Mdot
.00784 .02745 Mdot
.84314 .85098 Mdot
.85098 .86275 Mdot
.81569 .81569 Mdot
.00392 .00784 Mdot
.50588 .53333 Mdot
.00784 .02353 Mdot
.01569 .02745 Mdot
.12941 .12941 Mdot
.83529 .84314 Mdot
.01961 .02745 Mdot
0 .01176 Mdot
.36078 .4 Mdot
.00784 .03529 Mdot
.02745 .03137 Mdot
.8549 .83529 Mdot
.07843 .09804 Mdot
.00784 .01569 Mdot
.01569 .04314 Mdot
.00392 0 Mdot
.01176 .03529 Mdot
.51373 .46667 Mdot
.86667 .87059 Mdot
.04314 .06275 Mdot
.00392 .01176 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .01569 Mdot
.84314 .8549 Mdot
.37647 .39608 Mdot
.05882 .06667 Mdot
.00392 .00784 Mdot
.81569 .87059 Mdot
.00784 .01176 Mdot
.00784 .03137 Mdot
.67843 .64706 Mdot
.85098 .85882 Mdot
.81176 .81176 Mdot
0 .01176 Mdot
.41176 .05098 Mdot
.00784 .02353 Mdot
.03529 .04314 Mdot
.8549 .86275 Mdot
.06667 .07059 Mdot
.00392 .01176 Mdot
.01569 .05098 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.06667 .04314 Mdot
.68235 .69804 Mdot
.03137 .05098 Mdot
.00392 .01176 Mdot
.02745 .05098 Mdot
0 .00392 Mdot
.01176 .02745 Mdot
.83137 .83922 Mdot
.61176 .58824 Mdot
.02745 .05882 Mdot
.00392 .01961 Mdot
.79608 .82353 Mdot
.00784 .00784 Mdot
.00392 .02745 Mdot
.84706 .84314 Mdot
.49412 .51373 Mdot
.03529 .05098 Mdot
.00392 .01961 Mdot
.41961 .42353 Mdot
0 .01176 Mdot
.02353 .03529 Mdot
.83922 .85098 Mdot
.06275 .07451 Mdot
.55294 .55686 Mdot
.00392 .02353 Mdot
.00784 .00784 Mdot
.00392 .02353 Mdot
.03922 .03529 Mdot
.14118 .12941 Mdot
.04706 .06667 Mdot
.00392 .01569 Mdot
.00784 .03922 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.69804 .67843 Mdot
.85882 .8549 Mdot
.07059 .08235 Mdot
.00392 .00784 Mdot
.03922 .0549 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.84706 .86275 Mdot
.08627 .10196 Mdot
.03529 .0549 Mdot
0 .00392 Mdot
.52157 .56863 Mdot
.00392 .00784 Mdot
.02353 .02745 Mdot
.14118 .15686 Mdot
.02353 .02353 Mdot
.02745 .04314 Mdot
0 .02353 Mdot
.01176 0 Mdot
.00392 .01569 Mdot
.03922 .04706 Mdot
.08627 .0902 Mdot
.6 .57255 Mdot
.01569 .03529 Mdot
.01961 .03922 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.15294 .13725 Mdot
.25882 .28627 Mdot
.79608 .77647 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.00392 .01176 Mdot
.00392 .01961 Mdot
.56471 .59608 Mdot
.0549 .04706 Mdot
.76471 .75294 Mdot
.00392 .00392 Mdot
.56863 .59216 Mdot
.00392 .00392 Mdot
.02745 .04314 Mdot
.21961 .21569 Mdot
.85098 .85882 Mdot
.06275 .05098 Mdot
.00392 .01176 Mdot
.28235 .26667 Mdot
.00784 .01569 Mdot
.04314 .05882 Mdot
.07059 .08627 Mdot
.83922 .8549 Mdot
.01176 .02745 Mdot
.01176 .03137 Mdot
.00392 0 Mdot
.00392 .01961 Mdot
.04706 .06667 Mdot
.01176 .01176 Mdot
.83137 .84706 Mdot
0 .00784 Mdot
.00392 .03529 Mdot
.00784 .00392 Mdot
.00392 .00784 Mdot
.05882 .04314 Mdot
.87843 .86667 Mdot
.83922 .83922 Mdot
0 .01176 Mdot
.04706 .05098 Mdot
.00392 .00784 Mdot
.00784 .02745 Mdot
.84706 .8549 Mdot
.85882 .87059 Mdot
.81569 .82745 Mdot
0 .00392 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.02353 .03922 Mdot
.10588 .11765 Mdot
.8549 .86667 Mdot
.34902 .32941 Mdot
0 .01176 Mdot
.00392 .00784 Mdot
.00392 .00784 Mdot
.04314 .05098 Mdot
.82745 .81961 Mdot
.83529 .84314 Mdot
0 .01569 Mdot
.00392 .02745 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.54902 .54118 Mdot
.87843 .8902 Mdot
.82353 .84314 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.00392 .00392 Mdot
.00784 .02353 Mdot
.85098 .86275 Mdot
.87451 .87843 Mdot
.83137 .84314 Mdot
.00392 .01569 Mdot
.53725 .54902 Mdot
0 0 Mdot
.01176 .03137 Mdot
.34902 .31765 Mdot
.72941 .76471 Mdot
.81961 .82745 Mdot
.00392 .03137 Mdot
.55294 .03137 Mdot
.00392 .01569 Mdot
.03137 .04706 Mdot
.87059 .88235 Mdot
.11765 .13725 Mdot
.10588 .11373 Mdot
.02353 .05098 Mdot
.01569 .00784 Mdot
.00784 .01961 Mdot
.04314 .06667 Mdot
.8902 .90588 Mdot
.03137 .05098 Mdot
.01176 .01961 Mdot
.00392 .02745 Mdot
0 0 Mdot
.00784 .00392 Mdot
.0549 .07059 Mdot
.86667 .87843 Mdot
.36863 .33725 Mdot
.02353 .03922 Mdot
.00392 .02745 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.50196 .52157 Mdot
.66275 .70588 Mdot
.09412 .1098 Mdot
.00392 .02745 Mdot
0 .01569 Mdot
.01176 .00784 Mdot
.00392 .00784 Mdot
.38039 .36078 Mdot
.11373 .13333 Mdot
.03529 .04706 Mdot
.01176 .04314 Mdot
.56078 .56863 Mdot
0 .00392 Mdot
.00784 .02745 Mdot
.90196 .90588 Mdot
.42745 .41961 Mdot
.64314 .63137 Mdot
.00784 .03137 Mdot
.12549 .11765 Mdot
.00784 .01569 Mdot
.01961 .03529 Mdot
.8902 .89804 Mdot
.87059 .87059 Mdot
.83137 .83137 Mdot
.01961 .03922 Mdot
.56078 .02353 Mdot
.00392 .01569 Mdot
.03137 .0549 Mdot
.88235 .89412 Mdot
.85098 .85882 Mdot
.08235 .09804 Mdot
0 .00392 Mdot
.00784 .00392 Mdot
0 0 Mdot
.03529 .0549 Mdot
.27451 .31765 Mdot
.6902 .7098 Mdot
.00784 .04314 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.0902 .10588 Mdot
.07451 .09412 Mdot
.03922 .0549 Mdot
.00392 .03529 Mdot
.01176 .03529 Mdot
0 .00392 Mdot
.00784 .01569 Mdot
.84706 .85098 Mdot
.14902 .14118 Mdot
.03137 .05098 Mdot
.00784 .04314 Mdot
.00392 .02745 Mdot
0 .00392 Mdot
0 .00784 Mdot
.85882 .87059 Mdot
.86275 .87843 Mdot
.37647 .34902 Mdot
.00392 .03137 Mdot
.23529 .25098 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.87451 .88235 Mdot
.85098 .86275 Mdot
.81961 .84314 Mdot
.00392 .02745 Mdot
.4 .40784 Mdot
.00392 .01176 Mdot
0 .00784 Mdot
.27059 .31373 Mdot
.64706 .6902 Mdot
.07451 .10196 Mdot
.01569 .04314 Mdot
.05098 .01961 Mdot
.00784 .01176 Mdot
.00784 .03922 Mdot
.08235 .08235 Mdot
.05882 .09412 Mdot
.01569 .03922 Mdot
.02353 .04314 Mdot
.03529 0 Mdot
.00392 .01176 Mdot
.01961 .02353 Mdot
.07843 .08627 Mdot
.06667 .09412 Mdot
0 .01961 Mdot
.03922 .06275 Mdot
.00392 .00392 Mdot
0 .02353 Mdot
.83137 .83922 Mdot
.50196 .5098 Mdot
.38824 .38039 Mdot
.00392 .01961 Mdot
.02353 .05098 Mdot
.00392 .00392 Mdot
.02745 .04706 Mdot
.83922 .8549 Mdot
.86667 .87059 Mdot
.85098 .86275 Mdot
.00392 .01961 Mdot
.00392 .03137 Mdot
.00784 .00784 Mdot
.01569 .03137 Mdot
.64314 .67059 Mdot
.7098 .72549 Mdot
.22745 .27451 Mdot
.00784 .03137 Mdot
.02353 .03922 Mdot
.01176 .01176 Mdot
.00392 .01176 Mdot
.06667 .08235 Mdot
.01569 .03137 Mdot
.02353 .03529 Mdot
.00784 .02745 Mdot
.34902 .35294 Mdot
0 0 Mdot
.00392 .01569 Mdot
.07059 .08235 Mdot
.44314 .42353 Mdot
.21961 .20784 Mdot
.00392 .03137 Mdot
.00392 .00392 Mdot
.00392 .00392 Mdot
.03137 .03137 Mdot
.08235 .10196 Mdot
.83529 .84314 Mdot
.01569 .01176 Mdot
.01176 .03137 Mdot
.59216 .01176 Mdot
.01176 .03922 Mdot
.81961 .81961 Mdot
.04706 .07451 Mdot
.82353 .8549 Mdot
.02745 .05882 Mdot
.03529 .04706 Mdot
0 .00392 Mdot
.00784 .03922 Mdot
.82745 .83922 Mdot
.05882 .07451 Mdot
.40784 .41961 Mdot
.00392 .03529 Mdot
.04314 .06667 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18824 .21569 Mdot
.22353 .27059 Mdot
.85098 .85882 Mdot
.00392 .02353 Mdot
.00392 .03529 Mdot
.00392 .00392 Mdot
.00784 .03529 Mdot
.01176 .02353 Mdot
.36471 .41176 Mdot
.84706 .85098 Mdot
.01176 .02745 Mdot
.00784 .01961 Mdot
.01176 .00784 Mdot
.01569 .02745 Mdot
.76471 .73333 Mdot
.12157 .17647 Mdot
.83137 .84314 Mdot
.00392 .02745 Mdot
.38431 .38824 Mdot
.00392 .00392 Mdot
.06275 .06667 Mdot
.86275 .88235 Mdot
.03137 .05098 Mdot
.83922 .84706 Mdot
.01176 .03137 Mdot
0 0 Mdot
.00784 .02353 Mdot
.80784 .79608 Mdot
.8549 .87059 Mdot
.72941 .71765 Mdot
.84314 .8549 Mdot
.01569 .03922 Mdot
.03922 .01569 Mdot
.28627 .3098 Mdot
.81961 .82745 Mdot
.6549 .66667 Mdot
.85098 .8549 Mdot
.67059 .6902 Mdot
.01961 .04314 Mdot
.00392 .00392 Mdot
.03529 .06275 Mdot
.11373 .11765 Mdot
.06667 .07451 Mdot
.85098 .85882 Mdot
.01961 .05098 Mdot
.01961 .03529 Mdot
.1098 .11373 Mdot
.00392 .02745 Mdot
.76078 .75686 Mdot
.06667 .08627 Mdot
.80784 .83922 Mdot
0 .02745 Mdot
.00784 .03529 Mdot
.00392 .00392 Mdot
.01176 .04314 Mdot
.51373 .55294 Mdot
.06275 .07843 Mdot
.1098 .15686 Mdot
.01176 .03529 Mdot
0 .02353 Mdot
.00392 .00784 Mdot
.01961 .03529 Mdot
.05882 .07843 Mdot
.62745 .61961 Mdot
.06667 .09804 Mdot
0 .01569 Mdot
.45098 .46275 Mdot
0 .00392 Mdot
.31765 .30196 Mdot
.36863 .36078 Mdot
.87059 .87843 Mdot
.76471 .76078 Mdot
0 .01569 Mdot
.00392 .00392 Mdot
0 .00784 Mdot
.83137 .83922 Mdot
.86275 .87843 Mdot
.86667 .87059 Mdot
.79608 .81569 Mdot
.00392 .01569 Mdot
0 .00784 Mdot
.00392 .01961 Mdot
.08627 .07059 Mdot
.08627 .10588 Mdot
.40784 .45882 Mdot
.03137 .0549 Mdot
.00392 .01569 Mdot
.12157 .03137 Mdot
.00784 .02353 Mdot
.83137 .83529 Mdot
.06275 .08627 Mdot
.09412 .12157 Mdot
.00784 .02745 Mdot
.00784 .03137 Mdot
.00392 .00392 Mdot
.02353 .04314 Mdot
.07059 .09412 Mdot
.07843 .0902 Mdot
.06275 .07451 Mdot
.00784 .03529 Mdot
.00392 .03137 Mdot
.00392 0 Mdot
.00784 .02353 Mdot
.01176 .01961 Mdot
.3098 .3098 Mdot
.20784 .18824 Mdot
.00392 .02745 Mdot
.00784 .03529 Mdot
0 .00392 Mdot
.01176 .03529 Mdot
.62745 .61176 Mdot
.85882 .86667 Mdot
.84314 .82745 Mdot
.00784 .04314 Mdot
.03137 .03922 Mdot
0 0 Mdot
.01961 .03922 Mdot
.85098 .86275 Mdot
.8549 .87451 Mdot
.7098 .75294 Mdot
.00392 .02353 Mdot
.10196 .11373 Mdot
.00784 .00784 Mdot
.41569 .42353 Mdot
.19608 .24314 Mdot
.14902 .2 Mdot
.06667 .10588 Mdot
0 .00784 Mdot
0 0 Mdot
.00392 .01176 Mdot
.81569 .81961 Mdot
.0549 .06275 Mdot
.05098 .07451 Mdot
.05098 .07843 Mdot
0 .01569 Mdot
0 .00392 Mdot
.00392 .00784 Mdot
.76471 .76863 Mdot
.0549 .06667 Mdot
.12157 .12549 Mdot
0 .00784 Mdot
.00392 .01176 Mdot
.01569 .01569 Mdot
.00392 .01569 Mdot
.82745 .83529 Mdot
.0549 .05882 Mdot
.73725 .73333 Mdot
0 .00784 Mdot
0 .01176 Mdot
.00392 .00392 Mdot
.00392 .01961 Mdot
.80392 .79216 Mdot
.03529 .0549 Mdot
.86667 .87059 Mdot
.00392 .01569 Mdot
.00392 .02353 Mdot
.16078 .03137 Mdot
0 .01961 Mdot
.81176 .83529 Mdot
.0549 .07843 Mdot
.84314 .84706 Mdot
.03137 .05098 Mdot
.00392 .03137 Mdot
.00784 0 Mdot
.00784 .03137 Mdot
.16471 .20392 Mdot
.0549 .07451 Mdot
.74118 .7451 Mdot
.01176 .03529 Mdot
.00392 .02353 Mdot
.00392 0 Mdot
.01176 .03922 Mdot
.03529 .06667 Mdot
.06667 .09804 Mdot
.82353 .82353 Mdot
0 .01569 Mdot
.00392 .03137 Mdot
0 0 Mdot
.01176 .04314 Mdot
.03137 .05882 Mdot
.07059 .11765 Mdot
.85098 .8549 Mdot
0 .01569 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .02745 Mdot
.05098 .07451 Mdot
.05882 .10196 Mdot
.8549 .86275 Mdot
.00392 .02745 Mdot
.07843 .08235 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.04314 .06275 Mdot
.06275 .08235 Mdot
.85882 .86667 Mdot
.00784 .02745 Mdot
0 .00392 Mdot
.00784 .01176 Mdot
.31373 .3098 Mdot
.04706 .05882 Mdot
.24706 .2549 Mdot
.85882 .86667 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
0 .00392 Mdot
.83137 .83137 Mdot
.04706 .06667 Mdot
.86667 .87059 Mdot
.8549 .86275 Mdot
.01176 .03137 Mdot
.01176 .01961 Mdot
.00392 .01176 Mdot
.82353 .82745 Mdot
.05098 .07059 Mdot
.87059 .87451 Mdot
.8549 .86275 Mdot
.01569 .03529 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.80392 .80392 Mdot
.05882 .07059 Mdot
.87059 .87843 Mdot
.8549 .86275 Mdot
.00784 .03137 Mdot
0 0 Mdot
0 .01961 Mdot
.14118 .14118 Mdot
.05098 .06667 Mdot
.87059 .87843 Mdot
.63922 .66275 Mdot
.01176 .04314 Mdot
.12157 .00784 Mdot
.00392 .02745 Mdot
.03922 .0549 Mdot
.07451 .10196 Mdot
.76471 .79608 Mdot
.03922 .06667 Mdot
.02745 .0549 Mdot
.23529 .22353 Mdot
.00392 .03922 Mdot
.05882 .07843 Mdot
.4 .39608 Mdot
.11373 .16471 Mdot
.01176 .02745 Mdot
.05882 .07843 Mdot
.01176 .01176 Mdot
.00784 .03922 Mdot
.0549 .07451 Mdot
.85882 .86275 Mdot
.04706 .07451 Mdot
.01569 .02745 Mdot
.21961 .22745 Mdot
.0549 .05098 Mdot
.00784 .04314 Mdot
.03922 .0549 Mdot
.87451 .8902 Mdot
.07059 .08235 Mdot
.00784 .02745 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.01569 .04706 Mdot
.04706 .06275 Mdot
.86667 .87843 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.33333 .35686 Mdot
0 0 Mdot
.00784 .03529 Mdot
.03922 .0549 Mdot
.87451 .88235 Mdot
.37255 .36078 Mdot
.00392 .01961 Mdot
.30588 .32157 Mdot
.00784 .00392 Mdot
.01176 .03922 Mdot
.04314 .05882 Mdot
.87059 .88235 Mdot
.78431 .76863 Mdot
.00784 .03529 Mdot
.01176 .03529 Mdot
0 0 Mdot
.00784 .03922 Mdot
.04314 .05882 Mdot
.6902 .72549 Mdot
.85098 .85098 Mdot
.01176 .03529 Mdot
.01961 .04706 Mdot
0 0 Mdot
.01961 .04314 Mdot
.03922 .05882 Mdot
.11373 .13725 Mdot
.83529 .84314 Mdot
.00784 .03137 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
.01176 .02745 Mdot
.06275 .09412 Mdot
.72157 .71373 Mdot
.83922 .84706 Mdot
.01961 .03137 Mdot
.00392 .01569 Mdot
0 0 Mdot
.01176 .02745 Mdot
.06275 .06667 Mdot
.86667 .87451 Mdot
.83922 .84706 Mdot
.02353 .03922 Mdot
.01176 .02745 Mdot
.00784 .01569 Mdot
.02353 .05098 Mdot
.72549 .71373 Mdot
.72549 .76078 Mdot
.83922 .84706 Mdot
.01961 .04706 Mdot
.00392 .00784 Mdot
.00392 .01176 Mdot
.03137 .05098 Mdot
.86275 .87059 Mdot
.17255 .21961 Mdot
.84314 .86275 Mdot
.01176 .04314 Mdot
.01176 .01569 Mdot
.00392 .01176 Mdot
.02745 .05882 Mdot
.85882 .87451 Mdot
.01961 .03529 Mdot
.72941 .74902 Mdot
.00784 .03529 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.04314 .07843 Mdot
.86275 .87059 Mdot
.65882 .65882 Mdot
.75294 .76078 Mdot
.00392 .02353 Mdot
.00392 .00784 Mdot
0 .01176 Mdot
.05882 .0902 Mdot
.84706 .87059 Mdot
.87843 .87843 Mdot
.83529 .83922 Mdot
.00784 .02745 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.08627 .12157 Mdot
.30588 .37255 Mdot
.87059 .87451 Mdot
.83922 .84706 Mdot
.01569 .03137 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18039 .20784 Mdot
.06275 .1098 Mdot
.86667 .87451 Mdot
.56078 .59216 Mdot
.16078 .16471 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.34902 .36078 Mdot
.08235 .10588 Mdot
.84706 .8549 Mdot
.67059 .68235 Mdot
.76471 .76863 Mdot
.01569 .00392 Mdot
0 .01176 Mdot
.47059 .49412 Mdot
.11373 .11373 Mdot
.82353 .85098 Mdot
.82745 .83137 Mdot
.5098 .52941 Mdot
.76078 .00392 Mdot
.00392 .01961 Mdot
.24314 .27843 Mdot
.56863 .56863 Mdot
.4902 .5451 Mdot
.82353 .83137 Mdot
.25882 .2902 Mdot
.52157 .00392 Mdot
.00392 .02353 Mdot
.09412 .12941 Mdot
.74118 .73725 Mdot
.14902 .21569 Mdot
.81961 .83137 Mdot
.11373 .14118 Mdot
.51765 .00392 Mdot
.03137 .05098 Mdot
.06667 .09804 Mdot
.86275 .86667 Mdot
.10196 .14902 Mdot
.81961 .83137 Mdot
.12941 .1451 Mdot
.52549 .01569 Mdot
.00784 .02353 Mdot
.01961 .03922 Mdot
.85882 .87451 Mdot
.01569 .03137 Mdot
.82353 .83137 Mdot
.32157 .33725 Mdot
.52157 .01176 Mdot
.00784 .01961 Mdot
.04314 .04314 Mdot
.79608 .83137 Mdot
.0902 .09412 Mdot
.82353 .82745 Mdot
.5451 .56471 Mdot
.52157 .01176 Mdot
.00784 .02745 Mdot
.31373 .3098 Mdot
.43137 .49412 Mdot
.61176 .61176 Mdot
.82353 .82745 Mdot
.67059 .68627 Mdot
.51765 .00392 Mdot
.00392 .02353 Mdot
.62353 .61961 Mdot
.1451 .20392 Mdot
.77647 .77647 Mdot
.81569 .83137 Mdot
.75686 .76078 Mdot
.52549 .00784 Mdot
0 .01961 Mdot
.79608 .79608 Mdot
.0902 .12941 Mdot
.86275 .86667 Mdot
.76471 .79608 Mdot
.75686 .75294 Mdot
.52157 .00784 Mdot
.00392 .03137 Mdot
.81569 .81569 Mdot
.08235 .10196 Mdot
.87843 .88235 Mdot
.53333 .57647 Mdot
.7451 .7451 Mdot
.51373 .00392 Mdot
.00784 .03137 Mdot
.81961 .82353 Mdot
.1098 .11373 Mdot
.89804 .89804 Mdot
.23922 .30196 Mdot
.74118 .74118 Mdot
.50588 .00392 Mdot
.00392 .01961 Mdot
.81961 .82353 Mdot
.17647 .15686 Mdot
.91765 .92157 Mdot
.09412 .16078 Mdot
.76078 .76471 Mdot
.5098 .00784 Mdot
.00392 .02353 Mdot
.83137 .83529 Mdot
.25098 .21569 Mdot
.93333 .93725 Mdot
.04706 .10196 Mdot
.74902 .75294 Mdot
.51765 .00784 Mdot
.00392 .02353 Mdot
.82745 .83529 Mdot
.28627 .25098 Mdot
.94902 .95686 Mdot
.03529 .06667 Mdot
.7098 .71765 Mdot
.51373 .00784 Mdot
.00392 .02745 Mdot
.80784 .82353 Mdot
.2549 .23137 Mdot
.93725 .95294 Mdot
.05098 .06667 Mdot
.73725 .7451 Mdot
.51765 .00784 Mdot
.00392 .02745 Mdot
.71765 .74118 Mdot
.29412 .27451 Mdot
.93725 .95686 Mdot
.05882 .08235 Mdot
.74902 .76471 Mdot
.5098 .00392 Mdot
.00392 .01961 Mdot
.53333 .56471 Mdot
.27451 .25882 Mdot
.89412 .95294 Mdot
.05098 .07843 Mdot
.67059 .6902 Mdot
.5098 .00392 Mdot
.00392 .02353 Mdot
.30196 .3098 Mdot
.21176 .19608 Mdot
.40392 .5098 Mdot
.05882 .07451 Mdot
.59216 .6 Mdot
.5098 0 Mdot
.00784 .03137 Mdot
.18431 .17647 Mdot
.12549 .12941 Mdot
.1451 .21961 Mdot
.06667 .03922 Mdot
.76471 .77647 Mdot
.50196 0 Mdot
.01569 .04706 Mdot
.30196 .29412 Mdot
.07059 .0902 Mdot
.08627 .11373 Mdot
.10588 .00392 Mdot
.79216 .81569 Mdot
.50588 0 Mdot
.01961 .04706 Mdot
.6902 .6902 Mdot
.06275 .07843 Mdot
.08235 .09804 Mdot
.34118 .1098 Mdot
.67059 .70196 Mdot
.01569 .00392 Mdot
.14118 .15686 Mdot
.78824 .79216 Mdot
.08235 .08235 Mdot
.09804 .09804 Mdot
.47843 .18431 Mdot
.72941 .7451 Mdot
.01961 .00392 Mdot
.10588 .13333 Mdot
.82353 .82745 Mdot
.14118 .13333 Mdot
.14118 .11373 Mdot
.28627 .04706 Mdot
.68235 .6902 Mdot
.01961 .00784 Mdot
.03529 .07059 Mdot
.76471 .80392 Mdot
.20784 .18039 Mdot
.22353 .16471 Mdot
.10588 .00392 Mdot
.64706 .65882 Mdot
.01569 .00392 Mdot
.03529 .0549 Mdot
.43529 .50196 Mdot
.28627 .23922 Mdot
.32941 .26275 Mdot
.0549 .01176 Mdot
.60784 .61569 Mdot
.01569 0 Mdot
.39216 .39608 Mdot
.12157 .18824 Mdot
.28627 .25098 Mdot
.60392 .58039 Mdot
.04314 .03529 Mdot
.58824 .6 Mdot
.02745 .00784 Mdot
.25882 .27451 Mdot
.07843 .10588 Mdot
.21569 .18824 Mdot
.63137 .64706 Mdot
.04706 .05882 Mdot
.59608 .61961 Mdot
.01961 .00392 Mdot
.3098 .33725 Mdot
.1098 .1098 Mdot
.24706 .20784 Mdot
.64706 .67059 Mdot
.04314 .07843 Mdot
.58039 .60784 Mdot
.01961 .00392 Mdot
.05098 .07843 Mdot
.14902 .13725 Mdot
.24706 .21569 Mdot
.75294 .77647 Mdot
.03529 .07451 Mdot
.55294 .57647 Mdot
.01569 .00392 Mdot
0 .02745 Mdot
.12549 .12941 Mdot
.15294 .14902 Mdot
.70588 .75294 Mdot
.05098 .07451 Mdot
.56863 .58431 Mdot
.01569 .00392 Mdot
.00784 .03137 Mdot
.10588 .12549 Mdot
.10196 .11373 Mdot
.49804 .55294 Mdot
.06667 .07843 Mdot
.6549 .67451 Mdot
.02353 .00784 Mdot
.00784 .03529 Mdot
.03529 .0549 Mdot
.09804 .1098 Mdot
.58039 .63529 Mdot
.05882 .06667 Mdot
.66667 .69412 Mdot
.01569 .00392 Mdot
.01176 .03922 Mdot
.00392 .00784 Mdot
.1098 .1098 Mdot
.45882 .52941 Mdot
.06275 .07059 Mdot
.60784 .63529 Mdot
.01176 .00392 Mdot
0 .01176 Mdot
.1098 .11765 Mdot
.14118 .13725 Mdot
.21961 .25882 Mdot
.07843 .0902 Mdot
.66667 .68235 Mdot
.01961 0 Mdot
.00784 .01176 Mdot
.33725 .3451 Mdot
.21569 .19216 Mdot
.31373 .31373 Mdot
.26667 .27451 Mdot
.80784 .82353 Mdot
.03137 .00784 Mdot
.00392 .02353 Mdot
.59216 .59608 Mdot
.2902 .2549 Mdot
.31765 .32549 Mdot
.58431 .58824 Mdot
.7451 .78824 Mdot
.01961 0 Mdot
.01961 .03922 Mdot
.76863 .77255 Mdot
.23529 .21569 Mdot
.19216 .21176 Mdot
.77255 .77255 Mdot
.63529 .68627 Mdot
.04314 .00392 Mdot
.10588 .13333 Mdot
.81569 .81961 Mdot
.18039 .15294 Mdot
.12157 .12941 Mdot
.79608 .8 Mdot
.65098 .67451 Mdot
.0549 .00392 Mdot
.01961 .05098 Mdot
.82353 .83529 Mdot
.18824 .16078 Mdot
.18824 .18039 Mdot
.81569 .82353 Mdot
.6902 .71373 Mdot
.06667 .00392 Mdot
0 .02353 Mdot
.37255 .41176 Mdot
.28235 .22745 Mdot
.24706 .23529 Mdot
.81961 .82745 Mdot
.53725 .58431 Mdot
.46275 .06667 Mdot
.00392 .02353 Mdot
.08627 .12549 Mdot
.38431 .32941 Mdot
.27451 .26275 Mdot
.81569 .82353 Mdot
.03529 .09804 Mdot
.12157 .00392 Mdot
.00392 .02745 Mdot
.08627 .0902 Mdot
.33725 .30196 Mdot
.23922 .23529 Mdot
.80784 .82745 Mdot
.02353 .06275 Mdot
.01176 .00392 Mdot
.02353 .04314 Mdot
.11373 .11373 Mdot
.29412 .28627 Mdot
.28627 .04314 Mdot
.0902 .13725 Mdot
.08627 .14118 Mdot
0 0 Mdot
.00784 .02745 Mdot
.07451 .09804 Mdot
.2549 .23529 Mdot
.67843 .05098 Mdot
.60392 .61569 Mdot
.00392 .03137 Mdot
.03922 .03529 Mdot
.01569 .03529 Mdot
.11373 .10588 Mdot
.23529 .2 Mdot
.12549 .01176 Mdot
.83529 .86667 Mdot
.01176 .03922 Mdot
0 0 Mdot
.04314 .0549 Mdot
.16078 .12549 Mdot
.21176 .17647 Mdot
.02353 .0549 Mdot
.87843 .90588 Mdot
.01176 .01961 Mdot
.00784 .00392 Mdot
.07451 .09412 Mdot
.19216 .16863 Mdot
.24706 .2 Mdot
.68235 .67843 Mdot
.90196 .93725 Mdot
.04706 .03529 Mdot
.00392 .01569 Mdot
.04706 .05098 Mdot
.67059 .6902 Mdot
.34902 .27843 Mdot
.80784 .81961 Mdot
.81961 .85882 Mdot
.37647 .00392 Mdot
.00392 .02745 Mdot
.1451 .12549 Mdot
.53725 .49412 Mdot
.46667 .37255 Mdot
.07843 .10588 Mdot
.07843 .10588 Mdot
.01569 .00784 Mdot
.03922 .0549 Mdot
.52157 .45882 Mdot
.57647 .55294 Mdot
.5098 .4549 Mdot
.78039 .81569 Mdot
.05882 .07059 Mdot
.00392 .00784 Mdot
.12549 .1098 Mdot
.73333 .69804 Mdot
.65882 .64706 Mdot
.5098 .47451 Mdot
.77647 .82745 Mdot
.02745 .03922 Mdot
.00392 .00392 Mdot
.34118 .2902 Mdot
.80784 .79608 Mdot
.84706 .85882 Mdot
.4902 .47451 Mdot
.83137 .87451 Mdot
.00392 0 Mdot
.10588 .12549 Mdot
.55294 .52941 Mdot
.89412 .92549 Mdot
.83529 .85098 Mdot
.4902 .47843 Mdot
.74902 .80392 Mdot
.23922 .07059 Mdot
.16471 .15294 Mdot
.64706 .65882 Mdot
.44314 .46275 Mdot
.52941 .53333 Mdot
.47843 .46275 Mdot
.05882 .10196 Mdot
.01569 .01176 Mdot
.52157 .50588 Mdot
.43137 .41569 Mdot
.43922 .38824 Mdot
.56471 .55686 Mdot
.46275 .43922 Mdot
.01569 .00784 Mdot
.01961 .02353 Mdot
.51373 .49804 Mdot
.45098 .37647 Mdot
.47059 .41569 Mdot
.4902 .43137 Mdot
.43922 .44706 Mdot
.67059 .06275 Mdot
.4902 .47843 Mdot
.46667 .39216 Mdot
.46667 .38824 Mdot
.59608 .60392 Mdot
.4902 .42745 Mdot
.06667 .07843 Mdot
.03529 .01961 Mdot
.4 .33725 Mdot
.4549 .36471 Mdot
.47843 .42353 Mdot
.4549 .38039 Mdot
.58039 .5451 Mdot
.08627 .05098 Mdot
.43529 .40392 Mdot
.45098 .36471 Mdot
.44706 .36863 Mdot
.46275 .39216 Mdot
.38431 .28627 Mdot
.45882 .45882 Mdot
.08627 .04314 Mdot
.47059 .37255 Mdot
.44706 .37255 Mdot
.46275 .4 Mdot
.47059 .36471 Mdot
.44706 .34902 Mdot
.09412 .07843 Mdot
.43137 .39216 Mdot
.48235 .38431 Mdot
.45098 .36863 Mdot
.45882 .38431 Mdot
.42353 .32549 Mdot
.45882 .38039 Mdot
.09412 .04314 Mdot
.45098 .34902 Mdot
.47451 .38824 Mdot
.46667 .4 Mdot
.41961 .30588 Mdot
.47059 .38824 Mdot
.38039 .36078 Mdot
.40392 .3451 Mdot
.46667 .38039 Mdot
.45882 .39608 Mdot
.47059 .40392 Mdot
.45098 .3451 Mdot
.40392 .2902 Mdot
.31765 .21569 Mdot
.46667 .36471 Mdot
.46667 .36471 Mdot
.58824 .55294 Mdot
.42353 .3098 Mdot
.45882 .34902 Mdot
.38824 .38824 Mdot
.43922 .33725 Mdot
.45882 .35686 Mdot
.47843 .43529 Mdot
.46275 .43137 Mdot
.46667 .37647 Mdot
.41569 .30588 Mdot
.41176 .29804 Mdot
.45098 .35294 Mdot
.48627 .41569 Mdot
.23922 .21961 Mdot
.42745 .33333 Mdot
.4549 .37255 Mdot
.28627 .21961 Mdot
.47451 .37255 Mdot
.47059 .37255 Mdot
.35294 .32941 Mdot
.42353 .38039 Mdot
.4549 .36471 Mdot
.31765 .24706 Mdot
.38039 .27843 Mdot
.46667 .35294 Mdot
.2902 .25882 Mdot
.58824 .5451 Mdot
.46275 .35294 Mdot
.45098 .3451 Mdot
.27059 .02745 Mdot
.46667 .36078 Mdot
.42745 .36863 Mdot
.55294 .56863 Mdot
.44706 .34902 Mdot
.45098 .3451 Mdot
.2902 .21569 Mdot
.42745 .36078 Mdot
.46275 .35686 Mdot
.40392 .32941 Mdot
.59608 .54118 Mdot
.44314 .34902 Mdot
.43137 .37255 Mdot
.42353 .32941 Mdot
.47059 .34902 Mdot
.30196 .2549 Mdot
.68235 .62353 Mdot
.47451 .38039 Mdot
.46667 .38824 Mdot
.38824 .25098 Mdot
.43922 .35294 Mdot
.32941 .2902 Mdot
.40392 .25882 Mdot
.40392 .2549 Mdot
.46667 .37255 Mdot
.31373 .25098 Mdot
.41569 .35294 Mdot
.49804 .4 Mdot
.44314 .23922 Mdot
.48235 .38431 Mdot
.48627 .37255 Mdot
.41961 .3451 Mdot
.69804 .04706 Mdot
.38431 .27451 Mdot
.40392 .29412 Mdot
.4 .32941 Mdot
.43529 .30196 Mdot
.43922 .33725 Mdot
.40784 .36863 Mdot
.4902 .44706 Mdot
.51373 .41569 Mdot
.47843 .30196 Mdot
.36471 .27451 Mdot
.50196 .38824 Mdot
.39216 .32157 Mdot
.52157 .47843 Mdot
.43529 .33725 Mdot
.47059 .3098 Mdot
.32157 .28627 Mdot
.5098 .38431 Mdot
.37647 .30588 Mdot
.42353 .17255 Mdot
.52549 .48627 Mdot
.41176 .27451 Mdot
.67843 .63529 Mdot
.50196 .39608 Mdot
.37255 .28627 Mdot
.46667 .42745 Mdot
.58431 .57255 Mdot
.43137 .23922 Mdot
.48627 .34902 Mdot
.52941 .38431 Mdot
.41569 .3098 Mdot
.47451 .45882 Mdot
.60784 .6 Mdot
.50196 .44706 Mdot
.61961 .55294 Mdot
.58039 .40784 Mdot
.45098 .33725 Mdot
.49412 .46275 Mdot
.61176 .59216 Mdot
.56471 .52157 Mdot
.47843 .41961 Mdot
.65882 .47843 Mdot
.47843 .38039 Mdot
.52549 .50196 Mdot
.60392 .57647 Mdot
.60392 .57647 Mdot
.48235 .38431 Mdot
.78431 .65098 Mdot
.56471 .50588 Mdot
.53333 .52941 Mdot
.52941 .50196 Mdot
.63137 .60784 Mdot
.49804 .35294 Mdot
.83922 .77647 Mdot
.6 .56078 Mdot
.53725 .52549 Mdot
.65098 .64314 Mdot
.62745 .60784 Mdot
.56078 .50196 Mdot
.88235 .83922 Mdot
.64706 .58824 Mdot
.50588 .47843 Mdot
.68627 .68235 Mdot
.67843 .67843 Mdot
.99608 .95294 Mdot
.83137 .83137 Mdot
.60784 .59216 Mdot
.74902 .12157 Mdot
.6902 .6902 Mdot
.8 .80392 Mdot
.99216 .99216 Mdot
.7098 .6902 Mdot
.54118 .53333 Mdot
.72157 .71373 Mdot
.72157 .71765 Mdot
.99608 .99608 Mdot
.81176 .81176 Mdot
.62745 .61176 Mdot
.69804 .6902 Mdot
.73725 .73725 Mdot
.95294 .96078 Mdot
.92549 .92157 Mdot
.65882 .65098 Mdot
.67059 .64706 Mdot
.76863 .76078 Mdot
.94118 .93725 Mdot
.92549 .92549 Mdot
.61569 .6 Mdot
.76863 .76471 Mdot
.83922 .83922 Mdot
.99216 .99216 Mdot
.84314 .8549 Mdot
.88627 .08235 Mdot
.80392 .8 Mdot
.95294 .95686 Mdot
.94902 .95294 Mdot
.41176 .26275 Mdot
.81569 .81569 Mdot
.9451 .94118 Mdot
.94118 .95294 Mdot
.76078 .15294 Mdot
.82353 .82745 Mdot
.99216 .98824 Mdot
.72549 .72157 Mdot
.6 .52157 Mdot
.97647 .98824 Mdot
.6 .57255 Mdot
.56078 .44706 Mdot
.72549 .70196 Mdot
.81961 .21176 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.78431 .20392 Mdot
.43529 .38824 Mdot
.7451 .68235 Mdot
.75686 .73333 Mdot
.63529 .54118 Mdot
.43137 .44314 Mdot
.72157 .68235 Mdot
.7098 .63529 Mdot
.75294 .75686 Mdot
.79216 .78431 Mdot
.71765 .62745 Mdot
.83137 .80784 Mdot
.81569 .83137 Mdot
.58824 .43922 Mdot
.68627 .61176 Mdot
.63137 .63922 Mdot
.81961 .82745 Mdot
.63529 .51373 Mdot
.66275 .60392 Mdot
.74902 .75294 Mdot
.8 .80784 Mdot
.62353 .48235 Mdot
.76471 .66667 Mdot
.83137 .81569 Mdot
.81176 .83137 Mdot
.83529 .05098 Mdot
.60392 .5451 Mdot
.75686 .72941 Mdot
.30588 .43137 Mdot
.79608 .81176 Mdot
.63922 .51373 Mdot
.80784 .72549 Mdot
.7098 .68627 Mdot
.83137 .83922 Mdot
.74902 .77255 Mdot
.73333 .63137 Mdot
.80784 .72941 Mdot
.73333 .70588 Mdot
.81569 .82353 Mdot
.52549 .21569 Mdot
.73725 .64706 Mdot
.78431 .70588 Mdot
.72941 .72549 Mdot
.81569 .8549 Mdot
.82745 .05098 Mdot
.7451 .66275 Mdot
.79216 .7098 Mdot
.83137 .81176 Mdot
.82353 .84706 Mdot
.49804 .54118 Mdot
.71765 .61961 Mdot
.81569 .81961 Mdot
.80784 .76863 Mdot
.83922 .85098 Mdot
.79608 .81569 Mdot
.65882 .57647 Mdot
.75686 .64706 Mdot
.76471 .71765 Mdot
.73725 .77255 Mdot
.78039 .80392 Mdot
.59216 .45882 Mdot
.7098 .61569 Mdot
.79608 .70196 Mdot
.70588 .67843 Mdot
.83922 .86667 Mdot
.75686 .81569 Mdot
.68627 .6 Mdot
.7451 .63137 Mdot
.75686 .68627 Mdot
.44706 .52157 Mdot
.79216 .82353 Mdot
.56078 .41176 Mdot
.67843 .58431 Mdot
.76471 .67451 Mdot
.84706 .81176 Mdot
.22353 .36863 Mdot
.81176 .83922 Mdot
.61176 .49804 Mdot
.7098 .60392 Mdot
.78824 .69412 Mdot
.77647 .74902 Mdot
.83137 .8549 Mdot
.73725 .76078 Mdot
.58039 .5098 Mdot
.43922 .39608 Mdot
.76078 .66667 Mdot
.77647 .75686 Mdot
.83529 .85882 Mdot
.57647 .62353 Mdot
.14118 .09412 Mdot
.57647 .53333 Mdot
.75294 .6549 Mdot
.76863 .74118 Mdot
.83137 .8549 Mdot
.34902 .4 Mdot
.15294 .08235 Mdot
.62353 .54118 Mdot
.76471 .66667 Mdot
.69412 .67059 Mdot
.83529 .86667 Mdot
.26275 .3451 Mdot
.26275 .17647 Mdot
.61176 .53725 Mdot
.77647 .68235 Mdot
.82353 .8 Mdot
.83922 .84706 Mdot
.79216 .84314 Mdot
.61569 .51373 Mdot
.65882 .53333 Mdot
.76078 .65882 Mdot
.70588 .64314 Mdot
.5098 .48627 Mdot
.77647 .75294 Mdot
.56863 .47843 Mdot
.63922 .5098 Mdot
.7451 .63922 Mdot
.70588 .61569 Mdot
.38824 .37255 Mdot
.81176 .83529 Mdot
.44314 .32941 Mdot
.61961 .50196 Mdot
.41569 .4 Mdot
.74902 .65882 Mdot
.64314 .61569 Mdot
.64314 .66667 Mdot
.46667 .5098 Mdot
.61176 .50196 Mdot
.61569 .43922 Mdot
.76863 .67059 Mdot
.75686 .6902 Mdot
.02745 .03922 Mdot
.72941 .58431 Mdot
.51765 .44314 Mdot
.61569 .46667 Mdot
.72549 .61961 Mdot
.73725 .63529 Mdot
.03529 .04314 Mdot
.80392 .82745 Mdot
.5451 .55686 Mdot
.62353 .51765 Mdot
.61176 .43922 Mdot
.76863 .68235 Mdot
.64314 .57255 Mdot
.01961 .02353 Mdot
.79216 .71765 Mdot
.56471 .48627 Mdot
.6 .44314 Mdot
.7098 .57647 Mdot
.73333 .63137 Mdot
.01961 .03137 Mdot
.24314 .25882 Mdot
.66275 .68235 Mdot
.58824 .47451 Mdot
.61176 .41569 Mdot
.76078 .68627 Mdot
.61961 .57255 Mdot
.01961 .02745 Mdot
.59608 .03922 Mdot
.73333 .75686 Mdot
.59608 .4549 Mdot
.6549 .50196 Mdot
.46667 .43137 Mdot
.02745 .03922 Mdot
.02353 .03137 Mdot
.27843 .31765 Mdot
.59608 .53333 Mdot
.57255 .37647 Mdot
.72157 .60392 Mdot
.71765 .63137 Mdot
.03137 .03922 Mdot
.58824 .59216 Mdot
.82745 .05098 Mdot
.58039 .48235 Mdot
.62745 .43922 Mdot
.49412 .45882 Mdot
.07451 .0549 Mdot
.30588 .40392 Mdot
.59216 .19608 Mdot
.77647 .80784 Mdot
.6 .47843 Mdot
.65098 .49412 Mdot
.5451 .51373 Mdot
.04314 .05098 Mdot
.28627 .42353 Mdot
.62745 .01176 Mdot
.82353 .83529 Mdot
.58824 .43137 Mdot
.68235 .54902 Mdot
.76471 .68235 Mdot
.11373 .11765 Mdot
.28235 .33725 Mdot
.43922 .38824 Mdot
.56863 .51765 Mdot
.56863 .37647 Mdot
.72549 .61961 Mdot
.61176 .57647 Mdot
.23529 .38431 Mdot
.02353 .03922 Mdot
.53725 .52941 Mdot
.58824 .53725 Mdot
.59216 .40392 Mdot
.76078 .66275 Mdot
.06667 .06667 Mdot
.81961 .82353 Mdot
.67059 .71373 Mdot
.7451 .76471 Mdot
.57255 .48627 Mdot
.63529 .47451 Mdot
.78824 .70196 Mdot
.05882 .05098 Mdot
.68235 .68627 Mdot
.59216 .08235 Mdot
.77255 .81569 Mdot
.59608 .50588 Mdot
.66667 .55686 Mdot
.78824 .72157 Mdot
.34118 .39216 Mdot
.74902 .79216 Mdot
.50196 .02353 Mdot
.57647 .60784 Mdot
.58039 .47451 Mdot
.6902 .57647 Mdot
.77647 .69804 Mdot
.24314 .41961 Mdot
.27843 .38431 Mdot
.46275 .03922 Mdot
.66275 .67843 Mdot
.57647 .46275 Mdot
.69804 .59216 Mdot
.76078 .68235 Mdot
.61961 .58039 Mdot
.79608 .85882 Mdot
.39216 .01569 Mdot
.81569 .84706 Mdot
.56471 .42353 Mdot
.70588 .61176 Mdot
.25882 .23137 Mdot
.4549 .41961 Mdot
.81961 .8549 Mdot
.43922 .04706 Mdot
.69412 .70196 Mdot
.56471 .38824 Mdot
.7098 .61176 Mdot
.08235 .06667 Mdot
.04314 .05098 Mdot
.82353 .85882 Mdot
.37255 .02745 Mdot
.55294 .54118 Mdot
.55686 .39608 Mdot
.72157 .62745 Mdot
.0902 .05882 Mdot
.02353 .04314 Mdot
.82745 .8549 Mdot
.30196 .00392 Mdot
.56471 .54118 Mdot
.56863 .41569 Mdot
.71373 .62745 Mdot
.09412 .05882 Mdot
.02353 .03529 Mdot
.74118 .77255 Mdot
.38431 .01569 Mdot
.56863 .54902 Mdot
.56471 .41176 Mdot
.72941 .64314 Mdot
.30196 .29804 Mdot
.02745 .03529 Mdot
.37647 .42353 Mdot
.51765 .05882 Mdot
.58431 .56078 Mdot
.59216 .4549 Mdot
.74118 .65882 Mdot
.27059 .46275 Mdot
.11765 .12549 Mdot
.07843 .12157 Mdot
.49412 .06275 Mdot
.58431 .56078 Mdot
.6 .46275 Mdot
.73725 .6549 Mdot
.30196 .49804 Mdot
.34902 .43922 Mdot
.07059 .11373 Mdot
.44706 .02353 Mdot
.59216 .56078 Mdot
.62353 .49804 Mdot
.72941 .64706 Mdot
.58431 .69804 Mdot
.16863 .36471 Mdot
.06275 .1098 Mdot
.47451 .02353 Mdot
.58431 .55686 Mdot
.62745 .50588 Mdot
.72549 .64706 Mdot
.74118 .76471 Mdot
.41176 .53333 Mdot
.07059 .10196 Mdot
.43137 .00784 Mdot
.58824 .56863 Mdot
.61961 .5098 Mdot
.72941 .63529 Mdot
.7451 .7098 Mdot
.77255 .78039 Mdot
.06667 .08627 Mdot
.47451 .03137 Mdot
.54902 .53333 Mdot
.63529 .52549 Mdot
.72549 .63137 Mdot
.72941 .67451 Mdot
.62353 .58431 Mdot
.07451 .09804 Mdot
.55686 .08235 Mdot
.53333 .51373 Mdot
.62745 .52549 Mdot
.72157 .63529 Mdot
.67451 .62353 Mdot
.50196 .45882 Mdot
.06667 .09804 Mdot
.57255 .15686 Mdot
.52941 .50196 Mdot
.63922 .54118 Mdot
.73333 .64314 Mdot
.26275 .24314 Mdot
.16863 .15294 Mdot
.0549 .08235 Mdot
.58039 .2902 Mdot
.50588 .47843 Mdot
.63922 .55294 Mdot
.72549 .63529 Mdot
.11765 .10196 Mdot
.0549 .06275 Mdot
.0549 .08235 Mdot
.65882 .50588 Mdot
.50588 .48235 Mdot
.63922 .54902 Mdot
.72549 .63137 Mdot
.10196 .08235 Mdot
.05882 .05098 Mdot
.0549 .08235 Mdot
.63529 .58039 Mdot
.49804 .47451 Mdot
.64314 .5451 Mdot
.73333 .65098 Mdot
.1098 .0902 Mdot
.22353 .21176 Mdot
.04706 .06667 Mdot
.5451 .53333 Mdot
.48627 .46667 Mdot
.63529 .54118 Mdot
.73333 .64314 Mdot
.23529 .23529 Mdot
.18824 .25882 Mdot
.03922 .06275 Mdot
.72549 .73725 Mdot
.46275 .46275 Mdot
.61569 .52941 Mdot
.72157 .62745 Mdot
.30588 .3098 Mdot
.31373 .34118 Mdot
.06667 .0902 Mdot
.56863 .60784 Mdot
.69412 .70196 Mdot
.61569 .54118 Mdot
.7098 .61569 Mdot
.47059 .50196 Mdot
.04706 .04314 Mdot
.31373 .34118 Mdot
.41961 .50196 Mdot
.76471 .78039 Mdot
.62745 .56078 Mdot
.71765 .63137 Mdot
.47059 .56863 Mdot
.04706 .05882 Mdot
.35686 .42745 Mdot
.73333 .81176 Mdot
.76078 .78431 Mdot
.65098 .58039 Mdot
.70196 .60784 Mdot
.3098 .45882 Mdot
.07843 .07843 Mdot
.4549 .52549 Mdot
.47451 .58039 Mdot
.65098 .66667 Mdot
.64706 .58431 Mdot
.70196 .61961 Mdot
.66275 .70588 Mdot
.17647 .16471 Mdot
.63137 .6902 Mdot
.79608 .87451 Mdot
.51765 .52549 Mdot
.6549 .59216 Mdot
.6902 .61569 Mdot
.77255 .72549 Mdot
.27451 .25882 Mdot
.41961 .49412 Mdot
.79216 .84706 Mdot
.5098 .51765 Mdot
.64314 .6 Mdot
.68235 .59608 Mdot
.78039 .7098 Mdot
.3098 .30588 Mdot
.03922 .07843 Mdot
.77647 .83137 Mdot
.45882 .47059 Mdot
.6549 .60784 Mdot
.67451 .58824 Mdot
.78039 .71373 Mdot
.30196 .30196 Mdot
.01176 .02745 Mdot
.80392 .84314 Mdot
.42353 .45098 Mdot
.65098 .61569 Mdot
.67843 .58824 Mdot
.78431 .72157 Mdot
.30196 .30588 Mdot
.01569 .03529 Mdot
.79216 .83922 Mdot
.46275 .50588 Mdot
.63922 .60784 Mdot
.66275 .57647 Mdot
.78824 .72157 Mdot
.62353 .6 Mdot
.38824 .42353 Mdot
.79608 .85098 Mdot
.6549 .7098 Mdot
.63137 .59216 Mdot
.6549 .56078 Mdot
.76078 .69412 Mdot
.68627 .64706 Mdot
.65098 .66275 Mdot
.79216 .82353 Mdot
.54902 .55294 Mdot
.61176 .56471 Mdot
.64314 .55294 Mdot
.75686 .6902 Mdot
.72549 .67451 Mdot
.63137 .60392 Mdot
.79608 .83137 Mdot
.56078 .40784 Mdot
.56863 .52549 Mdot
.64314 .54902 Mdot
.75294 .67059 Mdot
.7098 .67059 Mdot
.60392 .54902 Mdot
.80392 .8549 Mdot
.26667 .21961 Mdot
.56471 .53725 Mdot
.63922 .54118 Mdot
.74118 .66667 Mdot
.71765 .69412 Mdot
.61176 .56078 Mdot
.7451 .80784 Mdot
.16863 .21176 Mdot
.56471 .55294 Mdot
.61569 .52157 Mdot
.73725 .67843 Mdot
.73333 .69804 Mdot
.61961 .56863 Mdot
.2549 .32549 Mdot
.59216 .63137 Mdot
.56078 .56078 Mdot
.61569 .52941 Mdot
.73725 .67843 Mdot
.72941 .69412 Mdot
.63529 .59608 Mdot
.02353 .05882 Mdot
.63922 .65882 Mdot
.69412 .71373 Mdot
.62745 .54902 Mdot
.73725 .66275 Mdot
.72941 .69804 Mdot
.61176 .57647 Mdot
.00784 .02745 Mdot
.48627 .51373 Mdot
.42745 .44706 Mdot
.62353 .56078 Mdot
.72549 .6549 Mdot
.75686 .73333 Mdot
.12941 .1451 Mdot
.26667 .29804 Mdot
.52941 .60784 Mdot
.65098 .67451 Mdot
.60784 .55686 Mdot
.70196 .63922 Mdot
.76471 .72941 Mdot
.0549 .06275 Mdot
.59216 .59608 Mdot
.76863 .83529 Mdot
.30196 .33333 Mdot
.62353 .58824 Mdot
.69804 .63922 Mdot
.74902 .71373 Mdot
.04706 .05882 Mdot
.04314 .05098 Mdot
.78824 .84706 Mdot
.45098 .49804 Mdot
.64314 .61176 Mdot
.67451 .60392 Mdot
.75686 .71373 Mdot
.07843 .09412 Mdot
.01569 .03137 Mdot
.77647 .83529 Mdot
.55686 .59216 Mdot
.61176 .6 Mdot
.65882 .59216 Mdot
.74902 .70588 Mdot
.28235 .27451 Mdot
.00784 .02353 Mdot
.79216 .84314 Mdot
.58039 .63137 Mdot
.61961 .59608 Mdot
.65882 .57647 Mdot
.73725 .69804 Mdot
.68627 .66667 Mdot
.01569 .03922 Mdot
.69412 .7098 Mdot
.66275 .60392 Mdot
.6 .58039 Mdot
.64706 .56078 Mdot
.72941 .68627 Mdot
.72549 .69804 Mdot
.01569 .03529 Mdot
.01961 .06275 Mdot
.21176 .12941 Mdot
.58824 .58431 Mdot
.63529 .53725 Mdot
.7451 .6902 Mdot
.72941 .69804 Mdot
.02353 .04706 Mdot
.00392 .04314 Mdot
.08235 .18431 Mdot
.55686 .56471 Mdot
.61961 .53333 Mdot
.72941 .66275 Mdot
.75294 .72549 Mdot
.03922 .0549 Mdot
.00392 .04706 Mdot
.1098 .2 Mdot
.81961 .8549 Mdot
.60784 .54118 Mdot
.68627 .61176 Mdot
.75686 .72941 Mdot
.02745 .05098 Mdot
.44706 .49412 Mdot
.65882 .70196 Mdot
.35294 .38824 Mdot
.58039 .54118 Mdot
.63922 .55686 Mdot
.76078 .73333 Mdot
.03137 .04706 Mdot
.43529 .53333 Mdot
.29804 .40392 Mdot
.6902 .72549 Mdot
.56078 .52549 Mdot
.61961 .51765 Mdot
.76863 .75294 Mdot
.04314 .0549 Mdot
.03529 .07843 Mdot
.78039 .85098 Mdot
.34902 .37255 Mdot
.59216 .55294 Mdot
.59608 .49412 Mdot
.59216 .58824 Mdot
.05098 .07451 Mdot
.01569 .03529 Mdot
.77255 .84314 Mdot
.48627 .52157 Mdot
.58431 .5451 Mdot
.61176 .50588 Mdot
.66667 .64706 Mdot
.11373 .14118 Mdot
.00784 .03137 Mdot
.77647 .86275 Mdot
.73725 .78824 Mdot
.58824 .56863 Mdot
.60784 .50196 Mdot
.71373 .67059 Mdot
.62745 .63529 Mdot
.00392 .03529 Mdot
.4549 .62353 Mdot
.59216 .53725 Mdot
.55686 .55294 Mdot
.59608 .48235 Mdot
.63922 .58431 Mdot
.70588 .68235 Mdot
.01176 .03529 Mdot
.08235 .32549 Mdot
.32941 .30588 Mdot
.56863 .55294 Mdot
.57255 .48235 Mdot
.62353 .56471 Mdot
.70588 .69804 Mdot
.03137 .05098 Mdot
.04706 .25882 Mdot
.30196 .29804 Mdot
.54118 .55294 Mdot
.58431 .4902 Mdot
.63922 .57255 Mdot
.72941 .71373 Mdot
.02745 .03529 Mdot
.47843 .5451 Mdot
.39216 .37647 Mdot
.48627 .50196 Mdot
.55686 .48627 Mdot
.60392 .51765 Mdot
.75686 .73725 Mdot
.02745 .04314 Mdot
.72941 .79216 Mdot
.48627 .4902 Mdot
.40392 .43922 Mdot
.55294 .50196 Mdot
.58824 .48627 Mdot
.75686 .74118 Mdot
.03529 .04706 Mdot
.56078 .7451 Mdot
.73725 .76863 Mdot
.33333 .38824 Mdot
.53725 .49412 Mdot
.57647 .44314 Mdot
.77647 .75294 Mdot
.03137 .04706 Mdot
.1451 .37647 Mdot
.40392 .49412 Mdot
.45882 .51765 Mdot
.53333 .50588 Mdot
.56471 .43529 Mdot
.75294 .73725 Mdot
.04706 .05882 Mdot
.31765 .45098 Mdot
.39608 .47843 Mdot
.73725 .78824 Mdot
.55294 .53725 Mdot
.56471 .44706 Mdot
.74118 .71765 Mdot
.03529 .04314 Mdot
.3098 .37647 Mdot
.78039 .83529 Mdot
.75686 .82353 Mdot
.53725 .5098 Mdot
.54902 .43529 Mdot
.63137 .58431 Mdot
.1098 .13333 Mdot
.1451 .18039 Mdot
.37255 .4549 Mdot
.64706 .58431 Mdot
.56471 .54902 Mdot
.54118 .42745 Mdot
.61176 .55294 Mdot
.72157 .70588 Mdot
.03922 .06667 Mdot
.42745 .47451 Mdot
.23922 .27451 Mdot
.53725 .53333 Mdot
.52941 .41961 Mdot
.60392 .53333 Mdot
.72549 .72549 Mdot
.10588 .14118 Mdot
.81176 .86275 Mdot
.36078 .36471 Mdot
.47843 .4902 Mdot
.54118 .45098 Mdot
.59216 .51765 Mdot
.73725 .73725 Mdot
.62745 .6549 Mdot
.64314 .73333 Mdot
.2549 .34118 Mdot
.12157 .14902 Mdot
.54902 .49804 Mdot
.63137 .57255 Mdot
.7451 .74118 Mdot
.58431 .62745 Mdot
.31373 .40392 Mdot
.43529 .49804 Mdot
.33333 .36471 Mdot
.55686 .52941 Mdot
.58824 .50588 Mdot
.74902 .7451 Mdot
.12941 .16863 Mdot
.56078 .58431 Mdot
.12549 .29804 Mdot
.18431 .18431 Mdot
.54118 .52157 Mdot
.59216 .50196 Mdot
.74902 .74902 Mdot
.12157 .18039 Mdot
.37647 .40392 Mdot
.63529 .68235 Mdot
.11373 .12157 Mdot
.49412 .48627 Mdot
.6 .50196 Mdot
.58039 .57647 Mdot
.1451 .21176 Mdot
.13333 .17255 Mdot
.43922 .52157 Mdot
.22353 .21569 Mdot
.49804 .4902 Mdot
.55294 .45882 Mdot
.56471 .53725 Mdot
.64706 .66667 Mdot
.10588 .12941 Mdot
.78824 .83137 Mdot
.70588 .08235 Mdot
.5098 .50196 Mdot
.56863 .46667 Mdot
.66667 .62353 Mdot
.71373 .70196 Mdot
.14902 .18431 Mdot
.11373 .18039 Mdot
.07059 .18824 Mdot
.48235 .48627 Mdot
.54902 .45098 Mdot
.67059 .62745 Mdot
.72941 .73333 Mdot
.12549 .16863 Mdot
.00784 .04706 Mdot
.04706 .19608 Mdot
.47451 .4902 Mdot
.54118 .4549 Mdot
.68627 .65882 Mdot
.73333 .72157 Mdot
.15294 .18431 Mdot
.00392 .03137 Mdot
.07843 .20784 Mdot
.43137 .43922 Mdot
.52941 .48235 Mdot
.65882 .63529 Mdot
.7451 .74902 Mdot
.20392 .2549 Mdot
.00784 .02745 Mdot
.39608 .42745 Mdot
.21176 .23529 Mdot
.50588 .47059 Mdot
.64706 .61176 Mdot
.72157 .71765 Mdot
.35686 .47451 Mdot
.00784 .04706 Mdot
.46275 .45882 Mdot
.08627 .09804 Mdot
.43922 .41569 Mdot
.63922 .6 Mdot
.71765 .7098 Mdot
.23922 .39216 Mdot
.00784 .04314 Mdot
.47059 .48235 Mdot
.20784 .22745 Mdot
.42745 .41569 Mdot
.61176 .56471 Mdot
.71765 .71373 Mdot
.28627 .43137 Mdot
.02353 .04314 Mdot
.44706 .48627 Mdot
.19608 .18039 Mdot
.44314 .41961 Mdot
.61176 .56078 Mdot
.72157 .72941 Mdot
.67451 .68627 Mdot
.04314 .06667 Mdot
.18039 .22745 Mdot
.31373 .26275 Mdot
.47451 .46275 Mdot
.59216 .52549 Mdot
.70588 .71765 Mdot
.71373 .70588 Mdot
.06275 .10196 Mdot
.00392 .03529 Mdot
.31373 .33725 Mdot
.42353 .43529 Mdot
.54902 .48627 Mdot
.7098 .7098 Mdot
.6902 .67843 Mdot
.07059 .10588 Mdot
.16078 .20392 Mdot
.34118 .37255 Mdot
.40392 .4 Mdot
.56863 .49412 Mdot
.67059 .65098 Mdot
.71373 .72157 Mdot
.03137 .05882 Mdot
.5098 .53725 Mdot
.40392 .4 Mdot
.34902 .35686 Mdot
.54902 .48627 Mdot
.68627 .6549 Mdot
.7098 .7098 Mdot
.01961 .03922 Mdot
.03137 .07451 Mdot
.1098 .18431 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.69412 .66667 Mdot
.68627 .69412 Mdot
.02353 .05098 Mdot
.00392 .04314 Mdot
.44314 .43922 Mdot
.30196 .31765 Mdot
.4549 .43922 Mdot
.66275 .63529 Mdot
.72941 .73333 Mdot
.00784 .03529 Mdot
.00392 .02745 Mdot
.47843 .47451 Mdot
.12157 .11373 Mdot
.43922 .43137 Mdot
.63922 .59608 Mdot
.71373 .72157 Mdot
.03529 .05882 Mdot
.00784 .03529 Mdot
.6 .6902 Mdot
.3451 .31765 Mdot
.4549 .44706 Mdot
.61961 .55294 Mdot
.70196 .6902 Mdot
.03922 .06667 Mdot
.04314 .08627 Mdot
.04706 .09412 Mdot
.27843 .32157 Mdot
.38431 .38824 Mdot
.6 .53725 Mdot
.58824 .56078 Mdot
.34902 .38431 Mdot
.56471 .57647 Mdot
.42745 .49804 Mdot
.0549 .23529 Mdot
.31765 .33333 Mdot
.55294 .50196 Mdot
.54902 .49412 Mdot
.68235 .69804 Mdot
.59216 .62353 Mdot
.80392 .90588 Mdot
.08627 .20392 Mdot
.27451 .29412 Mdot
.52549 .49412 Mdot
.61569 .58824 Mdot
.66275 .67451 Mdot
.4902 .62353 Mdot
.18824 .4 Mdot
.43922 .43529 Mdot
.27451 .27451 Mdot
.50196 .47451 Mdot
.66275 .62745 Mdot
.69804 .72157 Mdot
.18824 .46275 Mdot
.12941 .39216 Mdot
.47451 .46667 Mdot
.39608 .38824 Mdot
.44314 .43529 Mdot
.61961 .57647 Mdot
.70588 .70588 Mdot
.33333 .48627 Mdot
.12941 .36471 Mdot
.48627 .4902 Mdot
.37647 .37647 Mdot
.44314 .43922 Mdot
.57255 .50196 Mdot
.69804 .69804 Mdot
.07059 .0902 Mdot
.18039 .22745 Mdot
.74902 .80784 Mdot
.27843 .3098 Mdot
.38431 .38039 Mdot
.52157 .43529 Mdot
.61961 .60392 Mdot
.02353 .04706 Mdot
.32941 .34902 Mdot
.15686 .3451 Mdot
.40392 .42353 Mdot
.29804 .3098 Mdot
.46275 .4 Mdot
.6549 .64314 Mdot
.06275 .09412 Mdot
.58039 .58039 Mdot
.10196 .13725 Mdot
.41569 .39608 Mdot
.12549 .14118 Mdot
.45098 .43137 Mdot
.6549 .63137 Mdot
.65882 .66275 Mdot
.12549 .19608 Mdot
.03137 .0549 Mdot
.44706 .43137 Mdot
.28235 .29412 Mdot
.4549 .44314 Mdot
.55294 .49804 Mdot
.66667 .6549 Mdot
.07843 .12941 Mdot
.03529 .07059 Mdot
.46275 .46275 Mdot
.38824 .38824 Mdot
.49804 .4902 Mdot
.57255 .5098 Mdot
.68627 .69412 Mdot
.38824 .51765 Mdot
.26667 .32157 Mdot
.48627 .48627 Mdot
.26275 .27451 Mdot
.41961 .42353 Mdot
.47843 .37647 Mdot
.65098 .66275 Mdot
.22353 .48235 Mdot
.67843 .69412 Mdot
.03137 .07843 Mdot
.07451 .23529 Mdot
.35294 .37255 Mdot
.4902 .39608 Mdot
.71373 .71765 Mdot
.24314 .33333 Mdot
.48235 .58431 Mdot
.00392 .03922 Mdot
.0549 .23529 Mdot
.3098 .33725 Mdot
.43529 .38039 Mdot
.67451 .65882 Mdot
.05098 .07843 Mdot
.04314 .08627 Mdot
.00784 .05882 Mdot
.06667 .2902 Mdot
.22353 .23137 Mdot
.39608 .38824 Mdot
.53725 .50196 Mdot
.5098 .5451 Mdot
.56863 .63922 Mdot
.03529 .09412 Mdot
.0902 .28627 Mdot
.31765 .30196 Mdot
.47059 .47843 Mdot
.58039 .53333 Mdot
.69412 .70588 Mdot
.32157 .54118 Mdot
.42745 .48627 Mdot
.31373 .36078 Mdot
.4 .31373 Mdot
.47843 .48627 Mdot
.56471 .50588 Mdot
.7098 .72157 Mdot
.32941 .50588 Mdot
.77647 .84314 Mdot
.00392 .03529 Mdot
.40784 .39216 Mdot
.37647 .38824 Mdot
.52941 .47059 Mdot
.6902 .70588 Mdot
.06667 .08627 Mdot
.63529 .66667 Mdot
.10588 .13725 Mdot
.42353 .41569 Mdot
.30588 .32549 Mdot
.43529 .38824 Mdot
.59216 .57647 Mdot
.20784 .22745 Mdot
.15294 .39216 Mdot
.0902 .13725 Mdot
.09804 .23137 Mdot
.26667 .27059 Mdot
.38039 .33333 Mdot
.82745 .82353 Mdot
.07059 .0902 Mdot
.27451 .35686 Mdot
.02353 .04706 Mdot
.45098 .47059 Mdot
.22745 .21569 Mdot
.44706 .44706 Mdot
.51373 .4902 Mdot
.65882 .66275 Mdot
.03922 .07451 Mdot
.00392 .03137 Mdot
.17255 .3451 Mdot
.29804 .28235 Mdot
.46275 .47059 Mdot
.59608 .54118 Mdot
.70588 .71373 Mdot
.07451 .12157 Mdot
.01961 .0549 Mdot
.06275 .31373 Mdot
.18431 .27451 Mdot
.43137 .46667 Mdot
.52549 .47059 Mdot
.68235 .6902 Mdot
.1098 .19216 Mdot
.64314 .71765 Mdot
.0549 .10588 Mdot
.0549 .25882 Mdot
.33725 .37647 Mdot
.5098 .45098 Mdot
.66275 .66667 Mdot
.03922 .06667 Mdot
.49804 .54902 Mdot
.71373 .73725 Mdot
.12941 .23922 Mdot
.27451 .27843 Mdot
.41961 .4 Mdot
.53725 .52941 Mdot
.08235 .12941 Mdot
.71373 .73725 Mdot
.04314 .07843 Mdot
.18431 .30196 Mdot
.08627 .08235 Mdot
.41569 .40784 Mdot
.5451 .52941 Mdot
.70588 .71373 Mdot
.65882 .72549 Mdot
.16078 .31373 Mdot
.41569 .4902 Mdot
.30196 .27843 Mdot
.38039 .4 Mdot
.57647 .5451 Mdot
.69804 .71373 Mdot
.34118 .53333 Mdot
.01961 .05882 Mdot
.2 .37647 Mdot
.27059 .30588 Mdot
.03529 .06667 Mdot
.51373 .45882 Mdot
.63137 .63529 Mdot
.43137 .62745 Mdot
.55294 .59608 Mdot
.21961 .31373 Mdot
.21569 .28235 Mdot
.13725 .17255 Mdot
.4549 .42353 Mdot
.54118 .52549 Mdot
.06275 .1098 Mdot
.6 .62745 Mdot
.0549 .07451 Mdot
.44314 .43529 Mdot
.25098 .25882 Mdot
.41176 .41176 Mdot
.50588 .48235 Mdot
.29412 .32941 Mdot
.6 .62353 Mdot
.02353 .0549 Mdot
.48235 .47843 Mdot
.28235 .26275 Mdot
.38431 .40392 Mdot
.55686 .53725 Mdot
.6902 .69804 Mdot
.71765 .73333 Mdot
.03529 .07843 Mdot
.44314 .46275 Mdot
.12941 .01569 Mdot
.30588 .32941 Mdot
.58431 .55294 Mdot
.6902 .70588 Mdot
.66275 .67451 Mdot
.61961 .67059 Mdot
.29412 .30588 Mdot
.11765 .17647 Mdot
.31373 .35686 Mdot
.52157 .47451 Mdot
.5098 .5098 Mdot
.23137 .39608 Mdot
.6549 .7451 Mdot
.02745 .07451 Mdot
.37647 .37255 Mdot
.26275 .28627 Mdot
.44706 .42353 Mdot
.50196 .47843 Mdot
.05098 .07059 Mdot
.63137 .68235 Mdot
.00392 .03529 Mdot
.46667 .46275 Mdot
.06667 .06667 Mdot
.40784 .42353 Mdot
.46275 .4549 Mdot
.66275 .68627 Mdot
.66275 .67843 Mdot
.11373 .17647 Mdot
.43529 .43137 Mdot
.09804 .01569 Mdot
.2902 .3098 Mdot
.49412 .4549 Mdot
.65098 .66275 Mdot
.64314 .67059 Mdot
.5098 .59216 Mdot
0 .02745 Mdot
.05882 .17255 Mdot
.27451 .31765 Mdot
.55294 .51765 Mdot
.50196 .50588 Mdot
.35294 .46667 Mdot
.80784 .8549 Mdot
.00392 .03137 Mdot
.04706 .2 Mdot
.28235 .32157 Mdot
.50588 .47843 Mdot
.4902 .48235 Mdot
.03529 .05098 Mdot
.64706 .77255 Mdot
.00392 .02745 Mdot
.11765 .24706 Mdot
.27059 .2902 Mdot
.44706 .43922 Mdot
.43529 .43922 Mdot
.31765 .35686 Mdot
.72941 .81961 Mdot
0 .03137 Mdot
.42745 .41176 Mdot
.21961 .19216 Mdot
.33725 .34902 Mdot
.33725 .33333 Mdot
.63137 .64706 Mdot
.67843 .70196 Mdot
0 .03137 Mdot
.02745 .0549 Mdot
.6549 .12157 Mdot
.24706 .28235 Mdot
.49412 .44314 Mdot
.56471 .57255 Mdot
.06667 .13333 Mdot
.00392 .03529 Mdot
.26275 .34118 Mdot
.35294 .34118 Mdot
.27059 .3098 Mdot
.51765 .49412 Mdot
.4902 .48235 Mdot
.03922 .07059 Mdot
.02353 .08235 Mdot
.21176 .40784 Mdot
.03529 .21961 Mdot
.10196 .13333 Mdot
.44706 .45098 Mdot
.47059 .45098 Mdot
.65098 .67451 Mdot
.62353 .68627 Mdot
.11373 .16863 Mdot
.42353 .45098 Mdot
.39608 .38824 Mdot
.39216 .41569 Mdot
.50196 .4902 Mdot
.57255 .59608 Mdot
.65882 .68235 Mdot
.40784 .44706 Mdot
.13725 .25882 Mdot
.80784 .03529 Mdot
.27451 .30588 Mdot
.45098 .41961 Mdot
.56471 .56471 Mdot
.03529 .06275 Mdot
.07451 .12157 Mdot
.00392 .02353 Mdot
.36863 .35294 Mdot
.27451 .30588 Mdot
.52549 .50588 Mdot
.83922 .87451 Mdot
.04706 .07451 Mdot
.00784 .04706 Mdot
.05882 .12941 Mdot
.21176 .26275 Mdot
.2 .20784 Mdot
.40784 .40392 Mdot
.49804 .47451 Mdot
.61569 .63529 Mdot
.00392 .03922 Mdot
.36078 .52941 Mdot
.40392 .39216 Mdot
.12941 .13725 Mdot
.39608 .41961 Mdot
.50588 .48627 Mdot
.56471 .58039 Mdot
.06275 .11373 Mdot
.16471 .23922 Mdot
.06667 .07059 Mdot
.63529 .03137 Mdot
.28627 .31765 Mdot
.47451 .43137 Mdot
.59216 .60392 Mdot
.04706 .07451 Mdot
.20784 .31373 Mdot
.00784 .03137 Mdot
.38824 .35686 Mdot
.2549 .28235 Mdot
.46275 .43529 Mdot
.53333 .53333 Mdot
.26667 .29412 Mdot
.19216 .43529 Mdot
.00392 .04706 Mdot
.40392 .38039 Mdot
.16471 .17255 Mdot
.33725 .32157 Mdot
.53333 .52941 Mdot
.74902 .76863 Mdot
.2549 .36078 Mdot
.00392 .03137 Mdot
.40784 .39216 Mdot
.32941 .30588 Mdot
.37647 .4 Mdot
.47451 .46275 Mdot
.53725 .55294 Mdot
.03922 .06667 Mdot
.31373 .48627 Mdot
.06667 .09804 Mdot
.64706 .1098 Mdot
.04314 .0902 Mdot
.45098 .42745 Mdot
.57647 .58824 Mdot
.09412 .14118 Mdot
.13333 .18824 Mdot
.30196 .37647 Mdot
.36863 .3451 Mdot
.24314 .2902 Mdot
.49804 .47451 Mdot
.51373 .50588 Mdot
.77647 .79216 Mdot
.11765 .22353 Mdot
.24706 .36078 Mdot
.41176 .38039 Mdot
.24706 .2549 Mdot
.42745 .41961 Mdot
.4902 .48235 Mdot
.61961 .65098 Mdot
.46667 .61176 Mdot
.02353 .05098 Mdot
.41176 .39216 Mdot
.27451 .23922 Mdot
.33333 .34118 Mdot
.48627 .46667 Mdot
.76863 .78431 Mdot
.13333 .16471 Mdot
.00784 .04314 Mdot
.18431 .20392 Mdot
.62353 .00784 Mdot
.24706 .27843 Mdot
.47843 .45098 Mdot
.60392 .62353 Mdot
.0549 .08627 Mdot
.54118 .65882 Mdot
0 .02745 Mdot
.38824 .36078 Mdot
.04706 .06275 Mdot
.51373 .50196 Mdot
.46667 .46275 Mdot
.42353 .47451 Mdot
.29412 .40392 Mdot
.12941 .18824 Mdot
.41176 .4 Mdot
.26667 .26275 Mdot
.42353 .43529 Mdot
.46275 .45098 Mdot
.63137 .66667 Mdot
.29412 .34118 Mdot
.08627 .3098 Mdot
.38824 .37255 Mdot
.15294 .12157 Mdot
.27843 .31765 Mdot
.46667 .45882 Mdot
.78039 .78824 Mdot
.02353 .07059 Mdot
.00392 .04314 Mdot
.00392 .01176 Mdot
.32157 .28627 Mdot
.30196 .32157 Mdot
.54902 .53333 Mdot
.38431 .43922 Mdot
.07451 .11765 Mdot
.83529 .87843 Mdot
0 .01569 Mdot
.4 .36471 Mdot
.22745 .2549 Mdot
.46667 .46275 Mdot
.47843 .48235 Mdot
.27451 .3451 Mdot
.28627 .52157 Mdot
.00392 .03529 Mdot
.40392 .37647 Mdot
.23137 .19608 Mdot
.41176 .42745 Mdot
.47843 .47451 Mdot
.80784 .84314 Mdot
.15686 .21961 Mdot
.00784 .0549 Mdot
.33333 .37647 Mdot
.08627 0 Mdot
.35294 .38824 Mdot
.48627 .45882 Mdot
.58431 .60392 Mdot
.0549 .10196 Mdot
.16078 .21569 Mdot
.00784 .02745 Mdot
.37647 .36078 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.50588 .55686 Mdot
.21569 .38431 Mdot
.82353 .87059 Mdot
.21176 .31373 Mdot
.4 .38039 Mdot
.25098 .2549 Mdot
.30196 .31373 Mdot
.49412 .4902 Mdot
.6902 .72549 Mdot
.8549 .91765 Mdot
.01569 .05098 Mdot
.41176 .39608 Mdot
.08627 .05098 Mdot
.37255 .38824 Mdot
.82353 .83137 Mdot
.77255 .80392 Mdot
.02745 .07059 Mdot
.00784 .04314 Mdot
.08627 .23529 Mdot
.33333 .26667 Mdot
.12157 .14902 Mdot
.54902 .5098 Mdot
.52549 .54118 Mdot
.48235 .52157 Mdot
.81569 .85098 Mdot
.01569 .04706 Mdot
.38039 .35686 Mdot
.13333 .16471 Mdot
.42353 .42353 Mdot
.18431 .35294 Mdot
.31373 .33725 Mdot
.83529 .87059 Mdot
.60784 .72941 Mdot
.40784 .39608 Mdot
.28235 .2549 Mdot
.40392 .41961 Mdot
.47059 .45882 Mdot
.84706 .88627 Mdot
.23137 .44314 Mdot
.17255 .35686 Mdot
.41176 .38824 Mdot
.25098 .0549 Mdot
.41176 .43137 Mdot
.49804 .50588 Mdot
.56078 .58824 Mdot
.06667 .09412 Mdot
.18824 .24706 Mdot
.37255 .4549 Mdot
.38039 .3451 Mdot
.28627 .30196 Mdot
.4902 .47451 Mdot
.72941 .74902 Mdot
.30196 .55294 Mdot
.82745 .86275 Mdot
.53725 .59216 Mdot
.40392 .38039 Mdot
.08235 .10196 Mdot
.16078 .18431 Mdot
.10588 .32941 Mdot
.69412 .79608 Mdot
.83529 .86667 Mdot
.58824 .65882 Mdot
.40784 .38824 Mdot
.26667 .19608 Mdot
.3451 .38824 Mdot
.47059 .48235 Mdot
.82353 .84706 Mdot
.16863 .4 Mdot
.61569 .72941 Mdot
.42745 .42353 Mdot
.37255 .32941 Mdot
.37647 .41569 Mdot
.56863 .5451 Mdot
.68627 .71373 Mdot
.05098 .0902 Mdot
.82353 .85882 Mdot
.57647 .60392 Mdot
.38431 .36471 Mdot
.33333 .36471 Mdot
.39216 .38431 Mdot
.48627 .4902 Mdot
.23529 .47843 Mdot
.83529 .87451 Mdot
.7451 .79608 Mdot
.41569 .39608 Mdot
.04706 .01176 Mdot
.22353 .24314 Mdot
.45882 .47451 Mdot
.8549 .88235 Mdot
.84706 .87843 Mdot
.65882 .76078 Mdot
.43137 .42353 Mdot
.36078 .30588 Mdot
.14118 .18431 Mdot
.57255 .55294 Mdot
.60784 .64706 Mdot
.20784 .47059 Mdot
.82745 .86667 Mdot
.49412 .51765 Mdot
.39216 .37255 Mdot
.3098 .35686 Mdot
.46275 .44314 Mdot
.56863 .58431 Mdot
.12157 .2 Mdot
.83137 .86275 Mdot
.62353 .66275 Mdot
.41176 .40784 Mdot
.21569 .18039 Mdot
.47451 .49804 Mdot
.21176 .44314 Mdot
.84706 .8902 Mdot
.8549 .88627 Mdot
.37255 .48235 Mdot
.41961 .41569 Mdot
.1451 .02745 Mdot
.40392 .43137 Mdot
.62353 .61176 Mdot
.67059 .69412 Mdot
.8549 .88627 Mdot
.81961 .85882 Mdot
.53725 .55294 Mdot
.39608 .36078 Mdot
.18431 .21176 Mdot
.53333 .52549 Mdot
.84314 .86275 Mdot
.72157 .91373 Mdot
.83922 .87059 Mdot
.78431 .82353 Mdot
.41569 .38824 Mdot
.25882 .26667 Mdot
.43529 .45098 Mdot
.58431 .61176 Mdot
.83137 .87843 Mdot
.8549 .88235 Mdot
.56078 .63137 Mdot
.43137 .41176 Mdot
.15294 .07451 Mdot
.40784 .43922 Mdot
.53333 .63922 Mdot
.69412 .73333 Mdot
.8549 .88627 Mdot
.83137 .87451 Mdot
.55686 .57647 Mdot
.37255 .3451 Mdot
.36471 .40392 Mdot
.50588 .49412 Mdot
.61176 .63529 Mdot
.72157 .8549 Mdot
.8549 .88235 Mdot
.65882 .69412 Mdot
.40784 .39216 Mdot
.13333 .12157 Mdot
.33333 .3451 Mdot
.61569 .64706 Mdot
.78824 .9098 Mdot
.85882 .88627 Mdot
.5451 .64706 Mdot
.45882 .43529 Mdot
.13725 .0902 Mdot
.20784 .25098 Mdot
.12941 .46667 Mdot
.98039 1 Mdot
.87451 .90196 Mdot
.83922 .90196 Mdot
.58824 .61176 Mdot
.39216 .35686 Mdot
.35686 .4 Mdot
.56863 .57255 Mdot
.84706 .86667 Mdot
.91765 .9451 Mdot
.85098 .89804 Mdot
.79608 .81961 Mdot
.41176 .39216 Mdot
.32941 .35294 Mdot
.4549 .45098 Mdot
.76471 .81569 Mdot
.91373 .9451 Mdot
.86275 .89804 Mdot
.64706 .72157 Mdot
.47451 .46667 Mdot
.1098 .06275 Mdot
.29412 .30588 Mdot
.14902 .52157 Mdot
1 1 Mdot
.88235 .91373 Mdot
.77255 .86275 Mdot
.68235 .69804 Mdot
.40392 .36471 Mdot
.29804 .32941 Mdot
.56078 .56078 Mdot
.94902 .96471 Mdot
.91373 .95294 Mdot
.83922 .88235 Mdot
.76471 .8 Mdot
.44314 .42745 Mdot
.32549 .34118 Mdot
.50196 .50588 Mdot
.87451 .89804 Mdot
.92157 .98824 Mdot
.84706 .88627 Mdot
.35686 .4902 Mdot
.4902 .49412 Mdot
.18431 .11765 Mdot
.19216 .22353 Mdot
.23529 .63922 Mdot
.9451 .95686 Mdot
.84706 .8902 Mdot
.81569 .87059 Mdot
.62353 .64706 Mdot
.42353 .38824 Mdot
.31373 .34118 Mdot
.64706 .6549 Mdot
.99608 1 Mdot
.87451 .9098 Mdot
.82745 .87451 Mdot
.4902 .52941 Mdot
.46667 .46275 Mdot
.11373 .12157 Mdot
.57255 .59216 Mdot
.88235 .91373 Mdot
.89412 .98824 Mdot
.83137 .87843 Mdot
.43137 .54902 Mdot
.46275 .46667 Mdot
.23529 .12549 Mdot
.22353 .23922 Mdot
.30588 .69804 Mdot
.52157 .6549 Mdot
.85098 .8902 Mdot
.82353 .8902 Mdot
.53333 .5451 Mdot
.44706 .42745 Mdot
.06275 .1098 Mdot
.76863 .77647 Mdot
.76863 .82745 Mdot
.86667 .90196 Mdot
.83137 .97647 Mdot
.58039 .6549 Mdot
.43922 .43137 Mdot
.18039 .18039 Mdot
.64314 .65098 Mdot
.80784 .85098 Mdot
.81176 .92549 Mdot
.64706 .92941 Mdot
.33333 .63529 Mdot
.50588 .52157 Mdot
.23529 .12941 Mdot
.15294 .22353 Mdot
.23922 .61176 Mdot
.84706 .89412 Mdot
.62353 .9098 Mdot
.18039 .60392 Mdot
.34902 .5451 Mdot
.60784 .61961 Mdot
.22745 .25098 Mdot
.69804 .72157 Mdot
.8549 .88627 Mdot
.74902 .9451 Mdot
.17255 .5098 Mdot
.09804 .41176 Mdot
.42745 .40784 Mdot
.13333 .13333 Mdot
.63922 .6549 Mdot
.85098 .87843 Mdot
.71765 .94118 Mdot
.43137 .91373 Mdot
.04706 .18039 Mdot
.14902 .38824 Mdot
.12549 .02745 Mdot
.23922 .25882 Mdot
.15686 .41176 Mdot
.7098 .93725 Mdot
.66667 1 Mdot
.03137 .08627 Mdot
.03922 .18039 Mdot
.60392 .62353 Mdot
.37647 .41569 Mdot
.62745 .65098 Mdot
.56471 .87843 Mdot
.85882 1 Mdot
.03137 .09412 Mdot
.02745 .08235 Mdot
.34118 .47059 Mdot
.25882 .26275 Mdot
.60392 .62745 Mdot
.59608 .86275 Mdot
.83529 .99216 Mdot
.06667 .20392 Mdot
.32157 .38039 Mdot
.03922 .16078 Mdot
.04706 .03137 Mdot
.53333 .57255 Mdot
.54118 .78824 Mdot
.6 .99608 Mdot
.15686 .48235 Mdot
.53725 .55686 Mdot
0 .02353 Mdot
.37647 .32549 Mdot
.47451 .5098 Mdot
.62745 .74118 Mdot
.4902 .98039 Mdot
.18431 .44706 Mdot
.41961 .52157 Mdot
.57647 .59608 Mdot
.21961 .45882 Mdot
.27843 .28235 Mdot
.64706 .67843 Mdot
.45098 .97255 Mdot
.21569 .47843 Mdot
.06275 .10588 Mdot
.57255 .62745 Mdot
.01176 .05882 Mdot
.20392 .17647 Mdot
.58431 .60392 Mdot
.28235 .84314 Mdot
.27451 .52549 Mdot
.31765 .67843 Mdot
.58039 .64706 Mdot
.13725 .17647 Mdot
.22353 .17647 Mdot
.47451 .50196 Mdot
.21176 .73333 Mdot
.28235 .54118 Mdot
.57255 .99608 Mdot
.6 .67059 Mdot
0 .01176 Mdot
.69412 .07451 Mdot
.4 .43922 Mdot
.21961 .69412 Mdot
.22745 .4902 Mdot
.54902 .94902 Mdot
.34902 .4549 Mdot
.31373 .36863 Mdot
.06667 .18039 Mdot
.37647 .40392 Mdot
.2 .65882 Mdot
.18824 .45098 Mdot
.5098 .93333 Mdot
.05882 .09804 Mdot
.21176 .2902 Mdot
.59608 .63137 Mdot
.43137 .43529 Mdot
.16863 .61176 Mdot
.11373 .52157 Mdot
.44314 .93333 Mdot
.11765 .26667 Mdot
.10588 .20392 Mdot
.42745 .45882 Mdot
.4 .33333 Mdot
.18039 .58039 Mdot
.17647 .45882 Mdot
.4 .92157 Mdot
.46667 .95294 Mdot
.04314 .09804 Mdot
.47451 .4902 Mdot
.31373 .21176 Mdot
.14118 .47451 Mdot
.03922 .30588 Mdot
.37255 .8902 Mdot
.66275 .99608 Mdot
.05882 .1098 Mdot
.00392 .04706 Mdot
.55686 .0902 Mdot
.17647 .38824 Mdot
.13333 .33725 Mdot
.33725 .83529 Mdot
.88627 1 Mdot
.05098 .12549 Mdot
.00392 .03137 Mdot
.1451 .23922 Mdot
.40392 .47843 Mdot
.10196 .29804 Mdot
.28627 .79216 Mdot
.87451 .98039 Mdot
.06667 .14902 Mdot
.01961 .06275 Mdot
.42353 .50196 Mdot
.38431 .40392 Mdot
.10196 .25882 Mdot
.19216 .7098 Mdot
.64706 .89412 Mdot
.14118 .38824 Mdot
.06275 .18824 Mdot
.02745 .10588 Mdot
.38824 .39608 Mdot
.12157 .34902 Mdot
.23137 .76863 Mdot
.5451 .96078 Mdot
.2549 .68627 Mdot
.12549 .41176 Mdot
.01961 .06275 Mdot
.38431 .36863 Mdot
.11765 .43529 Mdot
.22745 .79216 Mdot
.48235 .97255 Mdot
.27843 .76078 Mdot
.17647 .58431 Mdot
.03137 .05882 Mdot
.36471 .3098 Mdot
.09412 .41961 Mdot
.41569 .95294 Mdot
.41569 .93333 Mdot
.31373 .76863 Mdot
.19608 .62353 Mdot
.03137 .14118 Mdot
.35294 .25882 Mdot
.09412 .41961 Mdot
.25882 .81961 Mdot
.37647 .88627 Mdot
.31765 .72549 Mdot
.24706 .53333 Mdot
.09412 .40392 Mdot
.34902 .24706 Mdot
.10588 .45098 Mdot
.23529 .78039 Mdot
.36078 .86667 Mdot
.38431 .61176 Mdot
.4902 .57647 Mdot
.13333 .47451 Mdot
.34118 .23137 Mdot
.11765 .4902 Mdot
.22353 .74902 Mdot
.34118 .83137 Mdot
.52157 .57647 Mdot
.7098 .7098 Mdot
.18824 .39608 Mdot
.3451 .17255 Mdot
.13725 .51765 Mdot
.26275 .78431 Mdot
.3451 .76863 Mdot
.59608 .60392 Mdot
.77255 .77255 Mdot
.35294 .4 Mdot
.34118 .12157 Mdot
.15294 .5451 Mdot
.23137 .73333 Mdot
.41176 .62745 Mdot
.67059 .67451 Mdot
.78431 .80784 Mdot
.38039 .37255 Mdot
.23529 .07451 Mdot
.14902 .55686 Mdot
.21176 .71373 Mdot
.55294 .57255 Mdot
.87843 .88235 Mdot
.49412 .52549 Mdot
.36471 .34902 Mdot
.07451 .12941 Mdot
.16078 .58039 Mdot
.14118 .61569 Mdot
.59608 .59216 Mdot
.56471 .58824 Mdot
.41961 .37647 Mdot
.34902 .31765 Mdot
.07843 .21569 Mdot
.16078 .58824 Mdot
.21961 .51765 Mdot
.78824 .78824 Mdot
.45098 .40392 Mdot
.39608 .2902 Mdot
.34118 .29804 Mdot
.03529 .0902 Mdot
.14902 .59216 Mdot
.52157 .53333 Mdot
.54902 .58039 Mdot
.41176 .30588 Mdot
.38039 .28627 Mdot
.32549 .28627 Mdot
.09804 .36863 Mdot
.18824 .62353 Mdot
.60784 .6 Mdot
.43922 .37255 Mdot
.36471 .24314 Mdot
.39608 .3098 Mdot
.30588 .25098 Mdot
.13333 .52157 Mdot
.28235 .52549 Mdot
.60784 .63137 Mdot
.39216 .2902 Mdot
.37255 .25882 Mdot
.38431 .28627 Mdot
.27843 .20392 Mdot
.09412 .47843 Mdot
.56078 .57647 Mdot
.36078 .27843 Mdot
.38824 .26275 Mdot
.36078 .2549 Mdot
.36863 .25882 Mdot
.1451 .03529 Mdot
.12941 .53333 Mdot
.76078 .74902 Mdot
.40392 .28627 Mdot
.37255 .25098 Mdot
.39608 .29412 Mdot
.35686 .25098 Mdot
.07843 .15686 Mdot
.17647 .43137 Mdot
.39608 .38039 Mdot
.41569 .31765 Mdot
.36863 .25098 Mdot
.38039 .2902 Mdot
.33725 .27843 Mdot
.12549 .45098 Mdot
.56863 .56471 Mdot
.46275 .38431 Mdot
.43922 .33333 Mdot
.37255 .25098 Mdot
.37647 .27451 Mdot
.27843 .2 Mdot
.11765 .49412 Mdot
.68627 .69412 Mdot
.52157 .46275 Mdot
.41961 .32941 Mdot
.35686 .23529 Mdot
.41569 .33333 Mdot
.33725 .24314 Mdot
.15294 .42353 Mdot
.52549 .4549 Mdot
.55686 .49412 Mdot
.39216 .31373 Mdot
.36078 .27451 Mdot
.36863 .28627 Mdot
.14118 .02745 Mdot
.65098 .64314 Mdot
.57255 .59608 Mdot
.45098 .39608 Mdot
.40784 .34902 Mdot
.41569 .38039 Mdot
.34902 .30588 Mdot
.16471 .52549 Mdot
.35686 .31373 Mdot
.42745 .39216 Mdot
.52157 .48235 Mdot
.34118 .32157 Mdot
.37255 .32157 Mdot
.41961 .36471 Mdot
.25098 .43137 Mdot
.39608 .28627 Mdot
.41569 .31765 Mdot
.23137 .21569 Mdot
.27059 .24314 Mdot
.44706 .38431 Mdot
.38431 .29804 Mdot
.55686 .54902 Mdot
.38431 .2549 Mdot
.47059 .41961 Mdot
.33333 .30588 Mdot
.22353 .18039 Mdot
.34118 .30588 Mdot
.26667 .61961 Mdot
.40392 .3098 Mdot
.40392 .2902 Mdot
.43137 .4 Mdot
.39216 .33333 Mdot
.41176 .36078 Mdot
.44314 .40784 Mdot
.45098 .42745 Mdot
.41176 .27451 Mdot
.39608 .33333 Mdot
.51373 .47059 Mdot
.43922 .33333 Mdot
.37647 .32157 Mdot
.6549 .04706 Mdot
.40392 .28627 Mdot
.4 .25882 Mdot
.7098 .69412 Mdot
.41961 .26667 Mdot
.39608 .30588 Mdot
.50196 .46667 Mdot
.38824 .31765 Mdot
.41176 .2902 Mdot
.40392 .31373 Mdot
.5098 .43922 Mdot
.38039 .26275 Mdot
.42353 .4 Mdot
.35686 .17647 Mdot
.40784 .28235 Mdot
.39216 .27451 Mdot
.44314 .39216 Mdot
.37255 .25098 Mdot
.42353 .32549 Mdot
.54902 .52549 Mdot
.30588 .16863 Mdot
.40392 .27059 Mdot
.78431 .76471 Mdot
.3451 .33333 Mdot
.43137 .38039 Mdot
.59608 .59216 Mdot
.3098 .18824 Mdot
.41569 .29804 Mdot
.4 .21961 Mdot
.4549 .40392 Mdot
.48235 .43922 Mdot
.62353 .61569 Mdot
.38431 .27843 Mdot
.34118 .1451 Mdot
.36863 .19608 Mdot
.45882 .38824 Mdot
.44706 .37255 Mdot
.52157 .46667 Mdot
.59608 .59608 Mdot
.35686 .27843 Mdot
.43922 .33725 Mdot
.38039 .23529 Mdot
.63137 .64314 Mdot
.48627 .41176 Mdot
.71373 .71765 Mdot
.23922 .16471 Mdot
.41569 .28627 Mdot
.46275 .36078 Mdot
.6 .57255 Mdot
.53725 .52157 Mdot
.78824 .79608 Mdot
.37255 .19216 Mdot
.40784 .29412 Mdot
.44706 .32157 Mdot
.53725 .42353 Mdot
.64706 .63922 Mdot
.8902 .89412 Mdot
.33725 .07843 Mdot
.41569 .32941 Mdot
.45882 .3451 Mdot
.45882 .29804 Mdot
.59608 .48627 Mdot
.92157 .93725 Mdot
.35686 .0902 Mdot
.39608 .33333 Mdot
.46275 .36863 Mdot
.56078 .42745 Mdot
.8902 .81569 Mdot
.85882 .8902 Mdot
.3451 .19608 Mdot
.38824 .32157 Mdot
.4549 .37647 Mdot
.63137 .55294 Mdot
.99608 .98824 Mdot
.81569 .84706 Mdot
.34902 .30196 Mdot
.4902 .43922 Mdot
.52941 .45098 Mdot
.88235 .84706 Mdot
.99216 .99608 Mdot
.73725 .74118 Mdot
.43137 .38824 Mdot
.47843 .42745 Mdot
.61176 .56078 Mdot
.99216 .99216 Mdot
.87451 .89412 Mdot
.35686 .16471 Mdot
.42745 .36078 Mdot
.57647 .55294 Mdot
.99608 .99216 Mdot
.89412 .9098 Mdot
.76863 .78039 Mdot
.47451 .43137 Mdot
.59608 .58431 Mdot
1 .99216 Mdot
.97255 .98039 Mdot
.82353 .82745 Mdot
.45098 .41569 Mdot
.57647 .55294 Mdot
.92157 .92157 Mdot
.97647 .98039 Mdot
.83529 .84314 Mdot
.43137 .38824 Mdot
.60784 .59216 Mdot
.90196 .90588 Mdot
.92157 .92941 Mdot
.83137 .84706 Mdot
.46275 .43137 Mdot
.67059 .66275 Mdot
.98824 .99216 Mdot
.93333 .92941 Mdot
.52549 .44314 Mdot
.53725 .51373 Mdot
.89804 .90588 Mdot
.96078 .96078 Mdot
.85098 .8549 Mdot
.48235 .43922 Mdot
.7451 .7451 Mdot
.96863 .96471 Mdot
.8902 .8902 Mdot
.38824 .2549 Mdot
.72549 .72549 Mdot
.93333 .93725 Mdot
.90196 .9098 Mdot
.4902 .41569 Mdot
.83529 .83922 Mdot
.91765 .92941 Mdot
.77255 .18824 Mdot
.6902 .68627 Mdot
.94118 .94118 Mdot
.78039 .20784 Mdot
.69804 .67451 Mdot
.65882 .59608 Mdot
.49804 .32157 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool4oomo00?ooooo00Googl0ooooooooO`3ooooooomo0006
ooooo`04oomo0?oooooooooooomo02gooooo00?oogl0ooooooooool05?ooool4oomo02[ooooo00?o
ogl0ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o
X23`ooooooooool0Noooool00ol0003oooooooooo`09ooooo`002_ooool6oomo00?ooooo00?oogl0
ooooooooool01oooool01?ooO`3ooooooomo0?ooO`14ooooo`Coogl02oooool00oooO`3ooooooooo
o`17ooooo`03o`000?oooooooooo00oooooo00?oX23`ooooooooool01Oooool00onP8?3ooooooooo
o`12ooooo`03oj0Pl?oooooooooo023ooooo0_nP8?12ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`Coogl00_ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo04oooooo00?oogl0
ooooooooool0Doooool00ol0003oooooooooo`0?ooooo`03oj0Pl?oooooooooo00kooooo00?oX23`
ooooooooool00oooool00onP8?3oooooooooo`0[ooooo`;oX23`KOooool00ol0003oooooooooo`09
ooooo`002_ooool7oomo0003ooooooooO`3oogl005[ooooo00?oogl0ooooooooool0COooool00ol0
003oooooooooo`0?ooooo`;oX23`00?ooooooj0Pl?ooool0Boooool00onP8?3oooooooooo`02oooo
o`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool0Eoooool00ol0003oooooooooo`09oooo
o`002_ooool6oomo00Gooooo00?oogl0ooooooooool08_ooool00oooO`3oooooooooo`21ooooo`03
o`000?oooooooooo00oooooo1?nP8?0Booooo`03oj0Pl?oooooooooo00;oX23`:?ooool00onP8?3o
ooooooooo`1^ooooo`03o`000?oooooooooo00Wooooo000:ooooo`_oogl02_ooool00oooO`3ooooo
ooooo`04ooooo`03oomo0?oooooooooo04Cooooo00?oogl0ooooooooool0C_ooool00ol0003ooooo
ooooo`0?ooooo`KoX23`0_ooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?oooooooooo03Sooooo
00?oX23`ooooooooool06_ooool00onP8?3oooooooooo`0Looooo`03oj0Pl?oooooooooo023ooooo
00?o0000ooooooooool02Oooool000[ooooo1oooO`000oooooooogl0oomo0003oomo0003oooooooo
O`3oogl00:Cooooo00?o0000ooooooooool03oooool00onP8?3oooooooooo`03oj0Pl4gooooo00?o
X23`ooooooooool05Oooool00onP8?3oooooooooo`16ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?ooO`3oogl000Koogl000?ooooooomo0?ooO`000oooool2oomo02;ooooo00?oogl0
ooooooooool0O_ooool00ol0003oooooooooo`0?ooooo`;oX23`0_ooool3oj0Pl003oooooonP8?3o
oooo0:[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooO`003OooO`0Soooo
o`03oomo0?oooooooooo01?ooooo00?oogl0ooooooooool0;_ooool01?ooO`3oooooooooooooO`0J
ooooo`04oomo0?oooooooooooomo01Sooooo00?o0000ooooooooool03oooool2oj0Pl003oooooonP
8?3oX23`00;oX23`00Cooooooj0Pl?ooooooX23`1?ooool00onP8?3oooooooooo`0mooooo`03oj0P
l?oooooooooo02Cooooo00?oX23`ooooooooool07?ooool2oj0Pl1gooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo1_ooO`000oooooooogl0oomo0002oomo05kooooo
00?oogl0ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`000?nP8?3ooooo00?oX23`
00?ooooooj0Pl?nP8?001?ooool00onP8?3oooooooooo`0Mooooo`03oj0Pl?oooooooooo08Cooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo2oooO`000oooooooogl0
ooooo`0Yooooo`03oomo0?oooooooooo03[ooooo00Coogl0ooooooooooooogl0>?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?nP8?3oX23`00KoX23`00?ooooooj0Pl?ooool01?ooool2oj0Pl0;o
oooo00?oX23`ooooooooool0@_ooool01OnP8?3oooooooooooooooooX23`05Kooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool00oooool:oomo0003ooooooooO`3ooooo043o
oooo00?oogl0ooooooooool0G_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o
oooo0onP8?03ooooo`04oj0Pl?oooooooooooj0Pl:Cooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool00oooool00oooO`3ooooooomo0004oomo0003ooooooooO`3oogl001[o
oooo00?oogl0ooooooooool0Qoooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
o`CoX23`00Gooooooj0Pl?oooooooooooj0Pl02Wooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo00?ooooo2?ooO`000oooooooogl0oomo001Yooooo`03oomo0?oooooooooo
03Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`KoX23`0oooool00onP
8?3oooooooooo`0:ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool04?ooool00onP
8?3oooooooooo`0mooooo`03oj0Pl?oooooooooo03Cooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool01oooool5oomo0003ooooooooO`3ooooo00Gooooo00Coogl0oooooooo
ooooogl0Q?ooool00oooO`3oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo0_nP8?04ooooo`03oj0Pl?oooooooooo00;ooooo00CoX23`ooooooooooooX23`2?oo
ool00onP8?3oooooooooo`16ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool04_oo
ool00onP8?3oooooooooo`0booooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo00Oooooo1oooO`000oooooooogl0ooooo`0<ooooo`03oomo0?oooooooooo097ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`;oX23`00Kooooooj0Pl?nP8?3oX23`oooo
oonP8?07ooooo`05oj0Pl?oooooooooooooooonP8?009oooool00onP8?3oooooooooo`0Qooooo`03
oj0Pl?oooooooooo04gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
1oooool4oomo00;ooooo00Coogl0oooooooooooooooo0_ooO`1[ooooo`03oomo0?oooooooooo033o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`;oX23`00Cooooooj0Pl?oo
oooooooo0_nP8?000oooooooX23`ooooo`09ooooo`03oj0Pl?oooooooooo09Sooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool00oooool01?ooO`3ooooooomo0?ooool2oomo
0006ooooooooO`3oogl0oomo0?ooooooogl00_ooool00oooO`3oooooooooo`2Mooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01Oooool00onP8?3ooooooj0Pl003oj0Pl003oooooonP
8?3ooooo00Cooooo00?oX23`ooooooooool0W?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`08ooooo`03oomo0?ooooooogl000?oogl00oooool00oooO`3oooooooooo`1Z
ooooo`03oomo0?oooooooooo033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02
ooooo`03oj0Pl?oooooooooo00;ooooo0onP8?2Wooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo00Sooooo00Googl0ooooooooooooogl0ooooo`02oomo0005ooooooooO`3o
ooooooooooooO`009_ooool00oooO`3oooooooooo`1dooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01oooool2oj0Pl6Sooooo00?oX23`ooooooooool0?Oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`09ooooo`04oomo0?oooooooooooomo00;ooooo1Ooo
O`02ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool0Toooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Sooooo0onP8?06ooooo`03oj0Pl?ooooooX23`00[ooooo00?o
X23`ooooooooool0T?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0<
ooooo`;oogl0MOooool00oooO`3oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02_ooool2oj0Pl0Gooooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oo
oooooooo01oooooo00?oX23`ooooooooool0=_ooool00onP8?3oooooooooo`0kooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo00cooooo0_ooO`001?ooooooogl0oooooooo
ool3oomo0003ooooooooO`3ooooo00;oogl0Uoooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Kooooo0_nP8?02ooooo`?oX23`0oooool00onP8?3ooooooj0Pl00@ooooo`05oj0Pl?oo
oooooooooooooonP8?00ROooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0?ooooo`03oomo0?ooooooogl000;ooooo00?oogl0ooooooooO`000_ooool00oooO`3ooooooooo
o`2Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00onP8?3ooooooooo
o`03ooooo`03oj0Pl?ooooooX23`00?ooooo00?oX23`ooooooooool0VOooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`0=ooooo`04oomo0?ooooooooooooooo`;oogl00ooo
ool3oomo00;ooooo00?oogl0ooooooooool0Toooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00gooooo00CoX23`oooooonP8?3oX23`0oooool00onP8?3oooooooooo`2Jooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00cooooo00?oogl0ooooooooool00_oo
ool01OooO`3oooooooooooooO`3ooooo00;oogl01?ooool01_ooO`3oooooooooooooO`3ooooooomo
05oooooo00?oogl0ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo00?oX23`ooooooooool02Oooool01OnP8?3ooooooj0Pl?nP8?3ooooo00;oX23`9Oooool0
0onP8?3oooooooooo`1dooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
00oooooo00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`2Fooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02Oooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo
09_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool04?ooool00oooO`3o
ooooooooo`03ooooo`03oomo0?oooooooooo00;oogl000?ooooooomo0?ooO`00Ioooool00oooO`3o
ooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool00onP8?3o
ooooooooo`0=ooooo`03oj0Pl?oooooooooo04Kooooo00?oX23`ooooooooool0B_ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0=ooooo`03oomo0?oooooooooo00kooooo
00?oogl0ooooooooool0T?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo
00?oX23`ooooooooool0Z_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0Aooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool00oooool00oooO`3ooooooooo
o`03ooooo`03oomo0?oooooooooo08Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Aooooo`03oj0Pl?ooooooX23`00;oX23`1oooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oo
oooooooo00Wooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`1aooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo01Wooooo00?oogl0ooooooooool03_ooool0
0oooO`3oooooooooo`0Looooo`03oomo0?oooooooooo06Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`07ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool00_ooool0
0onP8?3oooooooooo`0Nooooo`03oj0Pl?oooooooooo07?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool04_ooool00oooO`3oooooooooo`09ooooo`05oomo0?oooooooooo
ooooooooO`00S_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo0_nP8?02
ooooo`03oj0Pl?oooooooooo00Wooooo00GoX23`oooooooooooooooooj0Pl006ooooo`03oj0Pl?oo
oooooooo00kooooo00?oX23`ooooooooool0LOooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`0Looooo`07oomo0?ooooooogl0ooooooooO`3ooooooomo000_ooooo`03oomo
0?oooooooooo05cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`;oX23`
0oooool01?nP8?3ooooooooooonP8?04ooooo`03oj0Pl?ooooooX23`00;ooooo0onP8?001?oooooo
X23`ooooooooool2oj0Pl003oooooonP8?3ooooo00;ooooo0_nP8?2;ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo01;ooooo00?oogl0ooooooooool02Oooool01?ooO`3o
oooooomo0?ooool2oomo00cooooo00?oogl0ooooooooool0O_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Sooooo0_nP8?0:ooooo`;oX23`7oooool00onP8?3oooooooooo`1@oooo
o`03oj0Pl?oooooooooo02Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool08_ooool2oomo0004ooooooooO`3ooooooomo027ooooo00?oogl0ooooooooool0IOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?oX23`ooooooooool02Oooool00onP
8?3ooooooj0Pl00@ooooo`03oj0Pl?ooooooX23`00Kooooo00?oX23`ooooooooool02oooool01?nP
8?3oooooooooooooool2oj0Pl2Kooooo00?oX23`ooooooooool0Aoooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`0Gooooo`03oomo0?oooooooooo00_ooooo00Googl0oooo
ooooO`3ooooooomo000Pooooo`03oomo0?oooooooooo06Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`oooooonP8?006oooool0
0onP8?3oooooooooo`1oooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
01Kooooo00Googl0oooooooooooooooooomo002Fooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02Oooool01?nP8?3ooooooooooonP8?03ooooo`03oj0Pl?oooooooooo00Oooooo00Go
X23`oooooooooooooooooj0Pl00@ooooo`03oj0Pl?oooooooooo05Sooooo00?oX23`ooooooooool0
9?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Mooooo`03oomo0?oo
ooooogl000Cooooo0_ooO`03ooooo`03oomo0?ooooooogl006Cooooo00?oogl0ooooooooool07_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?oX23`ooooooooool02Ooo
ool01OnP8?3oooooooooooooooooX23`00;ooooo00CoX23`ooooooooooooX23`0oooool00onP8?3o
ooooooooo`0=ooooo`03oj0Pl?oooooooooo057ooooo00?oX23`ooooooooool09Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Gooooo`03oomo0?oooooooooo00Cooooo
00?oogl0ooooooooool00oooool01OooO`3oooooooooooooO`3ooooo00;oogl01_ooool00oooO`3o
ooooooooo`02ooooo`03oomo0?oooooooooo07Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0;ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool02?ooool2oj0Pl3Co
oooo00?oX23`ooooooooool0Doooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`0Fooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01?ooool01?ooO`3ooooo
ooooooooool2oomo00Kooooo00?oogl0ooooooooO`00P?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00?ooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`03ooooo`;o
X23`1Oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?oooooooooo01Gooooo00?oX23`oooooooo
ool0JOooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Tooooo`03oomo
0?oooooooooo00Sooooo00?oogl0ooooooooool06?ooool00oooO`3oooooooooo`1Tooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07Oooool00onP8?3oooooooooo`02ooooo`03oj0P
l?oooooooooo08cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool08_oo
ool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo08Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`08oj0Pl?oooooooooooj0Pl?ooooooX23`oooooonP8?0Doooo
o`05oj0Pl?ooooooX23`oooooonP8?000oooool00onP8?3oooooooooo`0<ooooo`04oj0Pl?oooooo
oooooj0Pl0?ooooo00?oX23`ooooooooool0KOooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`0Wooooo`04oomo0?ooooooogl0oomo00Gooooo00?oogl0ooooooooool05ooo
ool00oooO`3ooooooomo001Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?oo
ool01?nP8?3ooooooooooonP8?02ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`ooooooooool0
1_ooool00onP8?3oooooooooo`20ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo023ooooo00?oogl0ooooooooool00_ooool01OooO`3oooooooooooooooooogl008Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`03oj0Pl?oooooooooo00Cooooo
00?oX23`oooooonP8?002oooool01OnP8?3oooooooooooooooooX23`07;ooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool09oooool00oooO`3oooooooooo`06ooooo`;oogl0
0oooool2oomo00?ooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`1/ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04_ooool00onP8?3oooooooooo`0:ooooo`04oj0P
l?oooooooooooj0Pl0?ooooo00?oX23`ooooooooool02oooool00onP8?3oooooooooo`05ooooo`;o
X23`00?ooooooj0Pl?nP8?00L?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`0Yooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooO`004Oooool00oooO`3ooooo
ooooo`1Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00onP8?3ooooo
ooooo`02ooooo`03oj0Pl?oooooooooo00;oX23`1Oooool00onP8?3oooooooooo`0;ooooo`04oj0P
l?ooooooooooooooo`;oX23`KOooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`0Tooooo`03oomo0?oooooooooo00Oooooo00Coogl0ooooooooooooogl01_ooool00oooO`3o
ooooooooo`0:ooooo`;oogl02?ooool00oooO`3oooooooooo`1Oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00onP8?3ooooooj0Pl007ooooo`03oj0Pl?oooooooooo00?o
oooo00?oX23`ooooooooool01oooool01OnP8?3oooooooooooooooooX23`00Cooooo1?nP8?001Ooo
ooooX23`oj0Pl?ooooooX23`00Cooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`03
oj0Pl004oooooonP8?3ooooooj0Pl6_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
ooooooooool0;oooool00oooO`3oooooooooo`1oooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04_ooool00onP8?3oooooooooo`0Fooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`
ooooooooool03?ooool00onP8?3oooooooooo`1Vooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo02Gooooo00?oogl0ooooooooool07Oooool00oooO`3oooooooooo`0Zoooo
o`03oomo0?oooooooooo03cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]oooo
o`03oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool0J?ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`0Uooooo`04oomo0?oooooooooooomo00;ooooo0_ooO`04oooo
o`03oomo0?oooooooooo00Oooooo00Coogl0ooooooooooooogl00_ooool2oomo00?ooooo00?oogl0
ooooooooool0J?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?oX23`
ooooooooool01oooool2oj0Pl0;ooooo00GoX23`oooooonP8?3ooooooj0Pl002ooooo`03oj0Pl?oo
oooooooo00Cooooo00?oX23`ooooooooool00_nP8?02ooooo`?oX23`0oooool00onP8?3ooooooooo
o`1Wooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04?ooooo00?oogl0
ooooooooool0Joooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?oX23`
ooooooooool00_ooool00onP8?3ooooooj0Pl003ooooo`04oj0Pl?oooooooooooj0Pl1?ooooo00?o
X23`ooooooooool0J?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0[
ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool00_ooool01OooO`3ooooooomo0?oo
ooooogl000Cooooo00Coogl0ooooooooooooogl00_ooool00oooO`3oooooooooo`1Yooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool01OnP8?3oooooooooooooooooX23`01Go
oooo00?oX23`ooooooooool00oooool01_nP8?3ooooooooooonP8?3ooooooj0Pl0Sooooo00?oX23`
ooooooooool01Oooool00onP8?3ooooooj0Pl003oj0Pl004oooooonP8?3oX23`oj0Pl1cooooo00?o
X23`ooooooooool0BOooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0c
ooooo`03oomo0?oooooooooo00oooooo00?oogl0ooooooooool0JOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02gooooo0_nP8?000oooooooX23`ooooo`0Booooo`03oj0Pl?oooooo
X23`06[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0A_ooool00ooo
O`3oooooooooo`0<ooooo`03oomo0?oooooooooo05Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0?ooooo`05oj0Pl?oooooooooooooooonP8?006Oooool00onP8?3oooooooooo`03
ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`03
ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool0Goooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`0Wooooo`03oomo0?oooooooooo00cooooo00Coogl0oooo
ooooooooogl01_ooool00oooO`3oooooooooo`04ooooo`;oogl00_ooool00oooO`3oooooooooo`04
ooooo`03oomo0?oooooooooo05cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04
ooooo`03oj0Pl?oooooooooo01Oooooo00?oX23`ooooooooool03Oooool01?nP8?3ooooooj0Pl?oo
ool2oj0Pl004oooooonP8?3oX23`ooooo`?oX23`00Cooooooj0Pl?ooooooX23`1Oooool01?nP8?3o
oooooooooonP8?1Yooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo033o
oooo00?oogl0ooooooooool00oooO`0Aooooo`03oomo0?ooooooogl000Oooooo00?oogl0oooooooo
ool0GOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?oX23`oooooooo
ool07oooool2oj0Pl005oooooonP8?3oX23`oooooonP8?002Oooool00onP8?3oooooooooo`03oooo
o`03oj0Pl?ooooooX23`06[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool0;Oooool2oomo0003ooooooooO`3ooooo00?ooooo00?oogl0ooooooooool00oooool00oooO`3o
ooooooooo`06ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01oooool00oooO`3o
ooooooooo`1Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00onP8?3o
ooooooooo`0?ooooo`03oj0Pl?oooooooooo00Gooooo0onP8?09ooooo`?oX23`0_ooool00onP8?3o
ooooooooo`05ooooo`?oX23`1Oooool01_nP8?3ooooooj0Pl?nP8?3ooooooj0Pl6Sooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0<oooool00oooO`3oooooooooo`0=oooo
o`03oomo0?oooooooooo00oooooo00?oogl0ooooooooool0FOooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02gooooo00GoX23`oooooonP8?3oX23`ooooo`02oj0Pl0Kooooo00?oX23`
ooooooooool00oooool2oj0Pl003oooooonP8?3ooooo00Sooooo00?oX23`ooooooooool01_ooool0
0onP8?3oooooooooo`1Hooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
03Kooooo00Googl0ooooooooooooogl0ooooo`02oomo00Gooooo00Coogl0ooooooooO`3oogl00ooo
ool00oooO`3oooooooooo`0:ooooo`03oomo0?oooooooooo05Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0<ooooo`05oj0Pl?oooooooooooooooonP8?006_ooool00onP8?3ooooo
ooooo`04ooooo`03oj0Pl?ooooooX23`00_ooooo0_nP8?06ooooo`;oX23`0oooool00onP8?3ooooo
ooooo`1Qooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04Wooooo00?o
ogl0ooooooooool0IOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o
X23`ooooooooool01oooool01?nP8?3ooooooooooonP8?03ooooo`;oX23`1Oooool00onP8?3ooooo
oj0Pl002oj0Pl0;ooooo00GoX23`oooooooooooooooooj0Pl01Tooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`000?oooooooooo03Cooooo00?oogl0ooooooooO`002?ooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?oooooooooo00Cooooo00Coogl0ooooooooooooogl0H_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?oX23`ooooooooool06?ooool00onP8?3o
ooooooooo`02ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`ooooooooool0H_ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0hooooo`;oogl02oooool01?ooO`3ooooo
ooooooooO`05ooooo`03oomo0?oooooooooo063ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Iooooo`04oj0Pl?oooooooooooj0Pl0kooooo0_nP8?000oooooooX23`ooooo`02oooo
o`08oj0Pl?oooooooooooj0Pl?ooooooX23`oooooonP8?02ooooo`03oj0Pl?oooooooooo00?oX23`
3Oooool00onP8?3oooooooooo`1Oooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo043ooooo00?oogl0ooooooooool02Oooool4oomo0005ooooooooO`3oooooooooooooO`00
G?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?oX23`ooooooooool0
8_ooool00onP8?3ooooooj0Pl003ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool0
J?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0hooooo`07oomo0?oo
oooooooooomo0?ooooooogl0ooooo`02oomo00Kooooo00Googl0oooooooooooooooooomo0002oooo
o`?oogl01Oooool00oooO`3oooooooooo`1Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07?ooool00onP8?3ooooooj0Pl00?ooooo`03oj0Pl?oooooooooo00Cooooo0_nP8?000ooo
ooooX23`ooooo`02ooooo`08oj0Pl?oooooooooooj0Pl?ooooooX23`oooooonP8?1]ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03_ooooo00Ooogl0oooooooooooooooo
oomo0?ooooooogl000Oooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`1Nooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00onP8?3ooooooj0Pl009ooooo`03
oj0Pl?oooooooooo00Wooooo00CoX23`oooooonP8?3oX23`0_ooool01?nP8?3ooooooooooonP8?05
ooooo`03oj0Pl?oooooooooo05kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0A?ooool00oooO`3oooooooooo`07ooooo`04oomo0?ooooooogl0oomo00Wooooo00?oogl0
ooooooooool0Doooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`0Kooooo`03oj0Pl?oooooooooo00;ooooo00GoX23`
oooooooooooooooooj0Pl002ooooo`;oX23`00?ooooooj0Pl?ooool0Ioooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`0cooooo`03oomo0?oooooooooo00Sooooo00?oogl0
ooooooooool01Oooool00oooO`3oooooooooo`02oomo00;ooooo0_ooO`001_ooooooogl0oomo0?oo
O`3ooooooomo05cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03oj0P
l?oooooooooo01Cooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`02ooooo`03oj0P
l?ooooooX23`00Cooooo0onP8?08ooooo`;oX23`0_ooool00onP8?3oooooooooo`1Nooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03oooooo00?oogl0ooooooooool03?oo
ool00oooO`3ooooooomo001Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05ooo
ool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00oooooo00?oX23`oooooonP8?000ooo
ool2oj0Pl0Kooooo00?oX23`oooooonP8?000_ooool00onP8?3ooooooj0Pl006ooooo`05oj0Pl?oo
oooooooooooooonP8?003oooool2oj0Pl4cooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0@_ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00;ooooo0ooo
O`000oooooooogl0oomo0004ooooo`05oomo0?ooooooooooooooooooO`00E?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02Cooooo00CoX23`ooooooooooooX23`1oooool00onP8?3o
ooooooooo`05ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00oooool7oj0Pl005
oooooonP8?3oX23`oooooonP8?000_ooool00onP8?3oooooooooo`1Nooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo04;ooooo00?oogl0ooooooooool01?ooool00oooO`3o
oooooomo0004ooooo`?oogl01?ooool00oooO`3oooooooooo`1Gooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05_ooool00onP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo01Wo
oooo00CoX23`oooooonP8?3oX23`0oooool5oj0Pl003oooooonP8?3oX23`00GoX23`0_ooool00onP
8?3oooooooooo`0Aooooo`03oj0Pl?oooooooooo04_ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0@?ooool00oooO`3oooooooooo`02oomo00Gooooo00?oogl0oooooooo
ool00_ooool2oomo00Kooooo00?oogl0ooooooooool0Eoooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Cooooo00GoX23`oooooooooooooooooj0Pl006ooooo`03oj0Pl?oooooooooo
00Cooooo00?oX23`oooooonP8?004Oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo
00?oX23`00?ooooooj0Pl?ooool00onP8?06ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`oooo
ooooool0COooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0mooooo`03
oomo0?oooooooooo00;ooooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`03ooooo`03
oomo0?oooooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`05
oj0Pl?oooooooooooooooonP8?007?ooool2oj0Pl0?ooooo00?oX23`ooooooooool00_ooool5oj0P
l0Gooooo00?oX23`ooooooooool0G_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`18ooooo`04oomo0?oooooooooooomo00Gooooo00?oogl0ooooooooool0GOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?oX23`ooooooooool08Oooool01?nP
8?3ooooooj0Pl?nP8?08ooooo`03oj0Pl?oooooooooo00;oX23`0oooool00onP8?3oooooooooo`05
ooooo`;oX23`5oooool00onP8?3oooooooooo`17ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo03kooooo0_ooO`04ooooo`03oomo0?oooooooooo01kooooo00?oogl0oooo
ooooool0BOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?oX23`oooo
ooooool00_ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`oooo
ooooool08Oooool2oj0Pl005oooooonP8?3ooooooooooonP8?001_ooool00onP8?3oooooooooo`0;
ooooo`;oX23`COooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1:oooo
o`03oomo0?oooooooooo00Cooooo00Coogl0ooooooooooooogl01?ooool00oooO`3oooooooooo`1E
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool00onP8?3ooooooj0Pl004
ooooo`?oX23`00Cooooooj0Pl?ooooooX23`1_ooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?oo
oooooooo00Gooooo00?oX23`ooooooooool0@oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`16ooooo`Coogl00_ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooo
oooo05cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03oj0Pl?oooooo
oooo00Oooooo00?oX23`ooooooooool03_ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooo
oooo00kooooo00OoX23`oooooonP8?3oX23`oooooonP8?3ooooo00?oX23`0_ooool3oj0Pl0;ooooo
00?oX23`ooooooooool01oooool00onP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo04_ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0D?ooool00oooO`3ooooooooo
o`02ooooo`03oomo0?oooooooooo05Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0mooooo`03oj0Pl?oooooooooo00Cooooo00CoX23`ooooooooooooX23`1Oooool2oj0Pl0Cooooo
00?oX23`ooooooooool02?ooool01OnP8?3oooooooooooooooooX23`04kooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool0C_ooool00oooO`3ooooooomo0004ooooo`03oomo
0?oooooooooo05Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03oj0P
l?oooooooooo00[ooooo00?oX23`ooooooooool00oooool01OnP8?3oooooooooooooooooX23`017o
oooo0_nP8?03ooooo`CoX23`00Cooooooj0Pl?nP8?3oX23`5?ooool00onP8?3oooooooooo`17oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo053ooooo00?oogl0oooooooo
O`00G_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?oX23`oooooooo
ool02_ooool00onP8?3oooooooooo`0Jooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooooo
ool00_nP8?02ooooo`GoX23`00?ooooooj0Pl?nP8?000oooool2oj0Pl0?ooooo00?oX23`oooooonP
8?001?ooool01?nP8?3ooooooooooonP8?03ooooo`04oj0Pl?ooooooooooooooo`;oX23`00?ooooo
oj0Pl?ooool0@Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1>oooo
o`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool0Eoooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02?ooooo00CoX23`ooooooooooooX23`8oooool00onP8?3oooooooooo`02
ooooo`;oX23`1Oooool01?nP8?3oooooooooooooool2oj0Pl0Wooooo00GoX23`oooooooooooooooo
oj0Pl017ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04_ooooo00?o
ogl0ooooooooool01oooool00oooO`3ooooooomo0009ooooo`03oomo0?oooooooooo04gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`04oj0Pl?oooooooooooj0Pl0[ooooo
0_nP8?0Fooooo`03oj0Pl?oooooooooo00gooooo00?oX23`ooooooooool00onP8?000oooooooX23`
ooooo`02oj0Pl003oooooonP8?3oX23`00Gooooo00SoX23`ooooooooooooX23`oooooonP8?3ooooo
oj0Pl0;ooooo00?oX23`ooooooooool0Boooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`1Hooooo`03oomo0?oooooooooo05Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0looooo`05oj0Pl?oooooooooooooooonP8?003oooool00onP8?3oooooooooo`03
ooooo`03oj0Pl?oooooooooo00;ooooo00CoX23`ooooooooooooX23`2?ooool2oj0Pl4Sooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0A_ooool00oooO`3oooooooooo`03
ooooo`04oomo0?ooooooogl0oomo00;ooooo00Coogl0ooooooooooooogl00oooool2oomo05Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03oj0Pl?ooooooX23`00Cooooo
00?oX23`ooooooooool01oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo01;ooooo
00CoX23`ooooooooooooX23`0_ooool3oj0Pl003oooooonP8?3ooooo00;oX23`00Cooooooj0Pl?oo
ooooX23`1?ooool00onP8?3oooooooooo`02ooooo`05oj0Pl?ooooooX23`oooooonP8?00Aoooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1Iooooo`03oomo0?oooooooooo
05Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03oj0Pl?oooooooooo
02Gooooo00?oX23`ooooooooool02oooool00onP8?3oooooooooo`03ooooo`05oj0Pl?ooooooX23`
oooooonP8?000_ooool01OnP8?3oooooooooooooooooX23`00Oooooo00?oX23`ooooooooool01_oo
ool00onP8?3oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo05;ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`1Eooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool08_ooool00onP8?3oooooooooo`0Eooooo`03oj0Pl?oooooo
oooo017ooooo0onP8?07ooooo`;oX23`00?ooooooj0Pl?nP8?00E?ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`1Eooooo`06oomo0?ooooooogl0oomo0?ooooooogl01_oo
ool00oooO`3oooooooooo`0?ooooo`03oomo0?oooooooooo03_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03oj0Pl?oooooooooo00Cooooo0_nP8?0=ooooo`04oj0Pl?oo
oooooooooj0Pl1Gooooo00?oX23`ooooooooool01?ooool00onP8?3ooooooj0Pl002ooooo`;oX23`
1?ooool00onP8?3oooooooooo`07oj0Pl0;ooooo00?oX23`ooooooooool01Oooool01onP8?3ooooo
oj0Pl?ooooooX23`oooooonP8?001Oooool00onP8?3oooooooooo`0oooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Iooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool06?ooool00onP8?3o
ooooooooo`0?ooooo`;oX23`00Gooooooj0Pl?oooooooooooj0Pl002ooooo`;oX23`1oooool2oj0P
l0;ooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`11ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo05_ooooo0_ooO`02ooooo`03oomo0?oooooooooo04oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03oj0Pl?oooooooooo017o
oooo00?oX23`ooooooooool03?ooool01OnP8?3oooooooooooooooooX23`00?ooooo00?oX23`oooo
ooooool02?ooool00onP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo00;ooooo0onP8?000ooo
ooooX23`oj0Pl002oj0Pl0Kooooo0_nP8?001?ooooooX23`oj0Pl?ooool3oj0Pl4Sooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0B_ooool00oooO`3oooooooooo`04oooo
o`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooO`00DOooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01;ooooo00?oX23`ooooooooool0<Oooool00onP8?3ooooooj0Pl004oooo
o`03oj0Pl?oooooooooo00Gooooo00GoX23`ooooooooooooX23`ooooo`02oj0Pl0;ooooo00KoX23`
oooooonP8?3oX23`oooooonP8?04ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool0
??ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1Booooo`03oomo0?oo
oooooooo00Cooooo00?oogl0ooooooooool0EOooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03?ooooo00?oX23`ooooooooool05?ooool2oj0Pl0;ooooo00GoX23`oooooooooooooooo
oj0Pl00=ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`oooooonP8?00@oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`1;ooooo`03oomo0?oooooooooo00Gooooo00?o
ogl0ooooooooool01?ooool3oomo00Cooooo0_ooO`1>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0>?ooool00onP8?3oooooooooo`0=ooooo`;oX23`1_ooool01_nP8?3ooooooj0P
l?ooooooX23`ooooo`;oX23`00?ooooooj0Pl?nP8?001?nP8?001?ooooooX23`ooooooooool2oj0P
l0;ooooo1_nP8?000oooooooX23`ooooo`03ooooo`03oj0Pl?oooooooooo03_ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0AOooool00oooO`3oooooooooo`0?ooooo`;o
ogl0F?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?oX23`oooooooo
ool0<_ooool2oj0Pl0Kooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooj0Pl003ooooo`;o
X23`1_ooool01OnP8?3oooooooooooooooooX23`043ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0EOooool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00Go
oooo00?oogl0ooooooooool0A_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`0Looooo`03oj0Pl?oooooooooo00Wo
oooo00?oX23`ooooooooool00_ooool00onP8?3ooooooj0Pl002ooooo`04oj0Pl?oooooooooooooo
o`CoX23`0_ooool01OnP8?3oooooooooooooooooX23`00;ooooo00GoX23`oooooonP8?3oX23`oooo
o`02oj0Pl43ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Eoooool0
0oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool0A_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00GoX23`oooooooooooooooooj0P
l002ooooo`03oj0Pl?oooooooooo01Gooooo00?oX23`ooooooooool05Oooool01?nP8?3ooooooooo
ooooool2oj0Pl0Kooooo00GoX23`oooooooooooooooooj0Pl005ooooo`03oj0Pl?oooooooooo00_o
oooo00?oX23`ooooooooool0@_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`1?ooooo`03oomo0?oooooooooo00?ooooo00Coogl0ooooooooooooogl00oooool2oomo00;o
oooo00?oogl0ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[o
oooo00?oX23`ooooooooool04Oooool00onP8?3ooooooj0Pl00=ooooo`03oj0Pl?oooooooooo00ko
oooo00?oX23`ooooooooool00oooool2oj0Pl0?ooooo00?oX23`ooooooooool01onP8?03ooooo`03
oj0Pl?oooooooooo00;ooooo00CoX23`oooooonP8?3oX23`@Oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`1Gooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
O`00D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?oX23`oooooooo
ool04_ooool00onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo00[ooooo00GoX23`oooooooo
oooooooooj0Pl00?ooooo`03oj0Pl?ooooooX23`00?oX23`1?ooool02?nP8?3ooooooooooonP8?3o
oooooj0Pl?ooooooX23`1_ooool00onP8?3oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo05Wooooo00?oogl0ooooooooool0EOooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo05Wooooo00?oX23`ooooooooool01?ooool2oj0Pl003oooooonP
8?3ooooo00;ooooo00GoX23`oooooonP8?3ooooooj0Pl003ooooo`03oj0Pl?oooooooooo03oooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0EOooool00oooO`3ooooooooo
o`04ooooo`04oomo0?oooooooooooomo00Gooooo0_ooO`000oooooooogl0ooooo`17ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool06?ooool00onP8?3oooooooooo`0Eooooo`03oj0P
l?oooooooooo00Cooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0Dooooo`04oj0P
l?oooooooooooj0Pl0;ooooo00GoX23`oooooonP8?3ooooooj0Pl002ooooo`05oj0Pl?oooooooooo
oj0Pl?ooool00_nP8?001OooooooX23`oooooonP8?3ooooo00;oX23`00Cooooooj0Pl?nP8?3oX23`
?oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1Mooooo`03oomo0?oo
oooooooo057ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1:ooooo`03oj0Pl?oo
oooooooo00Wooooo00?oX23`ooooooooool02?ooool00onP8?3ooooooj0Pl006ooooo`06oj0Pl?oo
oooooooooooooonP8?3ooooo0_nP8?06ooooo`03oj0Pl?oooooooooo03Kooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool0E_ooool01?ooO`3oooooooooooooO`06ooooo`07
oomo0?ooooooogl0ooooooooO`3ooooooomo0004ooooo`;oogl0A?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Sooooo00?oX23`ooooooooool06?ooool00onP8?3oooooooooo`0R
ooooo`03oj0Pl?oooooooooo00?ooooo1?nP8?000oooooooX23`oj0Pl003oj0Pl0;ooooo0onP8?02
ooooo`?oX23`0oooool00onP8?3oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo06Oooooo0_ooO`18ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0H_ooool01?nP8?3oooooooooooooool2oj0Pl0?ooooo00CoX23`oooooonP8?3oX23`0_oo
ool00onP8?3ooooooj0Pl00mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo05cooooo00Coogl0ooooooooooooogl0DOooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo067ooooo00?oX23`oooooonP8?001oooool00onP8?3ooooooj0Pl013ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo05[ooooo00?oogl0ooooooooool00oooool2
oomo0007ooooooooO`3oooooooooooooO`3ooooooomo0018ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0D_ooool00onP8?3oooooooooo`08ooooo`04oj0Pl?oooooooooooj0Pl0;o
oooo00OoX23`oooooooooooooooooj0Pl?ooooooX23`00;ooooo00?oX23`ooooooooool00onP8?0o
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo05cooooo00Googl0oooo
oooooooooooooomo0008ooooo`03oomo0?oooooooooo04Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Eooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool00oooool3
oj0Pl004oooooonP8?3ooooooj0Pl0?ooooo0_nP8?06ooooo`;oX23`1?ooool01OnP8?3ooooooooo
ooooooooX23`03?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0GOoo
ool00oooO`3oooooooooo`03ooooo`;oogl01?ooool01?ooO`3oooooooooooooO`14ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool06_ooool01?nP8?3ooooooooooonP8?0dooooo`03
oj0Pl?ooooooX23`00_ooooo00OoX23`oooooonP8?3oX23`oooooonP8?3ooooo00?oX23`0_ooool2
oj0Pl003oooooonP8?3oX23`00;oX23`1?ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooo
oooo02kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0I_ooool00ooo
O`3oooooooooo`02ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool0?Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?oX23`ooooooooool0AOooool2oj0P
l004oooooonP8?3ooooooj0Pl0Cooooo0_nP8?08ooooo`;oX23`>Oooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`1Qooooo`?oogl00oooool00oooO`3oooooooooo`02oomo
0003ooooooooO`3ooooo04;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hoooo
o`03oj0Pl?oooooooooo03kooooo00?oX23`ooooooooool00_ooool01?nP8?3ooooooj0Pl?nP8?02
ooooo`;oX23`00Oooooooj0Pl?nP8?3ooooooj0Pl?ooooooX23`00;ooooo0_nP8?02ooooo`03oj0P
l?oooooooooo00;ooooo00CoX23`ooooooooooooX23`=Oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`1Rooooo`04oomo0?ooooooooooooooo`;oogl00_ooool2oomo04Go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Zooooo`;oX23`00Cooooooj0Pl?oo
oooooooo0_nP8?06ooooo`03oj0Pl?oooooooooo03Kooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0J?ooool2oomo04Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Mooooo`03oj0Pl?oooooooooo04Gooooo1?nP8?03ooooo`04oj0Pl?oooooooooooj0P
l0Cooooo00?oX23`oooooonP8?001_ooool00onP8?3ooooooj0Pl00aooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo06Gooooo00?oogl0ooooooooool00oooool4oomo00Go
oooo00?oogl0ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_o
oooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`0Gooooo`03oj0Pl?oooooooooo00co
oooo00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`04ooooo`03oj0Pl?ooooooX23`00;o
X23`1Oooool00onP8?3oooooooooo`02oj0Pl003oooooonP8?3ooooo00?ooooo00?oX23`oooooooo
ool00onP8?0cooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Wooooo
0_ooO`03ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool0>oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?oX23`ooooooooool0E?ooool01?nP8?3ooooo
ooooooooool2oj0Pl0Kooooo00?oX23`ooooooooool00_nP8?0cooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`000?oooooooooo06Sooooo00?oogl0ooooooooool00_ooool00oooO`3ooooo
oomo0002ooooo`06oomo0?oooooooooooomo0?ooooooogl0>Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01oooooo0_nP8?0<ooooo`03oj0Pl?oooooooooo01oooooo00?oX23`oooo
ooooool00oooool00onP8?3oooooooooo`0=ooooo`04oj0Pl?ooooooX23`ooooo`;oX23`2_ooool2
oj0Pl0Cooooo00?oX23`ooooooooool00_nP8?0aooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`17oooo
o`04oj0Pl?oooooooooooj0Pl1Wooooo00?oX23`oooooonP8?000_ooool2oj0Pl0Wooooo00?oX23`
oooooonP8?001_ooool3oj0Pl37ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0L?ooool00oooO`3oooooooooo`0nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0H_ooool01OnP8?3ooooooooooonP8?3ooooo00;oX23`00?ooooooj0Pl?ooool01oooool0
0onP8?3oooooooooo`08ooooo`;oX23`00Cooooooj0Pl?ooooooX23`;Oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`1Uooooo`03oomo0?oooooooooo00;ooooo00?oogl0
ooooooooool00_ooO`08ooooo`03oomo0?oooooooooo03Oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Wooooo`03oj0Pl?oooooooooo00oooooo00?oX23`ooooooooool08Oooool0
0onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00Gooooo0_nP8?001_ooooooX23`oj0Pl?oo
ooooX23`ooooo`;oX23`1_ooool01?nP8?3ooooooj0Pl?ooool2oj0Pl003oooooonP8?3oX23`02go
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0L_ooool3oomo03cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1_ooooo`03oj0Pl?oooooooooo00;oX23`
2?ooool01?nP8?3oooooooooooooool2oj0Pl2oooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0K_ooool00oooO`3oooooooooo`02ooooo`05oomo0?ooooooogl0oooooooo
O`004_ooool00oooO`3oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Goooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooooonP
8?000onP8?000oooooooX23`ooooo`02ooooo`;oX23`00?ooooooj0Pl?ooool01Oooool4oj0Pl0;o
oooo00?oX23`ooooooooool0:Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00onP8?3ooooo
ooooo`07ooooo`03oj0Pl?oooooooooo00Kooooo00CoX23`oooooonP8?3oX23`0oooool01?nP8?3o
oooooooooonP8?06ooooo`06oj0Pl?oooooooooooj0Pl?ooooooX23`;?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`1aooooo`?oogl0?Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo027ooooo00?oX23`ooooooooool0>_ooool00onP8?3oooooooooo`06
ooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool00oooool00onP8?3ooooooj0Pl009
ooooo`05oj0Pl?ooooooX23`oooooonP8?00:_ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`1_ooooo`04oomo0?oooooooooooomo03kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1]ooooo`04oj0Pl?ooooooX23`ooooo`CoX23`00Kooooooj0Pl?oooooo
X23`oooooonP8?05ooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo0_nP8?0Yooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo073ooooo0_ooO`09ooooo`03oomo0?oooooooooo
00Kooooo00?oogl0ooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
06Wooooo00CoX23`ooooooooooooX23`1?ooool00onP8?3oooooooooo`06ooooo`04oj0Pl?oooooo
oooooj0Pl0Kooooo00CoX23`ooooooooooooX23`:Oooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`1aooooo`;oogl01?ooool2oomo0003ooooooooO`3ooooo03Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`03oj0Pl?oooooooooo03Sooooo0_nP
8?001?ooooooX23`oooooonP8?02ooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo0_nP8?000ooooooo
X23`ooooo`03ooooo`03oj0Pl?oooooooooo02Oooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0M?ooool2oomo00;ooooo00?oogl0ooooooooool0=_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo06oooooo00CoX23`oooooooooooooooo0_nP8?07ooooo`04
oj0Pl?oooooooooooj0Pl0?ooooo00?oX23`ooooooooool00_nP8?000oooooooX23`ooooo`0Voooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06oooooo00?oogl0oooooooo
O`000oooool01?ooO`3ooooooomo0?ooool2oomo0003ooooooooO`3oogl003?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0[ooooo`03oj0Pl?oooooooooo03_ooooo00OoX23`oooo
oooooooooooooj0Pl?ooooooX23`00Cooooo00CoX23`oooooonP8?3ooooo0_nP8?001?ooooooX23`
oooooonP8?02ooooo`05oj0Pl?oooooooooooj0Pl?ooool00_nP8?0Zooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo07Cooooo00?oogl0ooooooooool02Oooool01?ooO`3o
ooooooooooooO`0]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00onP
8?3oooooooooo`1<ooooo`03oj0Pl?oooooooooo00?oX23`1?ooool2oj0Pl003oooooonP8?3ooooo
00Cooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0Sooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo07Oooooo00?oogl0ooooooooool01_ooool00oooO`3o
ooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00onP8?3o
ooooooooo`0_ooooo`03oj0Pl?oooooooooo00oooooo0_nP8?000oooooooX23`oj0Pl002ooooo`Co
X23`1_ooool00onP8?3oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo07Cooooo0_ooO`04ooooo`;oogl00oooool00oooO`3oooooooooo`03ooooo`03oomo
0?oooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1cooooo`;oX23`
0_ooool01OnP8?3ooooooj0Pl?nP8?3ooooo00;oX23`00Cooooooj0Pl?ooooooX23`0_ooool00onP
8?3oooooooooo`03ooooo`?oX23`9?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`1iooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool0;?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?oX23`ooooooooool0DOooool00onP8?3o
ooooooooo`04ooooo`03oj0Pl?oooooooooo00;oX23`1?ooool00onP8?3oooooooooo`03ooooo`03
oj0Pl?ooooooX23`02Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
NOooool01OooO`3oooooooooooooO`3ooooo00Coogl00_ooool00oooO`3ooooooomo000Zooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool00onP8?3oooooooooo`1;ooooo`03
oj0Pl?oooooooooo00;ooooo00CoX23`oooooonP8?3ooooo1onP8?000oooooooX23`ooooo`02oj0P
l006oooooonP8?3ooooooj0Pl?ooooooX23`9Oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`1oooooo`;oogl000?ooooooomo0?ooool01_ooool00oooO`3oooooooooo`0T
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOooool00onP8?3oooooooooo`07
ooooo`03oj0Pl?ooooooX23`00?ooooo00?oX23`ooooooooool01_ooool2oj0Pl2Gooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0NOooool01?ooO`3oooooooooooooO`07
ooooo`;oogl0:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo00?oX23`
ooooooooool0>_ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00?ooooo0_nP8?03
ooooo`05oj0Pl?oooooooooooooooonP8?001Oooool00onP8?3oooooooooo`0Pooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo087ooooo00?oogl0ooooooooool00_ooool0
0oooO`3oooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool0
1?nP8?3ooooooooooonP8?13ooooo`03oj0Pl?ooooooX23`00Cooooo00?oX23`ooooooooool01_oo
ool01?nP8?3oooooooooooooool3oj0Pl0Cooooo0onP8?06ooooo`03oj0Pl?oooooooooo023ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0POooool2oomo02kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1mooooo`03oj0Pl?ooooooX23`00;ooooo00Co
X23`oooooonP8?3oX23`:oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`1nooooo`03oomo0?ooooooogl000?oogl0;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo06;ooooo00?oX23`ooooooooool02Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oo
oooooooo00cooooo1?nP8?000oooooooX23`ooooo`0Xooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo07_ooooo0_ooO`03ooooo`03oomo0?oooooooooo00?ooooo00?oogl0
ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?oX23`
ooooooooool0F?ooool00onP8?3oooooooooo`02oj0Pl005oooooonP8?3ooooooooooonP8?009ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1kooooo`;oogl01_ooool0
0oooO`3ooooooomo0003oomo02Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`21
ooooo`04oj0Pl?oooooooooooj0Pl0;ooooo00?oX23`oooooonP8?009oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`1oooooo`03oomo0?oooooooooo00;ooooo1?ooO`03
ooooo`03oomo0?oooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0_
ooooo`03oj0Pl?oooooooooo047ooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`0/
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo083ooooo00?oogl0oooo
ooooool00oooO`000oooooooogl0ooooo`0Xooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0P_ooool2oj0Pl0Kooooo00?oX23`ooooooooool09?ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`23ooooo`03oomo0?oooooooooo00?oogl000?ooooooomo0?oo
ool09Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo00?oX23`oooooooo
ool03?ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo03?ooooo00?oX23`oooooooo
ool03_ooool00onP8?3ooooooj0Pl003ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooooo
ool08?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`24ooooo`05oomo
0?ooooooogl0ooooooooO`000oooool01?ooO`3ooooooomo0?ooO`03ooooo`03oomo0?oooooooooo
01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`27ooooo`03oj0Pl?oooooooooo
02Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Poooool01OooO`3o
ooooooooooooooooogl000;ooooo00Coogl0ooooooooooooogl08oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Oooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`1G
ooooo`?oX23`0_ooool00onP8?3oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo08?ooooo00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`0Roooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0G_ooool00onP8?3oooooooooo`0Qoooo
o`03oj0Pl?oooooooooo00Cooooo00?oX23`oooooonP8?009Oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`28ooooo`03oomo0?ooooooogl000;ooooo00Googl0oooooooo
oooooooooomo000Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool00onP
8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo04gooooo00GoX23`oooooooooooooooooj0Pl004
ooooo`03oj0Pl?oooooooooo02Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0Q_ooool00oooO`3oooooooooo`03ooooo`?oogl00oooool01?ooO`3oooooooooooooO`0K
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N_ooool00onP8?3oooooooooo`06
ooooo`05oj0Pl?oooooooooooooooonP8?000oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oo
oooooooo01gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Poooool0
0oooO`3oooooooooo`02oomo00Cooooo0_ooO`001?ooooooogl0ooooooooO`0Oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0R?ooool2oj0Pl2Oooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0S?ooool2oomo0003ooooooooO`3ooooo00;ooooo00?oogl0
ooooooooool06oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo087ooooo00CoX23`
oooooonP8?3oX23`1?ooool2oj0Pl003oooooonP8?3oX23`00Gooooo00?oX23`oooooonP8?006ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`29ooooo`Coogl000?ooooo
oomo0?ooO`001_ooool00oooO`3oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0QOooool01?nP8?3ooooooj0Pl?nP8?03ooooo`03oj0Pl?oooooooooo00Cooooo00?o
X23`ooooooooool01oooool00onP8?3oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo08Oooooo00Ooogl0ooooooooooooogl0ooooooooO`3ooooo00Coogl0
0_ooool00oooO`3oooooooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:oooool00onP8?3oooooooooo`1Booooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool0
0_ooool3oj0Pl0?ooooo00?oX23`oooooonP8?007_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`28ooooo`03oomo0?ooooooogl000?ooooo1?ooO`02ooooo`03oomo0?oo
oooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`27ooooo`03oj0Pl?oo
oooooooo00Cooooo00CoX23`oooooonP8?3oX23`7oooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`2<ooooo`03oomo0?oooooooooo00Googl00_ooool00oooO`3ooooooooo
o`0Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00onP8?3ooooooooo
o`1<ooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo0onP8?0Oooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo08kooooo1oooO`000oooooooogl0oomo0003ooooo`03oomo0?oo
oooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`03oj0Pl?oo
oooooooo04[ooooo00GoX23`oooooonP8?3ooooooj0Pl003ooooo`05oj0Pl?ooooooX23`oooooonP
8?007Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2@ooooo`Koogl0
6oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo00?oX23`ooooooooool0
EOooool2oj0Pl005oooooonP8?3ooooooooooonP8?001?ooool00onP8?3oooooooooo`0Kooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo097ooooo1_ooO`001?ooooooogl0
oomo0?ooO`0Fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0ROooool01onP8?3o
oooooj0Pl?nP8?3ooooooj0Pl?ooool00_nP8?000oooooooX23`oj0Pl007ooooo`03oj0Pl?oooooo
oooo01;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0TOooool7oomo
01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1oooooo`03oj0Pl?oooooooooo
00cooooo00CoX23`oooooonP8?3ooooo0_nP8?02ooooo`03oj0Pl?oooooooooo01Sooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0T?ooool2oomo00?ooooo1?ooO`0Hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0S?ooool01?nP8?3oooooooooooooool2
oj0Pl003oooooonP8?3ooooo01cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0T_ooool7oomo0003ooooooooO`3oogl001Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0nooooo`03oj0Pl?oooooooooo02Oooooo00?oX23`ooooooooool07Oooool2oj0P
l0Gooooo00?oX23`ooooooooool01?nP8?0Kooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo08oooooo00?oogl0ooooooooool00oooool6oomo01Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2@ooooo`;oX23`00?ooooooj0Pl?nP8?007?ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Booooo`04oomo0?ooooooooooooooo`So
ogl04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06?ooooo00?oX23`oooooooo
ool09_ooool00onP8?3oooooooooo`03ooooo`GoX23`6_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`2Hooooo`Coogl05Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09Cooooo00CoX23`ooooooooooooX23`0oooool00onP8?3oooooooooo`0Cooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo09[ooooo1?ooO`0Cooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0@?ooool2oj0Pl4oooooo00CoX23`oooooooooooo
oooo0onP8?05ooooo`03oj0Pl?oooooooooo017ooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0Voooool01?ooO`3oooooooooooooO`0Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0LOooool00onP8?3oooooooooo`0Qooooo`03oj0Pl?oooooooooo00;o
oooo00CoX23`ooooooooooooX23`4oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2Mooooo`?oogl04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Ko
oooo00GoX23`oooooonP8?3ooooooj0Pl00Fooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo09_ooooo00?oogl0ooooooooO`000_ooO`0Aooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0S_ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00;o
oooo0_nP8?04ooooo`03oj0Pl?oooooooooo00oooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0Woooool00oooO`3oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0KOooool00onP8?3oooooooooo`0Kooooo`03oj0Pl?oooooooooo00cooooo
00CoX23`oooooooooooooooo0_nP8?0Aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1:ooooo`03oj0P
l?oooooooooo03;ooooo00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`02ooooo`03oj0P
l?oooooooooo01;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0X_oo
ool2oomo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`15ooooo`03oj0Pl?oo
oooooooo05_ooooo00?oX23`ooooooooool02oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`2Mooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool02oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08oooooo00?oX23`ooooooooool07oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0B?ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo
00Wooooo00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`0^ooooo`;oX23`00?ooooooj0P
l?ooool02_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Oooooo`03
oomo0?oooooooooo00;ooooo00?oogl0ooooooooO`002_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo07gooooo00?oX23`ooooooooool08oooool00onP8?3ooooooj0Pl00;ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0:Oooooo00?oogl0ooooooooool0
1oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07kooooo00?oX23`ooooooooool0
0oooool00onP8?3oooooooooo`0Jooooo`;oX23`0oooool00onP8?3oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Pooooo`03oj0Pl?oooooooooo04kooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0WOooool00oooO`3oooooooooo`05ooooo`Coogl01oooool0
0oooO`3o0000ooooo`0@ooooo`03o`000?oooooooooo04Sooooo00?oX23`ooooooooool01_ooool0
0onP8?3oooooooooo`1=ooooo`03oj0Pl?oooooooooo00gooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0Z?ooool00oooO`3oooooooooo`06ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Goooool00onP8?3oooooooooo`15ooooo`04oj0Pl?oooooooooo
oj0Pl0Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0:Sooooo00CoX23`ooooooooooooX23`1Oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0C_ooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo
05[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo00?oX23`ooooooooool06oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0EOooool00onP8?3oooooooooo`12ooooo`03oj0Pl?oooooooooo00oooooo
0_nP8?03ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0:cooooo00Ko
ogl0ooooooooooooogl0ooooool0000Aooooo`03o`000?oooooooooo09kooooo00?oX23`oooooooo
ool00_ooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?l0003ooooo00[ooooo000:ooooo`03o`00
0?oooooooooo0:oooooo00?oogl0ooooool000004Oooool00ol0003oooooooooo`2Cooooo`03oj0P
l?oooooooooo01Wooooo0_nP8?000ol0003oooooooooo`09ooooo`002_oooonco`000003oomo0?l0
003ooooo013oooooIol000000onP8?3o0000o`000002o`000003oj0Pl?l0003o000000So00000_nP
8?0Qo`000003oj0Pl?l0003o000000;o000000?oX23`o`000?l000003_l000001OnP8?3o0000o`00
0?nP8?3o000000_ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-14.4237, \
-6.63736, 1.4157, 1.4157}, {{208.5, 388.938}, {184.875, 4.5}} -> {-295.249, \
-6.59083, 1.41521, 1.41521}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian models", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[{
    \(\(d2d1 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data1)\);\)\), "\[IndentingNewLine]", 
    \(\(d2d2 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[d2d1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[d2d2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.2 g
.01923 .14078 m
.02069 .1425 L
.04364 .16716 L
.04389 .16739 L
.067 .19181 L
.06854 .19349 L
.09052 .21647 L
.0932 .21933 L
.11425 .24112 L
.11785 .24491 L
.13819 .26578 L
.1425 .27025 L
.16235 .29043 L
.16716 .29535 L
.18673 .31509 L
.19181 .32021 L
.21134 .33974 L
.21647 .34485 L
.23617 .3644 L
.24112 .36926 L
.26123 .38905 L
.26578 .39346 L
.28651 .41371 L
.29043 .41745 L
.31202 .43836 L
.31509 .44125 L
.33775 .46302 L
.33974 .46486 L
.3637 .48767 L
.3644 .4883 L
.38905 .5114 L
.39004 .51233 L
.41371 .53411 L
.41679 .53698 L
.43836 .55657 L
.44385 .56164 L
.46302 .57879 L
.47123 .58629 L
.48767 .60078 L
.49892 .61095 L
.51233 .62254 L
.52695 .6356 L
.53698 .64411 L
.55533 .66026 L
.56164 .66548 L
.58407 .68491 L
.58629 .6867 L
.61095 .70748 L
.61341 .70957 L
.6356 .72768 L
.64347 .73422 L
.66026 .74756 L
.67418 .75888 L
.68491 .76714 L
.70569 .78353 L
.70957 .7864 L
.73422 .80511 L
.73825 .80819 L
.75888 .82307 L
.77233 .83284 L
.78353 .84042 L
.80819 .85702 L
.80875 .8575 L
.83284 .87248 L
.84831 .88215 L
.8575 .88634 L
.88215 .89868 L
.9068 .90477 L
.92696 .88215 L
.91957 .8575 L
.9068 .83303 L
.90671 .83284 L
.89207 .80819 L
.88215 .79201 L
.87592 .78353 L
.85865 .75888 L
.8575 .75722 L
.84043 .73422 L
.83284 .72394 L
.8216 .70957 L
.80819 .69222 L
.80226 .68491 L
.78353 .66156 L
.78244 .66026 L
.76191 .6356 L
.75888 .63186 L
.74098 .61095 L
.73422 .60283 L
.71977 .58629 L
.70957 .57432 L
.69828 .56164 L
.68491 .54628 L
.67651 .53698 L
.66026 .51866 L
.65446 .51233 L
.6356 .49142 L
.63213 .48767 L
.61095 .46454 L
.60952 .46302 L
.58658 .43836 L
.58629 .43804 L
.56319 .41371 L
.56164 .41203 L
.5396 .38905 L
.53698 .38627 L
.51579 .3644 L
.51233 .36076 L
.49178 .33974 L
.48767 .3355 L
.46755 .31509 L
.46302 .31047 L
.4431 .29043 L
.43836 .28568 L
.41842 .26578 L
.41371 .26111 L
.39352 .24112 L
.38905 .23676 L
.3684 .21647 L
.3644 .21262 L
.34305 .19181 L
.33974 .18868 L
.31748 .16716 L
.31509 .16493 L
.29168 .1425 L
.29043 .14136 L
.26578 .11798 L
.26564 .11785 L
.24112 .0951 L
.23909 .0932 L
.21647 .07247 L
.21224 .06854 L
.19181 .05008 L
.18509 .04389 L
.16716 .0272 L
.15762 .01923 L
.01923 .01923 L
F
0 g
.01923 .14078 m
.02069 .1425 L
.04364 .16716 L
.04389 .16739 L
.067 .19181 L
.06854 .19349 L
.09052 .21647 L
.0932 .21933 L
.11425 .24112 L
.11785 .24491 L
.13819 .26578 L
.1425 .27025 L
.16235 .29043 L
.16716 .29535 L
.18673 .31509 L
.19181 .32021 L
.21134 .33974 L
.21647 .34485 L
.23617 .3644 L
.24112 .36926 L
.26123 .38905 L
.26578 .39346 L
.28651 .41371 L
.29043 .41745 L
.31202 .43836 L
.31509 .44125 L
.33775 .46302 L
.33974 .46486 L
.3637 .48767 L
.3644 .4883 L
.38905 .5114 L
.39004 .51233 L
.41371 .53411 L
.41679 .53698 L
.43836 .55657 L
.44385 .56164 L
.46302 .57879 L
.47123 .58629 L
.48767 .60078 L
.49892 .61095 L
.51233 .62254 L
.52695 .6356 L
.53698 .64411 L
.55533 .66026 L
.56164 .66548 L
.58407 .68491 L
.58629 .6867 L
.61095 .70748 L
.61341 .70957 L
.6356 .72768 L
Mistroke
.64347 .73422 L
.66026 .74756 L
.67418 .75888 L
.68491 .76714 L
.70569 .78353 L
.70957 .7864 L
.73422 .80511 L
.73825 .80819 L
.75888 .82307 L
.77233 .83284 L
.78353 .84042 L
.80819 .85702 L
.80875 .8575 L
.83284 .87248 L
.84831 .88215 L
.8575 .88634 L
.88215 .89868 L
.9068 .90477 L
.92696 .88215 L
.91957 .8575 L
.9068 .83303 L
.90671 .83284 L
.89207 .80819 L
.88215 .79201 L
.87592 .78353 L
.85865 .75888 L
.8575 .75722 L
.84043 .73422 L
.83284 .72394 L
.8216 .70957 L
.80819 .69222 L
.80226 .68491 L
.78353 .66156 L
.78244 .66026 L
.76191 .6356 L
.75888 .63186 L
.74098 .61095 L
.73422 .60283 L
.71977 .58629 L
.70957 .57432 L
.69828 .56164 L
.68491 .54628 L
.67651 .53698 L
.66026 .51866 L
.65446 .51233 L
.6356 .49142 L
.63213 .48767 L
.61095 .46454 L
.60952 .46302 L
.58658 .43836 L
Mistroke
.58629 .43804 L
.56319 .41371 L
.56164 .41203 L
.5396 .38905 L
.53698 .38627 L
.51579 .3644 L
.51233 .36076 L
.49178 .33974 L
.48767 .3355 L
.46755 .31509 L
.46302 .31047 L
.4431 .29043 L
.43836 .28568 L
.41842 .26578 L
.41371 .26111 L
.39352 .24112 L
.38905 .23676 L
.3684 .21647 L
.3644 .21262 L
.34305 .19181 L
.33974 .18868 L
.31748 .16716 L
.31509 .16493 L
.29168 .1425 L
.29043 .14136 L
.26578 .11798 L
.26564 .11785 L
.24112 .0951 L
.23909 .0932 L
.21647 .07247 L
.21224 .06854 L
.19181 .05008 L
.18509 .04389 L
.16716 .0272 L
.15762 .01923 L
Mfstroke
.01923 .17305 m
.03565 .19181 L
.04389 .19889 L
.06097 .21647 L
.06854 .22453 L
.08476 .24112 L
.0932 .24997 L
.10874 .26578 L
.11785 .27521 L
.13291 .29043 L
.1425 .30024 L
.15727 .31509 L
.16716 .32507 L
.18184 .33974 L
.19181 .34969 L
.2066 .3644 L
.21647 .37412 L
.23156 .38905 L
.24112 .39835 L
.25672 .41371 L
.26578 .4224 L
.28208 .43836 L
.29043 .44627 L
.30762 .46302 L
.31509 .46997 L
.33335 .48767 L
.33974 .49352 L
.35925 .51233 L
.3644 .51695 L
.38531 .53698 L
.38905 .54027 L
.4115 .56164 L
.41371 .56352 L
.43782 .58629 L
.43836 .58674 L
.46302 .60933 L
.46475 .61095 L
.48767 .63146 L
.49214 .6356 L
.51233 .65339 L
.5198 .66026 L
.53698 .67512 L
.54772 .68491 L
.56164 .69669 L
.57588 .70957 L
.58629 .71816 L
.60425 .73422 L
.61095 .73958 L
.63282 .75888 L
.6356 .76102 L
.66026 .78219 L
.66181 .78353 L
.68491 .80243 L
.69167 .80819 L
.70957 .82243 L
.72197 .83284 L
.73422 .84228 L
.75273 .8575 L
.75888 .86205 L
.78353 .88174 L
.78404 .88215 L
.80819 .90034 L
.81653 .9068 L
.83284 .9186 L
.85005 .93146 L
.8575 .93658 L
.88215 .9541 L
.88497 .95611 L
.9068 .97076 L
.92216 .98077 L
.01923 .98077 L
F
.01923 .17305 m
.03565 .19181 L
.04389 .19889 L
.06097 .21647 L
.06854 .22453 L
.08476 .24112 L
.0932 .24997 L
.10874 .26578 L
.11785 .27521 L
.13291 .29043 L
.1425 .30024 L
.15727 .31509 L
.16716 .32507 L
.18184 .33974 L
.19181 .34969 L
.2066 .3644 L
.21647 .37412 L
.23156 .38905 L
.24112 .39835 L
.25672 .41371 L
.26578 .4224 L
.28208 .43836 L
.29043 .44627 L
.30762 .46302 L
.31509 .46997 L
.33335 .48767 L
.33974 .49352 L
.35925 .51233 L
.3644 .51695 L
.38531 .53698 L
.38905 .54027 L
.4115 .56164 L
.41371 .56352 L
.43782 .58629 L
.43836 .58674 L
.46302 .60933 L
.46475 .61095 L
.48767 .63146 L
.49214 .6356 L
.51233 .65339 L
.5198 .66026 L
.53698 .67512 L
.54772 .68491 L
.56164 .69669 L
.57588 .70957 L
.58629 .71816 L
.60425 .73422 L
.61095 .73958 L
.63282 .75888 L
.6356 .76102 L
Mistroke
.66026 .78219 L
.66181 .78353 L
.68491 .80243 L
.69167 .80819 L
.70957 .82243 L
.72197 .83284 L
.73422 .84228 L
.75273 .8575 L
.75888 .86205 L
.78353 .88174 L
.78404 .88215 L
.80819 .90034 L
.81653 .9068 L
.83284 .9186 L
.85005 .93146 L
.8575 .93658 L
.88215 .9541 L
.88497 .95611 L
.9068 .97076 L
.92216 .98077 L
Mfstroke
.3 g
.01923 .11882 m
.04055 .1425 L
.04389 .14595 L
.06351 .16716 L
.06854 .17268 L
.08649 .19181 L
.0932 .19904 L
.10975 .21647 L
.11785 .22507 L
.13329 .24112 L
.1425 .25077 L
.15709 .26578 L
.16716 .27616 L
.18118 .29043 L
.19181 .30126 L
.20553 .31509 L
.21647 .32607 L
.23017 .33974 L
.24112 .35061 L
.25508 .3644 L
.26578 .37487 L
.28027 .38905 L
.29043 .39887 L
.30574 .41371 L
.31509 .42261 L
.33151 .43836 L
.33974 .4461 L
.35756 .46302 L
.3644 .46935 L
.38391 .48767 L
.38905 .49236 L
.41058 .51233 L
.41371 .51513 L
.43756 .53698 L
.43836 .53769 L
.46302 .55982 L
.46503 .56164 L
.48767 .58157 L
.49298 .58629 L
.51233 .60302 L
.52138 .61095 L
.53698 .62417 L
.55028 .6356 L
.56164 .64501 L
.57975 .66026 L
.58629 .66554 L
.60989 .68491 L
.61095 .68574 L
.6356 .70533 L
.64089 .70957 L
.66026 .72437 L
.67305 .73422 L
.68491 .74286 L
.7069 .75888 L
.70957 .76069 L
.73422 .77771 L
.7418 .78353 L
.75888 .7935 L
.78353 .80764 L
.78485 .80819 L
.80819 .82027 L
.83284 .82432 L
.84545 .80819 L
.83871 .78353 L
.83284 .77206 L
.82624 .75888 L
.81079 .73422 L
.80819 .72988 L
.79421 .70957 L
.78353 .69404 L
.77648 .68491 L
.75888 .66148 L
.75787 .66026 L
.73847 .6356 L
.73422 .63017 L
.71849 .61095 L
.70957 .59994 L
.69805 .58629 L
.68491 .57058 L
.67718 .56164 L
.66026 .54191 L
.6559 .53698 L
.6356 .51383 L
.63425 .51233 L
.61214 .48767 L
.61095 .48632 L
.58962 .46302 L
.58629 .45932 L
.56683 .43836 L
.56164 .4327 L
.54375 .41371 L
.53698 .40644 L
.5204 .38905 L
.51233 .38052 L
.49678 .3644 L
.48767 .35491 L
.47288 .33974 L
.46302 .32961 L
.44871 .31509 L
.43836 .30459 L
.42427 .29043 L
.41371 .27986 L
.39955 .26578 L
.38905 .25541 L
.37455 .24112 L
.3644 .23123 L
.34927 .21647 L
.33974 .2073 L
.32371 .19181 L
.31509 .18363 L
.29786 .16716 L
.29043 .16021 L
.27172 .1425 L
.26578 .13703 L
.24527 .11785 L
.24112 .11409 L
.21852 .0932 L
.21647 .09137 L
.19181 .06891 L
.19141 .06854 L
.16716 .04695 L
.16375 .04389 L
.1425 .02503 L
.13566 .01923 L
.01923 .01923 L
F
0 g
.01923 .11882 m
.04055 .1425 L
.04389 .14595 L
.06351 .16716 L
.06854 .17268 L
.08649 .19181 L
.0932 .19904 L
.10975 .21647 L
.11785 .22507 L
.13329 .24112 L
.1425 .25077 L
.15709 .26578 L
.16716 .27616 L
.18118 .29043 L
.19181 .30126 L
.20553 .31509 L
.21647 .32607 L
.23017 .33974 L
.24112 .35061 L
.25508 .3644 L
.26578 .37487 L
.28027 .38905 L
.29043 .39887 L
.30574 .41371 L
.31509 .42261 L
.33151 .43836 L
.33974 .4461 L
.35756 .46302 L
.3644 .46935 L
.38391 .48767 L
.38905 .49236 L
.41058 .51233 L
.41371 .51513 L
.43756 .53698 L
.43836 .53769 L
.46302 .55982 L
.46503 .56164 L
.48767 .58157 L
.49298 .58629 L
.51233 .60302 L
.52138 .61095 L
.53698 .62417 L
.55028 .6356 L
.56164 .64501 L
.57975 .66026 L
.58629 .66554 L
.60989 .68491 L
.61095 .68574 L
.6356 .70533 L
.64089 .70957 L
Mistroke
.66026 .72437 L
.67305 .73422 L
.68491 .74286 L
.7069 .75888 L
.70957 .76069 L
.73422 .77771 L
.7418 .78353 L
.75888 .7935 L
.78353 .80764 L
.78485 .80819 L
.80819 .82027 L
.83284 .82432 L
.84545 .80819 L
.83871 .78353 L
.83284 .77206 L
.82624 .75888 L
.81079 .73422 L
.80819 .72988 L
.79421 .70957 L
.78353 .69404 L
.77648 .68491 L
.75888 .66148 L
.75787 .66026 L
.73847 .6356 L
.73422 .63017 L
.71849 .61095 L
.70957 .59994 L
.69805 .58629 L
.68491 .57058 L
.67718 .56164 L
.66026 .54191 L
.6559 .53698 L
.6356 .51383 L
.63425 .51233 L
.61214 .48767 L
.61095 .48632 L
.58962 .46302 L
.58629 .45932 L
.56683 .43836 L
.56164 .4327 L
.54375 .41371 L
.53698 .40644 L
.5204 .38905 L
.51233 .38052 L
.49678 .3644 L
.48767 .35491 L
.47288 .33974 L
.46302 .32961 L
.44871 .31509 L
.43836 .30459 L
Mistroke
.42427 .29043 L
.41371 .27986 L
.39955 .26578 L
.38905 .25541 L
.37455 .24112 L
.3644 .23123 L
.34927 .21647 L
.33974 .2073 L
.32371 .19181 L
.31509 .18363 L
.29786 .16716 L
.29043 .16021 L
.27172 .1425 L
.26578 .13703 L
.24527 .11785 L
.24112 .11409 L
.21852 .0932 L
.21647 .09137 L
.19181 .06891 L
.19141 .06854 L
.16716 .04695 L
.16375 .04389 L
.1425 .02503 L
.13566 .01923 L
Mfstroke
.4 g
.01923 .10036 m
.03453 .11785 L
.04389 .12836 L
.05663 .1425 L
.06854 .15579 L
.07897 .16716 L
.0932 .18273 L
.10167 .19181 L
.11785 .20922 L
.12471 .21647 L
.1425 .23531 L
.14808 .24112 L
.16716 .26101 L
.17179 .26578 L
.19181 .28637 L
.19581 .29043 L
.21647 .31138 L
.22016 .31509 L
.24112 .33606 L
.24483 .33974 L
.26578 .36043 L
.26982 .3644 L
.29043 .38448 L
.29514 .38905 L
.31509 .40823 L
.32079 .41371 L
.33974 .43168 L
.34679 .43836 L
.3644 .45482 L
.37315 .46302 L
.38905 .47766 L
.39988 .48767 L
.41371 .5002 L
.42702 .51233 L
.43836 .52243 L
.45458 .53698 L
.46302 .54435 L
.48262 .56164 L
.48767 .56596 L
.51119 .58629 L
.51233 .58724 L
.53698 .60804 L
.54041 .61095 L
.56164 .62836 L
.57041 .6356 L
.58629 .6482 L
.6014 .66026 L
.61095 .66752 L
.63379 .68491 L
.6356 .68622 L
.66026 .70424 L
.66682 .70957 L
.68491 .72119 L
.70495 .73422 L
.70957 .73662 L
.73422 .75177 L
.75585 .75888 L
.75888 .75995 L
.77672 .75888 L
.77821 .73422 L
.76764 .70957 L
.75888 .69528 L
.75296 .68491 L
.73603 .66026 L
.73422 .65752 L
.71826 .6356 L
.70957 .62365 L
.6995 .61095 L
.68491 .59222 L
.67995 .58629 L
.66026 .5622 L
.65977 .56164 L
.63896 .53698 L
.6356 .53298 L
.61768 .51233 L
.61095 .50452 L
.59599 .48767 L
.58629 .47669 L
.5739 .46302 L
.56164 .44942 L
.55145 .43836 L
.53698 .42262 L
.52864 .41371 L
.51233 .39625 L
.50549 .38905 L
.48767 .37028 L
.48201 .3644 L
.46302 .34468 L
.45821 .33974 L
.43836 .31943 L
.43408 .31509 L
.41371 .29452 L
.40963 .29043 L
.38905 .26993 L
.38486 .26578 L
.3644 .24565 L
.35977 .24112 L
.33974 .22169 L
.33435 .21647 L
.31509 .19803 L
.30859 .19181 L
.29043 .17467 L
.28248 .16716 L
.26578 .15162 L
.25601 .1425 L
.24112 .12887 L
.22915 .11785 L
.21647 .10642 L
.20189 .0932 L
.19181 .08427 L
.17419 .06854 L
.16716 .06244 L
.14599 .04389 L
.1425 .0408 L
.11785 .01981 L
.11723 .01923 L
.01923 .01923 L
F
0 g
.01923 .10036 m
.03453 .11785 L
.04389 .12836 L
.05663 .1425 L
.06854 .15579 L
.07897 .16716 L
.0932 .18273 L
.10167 .19181 L
.11785 .20922 L
.12471 .21647 L
.1425 .23531 L
.14808 .24112 L
.16716 .26101 L
.17179 .26578 L
.19181 .28637 L
.19581 .29043 L
.21647 .31138 L
.22016 .31509 L
.24112 .33606 L
.24483 .33974 L
.26578 .36043 L
.26982 .3644 L
.29043 .38448 L
.29514 .38905 L
.31509 .40823 L
.32079 .41371 L
.33974 .43168 L
.34679 .43836 L
.3644 .45482 L
.37315 .46302 L
.38905 .47766 L
.39988 .48767 L
.41371 .5002 L
.42702 .51233 L
.43836 .52243 L
.45458 .53698 L
.46302 .54435 L
.48262 .56164 L
.48767 .56596 L
.51119 .58629 L
.51233 .58724 L
.53698 .60804 L
.54041 .61095 L
.56164 .62836 L
.57041 .6356 L
.58629 .6482 L
.6014 .66026 L
.61095 .66752 L
.63379 .68491 L
.6356 .68622 L
Mistroke
.66026 .70424 L
.66682 .70957 L
.68491 .72119 L
.70495 .73422 L
.70957 .73662 L
.73422 .75177 L
.75585 .75888 L
.75888 .75995 L
.77672 .75888 L
.77821 .73422 L
.76764 .70957 L
.75888 .69528 L
.75296 .68491 L
.73603 .66026 L
.73422 .65752 L
.71826 .6356 L
.70957 .62365 L
.6995 .61095 L
.68491 .59222 L
.67995 .58629 L
.66026 .5622 L
.65977 .56164 L
.63896 .53698 L
.6356 .53298 L
.61768 .51233 L
.61095 .50452 L
.59599 .48767 L
.58629 .47669 L
.5739 .46302 L
.56164 .44942 L
.55145 .43836 L
.53698 .42262 L
.52864 .41371 L
.51233 .39625 L
.50549 .38905 L
.48767 .37028 L
.48201 .3644 L
.46302 .34468 L
.45821 .33974 L
.43836 .31943 L
.43408 .31509 L
.41371 .29452 L
.40963 .29043 L
.38905 .26993 L
.38486 .26578 L
.3644 .24565 L
.35977 .24112 L
.33974 .22169 L
.33435 .21647 L
.31509 .19803 L
Mistroke
.30859 .19181 L
.29043 .17467 L
.28248 .16716 L
.26578 .15162 L
.25601 .1425 L
.24112 .12887 L
.22915 .11785 L
.21647 .10642 L
.20189 .0932 L
.19181 .08427 L
.17419 .06854 L
.16716 .06244 L
.14599 .04389 L
.1425 .0408 L
.11785 .01981 L
.11723 .01923 L
Mfstroke
.5 g
.01923 .08307 m
.02899 .0932 L
.04389 .11214 L
.04893 .11785 L
.06854 .14035 L
.07049 .1425 L
.09253 .16716 L
.0932 .16791 L
.11502 .19181 L
.11785 .19492 L
.13791 .21647 L
.1425 .22141 L
.16118 .24112 L
.16716 .24743 L
.18481 .26578 L
.19181 .27304 L
.2088 .29043 L
.21647 .29825 L
.23315 .31509 L
.24112 .32309 L
.25786 .33974 L
.26578 .34757 L
.28292 .3644 L
.29043 .37171 L
.30835 .38905 L
.31509 .3955 L
.33415 .41371 L
.33974 .41897 L
.36035 .43836 L
.3644 .4421 L
.38697 .46302 L
.38905 .46491 L
.41371 .48737 L
.41404 .48767 L
.43836 .5094 L
.44163 .51233 L
.46302 .53104 L
.46979 .53698 L
.48767 .55226 L
.4986 .56164 L
.51233 .57304 L
.52823 .58629 L
.53698 .59332 L
.55892 .61095 L
.56164 .61304 L
.58629 .63222 L
.59017 .6356 L
.61095 .65058 L
.62361 .66026 L
.6356 .66776 L
.66026 .68397 L
.66289 .68491 L
.68491 .69934 L
.70957 .70573 L
.72339 .68491 L
.71286 .66026 L
.70957 .6549 L
.69844 .6356 L
.68491 .61659 L
.68128 .61095 L
.6628 .58629 L
.66026 .58281 L
.64365 .56164 L
.6356 .55133 L
.62369 .53698 L
.61095 .52145 L
.60306 .51233 L
.58629 .49265 L
.58186 .48767 L
.56164 .46465 L
.56016 .46302 L
.53797 .43836 L
.53698 .43726 L
.51535 .41371 L
.51233 .41041 L
.49234 .38905 L
.48767 .38407 L
.46895 .3644 L
.46302 .35817 L
.44521 .33974 L
.43836 .33268 L
.4211 .31509 L
.41371 .30759 L
.39664 .29043 L
.38905 .28285 L
.37183 .26578 L
.3644 .25848 L
.34665 .24112 L
.33974 .23444 L
.32111 .21647 L
.31509 .21074 L
.29518 .19181 L
.29043 .18737 L
.26885 .16716 L
.26578 .16433 L
.2421 .1425 L
.24112 .14162 L
.21647 .1193 L
.21487 .11785 L
.19181 .09738 L
.18711 .0932 L
.16716 .07587 L
.15876 .06854 L
.1425 .05477 L
.1297 .04389 L
.11785 .0345 L
.09977 .01923 L
.01923 .01923 L
F
0 g
.01923 .08307 m
.02899 .0932 L
.04389 .11214 L
.04893 .11785 L
.06854 .14035 L
.07049 .1425 L
.09253 .16716 L
.0932 .16791 L
.11502 .19181 L
.11785 .19492 L
.13791 .21647 L
.1425 .22141 L
.16118 .24112 L
.16716 .24743 L
.18481 .26578 L
.19181 .27304 L
.2088 .29043 L
.21647 .29825 L
.23315 .31509 L
.24112 .32309 L
.25786 .33974 L
.26578 .34757 L
.28292 .3644 L
.29043 .37171 L
.30835 .38905 L
.31509 .3955 L
.33415 .41371 L
.33974 .41897 L
.36035 .43836 L
.3644 .4421 L
.38697 .46302 L
.38905 .46491 L
.41371 .48737 L
.41404 .48767 L
.43836 .5094 L
.44163 .51233 L
.46302 .53104 L
.46979 .53698 L
.48767 .55226 L
.4986 .56164 L
.51233 .57304 L
.52823 .58629 L
.53698 .59332 L
.55892 .61095 L
.56164 .61304 L
.58629 .63222 L
.59017 .6356 L
.61095 .65058 L
.62361 .66026 L
.6356 .66776 L
Mistroke
.66026 .68397 L
.66289 .68491 L
.68491 .69934 L
.70957 .70573 L
.72339 .68491 L
.71286 .66026 L
.70957 .6549 L
.69844 .6356 L
.68491 .61659 L
.68128 .61095 L
.6628 .58629 L
.66026 .58281 L
.64365 .56164 L
.6356 .55133 L
.62369 .53698 L
.61095 .52145 L
.60306 .51233 L
.58629 .49265 L
.58186 .48767 L
.56164 .46465 L
.56016 .46302 L
.53797 .43836 L
.53698 .43726 L
.51535 .41371 L
.51233 .41041 L
.49234 .38905 L
.48767 .38407 L
.46895 .3644 L
.46302 .35817 L
.44521 .33974 L
.43836 .33268 L
.4211 .31509 L
.41371 .30759 L
.39664 .29043 L
.38905 .28285 L
.37183 .26578 L
.3644 .25848 L
.34665 .24112 L
.33974 .23444 L
.32111 .21647 L
.31509 .21074 L
.29518 .19181 L
.29043 .18737 L
.26885 .16716 L
.26578 .16433 L
.2421 .1425 L
.24112 .14162 L
.21647 .1193 L
.21487 .11785 L
.19181 .09738 L
Mistroke
.18711 .0932 L
.16716 .07587 L
.15876 .06854 L
.1425 .05477 L
.1297 .04389 L
.11785 .0345 L
.09977 .01923 L
Mfstroke
.6 g
.01923 .06646 m
.02293 .06854 L
.04261 .0932 L
.04389 .09502 L
.06273 .11785 L
.06854 .1249 L
.08372 .1425 L
.0932 .15357 L
.10531 .16716 L
.11785 .18133 L
.12745 .19181 L
.1425 .20838 L
.15007 .21647 L
.16716 .23483 L
.17315 .24112 L
.19181 .26077 L
.19666 .26578 L
.21647 .28624 L
.22059 .29043 L
.24112 .31127 L
.24493 .31509 L
.26578 .33589 L
.26968 .33974 L
.29043 .36011 L
.29484 .3644 L
.31509 .38393 L
.32043 .38905 L
.33974 .40737 L
.34646 .41371 L
.3644 .43041 L
.37296 .43836 L
.38905 .45305 L
.39998 .46302 L
.41371 .47528 L
.42759 .48767 L
.43836 .49707 L
.45587 .51233 L
.46302 .51839 L
.48497 .53698 L
.48767 .5392 L
.51233 .55955 L
.51461 .56164 L
.53698 .5793 L
.54522 .58629 L
.56164 .59813 L
.57875 .61095 L
.58629 .61574 L
.61095 .63375 L
.61703 .6356 L
.6356 .64912 L
.66026 .65516 L
.67168 .6356 L
.66026 .61106 L
.66019 .61095 L
.64536 .58629 L
.6356 .56842 L
.62787 .56164 L
.61095 .53839 L
.60872 .53698 L
.58877 .51233 L
.58629 .50922 L
.56826 .48767 L
.56164 .47974 L
.54707 .46302 L
.53698 .45137 L
.5253 .43836 L
.51233 .42383 L
.50301 .41371 L
.48767 .39696 L
.48024 .38905 L
.46302 .37066 L
.45702 .3644 L
.43836 .34487 L
.43338 .33974 L
.41371 .31953 L
.40932 .31509 L
.38905 .29462 L
.38485 .29043 L
.3644 .27013 L
.35998 .26578 L
.33974 .24603 L
.33468 .24112 L
.31509 .22232 L
.30896 .21647 L
.29043 .199 L
.28279 .19181 L
.26578 .17608 L
.25612 .16716 L
.24112 .15356 L
.22893 .1425 L
.21647 .13146 L
.20112 .11785 L
.19181 .1098 L
.1726 .0932 L
.16716 .08862 L
.14321 .06854 L
.1425 .06797 L
.11785 .04774 L
.11352 .04389 L
.0932 .03886 L
.08214 .01923 L
.01923 .01923 L
F
0 g
.01923 .06646 m
.02293 .06854 L
.04261 .0932 L
.04389 .09502 L
.06273 .11785 L
.06854 .1249 L
.08372 .1425 L
.0932 .15357 L
.10531 .16716 L
.11785 .18133 L
.12745 .19181 L
.1425 .20838 L
.15007 .21647 L
.16716 .23483 L
.17315 .24112 L
.19181 .26077 L
.19666 .26578 L
.21647 .28624 L
.22059 .29043 L
.24112 .31127 L
.24493 .31509 L
.26578 .33589 L
.26968 .33974 L
.29043 .36011 L
.29484 .3644 L
.31509 .38393 L
.32043 .38905 L
.33974 .40737 L
.34646 .41371 L
.3644 .43041 L
.37296 .43836 L
.38905 .45305 L
.39998 .46302 L
.41371 .47528 L
.42759 .48767 L
.43836 .49707 L
.45587 .51233 L
.46302 .51839 L
.48497 .53698 L
.48767 .5392 L
.51233 .55955 L
.51461 .56164 L
.53698 .5793 L
.54522 .58629 L
.56164 .59813 L
.57875 .61095 L
.58629 .61574 L
.61095 .63375 L
.61703 .6356 L
.6356 .64912 L
Mistroke
.66026 .65516 L
.67168 .6356 L
.66026 .61106 L
.66019 .61095 L
.64536 .58629 L
.6356 .56842 L
.62787 .56164 L
.61095 .53839 L
.60872 .53698 L
.58877 .51233 L
.58629 .50922 L
.56826 .48767 L
.56164 .47974 L
.54707 .46302 L
.53698 .45137 L
.5253 .43836 L
.51233 .42383 L
.50301 .41371 L
.48767 .39696 L
.48024 .38905 L
.46302 .37066 L
.45702 .3644 L
.43836 .34487 L
.43338 .33974 L
.41371 .31953 L
.40932 .31509 L
.38905 .29462 L
.38485 .29043 L
.3644 .27013 L
.35998 .26578 L
.33974 .24603 L
.33468 .24112 L
.31509 .22232 L
.30896 .21647 L
.29043 .199 L
.28279 .19181 L
.26578 .17608 L
.25612 .16716 L
.24112 .15356 L
.22893 .1425 L
.21647 .13146 L
.20112 .11785 L
.19181 .1098 L
.1726 .0932 L
.16716 .08862 L
.14321 .06854 L
.1425 .06797 L
.11785 .04774 L
.11352 .04389 L
.0932 .03886 L
Mistroke
.08214 .01923 L
Mfstroke
.7 g
.01923 .02853 m
.02438 .04389 L
.04006 .06854 L
.04389 .07642 L
.05709 .0932 L
.06854 .11038 L
.07631 .11785 L
.0932 .13946 L
.09677 .1425 L
.11785 .16694 L
.11812 .16716 L
.1398 .19181 L
.1425 .19489 L
.16208 .21647 L
.16716 .22207 L
.18491 .24112 L
.19181 .24853 L
.20826 .26578 L
.21647 .27437 L
.2321 .29043 L
.24112 .29967 L
.25643 .31509 L
.26578 .32446 L
.28123 .33974 L
.29043 .34877 L
.30652 .3644 L
.31509 .37263 L
.33232 .38905 L
.33974 .39603 L
.35867 .41371 L
.3644 .41897 L
.38561 .43836 L
.38905 .44145 L
.41324 .46302 L
.41371 .46343 L
.43836 .48508 L
.44113 .48767 L
.46302 .50613 L
.46993 .51233 L
.48767 .52643 L
.50031 .53698 L
.51233 .54579 L
.53344 .56164 L
.53698 .56397 L
.56164 .58444 L
.57012 .58629 L
.58629 .59989 L
.61095 .60596 L
.62101 .58629 L
.61095 .56606 L
.60834 .56164 L
.59252 .53698 L
.58629 .52613 L
.57452 .51233 L
.56164 .49404 L
.55489 .48767 L
.53698 .46548 L
.53415 .46302 L
.51263 .43836 L
.51233 .43801 L
.49077 .41371 L
.48767 .41022 L
.46832 .38905 L
.46302 .38326 L
.44532 .3644 L
.43836 .35699 L
.42181 .33974 L
.41371 .33132 L
.39782 .31509 L
.38905 .30618 L
.37334 .29043 L
.3644 .28153 L
.34839 .26578 L
.33974 .25735 L
.32294 .24112 L
.31509 .23363 L
.29697 .21647 L
.29043 .21036 L
.27045 .19181 L
.26578 .18756 L
.2433 .16716 L
.24112 .16523 L
.21647 .14333 L
.2156 .1425 L
.19181 .12183 L
.18749 .11785 L
.16716 .10101 L
.15823 .0932 L
.1425 .08098 L
.12711 .06854 L
.11785 .06195 L
.0932 .04393 L
.0928 .04389 L
.06854 .02739 L
.05439 .01923 L
.01923 .01923 L
F
0 g
.01923 .02853 m
.02438 .04389 L
.04006 .06854 L
.04389 .07642 L
.05709 .0932 L
.06854 .11038 L
.07631 .11785 L
.0932 .13946 L
.09677 .1425 L
.11785 .16694 L
.11812 .16716 L
.1398 .19181 L
.1425 .19489 L
.16208 .21647 L
.16716 .22207 L
.18491 .24112 L
.19181 .24853 L
.20826 .26578 L
.21647 .27437 L
.2321 .29043 L
.24112 .29967 L
.25643 .31509 L
.26578 .32446 L
.28123 .33974 L
.29043 .34877 L
.30652 .3644 L
.31509 .37263 L
.33232 .38905 L
.33974 .39603 L
.35867 .41371 L
.3644 .41897 L
.38561 .43836 L
.38905 .44145 L
.41324 .46302 L
.41371 .46343 L
.43836 .48508 L
.44113 .48767 L
.46302 .50613 L
.46993 .51233 L
.48767 .52643 L
.50031 .53698 L
.51233 .54579 L
.53344 .56164 L
.53698 .56397 L
.56164 .58444 L
.57012 .58629 L
.58629 .59989 L
.61095 .60596 L
.62101 .58629 L
.61095 .56606 L
Mistroke
.60834 .56164 L
.59252 .53698 L
.58629 .52613 L
.57452 .51233 L
.56164 .49404 L
.55489 .48767 L
.53698 .46548 L
.53415 .46302 L
.51263 .43836 L
.51233 .43801 L
.49077 .41371 L
.48767 .41022 L
.46832 .38905 L
.46302 .38326 L
.44532 .3644 L
.43836 .35699 L
.42181 .33974 L
.41371 .33132 L
.39782 .31509 L
.38905 .30618 L
.37334 .29043 L
.3644 .28153 L
.34839 .26578 L
.33974 .25735 L
.32294 .24112 L
.31509 .23363 L
.29697 .21647 L
.29043 .21036 L
.27045 .19181 L
.26578 .18756 L
.2433 .16716 L
.24112 .16523 L
.21647 .14333 L
.2156 .1425 L
.19181 .12183 L
.18749 .11785 L
.16716 .10101 L
.15823 .0932 L
.1425 .08098 L
.12711 .06854 L
.11785 .06195 L
.0932 .04393 L
.0928 .04389 L
.06854 .02739 L
.05439 .01923 L
Mfstroke
.8 g
.06854 .05707 m
.0932 .06122 L
.10108 .06854 L
.11785 .07901 L
.13821 .0932 L
.1425 .09632 L
.16716 .11495 L
.17109 .11785 L
.19181 .13459 L
.20179 .1425 L
.21647 .15521 L
.23068 .16716 L
.24112 .17663 L
.25837 .19181 L
.26578 .19874 L
.28518 .21647 L
.29043 .22147 L
.31131 .24112 L
.31509 .24476 L
.33686 .26578 L
.33974 .26857 L
.36188 .29043 L
.3644 .29288 L
.38638 .31509 L
.38905 .31769 L
.41036 .33974 L
.41371 .34299 L
.4338 .3644 L
.43836 .36884 L
.45663 .38905 L
.46302 .39536 L
.47877 .41371 L
.48767 .42285 L
.50004 .43836 L
.51233 .45206 L
.52019 .46302 L
.53698 .48472 L
.53881 .48767 L
.55585 .51233 L
.56164 .52173 L
.56965 .53698 L
.56164 .55607 L
.53698 .54505 L
.52389 .53698 L
.51233 .52929 L
.4888 .51233 L
.48767 .51148 L
.46302 .49261 L
.45647 .48767 L
.43836 .47266 L
.42644 .46302 L
.41371 .45178 L
.398 .43836 L
.38905 .43013 L
.37064 .41371 L
.3644 .40781 L
.34407 .38905 L
.33974 .3849 L
.31814 .3644 L
.31509 .36145 L
.29277 .33974 L
.29043 .33748 L
.26792 .31509 L
.26578 .31302 L
.24358 .29043 L
.24112 .28807 L
.21975 .26578 L
.21647 .26261 L
.19648 .24112 L
.19181 .23661 L
.17384 .21647 L
.16716 .20989 L
.15194 .19181 L
.1425 .18206 L
.13097 .16716 L
.11785 .15214 L
.11123 .1425 L
.09321 .11785 L
.0932 .11783 L
.07682 .0932 L
.06854 .07773 L
.06502 .06854 L
F
0 g
.06854 .05707 m
.0932 .06122 L
.10108 .06854 L
.11785 .07901 L
.13821 .0932 L
.1425 .09632 L
.16716 .11495 L
.17109 .11785 L
.19181 .13459 L
.20179 .1425 L
.21647 .15521 L
.23068 .16716 L
.24112 .17663 L
.25837 .19181 L
.26578 .19874 L
.28518 .21647 L
.29043 .22147 L
.31131 .24112 L
.31509 .24476 L
.33686 .26578 L
.33974 .26857 L
.36188 .29043 L
.3644 .29288 L
.38638 .31509 L
.38905 .31769 L
.41036 .33974 L
.41371 .34299 L
.4338 .3644 L
.43836 .36884 L
.45663 .38905 L
.46302 .39536 L
.47877 .41371 L
.48767 .42285 L
.50004 .43836 L
.51233 .45206 L
.52019 .46302 L
.53698 .48472 L
.53881 .48767 L
.55585 .51233 L
.56164 .52173 L
.56965 .53698 L
.56164 .55607 L
.53698 .54505 L
.52389 .53698 L
.51233 .52929 L
.4888 .51233 L
.48767 .51148 L
.46302 .49261 L
.45647 .48767 L
.43836 .47266 L
Mistroke
.42644 .46302 L
.41371 .45178 L
.398 .43836 L
.38905 .43013 L
.37064 .41371 L
.3644 .40781 L
.34407 .38905 L
.33974 .3849 L
.31814 .3644 L
.31509 .36145 L
.29277 .33974 L
.29043 .33748 L
.26792 .31509 L
.26578 .31302 L
.24358 .29043 L
.24112 .28807 L
.21975 .26578 L
.21647 .26261 L
.19648 .24112 L
.19181 .23661 L
.17384 .21647 L
.16716 .20989 L
.15194 .19181 L
.1425 .18206 L
.13097 .16716 L
.11785 .15214 L
.11123 .1425 L
.09321 .11785 L
.0932 .11783 L
.07682 .0932 L
.06854 .07773 L
.06502 .06854 L
.06854 .05707 L
Mfstroke
.9 g
.1425 .11669 m
.1446 .11785 L
.16716 .13215 L
.18158 .1425 L
.19181 .15021 L
.21324 .16716 L
.21647 .16979 L
.24112 .19038 L
.24286 .19181 L
.26578 .21173 L
.27122 .21647 L
.29043 .23393 L
.29831 .24112 L
.31509 .2569 L
.32441 .26578 L
.33974 .28059 L
.34968 .29043 L
.3644 .305 L
.37417 .31509 L
.38905 .3302 L
.39789 .33974 L
.41371 .35633 L
.42079 .3644 L
.43836 .38371 L
.44276 .38905 L
.46302 .41297 L
.46358 .41371 L
.4834 .43836 L
.48767 .44397 L
.50141 .46302 L
.51233 .48074 L
.51579 .48767 L
.51233 .50262 L
.48767 .49236 L
.48018 .48767 L
.46302 .47594 L
.44567 .46302 L
.43836 .45736 L
.41485 .43836 L
.41371 .43742 L
.38905 .41666 L
.38553 .41371 L
.3644 .39506 L
.35761 .38905 L
.33974 .37263 L
.33085 .3644 L
.31509 .34945 L
.30503 .33974 L
.29043 .32555 L
.28001 .31509 L
.26578 .30092 L
.25576 .29043 L
.24112 .27548 L
.23228 .26578 L
.21647 .24903 L
.20966 .24112 L
.19181 .2212 L
.18803 .21647 L
.16758 .19181 L
.16716 .1913 L
.14821 .16716 L
.1425 .15937 L
.13103 .1425 L
.11919 .11785 L
F
0 g
.1425 .11669 m
.1446 .11785 L
.16716 .13215 L
.18158 .1425 L
.19181 .15021 L
.21324 .16716 L
.21647 .16979 L
.24112 .19038 L
.24286 .19181 L
.26578 .21173 L
.27122 .21647 L
.29043 .23393 L
.29831 .24112 L
.31509 .2569 L
.32441 .26578 L
.33974 .28059 L
.34968 .29043 L
.3644 .305 L
.37417 .31509 L
.38905 .3302 L
.39789 .33974 L
.41371 .35633 L
.42079 .3644 L
.43836 .38371 L
.44276 .38905 L
.46302 .41297 L
.46358 .41371 L
.4834 .43836 L
.48767 .44397 L
.50141 .46302 L
.51233 .48074 L
.51579 .48767 L
.51233 .50262 L
.48767 .49236 L
.48018 .48767 L
.46302 .47594 L
.44567 .46302 L
.43836 .45736 L
.41485 .43836 L
.41371 .43742 L
.38905 .41666 L
.38553 .41371 L
.3644 .39506 L
.35761 .38905 L
.33974 .37263 L
.33085 .3644 L
.31509 .34945 L
.30503 .33974 L
.29043 .32555 L
.28001 .31509 L
Mistroke
.26578 .30092 L
.25576 .29043 L
.24112 .27548 L
.23228 .26578 L
.21647 .24903 L
.20966 .24112 L
.19181 .2212 L
.18803 .21647 L
.16758 .19181 L
.16716 .1913 L
.14821 .16716 L
.1425 .15937 L
.13103 .1425 L
.11919 .11785 L
.1425 .11669 L
Mfstroke
1 g
.19181 .17655 m
.21647 .18946 L
.21982 .19181 L
.24112 .20789 L
.25172 .21647 L
.26578 .22829 L
.28049 .24112 L
.29043 .25004 L
.30751 .26578 L
.31509 .27293 L
.33323 .29043 L
.33974 .29686 L
.35781 .31509 L
.3644 .32191 L
.38126 .33974 L
.38905 .34824 L
.40348 .3644 L
.41371 .37636 L
.42415 .38905 L
.43836 .40788 L
.44237 .41371 L
.43836 .43414 L
.41371 .41858 L
.40716 .41371 L
.38905 .39946 L
.37653 .38905 L
.3644 .37862 L
.34838 .3644 L
.33974 .35652 L
.32179 .33974 L
.31509 .33333 L
.29644 .31509 L
.29043 .30907 L
.27221 .29043 L
.26578 .28368 L
.24913 .26578 L
.24112 .25688 L
.22735 .24112 L
.21647 .22804 L
.2073 .21647 L
.19181 .19429 L
.19034 .19181 L
F
0 g
.19181 .17655 m
.21647 .18946 L
.21982 .19181 L
.24112 .20789 L
.25172 .21647 L
.26578 .22829 L
.28049 .24112 L
.29043 .25004 L
.30751 .26578 L
.31509 .27293 L
.33323 .29043 L
.33974 .29686 L
.35781 .31509 L
.3644 .32191 L
.38126 .33974 L
.38905 .34824 L
.40348 .3644 L
.41371 .37636 L
.42415 .38905 L
.43836 .40788 L
.44237 .41371 L
.43836 .43414 L
.41371 .41858 L
.40716 .41371 L
.38905 .39946 L
.37653 .38905 L
.3644 .37862 L
.34838 .3644 L
.33974 .35652 L
.32179 .33974 L
.31509 .33333 L
.29644 .31509 L
.29043 .30907 L
.27221 .29043 L
.26578 .28368 L
.24913 .26578 L
.24112 .25688 L
.22735 .24112 L
.21647 .22804 L
.2073 .21647 L
.19181 .19429 L
.19034 .19181 L
.19181 .17655 L
s
.98077 .86484 m
.97555 .8575 L
.95754 .83284 L
.95611 .831 L
.93855 .80819 L
.93146 .79862 L
.9194 .78353 L
.9068 .76722 L
.89995 .75888 L
.88215 .73658 L
.88017 .73422 L
.8596 .70957 L
.8575 .70686 L
.83856 .68491 L
.83284 .67779 L
.81742 .66026 L
.80819 .64909 L
.79614 .6356 L
.78353 .62074 L
.77468 .61095 L
.75888 .59272 L
.75301 .58629 L
.73422 .56502 L
.7311 .56164 L
.70957 .53765 L
.70894 .53698 L
.68607 .51233 L
.68491 .51097 L
.66292 .48767 L
.66026 .48462 L
.63967 .46302 L
.6356 .45846 L
.6163 .43836 L
.61095 .43249 L
.59278 .41371 L
.58629 .40672 L
.5691 .38905 L
.56164 .38114 L
.54524 .3644 L
.53698 .35577 L
.5212 .33974 L
.51233 .3306 L
.49696 .31509 L
.48767 .30563 L
.47254 .29043 L
.46302 .28086 L
.44791 .26578 L
.43836 .2563 L
.42309 .24112 L
.41371 .23193 L
.39807 .21647 L
.38905 .20775 L
.37285 .19181 L
.3644 .18375 L
.34744 .16716 L
.33974 .15992 L
.32184 .1425 L
.31509 .13625 L
.29607 .11785 L
.29043 .11273 L
.27014 .0932 L
.26578 .08932 L
.24405 .06854 L
.24112 .066 L
.21783 .04389 L
.21647 .04215 L
.19181 .01957 L
.19137 .01923 L
.98077 .01923 L
F
.98077 .86484 m
.97555 .8575 L
.95754 .83284 L
.95611 .831 L
.93855 .80819 L
.93146 .79862 L
.9194 .78353 L
.9068 .76722 L
.89995 .75888 L
.88215 .73658 L
.88017 .73422 L
.8596 .70957 L
.8575 .70686 L
.83856 .68491 L
.83284 .67779 L
.81742 .66026 L
.80819 .64909 L
.79614 .6356 L
.78353 .62074 L
.77468 .61095 L
.75888 .59272 L
.75301 .58629 L
.73422 .56502 L
.7311 .56164 L
.70957 .53765 L
.70894 .53698 L
.68607 .51233 L
.68491 .51097 L
.66292 .48767 L
.66026 .48462 L
.63967 .46302 L
.6356 .45846 L
.6163 .43836 L
.61095 .43249 L
.59278 .41371 L
.58629 .40672 L
.5691 .38905 L
.56164 .38114 L
.54524 .3644 L
.53698 .35577 L
.5212 .33974 L
.51233 .3306 L
.49696 .31509 L
.48767 .30563 L
.47254 .29043 L
.46302 .28086 L
.44791 .26578 L
.43836 .2563 L
.42309 .24112 L
.41371 .23193 L
Mistroke
.39807 .21647 L
.38905 .20775 L
.37285 .19181 L
.3644 .18375 L
.34744 .16716 L
.33974 .15992 L
.32184 .1425 L
.31509 .13625 L
.29607 .11785 L
.29043 .11273 L
.27014 .0932 L
.26578 .08932 L
.24405 .06854 L
.24112 .066 L
.21783 .04389 L
.21647 .04215 L
.19181 .01957 L
.19137 .01923 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.2 g
.01923 .17258 m
.02694 .19181 L
.03816 .21647 L
.04389 .22802 L
.0508 .24112 L
.06455 .26578 L
.06854 .27268 L
.07938 .29043 L
.0932 .31221 L
.0951 .31509 L
.11184 .33974 L
.11785 .34842 L
.12939 .3644 L
.1425 .38225 L
.14768 .38905 L
.16674 .41371 L
.16716 .41424 L
.18669 .43836 L
.19181 .44464 L
.20732 .46302 L
.21647 .47375 L
.22867 .48767 L
.24112 .50174 L
.25073 .51233 L
.26578 .52871 L
.27354 .53698 L
.29043 .55475 L
.29711 .56164 L
.31509 .57992 L
.32146 .58629 L
.33974 .60427 L
.34663 .61095 L
.3644 .62785 L
.37265 .6356 L
.38905 .65069 L
.39958 .66026 L
.41371 .67281 L
.42747 .68491 L
.43836 .69424 L
.45641 .70957 L
.46302 .71501 L
.48651 .73422 L
.48767 .73514 L
.51233 .75447 L
.51802 .75888 L
.53698 .77308 L
.55111 .78353 L
.56164 .79102 L
.58609 .80819 L
.58629 .80832 L
.61095 .82468 L
.62356 .83284 L
.6356 .84028 L
.66026 .85508 L
.66439 .8575 L
.68491 .86883 L
.70957 .88167 L
.71052 .88215 L
.73422 .89322 L
.75888 .90354 L
.76711 .9068 L
.78353 .91225 L
.80819 .91906 L
.83284 .92341 L
.8575 .92431 L
.88215 .91972 L
.90343 .9068 L
.9068 .9034 L
.91749 .88215 L
.92092 .8575 L
.91908 .83284 L
.91387 .80819 L
.9068 .78481 L
.90624 .78353 L
.89662 .75888 L
.88546 .73422 L
.88215 .72735 L
.87291 .70957 L
.85924 .68491 L
.8575 .68187 L
.84441 .66026 L
.83284 .64188 L
.82871 .6356 L
.81204 .61095 L
.80819 .60535 L
.7945 .58629 L
.78353 .57129 L
.77622 .56164 L
.75888 .53911 L
.75719 .53698 L
.73731 .51233 L
.73422 .50853 L
.71668 .48767 L
.70957 .47929 L
.69535 .46302 L
.68491 .45119 L
.6733 .43836 L
.66026 .42411 L
.65052 .41371 L
.6356 .39798 L
.62697 .38905 L
.61095 .37271 L
.60265 .3644 L
.58629 .34827 L
.57751 .33974 L
.56164 .3246 L
.55153 .31509 L
.53698 .30168 L
.52464 .29043 L
.51233 .27948 L
.49679 .26578 L
.48767 .25796 L
.4679 .24112 L
.46302 .2371 L
.43836 .21689 L
.43784 .21647 L
.41371 .19751 L
.40636 .19181 L
.38905 .17882 L
.37334 .16716 L
.3644 .16078 L
.33974 .14341 L
.33844 .1425 L
.31509 .12696 L
.30106 .11785 L
.29043 .11125 L
.26578 .09636 L
.26038 .0932 L
.24112 .0825 L
.21647 .06954 L
.2145 .06854 L
.19181 .05785 L
.16716 .04737 L
.15847 .04389 L
.1425 .03843 L
.11785 .0314 L
.0932 .02679 L
.06854 .02553 L
.04389 .02972 L
.01928 .04389 L
.01923 .04392 L
F
0 g
.01923 .17258 m
.02694 .19181 L
.03816 .21647 L
.04389 .22802 L
.0508 .24112 L
.06455 .26578 L
.06854 .27268 L
.07938 .29043 L
.0932 .31221 L
.0951 .31509 L
.11184 .33974 L
.11785 .34842 L
.12939 .3644 L
.1425 .38225 L
.14768 .38905 L
.16674 .41371 L
.16716 .41424 L
.18669 .43836 L
.19181 .44464 L
.20732 .46302 L
.21647 .47375 L
.22867 .48767 L
.24112 .50174 L
.25073 .51233 L
.26578 .52871 L
.27354 .53698 L
.29043 .55475 L
.29711 .56164 L
.31509 .57992 L
.32146 .58629 L
.33974 .60427 L
.34663 .61095 L
.3644 .62785 L
.37265 .6356 L
.38905 .65069 L
.39958 .66026 L
.41371 .67281 L
.42747 .68491 L
.43836 .69424 L
.45641 .70957 L
.46302 .71501 L
.48651 .73422 L
.48767 .73514 L
.51233 .75447 L
.51802 .75888 L
.53698 .77308 L
.55111 .78353 L
.56164 .79102 L
.58609 .80819 L
.58629 .80832 L
Mistroke
.61095 .82468 L
.62356 .83284 L
.6356 .84028 L
.66026 .85508 L
.66439 .8575 L
.68491 .86883 L
.70957 .88167 L
.71052 .88215 L
.73422 .89322 L
.75888 .90354 L
.76711 .9068 L
.78353 .91225 L
.80819 .91906 L
.83284 .92341 L
.8575 .92431 L
.88215 .91972 L
.90343 .9068 L
.9068 .9034 L
.91749 .88215 L
.92092 .8575 L
.91908 .83284 L
.91387 .80819 L
.9068 .78481 L
.90624 .78353 L
.89662 .75888 L
.88546 .73422 L
.88215 .72735 L
.87291 .70957 L
.85924 .68491 L
.8575 .68187 L
.84441 .66026 L
.83284 .64188 L
.82871 .6356 L
.81204 .61095 L
.80819 .60535 L
.7945 .58629 L
.78353 .57129 L
.77622 .56164 L
.75888 .53911 L
.75719 .53698 L
.73731 .51233 L
.73422 .50853 L
.71668 .48767 L
.70957 .47929 L
.69535 .46302 L
.68491 .45119 L
.6733 .43836 L
.66026 .42411 L
.65052 .41371 L
.6356 .39798 L
Mistroke
.62697 .38905 L
.61095 .37271 L
.60265 .3644 L
.58629 .34827 L
.57751 .33974 L
.56164 .3246 L
.55153 .31509 L
.53698 .30168 L
.52464 .29043 L
.51233 .27948 L
.49679 .26578 L
.48767 .25796 L
.4679 .24112 L
.46302 .2371 L
.43836 .21689 L
.43784 .21647 L
.41371 .19751 L
.40636 .19181 L
.38905 .17882 L
.37334 .16716 L
.3644 .16078 L
.33974 .14341 L
.33844 .1425 L
.31509 .12696 L
.30106 .11785 L
.29043 .11125 L
.26578 .09636 L
.26038 .0932 L
.24112 .0825 L
.21647 .06954 L
.2145 .06854 L
.19181 .05785 L
.16716 .04737 L
.15847 .04389 L
.1425 .03843 L
.11785 .0314 L
.0932 .02679 L
.06854 .02553 L
.04389 .02972 L
.01928 .04389 L
.01923 .04392 L
Mfstroke
.01923 .28508 m
.0227 .29043 L
.03959 .31509 L
.04389 .32105 L
.05745 .33974 L
.06854 .35506 L
.07563 .3644 L
.0932 .38753 L
.09439 .38905 L
.11402 .41371 L
.11785 .41856 L
.13423 .43836 L
.1425 .44843 L
.15497 .46302 L
.16716 .47732 L
.17627 .48767 L
.19181 .5053 L
.19818 .51233 L
.21647 .53245 L
.22069 .53698 L
.24112 .5588 L
.24383 .56164 L
.26578 .58442 L
.26761 .58629 L
.29043 .60933 L
.29205 .61095 L
.31509 .63357 L
.31718 .6356 L
.33974 .65717 L
.343 .66026 L
.3644 .68014 L
.36956 .68491 L
.38905 .70251 L
.3969 .70957 L
.41371 .72429 L
.42504 .73422 L
.43836 .74551 L
.45405 .75888 L
.46302 .76622 L
.48398 .78353 L
.48767 .78644 L
.51233 .80607 L
.515 .80819 L
.53698 .82493 L
.54734 .83284 L
.56164 .84327 L
.58101 .8575 L
.58629 .86116 L
.61095 .87841 L
.61635 .88215 L
.6356 .89484 L
.65379 .9068 L
.66026 .91081 L
.68491 .92603 L
.69387 .93146 L
.70957 .94042 L
.73422 .95422 L
.7377 .95611 L
.75888 .96718 L
.78353 .97898 L
.78749 .98077 L
.01923 .98077 L
F
.01923 .28508 m
.0227 .29043 L
.03959 .31509 L
.04389 .32105 L
.05745 .33974 L
.06854 .35506 L
.07563 .3644 L
.0932 .38753 L
.09439 .38905 L
.11402 .41371 L
.11785 .41856 L
.13423 .43836 L
.1425 .44843 L
.15497 .46302 L
.16716 .47732 L
.17627 .48767 L
.19181 .5053 L
.19818 .51233 L
.21647 .53245 L
.22069 .53698 L
.24112 .5588 L
.24383 .56164 L
.26578 .58442 L
.26761 .58629 L
.29043 .60933 L
.29205 .61095 L
.31509 .63357 L
.31718 .6356 L
.33974 .65717 L
.343 .66026 L
.3644 .68014 L
.36956 .68491 L
.38905 .70251 L
.3969 .70957 L
.41371 .72429 L
.42504 .73422 L
.43836 .74551 L
.45405 .75888 L
.46302 .76622 L
.48398 .78353 L
.48767 .78644 L
.51233 .80607 L
.515 .80819 L
.53698 .82493 L
.54734 .83284 L
.56164 .84327 L
.58101 .8575 L
.58629 .86116 L
.61095 .87841 L
.61635 .88215 L
Mistroke
.6356 .89484 L
.65379 .9068 L
.66026 .91081 L
.68491 .92603 L
.69387 .93146 L
.70957 .94042 L
.73422 .95422 L
.7377 .95611 L
.75888 .96718 L
.78353 .97898 L
.78749 .98077 L
Mfstroke
.3 g
.0932 .09234 m
.11785 .08642 L
.1425 .08734 L
.16716 .09213 L
.17193 .0932 L
.19181 .09959 L
.21647 .1091 L
.23628 .11785 L
.24112 .12023 L
.26578 .13279 L
.28352 .1425 L
.29043 .14652 L
.31509 .16137 L
.32435 .16716 L
.33974 .17721 L
.36138 .19181 L
.3644 .19393 L
.38905 .21159 L
.39573 .21647 L
.41371 .23008 L
.42802 .24112 L
.43836 .24935 L
.45866 .26578 L
.46302 .2694 L
.48767 .29026 L
.48787 .29043 L
.51233 .31198 L
.5158 .31509 L
.53698 .3345 L
.54261 .33974 L
.56164 .35785 L
.5684 .3644 L
.58629 .38207 L
.59323 .38905 L
.61095 .40722 L
.61714 .41371 L
.6356 .43337 L
.64018 .43836 L
.66026 .46061 L
.66237 .46302 L
.6837 .48767 L
.68491 .48909 L
.70414 .51233 L
.70957 .51901 L
.72372 .53698 L
.73422 .5506 L
.74244 .56164 L
.75888 .58427 L
.76029 .58629 L
.7771 .61095 L
.78353 .62071 L
.79289 .6356 L
.8076 .66026 L
.80819 .66126 L
.82099 .68491 L
.83284 .7092 L
.833 .70957 L
.84328 .73422 L
.85152 .75888 L
.85704 .78353 L
.8575 .78671 L
.85867 .80819 L
.8575 .8194 L
.8538 .83284 L
.83284 .85617 L
.82999 .8575 L
.80819 .86316 L
.78353 .86281 L
.75888 .85838 L
.75458 .8575 L
.73422 .85118 L
.70957 .84188 L
.68884 .83284 L
.68491 .83093 L
.66026 .81851 L
.64127 .80819 L
.6356 .80491 L
.61095 .79017 L
.60027 .78353 L
.58629 .77444 L
.56313 .75888 L
.56164 .75783 L
.53698 .74025 L
.52871 .73422 L
.51233 .72187 L
.49634 .70957 L
.48767 .70269 L
.46565 .68491 L
.46302 .68273 L
.43836 .66193 L
.4364 .66026 L
.41371 .64031 L
.40843 .6356 L
.38905 .61789 L
.38158 .61095 L
.3644 .59464 L
.35575 .58629 L
.33974 .57052 L
.33089 .56164 L
.31509 .54548 L
.30695 .53698 L
.29043 .51944 L
.28388 .51233 L
.26578 .49233 L
.26167 .48767 L
.24112 .464 L
.24029 .46302 L
.21981 .43836 L
.21647 .43426 L
.2002 .41371 L
.19181 .40288 L
.18146 .38905 L
.16716 .36946 L
.1636 .3644 L
.14672 .33974 L
.1425 .33339 L
.13091 .31509 L
.11785 .2934 L
.11616 .29043 L
.10272 .26578 L
.0932 .24671 L
.09066 .24112 L
.08031 .21647 L
.07199 .19181 L
.06854 .17837 L
.06636 .16716 L
.06455 .1425 L
.06854 .11968 L
.0692 .11785 L
.09122 .0932 L
F
0 g
.0932 .09234 m
.11785 .08642 L
.1425 .08734 L
.16716 .09213 L
.17193 .0932 L
.19181 .09959 L
.21647 .1091 L
.23628 .11785 L
.24112 .12023 L
.26578 .13279 L
.28352 .1425 L
.29043 .14652 L
.31509 .16137 L
.32435 .16716 L
.33974 .17721 L
.36138 .19181 L
.3644 .19393 L
.38905 .21159 L
.39573 .21647 L
.41371 .23008 L
.42802 .24112 L
.43836 .24935 L
.45866 .26578 L
.46302 .2694 L
.48767 .29026 L
.48787 .29043 L
.51233 .31198 L
.5158 .31509 L
.53698 .3345 L
.54261 .33974 L
.56164 .35785 L
.5684 .3644 L
.58629 .38207 L
.59323 .38905 L
.61095 .40722 L
.61714 .41371 L
.6356 .43337 L
.64018 .43836 L
.66026 .46061 L
.66237 .46302 L
.6837 .48767 L
.68491 .48909 L
.70414 .51233 L
.70957 .51901 L
.72372 .53698 L
.73422 .5506 L
.74244 .56164 L
.75888 .58427 L
.76029 .58629 L
.7771 .61095 L
Mistroke
.78353 .62071 L
.79289 .6356 L
.8076 .66026 L
.80819 .66126 L
.82099 .68491 L
.83284 .7092 L
.833 .70957 L
.84328 .73422 L
.85152 .75888 L
.85704 .78353 L
.8575 .78671 L
.85867 .80819 L
.8575 .8194 L
.8538 .83284 L
.83284 .85617 L
.82999 .8575 L
.80819 .86316 L
.78353 .86281 L
.75888 .85838 L
.75458 .8575 L
.73422 .85118 L
.70957 .84188 L
.68884 .83284 L
.68491 .83093 L
.66026 .81851 L
.64127 .80819 L
.6356 .80491 L
.61095 .79017 L
.60027 .78353 L
.58629 .77444 L
.56313 .75888 L
.56164 .75783 L
.53698 .74025 L
.52871 .73422 L
.51233 .72187 L
.49634 .70957 L
.48767 .70269 L
.46565 .68491 L
.46302 .68273 L
.43836 .66193 L
.4364 .66026 L
.41371 .64031 L
.40843 .6356 L
.38905 .61789 L
.38158 .61095 L
.3644 .59464 L
.35575 .58629 L
.33974 .57052 L
.33089 .56164 L
.31509 .54548 L
Mistroke
.30695 .53698 L
.29043 .51944 L
.28388 .51233 L
.26578 .49233 L
.26167 .48767 L
.24112 .464 L
.24029 .46302 L
.21981 .43836 L
.21647 .43426 L
.2002 .41371 L
.19181 .40288 L
.18146 .38905 L
.16716 .36946 L
.1636 .3644 L
.14672 .33974 L
.1425 .33339 L
.13091 .31509 L
.11785 .2934 L
.11616 .29043 L
.10272 .26578 L
.0932 .24671 L
.09066 .24112 L
.08031 .21647 L
.07199 .19181 L
.06854 .17837 L
.06636 .16716 L
.06455 .1425 L
.06854 .11968 L
.0692 .11785 L
.09122 .0932 L
.0932 .09234 L
Mfstroke
.4 g
.1425 .13778 m
.16716 .13404 L
.19181 .13668 L
.21488 .1425 L
.21647 .14299 L
.24112 .15187 L
.26578 .16273 L
.27504 .16716 L
.29043 .17521 L
.31509 .18906 L
.31979 .19181 L
.33974 .20415 L
.35872 .21647 L
.3644 .22031 L
.38905 .23753 L
.39406 .24112 L
.41371 .25573 L
.42686 .26578 L
.43836 .27485 L
.45767 .29043 L
.46302 .29487 L
.48686 .31509 L
.48767 .3158 L
.51233 .33767 L
.51462 .33974 L
.53698 .36048 L
.54112 .3644 L
.56164 .38426 L
.56648 .38905 L
.58629 .40907 L
.59077 .41371 L
.61095 .435 L
.61405 .43836 L
.6356 .46216 L
.63636 .46302 L
.65767 .48767 L
.66026 .49074 L
.67799 .51233 L
.68491 .52096 L
.69734 .53698 L
.70957 .55321 L
.71568 .56164 L
.73297 .58629 L
.73422 .58813 L
.74906 .61095 L
.75888 .62689 L
.76391 .6356 L
.77735 .66026 L
.78353 .67237 L
.78914 .68491 L
.79893 .70957 L
.80614 .73422 L
.80819 .74479 L
.80971 .75888 L
.80819 .77966 L
.80726 .78353 L
.78974 .80819 L
.78353 .8109 L
.75888 .81575 L
.73422 .81365 L
.71128 .80819 L
.70957 .80768 L
.68491 .79906 L
.66026 .7884 L
.64994 .78353 L
.6356 .77609 L
.61095 .76239 L
.60492 .75888 L
.58629 .74743 L
.56584 .73422 L
.56164 .73139 L
.53698 .71427 L
.5304 .70957 L
.51233 .69618 L
.49752 .68491 L
.48767 .67718 L
.46664 .66026 L
.46302 .65726 L
.43836 .63643 L
.4374 .6356 L
.41371 .61465 L
.4096 .61095 L
.38905 .59195 L
.38306 .58629 L
.3644 .56828 L
.35766 .56164 L
.33974 .54359 L
.33333 .53698 L
.31509 .51779 L
.31002 .51233 L
.29043 .49078 L
.28768 .48767 L
.26632 .46302 L
.26578 .46238 L
.24596 .43836 L
.24112 .43236 L
.22658 .41371 L
.21647 .40036 L
.20821 .38905 L
.19181 .36578 L
.19088 .3644 L
.17474 .33974 L
.16716 .32757 L
.15985 .31509 L
.14635 .29043 L
.1425 .28313 L
.13451 .26578 L
.12463 .24112 L
.11785 .21958 L
.11733 .21647 L
.11358 .19181 L
.11578 .16716 L
.11785 .16122 L
.13126 .1425 L
F
0 g
.1425 .13778 m
.16716 .13404 L
.19181 .13668 L
.21488 .1425 L
.21647 .14299 L
.24112 .15187 L
.26578 .16273 L
.27504 .16716 L
.29043 .17521 L
.31509 .18906 L
.31979 .19181 L
.33974 .20415 L
.35872 .21647 L
.3644 .22031 L
.38905 .23753 L
.39406 .24112 L
.41371 .25573 L
.42686 .26578 L
.43836 .27485 L
.45767 .29043 L
.46302 .29487 L
.48686 .31509 L
.48767 .3158 L
.51233 .33767 L
.51462 .33974 L
.53698 .36048 L
.54112 .3644 L
.56164 .38426 L
.56648 .38905 L
.58629 .40907 L
.59077 .41371 L
.61095 .435 L
.61405 .43836 L
.6356 .46216 L
.63636 .46302 L
.65767 .48767 L
.66026 .49074 L
.67799 .51233 L
.68491 .52096 L
.69734 .53698 L
.70957 .55321 L
.71568 .56164 L
.73297 .58629 L
.73422 .58813 L
.74906 .61095 L
.75888 .62689 L
.76391 .6356 L
.77735 .66026 L
.78353 .67237 L
.78914 .68491 L
Mistroke
.79893 .70957 L
.80614 .73422 L
.80819 .74479 L
.80971 .75888 L
.80819 .77966 L
.80726 .78353 L
.78974 .80819 L
.78353 .8109 L
.75888 .81575 L
.73422 .81365 L
.71128 .80819 L
.70957 .80768 L
.68491 .79906 L
.66026 .7884 L
.64994 .78353 L
.6356 .77609 L
.61095 .76239 L
.60492 .75888 L
.58629 .74743 L
.56584 .73422 L
.56164 .73139 L
.53698 .71427 L
.5304 .70957 L
.51233 .69618 L
.49752 .68491 L
.48767 .67718 L
.46664 .66026 L
.46302 .65726 L
.43836 .63643 L
.4374 .6356 L
.41371 .61465 L
.4096 .61095 L
.38905 .59195 L
.38306 .58629 L
.3644 .56828 L
.35766 .56164 L
.33974 .54359 L
.33333 .53698 L
.31509 .51779 L
.31002 .51233 L
.29043 .49078 L
.28768 .48767 L
.26632 .46302 L
.26578 .46238 L
.24596 .43836 L
.24112 .43236 L
.22658 .41371 L
.21647 .40036 L
.20821 .38905 L
.19181 .36578 L
Mistroke
.19088 .3644 L
.17474 .33974 L
.16716 .32757 L
.15985 .31509 L
.14635 .29043 L
.1425 .28313 L
.13451 .26578 L
.12463 .24112 L
.11785 .21958 L
.11733 .21647 L
.11358 .19181 L
.11578 .16716 L
.11785 .16122 L
.13126 .1425 L
.1425 .13778 L
Mfstroke
.5 g
.16716 .18755 m
.19181 .17617 L
.21647 .17653 L
.24112 .18188 L
.26578 .19038 L
.26959 .19181 L
.29043 .20116 L
.31509 .21379 L
.32002 .21647 L
.33974 .22796 L
.36085 .24112 L
.3644 .24346 L
.38905 .2602 L
.39696 .26578 L
.41371 .27806 L
.43001 .29043 L
.43836 .29699 L
.46077 .31509 L
.46302 .31696 L
.48767 .33798 L
.4897 .33974 L
.51233 .36005 L
.51706 .3644 L
.53698 .38319 L
.54304 .38905 L
.56164 .40747 L
.56777 .41371 L
.58629 .43298 L
.59133 .43836 L
.61095 .45986 L
.61375 .46302 L
.63507 .48767 L
.6356 .4883 L
.65527 .51233 L
.66026 .5186 L
.67434 .53698 L
.68491 .5513 L
.69223 .56164 L
.70887 .58629 L
.70957 .58734 L
.72411 .61095 L
.73422 .6287 L
.73779 .6356 L
.74963 .66026 L
.75888 .68401 L
.75913 .68491 L
.76557 .70957 L
.76724 .73422 L
.75888 .75851 L
.75875 .75888 L
.73422 .77321 L
.70957 .77363 L
.68491 .76872 L
.66026 .76052 L
.65574 .75888 L
.6356 .74997 L
.61095 .73753 L
.60478 .73422 L
.58629 .72353 L
.56376 .70957 L
.56164 .70817 L
.53698 .69156 L
.52751 .68491 L
.51233 .67383 L
.49437 .66026 L
.48767 .65502 L
.46354 .6356 L
.46302 .63517 L
.43836 .61426 L
.43455 .61095 L
.41371 .59231 L
.40714 .58629 L
.38905 .56929 L
.38111 .56164 L
.3644 .54514 L
.35634 .53698 L
.33974 .51977 L
.33275 .51233 L
.31509 .49306 L
.31028 .48767 L
.29043 .46481 L
.28892 .46302 L
.26868 .43836 L
.26578 .43474 L
.24957 .41371 L
.24112 .40236 L
.23164 .38905 L
.21647 .36675 L
.21495 .3644 L
.19966 .33974 L
.19181 .32626 L
.18592 .31509 L
.17401 .29043 L
.16716 .27478 L
.16441 .26578 L
.15784 .24112 L
.15593 .21647 L
.16381 .19181 L
F
0 g
.16716 .18755 m
.19181 .17617 L
.21647 .17653 L
.24112 .18188 L
.26578 .19038 L
.26959 .19181 L
.29043 .20116 L
.31509 .21379 L
.32002 .21647 L
.33974 .22796 L
.36085 .24112 L
.3644 .24346 L
.38905 .2602 L
.39696 .26578 L
.41371 .27806 L
.43001 .29043 L
.43836 .29699 L
.46077 .31509 L
.46302 .31696 L
.48767 .33798 L
.4897 .33974 L
.51233 .36005 L
.51706 .3644 L
.53698 .38319 L
.54304 .38905 L
.56164 .40747 L
.56777 .41371 L
.58629 .43298 L
.59133 .43836 L
.61095 .45986 L
.61375 .46302 L
.63507 .48767 L
.6356 .4883 L
.65527 .51233 L
.66026 .5186 L
.67434 .53698 L
.68491 .5513 L
.69223 .56164 L
.70887 .58629 L
.70957 .58734 L
.72411 .61095 L
.73422 .6287 L
.73779 .6356 L
.74963 .66026 L
.75888 .68401 L
.75913 .68491 L
.76557 .70957 L
.76724 .73422 L
.75888 .75851 L
.75875 .75888 L
Mistroke
.73422 .77321 L
.70957 .77363 L
.68491 .76872 L
.66026 .76052 L
.65574 .75888 L
.6356 .74997 L
.61095 .73753 L
.60478 .73422 L
.58629 .72353 L
.56376 .70957 L
.56164 .70817 L
.53698 .69156 L
.52751 .68491 L
.51233 .67383 L
.49437 .66026 L
.48767 .65502 L
.46354 .6356 L
.46302 .63517 L
.43836 .61426 L
.43455 .61095 L
.41371 .59231 L
.40714 .58629 L
.38905 .56929 L
.38111 .56164 L
.3644 .54514 L
.35634 .53698 L
.33974 .51977 L
.33275 .51233 L
.31509 .49306 L
.31028 .48767 L
.29043 .46481 L
.28892 .46302 L
.26868 .43836 L
.26578 .43474 L
.24957 .41371 L
.24112 .40236 L
.23164 .38905 L
.21647 .36675 L
.21495 .3644 L
.19966 .33974 L
.19181 .32626 L
.18592 .31509 L
.17401 .29043 L
.16716 .27478 L
.16441 .26578 L
.15784 .24112 L
.15593 .21647 L
.16381 .19181 L
.16716 .18755 L
Mfstroke
.6 g
.24112 .21418 m
.25721 .21647 L
.26578 .21844 L
.29043 .22664 L
.31509 .23757 L
.32249 .24112 L
.33974 .2505 L
.3644 .26516 L
.36539 .26578 L
.38905 .28128 L
.40227 .29043 L
.41371 .29874 L
.43536 .31509 L
.43836 .31745 L
.46302 .33736 L
.46588 .33974 L
.48767 .35847 L
.49437 .3644 L
.51233 .38077 L
.52115 .38905 L
.53698 .40433 L
.54642 .41371 L
.56164 .42924 L
.57031 .43836 L
.58629 .45565 L
.59289 .46302 L
.61095 .4838 L
.6142 .48767 L
.63424 .51233 L
.6356 .51404 L
.65297 .53698 L
.66026 .547 L
.67031 .56164 L
.68491 .58425 L
.68614 .58629 L
.70027 .61095 L
.70957 .6291 L
.7123 .6356 L
.72178 .66026 L
.72755 .68491 L
.72717 .70957 L
.70957 .73245 L
.70135 .73422 L
.68491 .73576 L
.67065 .73422 L
.66026 .7321 L
.6356 .72426 L
.61095 .71359 L
.60241 .70957 L
.58629 .70087 L
.56164 .68639 L
.55923 .68491 L
.53698 .67042 L
.52221 .66026 L
.51233 .65311 L
.48903 .6356 L
.48767 .63454 L
.46302 .61476 L
.45841 .61095 L
.43836 .59379 L
.42986 .58629 L
.41371 .57163 L
.40302 .56164 L
.38905 .54821 L
.3777 .53698 L
.3644 .52346 L
.35377 .51233 L
.33974 .49723 L
.33114 .48767 L
.31509 .4693 L
.30979 .46302 L
.29043 .4393 L
.2897 .43836 L
.27092 .41371 L
.26578 .40671 L
.25353 .38905 L
.24112 .37011 L
.23765 .3644 L
.22346 .33974 L
.21647 .32682 L
.21133 .31509 L
.20175 .29043 L
.19586 .26578 L
.19599 .24112 L
.21647 .21699 L
.21878 .21647 L
F
0 g
.24112 .21418 m
.25721 .21647 L
.26578 .21844 L
.29043 .22664 L
.31509 .23757 L
.32249 .24112 L
.33974 .2505 L
.3644 .26516 L
.36539 .26578 L
.38905 .28128 L
.40227 .29043 L
.41371 .29874 L
.43536 .31509 L
.43836 .31745 L
.46302 .33736 L
.46588 .33974 L
.48767 .35847 L
.49437 .3644 L
.51233 .38077 L
.52115 .38905 L
.53698 .40433 L
.54642 .41371 L
.56164 .42924 L
.57031 .43836 L
.58629 .45565 L
.59289 .46302 L
.61095 .4838 L
.6142 .48767 L
.63424 .51233 L
.6356 .51404 L
.65297 .53698 L
.66026 .547 L
.67031 .56164 L
.68491 .58425 L
.68614 .58629 L
.70027 .61095 L
.70957 .6291 L
.7123 .6356 L
.72178 .66026 L
.72755 .68491 L
.72717 .70957 L
.70957 .73245 L
.70135 .73422 L
.68491 .73576 L
.67065 .73422 L
.66026 .7321 L
.6356 .72426 L
.61095 .71359 L
.60241 .70957 L
.58629 .70087 L
Mistroke
.56164 .68639 L
.55923 .68491 L
.53698 .67042 L
.52221 .66026 L
.51233 .65311 L
.48903 .6356 L
.48767 .63454 L
.46302 .61476 L
.45841 .61095 L
.43836 .59379 L
.42986 .58629 L
.41371 .57163 L
.40302 .56164 L
.38905 .54821 L
.3777 .53698 L
.3644 .52346 L
.35377 .51233 L
.33974 .49723 L
.33114 .48767 L
.31509 .4693 L
.30979 .46302 L
.29043 .4393 L
.2897 .43836 L
.27092 .41371 L
.26578 .40671 L
.25353 .38905 L
.24112 .37011 L
.23765 .3644 L
.22346 .33974 L
.21647 .32682 L
.21133 .31509 L
.20175 .29043 L
.19586 .26578 L
.19599 .24112 L
.21647 .21699 L
.21878 .21647 L
.24112 .21418 L
Mfstroke
.98077 .79885 m
.97351 .78353 L
.96079 .75888 L
.95611 .75035 L
.94696 .73422 L
.93251 .70957 L
.93146 .70779 L
.91701 .68491 L
.9068 .66895 L
.90095 .66026 L
.88412 .6356 L
.88215 .63271 L
.86644 .61095 L
.8575 .59852 L
.84825 .58629 L
.83284 .5659 L
.82949 .56164 L
.81 .53698 L
.80819 .53467 L
.78977 .51233 L
.78353 .5047 L
.76903 .48767 L
.75888 .47572 L
.74772 .46302 L
.73422 .44765 L
.72583 .43836 L
.70957 .42042 L
.70333 .41371 L
.68491 .39398 L
.68021 .38905 L
.66026 .36829 L
.65645 .3644 L
.6356 .3433 L
.63204 .33974 L
.61095 .31899 L
.60694 .31509 L
.58629 .29532 L
.58114 .29043 L
.56164 .27228 L
.55461 .26578 L
.53698 .24984 L
.52732 .24112 L
.51233 .22798 L
.49921 .21647 L
.48767 .20668 L
.47026 .19181 L
.46302 .18588 L
.44038 .16716 L
.43836 .16557 L
.41371 .14596 L
.40935 .1425 L
.38905 .12702 L
.37708 .11785 L
.3644 .1086 L
.34348 .0932 L
.33974 .0906 L
.31509 .07334 L
.30818 .06854 L
.29043 .05682 L
.27083 .04389 L
.26578 .04059 L
.24112 .02524 L
.23085 .01923 L
.98077 .01923 L
F
.98077 .79885 m
.97351 .78353 L
.96079 .75888 L
.95611 .75035 L
.94696 .73422 L
.93251 .70957 L
.93146 .70779 L
.91701 .68491 L
.9068 .66895 L
.90095 .66026 L
.88412 .6356 L
.88215 .63271 L
.86644 .61095 L
.8575 .59852 L
.84825 .58629 L
.83284 .5659 L
.82949 .56164 L
.81 .53698 L
.80819 .53467 L
.78977 .51233 L
.78353 .5047 L
.76903 .48767 L
.75888 .47572 L
.74772 .46302 L
.73422 .44765 L
.72583 .43836 L
.70957 .42042 L
.70333 .41371 L
.68491 .39398 L
.68021 .38905 L
.66026 .36829 L
.65645 .3644 L
.6356 .3433 L
.63204 .33974 L
.61095 .31899 L
.60694 .31509 L
.58629 .29532 L
.58114 .29043 L
.56164 .27228 L
.55461 .26578 L
.53698 .24984 L
.52732 .24112 L
.51233 .22798 L
.49921 .21647 L
.48767 .20668 L
.47026 .19181 L
.46302 .18588 L
.44038 .16716 L
.43836 .16557 L
.41371 .14596 L
Mistroke
.40935 .1425 L
.38905 .12702 L
.37708 .11785 L
.3644 .1086 L
.34348 .0932 L
.33974 .0906 L
.31509 .07334 L
.30818 .06854 L
.29043 .05682 L
.27083 .04389 L
.26578 .04059 L
.24112 .02524 L
.23085 .01923 L
Mfstroke
.7 g
.24112 .25897 m
.26578 .25071 L
.29043 .25406 L
.31509 .26216 L
.32512 .26578 L
.33974 .27322 L
.3644 .28668 L
.37087 .29043 L
.38905 .30196 L
.40846 .31509 L
.41371 .3189 L
.43836 .33732 L
.44149 .33974 L
.46302 .35714 L
.47166 .3644 L
.48767 .37834 L
.49955 .38905 L
.51233 .40096 L
.52555 .41371 L
.53698 .42508 L
.54988 .43836 L
.56164 .45086 L
.57267 .46302 L
.58629 .47855 L
.59397 .48767 L
.61095 .50865 L
.61378 .51233 L
.63207 .53698 L
.6356 .54185 L
.64868 .56164 L
.66026 .58054 L
.66336 .58629 L
.67584 .61095 L
.68491 .63433 L
.68516 .6356 L
.69013 .66026 L
.68514 .68491 L
.68491 .6854 L
.66026 .69901 L
.6356 .69641 L
.61095 .68874 L
.59979 .68491 L
.58629 .67798 L
.56164 .66475 L
.55379 .66026 L
.53698 .64967 L
.51606 .6356 L
.51233 .63291 L
.48767 .61465 L
.48287 .61095 L
.46302 .59499 L
.45261 .58629 L
.43836 .57394 L
.42465 .56164 L
.41371 .55148 L
.39859 .53698 L
.38905 .52754 L
.37421 .51233 L
.3644 .50196 L
.35136 .48767 L
.33974 .47451 L
.33001 .46302 L
.31509 .44472 L
.31014 .43836 L
.29182 .41371 L
.29043 .41184 L
.27513 .38905 L
.26578 .3742 L
.26037 .3644 L
.24781 .33974 L
.24112 .32322 L
.23833 .31509 L
.23311 .29043 L
.23718 .26578 L
F
0 g
.24112 .25897 m
.26578 .25071 L
.29043 .25406 L
.31509 .26216 L
.32512 .26578 L
.33974 .27322 L
.3644 .28668 L
.37087 .29043 L
.38905 .30196 L
.40846 .31509 L
.41371 .3189 L
.43836 .33732 L
.44149 .33974 L
.46302 .35714 L
.47166 .3644 L
.48767 .37834 L
.49955 .38905 L
.51233 .40096 L
.52555 .41371 L
.53698 .42508 L
.54988 .43836 L
.56164 .45086 L
.57267 .46302 L
.58629 .47855 L
.59397 .48767 L
.61095 .50865 L
.61378 .51233 L
.63207 .53698 L
.6356 .54185 L
.64868 .56164 L
.66026 .58054 L
.66336 .58629 L
.67584 .61095 L
.68491 .63433 L
.68516 .6356 L
.69013 .66026 L
.68514 .68491 L
.68491 .6854 L
.66026 .69901 L
.6356 .69641 L
.61095 .68874 L
.59979 .68491 L
.58629 .67798 L
.56164 .66475 L
.55379 .66026 L
.53698 .64967 L
.51606 .6356 L
.51233 .63291 L
.48767 .61465 L
.48287 .61095 L
Mistroke
.46302 .59499 L
.45261 .58629 L
.43836 .57394 L
.42465 .56164 L
.41371 .55148 L
.39859 .53698 L
.38905 .52754 L
.37421 .51233 L
.3644 .50196 L
.35136 .48767 L
.33974 .47451 L
.33001 .46302 L
.31509 .44472 L
.31014 .43836 L
.29182 .41371 L
.29043 .41184 L
.27513 .38905 L
.26578 .3742 L
.26037 .3644 L
.24781 .33974 L
.24112 .32322 L
.23833 .31509 L
.23311 .29043 L
.23718 .26578 L
.24112 .25897 L
Mfstroke
.8 g
.29043 .29044 m
.31509 .29067 L
.33974 .29796 L
.3644 .30946 L
.3756 .31509 L
.38905 .32341 L
.41371 .33965 L
.41385 .33974 L
.43836 .35759 L
.4472 .3644 L
.46302 .37726 L
.4769 .38905 L
.48767 .39862 L
.504 .41371 L
.51233 .42171 L
.52898 .43836 L
.53698 .44665 L
.55207 .46302 L
.56164 .47376 L
.57337 .48767 L
.58629 .50365 L
.59285 .51233 L
.61042 .53698 L
.61095 .53763 L
.62599 .56164 L
.6356 .57844 L
.63876 .58629 L
.64834 .61095 L
.65266 .6356 L
.6356 .65851 L
.61095 .65973 L
.58629 .65295 L
.56164 .6418 L
.54903 .6356 L
.53698 .6281 L
.51233 .6121 L
.51062 .61095 L
.48767 .59435 L
.47713 .58629 L
.46302 .57487 L
.44735 .56164 L
.43836 .55369 L
.42018 .53698 L
.41371 .5308 L
.39513 .51233 L
.38905 .50607 L
.37197 .48767 L
.3644 .47924 L
.35061 .46302 L
.33974 .44974 L
.33105 .43836 L
.31509 .41623 L
.31342 .41371 L
.29778 .38905 L
.29043 .3776 L
.28486 .3644 L
.27514 .33974 L
.27057 .31509 L
F
0 g
.29043 .29044 m
.31509 .29067 L
.33974 .29796 L
.3644 .30946 L
.3756 .31509 L
.38905 .32341 L
.41371 .33965 L
.41385 .33974 L
.43836 .35759 L
.4472 .3644 L
.46302 .37726 L
.4769 .38905 L
.48767 .39862 L
.504 .41371 L
.51233 .42171 L
.52898 .43836 L
.53698 .44665 L
.55207 .46302 L
.56164 .47376 L
.57337 .48767 L
.58629 .50365 L
.59285 .51233 L
.61042 .53698 L
.61095 .53763 L
.62599 .56164 L
.6356 .57844 L
.63876 .58629 L
.64834 .61095 L
.65266 .6356 L
.6356 .65851 L
.61095 .65973 L
.58629 .65295 L
.56164 .6418 L
.54903 .6356 L
.53698 .6281 L
.51233 .6121 L
.51062 .61095 L
.48767 .59435 L
.47713 .58629 L
.46302 .57487 L
.44735 .56164 L
.43836 .55369 L
.42018 .53698 L
.41371 .5308 L
.39513 .51233 L
.38905 .50607 L
.37197 .48767 L
.3644 .47924 L
.35061 .46302 L
.33974 .44974 L
Mistroke
.33105 .43836 L
.31509 .41623 L
.31342 .41371 L
.29778 .38905 L
.29043 .3776 L
.28486 .3644 L
.27514 .33974 L
.27057 .31509 L
.29043 .29044 L
Mfstroke
.9 g
.33974 .32918 m
.3644 .33644 L
.37218 .33974 L
.38905 .34749 L
.41371 .36255 L
.41668 .3644 L
.43836 .37965 L
.45086 .38905 L
.46302 .39907 L
.48003 .41371 L
.48767 .4207 L
.50611 .43836 L
.51233 .44456 L
.52971 .46302 L
.53698 .47094 L
.551 .48767 L
.56164 .50074 L
.5699 .51233 L
.58615 .53698 L
.58629 .53724 L
.59987 .56164 L
.60921 .58629 L
.60555 .61095 L
.58629 .62086 L
.56164 .61441 L
.55312 .61095 L
.53698 .60382 L
.51233 .58908 L
.50776 .58629 L
.48767 .57225 L
.47344 .56164 L
.46302 .55305 L
.44421 .53698 L
.43836 .53165 L
.41805 .51233 L
.41371 .50803 L
.39436 .48767 L
.38905 .48198 L
.37296 .46302 L
.3644 .45276 L
.35394 .43836 L
.33974 .41751 L
.3376 .41371 L
.32375 .38905 L
.31527 .3644 L
.31715 .33974 L
F
0 g
.33974 .32918 m
.3644 .33644 L
.37218 .33974 L
.38905 .34749 L
.41371 .36255 L
.41668 .3644 L
.43836 .37965 L
.45086 .38905 L
.46302 .39907 L
.48003 .41371 L
.48767 .4207 L
.50611 .43836 L
.51233 .44456 L
.52971 .46302 L
.53698 .47094 L
.551 .48767 L
.56164 .50074 L
.5699 .51233 L
.58615 .53698 L
.58629 .53724 L
.59987 .56164 L
.60921 .58629 L
.60555 .61095 L
.58629 .62086 L
.56164 .61441 L
.55312 .61095 L
.53698 .60382 L
.51233 .58908 L
.50776 .58629 L
.48767 .57225 L
.47344 .56164 L
.46302 .55305 L
.44421 .53698 L
.43836 .53165 L
.41805 .51233 L
.41371 .50803 L
.39436 .48767 L
.38905 .48198 L
.37296 .46302 L
.3644 .45276 L
.35394 .43836 L
.33974 .41751 L
.3376 .41371 L
.32375 .38905 L
.31527 .3644 L
.31715 .33974 L
.33974 .32918 L
s
1 g
.38905 .37997 m
.40693 .38905 L
.41371 .3924 L
.43836 .40699 L
.44898 .41371 L
.46302 .42534 L
.47837 .43836 L
.48767 .44715 L
.50287 .46302 L
.51233 .47239 L
.52379 .48767 L
.53698 .50462 L
.54069 .51233 L
.55304 .53698 L
.55509 .56164 L
.53698 .57076 L
.51824 .56164 L
.51233 .55885 L
.48767 .5449 L
.47465 .53698 L
.46302 .52694 L
.44554 .51233 L
.43836 .5055 L
.42103 .48767 L
.41371 .48098 L
.39993 .46302 L
.38905 .44676 L
.38285 .43836 L
.37054 .41371 L
.36773 .38905 L
F
0 g
.38905 .37997 m
.40693 .38905 L
.41371 .3924 L
.43836 .40699 L
.44898 .41371 L
.46302 .42534 L
.47837 .43836 L
.48767 .44715 L
.50287 .46302 L
.51233 .47239 L
.52379 .48767 L
.53698 .50462 L
.54069 .51233 L
.55304 .53698 L
.55509 .56164 L
.53698 .57076 L
.51824 .56164 L
.51233 .55885 L
.48767 .5449 L
.47465 .53698 L
.46302 .52694 L
.44554 .51233 L
.43836 .5055 L
.42103 .48767 L
.41371 .48098 L
.39993 .46302 L
.38905 .44676 L
.38285 .43836 L
.37054 .41371 L
.36773 .38905 L
.38905 .37997 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.663 .741 .908 r
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .48172 Mtetra
.662 .741 .909 r
.77742 .48172 .78397 .49006 .79903 .48556 .79254 .47721 Mtetra
.66 .741 .91 r
.79254 .47721 .79903 .48556 .81418 .48106 .80775 .47277 Mtetra
.654 .742 .914 r
.80775 .47277 .81418 .48106 .8294 .47662 .82305 .46851 Mtetra
.643 .743 .922 r
.82305 .46851 .8294 .47662 .84473 .47233 .83849 .46464 Mtetra
.62 .747 .937 r
.83849 .46464 .84473 .47233 .86018 .46837 .85408 .46146 Mtetra
.577 .753 .961 r
.85408 .46146 .86018 .46837 .87578 .46499 .86987 .45927 Mtetra
.502 .759 .988 r
.86987 .45927 .87578 .46499 .89157 .46245 .8859 .45822 Mtetra
.385 .752 .992 r
.8859 .45822 .89157 .46245 .90758 .46087 .90216 .4581 Mtetra
.267 .729 .95 r
.90216 .4581 .90758 .46087 .9238 .46007 .91858 .45817 Mtetra
.255 .745 .919 r
.91858 .45817 .9238 .46007 .94017 .45941 .93502 .45731 Mtetra
.411 .835 .96 r
.93502 .45731 .94017 .45941 .95656 .45795 .95132 .4544 Mtetra
.625 .895 .987 r
.95132 .4544 .95656 .45795 .97283 .45475 .96738 .44886 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.663 .741 .908 r
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .48241 Mtetra
.7407 .48241 .74743 .49075 .76238 .48624 .75571 .47787 Mtetra
.662 .741 .909 r
.75571 .47787 .76238 .48624 .77742 .48172 .77081 .47334 Mtetra
.659 .741 .911 r
.77081 .47334 .77742 .48172 .79254 .47721 .78599 .4689 Mtetra
.653 .742 .915 r
.78599 .4689 .79254 .47721 .80775 .47277 .80128 .46468 Mtetra
.639 .743 .924 r
.80128 .46468 .80775 .47277 .82305 .46851 .81669 .46092 Mtetra
.611 .747 .942 r
.81669 .46092 .82305 .46851 .83849 .46464 .83228 .45796 Mtetra
.557 .753 .969 r
.83228 .45796 .83849 .46464 .85408 .46146 .84808 .45617 Mtetra
.454 .752 .993 r
.84808 .45617 .85408 .46146 .86987 .45927 .86413 .45573 Mtetra
.285 .717 .967 r
.86413 .45573 .86987 .45927 .8859 .45822 .88043 .45638 Mtetra
.117 .649 .865 r
.88043 .45638 .8859 .45822 .90216 .4581 .8969 .45728 Mtetra
.097 .65 .806 r
.8969 .45728 .90216 .4581 .91858 .45817 .91339 .4571 Mtetra
.298 .788 .891 r
.91339 .4571 .91858 .45817 .93502 .45731 .92972 .45454 Mtetra
.6 .91 .981 r
.92972 .45454 .93502 .45731 .95132 .4544 .94577 .44888 Mtetra
.747 .871 .937 r
.94577 .44888 .95132 .4544 .96738 .44886 .96152 .44037 Mtetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.663 .741 .908 r
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47855 Mtetra
.71892 .47855 .72577 .48693 .7407 .48241 .73391 .474 Mtetra
.662 .741 .909 r
.73391 .474 .7407 .48241 .75571 .47787 .74898 .46946 Mtetra
.659 .741 .911 r
.74898 .46946 .75571 .47787 .77081 .47334 .76414 .46502 Mtetra
.651 .742 .916 r
.76414 .46502 .77081 .47334 .78599 .4689 .77941 .46084 Mtetra
.635 .744 .927 r
.77941 .46084 .78599 .4689 .80128 .46468 .7948 .4572 Mtetra
.601 .747 .947 r
.7948 .4572 .80128 .46468 .81669 .46092 .81038 .4545 Mtetra
.531 .751 .977 r
.81038 .4545 .81669 .46092 .83228 .45796 .82618 .45315 Mtetra
.39 .736 .991 r
.82618 .45315 .83228 .45796 .84808 .45617 .84225 .45339 Mtetra
.153 .653 .91 r
.84225 .45339 .84808 .45617 .86413 .45573 .85859 .45492 Mtetra
0 .524 .724 r
.85859 .45492 .86413 .45573 .88043 .45638 .87512 .45676 Mtetra
.08 0 0 r
.87512 .45676 .88043 .45638 .8969 .45728 .89166 .45736 Mtetra
.154 .696 .771 r
.89166 .45736 .8969 .45728 .91339 .4571 .90802 .4552 Mtetra
.563 .916 .962 r
.90802 .4552 .91339 .4571 .92972 .45454 .92406 .44941 Mtetra
.76 .887 .935 r
.92406 .44941 .92972 .45454 .94577 .44888 .93976 .4403 Mtetra
.785 .797 .863 r
.93976 .4403 .94577 .44888 .96152 .44037 .95524 .42913 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Mtetra
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Mtetra
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Mtetra
.56582 .51499 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50176 Mtetra
.60888 .50176 .61616 .50993 .63062 .50552 .62338 .49731 Mtetra
.62338 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48832 Mtetra
.65262 .48832 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.663 .741 .908 r
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47468 Mtetra
.69704 .47468 .70401 .4831 .71892 .47855 .712 .47011 Mtetra
.662 .741 .909 r
.712 .47011 .71892 .47855 .73391 .474 .72705 .46556 Mtetra
.658 .741 .911 r
.72705 .46556 .73391 .474 .74898 .46946 .74219 .46113 Mtetra
.649 .742 .917 r
.74219 .46113 .74898 .46946 .76414 .46502 .75743 .457 Mtetra
.63 .744 .93 r
.75743 .457 .76414 .46502 .77941 .46084 .77281 .45349 Mtetra
.588 .747 .953 r
.77281 .45349 .77941 .46084 .7948 .4572 .78837 .45107 Mtetra
.499 .747 .984 r
.78837 .45107 .7948 .4572 .81038 .4545 .80418 .45023 Mtetra
.305 .708 .977 r
.80418 .45023 .81038 .4545 .82618 .45315 .82027 .45123 Mtetra
0 .552 .805 r
.82027 .45123 .82618 .45315 .84225 .45339 .83665 .45374 Mtetra
.235 0 0 r
.83665 .45374 .84225 .45339 .85859 .45492 .85323 .45663 Mtetra
.244 0 0 r
.85323 .45663 .85859 .45492 .87512 .45676 .86982 .45812 Mtetra
.004 0 0 r
.86982 .45812 .87512 .45676 .89166 .45736 .88622 .4564 Mtetra
.51 .907 .922 r
.88622 .4564 .89166 .45736 .90802 .4552 .90226 .45049 Mtetra
.774 .903 .931 r
.90226 .45049 .90802 .4552 .92406 .44941 .91791 .44071 Mtetra
.799 .798 .851 r
.91791 .44071 .92406 .44941 .93976 .4403 .93331 .42852 Mtetra
.779 .734 .811 r
.93331 .42852 .93976 .4403 .95524 .42913 .94865 .41582 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Mtetra
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Mtetra
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Mtetra
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Mtetra
.55833 .50688 .56582 .51499 .5801 .51061 .57265 .50245 Mtetra
.57265 .50245 .5801 .51061 .59446 .5062 .58706 .49799 Mtetra
.58706 .49799 .59446 .5062 .60888 .50176 .60153 .49352 Mtetra
.60153 .49352 .60888 .50176 .62338 .49731 .61609 .48902 Mtetra
.61609 .48902 .62338 .49731 .63796 .49283 .63071 .48449 Mtetra
.63071 .48449 .63796 .49283 .65262 .48832 .64542 .47995 Mtetra
.663 .741 .908 r
.64542 .47995 .65262 .48832 .66735 .4838 .6602 .47538 Mtetra
.6602 .47538 .66735 .4838 .68215 .47925 .67506 .47079 Mtetra
.67506 .47079 .68215 .47925 .69704 .47468 .69 .4662 Mtetra
.661 .741 .909 r
.69 .4662 .69704 .47468 .712 .47011 .70503 .46165 Mtetra
.657 .741 .912 r
.70503 .46165 .712 .47011 .72705 .46556 .72014 .45723 Mtetra
.647 .742 .919 r
.72014 .45723 .72705 .46556 .74219 .46113 .73536 .45315 Mtetra
.624 .744 .933 r
.73536 .45315 .74219 .46113 .75743 .457 .75072 .44979 Mtetra
.574 .747 .959 r
.75072 .44979 .75743 .457 .77281 .45349 .76627 .44768 Mtetra
.458 .74 .989 r
.76627 .44768 .77281 .45349 .78837 .45107 .78207 .44739 Mtetra
.196 .659 .941 r
.78207 .44739 .78837 .45107 .80418 .45023 .79818 .44923 Mtetra
.18 0 0 r
.79818 .44923 .80418 .45023 .82027 .45123 .81459 .45283 Mtetra
.381 0 0 r
.81459 .45283 .82027 .45123 .83665 .45374 .83122 .4569 Mtetra
.374 0 0 r
.83122 .4569 .83665 .45374 .85323 .45663 .84787 .45938 Mtetra
.151 0 0 r
.84787 .45938 .85323 .45663 .86982 .45812 .86431 .45818 Mtetra
.438 .876 .856 r
.86431 .45818 .86982 .45812 .88622 .4564 .88035 .45214 Mtetra
.789 .918 .925 r
.88035 .45214 .88622 .4564 .90226 .45049 .89596 .44162 Mtetra
.811 .798 .839 r
.89596 .44162 .90226 .45049 .91791 .44071 .91127 .4283 Mtetra
.787 .727 .797 r
.91127 .4283 .91791 .44071 .93331 .42852 .92652 .41438 Mtetra
.761 .694 .788 r
.92652 .41438 .93331 .42852 .94865 .41582 .94191 .40163 Mtetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Mtetra
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Mtetra
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Mtetra
.55076 .49868 .55833 .50688 .57265 .50245 .56513 .49421 Mtetra
.56513 .49421 .57265 .50245 .58706 .49799 .57958 .48971 Mtetra
.57958 .48971 .58706 .49799 .60153 .49352 .59411 .48519 Mtetra
.59411 .48519 .60153 .49352 .61609 .48902 .60871 .48065 Mtetra
.60871 .48065 .61609 .48902 .63071 .48449 .6234 .47608 Mtetra
.663 .741 .908 r
.6234 .47608 .63071 .48449 .64542 .47995 .63815 .47149 Mtetra
.63815 .47149 .64542 .47995 .6602 .47538 .65299 .46689 Mtetra
.65299 .46689 .6602 .47538 .67506 .47079 .6679 .46228 Mtetra
.661 .741 .909 r
.6679 .46228 .67506 .47079 .69 .4662 .6829 .45771 Mtetra
.656 .741 .913 r
.6829 .45771 .69 .4662 .70503 .46165 .69799 .45331 Mtetra
.645 .742 .92 r
.69799 .45331 .70503 .46165 .72014 .45723 .71319 .44929 Mtetra
.618 .744 .936 r
.71319 .44929 .72014 .45723 .73536 .45315 .72853 .4461 Mtetra
.557 .746 .965 r
.72853 .4461 .73536 .45315 .75072 .44979 .74406 .44433 Mtetra
.407 .727 .99 r
.74406 .44433 .75072 .44979 .76627 .44768 .75985 .44465 Mtetra
.063 .585 .873 r
.75985 .44465 .76627 .44768 .78207 .44739 .77597 .44741 Mtetra
.336 0 0 r
.77597 .44741 .78207 .44739 .79818 .44923 .79241 .45221 Mtetra
.489 0 0 r
.79241 .45221 .79818 .44923 .81459 .45283 .80909 .45757 Mtetra
.467 0 0 r
.80909 .45757 .81459 .45283 .83122 .4569 .82579 .46116 Mtetra
.271 0 0 r
.82579 .46116 .83122 .4569 .84787 .45938 .84227 .46054 Mtetra
.348 .82 .763 r
.84227 .46054 .84787 .45938 .86431 .45818 .85831 .45437 Mtetra
.804 .931 .917 r
.85831 .45437 .86431 .45818 .88035 .45214 .87388 .44304 Mtetra
.824 .795 .825 r
.87388 .44304 .88035 .45214 .89596 .44162 .88912 .42848 Mtetra
.795 .72 .782 r
.88912 .42848 .89596 .44162 .91127 .4283 .90427 .41322 Mtetra
.766 .686 .774 r
.90427 .41322 .91127 .4283 .92652 .41438 .91957 .3993 Mtetra
.742 .675 .786 r
.91957 .3993 .92652 .41438 .94191 .40163 .93517 .3877 Mtetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Mtetra
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Mtetra
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Mtetra
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Mtetra
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Mtetra
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Mtetra
.54311 .4904 .55076 .49868 .56513 .49421 .55754 .48589 Mtetra
.55754 .48589 .56513 .49421 .57958 .48971 .57204 .48135 Mtetra
.57204 .48135 .57958 .48971 .59411 .48519 .58662 .47679 Mtetra
.58662 .47679 .59411 .48519 .60871 .48065 .60127 .4722 Mtetra
.663 .741 .908 r
.60127 .4722 .60871 .48065 .6234 .47608 .616 .46759 Mtetra
.616 .46759 .6234 .47608 .63815 .47149 .63082 .46296 Mtetra
.63082 .46296 .63815 .47149 .65299 .46689 .64571 .45834 Mtetra
.661 .741 .91 r
.64571 .45834 .65299 .46689 .6679 .46228 .66068 .45377 Mtetra
.655 .741 .913 r
.66068 .45377 .6679 .46228 .6829 .45771 .67574 .44937 Mtetra
.642 .742 .922 r
.67574 .44937 .6829 .45771 .69799 .45331 .69091 .44543 Mtetra
.611 .744 .94 r
.69091 .44543 .69799 .45331 .71319 .44929 .70623 .44241 Mtetra
.536 .744 .971 r
.70623 .44241 .71319 .44929 .72853 .4461 .72174 .44102 Mtetra
.343 .707 .984 r
.72174 .44102 .72853 .4461 .74406 .44433 .73752 .44199 Mtetra
0 .483 .769 r
.73752 .44199 .74406 .44433 .75985 .44465 .75364 .44576 Mtetra
.461 0 0 r
.75364 .44576 .75985 .44465 .77597 .44741 .7701 .45187 Mtetra
.563 .035 0 r
.7701 .45187 .77597 .44741 .79241 .45221 .78682 .45866 Mtetra
.532 .032 .015 r
.78682 .45866 .79241 .45221 .80909 .45757 .80357 .46346 Mtetra
.361 0 0 r
.80357 .46346 .80909 .45757 .82579 .46116 .82008 .46349 Mtetra
0 0 0 r
.82008 .46349 .82579 .46116 .84227 .46054 .83614 .45719 Mtetra
.82 .944 .906 r
.83614 .45719 .84227 .46054 .85831 .45437 .85168 .44498 Mtetra
.834 .792 .811 r
.85168 .44498 .85831 .45437 .87388 .44304 .86685 .42907 Mtetra
.801 .712 .767 r
.86685 .42907 .87388 .44304 .88912 .42848 .88191 .41235 Mtetra
.771 .677 .759 r
.88191 .41235 .88912 .42848 .90427 .41322 .89712 .39713 Mtetra
.745 .666 .773 r
.89712 .39713 .90427 .41322 .91957 .3993 .91264 .38458 Mtetra
.723 .673 .801 r
.91264 .38458 .91957 .3993 .93517 .3877 .92851 .37472 Mtetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Mtetra
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Mtetra
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Mtetra
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Mtetra
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Mtetra
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Mtetra
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Mtetra
.53539 .48205 .54311 .4904 .55754 .48589 .54987 .47749 Mtetra
.54987 .47749 .55754 .48589 .57204 .48135 .56442 .47291 Mtetra
.56442 .47291 .57204 .48135 .58662 .47679 .57905 .4683 Mtetra
.663 .741 .908 r
.57905 .4683 .58662 .47679 .60127 .4722 .59376 .46367 Mtetra
.59376 .46367 .60127 .4722 .616 .46759 .60854 .45902 Mtetra
.60854 .45902 .616 .46759 .63082 .46296 .62341 .45438 Mtetra
.66 .741 .91 r
.62341 .45438 .63082 .46296 .64571 .45834 .63835 .4498 Mtetra
.654 .741 .914 r
.63835 .4498 .64571 .45834 .66068 .45377 .65339 .44543 Mtetra
.639 .742 .923 r
.65339 .44543 .66068 .45377 .67574 .44937 .66854 .44156 Mtetra
.603 .744 .944 r
.66854 .44156 .67574 .44937 .69091 .44543 .68382 .43873 Mtetra
.512 .74 .977 r
.68382 .43873 .69091 .44543 .70623 .44241 .69931 .43774 Mtetra
.265 .676 .967 r
.69931 .43774 .70623 .44241 .72174 .44102 .71507 .43942 Mtetra
.238 0 0 r
.71507 .43942 .72174 .44102 .73752 .44199 .73119 .44427 Mtetra
.551 0 0 r
.73119 .44427 .73752 .44199 .75364 .44576 .74766 .4518 Mtetra
.613 .119 .056 r
.74766 .4518 .75364 .44576 .7701 .45187 .76441 .46014 Mtetra
.576 .108 .106 r
.76441 .46014 .7701 .45187 .78682 .45866 .7812 .46627 Mtetra
.427 0 0 r
.7812 .46627 .78682 .45866 .80357 .46346 .79775 .46703 Mtetra
0 0 0 r
.79775 .46703 .80357 .46346 .82008 .46349 .81381 .4606 Mtetra
.835 .954 .893 r
.81381 .4606 .82008 .46349 .83614 .45719 .82933 .44745 Mtetra
.844 .786 .796 r
.82933 .44745 .83614 .45719 .85168 .44498 .84444 .43007 Mtetra
.806 .703 .752 r
.84444 .43007 .85168 .44498 .86685 .42907 .85943 .41175 Mtetra
.774 .667 .745 r
.85943 .41175 .86685 .42907 .88191 .41235 .87455 .39514 Mtetra
.748 .657 .76 r
.87455 .39514 .88191 .41235 .89712 .39713 .88999 .38155 Mtetra
.726 .665 .789 r
.88999 .38155 .89712 .39713 .91264 .38458 .9058 .37101 Mtetra
.706 .683 .825 r
.9058 .37101 .91264 .38458 .92851 .37472 .92195 .36283 Mtetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Mtetra
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Mtetra
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Mtetra
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Mtetra
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Mtetra
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Mtetra
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Mtetra
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Mtetra
.5276 .47361 .53539 .48205 .54987 .47749 .54213 .46901 Mtetra
.54213 .46901 .54987 .47749 .56442 .47291 .55673 .46438 Mtetra
.663 .741 .908 r
.55673 .46438 .56442 .47291 .57905 .4683 .57141 .45973 Mtetra
.57141 .45973 .57905 .4683 .59376 .46367 .58617 .45507 Mtetra
.662 .741 .909 r
.58617 .45507 .59376 .46367 .60854 .45902 .60101 .45041 Mtetra
.66 .741 .91 r
.60101 .45041 .60854 .45902 .62341 .45438 .61593 .44582 Mtetra
.653 .741 .914 r
.61593 .44582 .62341 .45438 .63835 .4498 .63094 .44146 Mtetra
.636 .742 .925 r
.63094 .44146 .63835 .4498 .65339 .44543 .64606 .43767 Mtetra
.594 .743 .948 r
.64606 .43767 .65339 .44543 .66854 .44156 .66131 .43505 Mtetra
.484 .735 .982 r
.66131 .43505 .66854 .44156 .68382 .43873 .67677 .43448 Mtetra
.17 .631 .935 r
.67677 .43448 .68382 .43873 .69931 .43774 .69251 .43692 Mtetra
.372 0 0 r
.69251 .43692 .69931 .43774 .71507 .43942 .7086 .44293 Mtetra
.614 .084 0 r
.7086 .44293 .71507 .43942 .73119 .44427 .72507 .45199 Mtetra
.648 .183 .135 r
.72507 .45199 .73119 .44427 .74766 .4518 .74183 .46201 Mtetra
.607 .166 .176 r
.74183 .46201 .74766 .4518 .76441 .46014 .75866 .46958 Mtetra
.475 .016 .083 r
.75866 .46958 .76441 .46014 .7812 .46627 .77524 .47113 Mtetra
0 0 0 r
.77524 .47113 .7812 .46627 .79775 .46703 .79132 .46458 Mtetra
.85 .961 .878 r
.79132 .46458 .79775 .46703 .81381 .4606 .80683 .45042 Mtetra
.852 .78 .78 r
.80683 .45042 .81381 .4606 .82933 .44745 .8219 .43147 Mtetra
.81 .694 .738 r
.8219 .43147 .82933 .44745 .84444 .43007 .83681 .41143 Mtetra
.777 .658 .732 r
.83681 .41143 .84444 .43007 .85943 .41175 .85186 .39332 Mtetra
.751 .648 .747 r
.85186 .39332 .85943 .41175 .87455 .39514 .86723 .3786 Mtetra
.729 .656 .777 r
.86723 .3786 .87455 .39514 .88999 .38155 .88299 .36734 Mtetra
.709 .676 .816 r
.88299 .36734 .88999 .38155 .9058 .37101 .89908 .35874 Mtetra
.691 .699 .853 r
.89908 .35874 .9058 .37101 .92195 .36283 .91545 .35184 Mtetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Mtetra
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Mtetra
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Mtetra
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Mtetra
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Mtetra
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Mtetra
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Mtetra
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Mtetra
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46509 Mtetra
.51973 .46509 .5276 .47361 .54213 .46901 .53431 .46045 Mtetra
.663 .741 .908 r
.53431 .46045 .54213 .46901 .55673 .46438 .54896 .45577 Mtetra
.54896 .45577 .55673 .46438 .57141 .45973 .5637 .45109 Mtetra
.662 .741 .909 r
.5637 .45109 .57141 .45973 .58617 .45507 .57851 .44641 Mtetra
.66 .741 .91 r
.57851 .44641 .58617 .45507 .60101 .45041 .5934 .44182 Mtetra
.652 .741 .915 r
.5934 .44182 .60101 .45041 .61593 .44582 .60838 .43748 Mtetra
.633 .742 .927 r
.60838 .43748 .61593 .44582 .63094 .44146 .62347 .43378 Mtetra
.584 .743 .952 r
.62347 .43378 .63094 .44146 .64606 .43767 .63869 .43137 Mtetra
.452 .728 .985 r
.63869 .43137 .64606 .43767 .66131 .43505 .65412 .43125 Mtetra
.062 .57 .883 r
.65412 .43125 .66131 .43505 .67677 .43448 .66982 .43449 Mtetra
.481 0 0 r
.66982 .43449 .67677 .43448 .69251 .43692 .68588 .44173 Mtetra
.657 .157 .049 r
.68588 .44173 .69251 .43692 .7086 .44293 .70233 .45241 Mtetra
.672 .232 .197 r
.70233 .45241 .7086 .44293 .72507 .45199 .71909 .46422 Mtetra
.63 .211 .229 r
.71909 .46422 .72507 .45199 .74183 .46201 .73593 .47335 Mtetra
.51 .075 .15 r
.73593 .47335 .74183 .46201 .75866 .46958 .75254 .47577 Mtetra
.02 0 0 r
.75254 .47577 .75866 .46958 .77524 .47113 .76865 .4691 Mtetra
.864 .966 .863 r
.76865 .4691 .77524 .47113 .79132 .46458 .78415 .45387 Mtetra
.858 .772 .765 r
.78415 .45387 .79132 .46458 .80683 .45042 .79919 .43324 Mtetra
.812 .685 .724 r
.79919 .43324 .80683 .45042 .8219 .43147 .81406 .41137 Mtetra
.779 .649 .719 r
.81406 .41137 .8219 .43147 .83681 .41143 .82904 .39165 Mtetra
.753 .639 .735 r
.82904 .39165 .83681 .41143 .85186 .39332 .84435 .37574 Mtetra
.731 .647 .766 r
.84435 .37574 .85186 .39332 .86723 .3786 .86005 .3637 Mtetra
.711 .668 .806 r
.86005 .3637 .86723 .3786 .88299 .36734 .87611 .35466 Mtetra
.693 .694 .846 r
.87611 .35466 .88299 .36734 .89908 .35874 .89244 .34752 Mtetra
.679 .715 .876 r
.89244 .34752 .89908 .35874 .91545 .35184 .90897 .34141 Mtetra
.664 .741 .908 r
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Mtetra
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Mtetra
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Mtetra
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Mtetra
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Mtetra
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Mtetra
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Mtetra
.49724 .46116 .50523 .46972 .51973 .46509 .51179 .45649 Mtetra
.663 .741 .908 r
.51179 .45649 .51973 .46509 .53431 .46045 .52641 .4518 Mtetra
.52641 .4518 .53431 .46045 .54896 .45577 .54112 .4471 Mtetra
.662 .741 .909 r
.54112 .4471 .54896 .45577 .5637 .45109 .5559 .4424 Mtetra
.659 .741 .911 r
.5559 .4424 .5637 .45109 .57851 .44641 .57077 .4378 Mtetra
.651 .741 .916 r
.57077 .4378 .57851 .44641 .5934 .44182 .58572 .43349 Mtetra
.629 .742 .929 r
.58572 .43349 .5934 .44182 .60838 .43748 .60078 .42987 Mtetra
.574 .742 .956 r
.60078 .42987 .60838 .43748 .62347 .43378 .61597 .42769 Mtetra
.414 .718 .987 r
.61597 .42769 .62347 .43378 .63869 .43137 .63135 .42804 Mtetra
0 .492 .81 r
.63135 .42804 .63869 .43137 .65412 .43125 .647 .43212 Mtetra
.562 0 0 r
.647 .43212 .65412 .43125 .66982 .43449 .66301 .44065 Mtetra
.687 .214 .122 r
.66301 .44065 .66982 .43449 .68588 .44173 .67943 .45303 Mtetra
.689 .27 .245 r
.67943 .45303 .68588 .44173 .70233 .45241 .69617 .46674 Mtetra
.647 .246 .271 r
.69617 .46674 .70233 .45241 .71909 .46422 .71301 .47754 Mtetra
.537 .122 .202 r
.71301 .47754 .71909 .46422 .73593 .47335 .72964 .48089 Mtetra
.085 0 0 r
.72964 .48089 .73593 .47335 .75254 .47577 .74578 .47411 Mtetra
.878 .968 .847 r
.74578 .47411 .75254 .47577 .76865 .4691 .76129 .45777 Mtetra
.863 .763 .75 r
.76129 .45777 .76865 .4691 .78415 .45387 .77632 .43536 Mtetra
.814 .676 .711 r
.77632 .43536 .78415 .45387 .79919 .43324 .79115 .41156 Mtetra
.78 .64 .706 r
.79115 .41156 .79919 .43324 .81406 .41137 .80609 .39013 Mtetra
.754 .63 .723 r
.80609 .39013 .81406 .41137 .82904 .39165 .82135 .37295 Mtetra
.732 .638 .754 r
.82135 .37295 .82904 .39165 .84435 .37574 .83701 .36009 Mtetra
.713 .66 .797 r
.83701 .36009 .84435 .37574 .86005 .3637 .85302 .35057 Mtetra
.695 .688 .839 r
.85302 .35057 .86005 .3637 .87611 .35466 .86931 .34319 Mtetra
.68 .712 .872 r
.86931 .34319 .87611 .35466 .89244 .34752 .88581 .33696 Mtetra
.671 .728 .892 r
.88581 .33696 .89244 .34752 .90897 .34141 .90247 .33126 Mtetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Mtetra
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Mtetra
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Mtetra
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Mtetra
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Mtetra
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Mtetra
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Mtetra
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Mtetra
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Mtetra
.663 .741 .908 r
.48916 .45252 .49724 .46116 .51179 .45649 .50376 .44781 Mtetra
.50376 .44781 .51179 .45649 .52641 .4518 .51844 .44308 Mtetra
.662 .741 .909 r
.51844 .44308 .52641 .4518 .54112 .4471 .5332 .43837 Mtetra
.659 .741 .911 r
.5332 .43837 .54112 .4471 .5559 .4424 .54803 .43377 Mtetra
.65 .741 .917 r
.54803 .43377 .5559 .4424 .57077 .4378 .56296 .42947 Mtetra
.626 .742 .931 r
.56296 .42947 .57077 .4378 .58572 .43349 .57798 .42595 Mtetra
.562 .741 .96 r
.57798 .42595 .58572 .43349 .60078 .42987 .59313 .424 Mtetra
.371 .704 .985 r
.59313 .424 .60078 .42987 .61597 .42769 .60846 .42484 Mtetra
0 .403 .718 r
.60846 .42484 .61597 .42769 .63135 .42804 .62406 .42978 Mtetra
.622 .074 0 r
.62406 .42978 .63135 .42804 .647 .43212 .64 .43965 Mtetra
.708 .257 .179 r
.64 .43965 .647 .43212 .66301 .44065 .65636 .45382 Mtetra
.702 .3 .282 r
.65636 .45382 .66301 .44065 .67943 .45303 .67305 .46953 Mtetra
.66 .274 .304 r
.67305 .46953 .67943 .45303 .69617 .46674 .68988 .48208 Mtetra
.557 .159 .243 r
.68988 .48208 .69617 .46674 .71301 .47754 .70652 .48644 Mtetra
.137 0 0 r
.70652 .48644 .71301 .47754 .72964 .48089 .72268 .47956 Mtetra
.891 .967 .831 r
.72268 .47956 .72964 .48089 .74578 .47411 .73823 .46205 Mtetra
.866 .753 .736 r
.73823 .46205 .74578 .47411 .76129 .45777 .75327 .43779 Mtetra
.815 .666 .698 r
.75327 .43779 .76129 .45777 .77632 .43536 .76809 .41195 Mtetra
.781 .631 .695 r
.76809 .41195 .77632 .43536 .79115 .41156 .783 .38874 Mtetra
.755 .621 .711 r
.783 .38874 .79115 .41156 .80609 .39013 .79823 .37023 Mtetra
.734 .63 .743 r
.79823 .37023 .80609 .39013 .82135 .37295 .81384 .3565 Mtetra
.714 .653 .787 r
.81384 .3565 .82135 .37295 .83701 .36009 .82981 .34649 Mtetra
.697 .682 .832 r
.82981 .34649 .83701 .36009 .85302 .35057 .84608 .33885 Mtetra
.681 .709 .868 r
.84608 .33885 .85302 .35057 .86931 .34319 .86255 .33249 Mtetra
.672 .726 .89 r
.86255 .33249 .86931 .34319 .88581 .33696 .87917 .32672 Mtetra
.666 .735 .901 r
.87917 .32672 .88581 .33696 .90247 .33126 .89592 .32117 Mtetra
.664 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Mtetra
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Mtetra
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Mtetra
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Mtetra
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Mtetra
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Mtetra
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Mtetra
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Mtetra
.663 .741 .908 r
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .4438 Mtetra
.48101 .4438 .48916 .45252 .50376 .44781 .49566 .43905 Mtetra
.662 .741 .909 r
.49566 .43905 .50376 .44781 .51844 .44308 .51039 .43433 Mtetra
.658 .741 .911 r
.51039 .43433 .51844 .44308 .5332 .43837 .5252 .42971 Mtetra
.648 .741 .917 r
.5252 .42971 .5332 .43837 .54803 .43377 .54009 .42544 Mtetra
.622 .742 .933 r
.54009 .42544 .54803 .43377 .56296 .42947 .55507 .42201 Mtetra
.549 .739 .964 r
.55507 .42201 .56296 .42947 .57798 .42595 .57018 .4203 Mtetra
.322 .686 .979 r
.57018 .4203 .57798 .42595 .59313 .424 .58546 .42163 Mtetra
.287 0 0 r
.58546 .42163 .59313 .424 .60846 .42484 .60098 .42746 Mtetra
.664 .142 0 r
.60098 .42746 .60846 .42484 .62406 .42978 .61684 .43871 Mtetra
.723 .292 .224 r
.61684 .43871 .62406 .42978 .64 .43965 .63311 .45473 Mtetra
.712 .324 .312 r
.63311 .45473 .64 .43965 .65636 .45382 .64973 .47251 Mtetra
.67 .297 .33 r
.64973 .47251 .65636 .45382 .67305 .46953 .66652 .4869 Mtetra
.573 .189 .275 r
.66652 .4869 .67305 .46953 .68988 .48208 .68317 .49232 Mtetra
.178 0 0 r
.68317 .49232 .68988 .48208 .70652 .48644 .69936 .48537 Mtetra
.903 .965 .816 r
.69936 .48537 .70652 .48644 .72268 .47956 .71495 .46666 Mtetra
.868 .743 .723 r
.71495 .46666 .72268 .47956 .73823 .46205 .73003 .44048 Mtetra
.815 .657 .687 r
.73003 .44048 .73823 .46205 .75327 .43779 .74486 .41252 Mtetra
.781 .622 .684 r
.74486 .41252 .75327 .43779 .76809 .41195 .75977 .38745 Mtetra
.755 .613 .701 r
.75977 .38745 .76809 .41195 .783 .38874 .77497 .36756 Mtetra
.734 .621 .733 r
.77497 .36756 .783 .38874 .79823 .37023 .79055 .35293 Mtetra
.716 .645 .777 r
.79055 .35293 .79823 .37023 .81384 .3565 .8065 .3424 Mtetra
.698 .676 .825 r
.8065 .3424 .81384 .3565 .82981 .34649 .82273 .33449 Mtetra
.683 .705 .864 r
.82273 .33449 .82981 .34649 .84608 .33885 .83917 .328 Mtetra
.672 .724 .888 r
.83917 .328 .84608 .33885 .86255 .33249 .85577 .32216 Mtetra
.667 .734 .9 r
.85577 .32216 .86255 .33249 .87917 .32672 .87249 .31657 Mtetra
.665 .739 .905 r
.87249 .31657 .87917 .32672 .89592 .32117 .88931 .31105 Mtetra
.664 .741 .908 r
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Mtetra
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Mtetra
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Mtetra
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Mtetra
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Mtetra
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Mtetra
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Mtetra
.663 .741 .908 r
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43977 Mtetra
.45815 .43977 .46644 .44853 .48101 .4438 .47277 .435 Mtetra
.662 .741 .909 r
.47277 .435 .48101 .4438 .49566 .43905 .48747 .43026 Mtetra
.658 .741 .911 r
.48747 .43026 .49566 .43905 .51039 .43433 .50225 .42564 Mtetra
.647 .741 .918 r
.50225 .42564 .51039 .43433 .5252 .42971 .51711 .4214 Mtetra
.618 .742 .935 r
.51711 .4214 .5252 .42971 .54009 .42544 .53206 .41805 Mtetra
.536 .737 .968 r
.53206 .41805 .54009 .42544 .55507 .42201 .54712 .41658 Mtetra
.267 .664 .968 r
.54712 .41658 .55507 .42201 .57018 .4203 .56233 .41841 Mtetra
.385 0 0 r
.56233 .41841 .57018 .4203 .58546 .42163 .57777 .42515 Mtetra
.695 .195 .05 r
.57777 .42515 .58546 .42163 .60098 .42746 .59353 .4378 Mtetra
.735 .319 .26 r
.59353 .4378 .60098 .42746 .61684 .43871 .60968 .45571 Mtetra
.72 .344 .336 r
.60968 .45571 .61684 .43871 .63311 .45473 .6262 .47562 Mtetra
.679 .316 .351 r
.6262 .47562 .63311 .45473 .64973 .47251 .64293 .49192 Mtetra
.587 .213 .301 r
.64293 .49192 .64973 .47251 .66652 .4869 .65956 .49845 Mtetra
.211 0 0 r
.65956 .49845 .66652 .4869 .68317 .49232 .67579 .49144 Mtetra
.914 .96 .803 r
.67579 .49144 .68317 .49232 .69936 .48537 .69144 .47151 Mtetra
.868 .733 .711 r
.69144 .47151 .69936 .48537 .71495 .46666 .70658 .44335 Mtetra
.814 .649 .677 r
.70658 .44335 .71495 .46666 .73003 .44048 .72146 .41323 Mtetra
.78 .614 .674 r
.72146 .41323 .73003 .44048 .74486 .41252 .73638 .38625 Mtetra
.755 .605 .691 r
.73638 .38625 .74486 .41252 .75977 .38745 .75158 .36492 Mtetra
.735 .613 .723 r
.75158 .36492 .75977 .38745 .77497 .36756 .76714 .34937 Mtetra
.717 .638 .768 r
.76714 .34937 .77497 .36756 .79055 .35293 .78306 .3383 Mtetra
.7 .671 .818 r
.78306 .3383 .79055 .35293 .8065 .3424 .79926 .33011 Mtetra
.684 .701 .86 r
.79926 .33011 .8065 .3424 .82273 .33449 .81568 .32349 Mtetra
.673 .722 .886 r
.81568 .32349 .82273 .33449 .83917 .328 .83225 .31758 Mtetra
.667 .734 .9 r
.83225 .31758 .83917 .328 .85577 .32216 .84894 .31195 Mtetra
.665 .739 .905 r
.84894 .31195 .85577 .32216 .87249 .31657 .86574 .3064 Mtetra
.664 .74 .907 r
.86574 .3064 .87249 .31657 .88931 .31105 .88264 .30086 Mtetra
.664 .741 .908 r
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Mtetra
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Mtetra
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Mtetra
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Mtetra
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Mtetra
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Mtetra
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Mtetra
.663 .741 .908 r
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Mtetra
.43519 .43572 .44361 .44452 .45815 .43977 .44978 .43094 Mtetra
.662 .741 .909 r
.44978 .43094 .45815 .43977 .47277 .435 .46446 .42618 Mtetra
.657 .741 .912 r
.46446 .42618 .47277 .435 .48747 .43026 .4792 .42155 Mtetra
.646 .741 .919 r
.4792 .42155 .48747 .43026 .50225 .42564 .49403 .41733 Mtetra
.614 .742 .937 r
.49403 .41733 .50225 .42564 .51711 .4214 .50894 .41408 Mtetra
.522 .735 .971 r
.50894 .41408 .51711 .4214 .53206 .41805 .52395 .41284 Mtetra
.208 .636 .951 r
.52395 .41284 .53206 .41805 .54712 .41658 .53908 .41517 Mtetra
.467 0 0 r
.53908 .41517 .54712 .41658 .56233 .41841 .55442 .4228 Mtetra
.717 .237 .107 r
.55442 .4228 .56233 .41841 .57777 .42515 .57005 .43687 Mtetra
.744 .342 .289 r
.57005 .43687 .57777 .42515 .59353 .4378 .58606 .45669 Mtetra
.726 .36 .355 r
.58606 .45669 .59353 .4378 .60968 .45571 .60245 .47877 Mtetra
.686 .331 .368 r
.60245 .47877 .60968 .45571 .6262 .47562 .61909 .49702 Mtetra
.598 .233 .321 r
.61909 .49702 .6262 .47562 .64293 .49192 .6357 .50472 Mtetra
.237 0 .027 r
.6357 .50472 .64293 .49192 .65956 .49845 .65196 .49767 Mtetra
.923 .953 .791 r
.65196 .49767 .65956 .49845 .67579 .49144 .66769 .47651 Mtetra
.867 .722 .7 r
.66769 .47651 .67579 .49144 .69144 .47151 .68291 .44635 Mtetra
.813 .64 .668 r
.68291 .44635 .69144 .47151 .70658 .44335 .69787 .41401 Mtetra
.779 .607 .666 r
.69787 .41401 .70658 .44335 .72146 .41323 .71284 .38508 Mtetra
.755 .597 .682 r
.71284 .38508 .72146 .41323 .73638 .38625 .72805 .36231 Mtetra
.735 .606 .713 r
.72805 .36231 .73638 .38625 .75158 .36492 .74361 .34581 Mtetra
.718 .63 .759 r
.74361 .34581 .75158 .36492 .76714 .34937 .7595 .3342 Mtetra
.701 .665 .811 r
.7595 .3342 .76714 .34937 .78306 .3383 .77568 .32572 Mtetra
.685 .698 .856 r
.77568 .32572 .78306 .3383 .79926 .33011 .79207 .31895 Mtetra
.674 .721 .884 r
.79207 .31895 .79926 .33011 .81568 .32349 .80861 .31298 Mtetra
.667 .733 .899 r
.80861 .31298 .81568 .32349 .83225 .31758 .82528 .30731 Mtetra
.665 .738 .905 r
.82528 .30731 .83225 .31758 .84894 .31195 .84205 .30173 Mtetra
.664 .74 .907 r
.84205 .30173 .84894 .31195 .86574 .3064 .85892 .29615 Mtetra
.664 .741 .908 r
.85892 .29615 .86574 .3064 .88264 .30086 .87589 .29056 Mtetra
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Mtetra
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Mtetra
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Mtetra
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Mtetra
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Mtetra
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Mtetra
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43646 Mtetra
.663 .741 .908 r
.39764 .43646 .40624 .44525 .42068 .4405 .41213 .43166 Mtetra
.41213 .43166 .42068 .4405 .43519 .43572 .42669 .42685 Mtetra
.662 .741 .909 r
.42669 .42685 .43519 .43572 .44978 .43094 .44133 .42207 Mtetra
.657 .741 .912 r
.44133 .42207 .44978 .43094 .46446 .42618 .45605 .41744 Mtetra
.644 .741 .92 r
.45605 .41744 .46446 .42618 .4792 .42155 .47084 .41324 Mtetra
.61 .742 .939 r
.47084 .41324 .4792 .42155 .49403 .41733 .48571 .41008 Mtetra
.507 .732 .975 r
.48571 .41008 .49403 .41733 .50894 .41408 .50066 .40907 Mtetra
.146 .604 .928 r
.50066 .40907 .50894 .41408 .52395 .41284 .51571 .41189 Mtetra
.533 0 0 r
.51571 .41189 .52395 .41284 .53908 .41517 .53094 .42041 Mtetra
.733 .271 .152 r
.53094 .42041 .53908 .41517 .55442 .4228 .54642 .43589 Mtetra
.751 .36 .312 r
.54642 .43589 .55442 .4228 .57005 .43687 .56226 .45761 Mtetra
.732 .373 .371 r
.56226 .45761 .57005 .43687 .58606 .45669 .57848 .48187 Mtetra
.692 .344 .382 r
.57848 .48187 .58606 .45669 .60245 .47877 .595 .5021 Mtetra
.607 .25 .338 r
.595 .5021 .60245 .47877 .61909 .49702 .61156 .51098 Mtetra
.256 0 .057 r
.61156 .51098 .61909 .49702 .6357 .50472 .62786 .50392 Mtetra
.931 .944 .78 r
.62786 .50392 .6357 .50472 .65196 .49767 .64368 .48155 Mtetra
.865 .712 .69 r
.64368 .48155 .65196 .49767 .66769 .47651 .65903 .44937 Mtetra
.812 .632 .659 r
.65903 .44937 .66769 .47651 .68291 .44635 .67409 .41482 Mtetra
.778 .6 .658 r
.67409 .41482 .68291 .44635 .69787 .41401 .68913 .38393 Mtetra
.754 .59 .673 r
.68913 .38393 .69787 .41401 .71284 .38508 .70438 .35969 Mtetra
.735 .598 .705 r
.70438 .35969 .71284 .38508 .72805 .36231 .71994 .34224 Mtetra
.718 .623 .751 r
.71994 .34224 .72805 .36231 .74361 .34581 .73583 .33007 Mtetra
.702 .659 .804 r
.73583 .33007 .74361 .34581 .7595 .3342 .75199 .32131 Mtetra
.686 .694 .852 r
.75199 .32131 .7595 .3342 .77568 .32572 .76835 .3144 Mtetra
.674 .719 .882 r
.76835 .3144 .77568 .32572 .79207 .31895 .78486 .30835 Mtetra
.668 .732 .898 r
.78486 .30835 .79207 .31895 .80861 .31298 .8015 .30264 Mtetra
.665 .738 .905 r
.8015 .30264 .80861 .31298 .82528 .30731 .81824 .29703 Mtetra
.664 .74 .907 r
.81824 .29703 .82528 .30731 .84205 .30173 .83509 .29143 Mtetra
.664 .741 .908 r
.83509 .29143 .84205 .30173 .85892 .29615 .85203 .2858 Mtetra
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Mtetra
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Mtetra
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Mtetra
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Mtetra
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Mtetra
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Mtetra
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Mtetra
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Mtetra
.663 .741 .908 r
.3745 .43239 .38323 .44123 .39764 .43646 .38895 .42757 Mtetra
.38895 .42757 .39764 .43646 .41213 .43166 .40349 .42275 Mtetra
.661 .741 .909 r
.40349 .42275 .41213 .43166 .42669 .42685 .4181 .41795 Mtetra
.657 .741 .912 r
.4181 .41795 .42669 .42685 .44133 .42207 .43279 .41331 Mtetra
.643 .741 .92 r
.43279 .41331 .44133 .42207 .45605 .41744 .44754 .40912 Mtetra
.606 .741 .941 r
.44754 .40912 .45605 .41744 .47084 .41324 .46237 .40605 Mtetra
.492 .729 .977 r
.46237 .40605 .47084 .41324 .48571 .41008 .47725 .40527 Mtetra
.082 .569 .9 r
.47725 .40527 .48571 .41008 .50066 .40907 .49222 .40856 Mtetra
.584 .011 0 r
.49222 .40856 .50066 .40907 .51571 .41189 .50732 .41795 Mtetra
.746 .298 .188 r
.50732 .41795 .51571 .41189 .53094 .42041 .52263 .43479 Mtetra
.756 .374 .331 r
.52263 .43479 .53094 .42041 .54642 .43589 .53826 .45839 Mtetra
.736 .384 .384 r
.53826 .45839 .54642 .43589 .56226 .45761 .55429 .48481 Mtetra
.697 .355 .393 r
.55429 .48481 .56226 .45761 .57848 .48187 .57065 .50702 Mtetra
.615 .263 .351 r
.57065 .50702 .57848 .48187 .595 .5021 .58714 .51712 Mtetra
.272 0 .08 r
.58714 .51712 .595 .5021 .61156 .51098 .60348 .51007 Mtetra
.937 .933 .771 r
.60348 .51007 .61156 .51098 .62786 .50392 .61942 .4865 Mtetra
.863 .702 .681 r
.61942 .4865 .62786 .50392 .64368 .48155 .63491 .45234 Mtetra
.81 .625 .652 r
.63491 .45234 .64368 .48155 .65903 .44937 .65011 .41558 Mtetra
.777 .593 .651 r
.65011 .41558 .65903 .44937 .67409 .41482 .66526 .38275 Mtetra
.753 .583 .666 r
.66526 .38275 .67409 .41482 .68913 .38393 .68056 .35705 Mtetra
.734 .592 .697 r
.68056 .35705 .68913 .38393 .70438 .35969 .69615 .33864 Mtetra
.718 .617 .743 r
.69615 .33864 .70438 .35969 .71994 .34224 .71203 .32593 Mtetra
.703 .653 .798 r
.71203 .32593 .71994 .34224 .73583 .33007 .72817 .31688 Mtetra
.687 .69 .847 r
.72817 .31688 .73583 .33007 .75199 .32131 .74451 .30983 Mtetra
.675 .717 .88 r
.74451 .30983 .75199 .32131 .76835 .3144 .76099 .3037 Mtetra
.668 .731 .897 r
.76099 .3037 .76835 .3144 .78486 .30835 .7776 .29795 Mtetra
.665 .738 .904 r
.7776 .29795 .78486 .30835 .8015 .30264 .79432 .2923 Mtetra
.664 .74 .907 r
.79432 .2923 .8015 .30264 .81824 .29703 .81113 .28667 Mtetra
.664 .741 .908 r
.81113 .28667 .81824 .29703 .83509 .29143 .82805 .28102 Mtetra
.82805 .28102 .83509 .29143 .85203 .2858 .84507 .27534 Mtetra
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Mtetra
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Mtetra
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Mtetra
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Mtetra
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Mtetra
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Mtetra
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Mtetra
.663 .741 .908 r
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42347 Mtetra
.36568 .42347 .3745 .43239 .38895 .42757 .38018 .41862 Mtetra
.661 .741 .909 r
.38018 .41862 .38895 .42757 .40349 .42275 .39476 .41381 Mtetra
.656 .741 .912 r
.39476 .41381 .40349 .42275 .4181 .41795 .40942 .40916 Mtetra
.642 .741 .921 r
.40942 .40916 .4181 .41795 .43279 .41331 .42414 .40499 Mtetra
.602 .741 .943 r
.42414 .40499 .43279 .41331 .44754 .40912 .43891 .40199 Mtetra
.477 .726 .98 r
.43891 .40199 .44754 .40912 .46237 .40605 .45374 .40142 Mtetra
.02 .53 .867 r
.45374 .40142 .46237 .40605 .47725 .40527 .46861 .40517 Mtetra
.623 .064 0 r
.46861 .40517 .47725 .40527 .49222 .40856 .48356 .41539 Mtetra
.755 .32 .218 r
.48356 .41539 .49222 .40856 .50732 .41795 .49868 .43355 Mtetra
.76 .387 .347 r
.49868 .43355 .50732 .41795 .52263 .43479 .51408 .45897 Mtetra
.74 .394 .395 r
.51408 .45897 .52263 .43479 .53826 .45839 .52986 .4875 Mtetra
.702 .364 .402 r
.52986 .4875 .53826 .45839 .55429 .48481 .54604 .51165 Mtetra
.622 .275 .362 r
.54604 .51165 .55429 .48481 .57065 .50702 .56245 .52296 Mtetra
.283 0 .096 r
.56245 .52296 .57065 .50702 .58714 .51712 .57881 .51596 Mtetra
.941 .922 .764 r
.57881 .51596 .58714 .51712 .60348 .51007 .59489 .49125 Mtetra
.86 .692 .673 r
.59489 .49125 .60348 .51007 .61942 .4865 .61056 .45515 Mtetra
.807 .618 .646 r
.61056 .45515 .61942 .4865 .63491 .45234 .62594 .41623 Mtetra
.775 .587 .644 r
.62594 .41623 .63491 .45234 .65011 .41558 .64122 .38148 Mtetra
.752 .577 .659 r
.64122 .38148 .65011 .41558 .66526 .38275 .65661 .35436 Mtetra
.734 .585 .689 r
.65661 .35436 .66526 .38275 .68056 .35705 .67223 .33502 Mtetra
.718 .61 .735 r
.67223 .33502 .68056 .35705 .69615 .33864 .68811 .32176 Mtetra
.703 .648 .791 r
.68811 .32176 .69615 .33864 .71203 .32593 .70424 .31242 Mtetra
.688 .686 .843 r
.70424 .31242 .71203 .32593 .72817 .31688 .72055 .30523 Mtetra
.675 .715 .878 r
.72055 .30523 .72817 .31688 .74451 .30983 .73701 .29903 Mtetra
.668 .73 .896 r
.73701 .29903 .74451 .30983 .76099 .3037 .75359 .29324 Mtetra
.665 .737 .904 r
.75359 .29324 .76099 .3037 .7776 .29795 .77028 .28756 Mtetra
.664 .74 .907 r
.77028 .28756 .7776 .29795 .79432 .2923 .78706 .2819 Mtetra
.664 .741 .908 r
.78706 .2819 .79432 .2923 .81113 .28667 .80395 .27622 Mtetra
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Mtetra
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Mtetra
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Mtetra
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Mtetra
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Mtetra
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Mtetra
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42906 Mtetra
.31358 .42906 .32263 .43793 .3369 .43313 .3279 .42421 Mtetra
.663 .741 .908 r
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41935 Mtetra
.34229 .41935 .35125 .42831 .36568 .42347 .35677 .41448 Mtetra
.661 .741 .909 r
.35677 .41448 .36568 .42347 .38018 .41862 .37132 .40965 Mtetra
.656 .741 .913 r
.37132 .40965 .38018 .41862 .39476 .41381 .38594 .40499 Mtetra
.641 .741 .922 r
.38594 .40499 .39476 .41381 .40942 .40916 .40062 .40083 Mtetra
.598 .741 .944 r
.40062 .40083 .40942 .40916 .42414 .40499 .41535 .39791 Mtetra
.462 .722 .981 r
.41535 .39791 .42414 .40499 .43891 .40199 .4301 .39753 Mtetra
0 .491 .831 r
.4301 .39753 .43891 .40199 .45374 .40142 .44487 .4017 Mtetra
.653 .108 0 r
.44487 .4017 .45374 .40142 .46861 .40517 .45967 .4127 Mtetra
.763 .338 .242 r
.45967 .4127 .46861 .40517 .48356 .41539 .47457 .43211 Mtetra
.764 .397 .36 r
.47457 .43211 .48356 .41539 .49868 .43355 .48971 .45926 Mtetra
.743 .401 .403 r
.48971 .45926 .49868 .43355 .51408 .45897 .50522 .48981 Mtetra
.706 .372 .41 r
.50522 .48981 .51408 .45897 .52986 .4875 .52118 .51586 Mtetra
.628 .285 .37 r
.52118 .51586 .52986 .4875 .54604 .51165 .53747 .52836 Mtetra
.291 0 .107 r
.53747 .52836 .54604 .51165 .56245 .52296 .55387 .52143 Mtetra
.943 .908 .757 r
.55387 .52143 .56245 .52296 .57881 .51596 .57009 .49564 Mtetra
.856 .683 .666 r
.57009 .49564 .57881 .51596 .59489 .49125 .58598 .45768 Mtetra
.805 .611 .64 r
.58598 .45768 .59489 .49125 .61056 .45515 .60156 .41669 Mtetra
.773 .581 .639 r
.60156 .41669 .61056 .45515 .62594 .41623 .61701 .3801 Mtetra
.751 .572 .653 r
.61701 .3801 .62594 .41623 .64122 .38148 .6325 .35159 Mtetra
.733 .579 .683 r
.6325 .35159 .64122 .38148 .65661 .35436 .64817 .33134 Mtetra
.718 .604 .728 r
.64817 .33134 .65661 .35436 .67223 .33502 .66407 .31756 Mtetra
.704 .642 .785 r
.66407 .31756 .67223 .33502 .68811 .32176 .68018 .30794 Mtetra
.689 .683 .839 r
.68018 .30794 .68811 .32176 .70424 .31242 .69647 .30061 Mtetra
.676 .713 .876 r
.69647 .30061 .70424 .31242 .72055 .30523 .71291 .29434 Mtetra
.668 .73 .895 r
.71291 .29434 .72055 .30523 .73701 .29903 .72946 .2885 Mtetra
.665 .737 .904 r
.72946 .2885 .73701 .29903 .75359 .29324 .74612 .28279 Mtetra
.664 .74 .907 r
.74612 .28279 .75359 .29324 .77028 .28756 .76287 .2771 Mtetra
.664 .741 .908 r
.76287 .2771 .77028 .28756 .78706 .2819 .77973 .27139 Mtetra
.77973 .27139 .78706 .2819 .80395 .27622 .79669 .26566 Mtetra
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Mtetra
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Mtetra
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Mtetra
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Mtetra
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Mtetra
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Mtetra
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Mtetra
.29015 .42496 .29934 .43387 .31358 .42906 .30444 .4201 Mtetra
.663 .741 .908 r
.30444 .4201 .31358 .42906 .3279 .42421 .3188 .41521 Mtetra
.3188 .41521 .3279 .42421 .34229 .41935 .33324 .41032 Mtetra
.661 .741 .909 r
.33324 .41032 .34229 .41935 .35677 .41448 .34776 .40547 Mtetra
.656 .741 .913 r
.34776 .40547 .35677 .41448 .37132 .40965 .36235 .40079 Mtetra
.64 .741 .922 r
.36235 .40079 .37132 .40965 .38594 .40499 .37699 .39665 Mtetra
.595 .741 .946 r
.37699 .39665 .38594 .40499 .40062 .40083 .39168 .39378 Mtetra
.448 .719 .982 r
.39168 .39378 .40062 .40083 .41535 .39791 .40636 .39359 Mtetra
0 .452 .793 r
.40636 .39359 .41535 .39791 .4301 .39753 .42101 .39814 Mtetra
.676 .144 0 r
.42101 .39814 .4301 .39753 .44487 .4017 .43564 .40985 Mtetra
.768 .352 .261 r
.43564 .40985 .44487 .4017 .45967 .4127 .45031 .43042 Mtetra
.767 .405 .37 r
.45031 .43042 .45967 .4127 .47457 .43211 .46516 .45919 Mtetra
.746 .408 .41 r
.46516 .45919 .47457 .43211 .48971 .45926 .48037 .49165 Mtetra
.71 .379 .416 r
.48037 .49165 .48971 .45926 .50522 .48981 .49607 .5195 Mtetra
.634 .293 .377 r
.49607 .5195 .50522 .48981 .52118 .51586 .51223 .53316 Mtetra
.297 0 .113 r
.51223 .53316 .52118 .51586 .53747 .52836 .52866 .52633 Mtetra
.942 .894 .752 r
.52866 .52633 .53747 .52836 .55387 .52143 .54504 .49953 Mtetra
.852 .674 .66 r
.54504 .49953 .55387 .52143 .57009 .49564 .56117 .45984 Mtetra
.802 .605 .635 r
.56117 .45984 .57009 .49564 .58598 .45768 .57699 .41688 Mtetra
.772 .576 .634 r
.57699 .41688 .58598 .45768 .60156 .41669 .59263 .37855 Mtetra
.749 .566 .648 r
.59263 .37855 .60156 .41669 .61701 .3801 .60825 .34871 Mtetra
.732 .574 .677 r
.60825 .34871 .61701 .3801 .6325 .35159 .62398 .3276 Mtetra
.718 .599 .722 r
.62398 .3276 .6325 .35159 .64817 .33134 .6399 .31331 Mtetra
.704 .637 .78 r
.6399 .31331 .64817 .33134 .66407 .31756 .65601 .30343 Mtetra
.689 .679 .835 r
.65601 .30343 .66407 .31756 .68018 .30794 .67228 .29596 Mtetra
.676 .711 .874 r
.67228 .29596 .68018 .30794 .69647 .30061 .68868 .28962 Mtetra
.669 .729 .895 r
.68868 .28962 .69647 .30061 .71291 .29434 .70521 .28374 Mtetra
.665 .737 .903 r
.70521 .28374 .71291 .29434 .72946 .2885 .72184 .278 Mtetra
.664 .74 .907 r
.72184 .278 .72946 .2885 .74612 .28279 .73857 .27228 Mtetra
.664 .741 .908 r
.73857 .27228 .74612 .28279 .76287 .2771 .75539 .26654 Mtetra
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Mtetra
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Mtetra
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Mtetra
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Mtetra
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Mtetra
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Mtetra
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Mtetra
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Mtetra
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Mtetra
.663 .741 .908 r
.28087 .41596 .29015 .42496 .30444 .4201 .2952 .41105 Mtetra
.2952 .41105 .30444 .4201 .3188 .41521 .30961 .40614 Mtetra
.661 .741 .909 r
.30961 .40614 .3188 .41521 .33324 .41032 .3241 .40126 Mtetra
.655 .741 .913 r
.3241 .40126 .33324 .41032 .34776 .40547 .33865 .39658 Mtetra
.639 .741 .923 r
.33865 .39658 .34776 .40547 .36235 .40079 .35326 .39244 Mtetra
.592 .74 .947 r
.35326 .39244 .36235 .40079 .37699 .39665 .36789 .38963 Mtetra
.435 .715 .983 r
.36789 .38963 .37699 .39665 .39168 .39378 .3825 .38958 Mtetra
0 .416 .757 r
.3825 .38958 .39168 .39378 .40636 .39359 .39703 .39447 Mtetra
.694 .172 0 r
.39703 .39447 .40636 .39359 .42101 .39814 .41149 .40682 Mtetra
.773 .364 .277 r
.41149 .40682 .42101 .39814 .43564 .40985 .4259 .42844 Mtetra
.77 .413 .378 r
.4259 .42844 .43564 .40985 .45031 .43042 .44044 .45868 Mtetra
.749 .414 .416 r
.44044 .45868 .45031 .43042 .46516 .45919 .45531 .49291 Mtetra
.713 .385 .421 r
.45531 .49291 .46516 .45919 .48037 .49165 .47073 .52243 Mtetra
.639 .3 .382 r
.47073 .52243 .48037 .49165 .49607 .5195 .48674 .53719 Mtetra
.299 0 .114 r
.48674 .53719 .49607 .5195 .51223 .53316 .50318 .53049 Mtetra
.94 .879 .747 r
.50318 .53049 .51223 .53316 .52866 .52633 .51974 .5028 Mtetra
.848 .665 .655 r
.51974 .5028 .52866 .52633 .54504 .49953 .53612 .4615 Mtetra
.799 .599 .631 r
.53612 .4615 .54504 .49953 .56117 .45984 .55222 .41674 Mtetra
.77 .571 .63 r
.55222 .41674 .56117 .45984 .57699 .41688 .56808 .37677 Mtetra
.748 .562 .643 r
.56808 .37677 .57699 .41688 .59263 .37855 .58384 .34571 Mtetra
.731 .569 .671 r
.58384 .34571 .59263 .37855 .60825 .34871 .59966 .32379 Mtetra
.717 .593 .716 r
.59966 .32379 .60825 .34871 .62398 .3276 .61561 .30902 Mtetra
.704 .633 .775 r
.61561 .30902 .62398 .3276 .6399 .31331 .63171 .29888 Mtetra
.69 .676 .832 r
.63171 .29888 .6399 .31331 .65601 .30343 .64796 .29129 Mtetra
.677 .709 .872 r
.64796 .29129 .65601 .30343 .67228 .29596 .66434 .28488 Mtetra
.669 .728 .894 r
.66434 .28488 .67228 .29596 .68868 .28962 .68084 .27895 Mtetra
.665 .737 .903 r
.68084 .27895 .68868 .28962 .70521 .28374 .69744 .27318 Mtetra
.664 .74 .906 r
.69744 .27318 .70521 .28374 .72184 .278 .71413 .26743 Mtetra
.664 .741 .908 r
.71413 .26743 .72184 .278 .73857 .27228 .73093 .26167 Mtetra
.73093 .26167 .73857 .27228 .75539 .26654 .74783 .25587 Mtetra
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Mtetra
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Mtetra
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Mtetra
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Mtetra
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Mtetra
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Mtetra
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Mtetra
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Mtetra
.663 .741 .908 r
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40687 Mtetra
.27149 .40687 .28087 .41596 .2952 .41105 .28587 .40194 Mtetra
.661 .741 .909 r
.28587 .40194 .2952 .41105 .30961 .40614 .30032 .39704 Mtetra
.655 .741 .913 r
.30032 .39704 .30961 .40614 .3241 .40126 .31484 .39234 Mtetra
.638 .741 .923 r
.31484 .39234 .3241 .40126 .33865 .39658 .32941 .3882 Mtetra
.589 .74 .948 r
.32941 .3882 .33865 .39658 .35326 .39244 .34399 .38543 Mtetra
.423 .712 .984 r
.34399 .38543 .35326 .39244 .36789 .38963 .35852 .38551 Mtetra
0 .383 .724 r
.35852 .38551 .36789 .38963 .3825 .38958 .37294 .39069 Mtetra
.707 .195 .007 r
.37294 .39069 .3825 .38958 .39703 .39447 .3872 .4036 Mtetra
.777 .374 .289 r
.3872 .4036 .39703 .39447 .41149 .40682 .40135 .42613 Mtetra
.772 .418 .385 r
.40135 .42613 .41149 .40682 .4259 .42844 .41555 .45767 Mtetra
.751 .419 .421 r
.41555 .45767 .4259 .42844 .44044 .45868 .43006 .49347 Mtetra
.716 .39 .424 r
.43006 .49347 .44044 .45868 .45531 .49291 .44517 .52452 Mtetra
.643 .306 .385 r
.44517 .52452 .45531 .49291 .47073 .52243 .461 .5403 Mtetra
.299 0 .11 r
.461 .5403 .47073 .52243 .48674 .53719 .47746 .53376 Mtetra
.936 .864 .743 r
.47746 .53376 .48674 .53719 .50318 .53049 .4942 .50529 Mtetra
.843 .657 .651 r
.4942 .50529 .50318 .53049 .51974 .5028 .51087 .46257 Mtetra
.797 .594 .627 r
.51087 .46257 .51974 .5028 .53612 .4615 .52726 .41617 Mtetra
.768 .566 .626 r
.52726 .41617 .53612 .4615 .55222 .41674 .54336 .37474 Mtetra
.746 .557 .639 r
.54336 .37474 .55222 .41674 .56808 .37677 .5593 .34255 Mtetra
.73 .564 .667 r
.5593 .34255 .56808 .37677 .58384 .34571 .5752 .31989 Mtetra
.717 .589 .711 r
.5752 .31989 .58384 .34571 .59966 .32379 .59119 .30468 Mtetra
.704 .629 .77 r
.59119 .30468 .59966 .32379 .61561 .30902 .60729 .29431 Mtetra
.69 .673 .829 r
.60729 .29431 .61561 .30902 .63171 .29888 .62352 .28658 Mtetra
.677 .708 .871 r
.62352 .28658 .63171 .29888 .64796 .29129 .63988 .28011 Mtetra
.669 .727 .893 r
.63988 .28011 .64796 .29129 .66434 .28488 .65634 .27415 Mtetra
.665 .736 .903 r
.65634 .27415 .66434 .28488 .68084 .27895 .67291 .26834 Mtetra
.664 .74 .906 r
.67291 .26834 .68084 .27895 .69744 .27318 .68958 .26256 Mtetra
.664 .741 .907 r
.68958 .26256 .69744 .27318 .71413 .26743 .70635 .25677 Mtetra
.664 .741 .908 r
.70635 .25677 .71413 .26743 .73093 .26167 .72322 .25095 Mtetra
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Mtetra
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Mtetra
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Mtetra
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Mtetra
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Mtetra
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Mtetra
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Mtetra
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40763 Mtetra
.663 .741 .908 r
.2334 .40763 .24296 .41671 .25719 .4118 .24767 .40267 Mtetra
.24767 .40267 .25719 .4118 .27149 .40687 .26202 .39771 Mtetra
.661 .741 .909 r
.26202 .39771 .27149 .40687 .28587 .40194 .27644 .3928 Mtetra
.655 .741 .913 r
.27644 .3928 .28587 .40194 .30032 .39704 .29092 .38808 Mtetra
.638 .741 .924 r
.29092 .38808 .30032 .39704 .31484 .39234 .30545 .38394 Mtetra
.587 .74 .949 r
.30545 .38394 .31484 .39234 .32941 .3882 .31998 .38119 Mtetra
.413 .708 .984 r
.31998 .38119 .32941 .3882 .34399 .38543 .33443 .38137 Mtetra
0 .356 .695 r
.33443 .38137 .34399 .38543 .35852 .38551 .34872 .38678 Mtetra
.717 .212 .03 r
.34872 .38678 .35852 .38551 .37294 .39069 .3628 .40015 Mtetra
.78 .381 .299 r
.3628 .40015 .37294 .39069 .3872 .4036 .37667 .42345 Mtetra
.774 .423 .39 r
.37667 .42345 .3872 .4036 .40135 .42613 .39052 .4561 Mtetra
.754 .423 .424 r
.39052 .4561 .40135 .42613 .41555 .45767 .40464 .49325 Mtetra
.719 .394 .427 r
.40464 .49325 .41555 .45767 .43006 .49347 .41941 .52564 Mtetra
.648 .311 .388 r
.41941 .52564 .43006 .49347 .44517 .52452 .43505 .54235 Mtetra
.297 0 .101 r
.43505 .54235 .44517 .52452 .461 .5403 .45151 .53599 Mtetra
.931 .848 .739 r
.45151 .53599 .461 .5403 .47746 .53376 .46843 .50688 Mtetra
.839 .65 .647 r
.46843 .50688 .47746 .53376 .4942 .50529 .4854 .46294 Mtetra
.794 .589 .624 r
.4854 .46294 .4942 .50529 .51087 .46257 .50211 .41512 Mtetra
.766 .562 .623 r
.50211 .41512 .51087 .46257 .52726 .41617 .51848 .37239 Mtetra
.745 .553 .636 r
.51848 .37239 .52726 .41617 .54336 .37474 .5346 .33921 Mtetra
.729 .56 .663 r
.5346 .33921 .54336 .37474 .5593 .34255 .55061 .31588 Mtetra
.716 .584 .707 r
.55061 .31588 .5593 .34255 .5752 .31989 .56664 .30028 Mtetra
.704 .625 .766 r
.56664 .30028 .5752 .31989 .59119 .30468 .58275 .28969 Mtetra
.69 .67 .826 r
.58275 .28969 .59119 .30468 .60729 .29431 .59897 .28185 Mtetra
.678 .706 .869 r
.59897 .28185 .60729 .29431 .62352 .28658 .6153 .27532 Mtetra
.669 .727 .893 r
.6153 .27532 .62352 .28658 .63988 .28011 .63173 .26931 Mtetra
.665 .736 .903 r
.63173 .26931 .63988 .28011 .65634 .27415 .64827 .26348 Mtetra
.664 .74 .906 r
.64827 .26348 .65634 .27415 .67291 .26834 .66491 .25767 Mtetra
.664 .741 .907 r
.66491 .25767 .67291 .26834 .68958 .26256 .68164 .25185 Mtetra
.664 .741 .908 r
.68164 .25185 .68958 .26256 .70635 .25677 .69848 .24599 Mtetra
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Mtetra
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Mtetra
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Mtetra
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Mtetra
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Mtetra
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Mtetra
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Mtetra
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Mtetra
.663 .741 .908 r
.2095 .40343 .21921 .41256 .2334 .40763 .22374 .39846 Mtetra
.22374 .39846 .2334 .40763 .24767 .40267 .23805 .39347 Mtetra
.661 .741 .91 r
.23805 .39347 .24767 .40267 .26202 .39771 .25244 .38854 Mtetra
.655 .741 .913 r
.25244 .38854 .26202 .39771 .27644 .3928 .26689 .3838 Mtetra
.637 .741 .924 r
.26689 .3838 .27644 .3928 .29092 .38808 .28138 .37964 Mtetra
.585 .74 .95 r
.28138 .37964 .29092 .38808 .30545 .38394 .29585 .37691 Mtetra
.405 .706 .984 r
.29585 .37691 .30545 .38394 .31998 .38119 .31022 .37716 Mtetra
0 .334 .673 r
.31022 .37716 .31998 .38119 .33443 .38137 .32439 .38274 Mtetra
.725 .225 .047 r
.32439 .38274 .33443 .38137 .34872 .38678 .33827 .39646 Mtetra
.782 .387 .306 r
.33827 .39646 .34872 .38678 .3628 .40015 .35187 .42036 Mtetra
.776 .427 .394 r
.35187 .42036 .3628 .40015 .37667 .42345 .36535 .45391 Mtetra
.756 .426 .427 r
.36535 .45391 .37667 .42345 .39052 .4561 .37907 .49218 Mtetra
.722 .397 .429 r
.37907 .49218 .39052 .4561 .40464 .49325 .39348 .52569 Mtetra
.652 .315 .388 r
.39348 .52569 .40464 .49325 .41941 .52564 .40891 .54321 Mtetra
.292 0 .088 r
.40891 .54321 .41941 .52564 .43505 .54235 .42536 .53705 Mtetra
.924 .832 .736 r
.42536 .53705 .43505 .54235 .45151 .53599 .44247 .50746 Mtetra
.834 .643 .644 r
.44247 .50746 .45151 .53599 .46843 .50688 .45975 .46252 Mtetra
.791 .584 .621 r
.45975 .46252 .46843 .50688 .4854 .46294 .4768 .41351 Mtetra
.763 .558 .62 r
.4768 .41351 .4854 .46294 .50211 .41512 .49345 .36969 Mtetra
.743 .55 .633 r
.49345 .36969 .50211 .41512 .51848 .37239 .50977 .33567 Mtetra
.728 .557 .659 r
.50977 .33567 .51848 .37239 .5346 .33921 .52589 .31176 Mtetra
.715 .581 .703 r
.52589 .31176 .5346 .33921 .55061 .31588 .54197 .29582 Mtetra
.703 .621 .762 r
.54197 .29582 .55061 .31588 .56664 .30028 .55808 .28503 Mtetra
.69 .668 .823 r
.55808 .28503 .56664 .30028 .58275 .28969 .57428 .2771 Mtetra
.678 .705 .868 r
.57428 .2771 .58275 .28969 .59897 .28185 .59059 .2705 Mtetra
.669 .726 .892 r
.59059 .2705 .59897 .28185 .6153 .27532 .60699 .26446 Mtetra
.665 .736 .902 r
.60699 .26446 .6153 .27532 .63173 .26931 .6235 .25859 Mtetra
.664 .74 .906 r
.6235 .25859 .63173 .26931 .64827 .26348 .64011 .25275 Mtetra
.664 .741 .907 r
.64011 .25275 .64827 .26348 .66491 .25767 .65681 .2469 Mtetra
.664 .741 .908 r
.65681 .2469 .66491 .25767 .68164 .25185 .67362 .24101 Mtetra
.67362 .24101 .68164 .25185 .69848 .24599 .69052 .2351 Mtetra
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Mtetra
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Mtetra
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Mtetra
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Mtetra
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Mtetra
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Mtetra
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Mtetra
.663 .741 .908 r
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39422 Mtetra
.1997 .39422 .2095 .40343 .22374 .39846 .21398 .38921 Mtetra
.661 .741 .91 r
.21398 .38921 .22374 .39846 .23805 .39347 .22833 .38425 Mtetra
.655 .741 .913 r
.22833 .38425 .23805 .39347 .25244 .38854 .24275 .37949 Mtetra
.637 .742 .924 r
.24275 .37949 .25244 .38854 .26689 .3838 .25719 .37532 Mtetra
.584 .74 .95 r
.25719 .37532 .26689 .3838 .28138 .37964 .27161 .37259 Mtetra
.399 .704 .984 r
.27161 .37259 .28138 .37964 .29585 .37691 .28591 .37287 Mtetra
0 .319 .656 r
.28591 .37287 .29585 .37691 .31022 .37716 .29995 .37856 Mtetra
.73 .234 .059 r
.29995 .37856 .31022 .37716 .32439 .38274 .31364 .39251 Mtetra
.784 .391 .311 r
.31364 .39251 .32439 .38274 .33827 .39646 .32694 .41684 Mtetra
.778 .43 .397 r
.32694 .41684 .33827 .39646 .35187 .42036 .34005 .45105 Mtetra
.758 .429 .428 r
.34005 .45105 .35187 .42036 .36535 .45391 .35337 .49017 Mtetra
.725 .4 .43 r
.35337 .49017 .36535 .45391 .37907 .49218 .36741 .52458 Mtetra
.656 .318 .388 r
.36741 .52458 .37907 .49218 .39348 .52569 .38261 .54278 Mtetra
.284 0 .069 r
.38261 .54278 .39348 .52569 .40891 .54321 .39904 .53683 Mtetra
.916 .816 .733 r
.39904 .53683 .40891 .54321 .42536 .53705 .41633 .50691 Mtetra
.829 .636 .642 r
.41633 .50691 .42536 .53705 .44247 .50746 .43393 .46123 Mtetra
.788 .58 .619 r
.43393 .46123 .44247 .50746 .45975 .46252 .45132 .4113 Mtetra
.761 .555 .618 r
.45132 .4113 .45975 .46252 .4768 .41351 .46827 .3666 Mtetra
.742 .547 .63 r
.46827 .3666 .4768 .41351 .49345 .36969 .48479 .3319 Mtetra
.727 .553 .656 r
.48479 .3319 .49345 .36969 .50977 .33567 .50104 .30752 Mtetra
.714 .577 .7 r
.50104 .30752 .50977 .33567 .52589 .31176 .51717 .29128 Mtetra
.703 .618 .759 r
.51717 .29128 .52589 .31176 .54197 .29582 .53329 .28033 Mtetra
.69 .665 .821 r
.53329 .28033 .54197 .29582 .55808 .28503 .54948 .27231 Mtetra
.678 .703 .866 r
.54948 .27231 .55808 .28503 .57428 .2771 .56576 .26566 Mtetra
.669 .726 .891 r
.56576 .26566 .57428 .2771 .59059 .2705 .58213 .25957 Mtetra
.665 .736 .902 r
.58213 .25957 .59059 .2705 .60699 .26446 .59861 .25367 Mtetra
.664 .74 .906 r
.59861 .25367 .60699 .26446 .6235 .25859 .61518 .2478 Mtetra
.664 .741 .907 r
.61518 .2478 .6235 .25859 .64011 .25275 .63185 .24192 Mtetra
.664 .741 .908 r
.63185 .24192 .64011 .25275 .65681 .2469 .64863 .23601 Mtetra
.64863 .23601 .65681 .2469 .67362 .24101 .6655 .23006 Mtetra
.6655 .23006 .67362 .24101 .69052 .2351 .68248 .22408 Mtetra
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Mtetra
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Mtetra
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Mtetra
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Mtetra
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Mtetra
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Mtetra
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Mtetra
.663 .741 .908 r
.17554 .38996 .18549 .39922 .1997 .39422 .18979 .38493 Mtetra
.661 .741 .91 r
.18979 .38493 .1997 .39422 .21398 .38921 .20411 .37995 Mtetra
.655 .741 .913 r
.20411 .37995 .21398 .38921 .22833 .38425 .21849 .37517 Mtetra
.637 .742 .924 r
.21849 .37517 .22833 .38425 .24275 .37949 .23289 .37097 Mtetra
.583 .74 .95 r
.23289 .37097 .24275 .37949 .25719 .37532 .24726 .36822 Mtetra
.396 .703 .984 r
.24726 .36822 .25719 .37532 .27161 .37259 .26148 .3685 Mtetra
.275 0 0 r
.26148 .3685 .27161 .37259 .28591 .37287 .2754 .37424 Mtetra
.733 .24 .065 r
.2754 .37424 .28591 .37287 .29995 .37856 .28889 .38831 Mtetra
.785 .394 .314 r
.28889 .38831 .29995 .37856 .31364 .39251 .30191 .41288 Mtetra
.779 .432 .398 r
.30191 .41288 .31364 .39251 .32694 .41684 .31466 .44749 Mtetra
.76 .431 .429 r
.31466 .44749 .32694 .41684 .34005 .45105 .32755 .48718 Mtetra
.727 .402 .43 r
.32755 .48718 .34005 .45105 .35337 .49017 .34122 .52223 Mtetra
.659 .32 .387 r
.34122 .52223 .35337 .49017 .36741 .52458 .35618 .54095 Mtetra
.273 0 .044 r
.35618 .54095 .36741 .52458 .38261 .54278 .37257 .53523 Mtetra
.907 .801 .731 r
.37257 .53523 .38261 .54278 .39904 .53683 .39005 .50516 Mtetra
.824 .63 .64 r
.39005 .50516 .39904 .53683 .41633 .50691 .40796 .45899 Mtetra
.785 .576 .618 r
.40796 .45899 .41633 .50691 .43393 .46123 .4257 .40842 Mtetra
.759 .552 .616 r
.4257 .40842 .43393 .46123 .45132 .4113 .44295 .3631 Mtetra
.74 .544 .628 r
.44295 .3631 .45132 .4113 .46827 .3666 .45969 .32788 Mtetra
.725 .551 .654 r
.45969 .32788 .46827 .3666 .48479 .3319 .47606 .30314 Mtetra
.714 .575 .697 r
.47606 .30314 .48479 .3319 .50104 .30752 .49224 .28667 Mtetra
.703 .616 .756 r
.49224 .28667 .50104 .30752 .51717 .29128 .50837 .27559 Mtetra
.69 .664 .819 r
.50837 .27559 .51717 .29128 .53329 .28033 .52455 .26748 Mtetra
.678 .702 .865 r
.52455 .26748 .53329 .28033 .54948 .27231 .5408 .26079 Mtetra
.67 .725 .891 r
.5408 .26079 .54948 .27231 .56576 .26566 .55715 .25467 Mtetra
.666 .735 .902 r
.55715 .25467 .56576 .26566 .58213 .25957 .57359 .24873 Mtetra
.664 .739 .906 r
.57359 .24873 .58213 .25957 .59861 .25367 .59013 .24284 Mtetra
.664 .741 .907 r
.59013 .24284 .59861 .25367 .61518 .2478 .60677 .23692 Mtetra
.664 .741 .908 r
.60677 .23692 .61518 .2478 .63185 .24192 .62351 .23098 Mtetra
.62351 .23098 .63185 .24192 .64863 .23601 .64035 .225 Mtetra
.64035 .225 .64863 .23601 .6655 .23006 .6573 .21899 Mtetra
.6573 .21899 .6655 .23006 .68248 .22408 .67434 .21294 Mtetra
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Mtetra
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Mtetra
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Mtetra
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Mtetra
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Mtetra
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Mtetra
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Mtetra
.661 .741 .91 r
.16549 .38063 .17554 .38996 .18979 .38493 .17978 .37562 Mtetra
.655 .741 .913 r
.17978 .37562 .18979 .38493 .20411 .37995 .19412 .37081 Mtetra
.637 .742 .924 r
.19412 .37081 .20411 .37995 .21849 .37517 .20848 .36659 Mtetra
.584 .74 .95 r
.20848 .36659 .21849 .37517 .23289 .37097 .2228 .36381 Mtetra
.396 .703 .984 r
.2228 .36381 .23289 .37097 .24726 .36822 .23694 .36406 Mtetra
.276 0 0 r
.23694 .36406 .24726 .36822 .26148 .3685 .25074 .36977 Mtetra
.734 .242 .067 r
.25074 .36977 .26148 .3685 .2754 .37424 .26404 .38383 Mtetra
.786 .396 .315 r
.26404 .38383 .2754 .37424 .28889 .38831 .27679 .40846 Mtetra
.781 .434 .399 r
.27679 .40846 .28889 .38831 .30191 .41288 .28917 .44323 Mtetra
.761 .433 .429 r
.28917 .44323 .30191 .41288 .31466 .44749 .30166 .48319 Mtetra
.73 .404 .429 r
.30166 .48319 .31466 .44749 .32755 .48718 .31494 .51859 Mtetra
.663 .321 .384 r
.31494 .51859 .32755 .48718 .34122 .52223 .32965 .53769 Mtetra
.257 0 .011 r
.32965 .53769 .34122 .52223 .35618 .54095 .34601 .53221 Mtetra
.898 .786 .729 r
.34601 .53221 .35618 .54095 .37257 .53523 .36365 .50215 Mtetra
.819 .624 .638 r
.36365 .50215 .37257 .53523 .39005 .50516 .38186 .45578 Mtetra
.782 .572 .617 r
.38186 .45578 .39005 .50516 .40796 .45899 .39994 .40486 Mtetra
.757 .549 .615 r
.39994 .40486 .40796 .45899 .4257 .40842 .41749 .35916 Mtetra
.739 .541 .626 r
.41749 .35916 .4257 .40842 .44295 .3631 .43445 .32361 Mtetra
.724 .548 .652 r
.43445 .32361 .44295 .3631 .45969 .32788 .45095 .29862 Mtetra
.713 .572 .695 r
.45095 .29862 .45969 .32788 .47606 .30314 .46719 .28199 Mtetra
.702 .614 .755 r
.46719 .28199 .47606 .30314 .49224 .28667 .48333 .2708 Mtetra
.69 .662 .817 r
.48333 .2708 .49224 .28667 .50837 .27559 .49949 .26263 Mtetra
.678 .702 .865 r
.49949 .26263 .50837 .27559 .52455 .26748 .51572 .25589 Mtetra
.67 .725 .891 r
.51572 .25589 .52455 .26748 .5408 .26079 .53204 .24973 Mtetra
.666 .735 .902 r
.53204 .24973 .5408 .26079 .55715 .25467 .54845 .24377 Mtetra
.664 .739 .906 r
.54845 .24377 .55715 .25467 .57359 .24873 .56495 .23784 Mtetra
.664 .741 .907 r
.56495 .23784 .57359 .24873 .59013 .24284 .58156 .2319 Mtetra
.664 .741 .908 r
.58156 .2319 .59013 .24284 .60677 .23692 .59827 .22593 Mtetra
.59827 .22593 .60677 .23692 .62351 .23098 .61508 .21992 Mtetra
.61508 .21992 .62351 .23098 .64035 .225 .63199 .21388 Mtetra
.63199 .21388 .64035 .225 .6573 .21899 .649 .2078 Mtetra
.649 .2078 .6573 .21899 .67434 .21294 .66611 .20168 Mtetra
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Mtetra
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Mtetra
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Mtetra
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Mtetra
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Mtetra
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.655 .741 .913 r
.15533 .37128 .16549 .38063 .17978 .37562 .16963 .36644 Mtetra
.637 .742 .924 r
.16963 .36644 .17978 .37562 .19412 .37081 .18395 .36218 Mtetra
.584 .74 .95 r
.18395 .36218 .19412 .37081 .20848 .36659 .19822 .35936 Mtetra
.399 .704 .984 r
.19822 .35936 .20848 .36659 .2228 .36381 .21228 .35954 Mtetra
.27 0 0 r
.21228 .35954 .2228 .36381 .23694 .36406 .22597 .36515 Mtetra
.734 .24 .064 r
.22597 .36515 .23694 .36406 .25074 .36977 .23909 .37909 Mtetra
.787 .396 .313 r
.23909 .37909 .25074 .36977 .26404 .38383 .25158 .40358 Mtetra
.782 .434 .398 r
.25158 .40358 .26404 .38383 .27679 .40846 .26361 .43824 Mtetra
.763 .434 .428 r
.26361 .43824 .27679 .40846 .28917 .44323 .2757 .47817 Mtetra
.732 .405 .427 r
.2757 .47817 .28917 .44323 .30166 .48319 .28861 .51366 Mtetra
.666 .321 .38 r
.28861 .51366 .30166 .48319 .31494 .51859 .30307 .53295 Mtetra
.237 0 0 r
.30307 .53295 .31494 .51859 .32965 .53769 .31937 .52771 Mtetra
.888 .771 .727 r
.31937 .52771 .32965 .53769 .34601 .53221 .33716 .49784 Mtetra
.814 .618 .638 r
.33716 .49784 .34601 .53221 .36365 .50215 .35566 .45154 Mtetra
.779 .569 .616 r
.35566 .45154 .36365 .50215 .38186 .45578 .37407 .40058 Mtetra
.755 .547 .614 r
.37407 .40058 .38186 .45578 .39994 .40486 .39192 .35477 Mtetra
.737 .539 .625 r
.39192 .35477 .39994 .40486 .41749 .35916 .40909 .31907 Mtetra
.723 .546 .651 r
.40909 .31907 .41749 .35916 .43445 .32361 .42571 .29396 Mtetra
.712 .57 .694 r
.42571 .29396 .43445 .32361 .45095 .29862 .44201 .27722 Mtetra
.702 .612 .753 r
.44201 .27722 .45095 .29862 .46719 .28199 .45817 .26596 Mtetra
.69 .661 .816 r
.45817 .26596 .46719 .28199 .48333 .2708 .47431 .25774 Mtetra
.678 .701 .864 r
.47431 .25774 .48333 .2708 .49949 .26263 .49051 .25097 Mtetra
.67 .724 .89 r
.49051 .25097 .49949 .26263 .51572 .25589 .5068 .24478 Mtetra
.666 .735 .902 r
.5068 .24478 .51572 .25589 .53204 .24973 .52318 .23878 Mtetra
.664 .739 .906 r
.52318 .23878 .53204 .24973 .54845 .24377 .53965 .23282 Mtetra
.664 .741 .907 r
.53965 .23282 .54845 .24377 .56495 .23784 .55622 .22685 Mtetra
.664 .741 .908 r
.55622 .22685 .56495 .23784 .58156 .2319 .5729 .22085 Mtetra
.5729 .22085 .58156 .2319 .59827 .22593 .58967 .21481 Mtetra
.58967 .21481 .59827 .22593 .61508 .21992 .60655 .20873 Mtetra
.60655 .20873 .61508 .21992 .63199 .21388 .62353 .20262 Mtetra
.62353 .20262 .63199 .21388 .649 .2078 .64061 .19647 Mtetra
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Mtetra
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Mtetra
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Mtetra
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Mtetra
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Mtetra
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.638 .742 .924 r
.14503 .36204 .15533 .37128 .16963 .36644 .15931 .35775 Mtetra
.586 .74 .95 r
.15931 .35775 .16963 .36644 .18395 .36218 .17352 .35486 Mtetra
.405 .706 .984 r
.17352 .35486 .18395 .36218 .19822 .35936 .18752 .35494 Mtetra
0 .326 .665 r
.18752 .35494 .19822 .35936 .21228 .35954 .2011 .36039 Mtetra
.731 .235 .056 r
.2011 .36039 .21228 .35954 .22597 .36515 .21405 .37409 Mtetra
.787 .394 .31 r
.21405 .37409 .22597 .36515 .23909 .37909 .22629 .39826 Mtetra
.783 .434 .396 r
.22629 .39826 .23909 .37909 .25158 .40358 .23799 .43254 Mtetra
.764 .434 .426 r
.23799 .43254 .25158 .40358 .26361 .43824 .2497 .47214 Mtetra
.734 .406 .425 r
.2497 .47214 .26361 .43824 .2757 .47817 .26225 .50744 Mtetra
.669 .321 .375 r
.26225 .50744 .2757 .47817 .28861 .51366 .27646 .52675 Mtetra
.211 0 0 r
.27646 .52675 .28861 .51366 .30307 .53295 .29269 .52175 Mtetra
.878 .758 .726 r
.29269 .52175 .30307 .53295 .31937 .52771 .31061 .49223 Mtetra
.81 .614 .637 r
.31061 .49223 .31937 .52771 .33716 .49784 .32937 .44628 Mtetra
.776 .566 .615 r
.32937 .44628 .33716 .49784 .35566 .45154 .3481 .39558 Mtetra
.753 .544 .614 r
.3481 .39558 .35566 .45154 .37407 .40058 .36623 .34991 Mtetra
.735 .537 .625 r
.36623 .34991 .37407 .40058 .39192 .35477 .3836 .31426 Mtetra
.722 .545 .65 r
.3836 .31426 .39192 .35477 .40909 .31907 .40035 .28914 Mtetra
.711 .569 .693 r
.40035 .28914 .40909 .31907 .42571 .29396 .4167 .27238 Mtetra
.701 .611 .752 r
.4167 .27238 .42571 .29396 .44201 .27722 .43287 .26108 Mtetra
.69 .66 .816 r
.43287 .26108 .44201 .27722 .45817 .26596 .44901 .25282 Mtetra
.678 .701 .864 r
.44901 .25282 .45817 .26596 .47431 .25774 .46518 .24601 Mtetra
.67 .724 .89 r
.46518 .24601 .47431 .25774 .49051 .25097 .48143 .23979 Mtetra
.666 .735 .902 r
.48143 .23979 .49051 .25097 .5068 .24478 .49778 .23376 Mtetra
.664 .739 .906 r
.49778 .23376 .5068 .24478 .52318 .23878 .51422 .22778 Mtetra
.664 .741 .907 r
.51422 .22778 .52318 .23878 .53965 .23282 .53076 .22177 Mtetra
.664 .741 .908 r
.53076 .22177 .53965 .23282 .55622 .22685 .5474 .21574 Mtetra
.5474 .21574 .55622 .22685 .5729 .22085 .56414 .20967 Mtetra
.56414 .20967 .5729 .22085 .58967 .21481 .58098 .20357 Mtetra
.58098 .20357 .58967 .21481 .60655 .20873 .59792 .19742 Mtetra
.59792 .19742 .60655 .20873 .62353 .20262 .61497 .19124 Mtetra
.61497 .19124 .62353 .20262 .64061 .19647 .63212 .18502 Mtetra
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Mtetra
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Mtetra
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Mtetra
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Mtetra
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
.588 .741 .949 r
.13455 .35328 .14503 .36204 .15931 .35775 .14872 .35032 Mtetra
.413 .709 .984 r
.14872 .35032 .15931 .35775 .17352 .35486 .16265 .35027 Mtetra
0 .345 .686 r
.16265 .35027 .17352 .35486 .18752 .35494 .17613 .35549 Mtetra
.726 .226 .043 r
.17613 .35549 .18752 .35494 .2011 .36039 .18892 .36883 Mtetra
.787 .392 .305 r
.18892 .36883 .2011 .36039 .21405 .37409 .20093 .39249 Mtetra
.783 .433 .393 r
.20093 .39249 .21405 .37409 .22629 .39826 .21232 .42615 Mtetra
.766 .434 .424 r
.21232 .42615 .22629 .39826 .23799 .43254 .22368 .46512 Mtetra
.736 .406 .422 r
.22368 .46512 .23799 .43254 .2497 .47214 .23589 .49995 Mtetra
.672 .319 .368 r
.23589 .49995 .2497 .47214 .26225 .50744 .24986 .51911 Mtetra
.177 0 0 r
.24986 .51911 .26225 .50744 .27646 .52675 .26601 .51433 Mtetra
.867 .745 .725 r
.26601 .51433 .27646 .52675 .29269 .52175 .28403 .48533 Mtetra
.805 .609 .637 r
.28403 .48533 .29269 .52175 .31061 .49223 .30303 .44001 Mtetra
.773 .563 .615 r
.30303 .44001 .31061 .49223 .32937 .44628 .32205 .38986 Mtetra
.751 .542 .613 r
.32205 .38986 .32937 .44628 .3481 .39558 .34044 .34459 Mtetra
.734 .536 .625 r
.34044 .34459 .3481 .39558 .36623 .34991 .35801 .30918 Mtetra
.721 .544 .65 r
.35801 .30918 .36623 .34991 .3836 .31426 .37487 .28417 Mtetra
.71 .568 .693 r
.37487 .28417 .3836 .31426 .40035 .28914 .39128 .26745 Mtetra
.701 .61 .752 r
.39128 .26745 .40035 .28914 .4167 .27238 .40745 .25615 Mtetra
.69 .66 .816 r
.40745 .25615 .4167 .27238 .43287 .26108 .42357 .24787 Mtetra
.678 .7 .864 r
.42357 .24787 .43287 .26108 .44901 .25282 .43972 .24103 Mtetra
.669 .724 .89 r
.43972 .24103 .44901 .25282 .46518 .24601 .45594 .23478 Mtetra
.666 .735 .902 r
.45594 .23478 .46518 .24601 .48143 .23979 .47225 .22872 Mtetra
.664 .739 .906 r
.47225 .22872 .48143 .23979 .49778 .23376 .48865 .22271 Mtetra
.664 .741 .907 r
.48865 .22271 .49778 .23376 .51422 .22778 .50516 .21667 Mtetra
.664 .741 .908 r
.50516 .21667 .51422 .22778 .53076 .22177 .52176 .21061 Mtetra
.52176 .21061 .53076 .22177 .5474 .21574 .53847 .20451 Mtetra
.53847 .20451 .5474 .21574 .56414 .20967 .55527 .19837 Mtetra
.55527 .19837 .56414 .20967 .58098 .20357 .57218 .1922 Mtetra
.57218 .1922 .58098 .20357 .59792 .19742 .5892 .18598 Mtetra
.5892 .18598 .59792 .19742 .61497 .19124 .60632 .17973 Mtetra
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Mtetra
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Mtetra
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Mtetra
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Mtetra
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
.423 .712 .984 r
.12379 .34573 .13455 .35328 .14872 .35032 .13766 .34552 Mtetra
0 .37 .713 r
.13766 .34552 .14872 .35032 .16265 .35027 .15105 .35045 Mtetra
.719 .212 .024 r
.15105 .35045 .16265 .35027 .17613 .35549 .16371 .36333 Mtetra
.786 .387 .297 r
.16371 .36333 .17613 .35549 .18892 .36883 .17551 .38631 Mtetra
.784 .431 .388 r
.17551 .38631 .18892 .36883 .20093 .39249 .18663 .41911 Mtetra
.767 .433 .42 r
.18663 .41911 .20093 .39249 .21232 .42615 .19766 .45717 Mtetra
.738 .405 .417 r
.19766 .45717 .21232 .42615 .22368 .46512 .20955 .49126 Mtetra
.674 .316 .359 r
.20955 .49126 .22368 .46512 .23589 .49995 .22329 .5101 Mtetra
.134 0 0 r
.22329 .5101 .23589 .49995 .24986 .51911 .23935 .50553 Mtetra
.857 .733 .725 r
.23935 .50553 .24986 .51911 .26601 .51433 .25745 .47719 Mtetra
.8 .605 .638 r
.25745 .47719 .26601 .51433 .28403 .48533 .27665 .43274 Mtetra
.77 .561 .616 r
.27665 .43274 .28403 .48533 .30303 .44001 .29593 .38344 Mtetra
.749 .541 .614 r
.29593 .38344 .30303 .44001 .32205 .38986 .31455 .33882 Mtetra
.732 .535 .625 r
.31455 .33882 .32205 .38986 .34044 .34459 .3323 .30384 Mtetra
.72 .543 .65 r
.3323 .30384 .34044 .34459 .35801 .30918 .34927 .27906 Mtetra
.709 .568 .693 r
.34927 .27906 .35801 .30918 .37487 .28417 .36572 .26244 Mtetra
.7 .61 .753 r
.36572 .26244 .37487 .28417 .39128 .26745 .38191 .25117 Mtetra
.689 .66 .816 r
.38191 .25117 .39128 .26745 .40745 .25615 .39801 .24288 Mtetra
.678 .7 .864 r
.39801 .24288 .40745 .25615 .42357 .24787 .41413 .23602 Mtetra
.669 .724 .89 r
.41413 .23602 .42357 .24787 .43972 .24103 .43032 .22974 Mtetra
.665 .735 .902 r
.43032 .22974 .43972 .24103 .45594 .23478 .44659 .22366 Mtetra
.664 .739 .906 r
.44659 .22366 .45594 .23478 .47225 .22872 .46296 .21761 Mtetra
.664 .741 .907 r
.46296 .21761 .47225 .22872 .48865 .22271 .47943 .21154 Mtetra
.664 .741 .908 r
.47943 .21154 .48865 .22271 .50516 .21667 .496 .20545 Mtetra
.496 .20545 .50516 .21667 .52176 .21061 .51267 .19932 Mtetra
.51267 .19932 .52176 .21061 .53847 .20451 .52944 .19315 Mtetra
.52944 .19315 .53847 .20451 .55527 .19837 .54631 .18694 Mtetra
.54631 .18694 .55527 .19837 .57218 .1922 .56329 .1807 Mtetra
.56329 .1807 .57218 .1922 .5892 .18598 .58037 .17441 Mtetra
.58037 .17441 .5892 .18598 .60632 .17973 .59756 .16809 Mtetra
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Mtetra
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Mtetra
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
0 .4 .745 r
.11257 .34071 .12379 .34573 .13766 .34552 .12587 .3453 Mtetra
.709 .194 0 r
.12587 .3453 .13766 .34552 .15105 .35045 .13841 .3576 Mtetra
.785 .381 .287 r
.13841 .3576 .15105 .35045 .16371 .36333 .15003 .37974 Mtetra
.784 .428 .383 r
.15003 .37974 .16371 .36333 .17551 .38631 .16091 .41146 Mtetra
.768 .431 .415 r
.16091 .41146 .17551 .38631 .18663 .41911 .17165 .44834 Mtetra
.74 .403 .412 r
.17165 .44834 .18663 .41911 .19766 .45717 .18326 .48145 Mtetra
.676 .312 .349 r
.18326 .48145 .19766 .45717 .20955 .49126 .19678 .4998 Mtetra
.079 0 0 r
.19678 .4998 .20955 .49126 .22329 .5101 .21275 .49542 Mtetra
.847 .722 .725 r
.21275 .49542 .22329 .5101 .23935 .50553 .23089 .46788 Mtetra
.796 .601 .639 r
.23089 .46788 .23935 .50553 .25745 .47719 .25026 .42455 Mtetra
.767 .559 .617 r
.25026 .42455 .25745 .47719 .27665 .43274 .26975 .37635 Mtetra
.747 .54 .614 r
.26975 .37635 .27665 .43274 .29593 .38344 .28859 .33261 Mtetra
.731 .534 .625 r
.28859 .33261 .29593 .38344 .31455 .33882 .30649 .29823 Mtetra
.718 .542 .651 r
.30649 .29823 .31455 .33882 .3323 .30384 .32355 .2738 Mtetra
.708 .568 .694 r
.32355 .2738 .3323 .30384 .34927 .27906 .34005 .25734 Mtetra
.699 .611 .754 r
.34005 .25734 .34927 .27906 .36572 .26244 .35624 .24614 Mtetra
.689 .66 .817 r
.35624 .24614 .36572 .26244 .38191 .25117 .37232 .23786 Mtetra
.677 .701 .865 r
.37232 .23786 .38191 .25117 .39801 .24288 .38841 .23099 Mtetra
.669 .724 .891 r
.38841 .23099 .39801 .24288 .41413 .23602 .40456 .22468 Mtetra
.665 .735 .902 r
.40456 .22468 .41413 .23602 .43032 .22974 .4208 .21856 Mtetra
.664 .739 .906 r
.4208 .21856 .43032 .22974 .44659 .22366 .43714 .21249 Mtetra
.664 .741 .907 r
.43714 .21249 .44659 .22366 .46296 .21761 .45357 .20639 Mtetra
.664 .741 .908 r
.45357 .20639 .46296 .21761 .47943 .21154 .4701 .20026 Mtetra
.4701 .20026 .47943 .21154 .496 .20545 .48673 .1941 Mtetra
.48673 .1941 .496 .20545 .51267 .19932 .50347 .1879 Mtetra
.50347 .1879 .51267 .19932 .52944 .19315 .52031 .18166 Mtetra
.52031 .18166 .52944 .19315 .54631 .18694 .53725 .17538 Mtetra
.53725 .17538 .54631 .18694 .56329 .1807 .5543 .16907 Mtetra
.5543 .16907 .56329 .1807 .58037 .17441 .57145 .16271 Mtetra
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Mtetra
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Mtetra
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
.695 .171 0 r
.10059 .34003 .11257 .34071 .12587 .3453 .11303 .35168 Mtetra
.783 .373 .274 r
.11303 .35168 .12587 .3453 .13841 .3576 .1245 .37283 Mtetra
.784 .424 .375 r
.1245 .37283 .13841 .3576 .15003 .37974 .13517 .40326 Mtetra
.769 .428 .409 r
.13517 .40326 .15003 .37974 .16091 .41146 .14567 .43872 Mtetra
.741 .401 .405 r
.14567 .43872 .16091 .41146 .17165 .44834 .15703 .47061 Mtetra
.677 .306 .336 r
.15703 .47061 .17165 .44834 .18326 .48145 .17034 .48832 Mtetra
.011 0 0 r
.17034 .48832 .18326 .48145 .19678 .4998 .18621 .48411 Mtetra
.837 .711 .725 r
.18621 .48411 .19678 .4998 .21275 .49542 .20438 .45749 Mtetra
.791 .598 .64 r
.20438 .45749 .21275 .49542 .23089 .46788 .22387 .41548 Mtetra
.764 .557 .618 r
.22387 .41548 .23089 .46788 .25026 .42455 .24353 .36863 Mtetra
.745 .539 .616 r
.24353 .36863 .25026 .42455 .26975 .37635 .26254 .326 Mtetra
.73 .534 .627 r
.26254 .326 .26975 .37635 .28859 .33261 .28058 .29238 Mtetra
.717 .543 .652 r
.28058 .29238 .28859 .33261 .30649 .29823 .29772 .2684 Mtetra
.708 .569 .696 r
.29772 .2684 .30649 .29823 .32355 .2738 .31425 .25218 Mtetra
.699 .612 .756 r
.31425 .25218 .32355 .2738 .34005 .25734 .33043 .24106 Mtetra
.688 .661 .818 r
.33043 .24106 .34005 .25734 .35624 .24614 .3465 .23281 Mtetra
.677 .701 .865 r
.3465 .23281 .35624 .24614 .37232 .23786 .36256 .22592 Mtetra
.669 .725 .891 r
.36256 .22592 .37232 .23786 .38841 .23099 .37868 .21959 Mtetra
.665 .735 .902 r
.37868 .21959 .38841 .23099 .40456 .22468 .39488 .21345 Mtetra
.664 .739 .906 r
.39488 .21345 .40456 .22468 .4208 .21856 .41118 .20734 Mtetra
.664 .741 .907 r
.41118 .20734 .4208 .21856 .43714 .21249 .42757 .20121 Mtetra
.664 .741 .908 r
.42757 .20121 .43714 .21249 .45357 .20639 .44407 .19505 Mtetra
.44407 .19505 .45357 .20639 .4701 .20026 .46067 .18886 Mtetra
.46067 .18886 .4701 .20026 .48673 .1941 .47737 .18262 Mtetra
.47737 .18262 .48673 .1941 .50347 .1879 .49417 .17635 Mtetra
.49417 .17635 .50347 .1879 .52031 .18166 .51107 .17004 Mtetra
.51107 .17004 .52031 .18166 .53725 .17538 .52808 .16369 Mtetra
.52808 .16369 .53725 .17538 .5543 .16907 .5452 .1573 Mtetra
.5452 .1573 .5543 .16907 .57145 .16271 .56242 .15087 Mtetra
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Mtetra
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Mtetra
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Mtetra
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.78 .362 .257 r
.08756 .34557 .10059 .34003 .11303 .35168 .09891 .3656 Mtetra
.784 .419 .365 r
.09891 .3656 .11303 .35168 .1245 .37283 .10942 .39457 Mtetra
.77 .425 .401 r
.10942 .39457 .1245 .37283 .13517 .40326 .11972 .4284 Mtetra
.743 .397 .397 r
.11972 .4284 .13517 .40326 .14567 .43872 .13087 .45887 Mtetra
.678 .298 .32 r
.13087 .45887 .14567 .43872 .15703 .47061 .144 .47579 Mtetra
0 0 0 r
.144 .47579 .15703 .47061 .17034 .48832 .15976 .47173 Mtetra
.827 .702 .726 r
.15976 .47173 .17034 .48832 .18621 .48411 .17791 .44612 Mtetra
.787 .595 .642 r
.17791 .44612 .18621 .48411 .20438 .45749 .19748 .40562 Mtetra
.762 .556 .619 r
.19748 .40562 .20438 .45749 .22387 .41548 .21728 .36034 Mtetra
.743 .538 .617 r
.21728 .36034 .22387 .41548 .24353 .36863 .23642 .31901 Mtetra
.728 .534 .628 r
.23642 .31901 .24353 .36863 .26254 .326 .25456 .2863 Mtetra
.716 .543 .654 r
.25456 .2863 .26254 .326 .28058 .29238 .27177 .26287 Mtetra
.707 .57 .698 r
.27177 .26287 .28058 .29238 .29772 .2684 .28832 .24693 Mtetra
.698 .613 .758 r
.28832 .24693 .29772 .2684 .31425 .25218 .30451 .23594 Mtetra
.688 .663 .82 r
.30451 .23594 .31425 .25218 .33043 .24106 .32055 .22772 Mtetra
.677 .702 .866 r
.32055 .22772 .33043 .24106 .3465 .23281 .33658 .22083 Mtetra
.669 .725 .891 r
.33658 .22083 .3465 .23281 .36256 .22592 .35266 .21447 Mtetra
.665 .735 .902 r
.35266 .21447 .36256 .22592 .37868 .21959 .36883 .2083 Mtetra
.664 .739 .906 r
.36883 .2083 .37868 .21959 .39488 .21345 .38509 .20216 Mtetra
.664 .741 .907 r
.38509 .20216 .39488 .21345 .41118 .20734 .40145 .196 Mtetra
.664 .741 .908 r
.40145 .196 .41118 .20734 .42757 .20121 .4179 .18981 Mtetra
.4179 .18981 .42757 .20121 .44407 .19505 .43446 .18358 Mtetra
.43446 .18358 .44407 .19505 .46067 .18886 .45113 .17732 Mtetra
.45113 .17732 .46067 .18886 .47737 .18262 .46789 .17101 Mtetra
.46789 .17101 .47737 .18262 .49417 .17635 .48476 .16467 Mtetra
.48476 .16467 .49417 .17635 .51107 .17004 .50173 .15829 Mtetra
.50173 .15829 .51107 .17004 .52808 .16369 .51881 .15187 Mtetra
.51881 .15187 .52808 .16369 .5452 .1573 .536 .1454 Mtetra
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Mtetra
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Mtetra
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Mtetra
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.783 .412 .354 r
.07328 .35811 .08756 .34557 .09891 .3656 .08367 .38546 Mtetra
.77 .42 .392 r
.08367 .38546 .09891 .3656 .10942 .39457 .09381 .41748 Mtetra
.744 .392 .386 r
.09381 .41748 .10942 .39457 .11972 .4284 .10479 .44634 Mtetra
.678 .288 .301 r
.10479 .44634 .11972 .4284 .13087 .45887 .11776 .46237 Mtetra
0 0 0 r
.11776 .46237 .13087 .45887 .144 .47579 .13341 .45842 Mtetra
.818 .694 .727 r
.13341 .45842 .144 .47579 .15976 .47173 .15152 .43389 Mtetra
.782 .593 .644 r
.15152 .43389 .15976 .47173 .17791 .44612 .17112 .39507 Mtetra
.759 .555 .621 r
.17112 .39507 .17791 .44612 .19748 .40562 .191 .35154 Mtetra
.741 .538 .619 r
.191 .35154 .19748 .40562 .21728 .36034 .21024 .31168 Mtetra
.727 .534 .63 r
.21024 .31168 .21728 .36034 .23642 .31901 .22846 .28001 Mtetra
.715 .544 .657 r
.22846 .28001 .23642 .31901 .25456 .2863 .24571 .25723 Mtetra
.706 .572 .701 r
.24571 .25723 .25456 .2863 .27177 .26287 .26227 .24162 Mtetra
.697 .615 .761 r
.26227 .24162 .27177 .26287 .28832 .24693 .27845 .23077 Mtetra
.687 .664 .822 r
.27845 .23077 .28832 .24693 .30451 .23594 .29446 .2226 Mtetra
.676 .703 .867 r
.29446 .2226 .30451 .23594 .32055 .22772 .31046 .2157 Mtetra
.669 .725 .892 r
.31046 .2157 .32055 .22772 .33658 .22083 .32651 .20933 Mtetra
.665 .736 .902 r
.32651 .20933 .33658 .22083 .35266 .21447 .34264 .20313 Mtetra
.664 .739 .906 r
.34264 .20313 .35266 .21447 .36883 .2083 .35886 .19696 Mtetra
.664 .741 .907 r
.35886 .19696 .36883 .2083 .38509 .20216 .37518 .19077 Mtetra
.664 .741 .908 r
.37518 .19077 .38509 .20216 .40145 .196 .3916 .18454 Mtetra
.3916 .18454 .40145 .196 .4179 .18981 .40812 .17828 Mtetra
.40812 .17828 .4179 .18981 .43446 .18358 .42475 .17199 Mtetra
.42475 .17199 .43446 .18358 .45113 .17732 .44148 .16565 Mtetra
.44148 .16565 .45113 .17732 .46789 .17101 .45831 .15927 Mtetra
.45831 .15927 .46789 .17101 .48476 .16467 .47524 .15286 Mtetra
.47524 .15286 .48476 .16467 .50173 .15829 .49228 .1464 Mtetra
.49228 .1464 .50173 .15829 .51881 .15187 .50943 .1399 Mtetra
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Mtetra
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Mtetra
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Mtetra
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.77 .414 .381 r
.0579 .376 .07328 .35811 .08367 .38546 .06794 .40607 Mtetra
.744 .386 .374 r
.06794 .40607 .08367 .38546 .09381 .41748 .07878 .43318 Mtetra
.676 .275 .277 r
.07878 .43318 .09381 .41748 .10479 .44634 .09162 .4482 Mtetra
.255 .766 .787 r
.09162 .4482 .10479 .44634 .11776 .46237 .10715 .44434 Mtetra
.808 .686 .729 r
.10715 .44434 .11776 .46237 .13341 .45842 .1252 .42095 Mtetra
.778 .591 .647 r
.1252 .42095 .13341 .45842 .15152 .43389 .14479 .38392 Mtetra
.756 .555 .624 r
.14479 .38392 .15152 .43389 .17112 .39507 .1647 .34229 Mtetra
.739 .538 .621 r
.1647 .34229 .17112 .39507 .191 .35154 .18399 .30405 Mtetra
.725 .535 .633 r
.18399 .30405 .191 .35154 .21024 .31168 .20226 .27354 Mtetra
.714 .546 .66 r
.20226 .27354 .21024 .31168 .22846 .28001 .21954 .25147 Mtetra
.705 .574 .705 r
.21954 .25147 .22846 .28001 .24571 .25723 .2361 .23624 Mtetra
.697 .618 .764 r
.2361 .23624 .24571 .25723 .26227 .24162 .25226 .22557 Mtetra
.686 .666 .825 r
.25226 .22557 .26227 .24162 .27845 .23077 .26825 .21745 Mtetra
.676 .704 .869 r
.26825 .21745 .27845 .23077 .29446 .2226 .28421 .21055 Mtetra
.669 .726 .892 r
.28421 .21055 .29446 .2226 .31046 .2157 .30022 .20416 Mtetra
.665 .736 .903 r
.30022 .20416 .31046 .2157 .32651 .20933 .31631 .19793 Mtetra
.664 .74 .906 r
.31631 .19793 .32651 .20933 .34264 .20313 .3325 .19173 Mtetra
.664 .741 .907 r
.3325 .19173 .34264 .20313 .35886 .19696 .34878 .18551 Mtetra
.664 .741 .908 r
.34878 .18551 .35886 .19696 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18454 .38165 .17296 Mtetra
.38165 .17296 .3916 .18454 .40812 .17828 .39823 .16663 Mtetra
.39823 .16663 .40812 .17828 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15927 .44861 .1474 Mtetra
.44861 .1474 .45831 .15927 .47524 .15286 .46562 .1409 Mtetra
.46562 .1409 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Mtetra
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Mtetra
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Mtetra
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.744 .378 .359 r
.04209 .39427 .0579 .376 .06794 .40607 .05285 .41952 Mtetra
.673 .257 .248 r
.05285 .41952 .06794 .40607 .07878 .43318 .06558 .43344 Mtetra
.343 .82 .88 r
.06558 .43344 .07878 .43318 .09162 .4482 .08099 .42964 Mtetra
.799 .679 .732 r
.08099 .42964 .09162 .4482 .10715 .44434 .09894 .40743 Mtetra
.774 .59 .65 r
.09894 .40743 .10715 .44434 .1252 .42095 .11848 .37228 Mtetra
.754 .555 .627 r
.11848 .37228 .1252 .42095 .14479 .38392 .13838 .33268 Mtetra
.737 .539 .624 r
.13838 .33268 .14479 .38392 .1647 .34229 .15768 .29617 Mtetra
.724 .536 .636 r
.15768 .29617 .1647 .34229 .18399 .30405 .17596 .26691 Mtetra
.713 .548 .664 r
.17596 .26691 .18399 .30405 .20226 .27354 .19325 .24561 Mtetra
.705 .577 .709 r
.19325 .24561 .20226 .27354 .21954 .25147 .20981 .2308 Mtetra
.696 .621 .768 r
.20981 .2308 .21954 .25147 .2361 .23624 .22594 .22032 Mtetra
.686 .669 .828 r
.22594 .22032 .2361 .23624 .25226 .22557 .2419 .21226 Mtetra
.675 .706 .87 r
.2419 .21226 .25226 .22557 .26825 .21745 .25783 .20537 Mtetra
.668 .726 .893 r
.25783 .20537 .26825 .21745 .28421 .21055 .2738 .19896 Mtetra
.665 .736 .903 r
.2738 .19896 .28421 .21055 .30022 .20416 .28985 .1927 Mtetra
.664 .74 .906 r
.28985 .1927 .30022 .20416 .31631 .19793 .306 .18647 Mtetra
.664 .741 .907 r
.306 .18647 .31631 .19793 .3325 .19173 .32224 .18022 Mtetra
.664 .741 .908 r
.32224 .18022 .3325 .19173 .34878 .18551 .33859 .17393 Mtetra
.33859 .17393 .34878 .18551 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .1409 .45588 .12881 Mtetra
.45588 .12881 .46562 .1409 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.667 .235 .212 r
.02699 .40551 .04209 .39427 .05285 .41952 .03963 .41826 Mtetra
.418 .849 .944 r
.03963 .41826 .05285 .41952 .06558 .43344 .05493 .41448 Mtetra
.791 .674 .735 r
.05493 .41448 .06558 .43344 .08099 .42964 .07276 .39348 Mtetra
.77 .589 .654 r
.07276 .39348 .08099 .42964 .09894 .40743 .0922 .36027 Mtetra
.751 .555 .63 r
.0922 .36027 .09894 .40743 .11848 .37228 .11203 .32278 Mtetra
.736 .54 .628 r
.11203 .32278 .11848 .37228 .13838 .33268 .13131 .28809 Mtetra
.723 .538 .64 r
.13131 .28809 .13838 .33268 .15768 .29617 .14958 .26015 Mtetra
.712 .551 .668 r
.14958 .26015 .15768 .29617 .17596 .26691 .16685 .23968 Mtetra
.704 .58 .714 r
.16685 .23968 .17596 .26691 .19325 .24561 .18339 .22531 Mtetra
.695 .624 .773 r
.18339 .22531 .19325 .24561 .20981 .2308 .1995 .21503 Mtetra
.685 .671 .831 r
.1995 .21503 .20981 .2308 .22594 .22032 .21542 .20705 Mtetra
.675 .707 .872 r
.21542 .20705 .22594 .22032 .2419 .21226 .23131 .20017 Mtetra
.668 .727 .894 r
.23131 .20017 .2419 .21226 .25783 .20537 .24724 .19374 Mtetra
.665 .736 .903 r
.24724 .19374 .25783 .20537 .2738 .19896 .26326 .18745 Mtetra
.664 .74 .906 r
.26326 .18745 .2738 .19896 .28985 .1927 .27936 .18119 Mtetra
.664 .741 .907 r
.27936 .18119 .28985 .1927 .306 .18647 .29557 .1749 Mtetra
.664 .741 .908 r
.29557 .1749 .306 .18647 .32224 .18022 .31187 .16858 Mtetra
.31187 .16858 .32224 .18022 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.475 .857 .981 r
.01376 .40282 .02699 .40551 .03963 .41826 .02894 .39904 Mtetra
.782 .669 .739 r
.02894 .39904 .03963 .41826 .05493 .41448 .04663 .37923 Mtetra
.766 .589 .658 r
.04663 .37923 .05493 .41448 .07276 .39348 .06593 .34799 Mtetra
.749 .556 .634 r
.06593 .34799 .07276 .39348 .0922 .36027 .08566 .31266 Mtetra
.734 .541 .632 r
.08566 .31266 .0922 .36027 .11203 .32278 .10487 .27984 Mtetra
.722 .541 .645 r
.10487 .27984 .11203 .32278 .13131 .28809 .12309 .25328 Mtetra
.712 .554 .673 r
.12309 .25328 .13131 .28809 .14958 .26015 .14033 .23367 Mtetra
.703 .584 .719 r
.14033 .23367 .14958 .26015 .16685 .23968 .15684 .21977 Mtetra
.694 .628 .778 r
.15684 .21977 .16685 .23968 .18339 .22531 .17291 .20971 Mtetra
.684 .674 .835 r
.17291 .20971 .18339 .22531 .1995 .21503 .1888 .2018 Mtetra
.674 .709 .874 r
.1888 .2018 .1995 .21503 .21542 .20705 .20465 .19493 Mtetra
.668 .728 .894 r
.20465 .19493 .21542 .20705 .23131 .20017 .22055 .18848 Mtetra
.665 .736 .903 r
.22055 .18848 .23131 .20017 .24724 .19374 .23652 .18217 Mtetra
.664 .74 .906 r
.23652 .18217 .24724 .19374 .26326 .18745 .25259 .17587 Mtetra
.664 .741 .908 r
.25259 .17587 .26326 .18745 .27936 .18119 .26875 .16955 Mtetra
.26875 .16955 .27936 .18119 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.663 .741 .908 r
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54672 .5879 .5389 Mtetra
.5879 .5389 .59512 .54672 .60921 .5425 .60203 .53465 Mtetra
.60203 .53465 .60921 .5425 .62337 .53826 .61624 .53038 Mtetra
.663 .742 .909 r
.61624 .53038 .62337 .53826 .6376 .534 .63052 .52611 Mtetra
.662 .742 .909 r
.63052 .52611 .6376 .534 .6519 .52974 .64488 .52184 Mtetra
.66 .742 .911 r
.64488 .52184 .6519 .52974 .66628 .52549 .65931 .5176 Mtetra
.658 .743 .912 r
.65931 .5176 .66628 .52549 .68073 .52125 .67381 .51341 Mtetra
.655 .744 .915 r
.67381 .51341 .68073 .52125 .69526 .51706 .68841 .50932 Mtetra
.65 .746 .92 r
.68841 .50932 .69526 .51706 .70988 .51294 .70308 .50538 Mtetra
.643 .75 .927 r
.70308 .50538 .70988 .51294 .72458 .50894 .71786 .50164 Mtetra
.633 .754 .936 r
.71786 .50164 .72458 .50894 .73937 .50511 .73273 .49817 Mtetra
.618 .761 .947 r
.73273 .49817 .73937 .50511 .75426 .5015 .74771 .49503 Mtetra
.598 .769 .961 r
.74771 .49503 .75426 .5015 .76926 .49817 .76282 .49228 Mtetra
.572 .779 .977 r
.76282 .49228 .76926 .49817 .78437 .49513 .77805 .48992 Mtetra
.538 .789 .99 r
.77805 .48992 .78437 .49513 .7996 .49241 .79341 .48791 Mtetra
.498 .797 .999 r
.79341 .48791 .7996 .49241 .81495 .48996 .8089 .48618 Mtetra
.457 .803 .998 r
.8089 .48618 .81495 .48996 .83043 .4877 .82451 .48455 Mtetra
.426 .809 .99 r
.82451 .48455 .83043 .4877 .84601 .48551 .84022 .48282 Mtetra
.415 .818 .981 r
.84022 .48282 .84601 .48551 .86169 .4832 .85601 .48074 Mtetra
.436 .836 .978 r
.85601 .48074 .86169 .4832 .87744 .48058 .87185 .47807 Mtetra
.486 .861 .983 r
.87185 .47807 .87744 .48058 .89325 .47746 .88771 .47461 Mtetra
.554 .883 .989 r
.88771 .47461 .89325 .47746 .90907 .47368 .90356 .47022 Mtetra
.622 .893 .988 r
.90356 .47022 .90907 .47368 .9249 .46914 .91938 .46487 Mtetra
.675 .886 .976 r
.91938 .46487 .9249 .46914 .94073 .46383 .93518 .45861 Mtetra
.709 .866 .956 r
.93518 .45861 .94073 .46383 .95654 .4578 .95096 .4516 Mtetra
.726 .842 .936 r
.95096 .4516 .95654 .4578 .97235 .45118 .96673 .44407 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.663 .741 .908 r
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .5353 Mtetra
.5665 .5353 .57384 .54314 .5879 .5389 .58061 .53102 Mtetra
.58061 .53102 .5879 .5389 .60203 .53465 .59479 .52674 Mtetra
.662 .742 .909 r
.59479 .52674 .60203 .53465 .61624 .53038 .60905 .52245 Mtetra
.662 .742 .91 r
.60905 .52245 .61624 .53038 .63052 .52611 .62338 .51818 Mtetra
.66 .742 .911 r
.62338 .51818 .63052 .52611 .64488 .52184 .63779 .51393 Mtetra
.658 .743 .913 r
.63779 .51393 .64488 .52184 .65931 .5176 .65227 .50976 Mtetra
.654 .745 .917 r
.65227 .50976 .65931 .5176 .67381 .51341 .66684 .50569 Mtetra
.648 .747 .922 r
.66684 .50569 .67381 .51341 .68841 .50932 .6815 .50181 Mtetra
.639 .751 .929 r
.6815 .50181 .68841 .50932 .70308 .50538 .69625 .49817 Mtetra
.626 .756 .94 r
.69625 .49817 .70308 .50538 .71786 .50164 .7111 .49485 Mtetra
.608 .763 .954 r
.7111 .49485 .71786 .50164 .73273 .49817 .72607 .49195 Mtetra
.581 .772 .97 r
.72607 .49195 .73273 .49817 .74771 .49503 .74116 .48951 Mtetra
.544 .781 .986 r
.74116 .48951 .74771 .49503 .76282 .49228 .75639 .48757 Mtetra
.493 .787 .997 r
.75639 .48757 .76282 .49228 .77805 .48992 .77176 .48608 Mtetra
.43 .787 .996 r
.77176 .48608 .77805 .48992 .79341 .48791 .78727 .48494 Mtetra
.361 .779 .977 r
.78727 .48494 .79341 .48791 .8089 .48618 .8029 .48398 Mtetra
.304 .767 .945 r
.8029 .48398 .8089 .48618 .82451 .48455 .81865 .48293 Mtetra
.279 .765 .917 r
.81865 .48293 .82451 .48455 .84022 .48282 .83448 .48151 Mtetra
.301 .784 .909 r
.83448 .48151 .84022 .48282 .85601 .48074 .85037 .4794 Mtetra
.371 .826 .927 r
.85037 .4794 .85601 .48074 .87185 .47807 .86626 .47636 Mtetra
.474 .875 .957 r
.86626 .47636 .87185 .47807 .88771 .47461 .88214 .47218 Mtetra
.58 .907 .979 r
.88214 .47218 .88771 .47461 .90356 .47022 .89798 .46682 Mtetra
.664 .911 .978 r
.89798 .46682 .90356 .47022 .91938 .46487 .91377 .46033 Mtetra
.715 .891 .961 r
.91377 .46033 .91938 .46487 .93518 .45861 .92952 .4529 Mtetra
.739 .861 .937 r
.92952 .4529 .93518 .45861 .95096 .4516 .94524 .44478 Mtetra
.747 .831 .916 r
.94524 .44478 .95096 .4516 .96673 .44407 .96097 .43628 Mtetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55703 Mtetra
.46198 .55703 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .54021 Mtetra
.663 .741 .908 r
.51705 .54021 .5246 .54801 .5385 .54379 .531 .53595 Mtetra
.531 .53595 .5385 .54379 .55246 .53955 .54501 .53167 Mtetra
.54501 .53167 .55246 .53955 .5665 .5353 .5591 .52738 Mtetra
.5591 .52738 .5665 .5353 .58061 .53102 .57325 .52308 Mtetra
.662 .742 .909 r
.57325 .52308 .58061 .53102 .59479 .52674 .58748 .51878 Mtetra
.661 .742 .91 r
.58748 .51878 .59479 .52674 .60905 .52245 .60179 .5145 Mtetra
.66 .742 .911 r
.60179 .5145 .60905 .52245 .62338 .51818 .61617 .51025 Mtetra
.657 .743 .914 r
.61617 .51025 .62338 .51818 .63779 .51393 .63063 .50609 Mtetra
.652 .745 .918 r
.63063 .50609 .63779 .51393 .65227 .50976 .64518 .50206 Mtetra
.645 .748 .924 r
.64518 .50206 .65227 .50976 .66684 .50569 .65981 .49823 Mtetra
.635 .752 .933 r
.65981 .49823 .66684 .50569 .6815 .50181 .67454 .4947 Mtetra
.619 .757 .945 r
.67454 .4947 .6815 .50181 .69625 .49817 .68937 .49156 Mtetra
.595 .765 .96 r
.68937 .49156 .69625 .49817 .7111 .49485 .70432 .48891 Mtetra
.56 .773 .978 r
.70432 .48891 .7111 .49485 .72607 .49195 .7194 .48682 Mtetra
.507 .78 .994 r
.7194 .48682 .72607 .49195 .74116 .48951 .73463 .48534 Mtetra
.432 .778 .997 r
.73463 .48534 .74116 .48951 .75639 .48757 .75 .48444 Mtetra
.333 .759 .974 r
.75 .48444 .75639 .48757 .77176 .48608 .76552 .48399 Mtetra
.225 .72 .917 r
.76552 .48399 .77176 .48608 .78727 .48494 .78119 .4838 Mtetra
.137 .676 .842 r
.78119 .4838 .78727 .48494 .8029 .48398 .79697 .48356 Mtetra
.096 .652 .783 r
.79697 .48356 .8029 .48398 .81865 .48293 .81285 .48291 Mtetra
.118 .669 .767 r
.81285 .48291 .81865 .48293 .83448 .48151 .82878 .48149 Mtetra
.205 .733 .803 r
.82878 .48149 .83448 .48151 .85037 .4794 .84473 .47896 Mtetra
.348 .823 .874 r
.84473 .47896 .85037 .4794 .86626 .47636 .86065 .47508 Mtetra
.51 .901 .942 r
.86065 .47508 .86626 .47636 .88214 .47218 .87651 .46976 Mtetra
.641 .931 .97 r
.87651 .46976 .88214 .47218 .89798 .46682 .8923 .46304 Mtetra
.718 .916 .962 r
.8923 .46304 .89798 .46682 .91377 .46033 .90802 .45515 Mtetra
.753 .881 .937 r
.90802 .45515 .91377 .46033 .92952 .4529 .92369 .44637 Mtetra
.764 .845 .912 r
.92369 .44637 .92952 .4529 .94524 .44478 .93936 .4371 Mtetra
.762 .813 .894 r
.93936 .4371 .94524 .44478 .96097 .43628 .95505 .42768 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55703 .45418 .5493 Mtetra
.45418 .5493 .46198 .55703 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.663 .741 .908 r
.49552 .5366 .50318 .54444 .51705 .54021 .50944 .53233 Mtetra
.50944 .53233 .51705 .54021 .531 .53595 .52343 .52804 Mtetra
.52343 .52804 .531 .53595 .54501 .53167 .53749 .52373 Mtetra
.53749 .52373 .54501 .53167 .5591 .52738 .55162 .51941 Mtetra
.662 .742 .909 r
.55162 .51941 .5591 .52738 .57325 .52308 .56583 .5151 Mtetra
.661 .742 .91 r
.56583 .5151 .57325 .52308 .58748 .51878 .58011 .5108 Mtetra
.659 .743 .912 r
.58011 .5108 .58748 .51878 .60179 .5145 .59446 .50655 Mtetra
.656 .744 .914 r
.59446 .50655 .60179 .5145 .61617 .51025 .6089 .5024 Mtetra
.651 .745 .919 r
.6089 .5024 .61617 .51025 .63063 .50609 .62342 .4984 Mtetra
.643 .748 .926 r
.62342 .4984 .63063 .50609 .64518 .50206 .63802 .49464 Mtetra
.63 .753 .936 r
.63802 .49464 .64518 .50206 .65981 .49823 .65273 .49123 Mtetra
.61 .759 .95 r
.65273 .49123 .65981 .49823 .67454 .4947 .66754 .48827 Mtetra
.58 .766 .967 r
.66754 .48827 .67454 .4947 .68937 .49156 .68247 .4859 Mtetra
.533 .773 .986 r
.68247 .4859 .68937 .49156 .70432 .48891 .69754 .4842 Mtetra
.46 .774 .997 r
.69754 .4842 .70432 .48891 .7194 .48682 .71275 .48323 Mtetra
.35 .754 .983 r
.71275 .48323 .7194 .48682 .73463 .48534 .72812 .48298 Mtetra
.205 .7 .918 r
.72812 .48298 .73463 .48534 .75 .48444 .74366 .48331 Mtetra
.055 .615 .802 r
.74366 .48331 .75 .48444 .76552 .48399 .75935 .48399 Mtetra
.056 0 0 r
.75935 .48399 .76552 .48399 .78119 .4838 .77517 .48467 Mtetra
.103 0 0 r
.77517 .48467 .78119 .4838 .79697 .48356 .7911 .48494 Mtetra
.082 0 0 r
.7911 .48494 .79697 .48356 .81285 .48291 .80709 .48433 Mtetra
0 0 0 r
.80709 .48433 .81285 .48291 .82878 .48149 .82309 .48244 Mtetra
.18 .711 .724 r
.82309 .48244 .82878 .48149 .84473 .47896 .83905 .47896 Mtetra
.401 .856 .859 r
.83905 .47896 .84473 .47896 .86065 .47508 .85494 .47373 Mtetra
.6 .939 .944 r
.85494 .47373 .86065 .47508 .87651 .46976 .87074 .46682 Mtetra
.718 .94 .957 r
.87074 .46682 .87651 .46976 .8923 .46304 .88645 .45843 Mtetra
.768 .902 .935 r
.88645 .45843 .8923 .46304 .90802 .45515 .90208 .44893 Mtetra
.782 .858 .907 r
.90208 .44893 .90802 .45515 .92369 .44637 .91768 .43878 Mtetra
.779 .821 .885 r
.91768 .43878 .92369 .44637 .93936 .4371 .93329 .4284 Mtetra
.769 .792 .872 r
.93329 .4284 .93936 .4371 .95505 .42768 .94896 .4182 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53299 Mtetra
.663 .741 .908 r
.47389 .53299 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53233 .50175 .52438 Mtetra
.50175 .52438 .50944 .53233 .52343 .52804 .51578 .52006 Mtetra
.51578 .52006 .52343 .52804 .53749 .52373 .52989 .51572 Mtetra
.662 .742 .909 r
.52989 .51572 .53749 .52373 .55162 .51941 .54407 .51139 Mtetra
.661 .742 .91 r
.54407 .51139 .55162 .51941 .56583 .5151 .55833 .50709 Mtetra
.659 .743 .912 r
.55833 .50709 .56583 .5151 .58011 .5108 .57266 .50284 Mtetra
.655 .744 .915 r
.57266 .50284 .58011 .5108 .59446 .50655 .58707 .4987 Mtetra
.649 .746 .92 r
.58707 .4987 .59446 .50655 .6089 .5024 .60156 .49473 Mtetra
.64 .749 .928 r
.60156 .49473 .6089 .5024 .62342 .4984 .61614 .49104 Mtetra
.625 .753 .939 r
.61614 .49104 .62342 .4984 .63802 .49464 .63082 .48775 Mtetra
.601 .76 .954 r
.63082 .48775 .63802 .49464 .65273 .49123 .6456 .48499 Mtetra
.564 .767 .974 r
.6456 .48499 .65273 .49123 .66754 .48827 .66051 .4829 Mtetra
.502 .771 .992 r
.66051 .4829 .66754 .48827 .68247 .4859 .67556 .48162 Mtetra
.401 .76 .994 r
.67556 .48162 .68247 .4859 .69754 .4842 .69076 .48121 Mtetra
.246 .711 .947 r
.69076 .48121 .69754 .4842 .71275 .48323 .70613 .48166 Mtetra
.051 .606 .819 r
.70613 .48166 .71275 .48323 .72812 .48298 .72167 .48285 Mtetra
.126 0 0 r
.72167 .48285 .72812 .48298 .74366 .48331 .73738 .48451 Mtetra
.236 0 0 r
.73738 .48451 .74366 .48331 .75935 .48399 .75324 .48625 Mtetra
.277 0 0 r
.75324 .48625 .75935 .48399 .77517 .48467 .76921 .48756 Mtetra
.255 0 0 r
.76921 .48756 .77517 .48467 .7911 .48494 .78526 .48792 Mtetra
.17 0 0 r
.78526 .48792 .7911 .48494 .80709 .48433 .80131 .4868 Mtetra
.002 0 0 r
.80131 .4868 .80709 .48433 .82309 .48244 .81733 .48382 Mtetra
.257 .76 .723 r
.81733 .48382 .82309 .48244 .83905 .47896 .83326 .47878 Mtetra
.534 .923 .889 r
.83326 .47878 .83905 .47896 .85494 .47373 .84908 .47169 Mtetra
.712 .96 .945 r
.84908 .47169 .85494 .47373 .87074 .46682 .86479 .4628 Mtetra
.783 .922 .929 r
.86479 .4628 .87074 .46682 .88645 .45843 .88039 .45252 Mtetra
.8 .87 .899 r
.88039 .45252 .88645 .45843 .90208 .44893 .89593 .44139 Mtetra
.796 .826 .875 r
.89593 .44139 .90208 .44893 .91768 .43878 .91146 .42994 Mtetra
.784 .794 .86 r
.91146 .42994 .91768 .43878 .93329 .4284 .92704 .41864 Mtetra
.77 .77 .853 r
.92704 .41864 .93329 .4284 .94896 .4182 .94272 .40788 Mtetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.663 .741 .908 r
.45217 .52935 .46007 .53726 .47389 .53299 .46604 .52504 Mtetra
.46604 .52504 .47389 .53299 .48778 .52869 .47998 .52071 Mtetra
.47998 .52071 .48778 .52869 .50175 .52438 .49399 .51637 Mtetra
.663 .741 .909 r
.49399 .51637 .50175 .52438 .51578 .52006 .50807 .51202 Mtetra
.662 .742 .909 r
.50807 .51202 .51578 .52006 .52989 .51572 .52222 .50767 Mtetra
.661 .742 .91 r
.52222 .50767 .52989 .51572 .54407 .51139 .53645 .50336 Mtetra
.658 .743 .912 r
.53645 .50336 .54407 .51139 .55833 .50709 .55076 .49911 Mtetra
.654 .744 .916 r
.55076 .49911 .55833 .50709 .57266 .50284 .56514 .49498 Mtetra
.647 .746 .921 r
.56514 .49498 .57266 .50284 .58707 .4987 .57961 .49105 Mtetra
.637 .749 .93 r
.57961 .49105 .58707 .4987 .60156 .49473 .59416 .48743 Mtetra
.619 .754 .942 r
.59416 .48743 .60156 .49473 .61614 .49104 .60881 .48425 Mtetra
.591 .76 .959 r
.60881 .48425 .61614 .49104 .63082 .48775 .62356 .48169 Mtetra
.545 .766 .98 r
.62356 .48169 .63082 .48775 .6456 .48499 .63844 .47991 Mtetra
.465 .765 .995 r
.63844 .47991 .6456 .48499 .66051 .4829 .65346 .47906 Mtetra
.328 .736 .98 r
.65346 .47906 .66051 .4829 .67556 .48162 .66864 .47925 Mtetra
.122 .644 .882 r
.66864 .47925 .67556 .48162 .69076 .48121 .684 .48046 Mtetra
.111 0 0 r
.684 .48046 .69076 .48121 .70613 .48166 .69954 .48258 Mtetra
.286 0 0 r
.69954 .48258 .70613 .48166 .72167 .48285 .71526 .48532 Mtetra
.378 0 0 r
.71526 .48532 .72167 .48285 .73738 .48451 .73115 .48823 Mtetra
.405 0 0 r
.73115 .48823 .73738 .48451 .75324 .48625 .74717 .49073 Mtetra
.383 0 0 r
.74717 .49073 .75324 .48625 .76921 .48756 .76327 .4922 Mtetra
.309 0 0 r
.76327 .4922 .76921 .48756 .78526 .48792 .77939 .492 Mtetra
.162 0 0 r
.77939 .492 .78526 .48792 .80131 .4868 .79547 .48965 Mtetra
0 0 0 r
.79547 .48965 .80131 .4868 .81733 .48382 .81145 .48488 Mtetra
.443 .876 .801 r
.81145 .48488 .81733 .48382 .83326 .47878 .82731 .47767 Mtetra
.698 .973 .922 r
.82731 .47767 .83326 .47878 .84908 .47169 .84301 .46827 Mtetra
.797 .94 .921 r
.84301 .46827 .84908 .47169 .86479 .4628 .85859 .45717 Mtetra
.819 .88 .889 r
.85859 .45717 .86479 .4628 .88039 .45252 .87409 .44498 Mtetra
.813 .83 .863 r
.87409 .44498 .88039 .45252 .89593 .44139 .88955 .43233 Mtetra
.799 .793 .846 r
.88955 .43233 .89593 .44139 .91146 .42994 .90504 .41981 Mtetra
.783 .768 .839 r
.90504 .41981 .91146 .42994 .92704 .41864 .92062 .40788 Mtetra
.766 .751 .839 r
.92062 .40788 .92704 .41864 .94272 .40788 .93634 .39684 Mtetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.663 .741 .908 r
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51703 Mtetra
.45811 .51703 .46604 .52504 .47998 .52071 .47209 .51266 Mtetra
.663 .741 .909 r
.47209 .51266 .47998 .52071 .49399 .51637 .48615 .5083 Mtetra
.662 .742 .909 r
.48615 .5083 .49399 .51637 .50807 .51202 .50028 .50394 Mtetra
.66 .742 .91 r
.50028 .50394 .50807 .51202 .52222 .50767 .51448 .49961 Mtetra
.658 .743 .913 r
.51448 .49961 .52222 .50767 .53645 .50336 .52876 .49535 Mtetra
.653 .744 .916 r
.52876 .49535 .53645 .50336 .55076 .49911 .54312 .49123 Mtetra
.646 .746 .922 r
.54312 .49123 .55076 .49911 .56514 .49498 .55755 .48733 Mtetra
.634 .75 .932 r
.55755 .48733 .56514 .49498 .57961 .49105 .57207 .48378 Mtetra
.614 .754 .945 r
.57207 .48378 .57961 .49105 .59416 .48743 .58669 .48073 Mtetra
.581 .761 .964 r
.58669 .48073 .59416 .48743 .60881 .48425 .60142 .47838 Mtetra
.524 .765 .985 r
.60142 .47838 .60881 .48425 .62356 .48169 .61626 .4769 Mtetra
.422 .755 .995 r
.61626 .4769 .62356 .48169 .63844 .47991 .63125 .4765 Mtetra
.244 .7 .952 r
.63125 .4765 .63844 .47991 .65346 .47906 .6464 .4773 Mtetra
0 .554 .789 r
.6464 .4773 .65346 .47906 .66864 .47925 .66174 .47931 Mtetra
.259 0 0 r
.66174 .47931 .66864 .47925 .684 .48046 .67727 .48243 Mtetra
.41 0 0 r
.67727 .48243 .684 .48046 .69954 .48258 .69299 .48633 Mtetra
.478 0 0 r
.69299 .48633 .69954 .48258 .71526 .48532 .7089 .49053 Mtetra
.493 0 0 r
.7089 .49053 .71526 .48532 .73115 .48823 .72496 .49436 Mtetra
.471 0 0 r
.72496 .49436 .73115 .48823 .74717 .49073 .74111 .49708 Mtetra
.409 0 0 r
.74111 .49708 .74717 .49073 .76327 .4922 .75729 .49795 Mtetra
.285 0 0 r
.75729 .49795 .76327 .4922 .77939 .492 .77344 .49638 Mtetra
.049 0 0 r
.77344 .49638 .77939 .492 .79547 .48965 .78948 .49198 Mtetra
.332 .796 .685 r
.78948 .49198 .79547 .48965 .81145 .48488 .80538 .48472 Mtetra
.675 .976 .889 r
.80538 .48472 .81145 .48488 .82731 .47767 .8211 .47484 Mtetra
.811 .955 .91 r
.8211 .47484 .82731 .47767 .84301 .46827 .83668 .46289 Mtetra
.837 .887 .877 r
.83668 .46289 .84301 .46827 .85859 .45717 .85214 .44956 Mtetra
.829 .83 .848 r
.85214 .44956 .85859 .45717 .87409 .44498 .86754 .43561 Mtetra
.813 .79 .831 r
.86754 .43561 .87409 .44498 .88955 .43233 .88295 .42174 Mtetra
.795 .763 .823 r
.88295 .42174 .88955 .43233 .90504 .41981 .89843 .4085 Mtetra
.777 .745 .824 r
.89843 .4085 .90504 .41981 .92062 .40788 .91405 .39628 Mtetra
.759 .735 .83 r
.91405 .39628 .92062 .40788 .93634 .39684 .92984 .38525 Mtetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.663 .741 .908 r
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51769 Mtetra
.42226 .51769 .43036 .5257 .4442 .52137 .43615 .51332 Mtetra
.43615 .51332 .4442 .52137 .45811 .51703 .45011 .50894 Mtetra
.663 .741 .909 r
.45011 .50894 .45811 .51703 .47209 .51266 .46414 .50456 Mtetra
.662 .742 .909 r
.46414 .50456 .47209 .51266 .48615 .5083 .47824 .50018 Mtetra
.66 .742 .911 r
.47824 .50018 .48615 .5083 .50028 .50394 .49242 .49584 Mtetra
.657 .743 .913 r
.49242 .49584 .50028 .50394 .51448 .49961 .50667 .49158 Mtetra
.652 .744 .917 r
.50667 .49158 .51448 .49961 .52876 .49535 .52099 .48747 Mtetra
.644 .746 .923 r
.52099 .48747 .52876 .49535 .54312 .49123 .5354 .4836 Mtetra
.631 .75 .933 r
.5354 .4836 .54312 .49123 .55755 .48733 .54989 .48011 Mtetra
.608 .755 .948 r
.54989 .48011 .55755 .48733 .57207 .48378 .56447 .47718 Mtetra
.57 .76 .968 r
.56447 .47718 .57207 .48378 .58669 .48073 .57916 .47502 Mtetra
.501 .762 .989 r
.57916 .47502 .58669 .48073 .60142 .47838 .59397 .47385 Mtetra
.374 .741 .99 r
.59397 .47385 .60142 .47838 .61626 .4769 .60892 .4739 Mtetra
.15 .651 .909 r
.60892 .4739 .61626 .4769 .63125 .4765 .62404 .47533 Mtetra
.144 0 0 r
.62404 .47533 .63125 .4765 .6464 .4773 .63934 .47817 Mtetra
.378 0 0 r
.63934 .47817 .6464 .4773 .66174 .47931 .65484 .48232 Mtetra
.499 0 0 r
.65484 .48232 .66174 .47931 .67727 .48243 .67056 .48746 Mtetra
.547 .032 0 r
.67056 .48746 .67727 .48243 .69299 .48633 .68647 .49304 Mtetra
.554 .065 .05 r
.68647 .49304 .69299 .48633 .7089 .49053 .70255 .49832 Mtetra
.532 .056 .072 r
.70255 .49832 .7089 .49053 .72496 .49436 .71875 .50244 Mtetra
.478 .003 .048 r
.71875 .50244 .72496 .49436 .74111 .49708 .73499 .50454 Mtetra
.374 0 0 r
.73499 .50454 .74111 .49708 .75729 .49795 .7512 .50388 Mtetra
.17 0 0 r
.7512 .50388 .75729 .49795 .77344 .49638 .76731 .5 Mtetra
0 0 0 r
.76731 .5 .77344 .49638 .78948 .49198 .78326 .49277 Mtetra
.643 .967 .846 r
.78326 .49277 .78948 .49198 .80538 .48472 .79903 .48245 Mtetra
.823 .967 .897 r
.79903 .48245 .80538 .48472 .8211 .47484 .81461 .46963 Mtetra
.853 .891 .864 r
.81461 .46963 .8211 .47484 .83668 .46289 .83004 .45511 Mtetra
.843 .827 .832 r
.83004 .45511 .83668 .46289 .85214 .44956 .8454 .43976 Mtetra
.825 .784 .814 r
.8454 .43976 .85214 .44956 .86754 .43561 .86074 .42442 Mtetra
.806 .756 .807 r
.86074 .42442 .86754 .43561 .88295 .42174 .87614 .40975 Mtetra
.787 .738 .808 r
.87614 .40975 .88295 .42174 .89843 .4085 .89166 .39622 Mtetra
.769 .728 .815 r
.89166 .39622 .89843 .4085 .91405 .39628 .90736 .38405 Mtetra
.751 .723 .827 r
.90736 .38405 .91405 .39628 .92984 .38525 .92325 .37331 Mtetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51836 Mtetra
.663 .741 .908 r
.38644 .51836 .3947 .52637 .40845 .52204 .40023 .51399 Mtetra
.40023 .51399 .40845 .52204 .42226 .51769 .41409 .50961 Mtetra
.41409 .50961 .42226 .51769 .43615 .51332 .42802 .50521 Mtetra
.663 .741 .909 r
.42802 .50521 .43615 .51332 .45011 .50894 .44203 .5008 Mtetra
.662 .742 .909 r
.44203 .5008 .45011 .50894 .46414 .50456 .4561 .49641 Mtetra
.66 .742 .911 r
.4561 .49641 .46414 .50456 .47824 .50018 .47025 .49206 Mtetra
.657 .743 .913 r
.47025 .49206 .47824 .50018 .49242 .49584 .48447 .48779 Mtetra
.652 .744 .917 r
.48447 .48779 .49242 .49584 .50667 .49158 .49877 .48368 Mtetra
.643 .746 .924 r
.49877 .48368 .50667 .49158 .52099 .48747 .51315 .47983 Mtetra
.628 .75 .935 r
.51315 .47983 .52099 .48747 .5354 .4836 .5276 .4764 Mtetra
.603 .755 .951 r
.5276 .4764 .5354 .4836 .54989 .48011 .54215 .47358 Mtetra
.559 .76 .972 r
.54215 .47358 .54989 .48011 .56447 .47718 .5568 .47161 Mtetra
.478 .757 .992 r
.5568 .47161 .56447 .47718 .57916 .47502 .57157 .47074 Mtetra
.322 .722 .98 r
.57157 .47074 .57916 .47502 .59397 .47385 .58647 .47123 Mtetra
.054 .592 .853 r
.58647 .47123 .59397 .47385 .60892 .4739 .60154 .47328 Mtetra
.259 0 0 r
.60154 .47328 .60892 .4739 .62404 .47533 .6168 .47696 Mtetra
.467 0 0 r
.6168 .47696 .62404 .47533 .63934 .47817 .63226 .48218 Mtetra
.561 .033 0 r
.63226 .48218 .63934 .47817 .65484 .48232 .64795 .4886 Mtetra
.595 .107 .066 r
.64795 .4886 .65484 .48232 .67056 .48746 .66385 .49563 Mtetra
.596 .134 .126 r
.66385 .49563 .67056 .48746 .68647 .49304 .67994 .50247 Mtetra
.575 .125 .146 r
.67994 .50247 .68647 .49304 .70255 .49832 .69617 .50812 Mtetra
.528 .078 .127 r
.69617 .50812 .70255 .49832 .71875 .50244 .71246 .5116 Mtetra
.44 0 .057 r
.71246 .5116 .71875 .50244 .73499 .50454 .72874 .51201 Mtetra
.263 0 0 r
.72874 .51201 .73499 .50454 .7512 .50388 .74492 .50877 Mtetra
0 0 0 r
.74492 .50877 .7512 .50388 .76731 .5 .76094 .50168 Mtetra
.606 .949 .797 r
.76094 .50168 .76731 .5 .78326 .49277 .77675 .49098 Mtetra
.835 .974 .883 r
.77675 .49098 .78326 .49277 .79903 .48245 .79235 .47731 Mtetra
.867 .89 .85 r
.79235 .47731 .79903 .48245 .81461 .46963 .80779 .46156 Mtetra
.854 .822 .816 r
.80779 .46156 .81461 .46963 .83004 .45511 .82311 .44475 Mtetra
.834 .776 .797 r
.82311 .44475 .83004 .45511 .8454 .43976 .8384 .42784 Mtetra
.814 .747 .789 r
.8384 .42784 .8454 .43976 .86074 .42442 .85372 .41163 Mtetra
.795 .729 .791 r
.85372 .41163 .86074 .42442 .87614 .40975 .86916 .39666 Mtetra
.776 .719 .799 r
.86916 .39666 .87614 .40975 .89166 .39622 .88477 .38325 Mtetra
.759 .715 .812 r
.88477 .38325 .89166 .39622 .90736 .38405 .90058 .37147 Mtetra
.741 .715 .827 r
.90058 .37147 .90736 .38405 .92325 .37331 .9166 .36123 Mtetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.663 .741 .908 r
.36434 .51466 .37272 .5227 .38644 .51836 .37811 .51027 Mtetra
.37811 .51027 .38644 .51836 .40023 .51399 .39194 .50587 Mtetra
.39194 .50587 .40023 .51399 .41409 .50961 .40584 .50145 Mtetra
.663 .741 .909 r
.40584 .50145 .41409 .50961 .42802 .50521 .41982 .49703 Mtetra
.662 .742 .909 r
.41982 .49703 .42802 .50521 .44203 .5008 .43387 .49262 Mtetra
.66 .742 .911 r
.43387 .49262 .44203 .5008 .4561 .49641 .44799 .48825 Mtetra
.657 .743 .913 r
.44799 .48825 .4561 .49641 .47025 .49206 .46218 .48398 Mtetra
.651 .744 .918 r
.46218 .48398 .47025 .49206 .48447 .48779 .47645 .47987 Mtetra
.642 .746 .925 r
.47645 .47987 .48447 .48779 .49877 .48368 .49079 .47604 Mtetra
.626 .75 .936 r
.49079 .47604 .49877 .48368 .51315 .47983 .50522 .47266 Mtetra
.598 .755 .953 r
.50522 .47266 .51315 .47983 .5276 .4764 .51973 .46993 Mtetra
.549 .759 .975 r
.51973 .46993 .5276 .4764 .54215 .47358 .53433 .46813 Mtetra
.454 .752 .993 r
.53433 .46813 .54215 .47358 .5568 .47161 .54905 .46754 Mtetra
.27 .7 .966 r
.54905 .46754 .5568 .47161 .57157 .47074 .5639 .46845 Mtetra
0 .527 .789 r
.5639 .46845 .57157 .47074 .58647 .47123 .57891 .4711 Mtetra
.353 0 0 r
.57891 .4711 .58647 .47123 .60154 .47328 .59411 .47561 Mtetra
.532 0 0 r
.59411 .47561 .60154 .47328 .6168 .47696 .60952 .48189 Mtetra
.605 .101 .027 r
.60952 .48189 .6168 .47696 .63226 .48218 .62516 .48961 Mtetra
.629 .164 .13 r
.62516 .48961 .63226 .48218 .64795 .4886 .64103 .49816 Mtetra
.627 .186 .182 r
.64103 .49816 .64795 .4886 .66385 .49563 .65711 .50662 Mtetra
.607 .177 .2 r
.65711 .50662 .66385 .49563 .67994 .50247 .67335 .51392 Mtetra
.565 .136 .185 r
.67335 .51392 .67994 .50247 .69617 .50812 .68968 .5189 Mtetra
.489 .047 .126 r
.68968 .5189 .69617 .50812 .71246 .5116 .70602 .52054 Mtetra
.335 0 0 r
.70602 .52054 .71246 .5116 .72874 .51201 .72227 .51808 Mtetra
0 0 0 r
.72227 .51808 .72874 .51201 .74492 .50877 .73836 .51126 Mtetra
.567 .925 .749 r
.73836 .51126 .74492 .50877 .76094 .50168 .75424 .50028 Mtetra
.845 .979 .871 r
.75424 .50028 .76094 .50168 .77675 .49098 .76989 .4858 Mtetra
.878 .886 .835 r
.76989 .4858 .77675 .49098 .79235 .47731 .78534 .46883 Mtetra
.862 .813 .799 r
.78534 .46883 .79235 .47731 .80779 .46156 .80065 .45051 Mtetra
.841 .766 .779 r
.80065 .45051 .80779 .46156 .82311 .44475 .8159 .43195 Mtetra
.82 .736 .772 r
.8159 .43195 .82311 .44475 .8384 .42784 .83117 .41409 Mtetra
.801 .719 .774 r
.83117 .41409 .8384 .42784 .85372 .41163 .84654 .39759 Mtetra
.783 .709 .782 r
.84654 .39759 .85372 .41163 .86916 .39666 .86207 .38283 Mtetra
.765 .706 .796 r
.86207 .38283 .86916 .39666 .88477 .38325 .87779 .36992 Mtetra
.748 .707 .813 r
.87779 .36992 .88477 .38325 .90058 .37147 .89374 .35878 Mtetra
.731 .711 .832 r
.89374 .35878 .90058 .37147 .9166 .36123 .90991 .34918 Mtetra
.664 .741 .908 r
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.663 .741 .908 r
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .50212 Mtetra
.36969 .50212 .37811 .51027 .39194 .50587 .38356 .49768 Mtetra
.663 .741 .909 r
.38356 .49768 .39194 .50587 .40584 .50145 .39751 .49324 Mtetra
.662 .742 .909 r
.39751 .49324 .40584 .50145 .41982 .49703 .41153 .48881 Mtetra
.66 .742 .911 r
.41153 .48881 .41982 .49703 .43387 .49262 .42563 .48443 Mtetra
.656 .743 .913 r
.42563 .48443 .43387 .49262 .44799 .48825 .43979 .48014 Mtetra
.651 .744 .918 r
.43979 .48014 .44799 .48825 .46218 .48398 .45403 .47602 Mtetra
.641 .746 .925 r
.45403 .47602 .46218 .48398 .47645 .47987 .46834 .47221 Mtetra
.624 .75 .937 r
.46834 .47221 .47645 .47987 .49079 .47604 .48273 .46886 Mtetra
.594 .755 .955 r
.48273 .46886 .49079 .47604 .50522 .47266 .4972 .46622 Mtetra
.539 .757 .977 r
.4972 .46622 .50522 .47266 .51973 .46993 .51176 .46457 Mtetra
.432 .746 .993 r
.51176 .46457 .51973 .46993 .53433 .46813 .52642 .46423 Mtetra
.219 .675 .948 r
.52642 .46423 .53433 .46813 .54905 .46754 .54121 .46553 Mtetra
0 .463 .724 r
.54121 .46553 .54905 .46754 .5639 .46845 .55615 .46875 Mtetra
.426 0 0 r
.55615 .46875 .5639 .46845 .57891 .4711 .57128 .47404 Mtetra
.579 .04 0 r
.57128 .47404 .57891 .4711 .59411 .47561 .58662 .48136 Mtetra
.637 .153 .086 r
.58662 .48136 .59411 .47561 .60952 .48189 .60219 .49038 Mtetra
.654 .207 .177 r
.60219 .49038 .60952 .48189 .62516 .48961 .61801 .50044 Mtetra
.65 .226 .224 r
.61801 .50044 .62516 .48961 .64103 .49816 .63405 .51058 Mtetra
.631 .217 .24 r
.63405 .51058 .64103 .49816 .65711 .50662 .65028 .51961 Mtetra
.594 .181 .228 r
.65028 .51961 .65711 .50662 .67335 .51392 .66664 .52622 Mtetra
.526 .102 .178 r
.66664 .52622 .67335 .51392 .68968 .5189 .68302 .52921 Mtetra
.391 0 .055 r
.68302 .52921 .68968 .5189 .70602 .52054 .69934 .52769 Mtetra
.074 0 0 r
.69934 .52769 .70602 .52054 .72227 .51808 .7155 .52127 Mtetra
.53 .899 .708 r
.7155 .52127 .72227 .51808 .73836 .51126 .73146 .51011 Mtetra
.855 .98 .861 r
.73146 .51011 .73836 .51126 .75424 .50028 .74717 .4949 Mtetra
.886 .878 .821 r
.74717 .4949 .75424 .50028 .76989 .4858 .76266 .47674 Mtetra
.867 .801 .783 r
.76266 .47674 .76989 .4858 .78534 .46883 .77798 .4569 Mtetra
.845 .754 .763 r
.77798 .4569 .78534 .46883 .80065 .45051 .79322 .43665 Mtetra
.824 .724 .755 r
.79322 .43665 .80065 .45051 .8159 .43195 .80845 .41707 Mtetra
.805 .707 .757 r
.80845 .41707 .8159 .43195 .83117 .41409 .82377 .39895 Mtetra
.788 .699 .766 r
.82377 .39895 .83117 .41409 .84654 .39759 .83923 .38276 Mtetra
.771 .696 .781 r
.83923 .38276 .84654 .39759 .86207 .38283 .85489 .36864 Mtetra
.754 .698 .799 r
.85489 .36864 .86207 .38283 .87779 .36992 .87076 .35653 Mtetra
.737 .704 .819 r
.87076 .35653 .87779 .36992 .89374 .35878 .88687 .34618 Mtetra
.721 .71 .84 r
.88687 .34618 .89374 .35878 .90991 .34918 .90319 .33728 Mtetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.663 .741 .908 r
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49835 Mtetra
.34734 .49835 .35588 .50654 .36969 .50212 .36119 .49389 Mtetra
.663 .741 .909 r
.36119 .49389 .36969 .50212 .38356 .49768 .37511 .48943 Mtetra
.662 .742 .909 r
.37511 .48943 .38356 .49768 .39751 .49324 .3891 .48499 Mtetra
.66 .742 .911 r
.3891 .48499 .39751 .49324 .41153 .48881 .40317 .48058 Mtetra
.656 .743 .914 r
.40317 .48058 .41153 .48881 .42563 .48443 .4173 .47628 Mtetra
.65 .744 .918 r
.4173 .47628 .42563 .48443 .43979 .48014 .43151 .47216 Mtetra
.64 .746 .926 r
.43151 .47216 .43979 .48014 .45403 .47602 .44579 .46834 Mtetra
.622 .75 .938 r
.44579 .46834 .45403 .47602 .46834 .47221 .46014 .46502 Mtetra
.59 .754 .956 r
.46014 .46502 .46834 .47221 .48273 .46886 .47456 .46244 Mtetra
.531 .756 .979 r
.47456 .46244 .48273 .46886 .4972 .46622 .48907 .46091 Mtetra
.412 .74 .992 r
.48907 .46091 .4972 .46622 .51176 .46457 .50368 .46078 Mtetra
.174 .651 .93 r
.50368 .46078 .51176 .46457 .52642 .46423 .5184 .46243 Mtetra
.19 0 0 r
.5184 .46243 .52642 .46423 .54121 .46553 .53327 .46616 Mtetra
.48 0 0 r
.53327 .46616 .54121 .46553 .55615 .46875 .54831 .47219 Mtetra
.613 .09 0 r
.54831 .47219 .55615 .46875 .57128 .47404 .56356 .48049 Mtetra
.661 .192 .129 r
.56356 .48049 .57128 .47404 .58662 .48136 .57904 .49075 Mtetra
.674 .241 .212 r
.57904 .49075 .58662 .48136 .60219 .49038 .59478 .5023 Mtetra
.669 .257 .255 r
.59478 .5023 .60219 .49038 .61801 .50044 .61076 .51414 Mtetra
.651 .249 .27 r
.61076 .51414 .61801 .50044 .63405 .51058 .62696 .52493 Mtetra
.617 .216 .26 r
.62696 .52493 .63405 .51058 .65028 .51961 .64331 .53325 Mtetra
.557 .145 .216 r
.64331 .53325 .65028 .51961 .66664 .52622 .65972 .53771 Mtetra
.436 0 .107 r
.65972 .53771 .66664 .52622 .68302 .52921 .6761 .53728 Mtetra
.141 0 0 r
.6761 .53728 .68302 .52921 .69934 .52769 .69234 .53141 Mtetra
.499 .877 .677 r
.69234 .53141 .69934 .52769 .7155 .52127 .70838 .52021 Mtetra
.864 .978 .854 r
.70838 .52021 .7155 .52127 .73146 .51011 .72417 .50438 Mtetra
.891 .867 .809 r
.72417 .50438 .73146 .51011 .74717 .4949 .73973 .48509 Mtetra
.869 .788 .768 r
.73973 .48509 .74717 .4949 .76266 .47674 .75509 .46375 Mtetra
.846 .74 .747 r
.75509 .46375 .76266 .47674 .77798 .4569 .77034 .44181 Mtetra
.825 .712 .739 r
.77034 .44181 .77798 .4569 .79322 .43665 .78556 .42048 Mtetra
.807 .695 .741 r
.78556 .42048 .79322 .43665 .80845 .41707 .80083 .40069 Mtetra
.79 .687 .75 r
.80083 .40069 .80845 .41707 .82377 .39895 .81625 .38299 Mtetra
.774 .685 .765 r
.81625 .38299 .82377 .39895 .83923 .38276 .83185 .3676 Mtetra
.758 .689 .785 r
.83185 .3676 .83923 .38276 .85489 .36864 .84766 .35446 Mtetra
.742 .695 .806 r
.84766 .35446 .85489 .36864 .87076 .35653 .86371 .34331 Mtetra
.726 .703 .829 r
.86371 .34331 .87076 .35653 .88687 .34618 .87997 .33381 Mtetra
.711 .712 .849 r
.87997 .33381 .88687 .34618 .90319 .33728 .89644 .32561 Mtetra
.663 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49903 Mtetra
.31114 .49903 .31985 .50722 .33356 .50279 .32489 .49457 Mtetra
.32489 .49457 .33356 .50279 .34734 .49835 .33871 .49009 Mtetra
.663 .741 .909 r
.33871 .49009 .34734 .49835 .36119 .49389 .35261 .48561 Mtetra
.662 .742 .909 r
.35261 .48561 .36119 .49389 .37511 .48943 .36657 .48114 Mtetra
.66 .742 .911 r
.36657 .48114 .37511 .48943 .3891 .48499 .38061 .47672 Mtetra
.656 .743 .914 r
.38061 .47672 .3891 .48499 .40317 .48058 .39471 .47239 Mtetra
.65 .744 .918 r
.39471 .47239 .40317 .48058 .4173 .47628 .40889 .46826 Mtetra
.64 .746 .926 r
.40889 .46826 .4173 .47628 .43151 .47216 .42313 .46444 Mtetra
.621 .75 .938 r
.42313 .46444 .43151 .47216 .44579 .46834 .43744 .46113 Mtetra
.588 .754 .957 r
.43744 .46113 .44579 .46834 .46014 .46502 .45183 .45859 Mtetra
.524 .754 .98 r
.45183 .45859 .46014 .46502 .47456 .46244 .46628 .45715 Mtetra
.396 .734 .991 r
.46628 .45715 .47456 .46244 .48907 .46091 .48083 .45719 Mtetra
.137 .629 .913 r
.48083 .45719 .48907 .46091 .50368 .46078 .49548 .45912 Mtetra
.243 0 0 r
.49548 .45912 .50368 .46078 .5184 .46243 .51026 .4633 Mtetra
.52 0 0 r
.51026 .4633 .5184 .46243 .53327 .46616 .5252 .46997 Mtetra
.638 .128 .02 r
.5252 .46997 .53327 .46616 .54831 .47219 .54034 .47916 Mtetra
.679 .222 .16 r
.54034 .47916 .54831 .47219 .56356 .48049 .55571 .49059 Mtetra
.689 .267 .237 r
.55571 .49059 .56356 .48049 .57904 .49075 .57134 .50357 Mtetra
.684 .281 .277 r
.57134 .50357 .57904 .49075 .59478 .5023 .58724 .51705 Mtetra
.667 .274 .292 r
.58724 .51705 .59478 .5023 .61076 .51414 .60337 .52962 Mtetra
.637 .244 .283 r
.60337 .52962 .61076 .51414 .62696 .52493 .61969 .53969 Mtetra
.582 .179 .244 r
.61969 .53969 .62696 .52493 .64331 .53325 .63611 .54572 Mtetra
.473 .044 .144 r
.63611 .54572 .64331 .53325 .65972 .53771 .65253 .5465 Mtetra
.197 0 0 r
.65253 .5465 .65972 .53771 .6761 .53728 .66885 .54134 Mtetra
.474 .862 .659 r
.66885 .54134 .6761 .53728 .69234 .53141 .68498 .53025 Mtetra
.871 .973 .851 r
.68498 .53025 .69234 .53141 .70838 .52021 .70087 .51393 Mtetra
.892 .853 .797 r
.70087 .51393 .70838 .52021 .72417 .50438 .71651 .49362 Mtetra
.868 .773 .754 r
.71651 .49362 .72417 .50438 .73973 .48509 .73194 .47087 Mtetra
.845 .726 .733 r
.73194 .47087 .73973 .48509 .75509 .46375 .74722 .44726 Mtetra
.825 .698 .725 r
.74722 .44726 .75509 .46375 .77034 .44181 .76246 .42419 Mtetra
.808 .683 .727 r
.76246 .42419 .77034 .44181 .78556 .42048 .77772 .40271 Mtetra
.792 .675 .736 r
.77772 .40271 .78556 .42048 .80083 .40069 .79311 .38347 Mtetra
.777 .674 .751 r
.79311 .38347 .80083 .40069 .81625 .38299 .80866 .36676 Mtetra
.762 .678 .77 r
.80866 .36676 .81625 .38299 .83185 .3676 .82443 .35253 Mtetra
.746 .686 .793 r
.82443 .35253 .83185 .3676 .84766 .35446 .84042 .34054 Mtetra
.73 .696 .817 r
.84042 .34054 .84766 .35446 .86371 .34331 .85664 .33042 Mtetra
.715 .706 .84 r
.85664 .33042 .86371 .34331 .87997 .33381 .87306 .32176 Mtetra
.701 .716 .86 r
.87306 .32176 .87997 .33381 .89644 .32561 .88967 .31417 Mtetra
.663 .741 .908 r
.28862 .49525 .29746 .50347 .31114 .49903 .30235 .49076 Mtetra
.30235 .49076 .31114 .49903 .32489 .49457 .31614 .48627 Mtetra
.663 .741 .909 r
.31614 .48627 .32489 .49457 .33871 .49009 .33 .48177 Mtetra
.662 .742 .909 r
.33 .48177 .33871 .49009 .35261 .48561 .34394 .47728 Mtetra
.66 .742 .911 r
.34394 .47728 .35261 .48561 .36657 .48114 .35794 .47283 Mtetra
.656 .743 .913 r
.35794 .47283 .36657 .48114 .38061 .47672 .37202 .46849 Mtetra
.65 .744 .918 r
.37202 .46849 .38061 .47672 .39471 .47239 .38616 .46433 Mtetra
.639 .746 .926 r
.38616 .46433 .39471 .47239 .40889 .46826 .40037 .46049 Mtetra
.621 .749 .939 r
.40037 .46049 .40889 .46826 .42313 .46444 .41465 .45718 Mtetra
.586 .753 .957 r
.41465 .45718 .42313 .46444 .43744 .46113 .42899 .45466 Mtetra
.52 .753 .981 r
.42899 .45466 .43744 .46113 .45183 .45859 .44339 .45327 Mtetra
.385 .729 .99 r
.44339 .45327 .45183 .45859 .46628 .45715 .45787 .45343 Mtetra
.109 .612 .9 r
.45787 .45343 .46628 .45715 .48083 .45719 .47244 .45558 Mtetra
.282 0 0 r
.47244 .45558 .48083 .45719 .49548 .45912 .48713 .46012 Mtetra
.548 0 0 r
.48713 .46012 .49548 .45912 .51026 .4633 .50196 .46734 Mtetra
.656 .156 .049 r
.50196 .46734 .51026 .4633 .5252 .46997 .51698 .47731 Mtetra
.693 .245 .182 r
.51698 .47731 .5252 .46997 .54034 .47916 .53222 .48977 Mtetra
.702 .287 .255 r
.53222 .48977 .54034 .47916 .55571 .49059 .54772 .50407 Mtetra
.697 .301 .293 r
.54772 .50407 .55571 .49059 .57134 .50357 .56349 .5191 Mtetra
.681 .295 .308 r
.56349 .5191 .57134 .50357 .58724 .51705 .57953 .53339 Mtetra
.653 .267 .3 r
.57953 .53339 .58724 .51705 .60337 .52962 .59579 .54522 Mtetra
.604 .207 .264 r
.59579 .54522 .60337 .52962 .61969 .53969 .61219 .55288 Mtetra
.504 .081 .171 r
.61219 .55288 .61969 .53969 .63611 .54572 .62864 .55497 Mtetra
.245 0 0 r
.62864 .55497 .63611 .54572 .65253 .5465 .64502 .55066 Mtetra
.459 .854 .658 r
.64502 .55066 .65253 .5465 .66885 .54134 .66124 .53985 Mtetra
.877 .964 .851 r
.66124 .53985 .66885 .54134 .68498 .53025 .67724 .52322 Mtetra
.89 .836 .786 r
.67724 .52322 .68498 .53025 .70087 .51393 .69298 .50204 Mtetra
.864 .757 .742 r
.69298 .50204 .70087 .51393 .71651 .49362 .7085 .47799 Mtetra
.841 .712 .72 r
.7085 .47799 .71651 .49362 .73194 .47087 .72386 .4528 Mtetra
.823 .685 .712 r
.72386 .4528 .73194 .47087 .74722 .44726 .73914 .42803 Mtetra
.806 .67 .713 r
.73914 .42803 .74722 .44726 .76246 .42419 .75442 .40488 Mtetra
.792 .664 .722 r
.75442 .40488 .76246 .42419 .77772 .40271 .76979 .38411 Mtetra
.778 .663 .737 r
.76979 .38411 .77772 .40271 .79311 .38347 .78533 .36606 Mtetra
.764 .668 .757 r
.78533 .36606 .79311 .38347 .80866 .36676 .80106 .35072 Mtetra
.749 .677 .78 r
.80106 .35072 .80866 .36676 .82443 .35253 .81701 .33786 Mtetra
.734 .688 .806 r
.81701 .33786 .82443 .35253 .84042 .34054 .83318 .32708 Mtetra
.719 .699 .831 r
.83318 .32708 .84042 .34054 .85664 .33042 .84956 .31794 Mtetra
.705 .71 .853 r
.84956 .31794 .85664 .33042 .87306 .32176 .86613 .31002 Mtetra
.692 .72 .871 r
.86613 .31002 .87306 .32176 .88967 .31417 .88288 .30296 Mtetra
.663 .741 .908 r
.2797 .48695 .28862 .49525 .30235 .49076 .29346 .48243 Mtetra
.663 .741 .909 r
.29346 .48243 .30235 .49076 .31614 .48627 .3073 .47791 Mtetra
.662 .742 .909 r
.3073 .47791 .31614 .48627 .33 .48177 .32121 .47339 Mtetra
.66 .742 .911 r
.32121 .47339 .33 .48177 .34394 .47728 .33518 .46893 Mtetra
.656 .743 .913 r
.33518 .46893 .34394 .47728 .35794 .47283 .34923 .46456 Mtetra
.65 .744 .918 r
.34923 .46456 .35794 .47283 .37202 .46849 .36334 .46037 Mtetra
.64 .746 .926 r
.36334 .46037 .37202 .46849 .38616 .46433 .37751 .45651 Mtetra
.621 .749 .938 r
.37751 .45651 .38616 .46433 .40037 .46049 .39175 .45318 Mtetra
.586 .753 .957 r
.39175 .45318 .40037 .46049 .41465 .45718 .40604 .45065 Mtetra
.519 .752 .981 r
.40604 .45065 .41465 .45718 .42899 .45466 .4204 .44928 Mtetra
.38 .726 .989 r
.4204 .44928 .42899 .45466 .44339 .45327 .43481 .44951 Mtetra
.094 .601 .893 r
.43481 .44951 .44339 .45327 .45787 .45343 .4493 .45179 Mtetra
.305 0 0 r
.4493 .45179 .45787 .45343 .47244 .45558 .46389 .45659 Mtetra
.567 .003 0 r
.46389 .45659 .47244 .45558 .48713 .46012 .4786 .46423 Mtetra
.67 .176 .067 r
.4786 .46423 .48713 .46012 .50196 .46734 .49348 .47484 Mtetra
.704 .262 .197 r
.49348 .47484 .50196 .46734 .51698 .47731 .50857 .48819 Mtetra
.713 .302 .268 r
.50857 .48819 .51698 .47731 .53222 .48977 .52392 .50364 Mtetra
.708 .316 .305 r
.52392 .50364 .53222 .48977 .54772 .50407 .53954 .52009 Mtetra
.694 .311 .319 r
.53954 .52009 .54772 .50407 .56349 .5191 .55545 .53599 Mtetra
.668 .286 .312 r
.55545 .53599 .56349 .5191 .57953 .53339 .57162 .54952 Mtetra
.623 .23 .278 r
.57162 .54952 .57953 .53339 .59579 .54522 .58797 .55882 Mtetra
.532 .112 .19 r
.58797 .55882 .59579 .54522 .61219 .55288 .60442 .56231 Mtetra
.285 0 0 r
.60442 .56231 .61219 .55288 .62864 .55497 .62085 .55899 Mtetra
.452 .855 .674 r
.62085 .55899 .62864 .55497 .64502 .55066 .63716 .54863 Mtetra
.879 .951 .852 r
.63716 .54863 .64502 .55066 .66124 .53985 .65327 .53187 Mtetra
.884 .817 .777 r
.65327 .53187 .66124 .53985 .67724 .52322 .66914 .51001 Mtetra
.859 .74 .731 r
.66914 .51001 .67724 .52322 .69298 .50204 .68477 .48483 Mtetra
.837 .697 .709 r
.68477 .48483 .69298 .50204 .7085 .47799 .70023 .4582 Mtetra
.819 .672 .701 r
.70023 .4582 .7085 .47799 .72386 .4528 .71558 .43184 Mtetra
.804 .658 .702 r
.71558 .43184 .72386 .4528 .73914 .42803 .7309 .40708 Mtetra
.791 .652 .71 r
.7309 .40708 .73914 .42803 .75442 .40488 .7463 .3848 Mtetra
.778 .653 .724 r
.7463 .3848 .75442 .40488 .76979 .38411 .76183 .36542 Mtetra
.765 .658 .744 r
.76183 .36542 .76979 .38411 .78533 .36606 .77754 .34898 Mtetra
.751 .667 .768 r
.77754 .34898 .78533 .36606 .80106 .35072 .79345 .33524 Mtetra
.737 .679 .794 r
.79345 .33524 .80106 .35072 .81701 .33786 .80959 .32378 Mtetra
.722 .692 .821 r
.80959 .32378 .81701 .33786 .83318 .32708 .82593 .31415 Mtetra
.708 .705 .845 r
.82593 .31415 .83318 .32708 .84956 .31794 .84247 .30588 Mtetra
.695 .716 .865 r
.84247 .30588 .84956 .31794 .86613 .31002 .85918 .29857 Mtetra
.684 .724 .88 r
.85918 .29857 .86613 .31002 .88288 .30296 .87604 .29192 Mtetra
.663 .741 .909 r
.27069 .47857 .2797 .48695 .29346 .48243 .2845 .47403 Mtetra
.662 .742 .909 r
.2845 .47403 .29346 .48243 .3073 .47791 .29837 .46949 Mtetra
.66 .742 .911 r
.29837 .46949 .3073 .47791 .32121 .47339 .31232 .465 Mtetra
.657 .743 .913 r
.31232 .465 .32121 .47339 .33518 .46893 .32633 .4606 Mtetra
.651 .744 .918 r
.32633 .4606 .33518 .46893 .34923 .46456 .34041 .45639 Mtetra
.64 .746 .925 r
.34041 .45639 .34923 .46456 .36334 .46037 .35455 .45249 Mtetra
.621 .749 .938 r
.35455 .45249 .36334 .46037 .37751 .45651 .36875 .44912 Mtetra
.587 .752 .956 r
.36875 .44912 .37751 .45651 .39175 .45318 .383 .44656 Mtetra
.52 .751 .98 r
.383 .44656 .39175 .45318 .40604 .45065 .3973 .44517 Mtetra
.38 .724 .989 r
.3973 .44517 .40604 .45065 .4204 .44928 .41165 .4454 Mtetra
.09 .597 .893 r
.41165 .4454 .4204 .44928 .43481 .44951 .42606 .44775 Mtetra
.315 0 0 r
.42606 .44775 .43481 .44951 .4493 .45179 .44054 .4527 Mtetra
.577 .016 0 r
.44054 .4527 .4493 .45179 .46389 .45659 .45513 .46062 Mtetra
.679 .188 .076 r
.45513 .46062 .46389 .45659 .4786 .46423 .46986 .4717 Mtetra
.713 .273 .205 r
.46986 .4717 .4786 .46423 .49348 .47484 .48479 .48575 Mtetra
.721 .314 .275 r
.48479 .48575 .49348 .47484 .50857 .48819 .49996 .50216 Mtetra
.718 .329 .311 r
.49996 .50216 .50857 .48819 .52392 .50364 .51541 .51984 Mtetra
.705 .325 .326 r
.51541 .51984 .52392 .50364 .53954 .52009 .53116 .53719 Mtetra
.682 .301 .32 r
.53116 .53719 .53954 .52009 .55545 .53599 .54719 .55232 Mtetra
.641 .25 .287 r
.54719 .55232 .55545 .53599 .57162 .54952 .56346 .56321 Mtetra
.557 .137 .201 r
.56346 .56321 .57162 .54952 .58797 .55882 .57988 .56813 Mtetra
.32 0 0 r
.57988 .56813 .58797 .55882 .60442 .56231 .59634 .56591 Mtetra
.454 .865 .707 r
.59634 .56591 .60442 .56231 .62085 .55899 .61273 .55618 Mtetra
.876 .933 .855 r
.61273 .55618 .62085 .55899 .63716 .54863 .62896 .53949 Mtetra
.876 .797 .769 r
.62896 .53949 .63716 .54863 .65327 .53187 .64496 .51718 Mtetra
.851 .723 .722 r
.64496 .51718 .65327 .53187 .66914 .51001 .66074 .49108 Mtetra
.831 .683 .699 r
.66074 .49108 .66914 .51001 .68477 .48483 .67632 .4632 Mtetra
.814 .66 .691 r
.67632 .4632 .68477 .48483 .70023 .4582 .69177 .43538 Mtetra
.801 .647 .691 r
.69177 .43538 .70023 .4582 .71558 .43184 .70717 .40913 Mtetra
.788 .641 .699 r
.70717 .40913 .71558 .43184 .7309 .40708 .7226 .38542 Mtetra
.777 .642 .713 r
.7226 .38542 .7309 .40708 .7463 .3848 .73815 .36477 Mtetra
.765 .648 .732 r
.73815 .36477 .7463 .3848 .76183 .36542 .75386 .34724 Mtetra
.753 .658 .756 r
.75386 .34724 .76183 .36542 .77754 .34898 .76976 .33263 Mtetra
.739 .671 .784 r
.76976 .33263 .77754 .34898 .79345 .33524 .78587 .32049 Mtetra
.725 .685 .811 r
.78587 .32049 .79345 .33524 .80959 .32378 .80218 .31036 Mtetra
.711 .699 .837 r
.80218 .31036 .80959 .32378 .82593 .31415 .81868 .30173 Mtetra
.698 .712 .859 r
.81868 .30173 .82593 .31415 .84247 .30588 .83536 .29418 Mtetra
.687 .722 .876 r
.83536 .29418 .84247 .30588 .85918 .29857 .85219 .28736 Mtetra
.678 .729 .888 r
.85219 .28736 .85918 .29857 .87604 .29192 .86917 .281 Mtetra
.662 .742 .909 r
.26159 .47013 .27069 .47857 .2845 .47403 .27544 .46557 Mtetra
.66 .742 .911 r
.27544 .46557 .2845 .47403 .29837 .46949 .28935 .46105 Mtetra
.657 .742 .913 r
.28935 .46105 .29837 .46949 .31232 .465 .30334 .45662 Mtetra
.651 .744 .917 r
.30334 .45662 .31232 .465 .32633 .4606 .31738 .45237 Mtetra
.641 .745 .925 r
.31738 .45237 .32633 .4606 .34041 .45639 .33149 .44843 Mtetra
.622 .748 .937 r
.33149 .44843 .34041 .45639 .35455 .45249 .34565 .44501 Mtetra
.589 .751 .955 r
.34565 .44501 .35455 .45249 .36875 .44912 .35986 .44239 Mtetra
.523 .75 .979 r
.35986 .44239 .36875 .44912 .383 .44656 .3741 .44094 Mtetra
.386 .725 .989 r
.3741 .44094 .383 .44656 .3973 .44517 .38839 .44112 Mtetra
.1 .601 .899 r
.38839 .44112 .3973 .44517 .41165 .4454 .40271 .44345 Mtetra
.311 0 0 r
.40271 .44345 .41165 .4454 .42606 .44775 .4171 .44843 Mtetra
.58 .018 0 r
.4171 .44843 .42606 .44775 .44054 .4527 .43156 .45649 Mtetra
.685 .194 .076 r
.43156 .45649 .44054 .4527 .45513 .46062 .44614 .46785 Mtetra
.72 .281 .207 r
.44614 .46785 .45513 .46062 .46986 .4717 .46089 .48239 Mtetra
.729 .322 .277 r
.46089 .48239 .46986 .4717 .48479 .48575 .47586 .49953 Mtetra
.726 .338 .314 r
.47586 .49953 .48479 .48575 .49996 .50216 .49111 .5182 Mtetra
.715 .335 .329 r
.49111 .5182 .49996 .50216 .51541 .51984 .50667 .5368 Mtetra
.694 .314 .324 r
.50667 .5368 .51541 .51984 .53116 .53719 .52255 .55335 Mtetra
.657 .265 .292 r
.52255 .55335 .53116 .53719 .54719 .55232 .5387 .56575 Mtetra
.579 .158 .206 r
.5387 .56575 .54719 .55232 .56346 .56321 .55506 .57209 Mtetra
.351 0 0 r
.55506 .57209 .56346 .56321 .57988 .56813 .57153 .57104 Mtetra
.463 .879 .754 r
.57153 .57104 .57988 .56813 .59634 .56591 .58798 .56209 Mtetra
.869 .911 .857 r
.58798 .56209 .59634 .56591 .61273 .55618 .60432 .54571 Mtetra
.864 .776 .762 r
.60432 .54571 .61273 .55618 .62896 .53949 .62046 .52319 Mtetra
.842 .707 .714 r
.62046 .52319 .62896 .53949 .64496 .51718 .63639 .49642 Mtetra
.823 .669 .691 r
.63639 .49642 .64496 .51718 .66074 .49108 .65212 .46751 Mtetra
.809 .647 .683 r
.65212 .46751 .66074 .49108 .67632 .4632 .6677 .43846 Mtetra
.796 .636 .683 r
.6677 .43846 .67632 .4632 .69177 .43538 .6832 .41087 Mtetra
.785 .631 .69 r
.6832 .41087 .69177 .43538 .70717 .40913 .69871 .38585 Mtetra
.775 .632 .703 r
.69871 .38585 .70717 .40913 .7226 .38542 .7143 .364 Mtetra
.764 .638 .722 r
.7143 .364 .7226 .38542 .73815 .36477 .73002 .34545 Mtetra
.753 .649 .746 r
.73002 .34545 .73815 .36477 .75386 .34724 .74592 .32998 Mtetra
.741 .662 .773 r
.74592 .32998 .75386 .34724 .76976 .33263 .76201 .31719 Mtetra
.727 .678 .802 r
.76201 .31719 .76976 .33263 .78587 .32049 .7783 .30657 Mtetra
.713 .694 .83 r
.7783 .30657 .78587 .32049 .80218 .31036 .79477 .29758 Mtetra
.7 .707 .853 r
.79477 .29758 .80218 .31036 .81868 .30173 .81142 .28978 Mtetra
.689 .719 .872 r
.81142 .28978 .81868 .30173 .83536 .29418 .82822 .28279 Mtetra
.68 .727 .886 r
.82822 .28279 .83536 .29418 .85219 .28736 .84517 .27631 Mtetra
.673 .732 .895 r
.84517 .27631 .85219 .28736 .86917 .281 .86224 .27014 Mtetra
.66 .742 .91 r
.2524 .46163 .26159 .47013 .27544 .46557 .26628 .45709 Mtetra
.657 .742 .913 r
.26628 .45709 .27544 .46557 .28935 .46105 .28024 .45262 Mtetra
.652 .743 .917 r
.28024 .45262 .28935 .46105 .30334 .45662 .29425 .44833 Mtetra
.642 .745 .924 r
.29425 .44833 .30334 .45662 .31738 .45237 .30833 .44434 Mtetra
.624 .748 .936 r
.30833 .44434 .31738 .45237 .33149 .44843 .32245 .44085 Mtetra
.592 .751 .953 r
.32245 .44085 .33149 .44843 .34565 .44501 .33661 .43815 Mtetra
.529 .75 .977 r
.33661 .43815 .34565 .44501 .35986 .44239 .35081 .4366 Mtetra
.398 .726 .99 r
.35081 .4366 .35986 .44239 .3741 .44094 .36503 .43667 Mtetra
.121 .611 .91 r
.36503 .43667 .3741 .44094 .38839 .44112 .37928 .43889 Mtetra
.292 0 0 r
.37928 .43889 .38839 .44112 .40271 .44345 .39356 .44379 Mtetra
.576 .01 0 r
.39356 .44379 .40271 .44345 .4171 .44843 .40789 .45184 Mtetra
.687 .193 .067 r
.40789 .45184 .4171 .44843 .43156 .45649 .42232 .46329 Mtetra
.725 .283 .202 r
.42232 .46329 .43156 .45649 .44614 .46785 .43689 .47807 Mtetra
.735 .327 .275 r
.43689 .47807 .44614 .46785 .46089 .48239 .45166 .49569 Mtetra
.734 .344 .313 r
.45166 .49569 .46089 .48239 .47586 .49953 .46669 .51508 Mtetra
.724 .343 .329 r
.46669 .51508 .47586 .49953 .49111 .5182 .48204 .53466 Mtetra
.705 .324 .324 r
.48204 .53466 .49111 .5182 .50667 .5368 .49772 .55242 Mtetra
.672 .278 .292 r
.49772 .55242 .50667 .5368 .52255 .55335 .51373 .56617 Mtetra
.6 .174 .205 r
.51373 .56617 .52255 .55335 .5387 .56575 .52999 .57387 Mtetra
.378 0 0 r
.52999 .57387 .5387 .56575 .55506 .57209 .54643 .57404 Mtetra
.478 .895 .813 r
.54643 .57404 .55506 .57209 .57153 .57104 .56293 .56602 Mtetra
.856 .884 .857 r
.56293 .56602 .57153 .57104 .58798 .56209 .57937 .55015 Mtetra
.851 .755 .756 r
.57937 .55015 .58798 .56209 .60432 .54571 .59566 .52769 Mtetra
.832 .691 .708 r
.59566 .52769 .60432 .54571 .62046 .52319 .61175 .50054 Mtetra
.815 .656 .685 r
.61175 .50054 .62046 .52319 .63639 .49642 .62764 .47088 Mtetra
.802 .636 .676 r
.62764 .47088 .63639 .49642 .65212 .46751 .64337 .44083 Mtetra
.791 .625 .675 r
.64337 .44083 .65212 .46751 .6677 .43846 .659 .41211 Mtetra
.782 .621 .682 r
.659 .41211 .6677 .43846 .6832 .41087 .6746 .38595 Mtetra
.772 .623 .694 r
.6746 .38595 .6832 .41087 .69871 .38585 .69025 .36302 Mtetra
.763 .629 .713 r
.69025 .36302 .69871 .38585 .7143 .364 .70602 .34352 Mtetra
.753 .64 .736 r
.70602 .34352 .7143 .364 .73002 .34545 .72193 .32727 Mtetra
.741 .654 .764 r
.72193 .32727 .73002 .34545 .74592 .32998 .73802 .31385 Mtetra
.729 .671 .793 r
.73802 .31385 .74592 .32998 .76201 .31719 .75429 .30274 Mtetra
.716 .688 .822 r
.75429 .30274 .76201 .31719 .7783 .30657 .77074 .29341 Mtetra
.702 .703 .848 r
.77074 .29341 .7783 .30657 .79477 .29758 .78736 .28536 Mtetra
.69 .715 .868 r
.78736 .28536 .79477 .29758 .81142 .28978 .80413 .27819 Mtetra
.681 .725 .883 r
.80413 .27819 .81142 .28978 .82822 .28279 .82104 .2716 Mtetra
.674 .731 .893 r
.82104 .2716 .82822 .28279 .84517 .27631 .83808 .26535 Mtetra
.67 .735 .899 r
.83808 .26535 .84517 .27631 .86224 .27014 .85524 .25929 Mtetra
.658 .742 .912 r
.24311 .4531 .2524 .46163 .26628 .45709 .25703 .4486 Mtetra
.652 .743 .916 r
.25703 .4486 .26628 .45709 .28024 .45262 .27102 .44427 Mtetra
.643 .745 .923 r
.27102 .44427 .28024 .45262 .29425 .44833 .28506 .44022 Mtetra
.626 .747 .934 r
.28506 .44022 .29425 .44833 .30833 .44434 .29914 .43665 Mtetra
.595 .75 .951 r
.29914 .43665 .30833 .44434 .32245 .44085 .31327 .43384 Mtetra
.536 .75 .974 r
.31327 .43384 .32245 .44085 .33661 .43815 .32742 .43215 Mtetra
.414 .729 .99 r
.32742 .43215 .33661 .43815 .35081 .4366 .34158 .43206 Mtetra
.153 .626 .926 r
.34158 .43206 .35081 .4366 .36503 .43667 .35575 .43409 Mtetra
.258 0 0 r
.35575 .43409 .36503 .43667 .37928 .43889 .36993 .4388 Mtetra
.563 0 0 r
.36993 .4388 .37928 .43889 .39356 .44379 .38414 .44667 Mtetra
.685 .185 .049 r
.38414 .44667 .39356 .44379 .40789 .45184 .39842 .45802 Mtetra
.728 .282 .192 r
.39842 .45802 .40789 .45184 .42232 .46329 .4128 .47282 Mtetra
.74 .329 .269 r
.4128 .47282 .42232 .46329 .43689 .47807 .42736 .49062 Mtetra
.74 .348 .309 r
.42736 .49062 .43689 .47807 .45166 .49569 .44217 .51043 Mtetra
.732 .349 .325 r
.44217 .51043 .45166 .49569 .46669 .51508 .45729 .5307 Mtetra
.716 .332 .321 r
.45729 .5307 .46669 .51508 .48204 .53466 .47276 .5494 Mtetra
.685 .288 .288 r
.47276 .5494 .48204 .53466 .49772 .55242 .48858 .5643 Mtetra
.619 .187 .198 r
.48858 .5643 .49772 .55242 .51373 .56617 .50473 .57326 Mtetra
.401 0 0 r
.50473 .57326 .51373 .56617 .52999 .57387 .52111 .57464 Mtetra
.493 .905 .875 r
.52111 .57464 .52999 .57387 .54643 .57404 .53762 .56766 Mtetra
.839 .854 .856 r
.53762 .56766 .54643 .57404 .56293 .56602 .55414 .5525 Mtetra
.837 .734 .751 r
.55414 .5525 .56293 .56602 .57937 .55015 .57057 .53037 Mtetra
.82 .675 .702 r
.57057 .53037 .57937 .55015 .59566 .52769 .58683 .50314 Mtetra
.807 .643 .68 r
.58683 .50314 .59566 .52769 .61175 .50054 .6029 .47304 Mtetra
.796 .625 .67 r
.6029 .47304 .61175 .50054 .62764 .47088 .6188 .44227 Mtetra
.786 .616 .669 r
.6188 .44227 .62764 .47088 .64337 .44083 .63457 .41267 Mtetra
.777 .612 .675 r
.63457 .41267 .64337 .44083 .659 .41211 .65029 .38557 Mtetra
.769 .614 .687 r
.65029 .38557 .659 .41211 .6746 .38595 .66603 .36172 Mtetra
.761 .621 .705 r
.66603 .36172 .6746 .38595 .69025 .36302 .68184 .34138 Mtetra
.751 .632 .728 r
.68184 .34138 .69025 .36302 .70602 .34352 .69778 .32442 Mtetra
.741 .647 .755 r
.69778 .32442 .70602 .34352 .72193 .32727 .71388 .31042 Mtetra
.73 .664 .785 r
.71388 .31042 .72193 .32727 .73802 .31385 .73014 .29887 Mtetra
.717 .682 .815 r
.73014 .29887 .73802 .31385 .75429 .30274 .74657 .2892 Mtetra
.704 .698 .842 r
.74657 .2892 .75429 .30274 .77074 .29341 .76317 .28091 Mtetra
.692 .712 .864 r
.76317 .28091 .77074 .29341 .78736 .28536 .77991 .27358 Mtetra
.682 .722 .88 r
.77991 .27358 .78736 .28536 .80413 .27819 .7968 .26686 Mtetra
.675 .73 .891 r
.7968 .26686 .80413 .27819 .82104 .2716 .81381 .26053 Mtetra
.67 .735 .898 r
.81381 .26053 .82104 .2716 .83808 .26535 .83094 .25441 Mtetra
.667 .737 .903 r
.83094 .25441 .83808 .26535 .85524 .25929 .84819 .24841 Mtetra
.653 .743 .916 r
.23373 .44456 .24311 .4531 .25703 .4486 .24768 .44018 Mtetra
.644 .744 .922 r
.24768 .44018 .25703 .4486 .27102 .44427 .26169 .43606 Mtetra
.629 .747 .932 r
.26169 .43606 .27102 .44427 .28506 .44022 .27574 .4324 Mtetra
.6 .749 .949 r
.27574 .4324 .28506 .44022 .29914 .43665 .28982 .42947 Mtetra
.545 .749 .971 r
.28982 .42947 .29914 .43665 .31327 .43384 .30392 .42762 Mtetra
.433 .733 .99 r
.30392 .42762 .31327 .43384 .32742 .43215 .31803 .42731 Mtetra
.193 .645 .944 r
.31803 .42731 .32742 .43215 .34158 .43206 .33213 .42908 Mtetra
0 .38 .677 r
.33213 .42908 .34158 .43206 .35575 .43409 .34622 .43348 Mtetra
.539 0 0 r
.34622 .43348 .35575 .43409 .36993 .4388 .36032 .44104 Mtetra
.679 .169 .021 r
.36032 .44104 .36993 .4388 .38414 .44667 .37445 .45208 Mtetra
.728 .275 .175 r
.37445 .45208 .38414 .44667 .39842 .45802 .38866 .46665 Mtetra
.744 .327 .257 r
.38866 .46665 .39842 .45802 .4128 .47282 .40301 .48436 Mtetra
.746 .349 .301 r
.40301 .48436 .4128 .47282 .42736 .49062 .41759 .50428 Mtetra
.739 .352 .318 r
.41759 .50428 .42736 .49062 .44217 .51043 .43247 .5249 Mtetra
.725 .337 .314 r
.43247 .5249 .44217 .51043 .45729 .5307 .4477 .54425 Mtetra
.698 .295 .28 r
.4477 .54425 .45729 .5307 .47276 .5494 .46332 .56005 Mtetra
.636 .195 .186 r
.46332 .56005 .47276 .5494 .48858 .5643 .47931 .5701 Mtetra
.42 0 0 r
.47931 .5701 .48858 .5643 .50473 .57326 .49561 .57265 Mtetra
.506 .902 .932 r
.49561 .57265 .50473 .57326 .52111 .57464 .51211 .56676 Mtetra
.818 .822 .853 r
.51211 .56676 .52111 .57464 .53762 .56766 .52869 .55251 Mtetra
.821 .713 .746 r
.52869 .55251 .53762 .56766 .55414 .5525 .54523 .53096 Mtetra
.809 .66 .698 r
.54523 .53096 .55414 .5525 .57057 .53037 .56165 .50397 Mtetra
.798 .632 .675 r
.56165 .50397 .57057 .53037 .58683 .50314 .5779 .47376 Mtetra
.789 .615 .666 r
.5779 .47376 .58683 .50314 .6029 .47304 .59398 .44259 Mtetra
.781 .607 .664 r
.59398 .44259 .6029 .47304 .6188 .44227 .60992 .41239 Mtetra
.773 .604 .67 r
.60992 .41239 .6188 .44227 .63457 .41267 .62577 .38458 Mtetra
.766 .606 .681 r
.62577 .38458 .63457 .41267 .65029 .38557 .64161 .36 Mtetra
.758 .613 .698 r
.64161 .36 .65029 .38557 .66603 .36172 .6575 .33896 Mtetra
.75 .624 .72 r
.6575 .33896 .66603 .36172 .68184 .34138 .67348 .32138 Mtetra
.741 .639 .747 r
.67348 .32138 .68184 .34138 .69778 .32442 .68959 .30687 Mtetra
.73 .657 .778 r
.68959 .30687 .69778 .32442 .71388 .31042 .70586 .29491 Mtetra
.718 .676 .808 r
.70586 .29491 .71388 .31042 .73014 .29887 .72228 .28494 Mtetra
.706 .694 .836 r
.72228 .28494 .73014 .29887 .74657 .2892 .73885 .27643 Mtetra
.694 .709 .86 r
.73885 .27643 .74657 .2892 .76317 .28091 .75557 .26893 Mtetra
.684 .72 .877 r
.75557 .26893 .76317 .28091 .77991 .27358 .77243 .2621 Mtetra
.676 .728 .889 r
.77243 .2621 .77991 .27358 .7968 .26686 .78941 .25569 Mtetra
.671 .734 .897 r
.78941 .25569 .7968 .26686 .81381 .26053 .80651 .24951 Mtetra
.667 .737 .902 r
.80651 .24951 .81381 .26053 .83094 .25441 .82373 .24346 Mtetra
.666 .739 .905 r
.82373 .24346 .83094 .25441 .84819 .24841 .84106 .23746 Mtetra
.646 .744 .921 r
.22423 .43606 .23373 .44456 .24768 .44018 .23821 .43188 Mtetra
.631 .746 .931 r
.23821 .43188 .24768 .44018 .26169 .43606 .25223 .42812 Mtetra
.605 .749 .946 r
.25223 .42812 .26169 .43606 .27574 .4324 .26628 .42505 Mtetra
.555 .749 .968 r
.26628 .42505 .27574 .4324 .28982 .42947 .28034 .423 Mtetra
.454 .736 .988 r
.28034 .423 .28982 .42947 .30392 .42762 .29439 .42244 Mtetra
.24 .665 .96 r
.29439 .42244 .30392 .42762 .31803 .42731 .30843 .42388 Mtetra
0 .431 .738 r
.30843 .42388 .31803 .42731 .33213 .42908 .32244 .42788 Mtetra
.502 0 0 r
.32244 .42788 .33213 .42908 .34622 .43348 .33643 .43497 Mtetra
.667 .144 0 r
.33643 .43497 .34622 .43348 .36032 .44104 .35042 .44553 Mtetra
.726 .263 .15 r
.35042 .44553 .36032 .44104 .37445 .45208 .36447 .45964 Mtetra
.746 .321 .24 r
.36447 .45964 .37445 .45208 .38866 .46665 .37862 .47697 Mtetra
.75 .347 .288 r
.37862 .47697 .38866 .46665 .40301 .48436 .39297 .49668 Mtetra
.746 .353 .307 r
.39297 .49668 .40301 .48436 .41759 .50428 .40761 .51733 Mtetra
.734 .339 .303 r
.40761 .51733 .41759 .50428 .43247 .5249 .4226 .53699 Mtetra
.71 .3 .268 r
.4226 .53699 .43247 .5249 .4477 .54425 .438 .55341 Mtetra
.652 .2 .166 r
.438 .55341 .4477 .54425 .46332 .56005 .45381 .56435 Mtetra
.432 0 0 r
.45381 .56435 .46332 .56005 .47931 .5701 .46999 .56797 Mtetra
.512 .884 .973 r
.46999 .56797 .47931 .5701 .49561 .57265 .48644 .56321 Mtetra
.795 .79 .848 r
.48644 .56321 .49561 .57265 .51211 .56676 .50305 .55 Mtetra
.804 .693 .743 r
.50305 .55 .51211 .56676 .52869 .55251 .5197 .52929 Mtetra
.797 .646 .695 r
.5197 .52929 .52869 .55251 .54523 .53096 .53627 .50283 Mtetra
.789 .621 .672 r
.53627 .50283 .54523 .53096 .56165 .50397 .55269 .47285 Mtetra
.781 .606 .662 r
.55269 .47285 .56165 .50397 .5779 .47376 .56895 .44162 Mtetra
.775 .599 .661 r
.56895 .44162 .5779 .47376 .59398 .44259 .58506 .41113 Mtetra
.768 .597 .666 r
.58506 .41113 .59398 .44259 .60992 .41239 .60106 .38286 Mtetra
.762 .599 .676 r
.60106 .38286 .60992 .41239 .62577 .38458 .61702 .35776 Mtetra
.755 .606 .692 r
.61702 .35776 .62577 .38458 .64161 .36 .63299 .33619 Mtetra
.748 .618 .714 r
.63299 .33619 .64161 .36 .6575 .33896 .64902 .31811 Mtetra
.74 .633 .741 r
.64902 .31811 .6575 .33896 .67348 .32138 .66516 .30317 Mtetra
.73 .651 .771 r
.66516 .30317 .67348 .32138 .68959 .30687 .68144 .29086 Mtetra
.719 .671 .802 r
.68144 .29086 .68959 .30687 .70586 .29491 .69785 .28061 Mtetra
.707 .69 .831 r
.69785 .28061 .70586 .29491 .72228 .28494 .71441 .2719 Mtetra
.695 .706 .856 r
.71441 .2719 .72228 .28494 .73885 .27643 .73111 .26425 Mtetra
.685 .718 .875 r
.73111 .26425 .73885 .27643 .75557 .26893 .74794 .25731 Mtetra
.677 .727 .888 r
.74794 .25731 .75557 .26893 .77243 .2621 .76489 .25082 Mtetra
.671 .733 .896 r
.76489 .25082 .77243 .2621 .78941 .25569 .78196 .24458 Mtetra
.668 .736 .901 r
.78196 .24458 .78941 .25569 .80651 .24951 .79915 .23849 Mtetra
.666 .739 .904 r
.79915 .23849 .80651 .24951 .82373 .24346 .81645 .23245 Mtetra
.665 .74 .906 r
.81645 .23245 .82373 .24346 .84106 .23746 .83385 .22643 Mtetra
.634 .746 .929 r
.21463 .42767 .22423 .43606 .23821 .43188 .22861 .42381 Mtetra
.61 .748 .943 r
.22861 .42381 .23821 .43188 .25223 .42812 .24263 .42058 Mtetra
.565 .749 .963 r
.24263 .42058 .25223 .42812 .26628 .42505 .25665 .41832 Mtetra
.477 .74 .986 r
.25665 .41832 .26628 .42505 .28034 .423 .27066 .41747 Mtetra
.289 .685 .974 r
.27066 .41747 .28034 .423 .29439 .42244 .28464 .41852 Mtetra
0 .488 .801 r
.28464 .41852 .29439 .42244 .30843 .42388 .29858 .42203 Mtetra
.448 0 0 r
.29858 .42203 .30843 .42388 .32244 .42788 .31248 .42855 Mtetra
.646 .108 0 r
.31248 .42855 .32244 .42788 .33643 .43497 .32635 .43845 Mtetra
.72 .243 .115 r
.32635 .43845 .33643 .43497 .35042 .44553 .34024 .45188 Mtetra
.746 .31 .217 r
.34024 .45188 .35042 .44553 .36447 .45964 .35421 .46857 Mtetra
.753 .342 .27 r
.35421 .46857 .36447 .45964 .37862 .47697 .36835 .48776 Mtetra
.751 .35 .292 r
.36835 .48776 .37862 .47697 .39297 .49668 .38274 .50809 Mtetra
.741 .339 .288 r
.38274 .50809 .39297 .49668 .40761 .51733 .39749 .52773 Mtetra
.72 .3 .25 r
.39749 .52773 .40761 .51733 .4226 .53699 .41266 .54446 Mtetra
.665 .199 .138 r
.41266 .54446 .4226 .53699 .438 .55341 .42827 .55605 Mtetra
.434 0 0 r
.42827 .55605 .438 .55341 .45381 .56435 .44431 .56061 Mtetra
.511 .851 .995 r
.44431 .56061 .45381 .56435 .46999 .56797 .46069 .55696 Mtetra
.77 .758 .842 r
.46069 .55696 .46999 .56797 .48644 .56321 .4773 .54489 Mtetra
.787 .675 .74 r
.4773 .54489 .48644 .56321 .50305 .55 .49401 .52522 Mtetra
.785 .633 .693 r
.49401 .52522 .50305 .55 .5197 .52929 .51071 .4996 Mtetra
.78 .611 .67 r
.51071 .4996 .5197 .52929 .53627 .50283 .5273 .47018 Mtetra
.774 .598 .66 r
.5273 .47018 .53627 .50283 .55269 .47285 .54373 .43922 Mtetra
.769 .591 .658 r
.54373 .43922 .55269 .47285 .56895 .44162 .56002 .40875 Mtetra
.763 .59 .662 r
.56002 .40875 .56895 .44162 .58506 .41113 .57617 .38032 Mtetra
.758 .593 .672 r
.57617 .38032 .58506 .41113 .60106 .38286 .59225 .35492 Mtetra
.752 .6 .688 r
.59225 .35492 .60106 .38286 .61702 .35776 .60831 .333 Mtetra
.746 .612 .709 r
.60831 .333 .61702 .35776 .63299 .33619 .62441 .31456 Mtetra
.738 .627 .736 r
.62441 .31456 .63299 .33619 .64902 .31811 .64059 .29929 Mtetra
.729 .646 .766 r
.64059 .29929 .64902 .31811 .66516 .30317 .65688 .28669 Mtetra
.719 .666 .797 r
.65688 .28669 .66516 .30317 .68144 .29086 .67329 .27621 Mtetra
.707 .686 .827 r
.67329 .27621 .68144 .29086 .69785 .28061 .68983 .26731 Mtetra
.696 .703 .852 r
.68983 .26731 .69785 .28061 .71441 .2719 .70651 .25953 Mtetra
.685 .716 .872 r
.70651 .25953 .71441 .2719 .73111 .26425 .72332 .25249 Mtetra
.677 .726 .886 r
.72332 .25249 .73111 .26425 .74794 .25731 .74024 .24592 Mtetra
.672 .732 .895 r
.74024 .24592 .74794 .25731 .76489 .25082 .75729 .23963 Mtetra
.668 .736 .901 r
.75729 .23963 .76489 .25082 .78196 .24458 .77444 .23349 Mtetra
.666 .738 .904 r
.77444 .23349 .78196 .24458 .79915 .23849 .79171 .22741 Mtetra
.665 .74 .906 r
.79171 .22741 .79915 .23849 .81645 .23245 .80909 .22136 Mtetra
.664 .741 .907 r
.80909 .22136 .81645 .23245 .83385 .22643 .82657 .2153 Mtetra
.616 .747 .94 r
.20489 .41947 .21463 .42767 .22861 .42381 .21887 .41608 Mtetra
.576 .749 .959 r
.21887 .41608 .22861 .42381 .24263 .42058 .23286 .4136 Mtetra
.499 .743 .982 r
.23286 .4136 .24263 .42058 .25665 .41832 .24683 .41242 Mtetra
.339 .702 .983 r
.24683 .41242 .25665 .41832 .27066 .41747 .26077 .41304 Mtetra
.024 .546 .862 r
.26077 .41304 .27066 .41747 .28464 .41852 .27465 .416 Mtetra
.374 0 0 r
.27465 .416 .28464 .41852 .29858 .42203 .28846 .42182 Mtetra
.614 .057 0 r
.28846 .42182 .29858 .42203 .31248 .42855 .30223 .43093 Mtetra
.709 .215 .068 r
.30223 .43093 .31248 .42855 .32635 .43845 .31599 .44349 Mtetra
.743 .294 .185 r
.31599 .44349 .32635 .43845 .34024 .45188 .3298 .4593 Mtetra
.755 .332 .245 r
.3298 .4593 .34024 .45188 .35421 .46857 .34373 .47767 Mtetra
.755 .344 .271 r
.34373 .47767 .35421 .46857 .36835 .48776 .35791 .49737 Mtetra
.748 .335 .267 r
.35791 .49737 .36835 .48776 .38274 .50809 .37242 .51665 Mtetra
.728 .297 .226 r
.37242 .51665 .38274 .50809 .39749 .52773 .38735 .53338 Mtetra
.674 .192 .1 r
.38735 .53338 .39749 .52773 .41266 .54446 .40275 .54536 Mtetra
.423 0 0 r
.40275 .54536 .41266 .54446 .42827 .55605 .41862 .55068 Mtetra
.503 .809 1 r
.41862 .55068 .42827 .55605 .44431 .56061 .4349 .54808 Mtetra
.745 .728 .836 r
.4349 .54808 .44431 .56061 .46069 .55696 .45148 .53721 Mtetra
.771 .658 .738 r
.45148 .53721 .46069 .55696 .4773 .54489 .46823 .51876 Mtetra
.773 .621 .692 r
.46823 .51876 .4773 .54489 .49401 .52522 .48503 .49422 Mtetra
.77 .601 .669 r
.48503 .49422 .49401 .52522 .51071 .4996 .50176 .46567 Mtetra
.767 .59 .659 r
.50176 .46567 .51071 .4996 .5273 .47018 .51836 .43532 Mtetra
.763 .585 .657 r
.51836 .43532 .5273 .47018 .54373 .43922 .53481 .40519 Mtetra
.758 .584 .66 r
.53481 .40519 .54373 .43922 .56002 .40875 .55111 .37687 Mtetra
.754 .587 .67 r
.55111 .37687 .56002 .40875 .57617 .38032 .56732 .35142 Mtetra
.749 .595 .685 r
.56732 .35142 .57617 .38032 .59225 .35492 .58348 .32934 Mtetra
.743 .606 .706 r
.58348 .32934 .59225 .35492 .60831 .333 .59965 .31068 Mtetra
.736 .622 .731 r
.59965 .31068 .60831 .333 .62441 .31456 .61587 .29518 Mtetra
.728 .641 .761 r
.61587 .29518 .62441 .31456 .64059 .29929 .63218 .28237 Mtetra
.719 .662 .793 r
.63218 .28237 .64059 .29929 .65688 .28669 .6486 .27171 Mtetra
.708 .682 .823 r
.6486 .27171 .65688 .28669 .67329 .27621 .66513 .26266 Mtetra
.696 .7 .849 r
.66513 .26266 .67329 .27621 .68983 .26731 .68179 .25476 Mtetra
.686 .714 .87 r
.68179 .25476 .68983 .26731 .70651 .25953 .69857 .24763 Mtetra
.678 .724 .884 r
.69857 .24763 .70651 .25953 .72332 .25249 .71547 .24099 Mtetra
.672 .731 .894 r
.71547 .24099 .72332 .25249 .74024 .24592 .73249 .23465 Mtetra
.668 .735 .9 r
.73249 .23465 .74024 .24592 .75729 .23963 .74961 .22846 Mtetra
.666 .738 .904 r
.74961 .22846 .75729 .23963 .77444 .23349 .76685 .22235 Mtetra
.665 .74 .906 r
.76685 .22235 .77444 .23349 .79171 .22741 .78419 .21626 Mtetra
.664 .74 .907 r
.78419 .21626 .79171 .22741 .80909 .22136 .80165 .21016 Mtetra
.664 .741 .907 r
.80165 .21016 .80909 .22136 .82657 .2153 .8192 .20405 Mtetra
.586 .748 .954 r
.19502 .41156 .20489 .41947 .21887 .41608 .20897 .40883 Mtetra
.52 .745 .977 r
.20897 .40883 .21887 .41608 .23286 .4136 .22291 .40731 Mtetra
.387 .716 .988 r
.22291 .40731 .23286 .4136 .24683 .41242 .23681 .40747 Mtetra
.117 .6 .913 r
.23681 .40747 .24683 .41242 .26077 .41304 .25064 .40982 Mtetra
.276 0 0 r
.25064 .40982 .26077 .41304 .27465 .416 .26439 .41488 Mtetra
.565 0 0 r
.26439 .41488 .27465 .416 .28846 .42182 .27808 .42307 Mtetra
.689 .174 .004 r
.27808 .42307 .28846 .42182 .30223 .43093 .29172 .43459 Mtetra
.736 .27 .142 r
.29172 .43459 .30223 .43093 .31599 .44349 .30538 .4493 Mtetra
.753 .316 .213 r
.30538 .4493 .31599 .44349 .3298 .4593 .31915 .46661 Mtetra
.757 .333 .243 r
.31915 .46661 .3298 .4593 .34373 .47767 .33312 .48539 Mtetra
.752 .326 .24 r
.33312 .48539 .34373 .47767 .35791 .49737 .3474 .50399 Mtetra
.734 .288 .193 r
.3474 .50399 .35791 .49737 .37242 .51665 .36211 .52041 Mtetra
.678 .178 .05 r
.36211 .52041 .37242 .51665 .38735 .53338 .37729 .53251 Mtetra
.394 0 0 r
.37729 .53251 .38735 .53338 .40275 .54536 .39298 .53839 Mtetra
.493 .763 .991 r
.39298 .53839 .40275 .54536 .41862 .55068 .40913 .53673 Mtetra
.721 .7 .83 r
.40913 .53673 .41862 .55068 .4349 .54808 .42565 .52708 Mtetra
.754 .642 .737 r
.42565 .52708 .4349 .54808 .45148 .53721 .44241 .50996 Mtetra
.761 .611 .692 r
.44241 .50996 .45148 .53721 .46823 .51876 .45927 .48673 Mtetra
.761 .593 .669 r
.45927 .48673 .46823 .51876 .48503 .49422 .47612 .45932 Mtetra
.759 .583 .659 r
.47612 .45932 .48503 .49422 .50176 .46567 .49286 .42988 Mtetra
.757 .579 .656 r
.49286 .42988 .50176 .46567 .51836 .43532 .50946 .40039 Mtetra
.753 .579 .659 r
.50946 .40039 .51836 .43532 .53481 .40519 .52591 .37247 Mtetra
.75 .582 .668 r
.52591 .37247 .53481 .40519 .55111 .37687 .54225 .34721 Mtetra
.745 .59 .683 r
.54225 .34721 .55111 .37687 .56732 .35142 .55851 .32517 Mtetra
.74 .602 .703 r
.55851 .32517 .56732 .35142 .58348 .32934 .57475 .30645 Mtetra
.734 .618 .728 r
.57475 .30645 .58348 .32934 .59965 .31068 .59102 .29084 Mtetra
.727 .637 .758 r
.59102 .29084 .59965 .31068 .61587 .29518 .60735 .27789 Mtetra
.718 .658 .789 r
.60735 .27789 .61587 .29518 .63218 .28237 .62377 .2671 Mtetra
.708 .679 .82 r
.62377 .2671 .63218 .28237 .6486 .27171 .6403 .25794 Mtetra
.697 .697 .847 r
.6403 .25794 .6486 .27171 .66513 .26266 .65694 .24994 Mtetra
.687 .712 .868 r
.65694 .24994 .66513 .26266 .68179 .25476 .6737 .24273 Mtetra
.678 .723 .883 r
.6737 .24273 .68179 .25476 .69857 .24763 .69057 .23603 Mtetra
.673 .73 .893 r
.69057 .23603 .69857 .24763 .71547 .24099 .70756 .22964 Mtetra
.669 .735 .9 r
.70756 .22964 .71547 .24099 .73249 .23465 .72466 .22341 Mtetra
.666 .738 .903 r
.72466 .22341 .73249 .23465 .74961 .22846 .74186 .21726 Mtetra
.665 .739 .906 r
.74186 .21726 .74961 .22846 .76685 .22235 .75917 .21113 Mtetra
.664 .74 .907 r
.75917 .21113 .76685 .22235 .78419 .21626 .77659 .205 Mtetra
.664 .741 .907 r
.77659 .205 .78419 .21626 .80165 .21016 .79412 .19885 Mtetra
.664 .741 .908 r
.79412 .19885 .80165 .21016 .8192 .20405 .81176 .19268 Mtetra
.54 .746 .971 r
.18499 .40405 .19502 .41156 .20897 .40883 .19889 .40218 Mtetra
.431 .727 .988 r
.19889 .40218 .20897 .40883 .22291 .40731 .21276 .40185 Mtetra
.208 .645 .95 r
.21276 .40185 .22291 .40731 .23681 .40747 .22655 .40355 Mtetra
0 .415 .734 r
.22655 .40355 .23681 .40747 .25064 .40982 .24026 .40778 Mtetra
.492 0 0 r
.24026 .40778 .25064 .40982 .26439 .41488 .25387 .41497 Mtetra
.657 .118 0 r
.25387 .41497 .26439 .41488 .27808 .42307 .26743 .42533 Mtetra
.723 .235 .084 r
.26743 .42533 .27808 .42307 .29172 .43459 .28098 .43877 Mtetra
.748 .293 .169 r
.28098 .43877 .29172 .43459 .30538 .4493 .2946 .4548 Mtetra
.756 .316 .206 r
.2946 .4548 .30538 .4493 .31915 .46661 .30839 .47239 Mtetra
.753 .312 .204 r
.30839 .47239 .31915 .46661 .33312 .48539 .32247 .49003 Mtetra
.736 .273 .151 r
.32247 .49003 .33312 .48539 .3474 .50399 .33696 .50584 Mtetra
.674 .153 0 r
.33696 .50584 .3474 .50399 .36211 .52041 .35194 .51779 Mtetra
.343 0 0 r
.35194 .51779 .36211 .52041 .37729 .53251 .36743 .52402 Mtetra
.483 .72 .975 r
.36743 .52402 .37729 .53251 .39298 .53839 .38344 .52317 Mtetra
.698 .675 .824 r
.38344 .52317 .39298 .53839 .40913 .53673 .39986 .51471 Mtetra
.738 .628 .736 r
.39986 .51471 .40913 .53673 .42565 .52708 .41659 .49899 Mtetra
.749 .601 .693 r
.41659 .49899 .42565 .52708 .44241 .50996 .43349 .47722 Mtetra
.752 .586 .67 r
.43349 .47722 .44241 .50996 .45927 .48673 .45041 .45119 Mtetra
.752 .578 .659 r
.45041 .45119 .45927 .48673 .47612 .45932 .46727 .42293 Mtetra
.751 .574 .656 r
.46727 .42293 .47612 .45932 .49286 .42988 .484 .39437 Mtetra
.748 .574 .659 r
.484 .39437 .49286 .42988 .50946 .40039 .50059 .36712 Mtetra
.745 .578 .668 r
.50059 .36712 .50946 .40039 .52591 .37247 .51704 .34228 Mtetra
.742 .586 .682 r
.51704 .34228 .52591 .37247 .54225 .34721 .5334 .32047 Mtetra
.738 .598 .702 r
.5334 .32047 .54225 .34721 .55851 .32517 .54971 .30185 Mtetra
.732 .614 .727 r
.54971 .30185 .55851 .32517 .57475 .30645 .56603 .28624 Mtetra
.725 .634 .756 r
.56603 .28624 .57475 .30645 .59102 .29084 .58239 .27324 Mtetra
.717 .655 .787 r
.58239 .27324 .59102 .29084 .60735 .27789 .59882 .26238 Mtetra
.707 .676 .818 r
.59882 .26238 .60735 .27789 .62377 .2671 .61534 .25313 Mtetra
.697 .695 .845 r
.61534 .25313 .62377 .2671 .6403 .25794 .63196 .24506 Mtetra
.687 .711 .866 r
.63196 .24506 .6403 .25794 .65694 .24994 .6487 .23779 Mtetra
.679 .722 .882 r
.6487 .23779 .65694 .24994 .6737 .24273 .66555 .23104 Mtetra
.673 .73 .893 r
.66555 .23104 .6737 .24273 .69057 .23603 .6825 .2246 Mtetra
.669 .735 .899 r
.6825 .2246 .69057 .23603 .70756 .22964 .69957 .21833 Mtetra
.666 .738 .903 r
.69957 .21833 .70756 .22964 .72466 .22341 .71674 .21214 Mtetra
.665 .739 .905 r
.71674 .21214 .72466 .22341 .74186 .21726 .73403 .20598 Mtetra
.664 .74 .907 r
.73403 .20598 .74186 .21726 .75917 .21113 .75141 .19982 Mtetra
.664 .741 .907 r
.75141 .19982 .75917 .21113 .77659 .205 .76891 .19364 Mtetra
.664 .741 .908 r
.76891 .19364 .77659 .205 .79412 .19885 .78651 .18743 Mtetra
.78651 .18743 .79412 .19885 .81176 .19268 .80423 .18118 Mtetra
.469 .735 .985 r
.17478 .39703 .18499 .40405 .19889 .40218 .18861 .39621 Mtetra
.291 .68 .974 r
.18861 .39621 .19889 .40218 .21276 .40185 .20238 .39724 Mtetra
0 .509 .833 r
.20238 .39724 .21276 .40185 .22655 .40355 .21605 .40062 Mtetra
.388 0 0 r
.21605 .40062 .22655 .40355 .24026 .40778 .22963 .40673 Mtetra
.606 .041 0 r
.22963 .40673 .24026 .40778 .25387 .41497 .24312 .41584 Mtetra
.699 .186 .007 r
.24312 .41584 .25387 .41497 .26743 .42533 .25658 .42789 Mtetra
.737 .259 .111 r
.25658 .42789 .26743 .42533 .28098 .43877 .27008 .44245 Mtetra
.75 .29 .157 r
.27008 .44245 .28098 .43877 .2946 .4548 .28372 .45864 Mtetra
.75 .289 .156 r
.28372 .45864 .2946 .4548 .30839 .47239 .29763 .47508 Mtetra
.732 .248 .094 r
.29763 .47508 .30839 .47239 .32247 .49003 .31192 .49003 Mtetra
.658 .115 0 r
.31192 .49003 .32247 .49003 .33696 .50584 .32669 .50157 Mtetra
0 .313 .654 r
.32669 .50157 .33696 .50584 .35194 .51779 .342 .50792 Mtetra
.474 .683 .957 r
.342 .50792 .35194 .51779 .36743 .52402 .35785 .50773 Mtetra
.676 .653 .82 r
.35785 .50773 .36743 .52402 .38344 .52317 .37416 .50037 Mtetra
.723 .615 .737 r
.37416 .50037 .38344 .52317 .39986 .51471 .39082 .48608 Mtetra
.738 .593 .694 r
.39082 .48608 .39986 .51471 .41659 .49899 .40771 .46589 Mtetra
.743 .58 .672 r
.40771 .46589 .41659 .49899 .43349 .47722 .42468 .44141 Mtetra
.745 .573 .661 r
.42468 .44141 .43349 .47722 .45041 .45119 .44162 .41455 Mtetra
.745 .57 .658 r
.44162 .41455 .45041 .45119 .46727 .42293 .45846 .38717 Mtetra
.743 .571 .66 r
.45846 .38717 .46727 .42293 .484 .39437 .47516 .36082 Mtetra
.741 .575 .669 r
.47516 .36082 .484 .39437 .50059 .36712 .49171 .33663 Mtetra
.738 .583 .682 r
.49171 .33663 .50059 .36712 .51704 .34228 .50816 .31524 Mtetra
.735 .596 .701 r
.50816 .31524 .51704 .34228 .5334 .32047 .52455 .29687 Mtetra
.73 .612 .726 r
.52455 .29687 .5334 .32047 .54971 .30185 .54091 .28137 Mtetra
.724 .631 .755 r
.54091 .28137 .54971 .30185 .56603 .28624 .55729 .26841 Mtetra
.716 .653 .786 r
.55729 .26841 .56603 .28624 .58239 .27324 .57373 .25753 Mtetra
.707 .674 .816 r
.57373 .25753 .58239 .27324 .59882 .26238 .59025 .24825 Mtetra
.696 .694 .843 r
.59025 .24825 .59882 .26238 .61534 .25313 .60686 .24013 Mtetra
.687 .709 .865 r
.60686 .24013 .61534 .25313 .63196 .24506 .62357 .23281 Mtetra
.679 .721 .881 r
.62357 .23281 .63196 .24506 .6487 .23779 .64039 .22601 Mtetra
.673 .729 .892 r
.64039 .22601 .6487 .23779 .66555 .23104 .65732 .21953 Mtetra
.669 .734 .899 r
.65732 .21953 .66555 .23104 .6825 .2246 .67436 .21322 Mtetra
.666 .737 .903 r
.67436 .21322 .6825 .2246 .69957 .21833 .6915 .20699 Mtetra
.665 .739 .905 r
.6915 .20699 .69957 .21833 .71674 .21214 .70875 .2008 Mtetra
.664 .74 .907 r
.70875 .2008 .71674 .21214 .73403 .20598 .7261 .1946 Mtetra
.664 .741 .907 r
.7261 .1946 .73403 .20598 .75141 .19982 .74357 .18839 Mtetra
.664 .741 .908 r
.74357 .18839 .75141 .19982 .76891 .19364 .76114 .18215 Mtetra
.76114 .18215 .76891 .19364 .78651 .18743 .77882 .17587 Mtetra
.77882 .17587 .78651 .18743 .80423 .18118 .79661 .16955 Mtetra
.364 .706 .985 r
.16437 .39058 .17478 .39703 .18861 .39621 .17812 .39095 Mtetra
.103 .587 .908 r
.17812 .39095 .18861 .39621 .20238 .39724 .19177 .39344 Mtetra
.253 0 0 r
.19177 .39344 .20238 .39724 .21605 .40062 .20532 .39846 Mtetra
.526 0 0 r
.20532 .39846 .21605 .40062 .22963 .40673 .21877 .40625 Mtetra
.659 .117 0 r
.21877 .40625 .22963 .40673 .24312 .41584 .23217 .41682 Mtetra
.715 .211 .034 r
.23217 .41682 .24312 .41584 .25658 .42789 .24558 .4298 Mtetra
.737 .253 .091 r
.24558 .4298 .25658 .42789 .27008 .44245 .25911 .44442 Mtetra
.74 .255 .092 r
.25911 .44442 .27008 .44245 .28372 .45864 .27287 .45946 Mtetra
.718 .21 .021 r
.27287 .45946 .28372 .45864 .29763 .47508 .287 .47332 Mtetra
.623 .059 0 r
.287 .47332 .29763 .47508 .31192 .49003 .30159 .48422 Mtetra
0 .368 .749 r
.30159 .48422 .31192 .49003 .32669 .50157 .31671 .49048 Mtetra
.469 .653 .94 r
.31671 .49048 .32669 .50157 .342 .50792 .33238 .49078 Mtetra
.657 .635 .816 r
.33238 .49078 .342 .50792 .35785 .50773 .34855 .48443 Mtetra
.708 .605 .739 r
.34855 .48443 .35785 .50773 .37416 .50037 .36513 .47153 Mtetra
.727 .586 .697 r
.36513 .47153 .37416 .50037 .39082 .48608 .38198 .45297 Mtetra
.735 .575 .675 r
.38198 .45297 .39082 .48608 .40771 .46589 .39896 .43017 Mtetra
.738 .569 .663 r
.39896 .43017 .40771 .46589 .42468 .44141 .41595 .40489 Mtetra
.739 .567 .66 r
.41595 .40489 .42468 .44141 .44162 .41455 .43286 .37887 Mtetra
.738 .568 .662 r
.43286 .37887 .44162 .41455 .45846 .38717 .44964 .35364 Mtetra
.737 .573 .67 r
.44964 .35364 .45846 .38717 .47516 .36082 .46629 .33029 Mtetra
.735 .581 .684 r
.46629 .33029 .47516 .36082 .49171 .33663 .48281 .3095 Mtetra
.732 .594 .702 r
.48281 .3095 .49171 .33663 .50816 .31524 .49926 .29151 Mtetra
.727 .61 .726 r
.49926 .29151 .50816 .31524 .52455 .29687 .51566 .27624 Mtetra
.722 .63 .755 r
.51566 .27624 .52455 .29687 .54091 .28137 .53207 .2634 Mtetra
.714 .651 .785 r
.53207 .2634 .54091 .28137 .55729 .26841 .54851 .25256 Mtetra
.706 .673 .816 r
.54851 .25256 .55729 .26841 .57373 .25753 .56503 .24328 Mtetra
.696 .693 .843 r
.56503 .24328 .57373 .25753 .59025 .24825 .58162 .23513 Mtetra
.687 .709 .865 r
.58162 .23513 .59025 .24825 .60686 .24013 .59831 .22778 Mtetra
.679 .72 .881 r
.59831 .22778 .60686 .24013 .62357 .23281 .61511 .22095 Mtetra
.673 .729 .892 r
.61511 .22095 .62357 .23281 .64039 .22601 .63201 .21442 Mtetra
.669 .734 .899 r
.63201 .21442 .64039 .22601 .65732 .21953 .64901 .20808 Mtetra
.667 .737 .903 r
.64901 .20808 .65732 .21953 .67436 .21322 .66612 .20182 Mtetra
.665 .739 .905 r
.66612 .20182 .67436 .21322 .6915 .20699 .68334 .19559 Mtetra
.664 .74 .907 r
.68334 .19559 .6915 .20699 .70875 .2008 .70066 .18936 Mtetra
.664 .741 .907 r
.70066 .18936 .70875 .2008 .7261 .1946 .71809 .18312 Mtetra
.664 .741 .908 r
.71809 .18312 .7261 .1946 .74357 .18839 .73563 .17684 Mtetra
.73563 .17684 .74357 .18839 .76114 .18215 .75328 .17053 Mtetra
.75328 .17053 .76114 .18215 .77882 .17587 .77104 .16418 Mtetra
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Mtetra
.221 .647 .955 r
.15377 .38469 .16437 .39058 .17812 .39095 .16742 .38632 Mtetra
0 .457 .788 r
.16742 .38632 .17812 .39095 .19177 .39344 .18095 .39023 Mtetra
.408 0 0 r
.18095 .39023 .19177 .39344 .20532 .39846 .19438 .39669 Mtetra
.593 .021 0 r
.19438 .39669 .20532 .39846 .21877 .40625 .20775 .40573 Mtetra
.677 .142 0 r
.20775 .40573 .21877 .40625 .23217 .41682 .2211 .41705 Mtetra
.712 .199 .003 r
.2211 .41705 .23217 .41682 .24558 .4298 .23455 .43 Mtetra
.718 .206 .007 r
.23455 .43 .24558 .4298 .25911 .44442 .2482 .44348 Mtetra
.69 .156 0 r
.2482 .44348 .25911 .44442 .27287 .45946 .26218 .45607 Mtetra
.563 0 0 r
.26218 .45607 .27287 .45946 .287 .47332 .2766 .46614 Mtetra
0 .42 .823 r
.2766 .46614 .287 .47332 .30159 .48422 .29155 .47211 Mtetra
.466 .63 .925 r
.29155 .47211 .30159 .48422 .31671 .49048 .30705 .47271 Mtetra
.641 .62 .814 r
.30705 .47271 .31671 .49048 .33238 .49078 .32308 .46724 Mtetra
.695 .597 .742 r
.32308 .46724 .33238 .49078 .34855 .48443 .33954 .45568 Mtetra
.717 .58 .701 r
.33954 .45568 .34855 .48443 .36513 .47153 .35632 .43873 Mtetra
.727 .571 .679 r
.35632 .43873 .36513 .47153 .38198 .45297 .37327 .41768 Mtetra
.731 .566 .667 r
.37327 .41768 .38198 .45297 .39896 .43017 .39027 .3941 Mtetra
.733 .564 .663 r
.39027 .3941 .39896 .43017 .41595 .40489 .40722 .36961 Mtetra
.733 .566 .665 r
.40722 .36961 .41595 .40489 .43286 .37887 .42407 .34565 Mtetra
.733 .571 .673 r
.42407 .34565 .43286 .37887 .44964 .35364 .44078 .32331 Mtetra
.731 .58 .686 r
.44078 .32331 .44964 .35364 .46629 .33029 .45736 .30326 Mtetra
.728 .593 .704 r
.45736 .30326 .46629 .33029 .48281 .3095 .47385 .28578 Mtetra
.725 .609 .728 r
.47385 .28578 .48281 .3095 .49926 .29151 .49029 .27085 Mtetra
.72 .629 .756 r
.49029 .27085 .49926 .29151 .51566 .27624 .50672 .2582 Mtetra
.713 .651 .786 r
.50672 .2582 .51566 .27624 .53207 .2634 .52317 .24746 Mtetra
.704 .672 .816 r
.52317 .24746 .53207 .2634 .54851 .25256 .53968 .23821 Mtetra
.695 .692 .843 r
.53968 .23821 .54851 .25256 .56503 .24328 .55626 .23008 Mtetra
.686 .708 .864 r
.55626 .23008 .56503 .24328 .58162 .23513 .57293 .22271 Mtetra
.679 .72 .88 r
.57293 .22271 .58162 .23513 .59831 .22778 .58969 .21584 Mtetra
.673 .728 .891 r
.58969 .21584 .59831 .22778 .61511 .22095 .60656 .20929 Mtetra
.669 .734 .898 r
.60656 .20929 .61511 .22095 .63201 .21442 .62354 .20291 Mtetra
.667 .737 .903 r
.62354 .20291 .63201 .21442 .64901 .20808 .64061 .19662 Mtetra
.665 .739 .905 r
.64061 .19662 .64901 .20808 .66612 .20182 .6578 .19036 Mtetra
.664 .74 .907 r
.6578 .19036 .66612 .20182 .68334 .19559 .67509 .1841 Mtetra
.664 .741 .907 r
.67509 .1841 .68334 .19559 .70066 .18936 .69249 .17782 Mtetra
.664 .741 .908 r
.69249 .17782 .70066 .18936 .71809 .18312 .70999 .17151 Mtetra
.70999 .17151 .71809 .18312 .73563 .17684 .72761 .16516 Mtetra
.72761 .16516 .73563 .17684 .75328 .17053 .74533 .15878 Mtetra
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Mtetra
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Mtetra
.063 .56 .889 r
.14297 .3793 .15377 .38469 .16742 .38632 .15651 .38213 Mtetra
0 .334 .662 r
.15651 .38213 .16742 .38632 .18095 .39023 .16994 .38727 Mtetra
.488 0 0 r
.16994 .38727 .18095 .39023 .19438 .39669 .18329 .39476 Mtetra
.612 .046 0 r
.18329 .39476 .19438 .39669 .20775 .40573 .19662 .4044 Mtetra
.666 .121 0 r
.19662 .4044 .20775 .40573 .2211 .41705 .21002 .41561 Mtetra
.677 .135 0 r
.21002 .41561 .2211 .41705 .23455 .43 .22358 .42744 Mtetra
.638 .078 0 r
.22358 .42744 .23455 .43 .2482 .44348 .23745 .43862 Mtetra
.469 0 0 r
.23745 .43862 .2482 .44348 .26218 .45607 .25174 .4477 Mtetra
.021 .464 .874 r
.25174 .4477 .26218 .45607 .2766 .46614 .26653 .45321 Mtetra
.467 .615 .912 r
.26653 .45321 .2766 .46614 .29155 .47211 .28186 .45395 Mtetra
.626 .61 .814 r
.28186 .45395 .29155 .47211 .30705 .47271 .29773 .4492 Mtetra
.683 .59 .746 r
.29773 .4492 .30705 .47271 .32308 .46724 .31406 .43887 Mtetra
.707 .577 .706 r
.31406 .43887 .32308 .46724 .33954 .45568 .33073 .42351 Mtetra
.719 .568 .684 r
.33073 .42351 .33954 .45568 .35632 .43873 .34763 .40421 Mtetra
.725 .564 .672 r
.34763 .40421 .35632 .43873 .37327 .41768 .36461 .38239 Mtetra
.728 .563 .668 r
.36461 .38239 .37327 .41768 .39027 .3941 .38157 .35953 Mtetra
.729 .565 .67 r
.38157 .35953 .39027 .3941 .40722 .36961 .39844 .33697 Mtetra
.729 .571 .677 r
.39844 .33697 .40722 .36961 .42407 .34565 .41519 .31577 Mtetra
.728 .58 .69 r
.41519 .31577 .42407 .34565 .44078 .32331 .43181 .29658 Mtetra
.725 .593 .708 r
.43181 .29658 .44078 .32331 .45736 .30326 .44834 .27973 Mtetra
.722 .61 .731 r
.44834 .27973 .45736 .30326 .47385 .28578 .46481 .26521 Mtetra
.717 .629 .758 r
.46481 .26521 .47385 .28578 .49029 .27085 .48125 .25282 Mtetra
.711 .651 .788 r
.48125 .25282 .49029 .27085 .50672 .2582 .4977 .24224 Mtetra
.703 .672 .817 r
.4977 .24224 .50672 .2582 .52317 .24746 .5142 .23307 Mtetra
.694 .692 .843 r
.5142 .23307 .52317 .24746 .53968 .23821 .53076 .22496 Mtetra
.686 .708 .865 r
.53076 .22496 .53968 .23821 .55626 .23008 .54741 .21758 Mtetra
.678 .72 .88 r
.54741 .21758 .55626 .23008 .57293 .22271 .56415 .2107 Mtetra
.673 .728 .891 r
.56415 .2107 .57293 .22271 .58969 .21584 .58099 .20412 Mtetra
.669 .734 .898 r
.58099 .20412 .58969 .21584 .60656 .20929 .59793 .19771 Mtetra
.667 .737 .903 r
.59793 .19771 .60656 .20929 .62354 .20291 .61497 .19139 Mtetra
.665 .739 .905 r
.61497 .19139 .62354 .20291 .64061 .19662 .63212 .18509 Mtetra
.664 .74 .906 r
.63212 .18509 .64061 .19662 .6578 .19036 .64938 .1788 Mtetra
.664 .741 .907 r
.64938 .1788 .6578 .19036 .67509 .1841 .66675 .17249 Mtetra
.664 .741 .908 r
.66675 .17249 .67509 .1841 .69249 .17782 .68422 .16614 Mtetra
.68422 .16614 .69249 .17782 .70999 .17151 .7018 .15977 Mtetra
.7018 .15977 .70999 .17151 .72761 .16516 .71949 .15335 Mtetra
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Mtetra
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Mtetra
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Mtetra
0 .471 .809 r
.13198 .37421 .14297 .3793 .15651 .38213 .14543 .37806 Mtetra
.337 0 0 r
.14543 .37806 .15651 .38213 .16994 .38727 .15879 .38405 Mtetra
.507 0 0 r
.15879 .38405 .16994 .38727 .18329 .39476 .17212 .39201 Mtetra
.588 .013 0 r
.17212 .39201 .18329 .39476 .19662 .4044 .18549 .40146 Mtetra
.606 .035 0 r
.18549 .40146 .19662 .4044 .21002 .41561 .19901 .41159 Mtetra
.552 0 0 r
.19901 .41159 .21002 .41561 .22358 .42744 .21279 .42129 Mtetra
0 .223 .622 r
.21279 .42129 .22358 .42744 .23745 .43862 .22696 .42925 Mtetra
.114 .502 .906 r
.22696 .42925 .23745 .43862 .25174 .4477 .24161 .43415 Mtetra
.472 .605 .903 r
.24161 .43415 .25174 .4477 .26653 .45321 .25679 .43487 Mtetra
.615 .602 .815 r
.25679 .43487 .26653 .45321 .28186 .45395 .2725 .4307 Mtetra
.672 .586 .751 r
.2725 .4307 .28186 .45395 .29773 .4492 .28868 .42146 Mtetra
.698 .574 .712 r
.28868 .42146 .29773 .4492 .31406 .43887 .30523 .4076 Mtetra
.711 .567 .69 r
.30523 .4076 .31406 .43887 .33073 .42351 .32204 .39002 Mtetra
.719 .563 .678 r
.32204 .39002 .33073 .42351 .34763 .40421 .33896 .36998 Mtetra
.722 .563 .673 r
.33896 .36998 .34763 .40421 .36461 .38239 .3559 .3488 Mtetra
.724 .566 .675 r
.3559 .3488 .36461 .38239 .38157 .35953 .37277 .32773 Mtetra
.725 .572 .682 r
.37277 .32773 .38157 .35953 .39844 .33697 .38953 .30775 Mtetra
.724 .581 .694 r
.38953 .30775 .39844 .33697 .41519 .31577 .40618 .28952 Mtetra
.722 .594 .712 r
.40618 .28952 .41519 .31577 .43181 .29658 .42273 .27338 Mtetra
.719 .611 .735 r
.42273 .27338 .43181 .29658 .44834 .27973 .43921 .25935 Mtetra
.715 .63 .762 r
.43921 .25935 .44834 .27973 .46481 .26521 .45566 .24729 Mtetra
.709 .652 .791 r
.45566 .24729 .46481 .26521 .48125 .25282 .47211 .2369 Mtetra
.702 .673 .819 r
.47211 .2369 .48125 .25282 .4977 .24224 .48859 .22784 Mtetra
.693 .692 .845 r
.48859 .22784 .4977 .24224 .5142 .23307 .50514 .21977 Mtetra
.685 .708 .865 r
.50514 .21977 .5142 .23307 .53076 .22496 .52176 .21241 Mtetra
.678 .72 .881 r
.52176 .21241 .53076 .22496 .54741 .21758 .53847 .20552 Mtetra
.673 .728 .891 r
.53847 .20552 .54741 .21758 .56415 .2107 .55528 .19892 Mtetra
.669 .734 .898 r
.55528 .19892 .56415 .2107 .58099 .20412 .57219 .19248 Mtetra
.666 .737 .903 r
.57219 .19248 .58099 .20412 .59793 .19771 .5892 .18613 Mtetra
.665 .739 .905 r
.5892 .18613 .59793 .19771 .61497 .19139 .60632 .1798 Mtetra
.664 .74 .906 r
.60632 .1798 .61497 .19139 .63212 .18509 .62354 .17348 Mtetra
.664 .741 .907 r
.62354 .17348 .63212 .18509 .64938 .1788 .64087 .16713 Mtetra
.664 .741 .908 r
.64087 .16713 .64938 .1788 .66675 .17249 .65831 .16075 Mtetra
.65831 .16075 .66675 .17249 .68422 .16614 .67586 .15434 Mtetra
.67586 .15434 .68422 .16614 .7018 .15977 .69351 .14789 Mtetra
.69351 .14789 .7018 .15977 .71949 .15335 .71128 .14141 Mtetra
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Mtetra
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Mtetra
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Mtetra
0 .41 .756 r
.12083 .36915 .13198 .37421 .14543 .37806 .13422 .37369 Mtetra
.351 0 0 r
.13422 .37369 .14543 .37806 .15879 .38405 .14757 .38001 Mtetra
.463 0 0 r
.14757 .38001 .15879 .38405 .17212 .39201 .16094 .38773 Mtetra
.491 0 0 r
.16094 .38773 .17212 .39201 .18549 .40146 .17444 .39616 Mtetra
.422 0 0 r
.17444 .39616 .18549 .40146 .19901 .41159 .18817 .40434 Mtetra
0 .335 .751 r
.18817 .40434 .19901 .41159 .21279 .42129 .20225 .4111 Mtetra
.196 .534 .924 r
.20225 .4111 .21279 .42129 .22696 .42925 .21678 .41528 Mtetra
.479 .602 .897 r
.21678 .41528 .22696 .42925 .24161 .43415 .23182 .41584 Mtetra
.606 .598 .817 r
.23182 .41584 .24161 .43415 .25679 .43487 .24737 .41209 Mtetra
.662 .585 .758 r
.24737 .41209 .25679 .43487 .2725 .4307 .2634 .40382 Mtetra
.69 .574 .72 r
.2634 .40382 .2725 .4307 .28868 .42146 .27981 .39133 Mtetra
.704 .567 .697 r
.27981 .39133 .28868 .42146 .30523 .4076 .2965 .3754 Mtetra
.713 .564 .685 r
.2965 .3754 .30523 .4076 .32204 .39002 .31334 .35709 Mtetra
.717 .564 .68 r
.31334 .35709 .32204 .39002 .33896 .36998 .33022 .3376 Mtetra
.72 .567 .681 r
.33022 .3376 .33896 .36998 .3559 .3488 .34706 .31804 Mtetra
.721 .573 .688 r
.34706 .31804 .3559 .3488 .37277 .32773 .36382 .29935 Mtetra
.721 .583 .7 r
.36382 .29935 .37277 .32773 .38953 .30775 .38047 .28215 Mtetra
.719 .596 .718 r
.38047 .28215 .38953 .30775 .40618 .28952 .39702 .26677 Mtetra
.717 .613 .74 r
.39702 .26677 .40618 .28952 .42273 .27338 .4135 .2533 Mtetra
.713 .633 .766 r
.4135 .2533 .42273 .27338 .43921 .25935 .42995 .24161 Mtetra
.707 .654 .794 r
.42995 .24161 .43921 .25935 .45566 .24729 .44639 .23145 Mtetra
.7 .674 .822 r
.44639 .23145 .45566 .24729 .47211 .2369 .46286 .22253 Mtetra
.692 .693 .847 r
.46286 .22253 .47211 .2369 .48859 .22784 .47938 .21453 Mtetra
.684 .708 .867 r
.47938 .21453 .48859 .22784 .50514 .21977 .49598 .2072 Mtetra
.677 .72 .881 r
.49598 .2072 .50514 .21977 .52176 .21241 .51266 .2003 Mtetra
.672 .728 .892 r
.51266 .2003 .52176 .21241 .53847 .20552 .52944 .19368 Mtetra
.669 .734 .899 r
.52944 .19368 .53847 .20552 .55528 .19892 .54632 .18722 Mtetra
.666 .737 .903 r
.54632 .18722 .55528 .19892 .57219 .19248 .56329 .18084 Mtetra
.665 .739 .905 r
.56329 .18084 .57219 .19248 .5892 .18613 .58038 .17448 Mtetra
.664 .74 .906 r
.58038 .17448 .5892 .18613 .60632 .1798 .59756 .16812 Mtetra
.664 .741 .907 r
.59756 .16812 .60632 .1798 .62354 .17348 .61486 .16174 Mtetra
.664 .741 .908 r
.61486 .16174 .62354 .17348 .64087 .16713 .63226 .15533 Mtetra
.63226 .15533 .64087 .16713 .65831 .16075 .64977 .14889 Mtetra
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Mtetra
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Mtetra
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Mtetra
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Mtetra
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Mtetra
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Mtetra
0 .401 .756 r
.10956 .36374 .12083 .36915 .13422 .37369 .12295 .36851 Mtetra
0 .291 .65 r
.12295 .36851 .13422 .37369 .14757 .38001 .13635 .37457 Mtetra
.326 0 0 r
.13635 .37457 .14757 .38001 .16094 .38773 .14984 .38133 Mtetra
0 .301 .697 r
.14984 .38133 .16094 .38773 .17444 .39616 .16355 .38798 Mtetra
0 .434 .848 r
.16355 .38798 .17444 .39616 .18817 .40434 .17757 .39351 Mtetra
.269 .561 .933 r
.17757 .39351 .18817 .40434 .20225 .4111 .192 .39688 Mtetra
.488 .602 .893 r
.192 .39688 .20225 .4111 .21678 .41528 .20691 .39716 Mtetra
.6 .598 .821 r
.20691 .39716 .21678 .41528 .23182 .41584 .22232 .39369 Mtetra
.654 .585 .766 r
.22232 .39369 .23182 .41584 .24737 .41209 .23819 .38624 Mtetra
.682 .575 .729 r
.23819 .38624 .24737 .41209 .2634 .40382 .25445 .375 Mtetra
.698 .569 .706 r
.25445 .375 .2634 .40382 .27981 .39133 .27101 .3606 Mtetra
.707 .566 .693 r
.27101 .3606 .27981 .39133 .2965 .3754 .28774 .34396 Mtetra
.713 .566 .688 r
.28774 .34396 .2965 .3754 .31334 .35709 .30454 .32611 Mtetra
.716 .57 .689 r
.30454 .32611 .31334 .35709 .33022 .3376 .32133 .30807 Mtetra
.717 .576 .696 r
.32133 .30807 .33022 .3376 .34706 .31804 .33805 .29067 Mtetra
.717 .586 .708 r
.33805 .29067 .34706 .31804 .36382 .29935 .35468 .27453 Mtetra
.716 .6 .725 r
.35468 .27453 .36382 .29935 .38047 .28215 .37122 .25997 Mtetra
.714 .616 .747 r
.37122 .25997 .38047 .28215 .39702 .26677 .38769 .24709 Mtetra
.71 .636 .772 r
.38769 .24709 .39702 .26677 .4135 .2533 .40412 .23581 Mtetra
.705 .656 .799 r
.40412 .23581 .4135 .2533 .42995 .24161 .42055 .22592 Mtetra
.698 .676 .825 r
.42055 .22592 .42995 .24161 .44639 .23145 .437 .21715 Mtetra
.69 .695 .849 r
.437 .21715 .44639 .23145 .46286 .22253 .4535 .20924 Mtetra
.683 .709 .868 r
.4535 .20924 .46286 .22253 .47938 .21453 .47007 .20194 Mtetra
.677 .721 .882 r
.47007 .20194 .47938 .21453 .49598 .2072 .48672 .19505 Mtetra
.672 .729 .892 r
.48672 .19505 .49598 .2072 .51266 .2003 .50347 .18842 Mtetra
.668 .734 .899 r
.50347 .18842 .51266 .2003 .52944 .19368 .52031 .18193 Mtetra
.666 .737 .903 r
.52031 .18193 .52944 .19368 .54632 .18722 .53725 .17552 Mtetra
.665 .739 .905 r
.53725 .17552 .54632 .18722 .56329 .18084 .5543 .16913 Mtetra
.664 .74 .906 r
.5543 .16913 .56329 .18084 .58038 .17448 .57145 .16274 Mtetra
.664 .741 .907 r
.57145 .16274 .58038 .17448 .59756 .16812 .58871 .15633 Mtetra
.664 .741 .908 r
.58871 .15633 .59756 .16812 .61486 .16174 .60608 .14989 Mtetra
.60608 .14989 .61486 .16174 .63226 .15533 .62355 .14341 Mtetra
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Mtetra
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Mtetra
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Mtetra
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Mtetra
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Mtetra
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Mtetra
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Mtetra
0 .445 .812 r
.09824 .35758 .10956 .36374 .12295 .36851 .11168 .36206 Mtetra
0 .403 .785 r
.11168 .36206 .12295 .36851 .13635 .37457 .1252 .36723 Mtetra
0 .431 .829 r
.1252 .36723 .13635 .37457 .14984 .38133 .1389 .37239 Mtetra
.107 .513 .908 r
.1389 .37239 .14984 .38133 .16355 .38798 .15288 .37668 Mtetra
.331 .585 .936 r
.15288 .37668 .16355 .38798 .17757 .39351 .16724 .3792 Mtetra
.5 .607 .891 r
.16724 .3792 .17757 .39351 .192 .39688 .18204 .3791 Mtetra
.596 .6 .827 r
.18204 .3791 .192 .39688 .20691 .39716 .1973 .37579 Mtetra
.647 .588 .775 r
.1973 .37579 .20691 .39716 .22232 .39369 .21302 .369 Mtetra
.675 .579 .739 r
.21302 .369 .22232 .39369 .23819 .38624 .22913 .35886 Mtetra
.692 .572 .716 r
.22913 .35886 .23819 .38624 .25445 .375 .24554 .34586 Mtetra
.702 .57 .703 r
.24554 .34586 .25445 .375 .27101 .3606 .26214 .33078 Mtetra
.708 .57 .697 r
.26214 .33078 .27101 .3606 .28774 .34396 .27884 .3145 Mtetra
.712 .574 .698 r
.27884 .3145 .28774 .34396 .30454 .32611 .29555 .29793 Mtetra
.714 .581 .705 r
.29555 .29793 .30454 .32611 .32133 .30807 .31221 .28183 Mtetra
.714 .591 .716 r
.31221 .28183 .32133 .30807 .33805 .29067 .3288 .26675 Mtetra
.713 .604 .733 r
.3288 .26675 .33805 .29067 .35468 .27453 .34532 .25302 Mtetra
.711 .621 .754 r
.34532 .25302 .35468 .27453 .37122 .25997 .36177 .24076 Mtetra
.708 .639 .779 r
.36177 .24076 .37122 .25997 .38769 .24709 .37818 .22991 Mtetra
.702 .659 .805 r
.37818 .22991 .38769 .24709 .40412 .23581 .39459 .2203 Mtetra
.696 .679 .83 r
.39459 .2203 .40412 .23581 .42055 .22592 .41101 .2117 Mtetra
.689 .696 .852 r
.41101 .2117 .42055 .22592 .437 .21715 .42749 .20389 Mtetra
.682 .711 .87 r
.42749 .20389 .437 .21715 .4535 .20924 .44403 .19663 Mtetra
.676 .721 .884 r
.44403 .19663 .4535 .20924 .47007 .20194 .46065 .18976 Mtetra
.671 .729 .893 r
.46065 .18976 .47007 .20194 .48672 .19505 .47736 .18312 Mtetra
.668 .734 .899 r
.47736 .18312 .48672 .19505 .50347 .18842 .49417 .17661 Mtetra
.666 .737 .903 r
.49417 .17661 .50347 .18842 .52031 .18193 .51107 .17017 Mtetra
.665 .739 .905 r
.51107 .17017 .52031 .18193 .53725 .17552 .52808 .16376 Mtetra
.664 .74 .907 r
.52808 .16376 .53725 .17552 .5543 .16913 .5452 .15733 Mtetra
.664 .741 .907 r
.5452 .15733 .5543 .16913 .57145 .16274 .56242 .15089 Mtetra
.664 .741 .908 r
.56242 .15089 .57145 .16274 .58871 .15633 .57976 .14441 Mtetra
.57976 .14441 .58871 .15633 .60608 .14989 .5972 .1379 Mtetra
.5972 .1379 .60608 .14989 .62355 .14341 .61475 .13135 Mtetra
.61475 .13135 .62355 .14341 .64114 .13689 .63241 .12475 Mtetra
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Mtetra
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Mtetra
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Mtetra
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Mtetra
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Mtetra
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Mtetra
.062 .525 .895 r
.08691 .35028 .09824 .35758 .11168 .36206 .10047 .35395 Mtetra
.102 .532 .911 r
.10047 .35395 .11168 .36206 .1252 .36723 .11419 .35768 Mtetra
.227 .571 .94 r
.11419 .35768 .1252 .36723 .1389 .37239 .12815 .36076 Mtetra
.385 .606 .936 r
.12815 .36076 .1389 .37239 .15288 .37668 .14245 .3624 Mtetra
.513 .614 .89 r
.14245 .3624 .15288 .37668 .16724 .3792 .15716 .36186 Mtetra
.594 .606 .833 r
.15716 .36186 .16724 .3792 .18204 .3791 .1723 .3586 Mtetra
.642 .594 .785 r
.1723 .3586 .18204 .3791 .1973 .37579 .18787 .35233 Mtetra
.67 .584 .75 r
.18787 .35233 .1973 .37579 .21302 .369 .20382 .34314 Mtetra
.687 .578 .727 r
.20382 .34314 .21302 .369 .22913 .35886 .22007 .3314 Mtetra
.697 .575 .714 r
.22007 .3314 .22913 .35886 .24554 .34586 .23654 .31774 Mtetra
.704 .575 .708 r
.23654 .31774 .24554 .34586 .26214 .33078 .25312 .30294 Mtetra
.708 .579 .709 r
.25312 .30294 .26214 .33078 .27884 .3145 .26973 .28777 Mtetra
.71 .586 .715 r
.26973 .28777 .27884 .3145 .29555 .29793 .28632 .27291 Mtetra
.711 .596 .726 r
.28632 .27291 .29555 .29793 .31221 .28183 .30285 .25888 Mtetra
.71 .609 .742 r
.30285 .25888 .31221 .28183 .3288 .26675 .31932 .24598 Mtetra
.708 .626 .763 r
.31932 .24598 .3288 .26675 .34532 .25302 .33574 .23434 Mtetra
.705 .644 .786 r
.33574 .23434 .34532 .25302 .36177 .24076 .35212 .22393 Mtetra
.7 .664 .811 r
.35212 .22393 .36177 .24076 .37818 .22991 .3685 .21461 Mtetra
.694 .682 .834 r
.3685 .21461 .37818 .22991 .39459 .2203 .3849 .20621 Mtetra
.687 .699 .855 r
.3849 .20621 .39459 .2203 .41101 .2117 .40134 .1985 Mtetra
.681 .712 .872 r
.40134 .1985 .41101 .2117 .42749 .20389 .41785 .19129 Mtetra
.675 .722 .885 r
.41785 .19129 .42749 .20389 .44403 .19663 .43444 .18443 Mtetra
.671 .729 .894 r
.43444 .18443 .44403 .19663 .46065 .18976 .45111 .17779 Mtetra
.668 .734 .9 r
.45111 .17779 .46065 .18976 .47736 .18312 .46789 .17126 Mtetra
.666 .737 .903 r
.46789 .17126 .47736 .18312 .49417 .17661 .48476 .1648 Mtetra
.665 .739 .905 r
.48476 .1648 .49417 .17661 .51107 .17017 .50173 .15835 Mtetra
.664 .74 .907 r
.50173 .15835 .51107 .17017 .52808 .16376 .51881 .1519 Mtetra
.664 .741 .907 r
.51881 .1519 .52808 .16376 .5452 .15733 .536 .14542 Mtetra
.664 .741 .908 r
.536 .14542 .5452 .15733 .56242 .15089 .55329 .13891 Mtetra
.55329 .13891 .56242 .15089 .57976 .14441 .5707 .13236 Mtetra
.5707 .13236 .57976 .14441 .5972 .1379 .58821 .12577 Mtetra
.58821 .12577 .5972 .1379 .61475 .13135 .60583 .11914 Mtetra
.60583 .11914 .61475 .13135 .63241 .12475 .62357 .11247 Mtetra
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Mtetra
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Mtetra
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Mtetra
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Mtetra
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Mtetra
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Mtetra
.241 .601 .952 r
.07563 .34153 .08691 .35028 .10047 .35395 .08938 .34393 Mtetra
.322 .613 .953 r
.08938 .34393 .10047 .35395 .11419 .35768 .10334 .34585 Mtetra
.431 .625 .934 r
.10334 .34585 .11419 .35768 .12815 .36076 .1176 .34662 Mtetra
.527 .624 .891 r
.1176 .34662 .12815 .36076 .14245 .3624 .13223 .34559 Mtetra
.595 .613 .84 r
.13223 .34559 .14245 .3624 .15716 .36186 .14726 .34227 Mtetra
.638 .601 .796 r
.14726 .34227 .15716 .36186 .1723 .3586 .1627 .33641 Mtetra
.665 .591 .763 r
.1627 .33641 .1723 .3586 .18787 .35233 .17849 .32801 Mtetra
.682 .585 .74 r
.17849 .32801 .18787 .35233 .20382 .34314 .19459 .31737 Mtetra
.693 .582 .727 r
.19459 .31737 .20382 .34314 .22007 .3314 .21091 .305 Mtetra
.7 .582 .72 r
.21091 .305 .22007 .3314 .23654 .31774 .22735 .29156 Mtetra
.704 .586 .72 r
.22735 .29156 .23654 .31774 .25312 .30294 .24386 .27769 Mtetra
.707 .593 .726 r
.24386 .27769 .25312 .30294 .26973 .28777 .26035 .26401 Mtetra
.708 .603 .737 r
.26035 .26401 .26973 .28777 .28632 .27291 .27682 .25098 Mtetra
.707 .616 .753 r
.27682 .25098 .28632 .27291 .30285 .25888 .29323 .23889 Mtetra
.705 .632 .772 r
.29323 .23889 .30285 .25888 .31932 .24598 .3096 .22786 Mtetra
.702 .65 .794 r
.3096 .22786 .31932 .24598 .33574 .23434 .32595 .21789 Mtetra
.697 .668 .818 r
.32595 .21789 .33574 .23434 .35212 .22393 .34229 .20888 Mtetra
.692 .686 .84 r
.34229 .20888 .35212 .22393 .3685 .21461 .35866 .20066 Mtetra
.685 .701 .859 r
.35866 .20066 .3685 .21461 .3849 .20621 .37507 .19306 Mtetra
.679 .714 .875 r
.37507 .19306 .3849 .20621 .40134 .1985 .39154 .18592 Mtetra
.674 .723 .886 r
.39154 .18592 .40134 .1985 .41785 .19129 .40809 .17907 Mtetra
.67 .73 .895 r
.40809 .17907 .41785 .19129 .43444 .18443 .42473 .17242 Mtetra
.668 .735 .9 r
.42473 .17242 .43444 .18443 .45111 .17779 .44147 .16588 Mtetra
.666 .737 .903 r
.44147 .16588 .45111 .17779 .46789 .17126 .4583 .15939 Mtetra
.665 .739 .905 r
.4583 .15939 .46789 .17126 .48476 .1648 .47524 .15292 Mtetra
.664 .74 .907 r
.47524 .15292 .48476 .1648 .50173 .15835 .49228 .14643 Mtetra
.664 .741 .907 r
.49228 .14643 .50173 .15835 .51881 .1519 .50943 .13992 Mtetra
.664 .741 .908 r
.50943 .13992 .51881 .1519 .536 .14542 .52669 .13337 Mtetra
.52669 .13337 .536 .14542 .55329 .13891 .54406 .12679 Mtetra
.54406 .12679 .55329 .13891 .5707 .13236 .56153 .12017 Mtetra
.56153 .12017 .5707 .13236 .58821 .12577 .57912 .1135 Mtetra
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Mtetra
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Mtetra
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Mtetra
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Mtetra
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Mtetra
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Mtetra
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Mtetra
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Mtetra
.397 .643 .956 r
.06445 .33117 .07563 .34153 .08938 .34393 .07842 .332 Mtetra
.47 .642 .932 r
.07842 .332 .08938 .34393 .10334 .34585 .09266 .33191 Mtetra
.542 .635 .892 r
.09266 .33191 .10334 .34585 .1176 .34662 .10723 .33037 Mtetra
.597 .623 .848 r
.10723 .33037 .1176 .34662 .13223 .34559 .12216 .32694 Mtetra
.635 .61 .807 r
.12216 .32694 .13223 .34559 .14726 .34227 .13747 .32136 Mtetra
.661 .6 .776 r
.13747 .32136 .14726 .34227 .1627 .33641 .15312 .31362 Mtetra
.678 .593 .754 r
.15312 .31362 .1627 .33641 .17849 .32801 .16906 .30392 Mtetra
.689 .59 .74 r
.16906 .30392 .17849 .32801 .19459 .31737 .18523 .29269 Mtetra
.696 .59 .734 r
.18523 .29269 .19459 .31737 .21091 .305 .20154 .28046 Mtetra
.701 .594 .733 r
.20154 .28046 .21091 .305 .22735 .29156 .21791 .2678 Mtetra
.703 .601 .739 r
.21791 .2678 .22735 .29156 .24386 .27769 .23431 .25521 Mtetra
.705 .611 .749 r
.23431 .25521 .24386 .27769 .26035 .26401 .25069 .24312 Mtetra
.704 .623 .764 r
.25069 .24312 .26035 .26401 .27682 .25098 .26704 .2318 Mtetra
.703 .639 .782 r
.26704 .2318 .27682 .25098 .29323 .23889 .28335 .22136 Mtetra
.699 .656 .803 r
.28335 .22136 .29323 .23889 .3096 .22786 .29965 .21182 Mtetra
.695 .673 .825 r
.29965 .21182 .3096 .22786 .32595 .21789 .31596 .20311 Mtetra
.689 .69 .845 r
.31596 .20311 .32595 .21789 .34229 .20888 .33228 .19508 Mtetra
.683 .704 .863 r
.33228 .19508 .34229 .20888 .35866 .20066 .34866 .18759 Mtetra
.678 .716 .877 r
.34866 .18759 .35866 .20066 .37507 .19306 .3651 .1805 Mtetra
.673 .725 .888 r
.3651 .1805 .37507 .19306 .39154 .18592 .38161 .17368 Mtetra
.67 .731 .896 r
.38161 .17368 .39154 .18592 .40809 .17907 .39822 .16703 Mtetra
.667 .735 .901 r
.39822 .16703 .40809 .17907 .42473 .17242 .41491 .16047 Mtetra
.666 .738 .904 r
.41491 .16047 .42473 .17242 .44147 .16588 .43171 .15396 Mtetra
.665 .739 .906 r
.43171 .15396 .44147 .16588 .4583 .15939 .44861 .14745 Mtetra
.664 .74 .907 r
.44861 .14745 .4583 .15939 .47524 .15292 .46561 .14093 Mtetra
.664 .741 .907 r
.46561 .14093 .47524 .15292 .49228 .14643 .48273 .13439 Mtetra
.664 .741 .908 r
.48273 .13439 .49228 .14643 .50943 .13992 .49994 .12781 Mtetra
.49994 .12781 .50943 .13992 .52669 .13337 .51727 .12119 Mtetra
.51727 .12119 .52669 .13337 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12017 .55226 .10783 Mtetra
.55226 .10783 .56153 .12017 .57912 .1135 .56992 .10109 Mtetra
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Mtetra
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Mtetra
.504 .657 .929 r
.05336 .3192 .06445 .33117 .07842 .332 .06759 .31832 Mtetra
.556 .646 .894 r
.06759 .31832 .07842 .332 .09266 .33191 .08211 .31626 Mtetra
.601 .633 .855 r
.08211 .31626 .09266 .33191 .10723 .33037 .09696 .31265 Mtetra
.634 .621 .819 r
.09696 .31265 .10723 .33037 .12216 .32694 .11215 .30726 Mtetra
.658 .61 .79 r
.11215 .30726 .12216 .32694 .13747 .32136 .12767 .30004 Mtetra
.674 .603 .769 r
.12767 .30004 .13747 .32136 .15312 .31362 .14346 .29115 Mtetra
.685 .6 .755 r
.14346 .29115 .15312 .31362 .16906 .30392 .15948 .28091 Mtetra
.692 .6 .748 r
.15948 .28091 .16906 .30392 .18523 .29269 .17564 .26975 Mtetra
.697 .603 .747 r
.17564 .26975 .18523 .29269 .20154 .28046 .19189 .25816 Mtetra
.7 .61 .752 r
.19189 .25816 .20154 .28046 .21791 .2678 .20818 .24658 Mtetra
.701 .619 .762 r
.20818 .24658 .21791 .2678 .23431 .25521 .22447 .23536 Mtetra
.701 .632 .776 r
.22447 .23536 .23431 .25521 .25069 .24312 .24074 .22475 Mtetra
.7 .647 .793 r
.24074 .22475 .25069 .24312 .26704 .2318 .25699 .21487 Mtetra
.696 .663 .813 r
.25699 .21487 .26704 .2318 .28335 .22136 .27324 .20574 Mtetra
.692 .679 .833 r
.27324 .20574 .28335 .22136 .29965 .21182 .28949 .19731 Mtetra
.687 .694 .851 r
.28949 .19731 .29965 .21182 .31596 .20311 .30578 .18947 Mtetra
.681 .707 .867 r
.30578 .18947 .31596 .20311 .33228 .19508 .32212 .18209 Mtetra
.676 .718 .88 r
.32212 .18209 .33228 .19508 .34866 .18759 .33852 .17506 Mtetra
.672 .726 .89 r
.33852 .17506 .34866 .18759 .3651 .1805 .35499 .16826 Mtetra
.669 .732 .897 r
.35499 .16826 .3651 .1805 .38161 .17368 .37156 .16161 Mtetra
.667 .735 .901 r
.37156 .16161 .38161 .17368 .39822 .16703 .38822 .15503 Mtetra
.665 .738 .904 r
.38822 .15503 .39822 .16703 .41491 .16047 .40498 .14849 Mtetra
.665 .739 .906 r
.40498 .14849 .41491 .16047 .43171 .15396 .42184 .14196 Mtetra
.664 .74 .907 r
.42184 .14196 .43171 .15396 .44861 .14745 .4388 .13541 Mtetra
.664 .741 .907 r
.4388 .13541 .44861 .14745 .46561 .14093 .45588 .12883 Mtetra
.664 .741 .908 r
.45588 .12883 .46561 .14093 .48273 .13439 .47306 .12221 Mtetra
.47306 .12221 .48273 .13439 .49994 .12781 .49034 .11556 Mtetra
.49034 .11556 .49994 .12781 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Mtetra
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Mtetra
.57 .658 .896 r
.04237 .30581 .05336 .3192 .06759 .31832 .05685 .30325 Mtetra
.606 .645 .863 r
.05685 .30325 .06759 .31832 .08211 .31626 .07163 .29943 Mtetra
.634 .632 .831 r
.07163 .29943 .08211 .31626 .09696 .31265 .08672 .29414 Mtetra
.656 .622 .804 r
.08672 .29414 .09696 .31265 .11215 .30726 .10211 .28733 Mtetra
.671 .615 .784 r
.10211 .28733 .11215 .30726 .12767 .30004 .11777 .2791 Mtetra
.682 .611 .77 r
.11777 .2791 .12767 .30004 .14346 .29115 .13363 .2697 Mtetra
.689 .611 .764 r
.13363 .2697 .14346 .29115 .15948 .28091 .14966 .25949 Mtetra
.694 .614 .762 r
.14966 .25949 .15948 .28091 .17564 .26975 .16578 .24885 Mtetra
.697 .62 .767 r
.16578 .24885 .17564 .26975 .19189 .25816 .18195 .23816 Mtetra
.698 .629 .776 r
.18195 .23816 .19189 .25816 .20818 .24658 .19814 .22773 Mtetra
.698 .641 .789 r
.19814 .22773 .20818 .24658 .22447 .23536 .21432 .21777 Mtetra
.696 .655 .805 r
.21432 .21777 .22447 .23536 .24074 .22475 .23051 .20841 Mtetra
.693 .67 .822 r
.23051 .20841 .24074 .22475 .25699 .21487 .2467 .19966 Mtetra
.689 .685 .84 r
.2467 .19966 .25699 .21487 .27324 .20574 .2629 .1915 Mtetra
.684 .698 .857 r
.2629 .1915 .27324 .20574 .28949 .19731 .27915 .18384 Mtetra
.68 .71 .872 r
.27915 .18384 .28949 .19731 .30578 .18947 .29544 .17657 Mtetra
.675 .72 .883 r
.29544 .17657 .30578 .18947 .32212 .18209 .3118 .16959 Mtetra
.671 .727 .892 r
.3118 .16959 .32212 .18209 .33852 .17506 .32824 .16281 Mtetra
.668 .733 .898 r
.32824 .16281 .33852 .17506 .35499 .16826 .34476 .15615 Mtetra
.667 .736 .902 r
.34476 .15615 .35499 .16826 .37156 .16161 .36138 .14956 Mtetra
.665 .738 .904 r
.36138 .14956 .37156 .16161 .38822 .15503 .3781 .143 Mtetra
.664 .74 .906 r
.3781 .143 .38822 .15503 .40498 .14849 .39492 .13643 Mtetra
.664 .74 .907 r
.39492 .13643 .40498 .14849 .42184 .14196 .41185 .12985 Mtetra
.664 .741 .907 r
.41185 .12985 .42184 .14196 .4388 .13541 .42888 .12324 Mtetra
.664 .741 .908 r
.42888 .12324 .4388 .13541 .45588 .12883 .44602 .11659 Mtetra
.44602 .11659 .45588 .12883 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.611 .657 .87 r
.03143 .2913 .04237 .30581 .05685 .30325 .04615 .28725 Mtetra
.635 .645 .842 r
.04615 .28725 .05685 .30325 .07163 .29943 .06115 .28201 Mtetra
.654 .635 .818 r
.06115 .28201 .07163 .29943 .08672 .29414 .07643 .2755 Mtetra
.668 .627 .799 r
.07643 .2755 .08672 .29414 .10211 .28733 .09195 .26781 Mtetra
.679 .623 .786 r
.09195 .26781 .10211 .28733 .11777 .2791 .10768 .25911 Mtetra
.686 .623 .779 r
.10768 .25911 .11777 .2791 .13363 .2697 .12356 .2497 Mtetra
.691 .625 .778 r
.12356 .2497 .13363 .2697 .14966 .25949 .13955 .23989 Mtetra
.694 .631 .782 r
.13955 .23989 .14966 .25949 .16578 .24885 .1556 .22999 Mtetra
.695 .64 .79 r
.1556 .22999 .16578 .24885 .18195 .23816 .17169 .22026 Mtetra
.695 .651 .802 r
.17169 .22026 .18195 .23816 .19814 .22773 .18779 .21089 Mtetra
.693 .663 .816 r
.18779 .21089 .19814 .22773 .21432 .21777 .2039 .202 Mtetra
.69 .677 .832 r
.2039 .202 .21432 .21777 .23051 .20841 .22003 .19361 Mtetra
.687 .691 .848 r
.22003 .19361 .23051 .20841 .2467 .19966 .23618 .18569 Mtetra
.682 .703 .863 r
.23618 .18569 .2467 .19966 .2629 .1915 .25238 .17819 Mtetra
.678 .714 .876 r
.25238 .17819 .2629 .1915 .27915 .18384 .26863 .17102 Mtetra
.674 .722 .886 r
.26863 .17102 .27915 .18384 .29544 .17657 .28494 .1641 Mtetra
.67 .729 .893 r
.28494 .1641 .29544 .17657 .3118 .16959 .30134 .15733 Mtetra
.668 .733 .899 r
.30134 .15733 .3118 .16959 .32824 .16281 .31782 .15067 Mtetra
.666 .736 .902 r
.31782 .15067 .32824 .16281 .34476 .15615 .3344 .14407 Mtetra
.665 .738 .905 r
.3344 .14407 .34476 .15615 .36138 .14956 .35108 .13748 Mtetra
.664 .74 .906 r
.35108 .13748 .36138 .14956 .3781 .143 .36787 .13088 Mtetra
.664 .74 .907 r
.36787 .13088 .3781 .143 .39492 .13643 .38475 .12426 Mtetra
.664 .741 .907 r
.38475 .12426 .39492 .13643 .41185 .12985 .40174 .11762 Mtetra
.664 .741 .908 r
.40174 .11762 .41185 .12985 .42888 .12324 .41884 .11093 Mtetra
.41884 .11093 .42888 .12324 .44602 .11659 .43605 .10421 Mtetra
.43605 .10421 .44602 .11659 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`006P3ooonDo`0003<0ooooU?l0000K0?ooo`006P3o
ool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0T03o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`2@0?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0T03oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`050?ooo`8000000P3oool020000000oooo0?ooo`000000ooooo`0000000000oooo
0_l000000`3oool00000000000030?ooo`03o`0000000000oooo07@0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo06h0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00Co00000?ooo`3oool000001P2c/k<3000000<0Ogmo00@0000006IVIP1VIVH0
00000P1<C4`010000000<c<c03<c<`000004oaTI6G8000000`3oool00ol00000oooo0?ooo`0a0?oo
o`03o`00003oool0oooo00<06ATI3P00000?01TI6@03o`0000000000000006X000000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool01?l00000oooo0?ooo`0000080;>c/`8000000`1oOgl20000
000506IVIP000000C4a<04a<C00000000P0c<c<00`00003o6ATIoaTI6@02oaTI6G4000000`3oool0
0ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo01TI6@8000003P0c<c<3000000h06ATIJ`00
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`05o`00003oool0oooo09VIV@0000002@2c
/k<40000000707moO`000000IVIV00000?l00000C4a<0000000203<c<`0300000?lI6AWo6ATI00;o
6ATIL00000030?ooo`03o`00003oool0oooo0340oooo00Co00000?ooo`3ooooo00004`0c<c<20000
00h06ATI00<00000o`0000000000IP0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`05
o`00003oool0oooo09VIV@0000002P2c/k<01P000000VIVIo`0000000000Ogmo00000080IVIV00<0
000004a<C?l000000P0c<c<00ol0003o6ATIoaTI6@03oaTI6Fh000000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo01H0<c<c0`00000>01TI6FH000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0209VIV@030000002c/k<0/k>c0080/k>c0`000003
0;>c/`060000002IVIT0VIVI0000001oOgl000000P1VIVH00`000000C4a<0000000203<c<`030000
0?lI6AWo6ATI00?o6ATIK@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
6@0c<c<2000000d06ATII@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo0080VIVI00<000000;>c/`2c/k<00P2c/k<01@000000c<c<0<c<c000003o00000080/k>c
0P000000102IVIT0000007moO`00000206IVIP030000001<C4`000000080<c<c00<00000oaTI6OlI
6AT00olI6AU/000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0K03<c<`80
0000300I6AUT000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00Oo00000?ooo`3ooooo
00000000002IVIWo000000<0/k>c00<000000<c<c03<c<`00P3<c<`200000080/k>c00<0000009VI
V@0000000`0000000`1VIVKo000004a<C0020000000303<c<`00003o000000?o6ATI00?o00000000
00000000J@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool07@0c<c<20000
00/06ATIH`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`05o`00003oool0oooo07mo
O`0000000P2IVIT010000000/k>c0;>c/ol000060<c<c080000000H0/k>c0000002IVIT0VIVI0000
001oOgl300000080C4a<00@0000003<c<`0c<c<000000olI6AU[000000<0oooo00?o00000?ooo`3o
ool0<@3oool00ol00000oooo0?ooo`0O03<c<`030000000I6AT06ATI00T06ATI00?o000000000000
0000G`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`06o`00003oool0ooooo`00001o
Ogl000000P2IVIT00`000000/k>c000000080<c<c0060000002c/k<000000000002IVIT000000P1o
Ogl30000000504a<C0000000<c<c03<c<`0000000olI6AUZ000000<0oooo00?o00000?ooo`3oool0
<@3oool00ol00000oooo0?ooo`0=03<c<`@000003`0c<c<3000000X06ATIH00000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`07o`00003oool0oooo06IVIP000000Ogmoo`00000209VIV@03
0000002c/k<0000000P0c<c<00go00000;>c/`2c/k<0000009VIV@00003o000007moO`000000IVIV
0000001<C4`000000080<c<c00H00000oaTI6OlI6AWo6ATI00000?l0001W000000<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`0:03<c<`;o000000<0000004a<C01<C4`00P1<C4`8
000000X0<c<c00<0000001TI6@0I6AT02@0I6AUN000000<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool00P1VIVH01`000000Ogmo0000002IVIT000000;>c/`0000002@3<
c<`20000000;0;>c/`000000VIVI0000001oOgoo00000000001VIVH0000004a<C00000000P0c<c<0
0ol0003o6ATIoaTI6@02oaTI6FL000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo00X0<c<c00<0000004a<C01<C4`0301<C4`2000000T0<c<c00?o00000000000I6AT02P0I6AUL
000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00Co00000?ooo`3oool000000P1VIVH2
00000080VIVI00<000000;>c/`0000002P3<c<`00`000000/k>c0000000200000080Ogmo00D00000
06IVIP000000C4a<0000000203<c<`0300000?lI6AWo6ATI00;o6ATIIP0000030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool02@0c<c<00`000000C4a<04a<C00?04a<C08000002@0c
<c<2000000X06ATIF`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`05o`00003oool0
oooo04a<C00000000P1VIVH01?l00000000009VIVOl000020;>c/`030000003<c<`0c<c<00P0c<c<
00<000000;>c/`2c/k<00`0000001P1oOgl0000006IVIP000000C4a<00000080<c<c00<00000oaTI
6OlI6AT00_lI6AUU000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0803<c
<`030000001<C4`0C4a<0180C4a<0`00000803<c<`030000000I6AT06ATI00P06ATIFP0000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`0<o`00003oool0oooo0000001<C4`0000006IVIP00
0000Ogmoo`00002IVIT000000P2c/k<010000000c<c<0<c<c03<c<`500000080c<c<00`000000;>c
/`2c/k<0000009VIV@000000Ogmo0000001VIVH0000004a<C000000203<c<`0300000?lI6AWo6ATI
00;o6ATI00?o0000000000000000H@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool01`0c<c<00`000000C4a<04a<C00F04a<C08000001`0c<c<00ol00000000001TI6@0801TI
6@03o`0000000000000005H000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool01?l00000
oooo0?ooo`00000204a<C0090000001VIVH0000007moO`000000VIVI0000002c/k<0000000<0c<c<
00<000000>KViP3Vi^H00P3Vi^H20000000=0<c<c0000000/k>co`0000000000VIVI0000001oOgl0
000006IVIP000000C4a<0000000203<c<`0400000?lI6AWo6ATIoaTI6F@000000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo00L0<c<c00<0000004a<C01<C4`0601<C4`2000000L0
<c<c0P00000901TI6EL000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool01Ol00000oooo
0?ooo`0c<c<000000080C4a<00@0000006IVIP00000000000P2IVIT00`000000/k>c000000020<c<
c0030000003Vi^H0i^KV00@0i^KV00<000000<c<c00000000P2c/k<02@000000VIVI0000001oOgl0
000006IVIP000000C4a<0000000203<c<`0400000?lI6AWo6ATIoaTI6F<000000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo00L0<c<c00<0000004a<C01<C4`02P1<C4`5000000/0
C4a<0P00000703<c<`030000000I6AT06ATI00L06ATIEP0000030?ooo`03o`00003oool0oooo01T0
oooo000J0?ooo`08o`00003oool0ooooo`00000c<c<0000004a<C000000206IVIP07o`0000000000
VIVI09VIVOl00000/k>c000000020<c<c0030000003Vi^H0i^KV00@0i^KV00h000000<c<c0000000
00000;>c/`000000VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00@00000oaTI6OlI
6AWo6ATIHP0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool01`0c<c<00`00
0000C4a<04a<C00704a<C0<000001@1VIVH3000000X0C4a<00<0000003<c<`0c<c<01@0c<c<00`00
00006ATI01TI6@0701TI6ED000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000
oooo0?ooo`020000000403<c<ol00000000000000080IVIV100000020;>c/`030000003<c<`00000
00L0i^KV00Go00000<c<c03<c<`000000;>c/`050000000706IVIP000000C4a<o`0000000000<c<c
00000003oaTI6@03o`0000000000000005h000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00
003oool0oooo00L0<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0906IVIP@00000
1`1<C4`00ol0000000000000000503<c<`800000200I6AT00`00003o00000000001A000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool00_lI6AT00`000000<c<c03<c
<`0200000080IVIV00H0000007moO`00000000000;>c/ol000020<c<c0030000003Vi^H0i^KV00D0
i^KV0P0000001P3<c<`000000;>c/`2c/k<0000009VIV@80000000L0IVIVo`0000000000C4a<0000
000c<c<0000000Co6ATIG`0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0
1`0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00h0IVIV0P00000804a<C0030000
000c<c<0<c<c00@0<c<c0P00000801TI6E8000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00ol00000oooo0?ooo`03oaTI6@030000000c<c<0<c<c00<0000000<0IVIV0000001oOgl00P00
00001@2c/k<000000<c<c03<c<`0000000P0i^KV00L000000<c<c000000000000;>c/`000000VIVI
008000000P1VIVH01@000000C4a<0000000c<c<0000000Co6ATIGP0000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool01`0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV0140IVIV0P00000704a<C08000001P0c<c<00`0000006ATI01TI6@0601TI6E4000000`3oool0
0ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`04oaTI6@0;0000000c<c<0<c<c
o`00001<C4`0000006IVIP000000Ogmo00000?l000000P0000020<c<c003o`00003Vi^H0i^KV00H0
i^KV00Oo00000<c<c03<c<`000000;>c/`000000VIVI0080000000So000006IVIP000000C4a<o`00
000c<c<00000o`0000?o6ATI00?o0000000000000000FP0000030?ooo`03o`00003oool0oooo0340
oooo00?o00000?ooo`3oool01`0c<c<00`000000C4a<04a<C00404a<C003o`00001VIVH0IVIV01<0
IVIV00?o00000000000000001P1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H0
6ATI00<00000o`0000000000C@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`04o`00
003oool0oooo000000?o6ATI00/0000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl00000
09VIV@0200000080c<c<00<000000>KViP3Vi^H01`3Vi^H2000000030<c<c0000000/k>c00800000
0P1oOgl010000000IVIVo`000000000303<c<`0400000?lI6AWo6ATIoaTI6E`000000`3oool00ol0
0000oooo0?ooo`0a0?ooo`04o`00003oool0oooo000000H0<c<c00<0000004a<C01<C4`0101<C4`0
0`000000IVIV06IVIP0F06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0701TI6Dh000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool01?l0
0000oooo0?ooo`000004oaTI6@0;0000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000
002IVIT00P0000020<c<c0030000003Vi^H0i^KV0080i^KV0_l000040>KViP040000003<c<`00000
0;>c/`<0000000D0Ogmo000000000000C4a<0000000303<c<`0400000?lI6AWo6ATIoaTI6E/00000
0`3oool00ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo000000H0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0706IVIPX000001P1VIVH2000000D0C4a<0P00000503<c<`80
0000200I6AU=000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
0P000004oaTI6@0;0000000c<c<0<c<c0000001<C4co000006IVIP000000Ogmo0000002IVIT00P00
00020<c<c0060000003Vi^H0i^KV0>KVi_l00000oooo0_l000030>KViP080000003<c<`000000;>c
/`000000VIVI0000001oOgl20000000304a<C000000000000080<c<c00@00000oaTI6OlI6AWo6ATI
FP0000030?ooo`03o`00003oool0oooo0340oooo00Go00000?ooo`3oool06ATI0000000503<c<`03
0000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01@1VIVH00ol00000000007moO`0907moO`80
00001P1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT01P0I6AU<000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
10000003oaTI6@0=0000000c<c<0<c<co`00001<C4`0000006IVIP000000Ogmo0000002IVIT00000
o`0000020<c<c0040000003Vi^H0i^KVo`0000<0oooo0_l000020>KViP0:0000003<c<co00000;>c
/ol00000VIVI00000?l00000IVIV00000080C4a<00@0000003<c<`0c<c?o00000olI6AT00ol00000
00000000001F000000<0oooo00?o00000?ooo`3oool0<@3oool01Ol00000oooo0?ooo`0I6AT00000
00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo
00`0Ogmo00Co000000000000000000000`1VIVH00ol0000000000000000404a<C003o`0000000000
<c<c00@0<c<c00<0000001TI6@0I6AT01P0I6AT00ol00000000000000018000000<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool01@000002oaTI6@040000000c<c<0<c<c
03<c<`80000000@0IVIV0000001oOgl0Ogmo0P000000102c/k<000000<c<c00000020>KViP03o`00
003oool0oooo00<0oooo0_l000002`3Vi^H000000<c<c0000000/k>c0000002IVIWo00000000001V
IVKo00000080C4a<00@0000003<c<`0c<c<000000olI6AUH000000<0oooo00?o00000?ooo`3oool0
<@3oool01Ol00000oooo0?ooo`0I6AT0000000H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000
IVIV06IVIP0406IVIP030000001oOgl0Ogmo0100Ogmo0P00000406IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0701TI6DT000000`3oool00ol00000
oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`05000000?o6ATI00P0000003<c<`0c<c<0
000004a<C0000000IVIV00000080Ogmo0P000000102c/k<000000<c<c00000020>KViP03o`00003o
ool0oooo00@0oooo00So00000>KViP000000c<c<0000002c/k<0000009VIV@80000000D0IVIV0000
001<C4`0C4a<0000000203<c<`0400000?lI6AWo6ATIoaTI6EL000000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo00806ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl04P1oOgl00`000000IVIV06IV
IP0206IVIP800000101<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00L06ATIB000
00030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo00H000000olI6AT0
40000000<c<c03<c<`000000C4a<o`00001VIVH0000007moO`000000VIVI0000002c/k<000000<c<
c00000020>KViP03o`00003oool0oooo00<0oooo00Wo00000>KViP3Vi^Ko00000<c<c0000000/k>c
0000002IVIT00P000000101VIVH0000004a<C000000303<c<`0400000?lI6AWo6ATIoaTI6EH00000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00806ATI00<0000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0
201oOgl4000000P0Ogmo00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<C003o`00
000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AU8000000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool01P0000002Ol0003o6ATIoaTI6OlI6AWo00000000000c
<c?o000004a<C00200000009o`0000000000000000000?l000000000o`00003<c<`000000080i^KV
00?o00000?ooo`3oool00`3oool2o`0000090>KViP0000000000o`000000003o000009VIV@00003o
00000080000000Go0000000000000000<c<co`000004oaTI6ED000000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo00<06ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<04a<
C00204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl01P1oOgl2000000@0VIVI00Co
000000000000000000001@1oOgl3000000<0IVIV00?o00000000001<C4`00P1<C4`2000000@0<c<c
0P00000701TI6DL000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?oo
o`09000000?o6ATI00T0000003<c<`000000000004a<C0000000IVIV0000001oOgl00`0000020<c<
c0040000003Vi^H0i^KVo`0000H0oooo00Go00000>KViP3Vi^H000000<c<c0020000000:09VIV@00
0000Ogmo0000001VIVH0000004a<C0000000<c<c000000Co6ATIE00000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0100I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0
C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0
VIVI00P0VIVI0`00000507moO`8000000`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0
<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AU5000000<0oooo00?o00000?ooo`3oool06@3oool0
01X0oooo00?o00000?ooo`3oool02P000003oaTI6@0:0000000c<c<0<c<c0000001<C4co000006IV
IP000000Ogmoo`00008000000P3<c<`010000000i^KV0>KVi_l000060?ooo`05o`00003Vi^H0i^KV
o`00003<c<`010000000201oOgl0000006IVIP000000C4a<0000000c<c<000001?lI6AUC000000<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0401TI6@030000000c<c<0<c<c00<0
<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00@0
Ogmo00<0000009VIV@2IVIT0302IVIT00`000000Ogmo07moO`0407moO`050000001VIVH0IVIV06IV
IP000000101<C4`2000000@0<c<c00<0000001TI6@0I6AT01P0I6AU4000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool02P0000001Ol0003o6ATIoaTI6OlI6AWo0000
0080<c<c00`0000004a<C0000000IVIVo`00001oOgl00000o`000000003o00000<c<c00000020>KV
iP03o`00003oool0oooo00@0oooo0_l000001@3Vi^H000000<c<c?l00000/k>c0080000000T0Ogmo
o`00001VIVH0000004a<C?l00000<c<c00000?l000000olI6AT00ol0000000000000001?000000<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0501TI6@030000000c<c<0<c<c0080
<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0
Ogmo00<0000009VIV@2IVIT03P2IVIT00ol0000000000000000407moO`05o`00001VIVH0IVIV06IV
I_l000000P00000304a<C003o`00000c<c<0<c<c0080<c<c00<00000o`00000I6AT01P0I6AU30000
00<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool030000002oaTI6@04
0000000c<c<0<c<c00000080C4a<00X0000006IVIP000000000009VIV@000000/k>c0000003<c<co
00000P3Vi^H00ol00000oooo0?ooo`050?ooo`03o`00003Vi^H0000000<0000000P0VIVIo`00001o
Ogl0000006IVI_l00000C4a<00000080<c<c00D00000oaTI6OlI6AWo6ATIo`00001@000000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0501TI6@030000000c<c<0<c<c00<0<c<c
00Go000004a<C01<C4`0C4a<0000000406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT04@2IVIT00`000000Ogmo07moO`0207moO`800000101VIVH01@000000C4a<04a<C01<C4`00000
00D0<c<c00<0000001TI6@0I6AT01P0I6AU1000000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool030000003oaTI6@040000000c<c<0<c<c00000080C4a<0P0000001@1o
Ogl0000009VIV@000000/k>c008000000`3Vi^H00ol00000oooo0?ooo`040?ooo`05o`00003Vi^H0
i^KV0000003<c<`00P000000202IVIT0000007moO`000000IVIV0000001<C4`000000P0c<c<01@00
003o6ATIoaTI6OlI6AWo000004l000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo00H06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0
IVIV06IVIP0000001@1oOgl00`000000VIVI09VIV@0509VIV@T00000102IVIT2000000@0Ogmo00<0
000006IVIP1VIVH00P1VIVH01@000000C4a<04a<C01<C4`0000000D0<c<c00<0000001TI6@0I6AT0
1@0I6AU1000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool03@00
0003oaTI6@040000000c<c<0<c<c00000080C4a<00Oo00000000001oOgoo000009VIV@000000/k>c
008000000P3Vi^H00ol00000oooo0?ooo`050?ooo`05o`00003Vi^H0i^KV0000003<c<`00P000000
202IVIT0000007moO`000000IVIV0000001<C4`000000P0c<c<01@00003o6ATIoaTI6OlI6AWo0000
04h000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00H06ATI00<0000003<c
<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV00<0000007moO`1oOgl00P1oOgl0
0`000000VIVI09VIV@0309VIV@03o`0000000000/k>c00P0/k>c0P00000409VIV@8000000`1oOgl0
0ol00000IVIV06IVIP0206IVIP050000001<C4`0C4a<04a<C00000001@0c<c<00`0000006ATI01TI
6@0501TI6D0000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0=
00000007o`000?lI6AWo6ATIoaTI6Ol00000000003<c<`030000000506IVI_l00000Ogmo0000002I
VIT00_l00003000000030>KVi_l00000oooo00H0oooo00Oo00000>KViP3Vi^H000000<c<c000003o
0000008000000_l00000101VIVH0000004a<C000000203<c<`05o`000?lI6AWo6ATIoaTI6Ol00000
C@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool01`0I6AT00ol00000<c<c
03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`03
0000002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<02P2c/k<2000000@0VIVI0P00000207moO`80
00000`1VIVH01Ol00000C4a<04a<C01<C4co0000008000000`0c<c<00ol000006ATI01TI6@0501TI
6Cl000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0@000000?o
6ATI00<0000003<c<`0c<c<00P000000301VIVH00000000000000000VIVI0000002c/k<000000<c<
c0000000i^KVo`0000L0oooo0_l000001`3Vi^H000000<c<c0000000/k>c0000002IVIT00P000000
1P1VIVH0000004a<C0000000<c<c000000Co6ATI00?o0000000000000000BP0000030?ooo`03o`00
003oool0oooo0340oooo00?o00000?ooo`3oool01`0I6AT00`000000<c<c03<c<`0203<c<`030000
001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01Ol00000Ogmo07moO`1oOgl0000000D0
VIVI00<000000;>c/`2c/k<0302c/k<2000000@0VIVI00D0000007moO`1oOgl0Ogmo0000000306IV
IP800000101<C4`01@000000<c<c03<c<`0c<c<0000000L06ATI00?o0000000000000000>`000003
0?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo014000000olI6AT00`00
0000<c<c03<c<`0200000080IVIV0P000000202IVIT000000;>c/`000000c<c<0000003Vi^Ko0000
203oool02?l00000i^KVo`00003<c<`000000;>c/`000000VIVI0P0000001P1VIVH0000004a<C000
0000<c<c000000Co6ATI0_l0001:000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo
0?ooo`0801TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV
06IVIP1VIVH0000000@0Ogmo00D0000009VIV@2IVIT0VIVI0000000A0;>c/`8000000`2IVIT20000
0080Ogmo0P00000306IVIP030000001<C4`0C4a<0080C4a<00@0000003<c<`0c<c<0<c<c0P000007
01TI6C`000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0B0000
00?o6ATI00Wo000003<c<`0c<c<00000o`0000000000IVIV00000?l000000P0000001P2c/k<00000
0<c<c0000000i^KVo`0000P0oooo017o00000>KViP000000c<c<o`00002c/k?o000009VIV@00003o
000006IVIP000000C4a<o`00000c<c<00000o`000004oaTI6@03o`0000000000000004L000000`3o
ool00ol00000oooo0?ooo`0a0?ooo`04o`00003oool0oooo000000P06ATI00<0000003<c<`0c<c<0
0P0c<c<00`000000C4a<04a<C00204a<C005o`00001VIVH0IVIV06IVIP0000000`1oOgl01@000000
VIVI09VIV@2IVIT0000000P0/k>c1@0000060;>c/`8000000`2IVIT01@000000Ogmo07moO`1oOgoo
000000<0IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT0
6ATI00D06ATI>`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
018000001?lI6AT00`000000<c<c0000000204a<C08000000P1oOgl3000000050<c<c0000000i^KV
0>KVi_l00000203oool01?l00000i^KV0000003<c<`20000000809VIVOl00000Ogmo0000001VIVKo
000004a<C000000203<c<`0500000?lI6AWo6ATIoaTI6Ol00000B@0000030?ooo`03o`00003oool0
oooo0340oooo00Co00000?ooo`3oool00000200I6AT00`000000<c<c03<c<`0203<c<`03o`00001<
C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`050000002IVIT0VIVI09VIV@00
0000202c/k<00`000000c<c<0<c<c0020<c<c08000001P2c/k<01@000000VIVI09VIV@2IVIT00000
00<0Ogmo0P00000206IVIP8000000P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI
00D06ATI00?o0000000000000000=`0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03
o`00003oool0oooo01<000001?lI6AT00`000000<c<c0000000204a<C08000000P1oOgl300000005
0<c<c0000000i^KV0>KVi_l00000203oool01?l00000i^KV0000003<c<`20000000809VIV@000000
Ogmo0000001VIVH0000004a<C000000203<c<`0500000?lI6AWo6ATIoaTI6Ol00000B00000030?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool00P00000801TI6@050000000c<c<0<c<c
03<c<`0000001@1<C4`010000000IVIV06IVIP00000307moO`050000002IVIT0VIVI09VIV@000000
1`2c/k<00`000000c<c<0<c<c0050<c<c0<00000102c/k<200000080VIVI0P00000307moO`050000
001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00D0
6ATI>@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01@00000
1?lI6AT00`000000<c<c0000000204a<C005o`0000000000Ogmo07moOol000000P0000001@3<c<`0
00000>KViP3Vi^Ko000000P0oooo00Co00000>KVi_l00000c<c<100000001P1oOgl0000006IVIP00
0000C4a<00000080<c<c00D00000oaTI6OlI6AWo6ATIo`000017000000<0oooo00?o00000?ooo`3o
ool0<@3oool00ol00000oooo0?ooo`03000000L06ATI00<0000003<c<`0c<c<00P0c<c<00`000000
C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl01@000000VIVI09VIV@2IVIT0
000000D0/k>c00<000000<c<c03<c<`02@3<c<`00`00003o00000;>c/`030;>c/`050000002IVIT0
VIVI09VIV@0000000`1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00<0000003<c<`0c<c<0
0`0c<c<00`0000006ATI01TI6@0501TI6CP000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00ol00000oooo0?ooo`0F000000?o6ATI00Co000003<c<`000000C4a<1@0000000`2IVIWo0000
0000000200000080i^KV00?o00000?ooo`3oool01P3oool01_l00000i^KV0000003<c<`000000;>c
/`80000000H0Ogmoo`00001VIVH0000004a<C000000203<c<`05o`000?lI6AWo6ATIoaTI6Ol00000
AP0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool00`0000000ol000006ATI
01TI6@0501TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`010000000IVIV
06IVIP00000307moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c00<0<c<
c08000000`2c/k<01?l00000VIVI09VIV@2IVIT200000080Ogmo0P00000206IVIP050000001<C4`0
C4a<o`0000000000100c<c<00`0000006ATI01TI6@0501TI6CL000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0G000000;o6ATI00@0000003<c<`0c<c<000000P1<
C4`01`000000IVIV000000000000VIVI0000002c/k<00P0000000`3Vi^Ko00000?ooo`080?ooo`04
o`00003Vi^H0000000000080/k>c00D00000o`0000000000IVIVo`00000204a<C0040000000c<c<0
<c<c000000?o6ATI00?o0000000000000000@`0000030?ooo`03o`00003oool0oooo0340oooo00?o
00000?ooo`3oool01@00000601TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<
C4`010000000IVIV06IVIP00000307moO`050000002IVIT0VIVI09VIVOl00000102c/k<00`000000
c<c<0<c<c00>0<c<c08000000P2c/k<2000000<0VIVI00D0000007moO`1oOgl0Ogmo0000000206IV
IP050000001<C4`0C4a<04a<C0000000100c<c<00ol000006ATI01TI6@0501TI6@03o`0000000000
000003<000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0G0000
00?o6ATI00@0000003<c<`0c<c<000000P1<C4`20000000307moO`00000000000080/k>c0P000000
0`3Vi^Ko00000?ooo`070?ooo`03o`00003Vi^H0i^KV008000000P2c/k<30000000506IVIP000000
C4a<04a<C00000000P0c<c<01@00003o6ATIoaTI6OlI6AWo000004@000000`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo00D000001`0I6AT00`000000<c<c03<c<`0203<c<`030000
001<C4`0C4a<0080C4a<00@0000006IVIP1VIVH000000`1oOgl010000000VIVI09VIV@0000040;>c
/`030000003<c<`0c<c<00H0c<c<100000060<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT0
1@000000Ogmo07moO`1oOgl000000080IVIV00D0000004a<C01<C4`0C4a<0000000403<c<`030000
000I6AT06ATI00D06ATI=@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003o
ool0oooo01P000000olI6AT010000000<c<c03<c<`00000204a<C005o`0000000000Ogmoo`000000
00000P2c/k<2000000030>KVi_l00000oooo00L0oooo00?o00000>KViP3Vi^H00P0000000`2c/k<0
000009VIV@020000000506IVIP000000C4a<04a<C00000000P0c<c<01@00003o6ATIoaTI6OlI6AWo
000004<000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00H000001`0I6AT0
0`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH01@000000Ogmo07mo
O`1oOgl0000000<0VIVI00D000000;>c/`2c/k<0/k>c000000070<c<c0030000003Vi^H0i^KV0080
i^KV00<00000o`00003<c<`0103<c<`01@00003o00000;>c/`2c/k?o000000<0VIVI00Go000007mo
O`1oOgl0Ogmoo`00000206IVIP05o`00001<C4`0C4a<04a<C?l00000100c<c<00`0000006ATI01TI
6@0501TI6C@000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0H
00000007o`000?lI6AWo6ATIoaTI6Ol00000000003<c<`030000000306IVI_l00000Ogmo00<00000
00Co00000<c<c0000000i^KV0_l000070?ooo`05o`00003Vi^H0i^KV00000?l000000P0000000`2I
VIT00000o`00000200000005o`00001<C4`0000003<c<ol000001?lI6AT00ol00000000000000010
000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`07000000L06ATI00?o0000
03<c<`0c<c<00P0c<c<01Ol00000C4a<04a<C01<C4`000000080IVIV00D0000007moO`1oOgl0Ogmo
0000000209VIV@050000002c/k<0/k>c0;>c/`0000001P3<c<`00`000000i^KV0>KViP050>KViP80
0000103<c<`200000080/k>c0P0000000`2IVIT000000000000207moO`050000001VIVH0IVIV06IV
IP0000000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00D06ATI<`0000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01X000001?lI6AT00`000000
<c<c03<c<`020000000506IVIP00000000000000002IVIT00P0000001@3<c<co00000000003Vi^Ko
000000L0oooo00Go00000>KViP3Vi^H000000<c<c0020000000:09VIV@000000Ogmo0000001VIVH0
000004a<C0000000<c<c000000Co6ATI00?o0000000000000000?`0000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool01`00000701TI6@030000000c<c<0<c<c0080<c<c00D00000
04a<C01<C4`0C4a<0000000306IVIP040000001oOgl0Ogmo00000080VIVI00D000000;>c/`2c/k<0
/k>c000000060<c<c0030000003Vi^H0i^KV00L0i^KV0P0000040<c<c0050000002c/k<0/k>c0;>c
/`0000000P2IVIT20000000307moO`000000IVIV0080IVIV00D0000004a<C01<C4`0C4a<00000004
03<c<`03o`00000I6AT06ATI00D06ATI<P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo01/000001?lI6AT00`000000<c<c03<c<`0200000080IVIV0P0000000`2I
VIT00000000000020<c<c0030000003Vi^Ko000000L0oooo00Go00000>KViP3Vi^Ko00000<c<c004
0000000807moO`000000IVIV0000001<C4`0000003<c<`000004oaTI6@03o`0000000000000003h0
00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00L0000000?o000001TI6@0I
6AT01@0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01000
0000Ogmo07moO`00000209VIV@050000002c/k<0/k>c0;>c/`000000103<c<`00`000000i^KV0>KV
iP0:0>KViP8000000`3<c<`200000080/k>c00Oo000009VIV@2IVIT0VIVIo`00001oOgl0000000<0
IVIV00D0000004a<C01<C4`0C4a<o`00000403<c<`030000000I6AT06ATI00D06ATI<@0000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo01`000001?lI6AT04?l00000
<c<c03<c<`00003o00000000001VIVKo00000000002IVIWo000000000?l00000c<c<0000003Vi^H2
o`0000H0oooo00Oo00000>KViP3Vi^H000000<c<c?l00000/k>c0080000000T0Ogmoo`00001VIVH0
000004a<C?l00000<c<c00000?l000000olI6AT00ol0000000000000000m000000<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`09000000L06ATI00<0000003<c<`0c<c<00P0c<c<0
1@000000C4a<04a<C01<C4`0000000<0IVIV00@0000007moO`1oOgl000000P2IVIT01@000000/k>c
0;>c/`2c/k<0000000<0c<c<00<000000>KViP3Vi^H0303Vi^H00`000000c<c<0<c<c0020<c<c003
0000002c/k<0/k>c008000000P2IVIT010000000Ogmoo`000000000206IVIP050000001<C4`0C4a<
04a<C0000000100c<c<2000000H06ATI<00000030?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo01d000001?lI6AT00`000000<c<c0000000204a<C00:0000001VIVH00000
0000002IVIT000000;>c/`000000c<c<o`000080i^KV00?o00000?ooo`3oool0103oool03_l00000
i^KV0000003<c<`000000;>c/`000000VIVIo`00001oOgl0000006IVI_l0000000000`0c<c<01@00
003o6ATIoaTI6OlI6AWo000003h000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo00T000001`0I6AT00`000000<c<c03<c<`0303<c<`04o`00001<C4`0C4a<000000<0IVIV00Co
000007moO`1oOgoo00000P2IVIT01@000000/k>c0;>c/`2c/k<0000000<0c<c<00<000000>KViP3V
i^H03@3Vi^H00`000000c<c<0<c<c0020<c<c0070000002c/k<0/k>c0;>c/`000000VIVI00000003
07moO`040000001VIVH0IVIV000000<0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI
6@0401TI6@03o`0000000000000002`000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0N000000Co6ATI00<0000003<c<`0000000P1<C4`20000000807moO`000000
VIVI0000002c/k<000000<c<c00000020>KViP03o`00003oool0oooo00@0oooo00[o00000>KViP00
0000c<c<0000002c/k<0000009VIV@000000Ogmo0P0000000`1<C4`0000003<c<`0203<c<`050000
0?lI6AWo6ATIoaTI6Ol00000?@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3o
ool02P00000701TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000206IV
IP040000001oOgl0Ogmo000000<0VIVI00D000000;>c/`2c/k<0/k>c000000030<c<c0030000003V
i^H0i^KV00d0i^KV00<000000<c<c03<c<`00P3<c<`01`000000/k>c0;>c/`2c/k<0000009VIV@00
00000`1oOgl010000000IVIV06IVIP00000304a<C0030000000c<c<0<c<c0080<c<c00<0000001TI
6@0I6AT01@0I6AT^000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3o
ool07`000004oaTI6@030000000c<c<000000080C4a<00co00000000001oOgoo000009VIV@000000
/k>c0000003<c<`000000>KVi_l000060?ooo`0;o`00003Vi^H0i^KVo`00003<c<`000000;>c/`00
0000VIVI0000001oOgl00P0000000`1<C4`000000000000203<c<`0500000?lI6AWo6ATIoaTI6Ol0
0000?00000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool02`00000701TI6@03
o`00000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP040000001oOgl0Ogmo
00000080VIVI00D000000;>c/`2c/k<0/k>c000000030<c<c0030000003Vi^H0i^KV00H0i^KV1?l0
00040>KViP8000000`3<c<`010000000/k>c0;>c/`00000209VIV@8000000P1oOgl01?l00000IVIV
06IVI_l0000304a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AT]000000<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool08@000003oaTI6@03o`00
000c<c<000000080000000/0IVIVo`00001oOgl0000009VIVOl00000/k>co`00003<c<`000000>KV
iP02o`0000D0oooo00go00000>KViP3Vi^H000000<c<c?l00000/k>co`00002IVIT00000o`00001V
IVH000000080C4a<00@0000003<c<ol0000000000olI6AT00ol0000000000000000i000000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0<000000L06ATI00<0000003<c<`0c<c<0
0P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00@0000007moO`1oOgl000000P2IVIT01@00
0000/k>c0;>c/`2c/k<0000000<0c<c<00<000000>KViP3Vi^H00`3Vi^H2o`0000@0oooo0_l00004
0>KViP8000000P3<c<`2000000030;>c/`000000VIVI0080VIVI00@0000007moO`1oOgl000000P1V
IVH01@000000C4a<04a<C01<C4`0000000@0<c<c00<0000001TI6@0I6AT01@0I6AT/000000<0oooo
00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool08P000002oaTI6@8000000P0c
<c<20000000506IVIP00000000000000002IVIT00`000000103<c<co00000000003Vi^H2o`0000<0
oooo017o00000>KViP3Vi^H0i^KV0000003<c<`000000;>c/`000000VIVIo`0000000000IVIVo`00
00000000C4a<0000000203<c<`0500000?lI6AWo6ATIoaTI6Ol00000>P0000030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool03@00000701TI6@050000000c<c<0<c<c03<c<`000000
0`1<C4`010000000IVIV06IVIP00000307moO`040000002IVIT0VIVI00000080/k>c00D000000<c<
c03<c<`0c<c<000000050>KViP03o`00003oool0oooo00D0oooo00?o00000>KViP3Vi^H00`3Vi^H2
00000080c<c<00<000000;>c/`0000000`2IVIT00`000000Ogmo0000000306IVIP050000001<C4`0
C4a<04a<C0000000100c<c<00ol00000000001TI6@0501TI6@03o`0000000000000002P000000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0S000000?o6ATI00<00000
03<c<`0c<c<00P00000206IVIP8000000P2IVIT200000080c<c<00@000000>KViP3Vi^Ko00000`3o
ool02_l00000i^KV0>KViP3Vi^H000000<c<c0000000/k>c0000002IVIT200000080IVIV00<00000
04a<C00000000P0c<c<01@00003o6ATIoaTI6OlI6AWo000003T000000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo00h000001`0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<
00<0000006IVIP1VIVH00P00000207moO`040000002IVIT0VIVI00000080/k>c00D000000<c<c03<
c<`0c<c<000000040>KViP03o`00003oool0oooo00H0oooo00?o00000>KViP3Vi^H0103Vi^H01@00
0000c<c<0<c<c0000000/k>c008000000P2IVIT00ol00000Ogmo0000000306IVIP050000001<C4`0
C4a<04a<C00000001@0c<c<00`0000006ATI01TI6@0401TI6BX000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0T000000?o6ATI00Oo000003<c<`0c<c<00000o`00
00000000IVIV00;o000000L0000009VIVOl000000000o`00003<c<`000000080i^KV00Co00000?oo
o`3oool0oooo0_l000020>KViP060000003<c<`000000;>c/`000000VIVI0P0000001Ol00000IVIV
0000001<C4co00000080<c<c00D00000oaTI6OlI6AWo6ATIo`00000h000000<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`0>00000003o`00000I6AT06ATI00D06ATI00Go000003<c
<`0c<c<0<c<co`00000304a<C005o`00001VIVH0IVIV06IVIP0000000P1oOgl01?l00000VIVI09VI
V@0000020;>c/`050000003<c<`0c<c<0<c<c00000000`3Vi^H00ol00000oooo0?ooo`070?ooo`?o
0000103Vi^H010000000c<c<0<c<c00000020;>c/`070000002IVIT0VIVI0000001oOgoo00000000
000206IVIP06o`0000000000C4a<04a<C?l000000000100c<c<00`0000006ATI01TI6@0401TI6BT0
00000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0T000000Co6ATI
00<0000003<c<`0000000P1<C4`01P000000IVIV0000001oOgl0000009VIV@80000000<0c<c<o`00
000000000P3Vi^H2o`000080oooo00Co00000>KViP3Vi^H000000P3<c<`20000000609VIV@000000
Ogmo0000001VIVH000000P1<C4`00`000000<c<c00000004oaTI6@03o`0000000000000003D00000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo00l000001`0I6AT01@000000<c<c
03<c<`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`040000002IVIT0VIVI
00000080/k>c00Go00000<c<c03<c<`0c<c<o`0000030>KViP03o`00003oool0oooo00X0oooo00Go
00000>KViP3Vi^H0i^KV000000020<c<c0070000002c/k<0/k>c0;>c/`000000VIVI0000000307mo
O`040000001VIVH0IVIV000000<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@05
01TI6@03o`0000000000000002D000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`0V000000?o6ATI00/0000003<c<`000000000004a<C0000000IVIV0000001oOgl0
000009VIV@0200000080c<c<00@000000>KViP3Vi^H0i^KV0_l000040>KViP030000003<c<`0c<c<
0080000000H0VIVI0000001oOgl0000006IVIP00000204a<C0030000000c<c<0000000Co6ATI00?o
0000000000000000=00000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool04000
000601TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP040000
001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k<000000P3<c<`00`000000i^KV0>KViP020>KV
iP03o`00003oool0oooo00X0oooo00Go00000>KViP3Vi^H0i^KV000000020<c<c08000000P2c/k<0
0`000000VIVI0000000307moO`040000001VIVH0IVIV000000<0C4a<00<0000003<c<`0c<c<00P0c
<c<00`0000006ATI01TI6@0501TI6BL000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`0W000000?o6ATI00/0000003<c<`0c<c<0000004a<C?l00000IVIV0000001o
Ogoo000009VIV@03000000030<c<c0000000i^KV0080i^KV00?o00000>KViP3Vi^H00`3Vi^H00`00
0000c<c<0<c<c0020000000609VIV@000000Ogmo0000001VIVH000000P1<C4`00`000000<c<c0000
0004oaTI6@03o`0000000000000003<000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003o
ool0oooo014000001P0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C0000000
0P1VIVH01@000000Ogmo07moO`1oOgl000000080VIVI00@000000;>c/`2c/k<000000P3<c<`01@00
0000i^KV0>KViP3Vi^Ko000000d0oooo00Go00000>KViP3Vi^H0i^KV000000030<c<c0050000002c
/k<0/k>c0000002IVIT00P00000207moO`04o`00001VIVH0IVIV000000<0C4a<00?o000003<c<`0c
<c<00P0c<c<00`0000006ATI01TI6@0501TI6BH000000`3oool00ol00000oooo0?ooo`0I0?ooo`00
6P3oool00ol00000oooo0?ooo`0W00000005o`000?lI6AWo6ATIoaTI6Ol000000P0c<c<03Ol00000
C4a<0000001VIVKo000007moO`000000VIVIo`00002c/k<000000<c<c00000002@3Vi^H00ol00000
c<c<0<c<c0020000000809VIV@000000Ogmo0000001VIVH0000004a<C?l0000203<c<`0300000?lI
6AWo6ATI00;o6ATI00?o0000000000000000<P0000030?ooo`03o`00003oool0oooo0340oooo00?o
00000?ooo`3oool04P00000601TI6@03o`00000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<
o`00000206IVIP0500000?l00000Ogmo07moO`0000000P2IVIT010000000/k>c0;>c/`0000020<c<
c0050000003Vi^H0i^KV0>KVi_l000003@3oool2o`000080i^KV00Go00000<c<c03<c<`0c<c<o`00
00020;>c/`040000002IVIT0VIVI00000080Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000
<c<c03<c<`0203<c<`030000000I6AT06ATI00D06ATI9@0000030?ooo`03o`00003oool0oooo01T0
oooo000J0?ooo`03o`00003oool0oooo02T000000_lI6AT200000080<c<c00H0000004a<C0000000
IVIV0000001oOgl3000000040;>c/`000000c<c<000000T0i^KV00H000000<c<c0000000/k>c0000
002IVIT200000080IVIV00<0000004a<C00000000P0c<c<01@00003o6ATIoaTI6OlI6AWo000003@0
00000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo018000001`0I6AT01@000000
<c<c03<c<`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`040000002IVIT0
VIVIo`000080/k>c00D000000<c<c03<c<`0c<c<000000030>KViP03o`00003oool0oooo00`0oooo
00Co00000>KViP3Vi^H000000`3<c<`00`000000/k>c0000000209VIV@070000001oOgl0Ogmo07mo
O`000000IVIV0000000404a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AT0
0ol0000000000000000Q000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?oo
o`3oool0:@000004oaTI6@0@0000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000002I
VIT000000;>c/`000000c<c<000000P0i^KV00L000000<c<c03<c<`000000;>c/`000000VIVI0080
00000P1VIVH00`000000C4a<0000000203<c<`0500000?lI6AWo6ATIoaTI6Ol00000<`0000030?oo
o`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool04`00000701TI6@050000000c<c<0<c<c
03<c<`0000000`1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00@0000009VIV@2IVIT00000
0P2c/k<01@000000c<c<0<c<c03<c<`000000080i^KV00?o00000?ooo`3oool0303oool01Ol00000
i^KV0>KViP3Vi^H000000080c<c<00@000000;>c/`2c/k<000000P2IVIT01`000000Ogmo07moO`1o
Ogl0000006IVIP000000101<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00@06ATI
900000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02X000001?lI
6AT03`000000<c<c03<c<`000000C4a<o`00001VIVH0000007moO`000000VIVI0000002c/k<00000
0<c<c002000000L0i^KV00<000000<c<c00000000P2c/k<20000000407moO`000000IVIV00000080
C4a<00@0000003<c<`0c<c<000000olI6AT00ol0000000000000000`000000<0oooo00?o00000?oo
o`3oool0<@3oool00ol00000oooo0?ooo`0D000000L06ATI00D0000003<c<`0c<c<0<c<c00000003
04a<C0040000001VIVH0IVIV000000<0Ogmo00@0000009VIV@2IVIT000000P2c/k<010000000c<c<
0<c<c00000030>KViP03o`00003oool0oooo00`0oooo00Go00000>KViP3Vi^H0i^KV000000020<c<
c0040000002c/k<0/k>c00000080VIVI00Oo000007moO`1oOgl0Ogmoo`00001VIVH0000000@0C4a<
00Go000003<c<`0c<c<0<c<c0000000701TI6B<000000`3oool00ol00000oooo0?ooo`0I0?ooo`00
6P3oool00ol00000oooo0?ooo`0Z00000003o`000?lI6AWo6ATI00;o6ATI0P0000001@0c<c?o0000
04a<C0000000IVIV00<0000000@0VIVI0000002c/k<000000P3<c<`00`000000i^KV0>KViP050>KV
iP030000003<c<`000000080/k>c100000001Ol00000000004a<C01<C4co00000080<c<c00D00000
oaTI6OlI6AWo6ATIo`00000a000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?oo
o`0E000000L06ATI00Go000003<c<`0c<c<0<c<c0000000304a<C0050000001VIVH0IVIV00000?l0
00000P1oOgl010000000VIVI09VIV@0000020;>c/`040000003<c<`0c<c<000000<0i^KV00?o0000
0?ooo`3oool0303oool01Ol00000i^KV0>KViP3Vi^Ko00000080c<c<00Co00000;>c/`2c/k<00000
0P2IVIT010000000Ogmo07moO`00000206IVIP8000000P1<C4`00`000000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00D06ATI8P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo02d000001?lI6AT00`000000<c<c0000000200000080IVIV0P0000001`2IVIT00000
0;>c/ol0000000000<c<c00000001P3Vi^H010000000c<c<0<c<c00000020;>c/`040000002IVIT0
000007moO`8000000P1<C4`010000000<c<c03<c<`000003oaTI6@03o`0000000000000002h00000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo01H000001`0I6AT01@000000<c<c
03<c<`0c<c<0000000<0C4a<00P0000006IVIP1VIVH0IVIV0000001oOgoo000000000080VIVI00Ko
00000;>c/`2c/k<000000<c<c00000040>KViP03o`00003oool0oooo00`0oooo00Go00000>KViP3V
i^H0i^KV000000020<c<c0040000002c/k<0/k>c00000080VIVI00@0000007moO`1oOgl000000`1V
IVH010000000C4a<04a<C000000403<c<`030000000I6AT06ATI00@06ATI8P0000030?ooo`03o`00
003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo02h000001?lI6AT00`000000<c<c03<c
<`030000000306IVIP0000000000008000000P2c/k<00`000000c<c<00000002000000@0i^KV00Co
00000<c<c03<c<`000000P2c/k<010000000VIVI0000001oOgl30000000504a<C0000000<c<c03<c
<`0000000olI6AT00ol0000000000000000]000000<0oooo00?o00000?ooo`3oool0<@3oool00ol0
0000oooo0?ooo`0F00000003o`00000I6AT06ATI00D06ATI00D0000003<c<`0c<c<0<c<c00000003
04a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl010000000VIVI09VIV@0000020;>c/`030000
003<c<`0000000@0i^KV00?o00000?ooo`3oool0303oool01Ol00000i^KV0>KViP3Vi^H000000080
c<c<00@000000;>c/`2c/k?o00000P2IVIT010000000Ogmo07moO`00000306IVIP040000001<C4`0
C4a<000000@0<c<c00<0000001TI6@0I6AT0100I6ATQ000000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool0;P0000000ol0003o6ATIoaTI6@02oaTI6@0>0000000c<c<0
<c<co`00001<C4`0000006IVIP000000Ogmo00000?l0000000000;>c/`0000030<c<c0030000003V
i^H0i^KV0080i^KV00@000000<c<c03<c<`000000P2c/k<02@000000VIVIo`00001oOgl0000006IV
IP000000C4a<0000000203<c<`0500000?lI6AWo6ATIoaTI6Ol00000;P0000030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool06000000701TI6@050000000c<c<0<c<c03<c<`000000
0`1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00@0000009VIV@2IVIT000000P2c/k<01?l0
0000c<c<00000?l000030>KViP03o`00003oool0oooo00`0oooo00Go00000>KViP3Vi^H0i^KV0000
00020<c<c0040000002c/k<0/k>c00000080VIVI00@0000007moO`1oOgl000000`1VIVH01?l00000
C4a<04a<C?l0000403<c<`03o`00000I6AT06ATI00D06ATI7`0000030?ooo`03o`00003oool0oooo
01T0oooo000J0?ooo`03o`00003oool0oooo030000000olI6AT010000000<c<c03<c<`00000204a<
C080000000P0Ogmo0000002IVIT0VIVI0000002c/k?o000000000080c<c<00Go00000000003Vi^H0
i^KV000000020<c<c00<0000002c/k<0/k>c0;>c/ol00000000007moOol00000IVIV0000001<C4`0
00000P0c<c<00ol0003o6ATIoaTI6@02oaTI6@03o`0000000000000002/000000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo01P000001`0I6AT00`000000<c<c03<c<`0203<c<`05
o`00001<C4`0C4a<04a<C?l000000P1VIVH01?l00000Ogmo07moO`00000309VIV@030000002c/k<0
000000<0c<c<00@000000>KViP3Vi^Ko00003P3oool01Ol00000i^KV0>KViP3Vi^H000000080c<c<
00L000000;>c/`2c/k<0/k>c0000002IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV00000003
04a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0100I6ATO000000<0oooo00?o0000
0?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0<@000003oaTI6@040000000c<c<0<c<c
00000080C4a<0P0000001@1oOgl000000000002IVIT000000080/k>c00@000000<c<c03<c<`0c<c<
0P0000040<c<c00<0000002c/k<0/k>c0000002IVIT0000007moO`000000IVIV0000001<C4`00000
0P0c<c<00`00003o6ATIoaTI6@02oaTI6@03o`0000000000000002X000000`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo01T000001`0I6AT00`000000<c<c03<c<`0203<c<`050000
001<C4`0C4a<04a<C00000000P1VIVH010000000Ogmo07moO`00000309VIV@030000002c/k<00000
00<0c<c<00@000000>KViP3Vi^Ko00003P3oool01Ol00000i^KV0>KViP3Vi^H000000080c<c<00L0
00000;>c/`2c/k<0/k>c0000002IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<
C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0100I6ATN000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool0<P000003oaTI6@040000000c<c<0<c<c0000
0080C4a<0P00000207moO`030000002IVIWo00000080/k>c00D000000<c<c03<c<`0c<c<00000005
0<c<c0030000002c/k<0/k>c008000000P1oOgl01@000000IVIV0000001<C4`000000080<c<c00<0
0000oaTI6OlI6AT00_lI6AT00ol0000000000000000Y000000<0oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`0I00000003o`00000I6AT06ATI00D06ATI00<0000003<c<`0c<c<00P0c
<c<01@000000C4a<04a<C01<C4`000000080IVIV00@0000007moO`1oOgl000000P2IVIT010000000
/k>c0;>c/`0000030<c<c0040000003Vi^H0i^KVo`0000h0oooo00Go00000>KViP3Vi^H0i^KV0000
00020<c<c007o`00002c/k<0/k>c0;>c/ol00000VIVI0000000207moO`050000001VIVH0IVIV06IV
IP0000000P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00@06ATI7@0000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo0380000000Co0000oaTI6OlI
6AWo6ATI0P000000100c<c?o00000000001<C4`2o`0000040000001oOgoo000009VIV@80000000<0
/k>c000000000000203<c<`03?l00000/k>c0000002IVIT00000o`00001oOgl0000006IVI_l00000
C4a<00000080<c<c00<00000oaTI6OlI6AT00_lI6AT00ol0000000000000000X000000<0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0K000000L06ATI00<0000003<c<`0c<c<00P0c
<c<01@000000C4a<04a<C01<C4`000000080IVIV00@0000007moO`1oOgl000000P2IVIT010000000
/k>c0;>c/ol000020<c<c004o`00003Vi^H0i^KV0>KViP;o0000303oool00ol00000i^KV0>KViP02
0>KViP040000003<c<`0c<c<00000080/k>c00@0000009VIV@2IVIT000000P1oOgl01Ol00000IVIV
06IVIP1VIVKo00000080C4a<00?o000003<c<`0c<c<00P0c<c<00ol000006ATI01TI6@0501TI6@03
o`0000000000000001T000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0d000000Co6ATI00<0000003<c<`0000000P1<C4`01@000000IVIV0000001oOgl000000080
VIVI00@000000;>c/`2c/k<00000203<c<`01@000000/k>c0000002IVIT000000080Ogmo00Co0000
0000001<C4`000000`0c<c<01Ol0003o6ATIoaTI6OlI6AWo000002X000000`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo01`000001`0I6AT00`000000<c<c03<c<`0203<c<`04o`00
001<C4`0C4a<o`0000<0IVIV00Co000007moO`1oOgl000000P2IVIT010000000/k>c0;>c/`000002
0<c<c0030000003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool02@3oool00ol00000i^KV0>KViP02
0>KViP040000003<c<`0c<c<00000080/k>c00@0000009VIV@2IVIT000000`1oOgl01@000000IVIV
06IVIP1VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c0000000801TI6A/000000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0e000000Co6ATI00<0000003<c<`00
00000P1<C4`01@000000IVIV0000001oOgl000000080VIVI00@000000;>c/`2c/k<000001`3<c<`0
30000000/k>c0;>c/`000000VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00<00000
oaTI6OlI6AT00_lI6AT00ol0000000000000000W000000<0oooo00?o00000?ooo`3oool0<@3oool0
0ol00000oooo0?ooo`0M000000L06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001V
IVH0IVIV000000<0Ogmo00@0000009VIV@2IVIT000000P2c/k<010000000c<c<0<c<c00000040>KV
iP03o`00003oool0oooo00T0oooo00?o00000>KViP3Vi^H00P3Vi^H010000000c<c<0<c<c0000002
0;>c/`040000002IVIT0VIVI00000080Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0030000
000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6ATJ000000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0=P000004oaTI6@03o`00000c<c<000000080C4a<00D0
000006IVI_l00000Ogmo0000000209VIV@040000002c/k<0/k>c000000L0c<c<00D000000;>c/`00
0000VIVI0000000207moO`050000001VIVH0000004a<C00000000P0c<c<00`00003o6ATIoaTI6@02
oaTI6@03o`0000000000000002H000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo01d0000000?o000001TI6@0I6AT0100I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0
C4a<04a<C00000000P1VIVH010000000Ogmo07moO`00000309VIV@040000002c/k<0/k>c00000080
c<c<00<000000>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`080?ooo`03o`00003Vi^H0i^KV0080
i^KV0P0000020<c<c0040000002c/k<0/k>c00000080VIVI00@0000007moO`1oOgl000000`1VIVH0
10000000C4a<04a<C000000403<c<`030000000I6AT06ATI00H06ATI6@0000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo03P000000_lI6AT20000000603<c<`000000
000004a<C?l00000IVIV0P0000001?l00000000009VIVOl000020;>c/`8000001@3<c<`03`000000
/k>c0;>c/`000000VIVI00000?l00000Ogmo0000001VIVKo000004a<C000003o000003<c<`020000
00?o6ATI00?o00000000000000009@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool07P00000701TI6@8000000`0c<c<01@000000C4a<04a<C01<C4`000000080IVIV0P000000
0`1oOgl000000000000209VIV@040000002c/k<0/k>co`000080c<c<00?o00000000003Vi^H00P3V
i^H2o`0000T0oooo00?o00000>KViP3Vi^H00P3Vi^H01@000000c<c<0<c<c03<c<`000000080/k>c
00@0000009VIV@2IVIWo00000P1oOgl010000000IVIV06IVIP00000304a<C0030000000c<c<0<c<c
0080<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000000F000000<0oooo00?o00000?oo
o`3oool06@3oool001X0oooo00?o00000?ooo`3oool0>@000003oaTI6@050000000c<c<0<c<c0000
001<C4`00P0000001@1VIVH0000007moO`000000VIVI008000000P2c/k<300000080c<c<00@00000
0;>c/`2c/k<000000P2IVIT00`000000Ogmo0000000206IVIP040000001<C4`0C4a<00000080<c<c
00D00000oaTI6OlI6AWo6ATIo`00000V000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`0O000000P06ATI00H0000003<c<`0c<c<0<c<co`000000000204a<C005o`0000000000
IVIV06IVIP0000000P1oOgl010000000VIVI09VIV@0000020;>c/`050000003<c<`0c<c<0<c<c000
0000103Vi^H2o`0000L0oooo00?o00000>KViP3Vi^H00P3Vi^H01@000000c<c<0<c<c03<c<`00000
0080/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`040000001VIVH0IVIV000000<0C4a<00<0
000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6AP000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`0j000000?o6ATI00Co000003<c<`0c<c<000000P1<
C4`01@000000IVIVo`00001oOgl000000080VIVI00<000000;>c/`2c/k<00P2c/k<2000000@0/k>c
00D0000009VIV@2IVIT0000007moO`020000000506IVIP000000C4a<04a<C00000000P0c<c<01@00
003o6ATIoaTI6OlI6AWo000002D000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo02000000200I6AT00ol00000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000P1V
IVH010000000Ogmo07moO`00000209VIV@030000002c/k<0/k>c008000000P3<c<`2000000@0i^KV
00?o00000?ooo`3oool01@3oool00ol00000i^KV0>KViP020>KViP050000003<c<`0c<c<0<c<c000
00000P2c/k<010000000VIVI09VIV@00000307moO`04o`00001VIVH0IVIVo`0000<0C4a<00?o0000
03<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6AL000000`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`0k000000?o6ATI00<0000003<c<`0c<c<00P0000002@1<
C4co000006IVIP000000Ogmoo`0000000000VIVIo`00000:0;>c/`040000002IVIT0VIVI00000080
Ogmo00<0000006IVIP0000000P1<C4`010000000<c<c03<c<`000003oaTI6@03o`00000000000000
028000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo0200000000?o00000000
000I6AT01P0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH0
10000000Ogmo07moO`00000209VIV@05o`00002c/k<0/k>c0;>c/`0000000`3<c<`00`000000i^KV
0>KViP020>KViP?o00000`3oool2o`0000D0i^KV00D000000<c<c03<c<`0c<c<000000020;>c/`04
0000002IVIT0VIVI000000<0Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`02
03<c<`030000000I6AT06ATI00D06ATI5P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo03/000001?lI6AT02@000000<c<c03<c<`0c<c<0000004a<C0000000IVIV
0000000207moO`040000002IVIT00000000000T0/k>c00So000009VIV@2IVIWo000007moO`000000
IVIV00000080C4a<00@0000003<c<`0c<c<000001?lI6AT00ol0000000000000000Q000000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0R000000L06ATI00<0000003<c<`0c<c<0
0`0c<c<01Ol00000C4a<04a<C01<C4co00000080IVIV00Co000007moO`1oOgl000000P2IVIT01@00
0000/k>c0;>c/`2c/k<0000000<0c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000ooooo`000007
0>KViP050000003<c<`0c<c<0<c<c00000000P2c/k<010000000VIVI09VIV@00000307moO`040000
001VIVH0IVIV000000<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@03
o`0000000000000001<000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo
0?ooo`0l000000Co6ATI00P0000003<c<`0c<c<0<c<c0000001<C4`0000006IVIP80000000D0Ogmo
0000002IVIT0VIVI000000080;>c/`040000002IVIT0VIVI00000080Ogmo00<0000006IVIP000000
0P1<C4`010000000<c<c03<c<`000004oaTI6@03o`00000000000000020000000`3oool00ol00000
oooo0?ooo`0a0?ooo`03o`00003oool0oooo02<000001`0I6AT00`000000<c<c03<c<`0203<c<`05
0000001<C4`0C4a<04a<C00000000`1VIVH010000000Ogmo07moO`00000209VIV@050000002c/k<0
/k>c0;>c/`0000000`3<c<`2000000D0i^KV00?o00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<
c0020<c<c0040000002c/k<0/k>c00000080VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP05
0000001<C4`0C4a<04a<C0000000100c<c<00`0000006ATI01TI6@0501TI6AD000000`3oool00ol0
0000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`0m000000Co6ATI00Oo000003<c<`0c
<c<0<c<co`00001<C4`000000080IVIV00<0000007moOol000000P2IVIT00`000000/k>c0;>c/`06
0;>c/`040000002IVIT0VIVI00000080Ogmo00<0000006IVIP0000000P1<C4`010000000<c<c03<c
<`000004oaTI6@03o`0000000000000001l000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00
003oool0oooo02@000001`0I6AT00ol00000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C000
00000`1VIVH010000000Ogmo07moO`00000209VIV@050000002c/k<0/k>c0;>c/`000000103<c<`0
0`000000i^KV0>KViP0<0>KViP050000003<c<`0c<c<0<c<c?l000000`2c/k<01?l00000VIVI09VI
V@00000207moO`050000001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<c03<c<`0303<c<`03
0000000I6AT06ATI00D06ATI500000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo03l000000olI6AT200000080<c<c00L0000004a<C0000000000006IVI_l00000Ogmo
0080000000<0VIVIo`00000000001P2c/k<01`000000VIVI09VIV@2IVIT0000007moOol000000P1V
IVH010000000C4a<04a<C000000203<c<`0300000?lI6AWo6ATI00;o6ATI00?o0000000000000000
7P0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool09P00000601TI6@800000
0`0c<c<200000080C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`030000002IVIT0VIVI0080
00000P2c/k<2000000<0c<c<0P00000<0>KViP030000003<c<`0c<c<0080c<c<00@000000;>c/`2c
/k<000000`2IVIT010000000Ogmo07moO`00000306IVIP050000001<C4`0C4a<o`0000000000100c
<c<00`0000006ATI01TI6@0501TI6A<000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`10000000Co6ATI00@0000003<c<`0c<c<000000P1<C4`01P000000IVIV0000
00000000Ogmo00000080VIVI00<000000;>c/`2c/k<00`2c/k<01@000000VIVI09VIV@2IVIT00000
0080Ogmo00H0000006IVIP1VIVKo000004a<C000000303<c<`0300000?lI6AWo6ATI00;o6ATI00?o
00000000000000007@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool09`00
000701TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4co00000000000206IVIP05o`00
00000000Ogmoo`00000000000P2IVIT200000080/k>c0P0000030<c<c08000002P3Vi^H00`000000
c<c<0<c<c0020<c<c0040000002c/k<0/k>c000000<0VIVI00@0000007moO`1oOgl000000`1VIVH0
1@000000C4a<04a<C01<C4`0000000@0<c<c00<0000001TI6@0I6AT01@0I6ATC000000<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0@@000004oaTI6@03o`00000c<c<0
<c<c0080000000H0C4a<0000001VIVH0IVIV0000001oOgl20000000609VIV@00000000000000002c
/k<000001@2IVIT010000000Ogmo07moO`00000206IVIP040000001<C4`0000000000080<c<c00<0
0000oaTI6OlI6AT00_lI6AT00ol0000000000000000L000000<0oooo00?o00000?ooo`3oool0<@3o
ool00ol00000oooo0?ooo`0X000000L06ATI00?o000003<c<`0c<c<00P0c<c<01@000000C4a<04a<
C01<C4`0000000<0IVIV00@0000007moO`1oOgl000000`2IVIT01@000000/k>c0;>c/`2c/k<00000
00@0c<c<0P0000080>KViP030000003<c<`0c<c<00<0c<c<00@000000;>c/`2c/k<000000`2IVIT0
10000000Ogmo07moO`00000306IVIP050000001<C4`0C4a<04a<C0000000100c<c<00`0000006ATI
01TI6@0501TI6A8000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?oo
o`13000000?o6ATI00H0000003<c<`0c<c<0<c<c0000001<C4`20000000506IVI_l00000Ogmo07mo
Ool000000`2IVIT2000000H0VIVI00@0000007moO`1oOgl000000P1VIVH010000000C4a<04a<C000
000203<c<`03o`000?lI6AWo6ATI00;o6ATI00?o00000000000000006`0000030?ooo`03o`00003o
ool0oooo0340oooo00?o00000?ooo`3oool0:@00000701TI6@030000000c<c<0<c<c0080<c<c00D0
000004a<C01<C4`0C4a<0000000306IVIP040000001oOgl0Ogmo000000<0VIVI00D000000;>c/`2c
/k<0/k>c000000050<c<c0030000003Vi^H0i^KV00@0i^KV0P0000050<c<c0050000002c/k<0/k>c
0;>c/`0000000`2IVIT010000000Ogmo07moO`00000306IVIP050000001<C4`0C4a<04a<C0000000
100c<c<00`0000006ATI01TI6@0501TI6@03o`0000000000000000h000000`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`14000000?o6ATI00D0000003<c<`0c<c<0<c<c
0000000204a<C0030000001VIVH000000080Ogmo0P00000909VIV@070000001oOgl0Ogmo07moOol0
0000IVIV0000000204a<C0050000000c<c<0<c<c03<c<`0000000olI6AT00ol0000000000000000K
000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0Y000000P06ATI00<00000
03<c<`0c<c<00P0c<c<01Ol00000C4a<04a<C01<C4co00000080IVIV00Ko00000000001oOgl0Ogmo
o`000000000209VIV@05o`00002c/k<0/k>co`00000000001@3<c<`00ol000000000000000020>KV
iP030000003<c<`0c<c<00D0c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@040000001oOgl0
Ogmo000000<0IVIV00D0000004a<C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI00D06ATI
4@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo04D000000olI
6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVIP0000000`1oOgl00`000000VIVI
09VIV@0709VIV@040000001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`000000`0c<c<01@00
003o6ATIoaTI6OlI6AWo000001`000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo02X00000200I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1V
IVH01@000000Ogmo07moO`1oOgl000000080VIVI00@000000;>c/`2c/k<0/k>c0P0000060<c<c080
0000203<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl01@00
0000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@05
01TI6A0000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`150000
0005o`000?lI6AWo6ATIoaTI6@0000000`0c<c<01P000000C4a<04a<C?l00000IVIV000000<0Ogmo
00<0000009VIV@2IVIT01P2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00@0000004a<C01<
C4`000000`0c<c<01@00003o6ATIoaTI6OlI6AWo000001/000000`3oool00ol00000oooo0?ooo`0a
0?ooo`03o`00003oool0oooo02/00000200I6AT00ol00000<c<c03<c<`0203<c<`050000001<C4`0
C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1oOgl000000080VIVI00<000000;>c/`2c/k<0
0P2c/k<2000000l0c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@05o`00001oOgl0Ogmo07mo
Ool000000P1VIVH01Ol00000C4a<04a<C01<C4`0000000D0<c<c00<0000001TI6@0I6AT0100I6AT@
000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0AP000004oaTI
6@8000000P0c<c<20000000404a<C0000000IVIVo`000080000000<0Ogmoo`00000000001`2IVIT0
1@000000Ogmo07moO`1oOgl000000080IVIV00@0000004a<C01<C4co00000P0c<c<00ol0003o6ATI
oaTI6@02oaTI6@03o`0000000000000001P000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00
003oool0oooo02/0000000?o00000000000I6AT01P0I6AT00`000000<c<c03<c<`0203<c<`040000
001<C4`0C4a<04a<C08000000P1VIVH200000080Ogmo00H0000009VIV@2IVIT00000o`0000000003
0;>c/`030000003<c<`0c<c<00`0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2I
VIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0<c<c00<0<c<c
00<0000001TI6@0I6AT0100I6AT00`00003o00000000000<000000<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0A`000005oaTI6@070000000c<c<0<c<c03<c<`000000
C4a<0000000306IVIP040000001oOgl0Ogmo000000H0VIVI00D0000007moO`1oOgl0Ogmo00000002
06IVIP040000001<C4`0C4a<00000080<c<c00<00000oaTI6OlI6AT00olI6AT00ol0000000000000
000G000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0^000000L06ATI00<0
000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP000000
0P1oOgl00`000000VIVI09VIV@0209VIV@060000002c/k<0/k>c0;>c/ol0000000002`3<c<`00`00
0000/k>c0;>c/`030;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IVIP1V
IVH0000000<0C4a<00<0000003<c<`0c<c<00`0c<c<00ol000006ATI01TI6@0501TI6@h000000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`18000000Go6ATI00@00000
03<c<`0c<c<000000P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo0`00000209VIV@030000
001oOgl0Ogmo00<0Ogmo00@0000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<`000005oaTI
6@03o`0000000000000001H000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
02l000001`0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IV
IP1VIVH0IVIV0000000207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<2
000000P0c<c<00<000000;>c/`2c/k<0102c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00D0
000006IVIP1VIVH0IVIV0000000304a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0
1P0I6AT=000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0B000
00000ol0003o6ATIoaTI6@03oaTI6@040000000c<c<0<c<c00000080C4a<00D0000006IVIP1VIVH0
IVIV0000000407moO`8000001P1oOgl01`000000IVIV06IVIP1VIVH0000004a<C00000000`0c<c<0
0`00003o6ATIoaTI6@02oaTI6@03o`0000000000000001H000000`3oool00ol00000oooo0?ooo`0a
0?ooo`03o`00003oool0oooo02l0000000?o000001TI6@0I6AT01@0I6AT00`000000<c<c03<c<`02
03<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`8000000`2I
VIT00`000000/k>c0;>c/`030;>c/`<000000`3<c<`2000000L0/k>c00<0000009VIV@2IVIT00P2I
VIT010000000Ogmo07moO`00000306IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0
0P0c<c<00`0000006ATI01TI6@0501TI6@d000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3o
ool00ol00000oooo0?ooo`1;000000Co6ATI00Co00000000000c<c?o00001000000206IVIP03o`00
001oOgl0Ogmo00X0Ogmo00Co000006IVIP1VIVKo00000P1<C4`01@00003o000003<c<`0c<c<00000
00Co6ATI00?o00000000000000005@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?oo
o`3oool0<@00000701TI6@030000000c<c<0<c<c0080<c<c0P00000304a<C005o`0000000000IVIV
06IVI_l000000`1oOgl200000080VIVI00<00000o`00000000001@2c/k<3000000T0/k>c00<00000
09VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00?o000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00D06ATI300000030?ooo`03o`00003o
ool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo04`000001OlI6AT01P000000<c<c03<c<`0c
<c<0000004a<C080000000<0IVIV0000000000002P1oOgl01@000000IVIV06IVIP1VIVH000000080
C4a<00D0000003<c<`0c<c<0<c<c00000004oaTI6@03o`0000000000000001@000000`3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo038000001`0I6AT00`000000<c<c03<c<`0303<c
<`030000001<C4`0C4a<0080C4a<00@0000006IVIP1VIVH00000101oOgl2000000<0VIVI0P00000?
0;>c/`030000002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP050000001<
C4`0C4a<04a<C0000000100c<c<00`0000006ATI01TI6@0601TI6@03o`0000000000000000P00000
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1>000000Co6ATI00D0
000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH0IVIV008000002@1oOgl01@000000IVIV
06IVIP1VIVH000000080C4a<00D0000003<c<`0c<c<0<c<c00000004oaTI6@03o`00000000000000
01<000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03<000001`0I6AT20000
00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP02000000@0Ogmo00<0000009VI
V@2IVIT00P2IVIT2000000d0/k>c00<0000009VIV@2IVIT00`2IVIT01@000000Ogmo07moO`1oOgl0
000000<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT0
6ATI00H06ATI2P0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
04l000001?lI6AT01Ol00000<c<c03<c<`0c<c<000000080C4a<0P00000206IVIP8000001`1oOgl0
0`000000IVIV06IVIP0206IVIP040000001<C4`0C4a<000000<0<c<c00<00000oaTI6OlI6AT00_lI
6AT00ol0000000000000000B000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?oo
o`0d000000P06ATI00<0000003<c<`0c<c<00P0c<c<2000000<0C4a<00Co000006IVIP1VIVH0IVIV
0P00000307moO`800000102IVIT2000000X0/k>c0P00000509VIV@050000001oOgl0Ogmo07moO`00
0000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I
6AT01P0I6AT9000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
D0000003oaTI6@8000000`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV0P00000507moO`03
0000001VIVH0IVIV0080IVIV00@0000004a<C01<C4`00000100c<c<00ol0003o6ATIoaTI6@02oaTI
6@03o`00000000000000014000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
03D000001`0I6AT00`000000<c<c03<c<`0403<c<`050000001<C4`0C4a<04a<C0000000101VIVH0
0`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI0`0000050;>c/`8000001`2IVIT0
1@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c
<`0203<c<`030000000I6AT06ATI00H06ATI2@0000030?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo054000001?lI6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00<0
000006IVIP1VIVH00P1VIVH30000000307moO`000000IVIV00D0IVIV00@0000004a<C01<C4`00000
0`0c<c<00`00003o6ATIoaTI6@03oaTI6@03o`00000000000000010000000`3oool00ol00000oooo
0?ooo`0a0?ooo`03o`00003oool0oooo03H000001`0I6AT2000000D0<c<c00@0000004a<C01<C4`0
C4a<0P00000306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT01@2IVIT5000000T0
VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<00`0c<c<00`0000006ATI01TI6@0601TI6@P000000`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`1B000000Co6ATI00D0000003<c<`0c<c<0<c<co`00000304a<
C003o`00001VIVH0IVIV00@0IVIV00<0000006IVIP1VIVH01@1VIVH01@000000C4a<04a<C01<C4`0
000000<0<c<c00<00000oaTI6OlI6AT00olI6AT00ol0000000000000000?000000<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`0f00000003o`00000I6AT06ATI00H06ATI00<00000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP000000101o
Ogl2000001<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6@P000000`3o
ool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1B00000003o`000?lI6AWo
6ATI00;o6ATI00@0000003<c<`0c<c<0<c<c0P00000204a<C08000003@1VIVH01@000000C4a<04a<
C01<C4`0000000<0<c<c00<00000oaTI6OlI6AT00_lI6AT00ol0000000000000000?000000<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0i000000L06ATI00?o000003<c<`0c<c<0
0`0c<c<00ol00000C4a<04a<C00204a<C0070000001VIVH0IVIV06IVIP00003o00000000000307mo
O`@000003`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<
C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI1`0000030?oo
o`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo05@000001?lI6AT00`000000
<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C0000000301VIVH01@000000C4a<04a<C01<C4`0
000000<0<c<c00<00000oaTI6OlI6AT00_lI6AT00ol0000000000000000?000000<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`0j000000L06ATI00<0000003<c<`0c<c<00`0c<c<0
0`000000C4a<04a<C00204a<C003o`0000000000IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl0
0`000000VIVI09VIV@0;09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH0
0`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT7
000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0E@000004oaTI
6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4`0C4a<0P00000:06IVIP030000001<C4`0
C4a<0080C4a<00D0000003<c<`0c<c<0<c<c00000004oaTI6@03o`0000000000000000h000000`3o
ool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03/000001`0I6AT00`000000<c<c03<c
<`0303<c<`800000101<C4`00`000000IVIV06IVIP0206IVIP8000001@1oOgl3000000T0VIVI00<0
000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0
000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0601TI6@H000000`3oool00ol00000oooo0?oo
o`0I0?ooo`006P3oool00ol00000oooo0?ooo`1F000000Co6ATI0P00000303<c<`030000001<C4`0
C4a<0080C4a<00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00204a<C0040000000c<c<0
<c<c000000Go6ATI00?o00000000000000003@0000030?ooo`03o`00003oool0oooo0340oooo00?o
00000?ooo`3oool0>`00000801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00D0Ogmo0P00000609VIV@03o`00001o
Ogl0Ogmo00H0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c
<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT6000000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool0EP0000000ol000000000oaTI6@03oaTI6@8000000P0c<c<2
000000<0C4a<0P00000806IVIP030000001<C4`0C4a<0080C4a<00Go000003<c<`0c<c<0<c<c0000
0005oaTI6@;o00003@0000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0?@00
000701TI6@03o`0000000000000000@0<c<c00<00000o`00001<C4`00P1<C4`00ol0000000000000
000306IVIP0300000?l00000000000H0Ogmo00?o00000000000000000`00000907moO`030000001V
IVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0303<c<`03o`00000I
6AT06ATI00H06ATI1@0000030?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0
oooo05T000001OlI6AT010000000<c<c03<c<`0c<c<2000000<0C4a<0P00000606IVIP030000001<
C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`00003o6ATIoaTI6@03oaTI6@03o`000000
0000000000/000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo03l00000200I
6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00<0C4a<0P00000406IVIP030000001o
Ogl0Ogmo0180Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<C0030000000c
<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT5000000<0oooo00?o00000?ooo`3oool06@3o
ool001X0oooo00?o00000?ooo`3oool0FP000005oaTI6@030000000c<c<0<c<c0080<c<c00<00000
04a<C01<C4`00P1<C4`3000000<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`02
03<c<`0300000?lI6AWo6ATI00?o6ATI00?o00000000000000002P0000030?ooo`03o`00003oool0
oooo0340oooo00?o00000?ooo`3oool0@000000801TI6@03o`00000c<c<0<c<c00<0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP<00000401oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@06
01TI6@@000000`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1K0000
00Go6ATI0P00000303<c<`8000001@1<C4`01?l00000000000000000000604a<C0030000000c<c<0
<c<c0080<c<c00<00000oaTI6OlI6AT00olI6AT00ol00000000000000009000000<0oooo00?o0000
0?ooo`3oool0<@3oool00ol00000oooo0?ooo`1000000003o`00000I6AT06ATI00H06ATI0P000004
03<c<`0300000?l00000000000@0C4a<00<0000006IVIP1VIVH0101VIVH00`00003o00000000000;
07moO`8000001`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<00000
01TI6@0I6AT01P0I6AT00ol000000000000000030?ooo`03o`00003oool0oooo01T0oooo000J0?oo
o`03o`00003oool0oooo05`000001_lI6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<
00`0C4a<00<0000003<c<`0c<c<00P0c<c<00`00003o6ATIoaTI6@04oaTI6@03o`00000000000000
00P000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo048000002@0I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00?o00000000001VIVH01P1VIVH20000
00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT01P0I6AT3000000<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool0G@000006oaTI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<
C4`0301<C4`00`000000<c<c03<c<`0203<c<`0300000?lI6AWo6ATI00?o6ATI00?o000000000000
0000200000030?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0@`00000901TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0606IVIPP0
00002P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT01`0I6AT2000000<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0
GP000006oaTI6@030000000c<c<0<c<c0080<c<c00?o000004a<C01<C4`02`1<C4`00`000000<c<c
03<c<`0303<c<`0300000?lI6AWo6ATI00?o6ATI00?o00000000000000001`0000030?ooo`03o`00
003oool0oooo0340oooo00?o00000?ooo`3oool0A000000901TI6@030000000c<c<0<c<c00@0<c<c
00<0000004a<C01<C4`00`1<C4`2000001P0IVIV00?o000004a<C01<C4`0101<C4`00`000000<c<c
03<c<`0403<c<`030000000I6AT06ATI00H06ATI0P0000030?ooo`03o`00003oool0oooo01T0oooo
000J0?ooo`03o`00003oool0oooo060000001OlI6AT2000000<0<c<c0`00000;04a<C0030000000c
<c<0<c<c00<0<c<c00<00000oaTI6OlI6AT00olI6AT00ol00000000000000006000000<0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1400000003o`00000000006ATI00L06ATI00?o
000003<c<`0c<c<0100c<c<2000000D0C4a<1000000D06IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@050000003oool0oooo0?ooool00000
6`3oool001X0oooo00?o00000?ooo`3oool0H@000006oaTI6@030000000c<c<0<c<c00<0<c<c0P00
000904a<C0030000000c<c<0<c<c00@0<c<c00?o0000oaTI6OlI6AT00olI6AT00ol0000000000000
0005000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`17000000P06ATI0P00
000603<c<`8000001`1<C4`200000140IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c
<`0403<c<`030000000I6AT06ATI00L06ATI00D000000?ooo`3oool0ooooo`00000K0?ooo`006P3o
ool00ol00000oooo0?ooo`1R000000Ko6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00704a<C0030000000c<c<0<c<c00<0<c<c00<00000oaTI6OlI6AT01?lI6AT00ol0000000000000
0004000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`18000000T06ATI0P00
000603<c<`030000001<C4`0C4a<00H0C4a<0`00000=06IVIP030000001<C4`0C4a<00H0C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0701TI6@040000003oool0ooooo`0001/0oooo
000J0?ooo`03o`00003oool0oooo0680000000?o000000000?lI6AT01?lI6AT2000000D0<c<c0P00
000704a<C0030000000c<c<0<c<c00@0<c<c00<00000oaTI6OlI6AT01?lI6AT00ol0000000000000
0003000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1800000003o`000000
00006ATI00P06ATI0P00000503<c<`0300000?l00000000000P0C4a<0`00000906IVIP03o`00001<
C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0701TI6@<0oooo00?o
00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0I@000006oaTI6@030000000c<c<0
<c<c00@0<c<c0P00000504a<C0030000000c<c<0<c<c00@0<c<c00<00000oaTI6OlI6AT01?lI6AT0
0ol00000000000000003000000<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1;
000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00804a<C0T000002P1<C4`0
0`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00L06ATI0`3oool00ol00000oooo0?ooo`0I
0?ooo`006P3oool00ol00000oooo0?ooo`1V000000Ko6ATI00<0000003<c<`0c<c<01@0c<c<30000
000304a<C0000000<c<c00L0<c<c00<00000oaTI6OlI6AT01?lI6AT00ol000000000000000020000
00<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1<000000X06ATI00<0000003<c
<`0c<c<01@0c<c<2000001/0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0701TI
6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0I`000006oaTI6@03
o`00000c<c<0<c<c00L0<c<c00<0000003<c<`0c<c<01`0c<c<00`00003o6ATIoaTI6@04oaTI6@03
o`00000000000000008000000`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo04`0
000000?o000001TI6@0I6AT0200I6AT2000000L0<c<c0P00000I04a<C0030000000c<c<0<c<c00H0
<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00
003oool0oooo06T000001OlI6AT200000180<c<c00<00000oaTI6OlI6AT01?lI6AT2o`0000800000
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo04h000002`0I6AT00ol00000<c<c
03<c<`0603<c<`<000005@1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00H06ATI
0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1Z000000Ko6ATI0P00
000@03<c<`0300000?lI6AWo6ATI00Go6ATI00?o00000000000000000`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo04l000002`0I6AT2000000T0<c<c0P00000B04a<C0030000000c
<c<0<c<c00P0<c<c00<0000001TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo06/000001olI6AT00`000000<c<c03<c<`0>03<c<`0300000?lI6AWo
6ATI00Go6ATI00?o00000000003oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0
oooo054000002`0I6AT2000000T0<c<c0P00000?04a<C0030000000c<c<0<c<c00T0<c<c00<00000
01TI6@0I6AT01P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
06`000001olI6AT00`000000<c<c03<c<`0=03<c<`0300000?lI6AWo6ATI00Go6ATI00?o00000000
003oool00P3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo05800000300I6AT00ol0
0000<c<c03<c<`0803<c<`<000002`1<C4`00ol00000<c<c03<c<`0:03<c<`030000000I6AT06ATI
00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1/00000003
o`000000003o6ATI00Go6ATI0P00000>03<c<`0300000?lI6AWo6ATI00Go6ATI00Go00000?ooo`3o
ool0ooooo`00000c0?ooo`03o`00003oool0oooo0580000000?o00000000000000002P0I6AT30000
00X0<c<c3000000<03<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?oo
o`006P3oool00ol00000oooo0?ooo`1_000000Oo6ATI00<0000003<c<`0c<c<02`0c<c<00`00003o
6ATIoaTI6@06oaTI6@04o`00003oool0ooooo`0003<0oooo00?o00000?ooo`3oool0EP00000<01TI
6@800000800c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0
oooo00?o00000?ooo`3oool0L0000007oaTI6@<000002`0c<c<00`00003o6ATIoaTI6@05oaTI6@<0
oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1G000000d06ATI00<0000003<c<`0c
<c<07@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo
00?o00000?ooo`3oool0LP000008oaTI6@03o`00000c<c<0<c<c00P0<c<c00<00000oaTI6OlI6AT0
1OlI6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0E`0000000ol000000000
01TI6@0;01TI6@8000007@0c<c<00`0000006ATI01TI6@0601TI6@<0oooo00?o00000?ooo`3oool0
6@3oool001X0oooo00?o00000?ooo`3oool0L`000008oaTI6@800000200c<c<00`00003o6ATIoaTI
6@05oaTI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1J000000d06ATI0P00
000K03<c<`030000000I6AT06ATI00H06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool0
0ol00000oooo0?ooo`1d000000Wo6ATI0P00000503<c<`0300000?lI6AWo6ATI00Ko6ATI0`3oool0
0ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo05`000003@0I6AT3000001L0<c<c00<00000
01TI6@0I6AT01`0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo
07@0000000?o0000oaTI6OlI6AT02?lI6AT30000000303<c<`00003o6ATI00So6ATI0`3oool00ol0
0000oooo0?ooo`0a0?ooo`03o`00003oool0oooo05d000003`0I6AT2000001@0<c<c00<0000001TI
6@0I6AT0200I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo07H0
00003?lI6AT00`00003o6ATIoaTI6@08oaTI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000
oooo0?ooo`1M00000003o`0000000000000000h06ATI0P00000A03<c<`0300000?l000006ATI00T0
6ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`1g000001Ko6ATI
0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo064000003`0I6AT3000000`0<c<c
0P00000<01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0NP00
000CoaTI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1R000001406ATI3000
000>01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0NP000000
0ol0003o6ATIoaTI6@0@oaTI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1R
00000003o`00000000006ATI02P06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol0
0000oooo0?ooo`1m0000013o6ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo
06D00000:00I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo07h0
00003olI6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0I`00000V01TI6@<0
oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0O`00000>oaTI6@<0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1Y000002@06ATI0`3oool00ol00000oooo
0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`21000000co6ATI0`3oool00ol00000oooo0?oo
o`0a0?ooo`03o`00003oool0oooo06/000008P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J
0?ooo`03o`00003oool0oooo088000002olI6AT30?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0K000000Q01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?oo
o`3oool0P`00000:oaTI6@<0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`1_0000
01h06ATI0`3oool00ol00000oooo0?ooo`0I0?ooo`006P3oool00ol00000oooo0?ooo`24000000Wo
6ATI0`3oool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo0700000000?o000001TI6@0I
6AT06P0I6AT30?ooo`03o`00003oool0oooo01T0oooo000J0?ooo`03o`00003oool0oooo08D00000
2?lI6AT30?ooo`03o`00003oool0oooo0340oooo00?o00000?ooo`3oool0L@0000000ol000006ATI
01TI6@0I01TI6@<0oooo00?o00000?ooo`3oool06@3oool001X0oooo00?o00000?ooo`3oool0T03o
ool00ol00000oooo0?ooo`0a0?ooo`03o`00003oool0oooo0900oooo00?o00000?ooo`3oool06@3o
ool001X0ooooU?l0000c0?oooiCo00006`3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool008D0oooo0_l000350?ooo`;o0000@P3oool00880oooo0ol000000`3o
oooo00000?ooo`310?ooo`?o000000<0ooooo`00003oool0@@3oool00800oooo0_l000020?ooo`80
ZKgX0_l0002o0?ooo`;o00000P3oool20:Vmj0;o0000@@3oool007d0oooo0ol000000`3oool0ZKgX
0:Vmj0030:Vmj003o`00003ooooo00000;/0oooo0ol000000`3oool0ZKgX0:Vmj0030:Vmj003o`00
003ooooo00000400oooo001j0?ooo`?o00000`3oool60:Vmj003o`00003ooooo00000;P0oooo0ol0
00030?ooo`H0ZKgX00?o00000?ooool00000@03oool007P0oooo0_l000040?ooo`P0ZKgX00Co0000
0:Vmj03ooooo0000]@3oool2o`0000<0oooo2@2Y_NP01?l00000ZKgX0?ooool0000o0?ooo`00M@3o
ool3o`000080oooo302Y_NP01Ol00000ZKgX0:Vmj03ooooo00000;40oooo0ol000020?ooo``0ZKgX
00Go00000:Vmj02Y_NP0ooooo`00000n0?ooo`00L`3oool2o`000080oooo3`2Y_NP01Ol00000ZKgX
0:Vmj03ooooo00000:l0oooo0_l000020?ooo`l0ZKgX00Go00000:Vmj02Y_NP0ooooo`00000n0?oo
o`00L03oool3o`0000<0oooo402Y_NP01_l00000ZKgX0:Vmj02Y_NP0ooooo`000:/0oooo0ol00003
0?oooa00ZKgX00Ko00000:Vmj02Y_NP0ZKgX0?ooool0000m0?ooo`00KP3oool2o`0000@0oooo4P2Y
_NP01_l00000ZKgX0:Vmj02Y_NP0ooooo`000:T0oooo0_l000040?oooa80ZKgX00Ko00000:Vmj02Y
_NP0ZKgX0?ooool0000m0?ooo`00J`3oool3o`000080oooo5P2Y_NP00ol00000ZKgX0:Vmj0020:Vm
j0030?ooool00000oooo0:@0oooo0ol000020?oooaH0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00`3o
oooo00000?ooo`0k0?ooo`00J03oool3o`000080oooo6@2Y_NP00ol00000ZKgX0:Vmj0030:Vmj003
0?ooool00000oooo0:00oooo0ol000020?oooaT0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00`3ooooo
00000?ooo`0j0?ooo`00IP3oool2o`0000@0oooo6`2Y_NP00ol00000ZKgX0:Vmj0030:Vmj003o`00
003oool0oooo09d0oooo0_l000040?oooa/0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00`3ooooo0000
0?ooo`0j0?ooo`00H`3oool3o`0000@0oooo7@2Y_NP00ol00000ZKgX0:Vmj0040:Vmj003o`00003o
ool0oooo09T0oooo0ol000040?oooad0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00`3ooooo00000?oo
o`0i0?ooo`00H@3oool2o`0000@0oooo802Y_NP00ol00000ZKgX0:Vmj0040:Vmj0030?ooool00000
oooo09L0oooo0_l000040?ooob00ZKgX00?o00000:Vmj02Y_NP0102Y_NP00`3ooooo00000?ooo`0h
0?ooo`00GP3oool3o`000080oooo902Y_NP00ol00000ZKgX0:Vmj0050:Vmj003o`00003oool0oooo
09<0oooo0ol000020?ooob@0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP00ol00000oooo0?ooo`0g0?oo
o`00G03oool2o`000080oooo9`2Y_NP00ol00000ZKgX0:Vmj0050:Vmj0030?ooool00000oooo0940
oooo0_l000020?ooobL0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP00`3ooooo00000?ooo`0g0?ooo`00
F@3oool3o`0000<0oooo:02Y_NP00ol00000ZKgX0:Vmj0060:Vmj0030?ooool00000oooo08d0oooo
0ol000030?ooobP0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP00`3ooooo00000?ooo`0f0?ooo`00E`3o
ool2o`0000@0oooo:P2Y_NP00ol00000ZKgX0:Vmj0070:Vmj003o`00003oool0oooo08X0oooo0_l0
00040?ooobX0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP00`3ooooo00000?ooo`0f0?ooo`00E03oool3
o`0000<0oooo;@2Y_NP00ol00000ZKgX0:Vmj0070:Vmj0030?ooool00000oooo08L0oooo0ol00003
0?ooobd0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP00`3ooooo00000?ooo`0e0?ooo`00D@3oool3o`00
00<0oooo<02Y_NP00ol00000ZKgX0:Vmj0080:Vmj0030?ooool00000oooo08<0oooo0ol000030?oo
oc00ZKgX00?o00000:Vmj02Y_NP0202Y_NP00`3ooooo00000?ooo`0d0?ooo`00C`3oool2o`0000<0
oooo<`2Y_NP00ol00000ZKgX0:Vmj0080:Vmj0030?ooool00000oooo0840oooo0_l000030?oooc<0
ZKgX00?o00000:Vmj02Y_NP0202Y_NP00`3ooooo00000?ooo`0d0?ooo`00C03oool3o`000080oooo
=P2Y_NP00ol00000ZKgX0:Vmj0090:Vmj0030?ooool00000oooo07d0oooo0ol000020?ooocH0ZKgX
00?o00000:Vmj02Y_NP02@2Y_NP00`3ooooo00000?ooo`0c0?ooo`00BP3oool2o`0000@0oooo=`2Y
_NP00ol00000ZKgX0:Vmj00:0:Vmj003o`00003oool0oooo07X0oooo0_l000040?ooocL0ZKgX00?o
00000:Vmj02Y_NP02P2Y_NP00ol00000oooo0?ooo`0b0?ooo`00A`3oool3o`0000@0oooo>@2Y_NP0
0ol00000ZKgX0:Vmj00;0:Vmj003o`00003oool0oooo07H0oooo0ol000040?ooocT0ZKgX00?o0000
0:Vmj02Y_NP02`2Y_NP00ol00000oooo0?ooo`0a0?ooo`00A@3oool2o`0000@0oooo?02Y_NP00ol0
0000ZKgX0:Vmj00;0:Vmj0030?ooool00000oooo07@0oooo0_l000040?ooo`030:Vmi`2Y_NP0ZKgX
03T0ZKgX00?o00000:Vmj02Y_NP02`2Y_NP00`3ooooo00000?ooo`0a0?ooo`00@P3oool3o`0000<0
oooo?`2Y_NP00ol00000ZKgX0:Vmj00<0:Vmj003o`00003oool0oooo0700oooo0ol000020?ooo`80
Z[cW102Y_NL20:Vmj080ZKgW=P2Y_NP00ol00000ZKgX0:Vmj00<0:Vmj003o`00003oool0oooo0300
oooo000o0?ooo`?o00000`3ooom20:Vmj003o`00002Y_NP0ZKgX00`0ZKgX00<0ooooo`00003oool0
K@3oool3o`000080oooo0P2Z_>H40:Zli`80ZKgW0P2Z_>L40:Vmi`80ZKgX0P2Z_NLa0:Vmj003o`00
002Y_NP0ZKgX00`0ZKgX00<0ooooo`00003oool0<03oool003d0oooo0_l000030?ooodD0ZKgX00?o
00000:Vmj02Y_NP03@2Y_NP00`3ooooo00000?ooo`1Z0?ooo`;o00000`3oool50:ZliP80Z[cW0P2Z
_>H40:Zli`80ZKgW0P2Z_>L40:Zmi`80ZKgX0P2Z_NL/0:Vmj003o`00002Y_NP0ZKgX00d0ZKgX00<0
ooooo`00003oool0;`3oool003X0oooo0ol000020?ooodP0ZKgX00?o00000:Vmj02Y_NP03P2Y_NP0
0ol00000oooo0?ooo`1V0?ooo`?o0000103oool20:^kiP<0Z[cV00<0Zk_U0:ZliP2Z_>H00`2Z_>H2
0:Zli`80Z[cV102Z_>L20:Zmi`80Z[cW102Z_NL20:Vmj080Z[gW9`2Y_NP00ol00000ZKgX0:Vmj00>
0:Vmj003o`00003oool0oooo02h0oooo000h0?ooo`;o0000103ooom90:Vmj003o`00002Y_NP0ZKgX
00h0ZKgX00<0ooooo`00003oool0I03oool2o`0000D0oooo00<0Zk[T0:^kiP2[^nH00P2[^nH0102Z
_>H0Zk_U0:^ki@2[^nD30:ZliP030:^ki@2Z_>H0Z[cV00<0Z[cV0P2Z_>L20:ZliP@0Z[cW0P2Z_NL2
0:Zli`@0Z[gW0P2Y_NP00`2Z_NL0ZKgX0:Vmj00Q0:Vmj003o`00002Y_NP0ZKgX00h0ZKgX00<0oooo
o`00003oool0;P3oool003D0oooo0ol000040?oood/0ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00`3o
oooo00000?ooo`1P0?ooo`?o0000103oool00`2/^>80Zk[T0:^ji0020:^ji080Zk_V0P2[^^@40:^k
i@040:ZliP2[^nD0Zk_U0:^ki@<0Z[cV00<0Zk_U0:ZliP2Z_>H00`2Z_>H20:Zli`80ZkcV102Z_>L2
0:Zmi`030:Zli`2Z_NL0Z[gW0080Z[gW0P2Y_NP20:Zmi`H0ZKgX0P2Y_NLF0:Vmj003o`00002Y_NP0
ZKgX00l0ZKgX00<0ooooo`00003oool0;@3oool003<0oooo0_l000040?ooodh0ZKgX00?o00000:Vm
j02Y_NP0402Y_NP00ol00000oooo0?ooo`1M0?ooo`;o0000103oool20:ffh0<0[;SR0P2[^^@20:bh
hP@0Zk[T0P2[^nD20:bih`@0Zk_U00@0Z[cV0:^ki@2[^nD0Zk_U0`2Z_>H20:^ji@@0ZkcV0P2Z_>L0
0`2[^nH0Z[cW0:Zli`020:Zli`80Z[gW0P2Z_>L40:Zmi`80ZKgX0P2Z_NL40:Vmi`80ZKgX0P2Y_NL3
0:Vmj0030:Vmi`2Y_NP0ZKgX00/0ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00`3ooooo00000?ooo`0]
0?ooo`00<03oool3o`0000<0oooo0P2Y_NM?0:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?o00000?oo
o`3oool0F@3oool3o`0000<0oooo00<0[[?L0:ffh02]]^000`2]]^000`2/^>80[[GO0:jeg`040:bh
hP80Zk[T0P2]]n440:bih`80Zk_U0P2/^N<40:^ki@030:ZliP2[^^D0Zk[U0080Zk[U0P2[_>H00`2[
^^@0Zk_V0:^kiP020:^kiP80Z[cW0P2[^nH40:Zli`80Z[gW0P2Z_>L40:Zmi`80ZKgW0P2Z_NL40:Vm
i`040:Vmj02Y_NL0ZKgW0:Vmi`80ZKgX00<0ZKgW0:Vmj02Y_NP01`2Y_NP00ol00000ZKgX0:Vmj00@
0:Vmj0030?ooool00000oooo02`0oooo000]0?ooo`?o00000`3oool20:Zli`@0ZKgW0P2Y_NP20:Vm
idX0ZKgX00?o00000:Vmj02Y_NP04@2Y_NP00ol00000oooo0?ooo`1F0?ooo`?o00001@3oool30:jc
g0<0[KKP00<0[k;K0:jeg`2^]Ml00P2^]Ml20:bhhP80[[CM102]]n420:bih`80[KOP102/^N<20:^k
i@80[;WR0`2[^^D00`2/^>80Zk[T0:^ji0020:^ji080Zk_V0P2[^^@40:^kiP80Z[cW0P2[^nH40:Zl
i`80Z[gW00<0Z[cW0:Zmi`2Z_NL00`2Z_NL20:Vmi`030:Zmi`2Y_NL0ZKgW0080ZKgW00@0ZKgX0:Vm
i`2Y_NL0ZKgW202Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`00003oool0oooo02/0oooo000[0?oo
o`;o00000`3oool20:^ji0@0Z[cW0P2Y_NL20:Zli`@0ZKgW00<0ZKgX0:Vmi`2Y_NL0A`2Y_NP00ol0
0000ZKgX0:Vmj00A0:Vmj003o`00003oool0oooo05<0oooo0_l000060?ooo`80[k3I102^/m`0102]
]^00[k;K0:nbf`2_/]/20:jeg`030:naf@2^]=d0[[CM00<0[[CM0P2]]n420:jdg0@0[KOP0P2/^N<2
0:ffg`@0[;WR00@0Zk[U0:bhhP2/^>80[;SR0P2[^^@00`2]^>80Zk[T0:^ji0030:^ji080Zk_V0P2/
^^@40:^kiP80Z[cW00<0Zk_V0:Zli`2Z_>L00P2Z_>L20:Zmi`80Z[cW102Z_NL20:Vmi`80Z[gW102Y
_NL80:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?o00000?ooo`3oool0:P3oool002P0oooo0ol00002
0?ooo`030:beg`2[^^@0Zk[T00<0Zk[T0P2Z_>L20:^ji0@0Z[cW0P2Y_NL00`2Z_>L0ZKgW0:Vmi`02
0:Vmi`80ZKgX0P2Y_NM20:Vmj003o`00002Y_NP0ZKgX0140ZKgX00<0ooooo`00003oool0D03oool3
o`0000D0oooo00<0/:gD0:n`f@2_/=T00`2_/=T20:jcg0030;2_e`2_/]/0[k;K0080[k;K00@0[[GO
0:naf@2_/MT0[k7I0`2^]=d00`2`/=P0[[CL0:jdg0030:jdg080[KOP0P2_/m/40:ffg`80[;WR00<0
[[KO0:bhhP2/^>800P2/^>80102[^^@0[KSR0:fhhP2]^>830:^ji0030:fhh@2/^^@0[;[T00<0[;[T
0P2[^nH00`2/^^@0Zk_V0:^kiP020:^kiP80Z[cW0P2[^nD40:Zli`80Z[gW0P2Z_>L40:Zmi`80ZKgW
00<0Z[gW0:Vmj02Y_NP00P2Y_NP01@2Z_NL0ZKgX0:Vmj02Y_NSo000001<0ZKgX00<0ooooo`00003o
ool0:P3oool002H0oooo0_l000040?ooo`<0[;GO0`2[^^@00`2/]=l0Zk[T0:^ji0030:^ji080Z[cW
0P2[^N@30:Zli`80ZKgW0P2Z_>L40:Vmi`80ZKgX0P2Y_NLm0:Vmj003o`00002Y_NP0ZKgX0180ZKgX
00?o00000?ooo`3oool0C@3oool2o`0000L0oooo0`2`[M@30:n`f@030;6[dP2`[mL0/:oG0080/:oG
0P2_/]/20;6]e@@0[k7I00@0[[CM0;2`f02`/=P0/;3H0`2^]=`00`2a[mL0[k?K0:ncf`030:ncf`80
[KKO00<0[k;J0:jfg`2^]]l00P2^]]l20:bhhP80[[KN102]^>80102[^^@0[KSQ0:fhh@2]^>430:bj
i0030:fhh@2/^^@0[;[T0080[;[T0P2[^nH20:bji0@0Zk_U0P2Z_>L20:^ki@@0Z[cW0P2Z_NL00`2Z
_>L0Z[gW0:Zmi`020:Zmi`030:Vmj02Z_NL0Z[gW0080Z[gW0P2Y_NP00ol00000Z[gW0:Vmj00B0:Vm
j003o`00003oool0oooo02T0oooo000S0?ooo`?o0000103oool20:n/e@@0[;GO00@0Zk[T0:bdg`2/
]=l0[;CO0`2[^^@20:bdgP@0ZkWT00<0Z[cW0:^ii02[^N@0102Z_>L20:Vmi`80Z[cV102Y_NL20:Vm
j080ZKgW>02Y_NP00ol00000ZKgX0:Vmj00C0:Vmj003o`00003oool0oooo04T0oooo0ol000070?oo
o`030;6Yd02`[M@0/:gD00<0/:gD00@0[k3I0;6[dP2aZm80/J_B0P2`[mL00`2bZM00/JgE0;6]e@03
0;6]e@80[k7I00<0/JcC0;2`f02`/=P00`2`/=P0102^]=`0/JoG0;6_e`2a[mL30:ncf`030;6^e@2_
/]X0[k;J0080[k;J0P2^]]l20;2bfP@0[[KN0P2]^>820:jegP@0[KSQ00@0[;[T0:fhh@2]^>40[KSQ
0P2/^^@20:fhh@@0[;[T0P2[^nD20:bji0@0Zk_U0P2Z_>L00`2[^nD0Z[cW0:Zli`020:Zli`80Z[gW
0P2Z_>L40:Zmi`030:Vmj02Z_NOo00000080Z[gW0P2Y_NP00`2Z_NL0ZKgX0:Vmj00=0:Vmj0030?oo
ool00000oooo02T0oooo000Q0?ooo`;o0000103oool00`2aX<L0[jcE0:n/e@030:n/e@80[;GO0P2_
Zm@40:bdg`030:^ji02/]=h0[;CN0080[;CN0P2[^N@00`2]]=h0ZkWT0:^ii0020:^ii080Z[cW0P2[
^N@40:ZliP80ZKgW0P2Z_>H40:Vmi`030:Vmj02Y_NL0ZKgW03@0ZKgX00?o00000:Vmj02Y_NP0502Y
_NP00ol00000oooo0?ooo`160?ooo`;o00001`3oool00`2aY/d0/JW@0;6Yd0020;6Yd0<0/:gD00<0
/ZO>0;6[dP2aZm800P2aZm80102`[mL0/ZW@0;:Yd02bZM030;6]e@030;:Wc@2a[=<0/JcC0080/JcC
0`2`/=P00`2bZm40/JoG0;6_e`030;6_e`040:ncf`2a[]D0/JkE0;6^e@80[k;J00<0/ZgD0;2bfP2`
/]X00`2`/]X20:jfgP80/;7I102^]Mh20:fhh@030:neg@2]^>40[KSQ0080[KSQ00<0[;[T0:fhh@2]
^>400P2]^>420:bji080[KSQ102/^^@20:^ki@030:bji02[^nD0Zk_U0080Zk_U0P2Z_>L20:^kiP@0
Z[cW0P2Z_NL20:Zli`040:Zmiol00000Z[gW0:Zli`@0Z[gW0P2Y_NP20:Zmi`/0ZKgX00<0ooooo`00
003oool0:03oool001h0oooo0ol000050?ooo`<0/J370`2_[=D00`2aWlD0[j_D0:n[e0030:n[e080
[;CO0P2_Zm<30:bdgP030:nZd`2]]=h0[KCN0080[KCN0P2[^N@20:fcg@@0ZkWT0P2Z_>H20:^ii0@0
Z[cV0P2Y_NL00`2Z_>H0ZKgW0:Vmi`020:Vmi`80ZKgX0P2Y_NL30:Vmj080ZKgW:P2Y_NP00ol00000
ZKgX0:Vmj00D0:Vmj003o`00003oool0oooo04<0oooo0ol000080?ooo`<0/JK=102aZM00102`[M@0
/ZO>0;:WcP2bYlh30;6[dPD0/ZW@00@0/JgE0;:Wc@2bYld0/ZO=102a[=<0102`/=P0/Z_A0;:[d@2b
Zm430;6_e`030;>Yc`2a[]D0/JkE0080/JkE00@0[k;J0;:]e02b[M@0/ZgD0`2`/]X00`2b[M<0/;7I
0;2af@030;2af@80[[GN00<0/K7H0:neg@2_]Md00P2_]Md20:fhh@80[kGM0`2]^>400`2_]Md0[KSQ
0:fhh@030:fhh@80[;[T00<0[KSQ0:bji02/^^@00P2/^^@20:^ki@80[;[T102[^nH20:Zli`030:^k
iP2Z_>L0Z[cW00<0Z[cW00Co00000:Zli`2Z_>L0Z[cW0P2Z_NL20:Zli`@0Z[gW0P2Y_NP00`2Z_NL0
ZKgX0:Vmj0060:Vmj003o`00003oool0oooo02L0oooo000L0?ooo`;o00001`3oool50;6Pa`040:n/
e@2aWlD0/Io50;6Oa@<0[j_D00<0/Yk40:n[d`2_Zm<00`2_Zm<0102/]=h0[j[C0:nZd`2_Z]<20:fd
gP030:nYdP2]/md0[K?M00<0[K?M0P2[^N@20:fcg@@0ZkWT0P2Z_>H00`2[^N@0Z[cV0:ZliP020:Zl
iP80ZKgW0P2Z_>H40:Vmi`030:Vmj02Y_NL0ZKgW0080ZKgW00<0ZKgX0:Vmi`2Y_NL09P2Y_NP00ol0
0000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo0400oooo0_l000090?ooo`030;6SbP2aY/d0/JK=
00<0/JK=0P2aZM000`2bY<T0/ZO>0;:WcP030;:WcP030;6[dP2cYL/0/jG;00<0/ZW@00<0/j?80;:W
c@2bYld00`2bYld20;6/d`030;>Vb`2bZm40/Z_A00<0/Z_A00@0/JoG0;>Yc`2cZLl0/jW?0P2a[]D0
0`2cZ<h0/ZgD0;:]e0030;:]e0040;2bfP2b[M<0/ZgC0;:]d`<0/;7I00<0/jcB0;6af02a/MP00P2a
/MP20:neg@80/K7H102_]Md0102]^>40[kGM0:neg@2_]Md30:fhh@030:neg@2]^>40[KSQ0080[KSQ
0P2/^^@20:fhh@@0[;[T0P2[^nH00`2/^^@0Zk_V0:^kiP020:^kiP80Z[cW0P2[_>H01Ol00000Z[cW
0:Zli`2Z_>L0Z[gW00@0Z[cW0P2Z_NL00`2Z_>L0Z[gW0:Zmi`020:Zmi`80ZKgX0P2Z_NL40:Vmj003
o`00003oool0oooo02H0oooo000I0?ooo`?o0000203oool20;>E^0<0/J3700<0]9Bf0;6Oa@2aWlD0
0`2aWlD0102_Zm@0/Yk40;:Na02bW/@30:n[d`030;:N``2_Z]<0[j[C0080[j[C00@0[KCN0:nYdP2_
ZM80[jWB0`2]/md00`2`ZM40[K?M0:fcg@030:fcg@80ZkWT00<0[K?M0:^ii02[^N@00P2[^N@20:Zl
iP80ZkWT102Z_>H20:Vmi`80Z[cV0`2Y_NL00`2Z_>H0ZKgW0:Vmi`020:Vmi`80ZKgX0P2Y_NLQ0:Vm
j003o`00002Y_NP0ZKgX01D0ZKgX00<0ooooo`00003oool0?@3oool3o`0000X0oooo0`2aXlX30;6V
c@030;:QaP2bY<T0/ZC90080/ZC90`2bYlh00`2cXLH0/jG;0;>Ub`020;>Ub`040;:Yd02cXlP0/j?8
0;>Sb0<0/ZO=00<0]:750;>Vb`2cY//00P2cY//30;:[d@030;BTb@2cZLl0/jW?0080/jW?00@0/JkE
0;>XcP2cZ<h0/jS>0`2b[M@00`2dYl`0/ZgC0;:]d`030;:]d`040;2af@2c[=80/jcB0;>/dP80/K7H
00<0/jcA0;6af02a/MP00`2a/MP20:neg@80/K7G102_]Md0102]^>40[kGM0:neg@2_]Md20:fhh@03
0:neg@2]^>40[KSQ00<0[KSQ0P2/^^@00`2]^>40[;[T0:bji0020:bji080Zk_V0P2/^^@30:^liP04
o`00002Z_>L0Z[cW0:^liP@0Z[cW00<0ZkcV0:Zli`2Z_>L00P2Z_>L20:Zmi`80Z[cW102Z_NL20:Vm
j0030:Zmi`3ooooo000002L0oooo000F0?ooo`?o00002P3oool40;>E^0040;6Pa`2dU;H0]9Bf0;BD
]P@0/Io51@2bW/@0102_Zm<0/Yk30;:N``2bW/<30:nZd`D0[jWB00@0[K?M0;2Yd@2`ZM40/:WA0`2]
/md00`2`ZM40[K?M0:fcg@020:fcg@80ZkWT0P2]/md40:^ii080Z[cV0P2[^N<40:ZliP040:Vmi`2Z
_>H0Z[cV0:ZliP80ZKgW0P2Z_>H40:Vmi`80ZKgX00<0ZKgW0:Vmj02Y_NP06`2Y_NP00ol00000ZKgX
0:Vmj00F0:Vmj003o`00003oool0oooo03T0oooo0ol0000;0?ooo`030;6Qb02aXlX0/J?:00<0/J?:
00@0/JK=0;:QaP2bXLH0/Z76102bY<T0102bYlh0/j760;>QaP2cXLH20;>Ub`030;BO``2cXlP0/j?8
00<0/j?800@0/ZO=0;BQa@2dXLD0]:75102cY//0102bZm40]:C90;BTb@2dY<T20;>Yc`030;FSa`2c
Z<h0/jS>00<0/jS>00@0/ZgD0;BWc02dYl`0]:O<0`2b[M<00`2dYl/0/jcB0;>/dP020;>/dP040;6a
f02c[=40/jcA0;>/d@<0/K7H00<0/jcA0;6ae`2a/ML00`2a/ML20:neg@030;6ae`2_]Md0[kGM0080
[kGM00@0[KSQ0:neg@2_]Md0[kGM0`2]^>400`2_]Md0[KSQ0:fhh@020:fhh@80[;[T0P2]^>440:bj
i080ZkcV00?o00000:^liP2[_>H00P2[_>H00`2Z_>L0ZkcV0:^liP020:^liP80Z[cW00<0ZkcV0:Zl
i`2Z_>L00`2Z_>L70:Zmi`03o`00003oool0oooo02D0oooo000D0?ooo`;o0000303oool00`2fSJ`0
/iFh0;>E^0020;>E^0@0]9Bf0`2aWlD20;BC]@@0/Yk41@2bW/<00`2_Z]<0/Yg20;:M`P030:nYdP03
0;:L`P2`ZM40/:WA00<0/:WA00@0[K?M0;2Yd@2`ZM40/:WA202]/md20:^ii080[K?M102[^N<20:Zl
iP050:^ih`2Z_>H0Z[cV0:ZliP2[^N<01@2Z_>H20:Vmi`030:ZliP2Y_NL0ZKgW0080ZKgW0P2Y_NP2
0:VmiaP0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00`3ooooo00000?ooo`0g0?ooo`;o00003@3oool3
0;6Qb0<0/J?:00<0/Yk40;:QaP2bXLH00P2bXLH30;:Tb@030;>N``2cXLH0/j760080/j7600@0/jG;
0;BO``2dWl<0]9o3102cXlP40;BQa@<0/jK;00<0]J330;BTb@2dY<T00P2dY<T0102cZLl0]J?70;FS
a`2eXlL30;>XcP030;FRa@2dYl`0]:O<00<0]:O<00@0/ZgC0;BWb`2dYl/0]:O;0P2c[=800`2eY/X0
/jcA0;>/d@030;>/d@040;6af02c[=40/jcA0;>/d@<0/K7G00<0]:c@0;6ae`2a/ML00P2a/ML20:ne
g@80/[7G102_]Md0102]^>40[kGM0:neg@2_]Md20:fhh@80[kKM102]^>420:bji0050:fihP2/^^@0
[;[To`00002/^^@00P2[_>H20:bki0<0ZkcV00<0[;_U0:^liP2[_>H00P2[_>H20:Zli`80ZkcV1`2Z
_NL00`3ooooo00000?ooo`0U0?ooo`004@3oool3o`0000d0oooo0`2fSJ`30;>E^0030;J=Z`2dU;H0
]9Bf0080]9Bf00@0/Io50;BC]@2dTkD0]9>e0`2bW/@20;BB]0@0/Yk3102bWL80102_ZM80/Yc20;:L
`P2bW<830;2Yd@030;:L`@2`ZM40/:WA00<0/:WA00<0[K?M0;2Xd@2`Z=400`2]/md20;2Xd0@0[K?M
0P2[^N<00`2]/md0ZkWS0:^ih`020:^ih`040:ZliP2[^N<0ZkWS0:^ih`<0Z[cV00<0ZkWS0:ZliP2Z
_>H00P2Z_>H20:Vmi`80Z[cV102Y_NL20:Vmj0030:Vmi`2Y_NP0ZKgX0140ZKgX0_l0000I0:Vmj003
0?ooool00000oooo03<0oooo0ol0000=0?ooo`030;2Oa`2aXLP0/J7800<0/J7800@0/J?:0;:Na02b
W/@0/Yk4102bXLH0102bY<T0/ik30;>N``2cW/<20;>QaP030;BL_`2dWl<0]9o30080]9o30`2cXlP2
0;BM`0@0]:7500@0/jK;0;FP``2eX<<0]J330P2dY<T00`2fW/40]J?70;FSa`030;FSa`040;>XcP2e
X/D0]J;50;FRa@<0]:O<00<0]Z;40;BWb`2dYl/00P2dYl/0102c[=80]JK:0;FVbP2eY/X30;>/d@03
0;JVb@2c[=40/jcA00<0/jcA00@0/K7G0;B/d02d[=00]:c@0P2a/ML00`2d[=00/[7G0;:ae`030;:a
e`80[kGM00D0/[7G0:neg@2_]Md0[kGM0;:af0050:nfg@80[KSQ00<0[kKN0:fihP2]^N800P2]^N82
o`000080[KWR102/^n@0102[_>H0[;_U0:bki@2/^nD20:^liP80Zk_U102[_>H20:Zmi`030:ZliP2Z
_NL0Z[gW0080Z[gW00<0ooooo`00003oool0903oool00100oooo0_l0000>0?ooo`@0]Xf/0P2cUKP2
0;J=Z`@0]9Bf1@2dTkD0102bW/@0]9:d0;BB]02dT[@30;:N``030;BB/`2bWL80/Yg20080/Yg21@2b
W<80102`ZM40/Yc10;:L`@2bW<430;2Yd@030;:L`@2`Z=40/:SA0080/:SA00<0[K?M0;2Xd02`Z=00
0P2`Z=020:fcg@030;2Xd02]/md0[K?M0080[K?M0P2[^N<20:fcg@@0ZkWS00@0Z[cV0:^ih`2[^N<0
ZkWS0P2Z_>H20:^ii0@0Z[cV0P2Y_NL00`2Z_>H0ZKgW0:Vmi`020:Vmi`80ZKgX0P2Y_NL;0:Vmj0?o
000000<0ZKgXo`00002Y_NP06@2Y_NP00ol00000oooo0?ooo`0a0?ooo`;o0000303oool00`2_WlL0
/9o70;2Oa`020;2Oa`<0/J7800<0/Ig30;:Na02bW/@00P2bW/@30;:QaP030;>L`02cW/<0/ik30080
/ik300@0/j760;BL_`2dW;l0]9bo102dWl<0102cXlP0]9g00;BM`02dWL030;BQa@030;FK_@2eX<<0
]J330080]J3300@0]:C90;JN`@2fW/40]Yk10`2eXlL00`2fWKl0]J;50;FRa@030;FRa@040;BWc02f
X/@0]Z;40;JRa080]:O;00<0]j730;FVbP2eY/X00`2eY/X0102c[=40]ZK90;JVb@2fY/T30;>/d@03
0;JVb@2d[=00]:c@0080]:c@00@0/K7G0;B/d02d[=00]:c@0`2b/ML00`2d[=00/[7G0;:ae`020;:a
e`040:neg@2b/MP0/[7H0;:af0<0[kKM00<0/[;H0:nfgP2_]]h00P2_]]h3o`0000030:nfg_l00000
[KWR0080[KWR0P2/^n@01@2]^N80[;_U0:bki@2/^nD0[K[S00D0Zk_U0P2[_>H00`2[^nD0Z[cV0:Zl
iP020:ZliP80Z[gW0P2Z_>L00ol00000oooo0?ooo`0S0?ooo`00403oool00ol00000ooooo`00000<
0?ooo`D0]Xf/00@0/iFh0;J=Z`2fSJ/0]Xf[0`2dU;H20;J<Z@@0]9>e1@2dT[@0102bW/<0]9:c0;BB
/`2dT[<20;:M`P80]96b102bW<850;:L`@040;2Yd@2bW<40/Yc10;:L`@80/:SA0P2cW<030;2Xd003
0;>L`02`Z=00/:S@0080/:S@0P2]/md20;2Xd0@0[K?M0P2[^N<0102]/md0ZkWS0:^ih`2[^N<20:fc
g@@0ZkWT0P2Z_>H00`2[^N@0Z[cV0:ZliP020:ZliP80ZKgW0P2Z_>H40:Vmi`80ZKgX00<0ZKgW0:Vm
j02Y_NP00P2Y_NP3o`0000D0ZKgX00?o00000:Vmj02Y_NP0602Y_NP00ol00000oooo0?ooo`0`0?oo
o`03o`00003ooooo000000X0oooo0`2_WlL40;2Oa`040;6Qb02aWL<0/Ig30;6M``@0/Yk400<0/Z76
0;>L`02cW<00102cW/<40;BL_`<0]9o300<0]IZl0;BM`02dWL000`2dWL00102dXLD0]I^m0;FK_@2e
Vkd20;FP``030;JJ^`2fW/40]Yk100<0]Yk100@0]J?70;JM_`2fWKl0]Yfo0`2eX/D00`2gW;d0]Z;4
0;JRa0020;JRa0040;BWb`2gXL<0]j730;NQ``<0]JK:00<0]j720;JVb@2fY/T00`2fY/T0102c[=40
]ZK90;JVb@2fY/T20;B/d0030;JVb02d[=00]:c@00<0]:c@00@0/[7G0;B/d02d[=00]:c@0P2b/ML2
0;B]d@@0/[7H00@0[kKM0;:bf02b/]P0/[;H0ol000000`2b/mT0[kKN0:nfgP020:nfgP03o`00002]
^N80[kOO00@0[KWR00@0[;_U0:fjh`2]^^<0[K[S0`2[^nD00`2]^^<0Zk_U0:^ki@020:^ki@80Z[cV
0P2[_>D40:Zli`03o`00003oool0oooo0280oooo000@0?ooo`04o`00003oool0ooooo`0000/0oooo
00<0^8ZU0;J=[02fSJ`00P2fSJ`50;J=Z`040;BD]P2fS:T0]XbY0;J<Z@@0]9>e1@2dT[@40;BB/`04
0;:M`P2dTK80]96b0;BA/P<0/Yc20P2eTK880;:L`@030;2Xd@2cW<00/ic00080/ic000@0/:S@0;>L
`02cW<00/ic00P2`Z=000`2cW<00/:S@0;2Xd0030;2Xd080[K?M0P2`ZM030:fcg@030:^ih`2]/md0
[K?M0080[K?M0P2[^N@00`2]/md0ZkWT0:^ii0020:^ii080Z[cV0P2[^N@40:ZliP80ZKgW00<0Z[cV
0:Vmi`2Y_NL00P2Y_NL3o`0000030:Vmi`2Y_NP0ZKgX00H0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP0
0ol00000oooo0?ooo`0`0?ooo`04o`00003oool0ooooo`0000P0oooo102_WlL30;2Oa`030;2L``2a
WL<0/Ig30080/Ig30`2bW/@00`2bV[l0/ic00;>L`0020;>L`080/ik30P2cVKd40;BL_`040;BO``2e
V[`0]IZl0;FJ_0<0]9g000<0]YRi0;FK_@2eVkd00P2eVkd0102eX<<0]YZk0;JJ^`2fV[/40;JN`@D0
]Yfo00<0]J;50;NL_@2gW;d0102fX/@50;NQ``040;FVbP2gXL80]j720;NQ`P<0]ZK900<0^:710;JV
b@2fY/T00P2fY/T0102d[=00]ZK80;JVb02fY/P30;B/d0030;NWb@2d[=00]:c@0080]:c@00<0/[7G
0;B]d@2d[M400P2d[M420;:af0030;F]d@2b/]So000000;o000000<0[kKN0;:cf@2b/mT00P2b/mT2
0:nfgP030;:cfP2_]moo00000080[kOO0P2]^N820:ngg`@0[K[S00@0Zk_U0:fjh`2]^^<0[K[S0P2[
^nD00`2/^^@0ZkcU0:^li@030:^li@80Z[cW00<0ZkcVo`00003oool08`3oool00100oooo00Go0000
0?ooo`3oool0ooooo`0000090?ooo`80^8ZU102fSJ`50;J=Z`@0]XbY0`2dTkD20;J;Z0<0]9:d00<0
]h^X0;BB/`2dT[<00P2dT[<50;BA/P040;:L`P2eTK80]I6b0;FA/P<0/Yc100<0]I6a0;:L`@2bW<40
0P2bW<490;>L`0040;2Xd02cW<00/ic00;>L`0<0/:S@00<0/ic00;2Yd02`ZM000`2`ZM000`2]/md0
/:WA0;2Yd@030:fcg@030;2Yd@2]/md0[K?M0080[K?M0P2[^N@20:fcg@@0ZkWT0P2Z_>H00`2[^N@0
Z[cV0:ZliP020:ZliP?o000000<0Z[cW0:Vmi`2Y_NL00P2Y_NL20:Vmj0040:Vmi`2Y_NP0ZKgX0:Vm
j080ZKgW00?o00000:Vmj02Y_NP05`2Y_NP00ol00000oooo0?ooo`0_0?ooo`05o`00003oool0oooo
0?ooool000001P3oool20:fOb@@0[io700@0/9o70;2L``2`W<<0/9c3102aWL<00`2bW/@0/YZo0;:J
_`040;>L`0040;>N``2cVKd0/iVm0;>I_@<0]9bo00<0]9Ni0;FJ_02eV[`00`2eV[`00`2dWL00]YRi
0;JH^@040;FK_@@0]YZk0`2fW/420;NI^@@0]Yfo102gW;d20;JRa080^9bl102gXL<50;NQ`P040;JV
b@2hXL40^:710;RQ`@80]ZK900<0^:710;JVb02fY/P00`2fY/P0102d[=00]jO90;NWb@2gYlT20;B/
d080]jO90`2d[M400`2gZ<T0]JgAo`000002o`000080/[;H0P2e[]830;:cf@030;B_d`2b/mX0/[?J
0080/[?J00@0[kOOo`00002a]=/0/KCK102_]ml20:fjh`050:nhh02]^^<0[K[S0:fjh`2^^>40102/
^^@20:^li@80[;_T102[_>H00ol00000oooo0?ooo`0Q0?ooo`003`3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00D0oooo0`2hRZD30;J=[080^HVS102fSJ/50;J<Z@040;BC]@2fRjP0
]X^X0;J;Z080]9:d0`2gRjP30;BB/`030;N;Y`2dTK80]96b0080]96b1@2eTK80102bW<40]I6a0;FA
/@2eTK420;:L`@80]I6a102cW<000`2eTK40/ic00;>L`0060;>L`0040;2Xd02cW<00/ic00;>L`0<0
/:W@00<0/ig10;2Yd@2`ZM400P2`ZM40102]/md0/:WA0;2Yd@2`ZM480:fcg@80ZkWT00<0[KCN0:^i
i02[^N@00P2[^N@3o`0000030:^ji02Z_>L0Z[cW0080Z[cW0P2Y_NL00`2Z_>L0ZKgW0:Vmi`020:Vm
i`050:Vmj02Y_NL0ZKgW0:Vmiol000006@2Y_NP00`3ooooo00000?ooo`0^0?ooo`03o`00003oool0
oooo00<0oooo00Go00000?ooo`3oool0oooo0:^Pc0030:fOb@<0[io700<0[Yc50;2L``2`W<<00P2`
W<<30;6M``030;6I_`2bV[l0/YZo0080/YZo0P2cW<000`2cV;/0/iVm0;>I_@030;>I_@040;BL_`2d
UkT0]9Ni0;BG^@@0]IZl102fV;T20;FK_@80]YNg102fV[/0102fW/40]iVi0;NI^@2gVKT30;JM_`03
0;RH]`2gW;d0]ibm0080]ibm00@0]Z;40;RL_02hW;`0^9bl0`2gXL<20;RL^`@0]j72102hXL40102f
Y/T0^:710;RQ`@2hXL430;JVb0030;VQ`@2gYlT0]jO90080]jO900<0]:c@0;NWb@2gYlT00P2gYlT0
102d[M7o0000o`000?l000020;F]d@030;RYb`2e[]80]JkB00<0]JkB00@0/[?I0;B_d`2d[m<0]:oC
0P2b/mX00`2d/=@0/KCKo`0000030;6df`80[kOO00<0/KGL0:nhh02_^>000P2_^>00102]^^<0[[SQ
0:jhh@2^^>420:bji080[[WR102/^n@20:^liP030:bki@3ooooo00000280oooo000?0?ooo`03o`00
003oool0oooo00@0oooo00?o00000?ooo`3oool0103oool40;R:Y@040;J=[02iRJ<0^HVS0;V9X`<0
]Xf[00<0^HVR0;J<Z@2fS:T00`2fS:T40;J;Z0030;BB]02gRjP0]h^X0080]h^X0P2dT[<20;N;Y`@0
]96b00<0]h^V0;FA/P2eTK800P2eTK840;FA/@040;:L`@2eTK40]I6a0;FA/@<0/ic00P2eTK430;>L
`0030;JA/@2cW<00/ic000L0/ic000@0/:W@0;>M`@2cWL40/ig10P2`ZM400`2cWL40/:WA0;2Yd@03
0;2Yd@030:fcg@2`Z]80/:[B00<0[K?M00<0/:_B0:fdgP2]]=h00P2]]=h3o`0000030:fdgP2[^^@0
Zk[T0080Zk[T0P2Z_>L00`2[^^@0Z[cW0:Zli`020:Zli`80ZKgW0`2Z_>L20:Vmi`030:Zliol00000
ZKgX01P0ZKgX00?o00000?ooo`3oool0;@3oool00ol00000oooo0?ooo`040?ooo`030:NRd@2[X<`0
Zj3<0080Zj3<0`2]WlT0102_WlL0[Yc50:jLa@2^W<D40;2L``040;6M``2aVKl0/IVo0;6I_`<0/YZo
00@0/ic00;>H^`2cV;/0/iRk102cVKd40;BG^@<0]IZl00<0]IJg0;JH^@2fV;T00P2fV;T0102eVkd0
]YNg0;JG]`2fUkL40;JJ^`D0]iVi00@0]Yfo0;RH]`2hV;L0^9Rg0P2gW;d00`2hV;H0^9bl0;RL_003
0;RL_0040;NQ``2hW;/0^9bk0;RL^`<0]j7200<0^I^j0;RQ`@2hXL401`2hXL40102fY/P0^J710;VQ
`@2iXL420;NWb@040;VR`@2gYlT0]jO90;NWb@?o00000`2gZ<T0102e[M40^:W;0;RYb`2hZL/30;F^
dP030;RZc02d[m<0]:oC0080]:oC00P0/[?J0;B`e02d/=@0];3D0;6dfol00000/KCK0;BaeP@0/KGL
0P2_^>001@2a]]d0[[SQ0:jhh@2^^>40/;ON00D0[[WR0P2/^n@00`2^^^80[;_U0:bki@020:bki@03
o`00003oool0oooo0200oooo000?0?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0
0P3oool50;R:Y@040;J=[02iRJ<0^HVS0;V9X`<0]Xf[0P2iRJ840;J<Z@@0]X^X1@2gRjP0102dT[<0
]h^W0;N;Y`2gRjL30;BA/P80]h^V102eTK890;FA/@030;>L`02eTK40]I6a0080]I6a00<0/ic00;JA
/@2fTK400`2cW<020;JA/@@0/ic0102cWL40102`ZM40/ig10;>M`@2cWL430;2Yd@030;>N`P2`Z]80
/:[B0080/:[B00@0[K?M0;2[dP2`Zm80/:_B0ol000000`2`Zm<0[KCN0:fdgP020:fdgP80Zk[T00<0
[KGN0:^ji02[^^@00P2[^^@20:Zli`80Zk[T0`2Z_>L00`2[^^D0Z[cW0:Zli`020:Zli`03o`00002Y
_NP0Z[cW01H0ZKgX00<0ooooo`00003oool0;@3oool01Ol00000oooo0?ooo`3oool0XZGG00@0Yj;A
0`2[X<`20:fOb@030:^Mb02^W<D0[Yc50080[Yc50`2`W<<00`2_VL40/IVo0;6I_`020;6I_`<0/YZo
102cV;/30;>I_@80]9Jh102dUkT0102eV[`0]IJg0;FF]`2eU[L30;JH^@@0]YNg0`2fV[/20;NF]@@0
]iVi102hV;L0102gW;d0^9Rf0;RH]P2hV;H40;RL_0D0^9bk00@0]j720;VK^P2iVkX0^I^j0P2hXL42
0;ZL^@@0^:71102iXL400`2gYlT0^J;10;VR`@03o`0000030;NWb@2jXl80]jS900<0]jS91@2hZL/0
102e[]80^:[<0;RZc02hZ/`20;B_d`80^:_=102d/=@0102a]=_o00000;BaeP2d/MH20;6eg0030;Bb
e`2a]]d0/KKM0080/KKM00@0[[SQ0;2ggP2`]mh0/;ON0`2^^N800`2`^=l0[[[R0:jjhP020:jjhP80
[;_U00<0[K[S0?ooool000008@3oool000l0oooo00?o00000?ooo`3oool01P3oool01?l00000oooo
0?ooo`3oool50;R:Y@D0^HVS00@0]Xf[0;V9XP2iRJ80^HVR0`2fS:T00`2iR:80]X^X0;J;Z0020;J;
Z0D0]h^X1@2gRjL0102dTK80]h^V0;N;YP2gRjH30;FA/P80]hZV0`2eTK400`2hRjH0]I6a0;FA/@07
0;FA/@@0]Y6a00@0/ic00;JA/@2fTK40]Y6a0`2cW<000`2fT[40/ig10;>M`@070;>M`@040;2Yd@2c
W/80/ik20;>N`P80/:[B0P2cW/<3o`0000030:fdgP2`Zm<0/:_C0080/:_C0P2]]=h00`2`[=@0[KGN
0:fegP020:fegP80Zk[T0P2]]Ml40:^ji0040:Zli`2[^^D0Zk[U0:^ji@80Z[cW00<0Zk[U0:Zliol0
00000P2Z_>L20:Vmj080Z[cW4P2Y_NP00`3ooooo00000?ooo`0/0?ooo`03o`00002LZ=h0XZGG00<0
XZGG102WX]400`2[X<`0Yio=0:^Mb0030:^Mb0@0[Yc500@0/9c30:nI`@2_VL40[iW1102aVKl00`2b
V[l0/YNk0;:G^`040;>H^`040;>I_@2dU[P0]9Jh0;BF^0@0]9Ni102eU[L20;JH^@80]YBd102fUkL0
102fV[/0]iJe0;NF]@2gU[D30;NI^@030;RE/`2hV;L0^9Rg0080^9Rg102hV;H30;RL_080^INe102h
W;/40;VK^P040;RQ`@2jW;T0^Ybi0;ZL^@<0^:7100<0^Ybi0;VQ`@2iXL400P2iXL43o`000080^J;1
00@0]jO90;ZS`P2jXl80^Z?20P2gZ<T20;ZT`P<0^:W;00<0^ZG40;RZc02hZ/`00P2hZ/`00`2d[m<0
^:_=0;R[c@020;R[c@80];3D00D0]jg>0;BaeP2d/MKo00000;N^d0040;Bbe`80/KKM0P2c/mT40;2g
gP040:jihP2`^=l0/;SO0;2hg`80[[[R00<0[kSP0:fjh`2]^^<00P2]^^<00`3ooooo00000?ooo`0O
0?ooo`003`3oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0^hZQ00D0^8ZU1@2iRJ<0102f
SJ/0^HVR0;V9XP2iRJ820;J<Z@<0^HRR0P2fRjP20;Z8X@@0]h^X1@2gRjL50;N;YP040;FA/P2gRZH0
]hZV0;N:YP80]I6a0P2hRjH90;FA/@T0]Y6a00@0/ic00;JB/@2fT[40]Y:a0P2cWL420;JC/P@0/ig1
102cW/801P2`Z]80/ik3o`000?l00000/ik30;2[dP80]9o40`2`Zm<00`2dXLD0/:cD0;2/e0020;2/
e080[KGN0P2`[M@40:feg`80Zk[T0P2]]]l20:^ji@030:ffh02[^^D0Zk[U0080Zk[U00Co00000:Zl
i`2[^^D0Zk[U102Z_>L20:Vmj0030:Zli`2Y_NP0ZKgX00d0ZKgX00?o00000?ooo`3oool0:`3oool0
0ol00000W:SN09bXgP040::Ue`80Yj;A00@0XZ7D0:NOc@2WWld0Yio=102[WLP20:jLa@030:bJa02_
VL40[iW10080[iW10`2aVKl0102`Ukd0/YNk0;:G^`2bUk/30;>H^`030;>D^02dU[P0]9Jh0080]9Jh
0`2dUkT00`2eU;D0]IJg0;FF]`020;FF]`040;JH^@2fU;@0]YBd0;JD]0@0]YNg1@2gU[D0102gVKT0
^9Fc0;RE/`2hUK<30;RH]`030;VD/@2hV;H0^9Rf0080^9Rf00@0^9bl0;VG]@2iUkD0^INe0`2hW;/0
0`2jUk@0^I^j0;VK^P020;VK^PD0^Ybi00D0^:710;ZL^@2jW;T0^Ybi0;VQ`@02o`0000030;^M^P2i
X/40^J;10080^J;1102jXl800`2gZ<T0^ZC20;ZT`P020;ZT`P040;RYb`2jYL@0^ZG40;ZUa080^:[<
00<0^ZK50;R[c@2hZld00`2hZld40;N]cP040;Bae_l00000]jk@0;N^d080];;G00<0]k3B0;>cf@2c
/mT00`2c/mT20;2ggP050;>dfP2`^=l0/;SO0;2hg`2b]]/0102_^>020:fjh`80[kWQ00?o00000?oo
o`3oool07P3oool000l0oooo00?o00000?ooo`3oool0203oool00ol00000^hZQ0;^:X@030;R:Y@03
0;b:X02iRJ<0^HVS00<0^HVS102iRJ800`2fS:T0^HRR0;V8XP020;V8XP040;J;Z02jR:40^XRQ0;Z8
X@<0]h^X0P2jR:040;N;Y`D0]h^V102gRZH0102eTK40^8^V0;R;YP2hRjH30;FA/@80^8^V0`2eTK40
0`2hRjH0]Y6a0;JA/@020;JA/@030;V;YP2fTK40]Y6a0080]Y6a102fT[40102cWL40]Y>b0;JC/P2f
Tk830;>M`@040;JC/`2cW/80/ik20;>N`P?o00000`2cW/<40;BOa0040;2[d`2dXLD0]:750;BQa@80
/:cD00<0]:;60;2]e02`[M@00`2`[M@20:feg`050;2]e@2]]]l0[KKO0:ffg`2`[]H0102]]^020:^j
i@80[;OP00Co00000:^ji@2[^^D0Zk[U0P2Z_>L00`2[^nD0Z[cW0:Zli`020:Zli`80ZKgX00<0Z[cW
0:Vmj02Y_NP02P2Y_NP00ol00000oooo0?ooo`0Z0?ooo`04o`00003oool0W:SN09bXgP80XZGG00<0
VjGL0::Qe02RXM@00P2RXM@20:NOc@<0Zig800<0Z9c:0:bJa02/V/@00P2/V/@40:nI`@030;6I_`2`
Ukd0/9Nm00@0/YNk00@0/iRk0;>D^02cU;P0/iBh102dU[P0102dUkT0]IBe0;FD]@2eU;D30;FF]`@0
]YBd0`2fUkL20;NC/P@0]iJe102hUK<20;RH]`80^IBa102hV;H50;VG]@040;RL^`2jUk@0^YNd0;ZG
]080^I^j0P2kV;<60;ZL^@?o00000`2kWKX30;VR`@80^ijj0P2jXl800`2lWk/0^ZC20;ZT`P030;ZT
`P@0^ZG400@0^:[<0;ZVa@2jY/D0^ZK50`2hZld20;ZXa`80]jg>00H0^ZW80;N^d02g[]3o00000;N^
d02d/]L30;N`dP<0/k?I00<0][7D0;>dfP2c]=X00P2c]=X0102`^=l0/[KK0;:ff`2b]]/20:nhh080
/KOM102_^N400ol00000oooo0?ooo`0M0?ooo`003P3oool00ol00000oooo0?ooo`090?ooo`<0^hZQ
0P2hRZD20;b:X0D0^HVS102iRJ850;V8XP040;J;Z02jR:40^XRQ0;Z8X@<0]h^X0P2jR:030;N;Y`03
0;Z8X02gRjH0]h^V00<0]h^V102gRZH50;R;YP040;FA/@2hRjH0^8^V0;R;YP80]I6a0`2hRjH20;JA
/@80^H^V102fTK440;JB/@D0]Y>b00<0/ig10;JC/`2fTk<00ol000020;ND/`<0/ik300<0]iFd0;BO
a02dWl@00P2dWl@40;BQa@040;2/e02dX/H0]:;60;BRaP<0/:gD00<0]:?70;2]e@2`[MD00P2`[MD0
102]]]l0/:kF0;2^eP2`[]H20:ffh080/:oG102/]n000ol00000Zk[U0:bgh@040:^ki@80Z[cW00<0
Zk_U0:Zli`2Z_>L00P2Z_>L20:Vmj080Z[cW202Y_NP00ol00000oooo0?ooo`0X0?ooo`03o`00003o
ool0oooo0080TJSU102KYM`30::Qe0<0Yio=00@0Zig80:RLbP2XW<X0Z9c:0`2/V/@30:nI`@030:fG
`@2`Ukd0/9Nm0080/9Nm0`2bUk/40;>D^0@0]9Jh102eU;D20;FF]`80]Y:b102fU;@0102fUkL0]i>b
0;NC/P2gTk840;NF]@@0^9Fc00@0^9Rg0;VD/@2iU;40^IBa0`2hV;H20;ZD/0@0^INe102jUk@0102i
VkX0^iRc0;^H/`2kV;<30;ZL^@?o00000P2jW;T50;^M^P050;VR`@2kW[X0^ijj0;^N^P2jXl800`2l
Wk/30;ZT`P030;bP_02jYL@0^ZG40080^ZG41@2jY/D01@2hZld0^ZS70;ZXa`2jZ<L0]jg>00<0^ZW8
0P2g[]000ol00000^Z_;0;N`dP030;N`dP040;>cf@2f/M@0][7D0;Jae080/kCJ00D0][;F0;:ff`2b
]]/0/[KK0;Fdf0050;6gg@80[kWQ00<0/KSN0?ooool000007P3oool000h0oooo00?o00000?ooo`3o
ool02@3oool30;^:X@80^8ZU0`2lRZ030;V9X`030;b9W`2iRJ80^HVR0080^HVR1@2iR:850;Z8X@04
0;N;Z02jR:00^XRP0;Z8X0<0]h^W0P2jR:030;N;YP030;^8W`2gRZH0]hZV0080]hZV2@2hRjH00`2e
TK40^8^V0;R;YP020;R;YP040;JA/@2iRjH0^H^V0;V;YP<0]Y6a0P2iS:H30;JB/@030;V=Y`2fTk80
]Y>b0080]Y>b0ol000000`2fTk<0/ik20;ND/`030;ND/`040;>N``2gUK@0]iFd0;NE]080]9o40P2g
U[H30;BQa@D0]:;600@0/:gD0;BSa`2dXlL0]:?70P2`[MD20;BTb0<0/:kF00<0[KKP0;2_e`2`[mL0
0P2`[mL20:bgh0030:n`f02/]n7o00000080[;OQ0P2[^nD00`2/^>40Zk_U0:^ki@020:^ki@80Z[cW
0P2Z^nH40:Zli`80ZKgX0P2Z_NL20:Vmj0030:Zmiol00000oooo02T0oooo00Co00000?ooo`3oool0
oooo0P2AZ>D409^Ug0<0XZ7D00<0Yio=0::Nd@2XW<X00`2XW<X40:bJa0030:nI`@2]Ul40[IO100@0
/9Nm0P2bUk/20;6D^P<0/iBh0`2dU[P00`2dTkD0]IBe0;FD]@020;FD]@040;FF]`2fT[80]Y:b0;JB
/P@0]YBd102gTk830;NF]@80^9:`0`2hUK<50;VD/@040;RH]P2jU;00^YB`0;ZD/0@0^INe102jUk@4
0;^H/`?o00000P2lV;<20;ZL^@80_9Vc102kWKX40;^N^PD0_9nk00@0^ZC20;bP_02lX;`0_:2l0P2j
YL@20;fR_@<0^ZK500<0_J>o0;ZXa`2jZ<L00P2jZ<L40;ZYb0050;N^d02jZl/0^Z_;o`00002jZl/0
0P2g/=801@2j[Ld0][7D0;Jae02f/M@0^Jo?00@0][;F00@0/[KK0;Fdf02e]=P0]KCH0`2a]md00`2d
]MX0/KSN0;6hgP020;6hgP03o`00003oool0oooo01`0oooo000>0?ooo`03o`00003oool0oooo00P0
oooo102kRZ400`2hRZD0_8ZP0;b:X0020;b:X080^HVS0P2lRIl30;V9XP80_HVN102iR:850;Z8X@03
0;N;Z02jR:00^XRP0080^XRP00@0]h^W0;Z8X02jR:00^XRP0P2gRjH30;^8W`80]hZV0P2kR9l=0;R;
YP030;JA/@2iRjH0^H^V0080^H^V00@0]Y6a0;V<YP2iS:H0^HbV0P2fT[420;V=Y`040;JC/_l0003o
0000o`0000@0]Y>c1@2gU;<40;NE]0040;BOa02gU[H0]iJf0;NF]P<0]:7500D0]iNg0;BRaP2dX/H0
]:;60;NI^0040;BSa`030;2]e@2dY<P0]:C80080]:C800<0/:kF0;>UbP2cYLX00`2`[mL00`2cYl`0
[k3H0:n`f0020:n`f003o`00002/]n40[k7J00@0[;SQ0P2[^nD20:bhhP@0Z[_V0P2Z_>L20:ZkiP80
Z[gW00<0Z[_V0:Zmi`2Z_NL00P2Z_NL00ol00000oooo0?ooo`0W0?ooo`03o`00003oool0oooo0080
oooo0P2AZ>D209^Ug00408jUi02IX]X0VJ;J09VRfP<0XYkA102XW<X20:bJa0030:VIaP2]Ul40[IO1
0080[IO10`2`Ukd0102bUk/0/IBj0;6D^P2aU;X40;>D^0040;BF^02dTkD0]9>e0;BC]@<0]IBe102f
T[830;JD]080]i6`102gTk80102gU[D0^9:`0;RB/02hT[020;RE/`80^I:^102iU;440;ZD/0<0^INe
0P2kU:l30;ZG]0050;bD[ol0003o0000o`00002kV;<0102lV;<0102jW;T0_9Vc0;bI/`2lVK<30;^M
^P80_IZc0`2kW[X00`2nVk@0_9nk0;bO^`020;bO^`@0_:2l00<0^ZG40;fR_@2mX[d00P2mX[d0102j
Y/D0_J>o0;fS_`2mXkl20;ZXa`80_JG10`2jZLP30;Z[b`03o`00002jZl/0^Zg=00<0^Zg=00@0][7D
0;V_c`2i[ll0^Jo?0P2f/]H20;RadP@0]KCH00@0/KOM0;BefP2d]MX0];GJ0P2a^=h00`2c]m`0oooo
o`00000M0?ooo`003P3oool00ol00000oooo0?ooo`080?ooo`@0^hZQ1@2lRZ020;V9X`<0_8VO0P2i
RJ820;f9WP<0^HRR00<0_HVN0;Z8X@2jR:400`2jR:450;Z8X0040;N;Y`2jR:00^XRP0;Z8X080]h^V
0`2kR9l20;N:YP80^hRO0`2hRjH00`2kRIl0^8^V0;R;YP070;R;YPD0^H^V00H0]Y6a0;V<YP2iS:H0
^HbV0;JB/@2iSJL3o`000080]Y>b0P2jSJL30;JC/`030;Z>Z02gU;<0]iBc0080]iBc102gUK@50;NF
]P050;BQa@2gUkL0]iNg0;NG]`2dX/H00`2gVKP20;BSa`030;NJ^P2dY<P0]:C800<0]:C8102cYLX0
102`[mL0/jO<0;>Wc02cYl`20:n`f0030;>Xc@2_/M[o00000080[k7J0P2/^>420:nbf`@0[;SR0P2Z
^nH20:bhhP80Z[_V00<0[;WS0:ZkiP2Z^nH00P2Z^nH20:Zmi`030:ZliP3ooooo000002P0oooo00?o
00000?ooo`3oool00`3oool2086Xk@<0SZGT0`2IX]X30::Nd@80Z9c:00@0XYc>0:VIaP2YVLH0ZIW6
102]Ul420;2G_@030:jE_@2aU;X0/IBj0080/IBj0`2cU;P00`2bTkH0]9>e0;BC]@020;BC]@80]IBe
0P2eTK840;JB/P040;JD]02gTK00]i6`0;NA/0@0]i>b102hT[00102hUK<0^I:^0;VB[P2iTZh40;VD
/@030;ZB[@2jU;00^YB`0080^YB`00D0^INe0;^D[`2kU:l0^iB_0;ZG]003o`0000@0^iRc00@0_9F^
0;bH/`2lV;<0_9Rc1@2lVK<0102kWKX0_IZc0;fJ/`2mV[<20;^N^P80_Y^d0`2lWk/00`2nW;D0_:2l
0;bP_0020;bP_0D0_J:m102mXkl00`2jZ<L0_JG10;fU`@020;fU`@030;ZYb02mYl<0_JO300<0^Z_;
00Go00000;fYa@2j[Ld0^Zg=0;f[b0040;V_c`030;JbeP2h/M80^;7B0080^;7B0P2e]=P01@2h/]@0
];GJ0;BefP2d]MX0]kCG00@0/kOL00<0ooooo`00003oool06`3oool000h0oooo00?o00000?ooo`3o
ool01`3oool00`2oSZ80^hZQ0;^:X@020;^:X@D0_8ZP00<0^HVS0;b9W`2lRIl00P2lRIl0102iRJ80
_HVN0;f9WP2mRIh30;V8XP030;f9WP2jR:40^XRQ00<0^XRQ2@2jR:000`2gRjH0^hRO0;^8W`020;^8
W`040;N:YP2kR9l0^hRO0;^8W`<0^8^V0P2kRIl20;R;YP80_8VO102hRjH50;V;YP<0^HbV0ol00003
0;V=Y`040;JC/P2jSJL0^XfW0;Z=Y`80]Y>c0P2jSZP30;ND/`80^XnY0`2gUK@00`2jT:X0]iJf0;NF
]P020;NF]P@0]iNg102gVKP0102dXlL0]iZj0;NJ^P2gV[X30;BTb080]ibl0P2cYLX00`2gWKh0/jO<
0;>Wc0020;>Wc0060:n`f02cZ<d0/jS=0;>Xc@2_/M[o00000P2cZ/l40:nbf`80[;SR00D0[k?L0:bh
hP2/^>80[;SR0:jdg@040:bih`80Z[_V00<0[;WS0:ZliP2Z_>H00P2Z_>H00ol00000oooo0?ooo`0V
0?ooo`03o`00003oool0oooo00@0oooo0P21Z>d308jUi080VJ;J0P2RW]400`2HWmT0XYc>0::LcP02
0::LcP<0ZIW60P2]Ul400`2ZUl<0[YFm0:jE_@020:jE_@@0/IBj00<0/iBh0;:C]P2bTkH0102dTkD0
102eU;D0]I6b0;FA/P2eTK840;JB/P@0]i6`0`2gTk800`2hTJh0^9:`0;RB/0020;RB/0@0^I:^0`2i
U;420;ZB[@@0^YB`0P2kU:l3o`0000<0_9B_0`2kV;<20;bE[P<0_9Rc00<0_IJ^0;bI/`2lVK<00P2l
VK<50;fJ/`050;^N^P2nVk@0_Y^d0;jK]02lWk/00`2nW;D20;bP_080_ijf0`2mX[d00`2oWkP0_J>o
0;fS_`020;fS_`D0_JG1102mYl<01@2jZl/0_JW50;fYaOl00000^Zg=00<0_J_80`2i[ll01@2l[L/0
^;7B0;RadP2h/M80^k3>00@0^;;D00@0];GJ0;Nde`2g]=L0]kCG0P2c]m`00`2f]]T0ooooo`00000L
0?ooo`003P3oool00ol00000oooo0?ooo`060?ooo`80_hjR0`2kRZ420<2>X@@0_8ZP1@2lRIl0102i
RJ80_HVN0;f9WP2mRIh30;V8XP80_HVN0`2jR:400`2nRId0^XRP0;Z8X0070;Z8X0D0^hRO00<0]hZV
0;^8W`2kR9l00P2kR9l0102hRjH0^hVO0;^9W`2kRIl20;R;YP80_8VO0`2hRjH20;b9W`@0^H^V0ol0
00000`2iS:H0^HfW0;V=Y`030;V=Y`@0^XfW00<0]Y>c0;Z>Z02jSZP00P2jSZP0102gU;<0^XnY0;Z?
Z@2jSjT20;NE]080^Y2Z102gU[H40;NG]`@0]iVh1@2gV[X01@2dY<P0]ibl0;NL_02gW;`0/jG:00<0
]ifn0P2cYl`00`2gWl00/jS=0;>Xc@020;>Xc@030:naf_l00000/j[?0080/j[?0P2_/]/00`2cZm40
[k?L0:ncg0020:ncg0040:bhhP2^]=d0[[CM0:jdg@80[;WS00<0[[GN0:bih`2/^N<00P2/^N<20:Zl
iP030:^ji03ooooo000002L0oooo00?o00000?ooo`3oool01@3oool206FTm080N:C^0P2:X^@409RO
f@<0XYc>0`2YVLH0102]Ul40ZYO30:ZG``2ZUl<30:jE_@<0/IBj00<0[i>j0;:C]P2bTkH00P2bTkH3
0;BC]@@0]I6b0`2fT[820;J@/0@0]i6`00@0]i>b0;RA[P2hTJh0^96^0`2hT[000`2iT:`0^I:^0;VB
[P020;VB[P040;VD/@2jTZd0^Y:]0;ZB[@<0^YB`0ol000020;^D[`D0_9B_00@0^iRc0;bE[P2lUJh0
_9F^0P2lV;<20;fF[P@0_9Vc00<0_YN^0;fJ/`2mV[<00P2mV[<40;jK]0@0_Ybe00<0_:2l0;nN]P2o
W[H00P2oW[H0102mX[d0_inh0;nO^02oWkP20;fS_`80`:6j0`2mYL400`30Xk`0_JO30;fW``020;fW
``<0_JW500?o00000;f[b02mZlP00`2mZlP01@2i[ll0_:g;0;b]b`2l[L/0^;7B00<0^k3>0P2h/]@0
1@2j/]40]kCG0;Nde`2g]=L0^K?D00@0][KI00<0ooooo`00003oool06P3oool000d0oooo00?o0000
0?ooo`3oool01`3oool30;n>XP80^hZQ0P30SZ440;b:X0D0_8VO00@0^HVR0;f9WP2mRIh0_HVN0P2i
R:830;f9WP<0^XRQ00<0_XVM0;Z8X02jR:000P2jR:000`2nRId0^XRP0;Z8X0020;Z8X0X0^hRO00D0
^8^V0;^9W`2kRIl0^hVO0;R;YP030;b9W`<0^8^V0P2lRIl0102iRjKo0000o`000?l000030;V<YP80
_H^P102iSJL40;Z=Y`D0^XjX102jSjT0102gUK@0^Y2Z0;Z@ZP2jT:X30;NF]P80^i6[0P2gUkL20;^B
[@<0]iVh00<0^iB^0;NJ^P2gV[X00P2gV[X40;NL_0@0]ifn00@0/jO<0;NO`02gWl00]io00`2cZ<d0
1@2gXL80/j[?o`00002cZ/l0]j?400@0/j_A0P2_/m`01@2b[M<0[[CM0:jdg@2^]=d0/ZkD00@0[[GN
0P2/^N<00`2^]]l0Zk[T0:^ji0020:^ji003o`00003oool0oooo02@0oooo00?o00000?ooo`3oool0
1`3oool206FTm080N:C^0P2:X^@309ROf@@0XYc>00<0ZIW60:>Ib`2ZUl<00`2ZUl<40:jE_@030;6D
^P2_TkX0[i>j00@0/Y>f0P2dTkD20;>A/`@0]I6b00@0]Y:b0;J@/02fT;00]Y2`102gTK040;RA[P80
^9:`0P2iT:`40;VB[P@0^Y:]0ol000020;^B[0<0^iB_00<0_9:[0;bD[`2lU:l00P2lU:l50;bE[P03
0;bH/`2mUZh0_IJ^00<0_9Vc0P2nUjh40;fJ/`@0_Y^d00@0`9V`0;jL]@2nW;D0_Ybe1@2oW[H40;nO
^0030;fS_`30XKX0`:6j0080`:6j00@0_JG10<2S_030Xk`0`:>l0P2mYl<20<2V_P80_JW500<0`:S1
o`00002mZlP00P2mZlP00`30Z/@0_:g;0;b]b`020;b]b`@0^k3>00D0^;;D0;Zbd@2j/]40^[;A0;Nd
e`030;Vce080][KI0P2h]ML00ol00000oooo0?ooo`0I0?ooo`003@3oool00ol00000oooo0?ooo`06
0?ooo`@0_hjR00@0^hZQ0<2>X@30SZ40`8jQ0`2lRZ000`31SZ00_8VO0;b9W`030;b9W`D0_HVN00@0
^HRR0;f9WP2mRIh0_HVN0P2jR:430;j9W@<0^XRP00@0_XVM0;Z8X02jR:00^XRP0P2oRYd90;^8W`@0
^hVO00<0^8^V0;b9W`2lRIl00P2lRIl00`2hRjH0_8VO0;b9W`02o`000080^H^V0P2mRZ020;V<YP80
_H^P0`2iSJL00`2mS:40^XfW0;Z=Y`020;Z=Y`030;j<XP2jSZP0^XjX0080^XjX102jSjT50;Z@ZP05
0;NF]P2kTJ/0^i6[0;^AZ`2gUkL00`2kTZd20;NI^080^iB^0`2gV[X00`2kUK00]ibl0;NL_0020;NL
_0@0]ifn1@2gWl001P2cZ<d0]j720;NQ`P2gXL80/j[?o`000080]j?40P2cZm400`2gYLH0/ZgC0;:]
d`020;:]d`040:jdg@2b[]@0/ZkD0;:^e080[[GN0P2a/=H30:jfg`80Zk[T0P2]]n000ol00000oooo
0?ooo`0S0?ooo`03o`00003oool0oooo00T0oooo00<0?IWc05:Ll`1BW?<00P2:X^@309ROf@80XYc>
00@0V9cG0:>Ib`2SVL/0XiW;0`2ZUl<30:jE_@030:^E_`2_TkX0[i>j0080[i>j0`2bTkH0102dTkD0
/i6c0;>A/`2cTK<40;FA/P@0]Y2`102gTK040;RA[P040;RB/02iT:`0^I2/0;V@[0@0^I:^00H0^Y2[
0;ZB[Ol0003o00000;ZB[@2jU;030;^B[080^iB_0P2lTZ/40;bD[`030;fCZ`2lUJh0_9F^0080_9F^
102mUZh0102lVK<0_YN^0;jG[P2nUjh30;fJ/`80_iR_0P2nVk@20<2I/0<0_Ybe00<0`I^a0;nN]P2o
W[H00P2oW[H40;nO^0D0`:6j1030Xk`01@2mYl<0`:Jn0<2V_P30Y[h0_JW500<0`:S100?o00000;f[
b030Z/@00P30Z/@20;b]b`80_jg70P2k/<h01@2n[l/0^[;A0;Zbd@2j/]40_K7>00@0^K?D00<0][KI
0;Ree`2h]ML00P2h]ML00ol00000oooo0?ooo`0H0?ooo`003@3oool00ol00000oooo0?ooo`050?oo
o`D0_hjR00@0^hZQ0<2>X@30SZ40`8jQ0`2lRZ000`31SZ00_8VO0;b9W`030;b9W`D0_HVN00D0^HRR
0;f9WP2mRIh0_HVN0;Z8X@040;j9W@80^XRP0`2nRId20;Z8X080_hZM0`2kR9l00`2oRYd0^hRO0;^8
W`030;^8W`@0^hVO1@2lRIl3o`000080_8VO00D0^H^V0;f:X02mRZ00_HZP0;V<YP030;f;X0<0^HfW
0P2mS:420;Z=Y`80_XbR0`2jSZP00`2nSJ80^XnY0;Z?Z@020;Z?Z@030;j>X`2jT:X0^Y2Z0080^Y2Z
102kTJ/40;^B[@030;NI^02kU:h0^iB^0080^iB^00@0]iZj0;^E/02kUK00^iF`0P2gW;`20;^G/P80
]ifn0P2lVK@40;NO`0@0]j720P2gXl@00ol00000]j?40;>[d@030;NUaP80/ZgC00<0]ZO90;:^e02b
[]@00P2b[]@00`2^]Mh0/K3F0;6`eP020;6`eP030:jfg`2a/MP0/K7H00@0[KOP00?o00000?ooo`3o
ool08P3oool00ol00000oooo0?ooo`0:0?ooo`0300n6i@1BW?<0DYcc0080KYo_0P26Wn@309RLe`<0
XiW;102ZUl<0102^UKd0ZiFo0:^E_`2[UKl30:nC^P80/Y>f00<0/I:g0;>A/`2cTK<00P2cTK<30;FA
/P80]92a102fT;020;NA/0030;N@[P2hTJh0^96^0080^96^1@2iT:`20;VB[P?o00000`2jTZd40;^B
[0040;^D[`2lTZ/0_9:[0;bBZ`<0_9B_0P2mTj/40;bE[P@0_IJ^1@2nUjh01@2mV[<0_iR_0;nH[`2o
V:l0_Y^d00<0`9V`0P2nW;D20<6K/@<0_ijf0P32W;830;nO^0030<:N]030XKX0`:6j0080`:6j1030
Xk`40<2V_PD0`:S100Go00000<2Za030Z/@0`:[40;b]b`030;n]a`050;^`cP2n[l/0_Zo;0;j_b`2j
/]400`2m/Lh20;Vce080_;CA0`2h]ML00`2k]]@0ooooo`00000I0?ooo`003@3oool00ol00000oooo
0?ooo`050?ooo`D0_hjR00@0^hZQ0<2>X@30SZ40`8jQ0P2lRZ020<6>X0@0_8VO00<0`HjO0;f9WP2m
RIh01`2mRIh00`2jR:40_XVM0;j9W@020;j9W@80^XRP0`2nRId20;Z8X080_hZM0`2kR9l00`2oRYd0
^hRO0;^8W`020;^8W`030<2:W02kRIl0^hVO0080^hVO0P2lRIl3o`0000D0_8VO00D0^H^V0;f:X02m
RZ00_HZP0;V<YP040;f;X0040;V=Y`2mS:40_HbQ0;f<X@80^XfW0P2nS:830;Z>Z080_XfR0P2jSjT2
0;j>X`@0^Y2Z102kTJ/0102oT:D0^i:]0;^B[@2kTZd50;^D[P@0^iF`00D0]ibl0;^G/P2kUk80^iNb
0;NM_P030;bI]0<0]io00P2lVkH20;NQ`P050;bL^@2gXl@0]j?4o`00002gXl@0102gYLH0102b[M<0
]ZO90;JWb@2fYlT20;:^e080]ZS<0`2a/=H00`2fZlh0/K7H0;6af0020;6af080[KOP00<0/;;Jo`00
003oool08`3oool00ol00000oooo0?ooo`0;0?ooo`0300n6i@0JR>T06XSY0080KYo_0P26Wn@309RL
e`<0XiW;0P2ZUl<00`2TV<P0ZiFo0:^E_`020:^E_`<0[i>j00@0/Y>f0;6B]`2aT[L0/I:g102cTK<0
102eTK80]92a0;B@/@2dT;440;J@/0040;NA/02gT:h0]i2^0;N@[P<0^96^00@0^92/0;V@[02iT:`0
^I2/0ol000020;Z@Z`@0^Y:]102kTZ`50;bBZ`040;bD[`2mTj/0_I>[0;fCZ`<0_9F^0P2nTj/30;fF
[P030;nDZ`2nUjh0_YN^0080_YN^102oV:l50<2I/0050;jL]@31Vk40`I^a0<6K/@2oW[H00`32W;82
0;nO^080`Yjd0`30XKX20<>Q]P80`:>l0P33XkP30<2V_P060<>U^`30Z<40`:S10<2X`@33Z;ko0000
0P30Z/@01@33Zl40_jg70;n]a`2o[LL0`jg500@0_Zo;102m/Lh00`2i/m@0_;CA0;bdd@020;bdd@05
0;Ree`2k]]@0^kKD0;^fe?l000006@3oool000d0oooo00?o00000?ooo`3oool0103oool00`34UZP0
_hjR0;n>XP030;n>XPD0`8jQ00@0_8ZP0<6>X031SZ00`HjP0`2lRIl00`31SYl0_HVN0;f9WP070;f9
WPD0_XVM00<0^XRP0;j9W@2nRId00P2nRId0102jR:00_hZM0;n:W@2oRYd30;^8W`030;n:W@2kR9l0
^hRO0080^hRO00@0`8ZL0;^9W`2kRIl0^hVO0ol000080;b9W`@0_HZP00<0^HbV0;f;X02mRj000P2m
Rj001@2iSJL0_HbQ0;f<X@2mS:40^XfW00@0_XbR00@0^XjX0;j=XP2nSJ80_XfR0P2jSjT20;j>X`<0
^Y2Z00@0_hnT0;^AZ`2kTJ/0^i6[0P2oT:D30;^B[@030<2BY`2kU:h0^iB^0080^iB^102kUK040;^G
/PD0_9Vd00D0]io00;bK]P2lVkH0_9^f0;NQ`P030;bL^@80]j?400Go00000;^N^`2gYLH0]jG60;^Q
_P040;JWb@D0]ZS<00@0/K3F0;J[cP2fZlh0]Z_>0P2a/MP00`2e[M00/;;J0;2bfP020;2bfP03o`00
003oool0oooo0240oooo00?o00000?ooo`3oool03@3oool201Z8j@80>Y;`0P1RVnl209RLe`80XiW;
00<0V9_E0:BHb02TV<P00P2TV<P30:^E_`<0[i>j102aT[L40;>A/`@0]92a102fT;040;N@[P80^96^
0P2hT:`3o`0000030;V@[02jT:/0^Y2[00<0^Y2[0P2jTZd00`2kT:X0^i:/0;^B[0020;^B[0030;bA
Z@2lTZ/0_9:[0080_9:[1@2mTj/0102lUJh0_Y>[0;jCZ`2nTj/20;fF[P80_iB[102nUjh40;nH[`03
0<:G[030VK00`9V`0080`9V`1031Vk440<:L/P030;nO^032W[@0`Yjd0080`Yjd00D0`:6j0<>Q]P33
XKH0`j6f0<2S_0040<>S^0050<2V_P33YK/0`jFk0<>U^`30Z<400`33Z;h01Ol00000`j_10<>[`@33
Zl40_jg700<0`jg50P2n[l/20<:`b0<0_K7>00D0`K;<0;bdd@2l]=40_;CA0;ndd0030;^fe0030;fg
d`3ooooo000001P0oooo000=0?ooo`03o`00003oool0oooo00@0oooo00<0a9JX0;n>XP2oSZ800`2o
SZ850<2>X@040;b:X031SZ00`HjP0<6>X080_8VO0P31SYl40;f9WP030<:>WP2mRIh0_HVN0080_HVN
1@2nRId00`2jR:00_XVM0;j9W@020;j9W@040;Z8X02oRYd0_hZM0;n:W@80^hRO0`2oRYd20;^8W`80
`8ZL0ol000020<2;W@<0_8VO00<0`HbM0;b9W`2lRIl00`2lRIl40;f:X0D0_H^P102mS:400`2jSJL0
_XbR0;j<XP020;j<XP050;Z>Z02nSJ80_XfR0;j=XP2jSjT0102nSZ<0102jT:X0_hnT0;n?Y02oSj@2
0;^AZ`80_i2U0P2kTZd20<2BY`<0^iB^0P30TjP30;^E/0050<2EZP2kUk80^iNb0;^G/P31Uj`0102l
VK@40;bK]P@0_9bi00D0]j?40;^N^`2kW[_o00000;NUaP030;^Q_P<0]ZO900D0^j?10;JXc02fZ<`0
]ZS<0;^Ua0040;J[cP040;6af02e[M00]Jg@0;F]d080/;;J00<0]:kC0?ooool000008P3oool00ol0
0000oooo0?ooo`0?0?ooo`03001Wb00jT_00>Y;`0080HY__00<0PigS09RKe@2HVmD00P2HVmD30:BH
b0@0ZiFo00<0[i>j0:bD_@2/U;d00`2aT[L30;>A/`80/Y6d102dT;420;J@/0030;J@[`2gT:h0]i2^
0080]i2^00@0^96^o`000?l0003o0000102iT:`50;Z@Z`040;ZB[@2kT:X0^i2Z0;^@ZP80^i:/0P2l
TJT40;bBZ`030;jBZ02mTj/0_I>[0080_I>[00D0_9F^0;jCZ`2nTj/0_Y>[0;fF[P030;nDZ`<0_YN^
0P31UZ/20;nH[`80`YN/1030VK040<6K/@040<BK[P32W;80`Ybb0<:L/PD0`Yjd1033XKH50<>S^0@0
`jFk1033Z;h01033Zl7o00000<>[`@33Zl440<>]a@030;j_b`32/<P0`[380080`[3800D0_K7>0<6b
c031//`0`K;<0;bdd@030;ndd0060;^fe02m]m<0_KOC0;fgd`3ooooo00005`3oool000`0oooo00?o
00000?ooo`3oool0103oool30<BFZ0<0_hjR00<0aIJW0<2>X@30SZ400`30SZ440<6>X080_8VO0`31
SYl30;f9WP040<:>WP2mRIh0_HVN0;f9WP80`hjN2@2nRId00`2jR:00_hZM0;n:W@020;n:W@050;^8
W`2oRYd0_hZM0;n:W@2kR9l00ol000000`30RY`0^hVO0;^9W`020<2;W@<0_8VO00<0`HbM0;b9W`2l
RIl00P2lRIl00`31S9d0_HZP0;f:X0020;f:X0D0_H^P102mS:450;j<XP@0_XfR00<0^XnY0;j>X`2n
SZ<00P2nSZ<01@2jT:X0_hnT0;n?Y02oSj@0^i6[00@0_i2U00<0^i:]0<2BY`30TZL00P2kU:h30<2C
Z080^iF`0P30UJX20;^G/P80`IN/102lVK@40;bK]P040<6J/02lW;T0_9bi0;bL^@@0^ijk00?o0000
0;^Q_P2kXKh00P2kXKh01@2fYlT0^j?10;^S`@2kXl40]ZS<00<0^jG40P2fZlh01@2jYlH0]Jg@0;F]
d02e[M00^J[900@0]:kC00?o00000?ooo`3oool07`3oool00ol00000oooo0?ooo`0B0?ooo`05001:
YP00K]@06h?X01^3j023WN<00`2HVmD40:BHb080ZiFo00@0YIK60:bD_@2/U;d0[9Bm102aT[L0102c
TK<0/Y6d0;:A]02bTK@40;B@/@030;J@/02fT:l0]Y2_0080]i2^0ol000040;R@[080^I2/1P2jT:/4
0;^@ZP040;^B[02lTJT0_96Y0;bAZ@<0_9:[0P2nTZP40;fCZ`@0_Y>[1@2oU:/01@2nUjh0`IJ[0<6F
Z`31UZ/0_iR_00<0`YN/0`30VK020<>I[@80`I^a0P34Vjh30<:L/P030<BM[`32W[@0`Yjd0080`Yjd
1033XKH00`36XK<0`j>h0<>S^0020<>S^0@0`jFk1033Z;h00`37ZK`0`j_1o`0000020<J/`0<0`jg5
00D0aZo30<:`b032/<P0`[380<Fba`030<6bc0050<>db`2o]=00_kC@0;ndd032]ll0102m]m<00`3o
oooo00000?ooo`0F0?ooo`00303oool00ol00000oooo0?ooo`040?ooo`<0a9JX0P2oSZ820<FFY`D0
`8jQ1031SZ000`2lRIl0`HjO0<6>W`020<6>W`80_HVN0`32SYh20;f9WP80`hjN2@2nRId50;n:W@03
0;^8W`2oRYgo000000;o000000D0^hRO0<2:W030RY`0`8ZL0;^9W`030<2;W@<0_8VO0P31S9d30;b9
W`040<6<W@2mRZ00_HZP0;f:X080`XfM0`2mRj000`32SYh0_HbQ0;f<X@020;f<X@D0_XbR102nSJ85
0;j>X`@0_hnT00<0^i6[0;n@Y@2oT:D00P2oT:D01@2kTZd0`9:W0<2BY`30TZL0^iB^00<0`9>X00@0
^iF`0<2EZP30UJX0`9FZ0P2kUk820<6G[0<0_9Vd0P31V:h20;bK]P80`IZ`0`2lW;T01@31W;<0^ijk
0;^N^`2kW[_o000000@0^j6n102kXl440;^Ua0050;J[cP2jYlH0^ZO60;ZWaP2e[M000`2iZ/T20;B^
d`030;V/c@3ooooo00000200oooo00?o00000?ooo`3oool0503oool01000N<l06h?X01^3j01DUNl3
09RKe@80Y9S800@0V9WC0:FFaP2UU/H0YIK60`2/U;d30;6B]`030:jC^P2bTK@0/Y6d0080/Y6d102d
T;420;J@[`?o00000P2gT:h00`2hT:d0^92/0;R@[0020;R@[0030;V@[02jT:/0^Y2[00D0^Y2[102k
T:X00`2kTZ`0_96Y0;bAZ@020;bAZ@040;bBZ`2nTZP0_Y:X0;jBZ0@0_I>[102nTj/00`30U:P0_iB[
0;nDZ`020;nDZ`@0`IJ[00<0_iR_0<:G[032Uj`00P32Uj`01@30VK00`iV]0<>I[@33VJd0`I^a00<0
a9^^0P32W;820<BM[`<0`Yjd0P35Wk420<>Q]P80aZ6c0`33XkP20<JT]P80`jFk0P37YkT20<>X_P80
ajVl00<0`j_1o`000036[<000P36[<001@33[LD0aZo30<J_``36[l<0`[3800<0aK;700D0`K;<0<>d
b`33]</0`kC;0;ndd0030<:gc`80_KOC00@0`;WC0?ooo`3ooooo00005P3oool000`0oooo00?o0000
0?ooo`3oool00P3oool00`38Zkd0a9JX0<BFZ0020<BFZ080_hjR0`35UZL30<2>X@030<JGYP31SZ00
`HjP0080`HjP00<0_8VO0<6>W`31SYl00P31SYl20;f9WP<0`XjN0P2mRIh20<>>WP<0_XVM00<0`hjN
0;j9W@2nRId00`2nRId40;n:W@?o00000P2oRYd00`2kR9l0`8ZL0<2:W0020<2:W0040;^9W`30Rid0
`8^M0<2;W@80_8VO0`31S9d20;b9W`<0`HbM0P2mRZ020<:=W@<0_H^P00@0`XjN0;f<X@2mS:40_HbQ
0P33SYh30;j<XP030<B?W`2nSJ80_XfR0080_XfR1@2nSZ<40;n?Y0D0_i2U1030TZL40<2CZ0D0`9FZ
00D0^iNb0<6G[031Uj`0`IN/0;bI]0030<6H[P030;bK]P31V[00`IZ`0080`IZ`00D0_9bi0<6L/`31
W;<0`Ibc0;^N^`020<6N]P03o`00002kXKh0^j6n0080`J6i0P2kXl420<2S_080^jG400<0`:Fo0;ZW
aP2jYlH00P2jYlH40;VZb@060;B^d`2i[<d0^Jc=0;V/c@3ooooo00007`3oool00ol00000oooo0?oo
o`0F0?ooo`03012?h`00CK80E9G_0080Oi_T0`2HVM<40:FFaP<0[9Bm00@0/I:g0:jC^P2^TkX0[Y>j
102bTK@20;B@/@?o00000P2fT:l20;N@[P80^92]102hT:`70;Z@Z`030;^@Z@2kT:X0^i2Z0080^i2Z
1@2lTJT00`2lTZ/0_Y:X0;jBZ0020;jBZ080_I>[00@0_i:X0;jCZ`2nTj/0_Y>[0P30U:P40;nDZ`@0
`IJ[1@32Uj`40<>I[@030<6K/@34Vjh0a9^^0080a9^^00D0`Ybb0<BM[`34WJl0a9f_0<:N]0030<FO
/@030<>Q]P36XK<0aZ6c0080aZ6c00D0`j>h0<JT]P36Y;H0aZBf0<>U^`030<NW^@040<>X_P37ZK`0
ajVl0<NY_080aZc000?o00000<J/`036[<001036[l<40<Fba`@0`kC;1032]ll0102m]m<0`;WC0<2i
d`30^M<20?ooo`03o`00003oool0oooo01<0oooo000<0?ooo`04o`00003oool0oooo0?ooo`80b:^m
1034UZP00`2oSZ80aIJW0<FFY`020<FFY`<0`8jQ00<0aYNV0<6>X031SZ000P31SZ050<6>W`030;f9
WP32SYh0`XjN0080`XjN00@0_HVN0<>>WP33SYh0`hjN0`2nRId00`33SYh0_XVM0;j9W@020;j9W@03
0<B?W@2oRYd0_hZM00;o00001@2oRYd00`2kR9l0`8ZL0<2:W0020<2:W0030;^9W`30Rid0`8^M0080
`8^M00@0_8VO0<6<W@31S9d0`HbM0P2lRIl30<6<W@80_HZP0P32SId30;f;X080`XjN0P2mS:420<>>
WP<0_XbR00@0a8nO0;j=XP2nSJ80_XfR0P34T:030;j>X`030<FBX@2oSj@0_hnT0080_hnT00<0aI>R
0;n@Y@2oT:D00P2oT:D40<2BY`050<JFY030TjP0`9>X0<2CZ036UjH01030UJX40<6G[0@0`IR^1@31
V[040<6L/`@0`Ijf00Go00000<6Q^@31XKT0`J6i0;^S`@030<2S_0040;^Ua030YKl0`:Fo0<2U_`80
^ZO60P2oZ<820;VZb@070;jZa@2i[<d0^Jc=0;V/c@2m[<T0ooooo`00000O0?ooo`03o`00003oool0
oooo01P0oooo00@0>:Gd001_f@1oVn@0Oi_T0`2HVM<30:FFaP80[9Bm00<0YiG40:jC^P2^TkX00P2^
TkX40;:A]0;o000000<0]96b0;J@[`2fT:l00P2fT:l0102gT:h0^92]0;R@[@2hT:d40;R@[0H0^Y2[
0`2kT:T30;^@ZP030;fAZ02lTJT0_96Y0080_96Y1@2nTZP0102mTj/0_i:X0;nBZ02oTZP20;jCZ`80
`9BX0`2oU:/00`32UJP0`IJ[0<6FZ`020<6FZ`030<>GZ@32Uj`0`YN/0080`YN/1033VJd50<BK[P@0
a9f_1035Wk450<JQ/`@0aZBf1037YkT40<NY_0060<Z/_036[<00aZc0o`000036[<00bZno0P36[l<2
0<Vba080aK;70P38]LP20<>db`80a[S<0P32]ll01@34^]00`;WC0<2id`30^M<0`[cD0080oooo00?o
00000?ooo`3oool04`3oool000`0oooo00?o00000?ooo`3oool00`38Zkd40<BFZ0D0aIJW0P30SZ43
0<JGYP<0`HjP1@31SYl00`2mRIh0`XjN0<:>WP020<:>WP040;f9WP33SYh0`hjN0<>>WP<0_XVM00<0
`hjN0;j9W@2nRId00P2nRId3o`000080_hZM00<0aHnM0;n:W@2oRYd00P2oRYd50<2:W0D0`8^M00D0
_8VO0<6<W@31S9d0`HbM0;b9W`040<6<W@040;f:X032SId0`XfM0<:=W@80_H^P0`32SYh20;f<X@80
`hjN0`2nS:820<B?W`80_XfR0P34T:030;j>X`040<FBX@2oSj@0_hnT0;n?Y080aI>R0`2oT:D01035
U:<0`9:W0<2BY`30TZL20<JFY080`9>X0P36UjH40<2EZP@0`IN/00D0ai^Z0<6H[P31V:h0`IR^0<NM
[0040<6J/0@0`Ibc1031W[H01031XKWo00000<6Q^@31XKT40<2S_0@0`:Fo00D0^ZO60;nX`P2oZ<80
_jS20;VZb@030;jZa@060;V/c@2m[<T0_Jc90;f/b@3ooooo00007P3oool00ol00000oooo0?ooo`0J
0?ooo`03001_f@14Snh0A8o^0080V9WC0P2UU/H00`2IVM80YiG40:NEa0020:NEa0<0[Y>j00@0/Y6d
o`000?l0003o0000102dTK830;J@[`D0^92]0P2hT:`20;V@[0@0^Y2[102kT:T20;^@ZP80_I6X102l
TJT50;jBZ0@0_i:X00<0_Y>[0<2DZ030U:P00P30U:P0102oU:/0`YFX0<:EZ032UJP20<6FZ`80`iNY
0`32Uj`00`34V:X0`iV]0<>I[@020<>I[@030<FJZ`34Vjh0a9^^0080a9^^1034WJl01@38WZh0aIna
0<FO/@35Wk40b:6`00@0aZ6c1036Y;H00`3:Y[D0ajNi0<NW^@020<ZY^080ajVl0P3:[;`30<J/`003
o`00003:[kl0aZo300<0bK;400D0aK;70<Reb038]LP0b;G80<>db`030<Jhc0050<:gc`34^]00a;[@
0<Bjd030^M<00`32_=@20?ooo`03o`00003oool0oooo0180oooo000<0?ooo`03o`00001ifo/0b:^m
00@0b:^m0`34UZP50<FFY`030<2>X@36UjH0aYNV0080aYNV0P31SZ020<NGY@@0`HjO1@32SYh00`2m
RIh0`hjN0<>>WP020<>>WP040;j9W@33SYh0`hjN0<>>WP?o000000<0a8nM0;n:W@2oRYd00P2oRYd0
0`35Sid0_hZM0;n:W@020;n:W@D0`8ZL1@30Rid40<6<W@030;b9W`31S9d0`HbM0080`HbM00@0_HZP
0<:=W@32SId0`XfM0P2mRj030<:>WP040;f<X@33SYh0`hjN0<>>WP80_XbR0`34Sil0102nSJ80a92P
0<B@X034T:020;j>X`<0aI:Q0P2oSj@20<FCXP<0_i2U0P35U:<20<2BY`80aYJT0P30TjP20<JGYP<0
`9FZ0P37VJP20<6G[080ai^Z0P31V:h20<NM[0<0`IZ`0P37Wjl20<6L/`80aj6a0`31W[H01031XKWo
00000<6Q^@31XKT40<2S_0040<JX^`30YKl0`:Fo0<2U_`@0_jS2102nZ/D40;f/b@030?ooool00000
oooo01d0oooo00?o00000?ooo`3oool06`3oool0101h_?`0A8o^04B?kP1lV^@409VIdP<0YiG400D0
[Y>jo`000?l0003o00000;:A]0020;2B^0@0]96b0P2fT:l20;JA/0@0^92]00@0^92/0;V@[02iT:`0
^I2/102jT:/40;^@Z@040;^@ZP2mTJP0_I6X0;fAZ0<0_96Y0P2nTJP40;jBZ0@0_i:X00<0_Y>[0<2D
Z030U:P00P30U:P01@2oU:/0`YFX0<:EZ032UJP0`IJ[00<0`iNY0P32Uj`30<BHZP80`iV]0P35VZ/3
0<BK[P80aYb/0P34WJl20<RN[P80aIna0P38XK030<JQ/`80bJBb0P36Y;H20<ZV]@030<NW^@3:ZKP0
bZVh0080bZVh00P0ajVl0<Z/_03:[;`0bZbl0<J/`03:[koo00000<Z__`@0bK;41038]LP30<Jhc004
0<VlcP34^]00a;[@0<Bjd080a[kB0`32_=@00`34`=H0ooooo`00000D0?ooo`00303oool00ol00000
oooo07WKn`040<R[_@80a9JX0P3:[;`40<FFY`030<2>X@36UjH0aYNV0080aYNV0P31SZ020<NGY@@0
`HjO1@32SYh50<>>WP040;j9WOl0003o0000o`000080_XVM0`34Sid20;n:W@80aHnM0`2oRYd20<F@
W@@0`8ZL1@30Rid90<6<W@030;f:X032SId0`XfM0080`XfM00D0_H^P0<:>WP32SYh0`XjN0;f<X@04
0<>>WP050;j<XP34Sil0a8nO0<B?W`2nSJ801034T:001@2nSZ<0aI:Q0<FBX@35TZ40_hnT00@0aI>R
00D0_i2U0<FDX`35U:<0aIBS0<2BY`040<JFY0050<2CZ036UjH0aYNV0<JGYP30UJX00`37VJP01031
Uj`0ai^Z0<NKZP37VjX20<6H[P80aif/0P31V[030<NO[`040<6L/`37XK40aj6a0<NQ/@80`Ijf0P37
Xk@01031XKWo00000<NV^037Y[P20<2S_080aZRk0`30YKl01@36Z[h0_jS20;nX`P2oZ<80aJg200<0
_Z[500L0a:o60;f/b@2m[<T0_Jc90<:ab@3ooooo000001d0oooo00?o00000?ooo`3oool0703oool0
102:__P005G0001E`01lV^@309VIdP040:NEa?l0003o0000o`000080[Y>j00<0ZIG20;2B^02`T[P0
0P2`T[P30;BA/P040;J@[`2fTK00]Y6`0;JA/0@0^92]102iT:`30;Z@Z`030;^@ZP2kT:T0^i2Y0080
^i2Y1@2mTJP0102lTJT0_Y6X0;jAZ02nTJP30;jBZ0030<2BY`2oTZP0_i:X0080_i:X1@30U:P40<:E
Z0030<6FZ`33UjT0`iNY0080`iNY00D0`YN/0<BHZP34V:X0a9RZ0<>I[@030<FJZ`80a9^^0`36W:`0
0`34WJl0b9j^0<RN[P020<RN[P050<FO/@38XK00b:6`0<RQ/036XK<00`39Y;801036Y;H0bZJe0<ZV
]@3:Y[D50<ZY^0@0bZbl0`3:[kl01?l00000c[C10<Vba039//@20<fhaP80b;G80P3;^/X01@36^<`0
bKc>0<VlcP39_<h0a;[@00@0a[kB00H0`[cD0<C0eP34`=H0a<3F0?ooool0000C0?ooo`002`3oool0
1?l00000oooo0?ooo`3oool40<R[_@040<BFZ03:[;`0bZbl0<Z/_0@0aIJW1@36UjH01031SZ00aiNU
0<NGY@37UjD30<6>W`030<RGY032SYh0`XjN00<0`XjN0`33SYh3o`0000<0`hjN0P2nRId30<B?W@80
_hZM0`35Sid20;n:W@80aI2M0`30RY`00`36T9d0`8^M0<2;W@030<2;W@T0`HbM1@32SId40<:>WP03
0;f<X@33SYh0`hjN0080`hjN00D0_XbR0<B?W`34Sil0a8nO0;j=XP040<B@X0050;j>X`35TZ40aI:Q
0<FBX@2oSj@01035Tj801@2oT:D0aIBS0<FDX`35U:<0`9:W00@0aYJT1036UjH01@30UJX0aiVX0<NI
Z037VJP0`IN/00@0ai^Z00D0`IR^0<NM[037WJ`0aif/0<6J/0030<NO[`050<6L/`37XK40aj6a0<NQ
/@31W[H00`37Xk@01@31XKT0ajJho`000037Y[P0`:>l00@0aZRk00D0`:Fo0<JZ_P36Z[h0aZZn0;nX
`P030<F]`P050;jZa@34[lH0a:o60<B_aP2m[<T00`32/LT00`3ooooo00000?ooo`0J0?ooo`03o`00
003oool0oooo01h0oooo00@0R[kh001E`000EL00<XS/0ol000030:NEa0030:jC^P2YUL80ZIG200@0
/9:h0P2dTK800`2bT[H0]Y6`0;JA/0020;JA/0@0^92]1@2iT:`0102jT:/0^i2Z0;^@ZP2kT:X30;^@
Z@D0_I6X00@0_96Y0;jAZ02nTJP0_Y6X0`2nTZP20<2BY`<0_i:X00<0`IBW0<2DZ030U:P00P30U:P4
0<:EZ0D0`iNY1034V:X00`33VJd0aIZ[0<FJZ`020<FJZ`050<BK[P36W:`0aYb/0<JL[034WJl01038
WZh40<RQ/0@0bJBb103:Y[D00`3>ZkH0bZVh0<ZY^0020<ZY^0030<j^^P3:[;`0bZbl0080c[6m0P3:
[kl00`3>]<7o00000<Vba0030<fhaP050<Reb03;^/X0bk[:0<^jbP3>`Lh00`39_<h01@3;`m80a[kB
0<JndP36_]80b<CF00<0a<3F00@0aLGJ0?ooo`3ooooo00004P3oool000/0oooo00?o00000?ooo`3o
ool00P3oool20<R[_@0306_Il@3:[;`0bZbl0080bZbl1035UZL00`3<[K/0aYNV0<JGYP020<JGYP04
0<6>X037UjD0aiNU0<NGY@<0`HjO00<0b9NT0<:>WP32SYh00P32SYh01039V:Co0000o`000?l00006
0<>>WP030;j9W@34Sid0a8nM0080a8nM0P2oRYd30<F?W@80_hZM0P35T9d30<2:W0030<J@W@30Rid0
`8^M0080`8^M00<0ai6M0<6<W@31S9d00P31S9d00`38TYd0`HbM0<6<W@020<6<W@D0`XfM1032SYh5
0<>>WP@0a8nO1@34T:040<FBX@030;n?Y035Tj80aI>R0080aI>R1035U:<50<JFY0@0aYNV1037VJP5
0<NKZP@0aif/1037Wjl40<NQ/@@0aj>d0`37Y[P00ol00000aZRk0<JX^`030<JX^`@0aZZn1035[L84
0<B_aP@0`[7900<0ooooo`00003oool06P3oool00ol00000oooo0?ooo`0O0?ooo`?o00000`1jV^D3
09^Id@@0ZIG20`2`T[P0102dTK80/Y:f0;:B]P2bT[H40;JA/080^92]00<0^96_0;V@[02iT:`00`2i
T:`0102jT:/0^i2Z0;^@ZP2kT:X20;^@Z@80_96Y102mTJP50;jAZ0040;jBZ030TZL0`9:W0<2BY`80
_i:X0P31U:L30<2DZ0030<>EZ032UJP0`YFX0080`YFX00<0a9NX0<>GZ@33UjT00P33UjT40<BHZPD0
aIZ[1036W:`50<RN[P@0b:6`1039Y;800`3=Z;<0bZJe0<ZV]@020<j[]P<0bZVh0P3>[[X01@3:[;`0
c[6m0<ja_@3>/Kd0bZno00<0c[C100Go00000<fhaP3=^<H0cKS60=2ob@030<^jbP80c/7>00D0bKc>
0<_3dP3;`m80bl?B0<JndP030<S4eP060<C0eP35aMX0aLGJ0<G5fP3ooooo00004P3oool000/0oooo
00?o00000?ooo`3oool01@3oool00`1[fO40bZbl0<Z/_0020<Z/_080aIJW0P3<[K/40<JGYP@0aiNU
0P31SYl30<RGY0040<:>W_l0003o0000o`0000T0`hjN00<0_XVM0<B?W@34Sid00P34Sid00`2oRYd0
aHnM0<F?W@020<F?W@040;n:W@35T9d0aI2M0<F@W@<0`8ZL00<0aY2M0<2;W@30Rid00P30Rid01037
TId0`HbM0<6<W@31S9d20<RBW@<0`HbM0P38Tih40<:=W@@0`XjN1@33SYh40<B?W`D0a92P1035TZ45
0<FCXP@0aIBS1@36UZ@40<JGYP050<nQZ037VJP0aiVX0<NIZ03@Xj/01037VjX40<NM[0@0ain_1037
XK401@3@[KH0aj>d0<NS]037Xk@0cjni0080ajJh00?o00000<na_036Z;/00P36Z;/20<jc`080aZZn
0P3=]/@20<F]`P80bkS80P34[lH20<Vjc080`[790P37^ll00`3ooooo00000?ooo`0I0?ooo`03o`00
003oool0oooo01`0oooo0ol000030?ooo`0409fol01jV^D0NY[U07ZJi@80ViWA102YUL820;2B^003
0:bF`02bT[H0/Y:f0080/Y:f102fTK00102hT:d0^96_0;RA[`2hTJl30;V@[0030;ZB[@2kT:X0^i2Z
0080^i2Z00@0^i2Y0;bAZ@2lTJT0_96Y102mTJP50;jAZ0050;jBZ030TZL0`9:W0<2BY`2oTZP00`31
U:L30<2DZ080`iFX0P32UJP20<BGZ0<0`iNY00<0aYVY0<BHZP34V:X00P34V:X00`37VjT0aIZ[0<FJ
Z`020<FJZ`@0aYb/00@0bYn/0<RN[P38WZh0b9j^0P3;XZh20<RQ/080cJF`0P39Y;820<fX/`80bZJe
0`3>ZkH0103:ZKP0cZjj0<j^^P3>[[X40<ja_@070=:i`@3>]<40c[C10<jd`Ol00000dKc50<fhaP03
0=2ob@040<^jbP3>`Lh0c/7>0<k1cP<0bl?B00D0c<_H0<S4eP38a=H0b<CF0<S;g0030<G5fP80a<[O
00<0ooooo`00003oool0403oool000/0oooo00?o00000?ooo`3oool01P3oool40<Z/_0040<FFY`3<
[K/0c:fk0<b]^`@0aYNV1@37UjD00`31SYl0b9NTo`000002o`0000030<:>WP39V:@0bIRT00@0`hjN
00<0bYVS0<>>WP33SYh00P33SYh50<B?W@030;n:W@35Sid0aHnM0080aHnM00@0_hZM0<F@W@35T9d0
aI2M0P30RY`30<J@W@80`8^M0P37TId30<6<W@80b9:M0`31S9d20<RCWP<0`XfM00@0bIBN0<:>WP32
SYh0`XjN0P3:UIh30<>>WP040<^FW`34Sil0a8nO0<B?W`80c9RP0`34T:020<bIX@<0aI:Q1035Tj82
0<jLX`<0aIBS00D0cYjU0<JFY036UZ@0aYJT0<nOYP030<JGYP80cj6X0P37VJP20=2SZ`<0ai^Z0P3@
YZd20<NM[080d:R_0P37Wjl20=2Z/P80aj6a0`3@[KH02@37Xk@0cjni0<n_^@3?[kT0ajJh0<na_?l0
0000ck6l0<JX^`030<jc`0050<JZ_P3=]/@0cKK40<ffa035[L800`3;^<P01@34[lH0bK[<0<Vjc039
^/`0`[7900<0ak_?0ol0000I0?ooo`03o`00003oool0oooo01T0oooo0ol000070?ooo`030::nk@1j
V^D0NY[U00<0ViWA0`2YUL80102`T[P0[9K00:bF`02/U/030;:B]P<0]Y6`00<0]9>d0;RA[`2hTJl0
0P2hTJl20;V@[080^Y:]102kT:X0102kT:T0_96Y0;bAZ@2lTJT30;fAZ0030;jBZ@2nTJP0_Y6X00<0
_Y6X1030TZL00`2oTZP0`IBW0<6DY`020<6DY`040<2DZ033UJP0`iFX0<>EZ080`YFX0P34UjP30<>G
Z@80aYVY0P34V:X20<NKZ@<0aIZ[0P39WJ/20<JL[080bYn/0P38WZh30<^R[P050<RQ/03=YK00cJF`
0<fU/039Y;80103=Z;<0103:Y[D0cZ^f0<j[]P3>ZkH40<j^^P030=>f_@3>/Kd0c[6m00<0d[W100@0
c[C10=6la@3A_<Go0000103@_lT30<k1cP80d<[D00D0bl?B0<c;f03<bmP0c<_H0<S4eP030<S;g004
0<G5fP34b]l0a<[O0<?@i0?o0000403oool000/0oooo00?o00000?ooo`3oool01`3oool20<Z/_003
0?ooo`3<[K/0c:fk00<0c:fk0P36UjH00`3>[kX0aiNU0<NGY@020<NGY@?o00000P38Uj@20<:>WP<0
bIRT0`33SYh00`3:VJ<0`hjN0<>>WP020<>>WPD0a8nM1@35Sid00`2oRYd0aI2M0<F@W@020<F@W@04
0<2:W036T9d0aY2M0<J@W@80`8^M0`37TId20<6<W@80b9:M0`31S9d20<RCWP<0`XfM00@0bIBN0<:>
WP32SYh0`XjN0P3:UIh30<>>WP040<^FW`34Sil0a8nO0<B?W`80c9RP0`34T:020<bIX@<0aI:Q00@0
cIZR0<FCXP35Tj80aI>R0P3>W:<20<FDX`80cYjU0`36UZ@20<nOYP80aYNV0P3?XJP20<NIZ080d:>[
0P37VjX30=2V[@050<NM[03@Z:l0d:R_0=2X[`37Wjl00`3@Z[800`37XK40d:ff0=2]]P020=2]]P@0
cjni0`3?/K`00ol00000c[?00<jc`0020<jc`0<0cKK400D0d/_C0<^hb03;^<P0bkS80<o<eP030<Vj
c0050<c<f@37^ll0ak_?0<Nkc`38c=`00P3oool00ol00000oooo0?ooo`0G0?ooo`03o`00003oool0
oooo01H0oooo0ol0000;0?ooo`030::nk@2U_^/07H3W0080ViWA0P2YUL800`2MV]00[9K00:bF`002
0:bF`0@0/Y:f00<0]Y6`0;BC]02dTk@0102hTJl0102iT:`0^Y:]0;ZB[@2jTZd40;^@ZPD0_96Y00@0
_I6X0;jBZ@2nTZT0_Y:Y102nTJP40<2BY`D0`IBW00D0`9BX0<>EZ033UJP0`iFX0<:EZ0040<BGZ005
0<>GZ@36VJT0aYVY0<JIZ@34V:X00`37VjT20<FJZ`<0bIf[00<0aYb/0<ZO[03:Wj`00P3:Wj`01@38
WZh0bj:^0<^R[P3;XZh0b:6`00<0cJF`1@3=Z;<40<j[]P030=>b^@3>[[X0cZjj0080dkJm00<0c[6m
0=:i`@3B^L400P3B^L440=6la@03o`00003@_lT0d;o90080dlS@00@0c/7>0=3:e03@b]@0d<[D0`3<
bmP20<_Cg`80b<_L0P37d^801P34b]l0`m3T0<?@i033d>@0ooooo`000100oooo000;0?ooo`03o`00
003oool0oooo00/0oooo103<[K/01@36UjH0cZnj0<j_^P3>[kX0aiNU00;o000000<0aiNU0<RGY038
Uj@00P38Uj@00`32SYh0bIRT0<VHY0020<VHY080`hjN0P3:VJ<30<>>WP80biVS1034Sid50<F?W@D0
aI2M00@0`8ZL0<J@W@36T9d0aY2M0P30Rid30<NAW@040<6<W@38TYd0b9:M0<RBW@80`HbM0`38Tih3
0<:=W@80bIBN0P32SYh20<ZEWP<0`hjN0P3;UYl20<B?W`80c9RP0`34T:020<bIX@80aI:Q0P3=VZ83
0<FCXP80cYbS0P35U:<20<jNY@80aYJT0`3?WjH00`36UjH0cj6X0<nQZ0020<nQZ0050<NIZ03@Xj/0
d:>[0=2SZ`37VjX00`3@YZd01037WJ`0d:R_0=2X[`3@Z:l40=2Z/PD0d:ff103?[kT01@3JalL0ck6l
0<na_03HbL_o00000080c[?00P3Eb/l01@3=]/@0d/_C0=;;d`3Bbm<0bkS800<0clcF00D0bK[<0<c<
f@3<c=T0c<cI0<Nkc`030<S<g0030?ooool00000oooo01P0oooo00?o00000?ooo`3oool0503oool2
o`0000h0oooo102U_^/00`1hV^L0WI[@09fJd00209fJd0<0[9K00`2bT[H0102^Ukh0]9>d0;BC]02d
Tk@40;RA[`D0^Y:]0`2kT:X00`2lTj`0_96Y0;bAZ@020;bAZ@040;fAZ02nTZT0_Y:Y0;jBZ@<0_Y6X
00<0`9>X0<2BY`30TZL00P30TZL00`32UJP0`IBW0<6DY`020<6DY`@0`iFX00<0`YFX0<BGZ034UjP0
0P34UjP01@33UjT0aYVY0<JIZ@36VJT0a9RZ00@0ai^Y00D0aIZ[0<VMZ`39WJ/0bIf[0<JL[0040<ZO
[0@0bj:^103=YK000`3A[;<0cJRc0<fX/`020<fX/`030=:_]P3>ZkH0cZ^f0080dk:i00@0cZjj0=>f
_@3C][d0dkJm1@3B^L400`3Ga<L0dKc50=6la@020=G6c004o`00003Cb=00dlS@0=CDf@<0d<[D0P3@
e=`0103<bmP0bm?O0<_Cg`38fnP30<OBhP040<?Hj@33d>@0`m3T0<?@i080_mCZ00?o00000?ooo`3o
ool03P3oool000X0oooo00?o00000?ooo`3oool03@3oool20<b]^`030474b@3>[kX0cZnj00?o0000
0P37UjD00`3A/KX0b9NT0<RGY0020<RGY0030<:>WP39V:@0bIRT0080bIRT0P33SYh30<ZIX`80`hjN
0P3;VJ<30<B?W@030<bJX`35Sid0aHnM00<0aHnM1@35T9d40<J@W@030<2;W@37TId0ai6M0080ai6M
00<0`HbM0<RBW@38TYd00P38TYd01031S9d0b9>N0<RCWP38Tih20<:=W@<0bIBN00@0`XjN0<ZEWP3:
UIh0bYFN0P33SYh30<^FW`040<B?W`3<V:00c9RP0<bHX080a92P0`3<VJ420<FBX@80cIZR0P35Tj84
0<jLX`050<FDX`3>WZD0cYjU0<jNY@36UZ@00`3?WjH00`36UjH0cj6X0<nQZ0020<nQZ0@0d:>[103@
YZd40=2X[`050=g0_03@Z[80d:Zb0=2Z/P3L`kl00`3@[KH20=_5``80cjni0P3JalL01@3?/K`0f<W;
0=S9bol00000c[?00080eL[?00D0cNkZ0=;;d`3Bbm<0d/_C0<W[k0030<o<eP80a^O^0P3<c=T20<;S
k`80b<cL0P2og^l00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo0180oooo0ol0000A0?oo
o`80YKk[00<0YkkZ07P0001hV^L00`2MV]040:bF`0030;:B]P2^Ukh0[YNn00@0]9>d0`2hTJl00`2g
U;<0^Y:]0;ZB[@020;ZB[@80^i2Z0P2lTj`40;bAZ@@0_Y:Y0P2nTJP30<2CZ080`9:W0P32UJP40<6D
Y`@0`iFX1@34UjP40<JIZ@D0ai^Y1039WJ/50<ZO[0@0bj:^00<0d:R`0<fU/03=YK000P3A[;<30<fX
/`80dZnf00@0cZ^f0=>b^@3C/[T0dk:i103C][d0103H`L<0d[W10=:i`@3B^L420=O4a`060=6la@3E
a/`0eLK<0=OCe?l00000dlS@0`3De=T00`3@b]@0d=CL0=3Dg0020<cNiP050<_Cg`38fnP0b=_X0<SK
j037d^800`33f>T01@33d>@0_mCZ0;oDjP2ienoo00000100oooo000:0?ooo`03o`00003oool0oooo
00l0oooo0ol000020<j_^P80aiNU0P3A/KX40<RGY0D0bIRT00<0`hjN0<ZIX`3:VJ<00P3:VJ<20<>>
WP80biVS0`34Sid00`3<VZ<0aHnM0<F?W@030<F?W@D0aI2M1036T9d00`30Rid0ai6M0<NAW@020<NA
W@030<6<W@38TYd0b9:M0080b9:M00<0`HbM0<RCWP38Tih00P38Tih01@32SId0bIBN0<VDWP39U9h0
`XjN00<0bYFN0P33SYh30<^FW`040<B?W`3<V:00c9RP0<bHX080a92P103<VJ401@35TZ40cIZR0<fJ
XP3=VZ80aI>R00@0cYbS103>WZD01036UZ@0cinV0<nOYP3?WjH50<nQZ0@0d:>[103@YZd00`3N_[T0
d:R_0=2X[`020=g0_080d:Zb0`3L`kl01@3@[KH0flG30=_5``3KaL<0cjni0080f/O700L0eOCT0=S9
b`3HbL/0f<W;0=7aiol00000eL[?00<0cNkZ00D0d/_C0<W[k039jn`0bN_/0<o<eP020<KWkP80T>[f
0P32hnl209WXn`80_mk_0P2OiO`00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo00l0oooo
0ol0000F0?ooo`80YkkZ0P05M]l309fJd080[9K000@0X9c@0:jG_P2^Ukh0[YNn102dTk@20;RA[`80
]iBc102jTZd0102kT:X0_9>/0;bC[02lTj`40;bAZ@@0_Y:Y00<0_Y6X0<2CZ030TjP00P30TjP01030
TZL0`YFX0<:EZ032UJP30<6DY`030<BGZ033UJP0`iFX0080`iFX00<0aYVX0<BGZ034UjP00P34UjP0
1@37VjT0aYVY0<JIZ@36VJT0bIfZ00@0ai^Y00D0bin[0<VMZ`39WJ/0bIf[0<fR[@030<ZO[080cjF^
0P3;XZh20=2X/080cJF`0`3A[;<0103=Z;<0dZnf0=:_]P3B[kH40=>b^@030=Rm_`3C][d0dkJm00<0
f<7300H0d[W10=O4a`3Ga<L0elC70=[Bd03Ea/`30=OCe003o`00003De=T0e=CI0080dN7S00<0d=CL
0<cNiP3<g^H00P34i^l20<SKj080`>7_0P33f>T20;gLk`050;oDjP2ienl0^MO_0;WGkol000003`3o
ool000X0oooo00?o00000?ooo`3oool0303oool3o`0000030?ooo`11a<T0cZnj0080cZnj00<0aiNU
0=6a^P3A/KX00P3A/KX30<RGY0D0bIRT00<0`hjN0<ZIX`3:VJ<00P3:VJ<01033SYh0biVS0<^IX`3;
VJ<30<B?W@030<bJX`35Sid0aHnM0080aHnM00<0cY^S0<F@W@35T9d00`35T9d40<J@W@D0ai6M1@38
TYd50<RCWP050<:=W@39U9h0bIBN0<VDWP32SYh0103:UIh01@33SYh0biJO0<^FW`3;UYl0a8nO00@0
c9RP00<0a92P0<bIX@3<VJ400P3<VJ440<fJXP030<FCXP3>W:<0cYbS0080cYbS103>WZD40<nOYP03
0=ff/03?XJP0cj6X0080cj6X0`3@Xj/20=jk]P80d:J]0P3N_[T20=2X[`<0gL2l00@0d:Zb0=c3_`3L
`kl0g<>o0`3KaL<20=Wfh0050=[7a`3Em>@0eOCT0=Gdi03HbL/00P3AlNL0101IdL?o00000<g^jP3=
k^X2073Pf`80bN_/00<0P^S/02Nba@0W//D00P2@j_H204c9i080VNSk0P1YeOD209oUo0030?ooool0
0000oooo01H0oooo00?o00000?ooo`3oool0303oool3o`0001X0oooo0P2X_NT200Efg`80MigY102P
W=030:jG_P<0]9>d00@0^96_0;ND/`2gU;<0]iBc102jTZd50;bC[080_96Y00<0_YB/0;jBZ@2nTZT0
0P2nTZT50<2CZ0030<2BY`32UJP0`YFX0080`YFX00@0`IBW0<BGZ034UjP0a9NX0P33UJP20<JIZ0<0
a9NX0P37VjT20<JIZ@80bIfZ0`37VjT20<^OZ`80bIf[0P3=XZd30<ZO[080cjF^00<0bj:^0=2X/03@
Z;000P3@Z;00103=YK00dJbc0=6//`3A[;<40=:_]P030=Ri^`3C/[T0dk:i00<0f;fo00@0dkJm0=S1
``3H`L<0f<730`3Ga<L20=[Bd0<0em?D0P3Fhn000ol00000dN7S0=7Qh`020<S/k@030<cNiP34i^l0
a>K_0080]n[f0P30hNl20;OTmP80_Mc_0P2egO@20;WGk`030?ooool00000oooo00h0oooo000:0?oo
o`03o`00003oool0oooo00T0oooo0ol000050?ooo`80cZnj00<0oooo0=6a^P3A/KX00`3A/KX20<RG
Y080dk>i1039V:@50<ZIX`040<>>WP3;VJ<0biVS0<^IX`80a8nM0`3<VZ<30<F?W@030<jKX`35T9d0
aI2M0080aI2M00<0cifS0<J@W@36T9d00P36T9d50<NAW@D0b9:M1@38Tih40<VDWPD0bYFN103;UYl5
0<bHX0D0c9VQ103=VZ850<jLX`@0cYjU00<0g;>^0<nOYP3?WjH00P3M][030<nQZ080gKRc00D0d:>[
0=jk]P3N^kH0g[^f0=2V[@040=jn^@040=2X[`3M`;`0gL2l0=g0_0<0g<>o0P3Mmm`00`3KaL<0fOKP
0=Wfh00200000080eOCT00<0000009bol@2>`?P00P2>`?P00ol00000Tl3f09?0mP030832o080H/3m
3@3oool00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo00T0oooo0ol0000N0?ooo`040:Rm
j@2X_NP0Z;gX0:Rmj080MigY0`2PW=030:jG_P80]9>d00<0/IRm0;ND/`2gU;<00`2gU;<20;ZB[@80
^YJb102lTj`0102lTJT0_YB/0;jD[02nU:`30;jBZ@030<2FZ`30TjP0`9>X0080`9>X1@32UJP01@31
U:L0a9NX0<BGZ034UjP0`iFX00<0aYVX0`34UjP20<NKZ@80aYVY0P39WJX30<NKZ@80bin[0P39WJ/2
0<fR[@80bYn/0`3?YJh00`3;XZh0d:R`0=2X/0020=2X/0@0dJbc00<0ekJh0=:_]P3B[kH00`3H^K/0
103C/[T0f;fo0=Rm_`3H_Kl30=S1``80g=3<00<0elC70=[Bd03Jd]000P3Ji=d01P3Gdm@0e^?P0=KS
h03<l>_o00000=7Qh`80b>c]0P2gl?@00`34i^l0]n[f0;OZmP020:WYnP80]nCf0P2/h_T20;GMm0@0
oooo00?o00000?ooo`3oool03@3oool000X0oooo00?o00000?ooo`3oool01P3oool3o`0000`0oooo
103A/KX01038Uj@0dk>i0=>c^@3C/kT40<VHY0D0bYVS00<0`hjN0<^IX`3;VJ<00P3;VJ<01034Sid0
c9ZS0<bJX`3<VZ<20<F?W@<0cY^S0`35T9d0103?WJ<0aY2M0<J@W@36T9d20=2NX`@0ai6M1@38TYd5
0<RCWP@0bIBN1@3:UIh40<^FW`D0c9RP1@3<VJ440<fJXP050=^^ZP3>W:<0cYbS0<jLX`3L/J`00`3>
WZD20=bc[P80cinV0P3M][020<nQZ0<0gKRc00D0d:>[0=jk]P3N^kH0g[^f0=2V[@040=jn^@<0gL2l
0P3PmmP00`3L`kl0gOOL0=ggg0020::nk@030=Wfh02S_^`0Xkk/0080Xkk/0P2L_o400`2T_^`0W[o_
09jok`0209jok`03o`00003oool0oooo0140oooo00?o00000?ooo`3oool05@3oool00ol00000oooo
0?ooo`060?ooo`?o00008P3oool20:Rmj0040:Vmj02X_NT006_B001[dP80X9c@0`2^Ukh0102dTk@0
/IRm0;6H_@2aV;d40;ND/`040;ZB[@2jU[80^YJb0;ZF/P@0_9>/102nU:`20;jBZ@80`9J[1030TjP0
0`32Uj/0`YFX0<:EZ0020<:EZ0@0a9NX00<0`iFX0<JIZ036VJP00P36VJP00`34UjP0ai^Y0<NKZ@02
0<NKZ@050<JIZ@39WJX0bIfZ0<VMZP37VjT0103;Wj/01@39WJ/0cJ:]0<fR[@3=XZd0bYn/00<0cjF^
1@3@Z;030=6//`80ekJh00<0dZnf0=Ri^`3H^K/00P3H^K/30=Rm_`80gLg800<0f<730=c@c03Ld<`0
0P3MhmT01P3Jd]00f^CM0=[Tg@3Ji=d0coCX0=KSh080c?3[00<0]_Gao`000038k>d00P2gl?@20:C^
n0030;OZmP2YjOX0ZNWj0080WnCl0P2/h_T70?ooo`03o`00003oool0oooo00d0oooo000:0?ooo`03
o`00003oool0oooo00<0oooo0ol0000@0?ooo`80dK6j00<0oooo0=>c^@3C/kT00P3C/kT30<VHY080
e[Ji103:VJ<50<^IX`040<B?W@3<VZ<0c9ZS0<bJX`80aHnM0`3>Vj<20<F@W@<0cifS0P36T9d20=2N
X`<0ai6M0P3AWj<30<RBW@030=:QX`38Tih0b9>N00<0b9>N1039U9h50<ZEWP@0biJO1@3<V:001@3I
ZZL0c9VQ0<bIX@3<VJ40fZbX00<0cIZR0P3K[ZX30<jLX`80g;6/0P3>WZD20=bc[P80cinV0`3M][00
103?XJP0gKRc0=fh/`3M^;<40=jk]P040>Ogd03N_[T0g[ji0=jn^@80i?OD00@0gL2l0>3gf03PmmP0
Z;gY0P2V_NX20:Rmj@<0YkgZ0P2S_^`20:Nmj@<0Y;k/0P2N_nl20?ooo`03o`00003oool0oooo0100
oooo00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`030?ooo`?o00009P3oool30:Vmj003
0:Rmj@00Jm80Mj7/0080Mj7/00<0[YNn0:BNd02aV;d00`2aV;d40;ND/`@0^YJb102lTj`40;jD[004
0;jBZ@30UZ/0`9J[0<2FZ`<0`9>X0P32Uj/40<:EZ0@0a9NX1@36VJP00`34UjP0ai^Y0<NKZ@020<NK
Z@@0bIfZ00<0ai^Y0<^OZ`3;Wj/00P3;Wj/40<fR[@@0cjF^00@0e:jb0=2X/03@Z;00d:R`0P3F/[D0
103A[;<0ekJh0=Nf^03G][P50=Ri^`030=k9a03H_Kl0gLg80080gLg800<0h>;E0=c@c03MhmT00P3M
hmT20=;gi@040=[Tg@3?m>P0coCX0;;ik080R>cS00<0]_Ga09W`lOl000000P22i_40102Tk_P0U>Sj
08gRo@2=h_d209oTo0X0oooo00?o00000?ooo`3oool03@3oool000T0oooo00Co00000?ooo`3oool0
oooo0ol0000G0?ooo`@0dk>i00@0bIRT0=Jf^@3F][T0e[Ji103:VJ<50<^IX`@0c9ZS00<0aHnM0<jK
X`3>Vj<00P3>Vj<20<F@W@<0cifS0P36T9d20=2NX`<0ai6M0P3AWj<30<RBW@030=:QX`38Tih0b9>N
0080b9>N00@0e::T0<VDWP39U9h0bIBN0P3EY:@30<ZEWP040=JVY@3;UYl0biJO0<^FW`80ejRV0`3<
V:020=VZY`<0c9VQ0P3J[:P20<fJXP80fjjZ0P3>W:<30=ba[0030<jNY@3L/jh0g;>^0080g;>^103M
][040=fh/`040>Wec@3N^kH0g[^f0=jk]P80ioO@00<0g[ji0>Cge03Tmm@00`2Y_NP01@2X_NT0ZKgX
0:Vmj02Y_NP0Z;gY0080ZKgX0`2X_NP20:Nmj@T0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0D0?ooo`04o`00003oool0oooo0?ooo`?o0000:P3oool50:Vmj080Mj7/0`2TW]030;6H
_@<0]iBc0P2eV[d40;ZF/P80_9>/00<0_9Na0;jD[02nU:`00P2nU:`50<2FZ`040<2CZ032Uj/0`YN[
0<:GZ`<0`YFX00<0aIV[0<BGZ034UjP00P34UjP00`37W:/0aYVX0<JIZ0020<JIZ0D0ai^Y1039WJX5
0<^OZ`@0cJ:]00<0dZ^`0<nU[P3?YJh00P3D[[820=2X/0<0e[:e00D0dJbc0=Nf^03G][P0ekJh0=k5
`@030=Ri^`80g/W40`3McLP20>3Re@80eOWR00<0gN?I0=;gi@3BmnD00P2/nN<01P3?m>P0/_W/08S/
h`28k><0I]_K05WBg`80G]?]00?o000007WOm01lg?/03`3oool00ol00000oooo0?ooo`0=0?ooo`00
2@3oool4o`0001/0oooo0`3C/kT01039V:@0e[Ji0=Jf^@3F][T30<ZIX`030=Rh^@3;VJ<0biVS00<0
biVS103<VZ<00`35Sid0cY^S0<jKX`020<jKX`030<F@W@3?WJ<0cifS0080cifS00@0aY2M0=2NX`3@
WZ<0d9jS0`37TId20=6OX`<0b9:M0P3BXJ<30<RCWP040=BRY039U9h0bIBN0<VDWP80eJBT0`3:UIh2
0=JVY@80biJO0P3GZ:H30<bHX080fJZW0P3<VJ430=Z/Z0030<fJXP3K[ZX0fjjZ0080fjjZ00D0cYbS
0=ba[03L/J`0g;6/0<jNY@040=bc[P@0gKJ`00<0k??:0=fh/`3M^;<00`3YmLd00`3N^kH0ioO@0>Og
d00?0:Vmj0030:Rmj03oool0oooo00X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`0D0?ooo`Co0000;`3oool40:Vmj080Mj7/0P2TW]040;6H_@040;ND/`2eV[d0]IZm0;FJ_@@0^YJb
00@0_9>/0;bG/@2lUk40_9Na0`2nU:`00`2oVK40`9J[0<2FZ`020<2FZ`030<2CZ032Uj/0`YN[0080
`YN[00@0`YFX0<FIZ`35VJ/0aIV[0P34UjP20<NLZ`@0aYVX00<0bIj/0<NKZ@37VjT00P37VjT40<VM
ZP040<jT[P3;Wj/0bin[0<^OZ`80d:N_0P3=XZd20=:[/080cjF^0`3D[[801@3@Z;00e[:e0=Jb]@3F
/[D0gL6m0080ekJh0`3NaL401P3H^K/0g/W40=k9a03NbL@0h^3B0=g=b080h>;E0P3EnN820:Cgf005
0=;gi@2/nN<0[?WS077Pc@17`nX00P1]cod306[An`80KmKj00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0=0?ooo`002@3oool2o`000200oooo1@3F][T0103:VJ<0f;Ri0=Rh^@3H^;T30<^I
X`030=^k^@3<VZ<0c9ZS0080c9ZS1@3>Vj<00`35T9d0cifS0<nMX`020<nMX`040<J@W@3@WZ<0d9jS
0=2NX`80ai6M0`3AWj<20<RBW@<0dZ6S0P38Tih30=BRY080bIBN0P3EY:@30<ZEWP80eZJU00@0biJO
0=NXYP3GZ:H0ejRV0P3<V:040=VZY`050<bIX@3J[:P0fZbX0=Z/Z03=VZ80103K[ZX0103>W:<0g;6/
0=ba[03L/J`50=bc[P030>kaa`3M][00gKJ`0080k??:00@0gKRc0>Wec@3YmLd0jOG=4P2Y_NP?0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool04`3oool2o`000340oooo1@2Y_NP01000
G[l0Y9k@0:BNd02TW]020;6H_@030:RRd02eV[d0]IZm0080]IZm102jU[840;bG/@80_YB/0P2oVK44
0<2FZ`D0`YN[00D0`YFX0<FIZ`35VJ/0aIV[0<BGZ0030<NLZ`<0aYVX0P39WZ`30<NKZ@80c:6/0P39
WJX20<jT[P<0bin[0P3@Yjl00`3=XZd0dZ^`0=:[/0020=:[/0040<nU[P3D[[80e:jb0=B^/P@0e[:e
0P3M`Kd0103G][P0g/G10=k5`@3NaL430=k9a080h^3B00@0f?[N0>3Re@3EnN80eOWR0P2TmmP0101D
bjl0Olco07C=o`1dcOl:0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0303oool0
00/0oooo00?o00000?ooo`3oool07P3oool40=Jf^@040<ZIX`3H^;T0f;Ri0=Rh^@80biVS0`3K^kT3
0<bJX`030=fn^@3>Vj<0cY^S0080cY^S1@3?WJ<00`36T9d0d9jS0=2NX`020=2NX`030<NAW@3AWj<0
dInS0080dInS00@0b9:M0=:QX`3BXJ<0dZ6S0P38Tih30=BRY0040<VDWP3EY:@0eJBT0=FTY080bYFN
0`3FYZD00`3;UYl0ejRV0=NXYP020=NXYP030<bHX03IZZL0fJZW0080fJZW00D0c9VQ0=Z/Z03J[:P0
fZbX0<fJXP040=^^ZP@0g;6/00@0knk50=bc[P3L/jh0g;>^0P3^lLL00`3M][00k??:0>ccbP0D0:Vm
j1<0oooo00?o00000?ooo`3oool03P3oool00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo
02l0oooo1P2Y_NP207RWl0@0Z:;@102eV[d20;ZF/P030;VM_02lUk40_9Na0080_9Na00@0_YB/0;nI
/@2oVK40_iVa1030UZ/00`32W;40`YN[0<:GZ`020<:GZ`@0aIV[00<0a9NX0<NLZ`37W:/00P37W:/0
1036VJP0bIj/0<VN[039WZ`20<NKZ@<0c:6/00@0bIfZ0<jT[P3>Y:h0cZB^0P3;Wj/30=2W[`030<fR
[@3BZk00dZ^`0080dZ^`103D[[800`3K_K/0e[:e0=Jb]@030=g1_@<0g/G10P3TgLl00`3NbL@0h^3B
0>;PdP020=SjgP0409_bc0000000RLWm08W9oA00oooo00?o00000?ooo`3oool03P3oool00ol00000
oooo0?ooo`0<0?ooo`00303oool00ol00000oooo0?ooo`0N0?ooo`80e[Ji0P3oool30=Rh^@80biVS
0`3K^kT20<bJX`80gKji103>Vj<50<nMX`D0d9jS00<0ai6M0=6OX`3AWj<00P3AWj<01@38TYd0dZ6S
0=:QX`3BXJ<0b9>N00@0e::T00<0bIBN0=FTY03EY:@00P3EY:@01@3:UIh0eZJU0=JVY@3FYZD0biJO
00@0ejRV00<0c9RP0=VZY`3IZZL00P3IZZL40=Z/Z0D0fjjZ00<0l>c30=ba[03L/J`00`3_k/D00`3L
/jh0k_770>kaa`0B0:Vmj1X0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0F0?oo
o`03o`00003oool0oooo0300oooo1@2Y_NP207RWl0<0Z:;@102eV[d0102jU[80^Ifl0;VM_02iWK`3
0;bG/@D0_iVa0P30UZ/20<:L/@@0`YN[1035VJ/50<NLZ`030<JIZ039WZ`0bIj/0080bIj/00D0ai^Y
0<bQ[03<XJ`0c:6/0<VMZP040<jT[P040<^OZ`3@Yjl0d:N_0=2W[`D0dZ^`00<0fKVh0=B^/P3D[[80
0P3K_K/00`3F/[D0gL6m0=g1_@020=g1_@040>CJc03NaL40i=g?0>CMc`80f_[L00@0h^3B0=SjgP3H
n]h0Vo;<5@3oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo00`0oooo000=0?ooo`03
o`00003oool0oooo0280oooo0P3H^;T00`3;VJ<0fk^i0=^k^@020=^k^@040<bJX`3M_[T0gKji0=fn
^@<0cY^S0P3P`[T40<nMX`030>?5^P3@WZ<0d9jS0080d9jS1@3AWj<40=:QX`030<RCWP3DXZ@0e::T
0080e::T00<0bIBN0=FTY03EY:@00P3EY:@0103:UIh0eZJU0=JVY@3FYZD50=NXYPD0fJZW103J[:P0
103aj<40fjjZ0=^^ZP3K[ZX20?3/``040=ba[03_k/D0knk50>o^aA@0ZKgX703oool00ol00000oooo
0?ooo`0=0?ooo`03o`00003oool0oooo01L0oooo00?o00000?ooo`3oool0;`3oool70:Vmj004001@
Y`2XX]00Z:;@0:RRd080]IZm00<0[JOA0;VM_02iWK`00P2iWK`20;bG/@80_:2l102oVK401030UZ/0
`Yba0<:L/@32W;430<:GZ`030<FN/@35VJ/0aIV[0080aIV[00<0b::a0<NLZ`37W:/00P37W:/50<VN
[0@0c:6/1@3>Y:h40=2W[`040=Nd]P3BZk00dZ^`0=:[/080fKVh00D0e:jb0=^m^`3K_K/0fkfk0>?F
b@030=g1_@80i=[<00<0gO[J0>CMc`3Jn]`00P3Jn]`00`2Ak;l0oooo0?ooo`0F0?ooo`03o`00003o
ool0oooo00d0oooo00?o00000?ooo`3oool0303oool000h0oooo0_l0000U0?ooo`@0fk^i00<0c9ZS
0=fn^@3M_[T00P3M_[T0103>Vj<0h<:i0>32^@3P`[T30<nMX`80hlFj103@WZ<50=6OX`@0dZ6S1@3D
XZ@50=FTY0@0eZJU00<0kmfn0=NXYP3GZ:H00P3GZ:H0103`hKl0fJZW0=VZY`3IZZL20?7T`080fZbX
0`3aj<400`3K[ZX0l>c30?3/``030:Vmj0030>o^a@2Y_NP0ZKgX0100ZKgX803oool00ol00000oooo
0?ooo`0<0?ooo`03o`00003oool0oooo01P0oooo0_l0000`0?ooo`P0ZKgX0P1i[_@30:fWd@@0^Ifl
00@0_9Na0;bP_02lX;`0_:2l102oVK450<:L/@040<:GZ`35W[40aIja0<FN/@80aIV[0P38X[440<NL
Z`030<bU/@39WZ`0bIj/0080bIj/103<XJ`00`3A[;<0cZB^0<jT[P020<jT[P<0d:N_0P3G];H20=:[
/0<0fKVh103K_K/20>?Fb@040=g1_@3Tf/`0i=[<0=gjfP<0QnJe00<0f_[L0?ooo`3oool06@3oool0
0ol00000oooo0?ooo`0<0?ooo`03o`00003oool0oooo00`0oooo000@0?ooo`03o`00003oool0oooo
02<0oooo0P3K^kT20?ooo`@0gKji00@0cY^S0>32^@3P`[T0h<:i0`3?WJ<20>?5^P<0d9jS00<0iLVj
0=6OX`3AWj<00P3AWj<00`3XcK/0dZ6S0=:QX`020=:QX`030>[@^`3DXZ@0e::T0080e::T00<0k=Bl
0=FTY03EY:@00P3EY:@30=JVY@80kmfn0`3GZ:H20?3Q_`80fJZW0`3ai<00103J[:P0lNS10?7X`@3a
j<420:Vmj0030?3/``2Y_NP0ZKgX0180ZKgX903oool00ol00000oooo0?ooo`0;0?ooo`03o`00003o
ool0oooo01X0oooo00?o00000?ooo`3oool0;`3oool70:Vmj080NJkd0`2]Ym420;VM_0030;:/dP2l
X;`0_:2l0080_:2l0`2oVK420<6T_0@0`Yba00D0`YN[0<FN/@35W[40aIja0<FIZ`030<RR/@<0aib[
0P3<YK430<VN[080cjRb0P3<XJ`20=6//`<0cZB^0P3D/;D00`3@Yjl0ekBf0=Nd]P020=Nd]P050=:[
/03I^KP0fKVh0=Vi^03RdLH00P3K_K/30>?Fb@030=kif@3Tf/`0gO[J00<0QnJe7P3oool00ol00000
oooo0?ooo`0;0?ooo`03o`00003oool0oooo00`0oooo000A0?ooo`03o`00003oool0oooo02L0oooo
0P3M_[T20?ooo`@0h<:i00<0cifS0>?5^P3SaKX00P3SaKX0103@WZ<0iLVj0>G9^P3UbKX20=6OX`<0
j<fk0P3BXJ<20>[@^`<0e::T0P3/e;`30=FTY080k]Vm0P3FYZD20>oM_P80ejRV103`hKl00`3IZZL0
lNC00?7T`0030:Vmj0030?7X`@2Y_NP0ZKgX0140ZKgX:P3oool00ol00000oooo0?ooo`0:0?ooo`03
o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0;`3oool80:Vmj0<0[JOA00@0^Ifl0;:/dP2b
[=80/ZcB102lX;`0102oVK40`JBl0<6T_031Y;`40<:L/@@0aIja00<0aIV[0<RR/@38X[400P38X[40
1037W:/0c:Fa0<bU/@3<YK420<VN[0<0cjRb00@0c:6/0=6//`3A[;<0dJbc0P3>Y:h30=B`]@030=2W
[`3G];H0ekBf0080ekBf0`3I^KP20>;AaP060=^m^`3Se/T0hmK90>?Fb@3NnMT0On2]903oool00ol0
0000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00`0oooo000B0?ooo`03o`00003oool0oooo02/0
oooo0`3P`[T00`3?WJ<0hlFj0>?5^P020>?5^P040=2NX`3UbKX0iLVj0>G9^P80dInS0`3XcK/0103B
XJ<0j]2k0>[@^`3Zd;/20=BRY0<0k=Bl0P3EY:@30>kI_@030=JVY@3_gKh0kmfn0080kmfn00@0ejRV
0?3Q_`3`hKl0l>6o0P2Y_NP00`3ai<00ZKgX0:Vmj00D0:Vmj2`0oooo00?o00000?ooo`3oool02`3o
ool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo02l0oooo2@2Y_NP207^hn@<0/ZcB0`2l
X;`00`2h/m@0`JBl0<6T_0020<6T_0<0`Yba00<0aJRl0<FN/@35W[400P35W[450<RR/@030<NLZ`3<
YK40c:Fa0080c:Fa00D0bIj/0<nX/P3?Z;80cjRb0<bQ[0040=6//`040<jT[P3D/;D0e;2e0=B`]@D0
ekBf00<0h<c40=Vi^03RdLH00P3RdLH20>3ff@030>?Fb@3NnMT0On2]02D0oooo00?o00000?ooo`3o
ool02`3oool00ol00000oooo0?ooo`0;0?ooo`004`3oool2o`000300oooo0P3SaKX20:Vmj0<0iLVj
00<0dInS0>S=^`3XcK/00P3XcK/00`3BXJ<0j]2k0>[@^`020>[@^`030=BRY03/e;`0k=Bl0080k=Bl
00D0eJBT0>kI_@3^fKd0k]Vm0=JVY@030>oM_P<0ZKgX00<0l>6o0:Vmj02Y_NP05@2Y_NP`0?ooo`03
o`00003oool0oooo00X0oooo00?o00000?ooo`3oool0703oool2o`000300oooo2P2Y_NP01@1T0000
/ZcB0;:/dP2b[=80_:2l00<0^;?D1031Y;`01032W;40aJRl0<FX_035Z;`30<FN/@030<V/_@38X[40
b::a0080b::a1@3<YK440<nX/PD0dJbc103D/;D0103Ma/<0ekBf0=Nd]P3G];H20>3<a0060>7cfP3R
dLH0h]760>;AaP3Pm]T0NMbX:@3oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00/0
oooo000E0?ooo`03o`00003oool0oooo02l0oooo0`2Y_NP0103UbKX0ZKgX0:Vmj02Y_NP20>S=^`<0
ZKgX0P3Zd;/30:Vmj080k=Bl0P2Y_NP20>kI_A/0ZKgX=P3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo01h0oooo00?o00000?ooo`3oool0;`3oool:0:Vmj080O/?m102h/m@30<6T_003
0;jjeP35Z;`0aJRl0080aJRl0P35W[420<V/_@@0b::a00<0cK6n0<bU/@3<YK400P3<YK440<nX/P03
0=Jk`03A[;<0dJbc0080dJbc00<0fL710=B`]@3D/;D00`3Ma/<00`3G];H0h<c40>3<a0030>7cfP03
0>;AaP3Pm]T0oooo02/0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0;0?ooo`00
5P3oool00ol00000oooo0?ooo`0^0?ooobl0ZKgX>P3oool00ol00000oooo0?ooo`080?ooo`03o`00
003oool0oooo01l0oooo00?o00000?ooo`3oool0;P3oool;0:Vmj080O/?m102h/m@00`31Y;`0_[[F
0;jjeP040<FX_0040<FN/@39[;d0bJbm0<V/_@<0b::a0P3=/Kh30<bU/@80d[Jn0P3?Z;820=Jk`0<0
dJbc0P3I`L400`3D/;D0gLK30=g6``020=g6``030>3^fP3Pc<@0hO?J0080hO?J00<0MMZX0?ooo`3o
ool0;@3oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo00/0oooo000G0?ooo`03o`00
003oool0oooo02h0oooo;02Y_NPl0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool0
803oool00ol00000oooo0?ooo`0^0?ooo`d0ZKgX0P2h/m@00`20col0_[[F0;jjeP020;jjeP80aJRl
00<0aL;G0<V/_@39[;d00`39[;d00`38X[40cK6n0<fa_P020<fa_P050<bU/@3B][h0d[Jn0=:f_P3?
Z;80103F^l001@3A[;<0fL710=W1`@3I`L40g^WK00<0gLK300D0h>kJ07?J[01cfZ`0LmZ/0>7cfP0a
0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool02`3oool001P0oooo0_l0000`0?oo
obL0ZKgX@03oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo0240oooo0_l0000`0?oo
o``0ZKgX0`20col30;jjeP040<FX_035`]L0aL;G0<G2e`<0bJbm00<0bl[I0<fa_P3=/Kh00`3=/Kh4
0=:f_P050=KJf`3F^l00e[_00=Jk`03Kh]/00`3I`L430=kYf`030=g6``3Pk]X0oooo03H0oooo00?o
00000?ooo`3oool01`3oool00ol00000oooo0?ooo`0;0?ooo`006P3oool00ol00000oooo0?ooo`0]
0?ooob80ZKgXAP3oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo0280oooo00?o0000
0?ooo`3oool0;@3oool?0:Vmj080_[[F0P22fOh40<G2e`040<V/_@3;b]T0bl[I0<_:f@<0cK6n0P3A
d]X20=:f_P<0e][K00D0e[_00=_Rf`3Kh]/0fn;K0=W1`@030=kYf`0307CM]03oool0oooo03P0oooo
00?o00000?ooo`3oool01`3oool00ol00000oooo0?ooo`0:0?ooo`006`3oool00ol00000oooo0?oo
o`0]0?oooal0ZKgXB@3oool00ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo02<0oooo00?o
00000?ooo`3oool0;@3ooolC0:Vmj080aL;G0P23h_T40<_:f@050<fa_P3Ad]X0dM;J0=7BfP3B][h0
0`3Ff]/207[Ud080fn;K0P1fhL4o0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool0
2P3oool001`0oooo00?o00000?ooo`3oool0;P3ooolH0:Vmj4h0oooo00?o00000?ooo`3oool01P3o
ool00ol00000oooo0?ooo`0T0?ooo`03o`00003oool0oooo02h0oooo5P2Y_NP20<_:f@80PNK^0P3A
d]X307kWg`030=KJf`1jiM00N^G@04@0oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?oo
o`0:0?ooo`007@3oool00ol00000oooo0?ooo`0^0?oooa@0ZKgXDP3oool00ol00000oooo0?ooo`05
0?ooo`03o`00003oool0oooo02D0oooo00?o00000?ooo`3oool0;P3ooolD0:Vmj580oooo00?o0000
0?ooo`3oool01@3oool00ol00000oooo0?ooo`0:0?ooo`007P3oool2o`0002l0oooo4@2Y_NQE0?oo
o`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool09P3oool2o`0002h0oooo4P2Y_NQE0?oo
o`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool02P3oool00200oooo00?o00000?ooo`3o
ool0;@3oool;0:Vmj5X0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0X0?ooo`03
o`00003oool0oooo02`0oooo302Y_NQJ0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3o
ool02P3oool00240oooo00?o00000?ooo`3oool0;@3oool80:Vmj5d0oooo00?o00000?ooo`3oool0
0`3oool00ol00000oooo0?ooo`0Y0?ooo`03o`00003oool0oooo02d0oooo1`2Y_NQN0?ooo`03o`00
003oool0oooo00<0oooo00?o00000?ooo`3oool02P3oool00280oooo00?o00000?ooo`3oool0;@3o
ool40:Vmj640oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0Y0?ooo`03o`00003o
ool0oooo02d0oooo102Y_NQQ0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool02@3o
ool002<0oooo0_l0000]0?ooo`03o`00003oool0oooo06<0oooo00?o00000?ooo`3oool00P3oool0
0ol00000oooo0?ooo`0Z0?ooo`;o0000;@3oool00ol00000oooo0?ooo`1S0?ooo`03o`00003oool0
oooo0080oooo00?o00000?ooo`3oool02@3oool002D0oooo00?o00000?ooo`3oool0:P3oool00ol0
0000oooo0?ooo`1S0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool0;03oool00ol0
0000oooo0?ooo`0Z0?ooo`03o`00003oool0oooo06<0oooo00?o00000?ooo`3oool00P3oool00ol0
0000oooo0?ooo`090?ooo`009P3oool00ol00000oooo0?ooo`0Y0?ooo`03o`00003oool0oooo06@0
oooo00Go00000?ooo`3oool0ooooo`00000_0?ooo`03o`00003oool0oooo02T0oooo00?o00000?oo
o`3oool0I03oool01Ol00000oooo0?ooo`3ooooo000000/0oooo000W0?ooo`03o`00003oool0oooo
02P0oooo00?o00000?ooo`3oool0I@3oool01?l00000oooo0?ooool0000`0?ooo`03o`00003oool0
oooo02P0oooo00?o00000?ooo`3oool0I@3oool01?l00000oooo0?ooool0000;0?ooo`00:03oool2
o`0002P0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00000a0?ooo`;o0000:03oool0
0ol00000oooo0?ooo`1V0?ooo`03o`00003ooooo000000/0oooo000Z0?ooo`03o`00003oool0oooo
02D0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00000c0?ooo`03o`00003oool0oooo
02D0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00000;0?ooo`00:`3oool00ol00000
oooo0?ooo`0T0?ooo`03o`00003oool0oooo06L0oooo00?o00000?ooool00000<`3oool00ol00000
oooo0?ooo`0T0?ooo`03o`00003oool0oooo06L0oooo00?o00000?ooool000002P3oool002`0oooo
00?o00000?ooo`3oool08`3oool00ol00000oooo0?ooo`1X0?ooo`;o0000=03oool00ol00000oooo
0?ooo`0S0?ooo`03o`00003oool0oooo06P0oooo0_l0000:0?ooo`00;@3oool2o`0002<0oooo00?o
00000?ooo`3oool0I`3oool3o`0003D0oooo0_l0000S0?ooo`03o`00003oool0oooo06L0oooo0ol0
000:0?ooo`00;`3oool00ol00000oooo0?ooo`0P0?ooo`03o`00003oool0oooo06<0oooo1?l0000j
0?ooo`03o`00003oool0oooo0200oooo00?o00000?ooo`3oool0H`3oool4o`0000d0oooo000`0?oo
o`03o`00003oool0oooo01l0oooo00?o00000?ooo`3oool0H03oool3o`0003l0oooo00?o00000?oo
o`3oool07`3oool00ol00000oooo0?ooo`1P0?ooo`?o00004@3oool00340oooo00?o00000?ooo`3o
ool07P3oool00ol00000oooo0?ooo`1L0?ooo`Co0000@`3oool00ol00000oooo0?ooo`0N0?ooo`03
o`00003oool0oooo05`0oooo1?l0000D0?ooo`00<P3oool2o`0001h0oooo00?o00000?ooo`3oool0
F03oool4o`0004P0oooo0_l0000N0?ooo`03o`00003oool0oooo05P0oooo1?l0000H0?ooo`00=03o
ool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo05@0oooo1?l0001>0?ooo`03o`00003o
ool0oooo01/0oooo00?o00000?ooo`3oool0E03oool4o`0001`0oooo000e0?ooo`03o`00003oool0
oooo01X0oooo00?o00000?ooo`3oool0D@3oool3o`0005<0oooo00?o00000?ooo`3oool06P3oool0
0ol00000oooo0?ooo`1A0?ooo`?o0000803oool003H0oooo00?o00000?ooo`3oool06@3oool00ol0
0000oooo0?ooo`1=0?ooo`Co0000E`3oool00ol00000oooo0?ooo`0I0?ooo`03o`00003oool0oooo
04d0oooo1?l0000S0?ooo`00=`3oool2o`0001T0oooo00?o00000?ooo`3oool0B@3oool4o`0005`0
oooo0_l0000I0?ooo`03o`00003oool0oooo04T0oooo1?l0000W0?ooo`00>@3oool00ol00000oooo
0?ooo`0F0?ooo`03o`00003oool0oooo04D0oooo1?l0001R0?ooo`03o`00003oool0oooo01H0oooo
00?o00000?ooo`3oool0A@3oool4o`0002/0oooo000j0?ooo`03o`00003oool0oooo01@0oooo00?o
00000?ooo`3oool0@`3oool3o`0006L0oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?oo
o`130?ooo`?o0000;`3oool003/0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0?ooo`0o
0?ooo`Co0000J`3oool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo03l0oooo1?l0000b
0?ooo`00?03oool2o`0001<0oooo00?o00000?ooo`3oool0>`3oool4o`000700oooo0_l0000C0?oo
o`03o`00003oool0oooo03/0oooo1?l0000f0?ooo`00?P3oool00ol00000oooo0?ooo`0@0?ooo`03
o`00003oool0oooo03L0oooo1?l0001f0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3o
ool0=`3oool4o`0003X0oooo000o0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
<`3oool4o`0007/0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?ooo`Co0000
?P3oool00400oooo00?o00000?ooo`3oool03P3oool00ol00000oooo0?ooo`0`0?ooo`?o0000P03o
ool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo0300oooo0ol000120?ooo`00@@3oool0
0ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo02`0oooo1?l000240?ooo`03o`00003oool0
oooo00d0oooo00?o00000?ooo`3oool0;03oool4o`0004D0oooo00120?ooo`;o00003@3oool00ol0
0000oooo0?ooo`0X0?ooo`Co0000R@3oool2o`0000d0oooo00?o00000?ooo`3oool0:03oool4o`00
04T0oooo00140?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool0903oool4o`0008l0
oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0T0?ooo`Co0000C@3oool004D0oooo
00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0Q0?ooo`?o0000U03oool00ol00000oooo
0?ooo`090?ooo`03o`00003oool0oooo0240oooo0ol0001A0?ooo`00AP3oool00ol00000oooo0?oo
o`080?ooo`03o`00003oool0oooo01d0oooo1?l0002H0?ooo`03o`00003oool0oooo00P0oooo00?o
00000?ooo`3oool07@3oool4o`0005@0oooo00170?ooo`;o0000203oool00ol00000oooo0?ooo`0I
0?ooo`Co0000W@3oool2o`0000P0oooo00?o00000?ooo`3oool06@3oool4o`0005P0oooo00190?oo
o`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool05@3oool4o`000:<0oooo00?o00000?oo
o`3oool01@3oool00ol00000oooo0?ooo`0E0?ooo`Co0000G03oool004X0oooo00?o00000?ooo`3o
ool0103oool00ol00000oooo0?ooo`0B0?ooo`?o0000Z03oool00ol00000oooo0?ooo`040?ooo`03
o`00003oool0oooo0180oooo0ol0001P0?ooo`00B`3oool00ol00000oooo0?ooo`030?ooo`03o`00
003oool0oooo00h0oooo1?l0002/0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0
3P3oool4o`0006<0oooo001<0?ooo`;o00000`3oool00ol00000oooo0?ooo`0:0?ooo`Co0000/@3o
ool2o`0000<0oooo00?o00000?ooo`3oool02P3oool4o`0006L0oooo001>0?ooo`04o`00003oool0
ooooo`0000P0oooo1?l0002g0?ooo`04o`00003oool0ooooo`0000P0oooo1?l0001[0?ooo`00C`3o
ool00ol00000ooooo`0000050?ooo`?o0000_03oool00ol00000ooooo`0000050?ooo`?o0000K`3o
ool00500oooo0_l000000`3ooooo0000o`000002o`000<00oooo0_l000000`3ooooo0000o`000002
o`000780oooo001A0?ooo`;o0000a@3oool2o`0007H0oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-53.3508, \
-19.1129, 1.80794, 1.80794}, {{208.5, 389.375}, {315.688, 169}} -> {-412.962, \
-19.1129, 1.80794, 1.80794}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification in 2d", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, 
        gbase, Axes \[Rule] False, Frame \[Rule] True, \ 
        FrameTicks \[Rule] False, yS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
4e-05 4e-05 m
.00026 4e-05 L
.00045 4e-05 L
.00068 4e-05 L
.00089 4e-05 L
.00109 4e-05 L
.00127 4e-05 L
.00147 4e-05 L
.00169 4e-05 L
.0019 4e-05 L
.00213 4e-05 L
.00235 4e-05 L
.00255 4e-05 L
.00278 4e-05 L
.00291 4e-05 L
.00303 4e-05 L
.00326 4e-05 L
.00349 4e-05 L
.00361 4e-05 L
.00374 4e-05 L
.00397 4e-05 L
.00409 4e-05 L
.00421 4e-05 L
.00434 4e-05 L
.00448 4e-05 L
.0046 4e-05 L
.00473 4e-05 L
.00496 4e-05 L
.00519 4e-05 L
.0054 4e-05 L
.00561 4e-05 L
.0058 4e-05 L
.00601 4e-05 L
.00624 4e-05 L
.00647 4e-05 L
.00671 4e-05 L
.00691 4e-05 L
.00713 4e-05 L
.00727 4e-05 L
.00739 4e-05 L
.00752 4e-05 L
.00766 4e-05 L
.00789 4e-05 L
.00803 4e-05 L
.00815 4e-05 L
.00838 4e-05 L
.00859 4e-05 L
.00871 4e-05 L
.00884 4e-05 L
.00907 4e-05 L
Mistroke
.00921 4e-05 L
.00935 4e-05 L
.00946 4e-05 L
.00959 4e-05 L
.00973 4e-05 L
.00988 4e-05 L
.01001 4e-05 L
.01015 4e-05 L
.01028 4e-05 L
.0104 4e-05 L
.01053 4e-05 L
.01066 4e-05 L
.01089 4e-05 L
.01102 4e-05 L
.01114 4e-05 L
.01136 4e-05 L
.01159 4e-05 L
.0118 4e-05 L
.012 4e-05 L
.01223 4e-05 L
.01247 4e-05 L
.01259 4e-05 L
.01272 4e-05 L
.01295 4e-05 L
.01308 4e-05 L
.0132 4e-05 L
.01333 4e-05 L
.01347 4e-05 L
.0137 4e-05 L
.01384 4e-05 L
.01396 4e-05 L
.01419 4e-05 L
.0144 4e-05 L
.01464 4e-05 L
.01487 4e-05 L
.01508 4e-05 L
.01531 4e-05 L
.01552 4e-05 L
.01571 4e-05 L
.01593 4e-05 L
.01617 4e-05 L
.01629 4e-05 L
.01641 4e-05 L
.01664 4e-05 L
.01677 4e-05 L
.01689 4e-05 L
.01701 4e-05 L
.01715 4e-05 L
.01738 4e-05 L
.01751 4e-05 L
Mistroke
.01763 4e-05 L
.01785 4e-05 L
.01806 4e-05 L
.0183 4e-05 L
.01852 4e-05 L
.01874 4e-05 L
.01893 4e-05 L
.01915 4e-05 L
.01936 4e-05 L
.01956 4e-05 L
.01974 4e-05 L
.01993 4e-05 L
.02014 4e-05 L
.02035 4e-05 L
.02058 4e-05 L
.02079 4e-05 L
.02098 4e-05 L
.02121 4e-05 L
.02134 4e-05 L
.02146 4e-05 L
.02168 4e-05 L
.02191 4e-05 L
.02212 4e-05 L
.02234 4e-05 L
.02258 4e-05 L
.02281 4e-05 L
.02301 4e-05 L
.0232 4e-05 L
.02342 4e-05 L
.02363 4e-05 L
.02385 4e-05 L
.02409 4e-05 L
.0243 4e-05 L
.02452 4e-05 L
.02476 4e-05 L
.0249 4e-05 L
.02502 4e-05 L
.02526 4e-05 L
.02548 4e-05 L
.0257 4e-05 L
.02589 4e-05 L
.02611 4e-05 L
.02632 4e-05 L
.02651 4e-05 L
.02669 4e-05 L
.02689 4e-05 L
.02709 4e-05 L
.0273 4e-05 L
.02752 4e-05 L
.02774 4e-05 L
Mistroke
.02793 4e-05 L
.02815 4e-05 L
.02828 4e-05 L
.0284 4e-05 L
.02861 4e-05 L
.02884 4e-05 L
.02906 4e-05 L
.02931 4e-05 L
.02953 4e-05 L
.02974 4e-05 L
.02995 4e-05 L
.03014 4e-05 L
.03036 4e-05 L
.03057 4e-05 L
.0308 4e-05 L
.03104 4e-05 L
.03124 4e-05 L
.03146 4e-05 L
.0317 4e-05 L
.03184 4e-05 L
.03196 4e-05 L
.0322 4e-05 L
.03243 4e-05 L
.03262 4e-05 L
.03283 4e-05 L
.03306 4e-05 L
.03326 4e-05 L
.03346 4e-05 L
.03364 4e-05 L
.03383 4e-05 L
.03404 4e-05 L
.03425 4e-05 L
.03447 4e-05 L
.03468 4e-05 L
.03487 4e-05 L
.0351 4e-05 L
.03523 4e-05 L
.03534 4e-05 L
.03556 4e-05 L
.03579 4e-05 L
.03601 4e-05 L
.03625 4e-05 L
.03648 4e-05 L
.03669 4e-05 L
.0369 4e-05 L
.03709 4e-05 L
.03731 4e-05 L
.03752 4e-05 L
.03775 4e-05 L
.03799 4e-05 L
Mistroke
.03819 4e-05 L
.03842 4e-05 L
.03866 4e-05 L
.03879 4e-05 L
.03892 4e-05 L
.03916 4e-05 L
.03938 4e-05 L
.03958 4e-05 L
.03979 4e-05 L
.04001 4e-05 L
.04022 4e-05 L
.04041 4e-05 L
.04059 4e-05 L
.04079 4e-05 L
.04099 4e-05 L
.0412 4e-05 L
.04143 4e-05 L
.04164 4e-05 L
.04183 4e-05 L
.04206 4e-05 L
.04218 4e-05 L
.0423 4e-05 L
.04252 4e-05 L
.04275 4e-05 L
.04297 4e-05 L
.04321 4e-05 L
.04344 4e-05 L
.04365 4e-05 L
.04384 4e-05 L
.04405 4e-05 L
.04427 4e-05 L
.04448 4e-05 L
.04471 4e-05 L
.04495 4e-05 L
.04515 4e-05 L
.04538 4e-05 L
.04562 4e-05 L
.04576 4e-05 L
.04588 4e-05 L
.04612 4e-05 L
.04635 4e-05 L
.04654 4e-05 L
.04675 4e-05 L
.04698 4e-05 L
.04718 4e-05 L
.04738 4e-05 L
.04756 4e-05 L
.04776 4e-05 L
.04796 4e-05 L
.04817 4e-05 L
Mistroke
.04839 4e-05 L
.0486 4e-05 L
.0488 4e-05 L
.04902 4e-05 L
.04915 4e-05 L
.04927 4e-05 L
.04948 4e-05 L
.04971 4e-05 L
.04993 4e-05 L
.05006 4e-05 L
.05018 4e-05 L
.05039 4e-05 L
.05062 4e-05 L
.05082 4e-05 L
.05102 4e-05 L
.05123 4e-05 L
.05145 4e-05 L
.05168 4e-05 L
.05181 4e-05 L
.05193 4e-05 L
.05217 4e-05 L
.0523 4e-05 L
.05243 4e-05 L
.05265 4e-05 L
.05288 4e-05 L
.05311 4e-05 L
.05332 4e-05 L
.05351 4e-05 L
.05372 4e-05 L
.05392 4e-05 L
.0541 4e-05 L
.05431 4e-05 L
.05454 4e-05 L
.05475 4e-05 L
.05495 4e-05 L
.05518 4e-05 L
.05539 4e-05 L
.05559 4e-05 L
.05579 4e-05 L
.05602 4e-05 L
.05626 4e-05 L
.05646 4e-05 L
.05669 4e-05 L
.05693 4e-05 L
.05715 4e-05 L
.05726 4e-05 L
.05739 4e-05 L
.05753 4e-05 L
.05765 4e-05 L
.05788 4e-05 L
Mistroke
.05809 4e-05 L
.05833 4e-05 L
.05857 4e-05 L
.05877 4e-05 L
.05899 4e-05 L
.0592 4e-05 L
.05938 4e-05 L
.0596 4e-05 L
.05984 4e-05 L
.06007 4e-05 L
.06028 4e-05 L
.0605 4e-05 L
.06074 4e-05 L
.06096 4e-05 L
.06117 4e-05 L
.06141 4e-05 L
.06154 4e-05 L
.06167 4e-05 L
.0619 4e-05 L
.06202 4e-05 L
.06215 4e-05 L
.06227 4e-05 L
.0624 4e-05 L
.06264 4e-05 L
.06277 4e-05 L
.06289 4e-05 L
.06302 4e-05 L
.06316 4e-05 L
.06329 4e-05 L
.06342 4e-05 L
.06355 4e-05 L
.06366 4e-05 L
.06389 4e-05 L
.06412 4e-05 L
.06434 4e-05 L
.06458 4e-05 L
.06481 4e-05 L
.06502 4e-05 L
.06523 4e-05 L
.06542 4e-05 L
.06564 4e-05 L
.06585 4e-05 L
.06608 4e-05 L
.06632 4e-05 L
.06652 4e-05 L
.06675 4e-05 L
.06699 4e-05 L
.06712 4e-05 L
.06725 4e-05 L
.06749 4e-05 L
Mistroke
.06771 4e-05 L
.0679 4e-05 L
.06812 4e-05 L
.06834 4e-05 L
.06855 4e-05 L
.06874 4e-05 L
.06892 4e-05 L
.06912 4e-05 L
.06932 4e-05 L
.06953 4e-05 L
.06976 4e-05 L
.06997 4e-05 L
.07016 4e-05 L
.07039 4e-05 L
.07051 4e-05 L
.07063 4e-05 L
.07085 4e-05 L
.07107 4e-05 L
.0713 4e-05 L
.07154 4e-05 L
.07177 4e-05 L
.07198 4e-05 L
.07219 4e-05 L
.07238 4e-05 L
.0726 4e-05 L
.07281 4e-05 L
.07304 4e-05 L
.07328 4e-05 L
.07348 4e-05 L
.07371 4e-05 L
.07395 4e-05 L
.07408 4e-05 L
.07421 4e-05 L
.07445 4e-05 L
.07467 4e-05 L
.07487 4e-05 L
.07508 4e-05 L
.0753 4e-05 L
.07551 4e-05 L
.07571 4e-05 L
.07588 4e-05 L
.07609 4e-05 L
.07629 4e-05 L
.0765 4e-05 L
.07672 4e-05 L
.07693 4e-05 L
.07712 4e-05 L
.07735 4e-05 L
.07748 4e-05 L
.07759 4e-05 L
Mistroke
.07781 4e-05 L
.07804 4e-05 L
.07826 4e-05 L
.07839 4e-05 L
.0785 4e-05 L
.07872 4e-05 L
.07895 4e-05 L
.07915 4e-05 L
.07934 4e-05 L
.07955 4e-05 L
.07978 4e-05 L
.08 4e-05 L
.08013 4e-05 L
.08025 4e-05 L
.08049 4e-05 L
.08063 4e-05 L
.08075 4e-05 L
.08097 4e-05 L
.08121 4e-05 L
.08144 4e-05 L
.08164 4e-05 L
.08184 4e-05 L
.08205 4e-05 L
.08224 4e-05 L
.08242 4e-05 L
.08263 4e-05 L
.08286 4e-05 L
.08308 4e-05 L
.08328 4e-05 L
.08351 4e-05 L
.08372 4e-05 L
.08391 4e-05 L
.08412 4e-05 L
.08434 4e-05 L
.08458 4e-05 L
.08479 4e-05 L
.08501 4e-05 L
.08525 4e-05 L
.08547 4e-05 L
.08559 4e-05 L
.08572 4e-05 L
.08585 4e-05 L
.08598 4e-05 L
.0862 4e-05 L
.08641 4e-05 L
.08665 4e-05 L
.08689 4e-05 L
.08709 4e-05 L
.08731 4e-05 L
.08752 4e-05 L
Mistroke
.08771 4e-05 L
.08793 4e-05 L
.08817 4e-05 L
.08839 4e-05 L
.0886 4e-05 L
.08882 4e-05 L
.08906 4e-05 L
.08928 4e-05 L
.08949 4e-05 L
.08973 4e-05 L
.08987 4e-05 L
.08999 4e-05 L
.09022 4e-05 L
.09034 4e-05 L
.09047 4e-05 L
.09059 4e-05 L
.09072 4e-05 L
.09096 4e-05 L
.09109 4e-05 L
.09121 4e-05 L
.09134 4e-05 L
.09149 4e-05 L
.09161 4e-05 L
.09174 4e-05 L
.09187 4e-05 L
.09199 4e-05 L
.09221 4e-05 L
.09244 4e-05 L
.09266 4e-05 L
.09291 4e-05 L
.09313 4e-05 L
.09335 4e-05 L
.09356 4e-05 L
.09375 4e-05 L
.09397 4e-05 L
.09417 4e-05 L
.0944 4e-05 L
.09464 4e-05 L
.09484 4e-05 L
.09507 4e-05 L
.09531 4e-05 L
.09544 4e-05 L
.09557 4e-05 L
.09581 4e-05 L
.09603 4e-05 L
.09623 4e-05 L
.09644 4e-05 L
.09666 4e-05 L
.09687 4e-05 L
.09706 4e-05 L
Mistroke
.09724 4e-05 L
.09744 4e-05 L
.09764 4e-05 L
.09785 4e-05 L
.09808 4e-05 L
.09829 4e-05 L
.09848 4e-05 L
.09871 4e-05 L
.09883 4e-05 L
.09895 4e-05 L
.09917 4e-05 L
.09939 4e-05 L
.09962 4e-05 L
.09986 4e-05 L
.10009 4e-05 L
.1003 4e-05 L
.10051 4e-05 L
.1007 4e-05 L
.10092 4e-05 L
.10113 4e-05 L
.10136 4e-05 L
.1016 4e-05 L
.1018 4e-05 L
.10202 4e-05 L
.10227 4e-05 L
.1024 4e-05 L
.10252 4e-05 L
.10276 4e-05 L
.10299 4e-05 L
.10318 4e-05 L
.1034 4e-05 L
.10362 4e-05 L
.10383 4e-05 L
.10402 4e-05 L
.1042 4e-05 L
.10441 4e-05 L
.1046 4e-05 L
.10481 4e-05 L
.10504 4e-05 L
.10525 4e-05 L
.10544 4e-05 L
.10567 4e-05 L
.10579 4e-05 L
.10591 4e-05 L
.10613 4e-05 L
.10635 4e-05 L
.10658 4e-05 L
.1067 4e-05 L
.10682 4e-05 L
.10704 4e-05 L
Mistroke
.10726 4e-05 L
.10747 4e-05 L
.10766 4e-05 L
.10787 4e-05 L
.10809 4e-05 L
.10832 4e-05 L
.10845 4e-05 L
.10857 4e-05 L
.10881 4e-05 L
.10894 4e-05 L
.10907 4e-05 L
.10929 4e-05 L
.10953 4e-05 L
.10975 4e-05 L
.10996 4e-05 L
.11015 4e-05 L
.11036 4e-05 L
.11056 4e-05 L
.11074 4e-05 L
.11095 4e-05 L
.11118 4e-05 L
.11139 4e-05 L
.11159 4e-05 L
.11182 4e-05 L
.11203 4e-05 L
.11223 4e-05 L
.11243 4e-05 L
.11266 4e-05 L
.1129 4e-05 L
.1131 4e-05 L
.11333 4e-05 L
.11357 4e-05 L
.11379 4e-05 L
.1139 4e-05 L
.11403 4e-05 L
.11416 4e-05 L
.11429 4e-05 L
.11452 4e-05 L
.11473 4e-05 L
.11496 4e-05 L
.1152 4e-05 L
.11541 4e-05 L
.11563 4e-05 L
.11583 4e-05 L
.11602 4e-05 L
.11624 4e-05 L
.11648 4e-05 L
.11671 4e-05 L
.11691 4e-05 L
.11713 4e-05 L
Mistroke
.11737 4e-05 L
.1176 4e-05 L
.1178 4e-05 L
.11804 4e-05 L
.11818 4e-05 L
.1183 4e-05 L
.11854 4e-05 L
.11865 4e-05 L
.11878 4e-05 L
.1189 4e-05 L
.11904 4e-05 L
.11927 4e-05 L
.1194 4e-05 L
.11952 4e-05 L
.11966 4e-05 L
.1198 4e-05 L
.11992 4e-05 L
.12006 4e-05 L
.12018 4e-05 L
.1203 4e-05 L
.12052 4e-05 L
.12076 4e-05 L
.12098 4e-05 L
.12122 4e-05 L
.12145 4e-05 L
.12166 4e-05 L
.12187 4e-05 L
.12206 4e-05 L
.12228 4e-05 L
.12248 4e-05 L
.12271 4e-05 L
.12295 4e-05 L
.12315 4e-05 L
.12338 4e-05 L
.12362 4e-05 L
.12375 4e-05 L
.12388 4e-05 L
.12412 4e-05 L
.12434 4e-05 L
.12454 4e-05 L
.12475 4e-05 L
.12497 4e-05 L
.12518 4e-05 L
.12537 4e-05 L
.12555 4e-05 L
.12575 4e-05 L
.12595 4e-05 L
.12616 4e-05 L
.12639 4e-05 L
.1266 4e-05 L
Mistroke
.12679 4e-05 L
.12702 4e-05 L
.12714 4e-05 L
.12726 4e-05 L
.12748 4e-05 L
.1277 4e-05 L
.12793 4e-05 L
.12817 4e-05 L
.1284 4e-05 L
.12861 4e-05 L
.12882 4e-05 L
.12901 4e-05 L
.12923 4e-05 L
.12944 4e-05 L
.12967 4e-05 L
.1299 4e-05 L
.13011 4e-05 L
.13033 4e-05 L
.13057 4e-05 L
.13071 4e-05 L
.13083 4e-05 L
.13107 4e-05 L
.1313 4e-05 L
.13149 4e-05 L
.13171 4e-05 L
.13193 4e-05 L
.13214 4e-05 L
.13233 4e-05 L
.13251 4e-05 L
.13271 4e-05 L
.13291 4e-05 L
.13312 4e-05 L
.13335 4e-05 L
.13356 4e-05 L
.13375 4e-05 L
.13398 4e-05 L
.1341 4e-05 L
.13422 4e-05 L
.13444 4e-05 L
.13466 4e-05 L
.13489 4e-05 L
.13501 4e-05 L
.13513 4e-05 L
.13534 4e-05 L
.13557 4e-05 L
.13578 4e-05 L
.13597 4e-05 L
.13618 4e-05 L
.1364 4e-05 L
.13663 4e-05 L
Mistroke
.13676 4e-05 L
.13687 4e-05 L
.13712 4e-05 L
.13725 4e-05 L
.13737 4e-05 L
.13759 4e-05 L
.13783 4e-05 L
.13806 4e-05 L
.13827 4e-05 L
.13846 4e-05 L
.13867 4e-05 L
.13886 4e-05 L
.13904 4e-05 L
.13925 4e-05 L
.13948 4e-05 L
.1397 4e-05 L
.1399 4e-05 L
.14013 4e-05 L
.14034 4e-05 L
.14053 4e-05 L
.14074 4e-05 L
.14096 4e-05 L
.1412 4e-05 L
.14141 4e-05 L
.14163 4e-05 L
.14187 4e-05 L
.14209 4e-05 L
.14221 4e-05 L
.14234 4e-05 L
.14247 4e-05 L
.1426 4e-05 L
.14282 4e-05 L
.14303 4e-05 L
.14327 4e-05 L
.14351 4e-05 L
.14371 4e-05 L
.14393 4e-05 L
.14414 4e-05 L
.14432 4e-05 L
.14455 4e-05 L
.14478 4e-05 L
.14501 4e-05 L
.14522 4e-05 L
.14544 4e-05 L
.14568 4e-05 L
.1459 4e-05 L
.14611 4e-05 L
.14635 4e-05 L
.14648 4e-05 L
.14661 4e-05 L
Mistroke
.14684 4e-05 L
.14697 4e-05 L
.14708 4e-05 L
.14721 4e-05 L
.14734 4e-05 L
.14757 4e-05 L
.1477 4e-05 L
.14783 4e-05 L
.14796 4e-05 L
.1481 4e-05 L
.14823 4e-05 L
.14836 4e-05 L
.14849 4e-05 L
.1486 4e-05 L
.14883 4e-05 L
.14906 4e-05 L
.14928 4e-05 L
.14952 4e-05 L
.14975 4e-05 L
.14996 4e-05 L
.15017 4e-05 L
.15036 4e-05 L
.15058 4e-05 L
.15079 4e-05 L
.15101 4e-05 L
.15125 4e-05 L
.15146 4e-05 L
.15168 4e-05 L
.15192 4e-05 L
.15206 4e-05 L
.15218 4e-05 L
.15242 4e-05 L
.15265 4e-05 L
.15284 4e-05 L
.15305 4e-05 L
.15327 4e-05 L
.15348 4e-05 L
.15368 4e-05 L
.15385 4e-05 L
.15405 4e-05 L
.15426 4e-05 L
.15446 4e-05 L
.15469 4e-05 L
.1549 4e-05 L
.15509 4e-05 L
.15532 4e-05 L
.15544 4e-05 L
.15556 4e-05 L
.15578 4e-05 L
.15601 4e-05 L
Mistroke
.15623 4e-05 L
.15647 4e-05 L
.1567 4e-05 L
.15691 4e-05 L
.15712 4e-05 L
.15731 4e-05 L
.15753 4e-05 L
.15774 4e-05 L
.15797 4e-05 L
.15821 4e-05 L
.15841 4e-05 L
.15863 4e-05 L
.15888 4e-05 L
.15901 4e-05 L
.15913 4e-05 L
.15937 4e-05 L
.1596 4e-05 L
.15979 4e-05 L
.16001 4e-05 L
.16023 4e-05 L
.16044 4e-05 L
.16063 4e-05 L
.16081 4e-05 L
.16101 4e-05 L
.16121 4e-05 L
.16142 4e-05 L
.16165 4e-05 L
.16186 4e-05 L
.16205 4e-05 L
.16227 4e-05 L
.1624 4e-05 L
.16252 4e-05 L
.16273 4e-05 L
.16296 4e-05 L
.16319 4e-05 L
.16331 4e-05 L
.16343 4e-05 L
.16364 4e-05 L
.16387 4e-05 L
.16407 4e-05 L
.16426 4e-05 L
.16447 4e-05 L
.1647 4e-05 L
.16493 4e-05 L
.16505 4e-05 L
.16517 4e-05 L
.16541 4e-05 L
.16555 4e-05 L
.16567 4e-05 L
.16589 4e-05 L
Mistroke
.16613 4e-05 L
.16636 4e-05 L
.16656 4e-05 L
.16676 4e-05 L
.16697 4e-05 L
.16716 4e-05 L
.16734 4e-05 L
.16755 4e-05 L
.16778 4e-05 L
.168 4e-05 L
.1682 4e-05 L
.16842 4e-05 L
.16864 4e-05 L
.16883 4e-05 L
.16904 4e-05 L
.16926 4e-05 L
.1695 4e-05 L
.16971 4e-05 L
.16993 4e-05 L
.17009 4e-05 L
.17024 4e-05 L
.17041 4e-05 L
.17058 4e-05 L
.17073 4e-05 L
.17087 4e-05 L
.17103 4e-05 L
.1712 4e-05 L
.17134 4e-05 L
.17149 4e-05 L
.17165 4e-05 L
.1718 4e-05 L
.17194 4e-05 L
.17207 4e-05 L
.17221 4e-05 L
.17235 4e-05 L
.1725 4e-05 L
.17267 4e-05 L
.17284 4e-05 L
.173 4e-05 L
.17315 4e-05 L
.17329 4e-05 L
.17345 4e-05 L
.1736 4e-05 L
.17376 4e-05 L
.17393 4e-05 L
.17409 4e-05 L
.17424 4e-05 L
.17442 4e-05 L
.17461 4e-05 L
.17478 4e-05 L
Mistroke
.17495 4e-05 L
Mfstroke
4e-05 .13451 m
.00713 .13989 L
.01487 .14575 L
.02214 .15126 L
.02913 .15655 L
.03657 .16219 L
.04373 .16762 L
.05134 .17338 L
.05867 .17894 L
.06573 .18429 L
.07324 .18998 L
.08046 .19546 L
.08741 .20073 L
.09481 .20634 L
.10193 .21174 L
.1095 .21748 L
.11679 .22302 L
.12381 .22834 L
.13127 .234 L
.13846 .23946 L
.1461 .24525 L
.15345 .25084 L
.16053 .25622 L
.16806 .26194 L
.17495 .26716 L
s
.5 1 1 r
4e-05 4e-05 m
.00026 4e-05 L
.00045 4e-05 L
.00068 4e-05 L
.00089 4e-05 L
.00109 4e-05 L
.00127 4e-05 L
.00147 4e-05 L
.00169 4e-05 L
.0019 4e-05 L
.00213 4e-05 L
.00235 4e-05 L
.00255 4e-05 L
.00278 4e-05 L
.00291 4e-05 L
.00303 4e-05 L
.00326 4e-05 L
.00349 4e-05 L
.00361 4e-05 L
.00374 4e-05 L
.00397 4e-05 L
.00409 4e-05 L
.00421 4e-05 L
.00434 4e-05 L
.00448 4e-05 L
.0046 4e-05 L
.00473 4e-05 L
.00496 4e-05 L
.00519 4e-05 L
.0054 4e-05 L
.00561 4e-05 L
.0058 4e-05 L
.00601 4e-05 L
.00624 4e-05 L
.00647 4e-05 L
.00671 4e-05 L
.00691 4e-05 L
.00713 4e-05 L
.00727 4e-05 L
.00739 4e-05 L
.00752 4e-05 L
.00766 4e-05 L
.00789 4e-05 L
.00803 4e-05 L
.00815 4e-05 L
.00838 4e-05 L
.00859 4e-05 L
.00871 4e-05 L
.00884 4e-05 L
.00907 4e-05 L
.00921 4e-05 L
.00935 4e-05 L
.00946 4e-05 L
.00959 4e-05 L
.00973 4e-05 L
.00988 4e-05 L
.01001 4e-05 L
.01015 4e-05 L
.01028 4e-05 L
.0104 4e-05 L
.01053 4e-05 L
.01066 4e-05 L
.01089 4e-05 L
.01102 4e-05 L
.01114 4e-05 L
.01136 4e-05 L
.01159 4e-05 L
.0118 4e-05 L
.012 4e-05 L
.01223 4e-05 L
.01247 4e-05 L
.01259 4e-05 L
.01272 4e-05 L
.01295 4e-05 L
.01308 4e-05 L
.0132 4e-05 L
.01333 4e-05 L
.01347 4e-05 L
.0137 4e-05 L
.01384 4e-05 L
.01396 4e-05 L
.01419 4e-05 L
.0144 4e-05 L
.01464 4e-05 L
.01487 4e-05 L
.01508 4e-05 L
.01531 4e-05 L
.01552 4e-05 L
.01571 4e-05 L
.01593 4e-05 L
.01617 4e-05 L
.01629 4e-05 L
.01641 4e-05 L
.01664 4e-05 L
.01677 4e-05 L
.01689 4e-05 L
.01701 4e-05 L
.01715 4e-05 L
.01738 4e-05 L
.01751 4e-05 L
.01763 4e-05 L
.01785 4e-05 L
.01806 4e-05 L
.0183 4e-05 L
.01852 4e-05 L
.01874 4e-05 L
.01893 4e-05 L
.01915 4e-05 L
.01936 4e-05 L
.01956 4e-05 L
.01974 4e-05 L
.01993 4e-05 L
.02014 4e-05 L
.02035 4e-05 L
.02058 4e-05 L
.02079 4e-05 L
.02098 4e-05 L
.02121 4e-05 L
.02134 4e-05 L
.02146 4e-05 L
.02168 4e-05 L
.02191 4e-05 L
.02212 4e-05 L
.02234 4e-05 L
.02258 4e-05 L
.02281 4e-05 L
.02301 4e-05 L
.0232 4e-05 L
.02342 4e-05 L
.02363 4e-05 L
.02385 4e-05 L
.02409 4e-05 L
.0243 4e-05 L
.02452 4e-05 L
.02476 4e-05 L
.0249 4e-05 L
.02502 4e-05 L
.02526 4e-05 L
.02548 4e-05 L
.0257 4e-05 L
.02589 4e-05 L
.02611 4e-05 L
.02632 4e-05 L
.02651 4e-05 L
.02669 4e-05 L
.02689 4e-05 L
.02709 4e-05 L
.0273 4e-05 L
.02752 4e-05 L
.02774 4e-05 L
.02793 4e-05 L
.02815 4e-05 L
.02828 4e-05 L
.0284 4e-05 L
.02861 4e-05 L
.02884 4e-05 L
.02906 4e-05 L
.02931 4e-05 L
.02953 4e-05 L
.02974 4e-05 L
.02995 4e-05 L
.03014 4e-05 L
.03036 4e-05 L
.03057 4e-05 L
.0308 4e-05 L
.03104 4e-05 L
.03124 4e-05 L
.03146 4e-05 L
.0317 4e-05 L
.03184 4e-05 L
.03196 4e-05 L
.0322 4e-05 L
.03243 4e-05 L
.03262 4e-05 L
.03283 4e-05 L
.03306 4e-05 L
.03326 4e-05 L
.03346 4e-05 L
.03364 4e-05 L
.03383 4e-05 L
.03404 4e-05 L
.03425 4e-05 L
.03447 4e-05 L
.03468 4e-05 L
.03487 4e-05 L
.0351 4e-05 L
.03523 4e-05 L
.03534 4e-05 L
.03556 4e-05 L
.03579 4e-05 L
.03601 4e-05 L
.03625 4e-05 L
.03648 4e-05 L
.03669 4e-05 L
.0369 4e-05 L
.03709 4e-05 L
.03731 4e-05 L
.03752 4e-05 L
.03775 4e-05 L
.03799 4e-05 L
.03819 4e-05 L
.03842 4e-05 L
.03866 4e-05 L
.03879 4e-05 L
.03892 4e-05 L
.03916 4e-05 L
.03938 4e-05 L
.03958 4e-05 L
.03979 4e-05 L
.04001 4e-05 L
.04022 4e-05 L
.04041 4e-05 L
.04059 4e-05 L
.04079 4e-05 L
.04099 4e-05 L
.0412 4e-05 L
.04143 4e-05 L
.04164 4e-05 L
.04183 4e-05 L
.04206 4e-05 L
.04218 4e-05 L
.0423 4e-05 L
.04252 4e-05 L
.04275 4e-05 L
.04297 4e-05 L
.04321 4e-05 L
.04344 4e-05 L
.04365 4e-05 L
.04384 4e-05 L
.04405 4e-05 L
.04427 4e-05 L
.04448 4e-05 L
.04471 4e-05 L
.04495 4e-05 L
.04515 4e-05 L
.04538 4e-05 L
.04562 4e-05 L
.04576 4e-05 L
.04588 4e-05 L
.04612 4e-05 L
.04635 4e-05 L
.04654 4e-05 L
.04675 4e-05 L
.04698 4e-05 L
.04718 4e-05 L
.04738 4e-05 L
.04756 4e-05 L
.04776 4e-05 L
.04796 4e-05 L
.04817 4e-05 L
.04839 4e-05 L
.0486 4e-05 L
.0488 4e-05 L
.04902 4e-05 L
.04915 4e-05 L
.04927 4e-05 L
.04948 4e-05 L
.04971 4e-05 L
.04993 4e-05 L
.05006 4e-05 L
.05018 4e-05 L
.05039 4e-05 L
.05062 4e-05 L
.05082 4e-05 L
.05102 4e-05 L
.05123 4e-05 L
.05145 4e-05 L
.05168 4e-05 L
.05181 4e-05 L
.05193 4e-05 L
.05217 4e-05 L
.0523 4e-05 L
.05243 4e-05 L
.05265 4e-05 L
.05288 4e-05 L
.05311 4e-05 L
.05332 4e-05 L
.05351 4e-05 L
.05372 4e-05 L
.05392 4e-05 L
.0541 4e-05 L
.05431 4e-05 L
.05454 4e-05 L
.05475 4e-05 L
.05495 4e-05 L
.05518 4e-05 L
.05539 4e-05 L
.05559 4e-05 L
.05579 4e-05 L
.05602 4e-05 L
.05626 4e-05 L
.05646 4e-05 L
.05669 4e-05 L
.05693 4e-05 L
.05715 4e-05 L
.05726 4e-05 L
.05739 4e-05 L
.05753 4e-05 L
.05765 4e-05 L
.05788 4e-05 L
.05809 4e-05 L
.05833 4e-05 L
.05857 4e-05 L
.05877 4e-05 L
.05899 4e-05 L
.0592 4e-05 L
.05938 4e-05 L
.0596 4e-05 L
.05984 4e-05 L
.06007 4e-05 L
.06028 4e-05 L
.0605 4e-05 L
.06074 4e-05 L
.06096 4e-05 L
.06117 4e-05 L
.06141 4e-05 L
.06154 4e-05 L
.06167 4e-05 L
.0619 4e-05 L
.06202 4e-05 L
.06215 4e-05 L
.06227 4e-05 L
.0624 4e-05 L
.06264 4e-05 L
.06277 4e-05 L
.06289 4e-05 L
.06302 4e-05 L
.06316 4e-05 L
.06329 4e-05 L
.06342 4e-05 L
.06355 4e-05 L
.06366 4e-05 L
.06389 4e-05 L
.06412 4e-05 L
.06434 4e-05 L
.06458 4e-05 L
.06481 4e-05 L
.06502 4e-05 L
.06523 4e-05 L
.06542 4e-05 L
.06564 4e-05 L
.06585 4e-05 L
.06608 4e-05 L
.06632 4e-05 L
.06652 4e-05 L
.06675 4e-05 L
.06699 4e-05 L
.06712 4e-05 L
.06725 4e-05 L
.06749 4e-05 L
.06771 4e-05 L
.0679 4e-05 L
.06812 4e-05 L
.06834 4e-05 L
.06855 4e-05 L
.06874 4e-05 L
.06892 4e-05 L
.06912 4e-05 L
.06932 4e-05 L
.06953 4e-05 L
.06976 4e-05 L
.06997 4e-05 L
.07016 4e-05 L
.07039 4e-05 L
.07051 4e-05 L
.07063 4e-05 L
.07085 4e-05 L
.07107 4e-05 L
.0713 4e-05 L
.07154 4e-05 L
.07177 4e-05 L
.07198 4e-05 L
.07219 4e-05 L
.07238 4e-05 L
.0726 4e-05 L
.07281 4e-05 L
.07304 4e-05 L
.07328 4e-05 L
.07348 4e-05 L
.07371 4e-05 L
.07395 4e-05 L
.07408 4e-05 L
.07421 4e-05 L
.07445 4e-05 L
.07467 4e-05 L
.07487 4e-05 L
.07508 4e-05 L
.0753 4e-05 L
.07551 4e-05 L
.07571 4e-05 L
.07588 4e-05 L
.07609 4e-05 L
.07629 4e-05 L
.0765 4e-05 L
.07672 4e-05 L
.07693 4e-05 L
.07712 4e-05 L
.07735 4e-05 L
.07748 4e-05 L
.07759 4e-05 L
.07781 4e-05 L
.07804 4e-05 L
.07826 4e-05 L
.07839 4e-05 L
.0785 4e-05 L
.07872 4e-05 L
.07895 4e-05 L
.07915 4e-05 L
.07934 4e-05 L
.07955 4e-05 L
.07978 4e-05 L
.08 4e-05 L
.08013 4e-05 L
.08025 4e-05 L
.08049 4e-05 L
.08063 4e-05 L
.08075 4e-05 L
.08097 4e-05 L
.08121 4e-05 L
.08144 4e-05 L
.08164 4e-05 L
.08184 4e-05 L
.08205 4e-05 L
.08224 4e-05 L
.08242 4e-05 L
.08263 4e-05 L
.08286 4e-05 L
.08308 4e-05 L
.08328 4e-05 L
.08351 4e-05 L
.08372 4e-05 L
.08391 4e-05 L
.08412 4e-05 L
.08434 4e-05 L
.08458 4e-05 L
.08479 4e-05 L
.08501 4e-05 L
.08525 4e-05 L
.08547 4e-05 L
.08559 4e-05 L
.08572 4e-05 L
.08585 4e-05 L
.08598 4e-05 L
.0862 4e-05 L
.08641 4e-05 L
.08665 4e-05 L
.08689 4e-05 L
.08709 4e-05 L
.08731 4e-05 L
.08752 4e-05 L
.08771 4e-05 L
.08793 4e-05 L
.08817 4e-05 L
.08839 4e-05 L
.0886 4e-05 L
.08882 4e-05 L
.08906 4e-05 L
.08928 4e-05 L
.08949 4e-05 L
.08973 4e-05 L
.08987 4e-05 L
.08999 4e-05 L
.09022 4e-05 L
.09034 4e-05 L
.09047 4e-05 L
.09059 4e-05 L
.09072 4e-05 L
.09096 4e-05 L
.09109 4e-05 L
.09121 4e-05 L
.09134 4e-05 L
.09149 4e-05 L
.09161 4e-05 L
.09174 4e-05 L
.09187 4e-05 L
.09199 4e-05 L
.09221 4e-05 L
.09244 4e-05 L
.09266 4e-05 L
.09291 4e-05 L
.09313 4e-05 L
.09335 4e-05 L
.09356 4e-05 L
.09375 4e-05 L
.09397 4e-05 L
.09417 4e-05 L
.0944 4e-05 L
.09464 4e-05 L
.09484 4e-05 L
.09507 4e-05 L
.09531 4e-05 L
.09544 4e-05 L
.09557 4e-05 L
.09581 4e-05 L
.09603 4e-05 L
.09623 4e-05 L
.09644 4e-05 L
.09666 4e-05 L
.09687 4e-05 L
.09706 4e-05 L
.09724 4e-05 L
.09744 4e-05 L
.09764 4e-05 L
.09785 4e-05 L
.09808 4e-05 L
.09829 4e-05 L
.09848 4e-05 L
.09871 4e-05 L
.09883 4e-05 L
.09895 4e-05 L
.09917 4e-05 L
.09939 4e-05 L
.09962 4e-05 L
.09986 4e-05 L
.10009 4e-05 L
.1003 4e-05 L
.10051 4e-05 L
.1007 4e-05 L
.10092 4e-05 L
.10113 4e-05 L
.10136 4e-05 L
.1016 4e-05 L
.1018 4e-05 L
.10202 4e-05 L
.10227 4e-05 L
.1024 4e-05 L
.10252 4e-05 L
.10276 4e-05 L
.10299 4e-05 L
.10318 4e-05 L
.1034 4e-05 L
.10362 4e-05 L
.10383 4e-05 L
.10402 4e-05 L
.1042 4e-05 L
.10441 4e-05 L
.1046 4e-05 L
.10481 4e-05 L
.10504 4e-05 L
.10525 4e-05 L
.10544 4e-05 L
.10567 4e-05 L
.10579 4e-05 L
.10591 4e-05 L
.10613 4e-05 L
.10635 4e-05 L
.10658 4e-05 L
.1067 4e-05 L
.10682 4e-05 L
.10704 4e-05 L
.10726 4e-05 L
.10747 4e-05 L
.10766 4e-05 L
.10787 4e-05 L
.10809 4e-05 L
.10832 4e-05 L
.10845 4e-05 L
.10857 4e-05 L
.10881 4e-05 L
.10894 4e-05 L
.10907 4e-05 L
.10929 4e-05 L
.10953 4e-05 L
.10975 4e-05 L
.10996 4e-05 L
.11015 4e-05 L
.11036 4e-05 L
.11056 4e-05 L
.11074 4e-05 L
.11095 4e-05 L
.11118 4e-05 L
.11139 4e-05 L
.11159 4e-05 L
.11182 4e-05 L
.11203 4e-05 L
.11223 4e-05 L
.11243 4e-05 L
.11266 4e-05 L
.1129 4e-05 L
.1131 4e-05 L
.11333 4e-05 L
.11357 4e-05 L
.11379 4e-05 L
.1139 4e-05 L
.11403 4e-05 L
.11416 4e-05 L
.11429 4e-05 L
.11452 4e-05 L
.11473 4e-05 L
.11496 4e-05 L
.1152 4e-05 L
.11541 4e-05 L
.11563 4e-05 L
.11583 4e-05 L
.11602 4e-05 L
.11624 4e-05 L
.11648 4e-05 L
.11671 4e-05 L
.11691 4e-05 L
.11713 4e-05 L
.11737 4e-05 L
.1176 4e-05 L
.1178 4e-05 L
.11804 4e-05 L
.11818 4e-05 L
.1183 4e-05 L
.11854 4e-05 L
.11865 4e-05 L
.11878 4e-05 L
.1189 4e-05 L
.11904 4e-05 L
.11927 4e-05 L
.1194 4e-05 L
.11952 4e-05 L
.11966 4e-05 L
.1198 4e-05 L
.11992 4e-05 L
.12006 4e-05 L
.12018 4e-05 L
.1203 4e-05 L
.12052 4e-05 L
.12076 4e-05 L
.12098 4e-05 L
.12122 4e-05 L
.12145 4e-05 L
.12166 4e-05 L
.12187 4e-05 L
.12206 4e-05 L
.12228 4e-05 L
.12248 4e-05 L
.12271 4e-05 L
.12295 4e-05 L
.12315 4e-05 L
.12338 4e-05 L
.12362 4e-05 L
.12375 4e-05 L
.12388 4e-05 L
.12412 4e-05 L
.12434 4e-05 L
.12454 4e-05 L
.12475 4e-05 L
.12497 4e-05 L
.12518 4e-05 L
.12537 4e-05 L
.12555 4e-05 L
.12575 4e-05 L
.12595 4e-05 L
.12616 4e-05 L
.12639 4e-05 L
.1266 4e-05 L
.12679 4e-05 L
.12702 4e-05 L
.12714 4e-05 L
.12726 4e-05 L
.12748 4e-05 L
.1277 4e-05 L
.12793 4e-05 L
.12817 4e-05 L
.1284 4e-05 L
.12861 4e-05 L
.12882 4e-05 L
.12901 4e-05 L
.12923 4e-05 L
.12944 4e-05 L
.12967 4e-05 L
.1299 4e-05 L
.13011 4e-05 L
.13033 4e-05 L
.13057 4e-05 L
.13071 4e-05 L
.13083 4e-05 L
.13107 4e-05 L
.1313 4e-05 L
.13149 4e-05 L
.13171 4e-05 L
.13193 4e-05 L
.13214 4e-05 L
.13233 4e-05 L
.13251 4e-05 L
.13271 4e-05 L
.13291 4e-05 L
.13312 4e-05 L
.13335 4e-05 L
.13356 4e-05 L
.13375 4e-05 L
.13398 4e-05 L
.1341 4e-05 L
.13422 4e-05 L
.13444 4e-05 L
.13466 4e-05 L
.13489 4e-05 L
.13501 4e-05 L
.13513 4e-05 L
.13534 4e-05 L
.13557 4e-05 L
.13578 4e-05 L
.13597 4e-05 L
.13618 4e-05 L
.1364 4e-05 L
.13663 4e-05 L
.13676 4e-05 L
.13687 4e-05 L
.13712 4e-05 L
.13725 4e-05 L
.13737 4e-05 L
.13759 4e-05 L
.13783 4e-05 L
.13806 4e-05 L
.13827 4e-05 L
.13846 4e-05 L
.13867 4e-05 L
.13886 4e-05 L
.13904 4e-05 L
.13925 4e-05 L
.13948 4e-05 L
.1397 4e-05 L
.1399 4e-05 L
.14013 4e-05 L
.14034 4e-05 L
.14053 4e-05 L
.14074 4e-05 L
.14096 4e-05 L
.1412 4e-05 L
.14141 4e-05 L
.14163 4e-05 L
.14187 4e-05 L
.14209 4e-05 L
.14221 4e-05 L
.14234 4e-05 L
.14247 4e-05 L
.1426 4e-05 L
.14282 4e-05 L
.14303 4e-05 L
.14327 4e-05 L
.14351 4e-05 L
.14371 4e-05 L
.14393 4e-05 L
.14414 4e-05 L
.14432 4e-05 L
.14455 4e-05 L
.14478 4e-05 L
.14501 4e-05 L
.14522 4e-05 L
.14544 4e-05 L
.14568 4e-05 L
.1459 4e-05 L
.14611 4e-05 L
.14635 4e-05 L
.14648 4e-05 L
.14661 4e-05 L
.14684 4e-05 L
.14697 4e-05 L
.14708 4e-05 L
.14721 4e-05 L
.14734 4e-05 L
.14757 4e-05 L
.1477 4e-05 L
.14783 4e-05 L
.14796 4e-05 L
.1481 4e-05 L
.14823 4e-05 L
.14836 4e-05 L
.14849 4e-05 L
.1486 4e-05 L
.14883 4e-05 L
.14906 4e-05 L
.14928 4e-05 L
.14952 4e-05 L
.14975 4e-05 L
.14996 4e-05 L
.15017 4e-05 L
.15036 4e-05 L
.15058 4e-05 L
.15079 4e-05 L
.15101 4e-05 L
.15125 4e-05 L
.15146 4e-05 L
.15168 4e-05 L
.15192 4e-05 L
.15206 4e-05 L
.15218 4e-05 L
.15242 4e-05 L
.15265 4e-05 L
.15284 4e-05 L
.15305 4e-05 L
.15327 4e-05 L
.15348 4e-05 L
.15368 4e-05 L
.15385 4e-05 L
.15405 4e-05 L
.15426 4e-05 L
.15446 4e-05 L
.15469 4e-05 L
.1549 4e-05 L
.15509 4e-05 L
.15532 4e-05 L
.15544 4e-05 L
.15556 4e-05 L
.15578 4e-05 L
.15601 4e-05 L
.15623 4e-05 L
.15647 4e-05 L
.1567 4e-05 L
.15691 4e-05 L
.15712 4e-05 L
.15731 4e-05 L
.15753 4e-05 L
.15774 4e-05 L
.15797 4e-05 L
.15821 4e-05 L
.15841 4e-05 L
.15863 4e-05 L
.15888 4e-05 L
.15901 4e-05 L
.15913 4e-05 L
.15937 4e-05 L
.1596 4e-05 L
.15979 4e-05 L
.16001 4e-05 L
.16023 4e-05 L
.16044 4e-05 L
.16063 4e-05 L
.16081 4e-05 L
.16101 4e-05 L
.16121 4e-05 L
.16142 4e-05 L
.16165 4e-05 L
.16186 4e-05 L
.16205 4e-05 L
.16227 4e-05 L
.1624 4e-05 L
.16252 4e-05 L
.16273 4e-05 L
.16296 4e-05 L
.16319 4e-05 L
.16331 4e-05 L
.16343 4e-05 L
.16364 4e-05 L
.16387 4e-05 L
.16407 4e-05 L
.16426 4e-05 L
.16447 4e-05 L
.1647 4e-05 L
.16493 4e-05 L
.16505 4e-05 L
.16517 4e-05 L
.16541 4e-05 L
.16555 4e-05 L
.16567 4e-05 L
.16589 4e-05 L
.16613 4e-05 L
.16636 4e-05 L
.16656 4e-05 L
.16676 4e-05 L
.16697 4e-05 L
.16716 4e-05 L
.16734 4e-05 L
.16755 4e-05 L
.16778 4e-05 L
.168 4e-05 L
.1682 4e-05 L
.16842 4e-05 L
.16864 4e-05 L
.16883 4e-05 L
.16904 4e-05 L
.16926 4e-05 L
.1695 4e-05 L
.16971 4e-05 L
.16993 4e-05 L
.17009 4e-05 L
.17024 4e-05 L
.17041 4e-05 L
.17058 4e-05 L
.17073 4e-05 L
.17087 4e-05 L
.17103 4e-05 L
.1712 4e-05 L
.17134 4e-05 L
.17149 4e-05 L
.17165 4e-05 L
.1718 4e-05 L
.17194 4e-05 L
.17207 4e-05 L
.17221 4e-05 L
.17235 4e-05 L
.1725 4e-05 L
.17267 4e-05 L
.17284 4e-05 L
.173 4e-05 L
.17315 4e-05 L
.17329 4e-05 L
.17345 4e-05 L
.1736 4e-05 L
.17376 4e-05 L
.17393 4e-05 L
.17409 4e-05 L
.17424 4e-05 L
.17442 4e-05 L
.17461 4e-05 L
.17478 4e-05 L
.17495 4e-05 L
.17495 .26716 L
.16806 .26194 L
.16053 .25622 L
.15345 .25084 L
.1461 .24525 L
.13846 .23946 L
.13127 .234 L
.12381 .22834 L
.11679 .22302 L
.1095 .21748 L
.10193 .21174 L
.09481 .20634 L
.08741 .20073 L
.08046 .19546 L
.07324 .18998 L
.06573 .18429 L
.05867 .17894 L
.05134 .17338 L
.04373 .16762 L
.03657 .16219 L
.02913 .15655 L
.02214 .15126 L
.01487 .14575 L
.00713 .13989 L
4e-05 .13451 L
F
0 g
4e-05 4e-05 m
.00026 4e-05 L
.00045 4e-05 L
.00068 4e-05 L
.00089 4e-05 L
.00109 4e-05 L
.00127 4e-05 L
.00147 4e-05 L
.00169 4e-05 L
.0019 4e-05 L
.00213 4e-05 L
.00235 4e-05 L
.00255 4e-05 L
.00278 4e-05 L
.00291 4e-05 L
.00303 4e-05 L
.00326 4e-05 L
.00349 4e-05 L
.00361 4e-05 L
.00374 4e-05 L
.00397 4e-05 L
.00409 4e-05 L
.00421 4e-05 L
.00434 4e-05 L
.00448 4e-05 L
.0046 4e-05 L
.00473 4e-05 L
.00496 4e-05 L
.00519 4e-05 L
.0054 4e-05 L
.00561 4e-05 L
.0058 4e-05 L
.00601 4e-05 L
.00624 4e-05 L
.00647 4e-05 L
.00671 4e-05 L
.00691 4e-05 L
.00713 4e-05 L
.00727 4e-05 L
.00739 4e-05 L
.00752 4e-05 L
.00766 4e-05 L
.00789 4e-05 L
.00803 4e-05 L
.00815 4e-05 L
.00838 4e-05 L
.00859 4e-05 L
.00871 4e-05 L
.00884 4e-05 L
.00907 4e-05 L
Mistroke
.00921 4e-05 L
.00935 4e-05 L
.00946 4e-05 L
.00959 4e-05 L
.00973 4e-05 L
.00988 4e-05 L
.01001 4e-05 L
.01015 4e-05 L
.01028 4e-05 L
.0104 4e-05 L
.01053 4e-05 L
.01066 4e-05 L
.01089 4e-05 L
.01102 4e-05 L
.01114 4e-05 L
.01136 4e-05 L
.01159 4e-05 L
.0118 4e-05 L
.012 4e-05 L
.01223 4e-05 L
.01247 4e-05 L
.01259 4e-05 L
.01272 4e-05 L
.01295 4e-05 L
.01308 4e-05 L
.0132 4e-05 L
.01333 4e-05 L
.01347 4e-05 L
.0137 4e-05 L
.01384 4e-05 L
.01396 4e-05 L
.01419 4e-05 L
.0144 4e-05 L
.01464 4e-05 L
.01487 4e-05 L
.01508 4e-05 L
.01531 4e-05 L
.01552 4e-05 L
.01571 4e-05 L
.01593 4e-05 L
.01617 4e-05 L
.01629 4e-05 L
.01641 4e-05 L
.01664 4e-05 L
.01677 4e-05 L
.01689 4e-05 L
.01701 4e-05 L
.01715 4e-05 L
.01738 4e-05 L
.01751 4e-05 L
Mistroke
.01763 4e-05 L
.01785 4e-05 L
.01806 4e-05 L
.0183 4e-05 L
.01852 4e-05 L
.01874 4e-05 L
.01893 4e-05 L
.01915 4e-05 L
.01936 4e-05 L
.01956 4e-05 L
.01974 4e-05 L
.01993 4e-05 L
.02014 4e-05 L
.02035 4e-05 L
.02058 4e-05 L
.02079 4e-05 L
.02098 4e-05 L
.02121 4e-05 L
.02134 4e-05 L
.02146 4e-05 L
.02168 4e-05 L
.02191 4e-05 L
.02212 4e-05 L
.02234 4e-05 L
.02258 4e-05 L
.02281 4e-05 L
.02301 4e-05 L
.0232 4e-05 L
.02342 4e-05 L
.02363 4e-05 L
.02385 4e-05 L
.02409 4e-05 L
.0243 4e-05 L
.02452 4e-05 L
.02476 4e-05 L
.0249 4e-05 L
.02502 4e-05 L
.02526 4e-05 L
.02548 4e-05 L
.0257 4e-05 L
.02589 4e-05 L
.02611 4e-05 L
.02632 4e-05 L
.02651 4e-05 L
.02669 4e-05 L
.02689 4e-05 L
.02709 4e-05 L
.0273 4e-05 L
.02752 4e-05 L
.02774 4e-05 L
Mistroke
.02793 4e-05 L
.02815 4e-05 L
.02828 4e-05 L
.0284 4e-05 L
.02861 4e-05 L
.02884 4e-05 L
.02906 4e-05 L
.02931 4e-05 L
.02953 4e-05 L
.02974 4e-05 L
.02995 4e-05 L
.03014 4e-05 L
.03036 4e-05 L
.03057 4e-05 L
.0308 4e-05 L
.03104 4e-05 L
.03124 4e-05 L
.03146 4e-05 L
.0317 4e-05 L
.03184 4e-05 L
.03196 4e-05 L
.0322 4e-05 L
.03243 4e-05 L
.03262 4e-05 L
.03283 4e-05 L
.03306 4e-05 L
.03326 4e-05 L
.03346 4e-05 L
.03364 4e-05 L
.03383 4e-05 L
.03404 4e-05 L
.03425 4e-05 L
.03447 4e-05 L
.03468 4e-05 L
.03487 4e-05 L
.0351 4e-05 L
.03523 4e-05 L
.03534 4e-05 L
.03556 4e-05 L
.03579 4e-05 L
.03601 4e-05 L
.03625 4e-05 L
.03648 4e-05 L
.03669 4e-05 L
.0369 4e-05 L
.03709 4e-05 L
.03731 4e-05 L
.03752 4e-05 L
.03775 4e-05 L
.03799 4e-05 L
Mistroke
.03819 4e-05 L
.03842 4e-05 L
.03866 4e-05 L
.03879 4e-05 L
.03892 4e-05 L
.03916 4e-05 L
.03938 4e-05 L
.03958 4e-05 L
.03979 4e-05 L
.04001 4e-05 L
.04022 4e-05 L
.04041 4e-05 L
.04059 4e-05 L
.04079 4e-05 L
.04099 4e-05 L
.0412 4e-05 L
.04143 4e-05 L
.04164 4e-05 L
.04183 4e-05 L
.04206 4e-05 L
.04218 4e-05 L
.0423 4e-05 L
.04252 4e-05 L
.04275 4e-05 L
.04297 4e-05 L
.04321 4e-05 L
.04344 4e-05 L
.04365 4e-05 L
.04384 4e-05 L
.04405 4e-05 L
.04427 4e-05 L
.04448 4e-05 L
.04471 4e-05 L
.04495 4e-05 L
.04515 4e-05 L
.04538 4e-05 L
.04562 4e-05 L
.04576 4e-05 L
.04588 4e-05 L
.04612 4e-05 L
.04635 4e-05 L
.04654 4e-05 L
.04675 4e-05 L
.04698 4e-05 L
.04718 4e-05 L
.04738 4e-05 L
.04756 4e-05 L
.04776 4e-05 L
.04796 4e-05 L
.04817 4e-05 L
Mistroke
.04839 4e-05 L
.0486 4e-05 L
.0488 4e-05 L
.04902 4e-05 L
.04915 4e-05 L
.04927 4e-05 L
.04948 4e-05 L
.04971 4e-05 L
.04993 4e-05 L
.05006 4e-05 L
.05018 4e-05 L
.05039 4e-05 L
.05062 4e-05 L
.05082 4e-05 L
.05102 4e-05 L
.05123 4e-05 L
.05145 4e-05 L
.05168 4e-05 L
.05181 4e-05 L
.05193 4e-05 L
.05217 4e-05 L
.0523 4e-05 L
.05243 4e-05 L
.05265 4e-05 L
.05288 4e-05 L
.05311 4e-05 L
.05332 4e-05 L
.05351 4e-05 L
.05372 4e-05 L
.05392 4e-05 L
.0541 4e-05 L
.05431 4e-05 L
.05454 4e-05 L
.05475 4e-05 L
.05495 4e-05 L
.05518 4e-05 L
.05539 4e-05 L
.05559 4e-05 L
.05579 4e-05 L
.05602 4e-05 L
.05626 4e-05 L
.05646 4e-05 L
.05669 4e-05 L
.05693 4e-05 L
.05715 4e-05 L
.05726 4e-05 L
.05739 4e-05 L
.05753 4e-05 L
.05765 4e-05 L
.05788 4e-05 L
Mistroke
.05809 4e-05 L
.05833 4e-05 L
.05857 4e-05 L
.05877 4e-05 L
.05899 4e-05 L
.0592 4e-05 L
.05938 4e-05 L
.0596 4e-05 L
.05984 4e-05 L
.06007 4e-05 L
.06028 4e-05 L
.0605 4e-05 L
.06074 4e-05 L
.06096 4e-05 L
.06117 4e-05 L
.06141 4e-05 L
.06154 4e-05 L
.06167 4e-05 L
.0619 4e-05 L
.06202 4e-05 L
.06215 4e-05 L
.06227 4e-05 L
.0624 4e-05 L
.06264 4e-05 L
.06277 4e-05 L
.06289 4e-05 L
.06302 4e-05 L
.06316 4e-05 L
.06329 4e-05 L
.06342 4e-05 L
.06355 4e-05 L
.06366 4e-05 L
.06389 4e-05 L
.06412 4e-05 L
.06434 4e-05 L
.06458 4e-05 L
.06481 4e-05 L
.06502 4e-05 L
.06523 4e-05 L
.06542 4e-05 L
.06564 4e-05 L
.06585 4e-05 L
.06608 4e-05 L
.06632 4e-05 L
.06652 4e-05 L
.06675 4e-05 L
.06699 4e-05 L
.06712 4e-05 L
.06725 4e-05 L
.06749 4e-05 L
Mistroke
.06771 4e-05 L
.0679 4e-05 L
.06812 4e-05 L
.06834 4e-05 L
.06855 4e-05 L
.06874 4e-05 L
.06892 4e-05 L
.06912 4e-05 L
.06932 4e-05 L
.06953 4e-05 L
.06976 4e-05 L
.06997 4e-05 L
.07016 4e-05 L
.07039 4e-05 L
.07051 4e-05 L
.07063 4e-05 L
.07085 4e-05 L
.07107 4e-05 L
.0713 4e-05 L
.07154 4e-05 L
.07177 4e-05 L
.07198 4e-05 L
.07219 4e-05 L
.07238 4e-05 L
.0726 4e-05 L
.07281 4e-05 L
.07304 4e-05 L
.07328 4e-05 L
.07348 4e-05 L
.07371 4e-05 L
.07395 4e-05 L
.07408 4e-05 L
.07421 4e-05 L
.07445 4e-05 L
.07467 4e-05 L
.07487 4e-05 L
.07508 4e-05 L
.0753 4e-05 L
.07551 4e-05 L
.07571 4e-05 L
.07588 4e-05 L
.07609 4e-05 L
.07629 4e-05 L
.0765 4e-05 L
.07672 4e-05 L
.07693 4e-05 L
.07712 4e-05 L
.07735 4e-05 L
.07748 4e-05 L
.07759 4e-05 L
Mistroke
.07781 4e-05 L
.07804 4e-05 L
.07826 4e-05 L
.07839 4e-05 L
.0785 4e-05 L
.07872 4e-05 L
.07895 4e-05 L
.07915 4e-05 L
.07934 4e-05 L
.07955 4e-05 L
.07978 4e-05 L
.08 4e-05 L
.08013 4e-05 L
.08025 4e-05 L
.08049 4e-05 L
.08063 4e-05 L
.08075 4e-05 L
.08097 4e-05 L
.08121 4e-05 L
.08144 4e-05 L
.08164 4e-05 L
.08184 4e-05 L
.08205 4e-05 L
.08224 4e-05 L
.08242 4e-05 L
.08263 4e-05 L
.08286 4e-05 L
.08308 4e-05 L
.08328 4e-05 L
.08351 4e-05 L
.08372 4e-05 L
.08391 4e-05 L
.08412 4e-05 L
.08434 4e-05 L
.08458 4e-05 L
.08479 4e-05 L
.08501 4e-05 L
.08525 4e-05 L
.08547 4e-05 L
.08559 4e-05 L
.08572 4e-05 L
.08585 4e-05 L
.08598 4e-05 L
.0862 4e-05 L
.08641 4e-05 L
.08665 4e-05 L
.08689 4e-05 L
.08709 4e-05 L
.08731 4e-05 L
.08752 4e-05 L
Mistroke
.08771 4e-05 L
.08793 4e-05 L
.08817 4e-05 L
.08839 4e-05 L
.0886 4e-05 L
.08882 4e-05 L
.08906 4e-05 L
.08928 4e-05 L
.08949 4e-05 L
.08973 4e-05 L
.08987 4e-05 L
.08999 4e-05 L
.09022 4e-05 L
.09034 4e-05 L
.09047 4e-05 L
.09059 4e-05 L
.09072 4e-05 L
.09096 4e-05 L
.09109 4e-05 L
.09121 4e-05 L
.09134 4e-05 L
.09149 4e-05 L
.09161 4e-05 L
.09174 4e-05 L
.09187 4e-05 L
.09199 4e-05 L
.09221 4e-05 L
.09244 4e-05 L
.09266 4e-05 L
.09291 4e-05 L
.09313 4e-05 L
.09335 4e-05 L
.09356 4e-05 L
.09375 4e-05 L
.09397 4e-05 L
.09417 4e-05 L
.0944 4e-05 L
.09464 4e-05 L
.09484 4e-05 L
.09507 4e-05 L
.09531 4e-05 L
.09544 4e-05 L
.09557 4e-05 L
.09581 4e-05 L
.09603 4e-05 L
.09623 4e-05 L
.09644 4e-05 L
.09666 4e-05 L
.09687 4e-05 L
.09706 4e-05 L
Mistroke
.09724 4e-05 L
.09744 4e-05 L
.09764 4e-05 L
.09785 4e-05 L
.09808 4e-05 L
.09829 4e-05 L
.09848 4e-05 L
.09871 4e-05 L
.09883 4e-05 L
.09895 4e-05 L
.09917 4e-05 L
.09939 4e-05 L
.09962 4e-05 L
.09986 4e-05 L
.10009 4e-05 L
.1003 4e-05 L
.10051 4e-05 L
.1007 4e-05 L
.10092 4e-05 L
.10113 4e-05 L
.10136 4e-05 L
.1016 4e-05 L
.1018 4e-05 L
.10202 4e-05 L
.10227 4e-05 L
.1024 4e-05 L
.10252 4e-05 L
.10276 4e-05 L
.10299 4e-05 L
.10318 4e-05 L
.1034 4e-05 L
.10362 4e-05 L
.10383 4e-05 L
.10402 4e-05 L
.1042 4e-05 L
.10441 4e-05 L
.1046 4e-05 L
.10481 4e-05 L
.10504 4e-05 L
.10525 4e-05 L
.10544 4e-05 L
.10567 4e-05 L
.10579 4e-05 L
.10591 4e-05 L
.10613 4e-05 L
.10635 4e-05 L
.10658 4e-05 L
.1067 4e-05 L
.10682 4e-05 L
.10704 4e-05 L
Mistroke
.10726 4e-05 L
.10747 4e-05 L
.10766 4e-05 L
.10787 4e-05 L
.10809 4e-05 L
.10832 4e-05 L
.10845 4e-05 L
.10857 4e-05 L
.10881 4e-05 L
.10894 4e-05 L
.10907 4e-05 L
.10929 4e-05 L
.10953 4e-05 L
.10975 4e-05 L
.10996 4e-05 L
.11015 4e-05 L
.11036 4e-05 L
.11056 4e-05 L
.11074 4e-05 L
.11095 4e-05 L
.11118 4e-05 L
.11139 4e-05 L
.11159 4e-05 L
.11182 4e-05 L
.11203 4e-05 L
.11223 4e-05 L
.11243 4e-05 L
.11266 4e-05 L
.1129 4e-05 L
.1131 4e-05 L
.11333 4e-05 L
.11357 4e-05 L
.11379 4e-05 L
.1139 4e-05 L
.11403 4e-05 L
.11416 4e-05 L
.11429 4e-05 L
.11452 4e-05 L
.11473 4e-05 L
.11496 4e-05 L
.1152 4e-05 L
.11541 4e-05 L
.11563 4e-05 L
.11583 4e-05 L
.11602 4e-05 L
.11624 4e-05 L
.11648 4e-05 L
.11671 4e-05 L
.11691 4e-05 L
.11713 4e-05 L
Mistroke
.11737 4e-05 L
.1176 4e-05 L
.1178 4e-05 L
.11804 4e-05 L
.11818 4e-05 L
.1183 4e-05 L
.11854 4e-05 L
.11865 4e-05 L
.11878 4e-05 L
.1189 4e-05 L
.11904 4e-05 L
.11927 4e-05 L
.1194 4e-05 L
.11952 4e-05 L
.11966 4e-05 L
.1198 4e-05 L
.11992 4e-05 L
.12006 4e-05 L
.12018 4e-05 L
.1203 4e-05 L
.12052 4e-05 L
.12076 4e-05 L
.12098 4e-05 L
.12122 4e-05 L
.12145 4e-05 L
.12166 4e-05 L
.12187 4e-05 L
.12206 4e-05 L
.12228 4e-05 L
.12248 4e-05 L
.12271 4e-05 L
.12295 4e-05 L
.12315 4e-05 L
.12338 4e-05 L
.12362 4e-05 L
.12375 4e-05 L
.12388 4e-05 L
.12412 4e-05 L
.12434 4e-05 L
.12454 4e-05 L
.12475 4e-05 L
.12497 4e-05 L
.12518 4e-05 L
.12537 4e-05 L
.12555 4e-05 L
.12575 4e-05 L
.12595 4e-05 L
.12616 4e-05 L
.12639 4e-05 L
.1266 4e-05 L
Mistroke
.12679 4e-05 L
.12702 4e-05 L
.12714 4e-05 L
.12726 4e-05 L
.12748 4e-05 L
.1277 4e-05 L
.12793 4e-05 L
.12817 4e-05 L
.1284 4e-05 L
.12861 4e-05 L
.12882 4e-05 L
.12901 4e-05 L
.12923 4e-05 L
.12944 4e-05 L
.12967 4e-05 L
.1299 4e-05 L
.13011 4e-05 L
.13033 4e-05 L
.13057 4e-05 L
.13071 4e-05 L
.13083 4e-05 L
.13107 4e-05 L
.1313 4e-05 L
.13149 4e-05 L
.13171 4e-05 L
.13193 4e-05 L
.13214 4e-05 L
.13233 4e-05 L
.13251 4e-05 L
.13271 4e-05 L
.13291 4e-05 L
.13312 4e-05 L
.13335 4e-05 L
.13356 4e-05 L
.13375 4e-05 L
.13398 4e-05 L
.1341 4e-05 L
.13422 4e-05 L
.13444 4e-05 L
.13466 4e-05 L
.13489 4e-05 L
.13501 4e-05 L
.13513 4e-05 L
.13534 4e-05 L
.13557 4e-05 L
.13578 4e-05 L
.13597 4e-05 L
.13618 4e-05 L
.1364 4e-05 L
.13663 4e-05 L
Mistroke
.13676 4e-05 L
.13687 4e-05 L
.13712 4e-05 L
.13725 4e-05 L
.13737 4e-05 L
.13759 4e-05 L
.13783 4e-05 L
.13806 4e-05 L
.13827 4e-05 L
.13846 4e-05 L
.13867 4e-05 L
.13886 4e-05 L
.13904 4e-05 L
.13925 4e-05 L
.13948 4e-05 L
.1397 4e-05 L
.1399 4e-05 L
.14013 4e-05 L
.14034 4e-05 L
.14053 4e-05 L
.14074 4e-05 L
.14096 4e-05 L
.1412 4e-05 L
.14141 4e-05 L
.14163 4e-05 L
.14187 4e-05 L
.14209 4e-05 L
.14221 4e-05 L
.14234 4e-05 L
.14247 4e-05 L
.1426 4e-05 L
.14282 4e-05 L
.14303 4e-05 L
.14327 4e-05 L
.14351 4e-05 L
.14371 4e-05 L
.14393 4e-05 L
.14414 4e-05 L
.14432 4e-05 L
.14455 4e-05 L
.14478 4e-05 L
.14501 4e-05 L
.14522 4e-05 L
.14544 4e-05 L
.14568 4e-05 L
.1459 4e-05 L
.14611 4e-05 L
.14635 4e-05 L
.14648 4e-05 L
.14661 4e-05 L
Mistroke
.14684 4e-05 L
.14697 4e-05 L
.14708 4e-05 L
.14721 4e-05 L
.14734 4e-05 L
.14757 4e-05 L
.1477 4e-05 L
.14783 4e-05 L
.14796 4e-05 L
.1481 4e-05 L
.14823 4e-05 L
.14836 4e-05 L
.14849 4e-05 L
.1486 4e-05 L
.14883 4e-05 L
.14906 4e-05 L
.14928 4e-05 L
.14952 4e-05 L
.14975 4e-05 L
.14996 4e-05 L
.15017 4e-05 L
.15036 4e-05 L
.15058 4e-05 L
.15079 4e-05 L
.15101 4e-05 L
.15125 4e-05 L
.15146 4e-05 L
.15168 4e-05 L
.15192 4e-05 L
.15206 4e-05 L
.15218 4e-05 L
.15242 4e-05 L
.15265 4e-05 L
.15284 4e-05 L
.15305 4e-05 L
.15327 4e-05 L
.15348 4e-05 L
.15368 4e-05 L
.15385 4e-05 L
.15405 4e-05 L
.15426 4e-05 L
.15446 4e-05 L
.15469 4e-05 L
.1549 4e-05 L
.15509 4e-05 L
.15532 4e-05 L
.15544 4e-05 L
.15556 4e-05 L
.15578 4e-05 L
.15601 4e-05 L
Mistroke
.15623 4e-05 L
.15647 4e-05 L
.1567 4e-05 L
.15691 4e-05 L
.15712 4e-05 L
.15731 4e-05 L
.15753 4e-05 L
.15774 4e-05 L
.15797 4e-05 L
.15821 4e-05 L
.15841 4e-05 L
.15863 4e-05 L
.15888 4e-05 L
.15901 4e-05 L
.15913 4e-05 L
.15937 4e-05 L
.1596 4e-05 L
.15979 4e-05 L
.16001 4e-05 L
.16023 4e-05 L
.16044 4e-05 L
.16063 4e-05 L
.16081 4e-05 L
.16101 4e-05 L
.16121 4e-05 L
.16142 4e-05 L
.16165 4e-05 L
.16186 4e-05 L
.16205 4e-05 L
.16227 4e-05 L
.1624 4e-05 L
.16252 4e-05 L
.16273 4e-05 L
.16296 4e-05 L
.16319 4e-05 L
.16331 4e-05 L
.16343 4e-05 L
.16364 4e-05 L
.16387 4e-05 L
.16407 4e-05 L
.16426 4e-05 L
.16447 4e-05 L
.1647 4e-05 L
.16493 4e-05 L
.16505 4e-05 L
.16517 4e-05 L
.16541 4e-05 L
.16555 4e-05 L
.16567 4e-05 L
.16589 4e-05 L
Mistroke
.16613 4e-05 L
.16636 4e-05 L
.16656 4e-05 L
.16676 4e-05 L
.16697 4e-05 L
.16716 4e-05 L
.16734 4e-05 L
.16755 4e-05 L
.16778 4e-05 L
.168 4e-05 L
.1682 4e-05 L
.16842 4e-05 L
.16864 4e-05 L
.16883 4e-05 L
.16904 4e-05 L
.16926 4e-05 L
.1695 4e-05 L
.16971 4e-05 L
.16993 4e-05 L
.17009 4e-05 L
.17024 4e-05 L
.17041 4e-05 L
.17058 4e-05 L
.17073 4e-05 L
.17087 4e-05 L
.17103 4e-05 L
.1712 4e-05 L
.17134 4e-05 L
.17149 4e-05 L
.17165 4e-05 L
.1718 4e-05 L
.17194 4e-05 L
.17207 4e-05 L
.17221 4e-05 L
.17235 4e-05 L
.1725 4e-05 L
.17267 4e-05 L
.17284 4e-05 L
.173 4e-05 L
.17315 4e-05 L
.17329 4e-05 L
.17345 4e-05 L
.1736 4e-05 L
.17376 4e-05 L
.17393 4e-05 L
.17409 4e-05 L
.17424 4e-05 L
.17442 4e-05 L
.17461 4e-05 L
.17478 4e-05 L
Mistroke
.17495 4e-05 L
Mfstroke
4e-05 .13451 m
.00713 .13989 L
.01487 .14575 L
.02214 .15126 L
.02913 .15655 L
.03657 .16219 L
.04373 .16762 L
.05134 .17338 L
.05867 .17894 L
.06573 .18429 L
.07324 .18998 L
.08046 .19546 L
.08741 .20073 L
.09481 .20634 L
.10193 .21174 L
.1095 .21748 L
.11679 .22302 L
.12381 .22834 L
.13127 .234 L
.13846 .23946 L
.1461 .24525 L
.15345 .25084 L
.16053 .25622 L
.16806 .26194 L
.17495 .26716 L
s
.94766 .84358 m
.94978 .84521 L
.9521 .84699 L
.95427 .84866 L
.95636 .85027 L
.95858 .85197 L
.96072 .85362 L
.963 .85537 L
.96519 .85705 L
.9673 .85867 L
.96955 .86039 L
.97171 .86205 L
.97379 .86365 L
.976 .86534 L
.97813 .86698 L
.98039 .86871 L
.98257 .87038 L
.98467 .87199 L
.9869 .8737 L
.98905 .87535 L
.99133 .8771 L
.99353 .87878 L
.99565 .8804 L
.9979 .88213 L
.99996 .8837 L
s
.94766 .99996 m
.94978 .99996 L
.9521 .99996 L
.95427 .99996 L
.95636 .99996 L
.95858 .99996 L
.96072 .99996 L
.963 .99996 L
.96519 .99996 L
.9673 .99996 L
.96955 .99996 L
.97171 .99996 L
.97379 .99996 L
.976 .99996 L
.97813 .99996 L
.98039 .99996 L
.98257 .99996 L
.98467 .99996 L
.9869 .99996 L
.98905 .99996 L
.99133 .99996 L
.99353 .99996 L
.99565 .99996 L
.9979 .99996 L
.99996 .99996 L
s
.5 1 1 r
.94766 .84358 m
.94978 .84521 L
.9521 .84699 L
.95427 .84866 L
.95636 .85027 L
.95858 .85197 L
.96072 .85362 L
.963 .85537 L
.96519 .85705 L
.9673 .85867 L
.96955 .86039 L
.97171 .86205 L
.97379 .86365 L
.976 .86534 L
.97813 .86698 L
.98039 .86871 L
.98257 .87038 L
.98467 .87199 L
.9869 .8737 L
.98905 .87535 L
.99133 .8771 L
.99353 .87878 L
.99565 .8804 L
.9979 .88213 L
.99996 .8837 L
.99996 .99996 L
.9979 .99996 L
.99565 .99996 L
.99353 .99996 L
.99133 .99996 L
.98905 .99996 L
.9869 .99996 L
.98467 .99996 L
.98257 .99996 L
.98039 .99996 L
.97813 .99996 L
.976 .99996 L
.97379 .99996 L
.97171 .99996 L
.96955 .99996 L
.9673 .99996 L
.96519 .99996 L
.963 .99996 L
.96072 .99996 L
.95858 .99996 L
.95636 .99996 L
.95427 .99996 L
.9521 .99996 L
.94978 .99996 L
.94766 .99996 L
F
0 g
.94766 .84358 m
.94978 .84521 L
.9521 .84699 L
.95427 .84866 L
.95636 .85027 L
.95858 .85197 L
.96072 .85362 L
.963 .85537 L
.96519 .85705 L
.9673 .85867 L
.96955 .86039 L
.97171 .86205 L
.97379 .86365 L
.976 .86534 L
.97813 .86698 L
.98039 .86871 L
.98257 .87038 L
.98467 .87199 L
.9869 .8737 L
.98905 .87535 L
.99133 .8771 L
.99353 .87878 L
.99565 .8804 L
.9979 .88213 L
.99996 .8837 L
s
.94766 .99996 m
.94978 .99996 L
.9521 .99996 L
.95427 .99996 L
.95636 .99996 L
.95858 .99996 L
.96072 .99996 L
.963 .99996 L
.96519 .99996 L
.9673 .99996 L
.96955 .99996 L
.97171 .99996 L
.97379 .99996 L
.976 .99996 L
.97813 .99996 L
.98039 .99996 L
.98257 .99996 L
.98467 .99996 L
.9869 .99996 L
.98905 .99996 L
.99133 .99996 L
.99353 .99996 L
.99565 .99996 L
.9979 .99996 L
.99996 .99996 L
s
.17495 4e-05 m
.20629 .04016 L
.24048 .0839 L
.27259 .12494 L
.30346 .16437 L
.33633 .2063 L
.36797 .24659 L
.40159 .28934 L
.43399 .3304 L
.46516 .36976 L
.49831 .41139 L
.53024 .45114 L
.56094 .48885 L
.59363 .52815 L
.62508 .5646 L
.65853 .6011 L
.69075 .63348 L
.72174 .66217 L
.75471 .69075 L
.78646 .71705 L
.8202 .74421 L
.85271 .7699 L
.88399 .79434 L
.91725 .82013 L
.94766 .84358 L
s
.17495 .26716 m
.20629 .29099 L
.24048 .31699 L
.27259 .34145 L
.30346 .36501 L
.33633 .39013 L
.36797 .41437 L
.40159 .44022 L
.43399 .46525 L
.46516 .48947 L
.49831 .51548 L
.53024 .54087 L
.56094 .56577 L
.59363 .59316 L
.62508 .62089 L
.65853 .65262 L
.69075 .68596 L
.72174 .72049 L
.75471 .75918 L
.78646 .79765 L
.8202 .83931 L
.85271 .87993 L
.88399 .9193 L
.91725 .96138 L
.94766 .99996 L
s
.5 1 1 r
.17495 4e-05 m
.20629 .04016 L
.24048 .0839 L
.27259 .12494 L
.30346 .16437 L
.33633 .2063 L
.36797 .24659 L
.40159 .28934 L
.43399 .3304 L
.46516 .36976 L
.49831 .41139 L
.53024 .45114 L
.56094 .48885 L
.59363 .52815 L
.62508 .5646 L
.65853 .6011 L
.69075 .63348 L
.72174 .66217 L
.75471 .69075 L
.78646 .71705 L
.8202 .74421 L
.85271 .7699 L
.88399 .79434 L
.91725 .82013 L
.94766 .84358 L
.94766 .99996 L
.91725 .96138 L
.88399 .9193 L
.85271 .87993 L
.8202 .83931 L
.78646 .79765 L
.75471 .75918 L
.72174 .72049 L
.69075 .68596 L
.65853 .65262 L
.62508 .62089 L
.59363 .59316 L
.56094 .56577 L
.53024 .54087 L
.49831 .51548 L
.46516 .48947 L
.43399 .46525 L
.40159 .44022 L
.36797 .41437 L
.33633 .39013 L
.30346 .36501 L
.27259 .34145 L
.24048 .31699 L
.20629 .29099 L
.17495 .26716 L
F
0 g
.17495 4e-05 m
.20629 .04016 L
.24048 .0839 L
.27259 .12494 L
.30346 .16437 L
.33633 .2063 L
.36797 .24659 L
.40159 .28934 L
.43399 .3304 L
.46516 .36976 L
.49831 .41139 L
.53024 .45114 L
.56094 .48885 L
.59363 .52815 L
.62508 .5646 L
.65853 .6011 L
.69075 .63348 L
.72174 .66217 L
.75471 .69075 L
.78646 .71705 L
.8202 .74421 L
.85271 .7699 L
.88399 .79434 L
.91725 .82013 L
.94766 .84358 L
s
.17495 .26716 m
.20629 .29099 L
.24048 .31699 L
.27259 .34145 L
.30346 .36501 L
.33633 .39013 L
.36797 .41437 L
.40159 .44022 L
.43399 .46525 L
.46516 .48947 L
.49831 .51548 L
.53024 .54087 L
.56094 .56577 L
.59363 .59316 L
.62508 .62089 L
.65853 .65262 L
.69075 .68596 L
.72174 .72049 L
.75471 .75918 L
.78646 .79765 L
.8202 .83931 L
.85271 .87993 L
.88399 .9193 L
.91725 .96138 L
.94766 .99996 L
s
4e-05 .13451 m
.00713 .13989 L
.01487 .14575 L
.02214 .15126 L
.02913 .15655 L
.03657 .16219 L
.04373 .16762 L
.05134 .17338 L
.05867 .17894 L
.06573 .18429 L
.07324 .18998 L
.08046 .19546 L
.08741 .20073 L
.09481 .20634 L
.10193 .21174 L
.1095 .21748 L
.11679 .22302 L
.12381 .22834 L
.13127 .234 L
.13846 .23946 L
.1461 .24525 L
.15345 .25084 L
.16053 .25622 L
.16806 .26194 L
.17495 .26716 L
s
4e-05 .99996 m
.00713 .99996 L
.01487 .99996 L
.02214 .99996 L
.02913 .99996 L
.03657 .99996 L
.04373 .99996 L
.05134 .99996 L
.05867 .99996 L
.06573 .99996 L
.07324 .99996 L
.08046 .99996 L
.08741 .99996 L
.09481 .99996 L
.10193 .99996 L
.1095 .99996 L
.11679 .99996 L
.12381 .99996 L
.13127 .99996 L
.13846 .99996 L
.1461 .99996 L
.15345 .99996 L
.16053 .99996 L
.16806 .99996 L
.17495 .99996 L
s
1 1 .5 r
4e-05 .13451 m
.00713 .13989 L
.01487 .14575 L
.02214 .15126 L
.02913 .15655 L
.03657 .16219 L
.04373 .16762 L
.05134 .17338 L
.05867 .17894 L
.06573 .18429 L
.07324 .18998 L
.08046 .19546 L
.08741 .20073 L
.09481 .20634 L
.10193 .21174 L
.1095 .21748 L
.11679 .22302 L
.12381 .22834 L
.13127 .234 L
.13846 .23946 L
.1461 .24525 L
.15345 .25084 L
.16053 .25622 L
.16806 .26194 L
.17495 .26716 L
.17495 .99996 L
.16806 .99996 L
.16053 .99996 L
.15345 .99996 L
.1461 .99996 L
.13846 .99996 L
.13127 .99996 L
.12381 .99996 L
.11679 .99996 L
.1095 .99996 L
.10193 .99996 L
.09481 .99996 L
.08741 .99996 L
.08046 .99996 L
.07324 .99996 L
.06573 .99996 L
.05867 .99996 L
.05134 .99996 L
.04373 .99996 L
.03657 .99996 L
.02913 .99996 L
.02214 .99996 L
.01487 .99996 L
.00713 .99996 L
4e-05 .99996 L
F
0 g
4e-05 .13451 m
.00713 .13989 L
.01487 .14575 L
.02214 .15126 L
.02913 .15655 L
.03657 .16219 L
.04373 .16762 L
.05134 .17338 L
.05867 .17894 L
.06573 .18429 L
.07324 .18998 L
.08046 .19546 L
.08741 .20073 L
.09481 .20634 L
.10193 .21174 L
.1095 .21748 L
.11679 .22302 L
.12381 .22834 L
.13127 .234 L
.13846 .23946 L
.1461 .24525 L
.15345 .25084 L
.16053 .25622 L
.16806 .26194 L
.17495 .26716 L
s
4e-05 .99996 m
.00713 .99996 L
.01487 .99996 L
.02214 .99996 L
.02913 .99996 L
.03657 .99996 L
.04373 .99996 L
.05134 .99996 L
.05867 .99996 L
.06573 .99996 L
.07324 .99996 L
.08046 .99996 L
.08741 .99996 L
.09481 .99996 L
.10193 .99996 L
.1095 .99996 L
.11679 .99996 L
.12381 .99996 L
.13127 .99996 L
.13846 .99996 L
.1461 .99996 L
.15345 .99996 L
.16053 .99996 L
.16806 .99996 L
.17495 .99996 L
s
.94766 4e-05 m
.94772 4e-05 L
.94778 4e-05 L
.94785 4e-05 L
.94791 4e-05 L
.94797 4e-05 L
.94803 4e-05 L
.94809 4e-05 L
.94815 4e-05 L
.94822 4e-05 L
.94829 4e-05 L
.94835 4e-05 L
.94841 4e-05 L
.94848 4e-05 L
.94852 4e-05 L
.94855 4e-05 L
.94862 4e-05 L
.94869 4e-05 L
.94873 4e-05 L
.94877 4e-05 L
.94883 4e-05 L
.94887 4e-05 L
.94891 4e-05 L
.94895 4e-05 L
.94899 4e-05 L
.94902 4e-05 L
.94906 4e-05 L
.94913 4e-05 L
.9492 4e-05 L
.94926 4e-05 L
.94932 4e-05 L
.94938 4e-05 L
.94945 4e-05 L
.94951 4e-05 L
.94958 4e-05 L
.94965 4e-05 L
.94971 4e-05 L
.94978 4e-05 L
.94982 4e-05 L
.94986 4e-05 L
.9499 4e-05 L
.94994 4e-05 L
.95001 4e-05 L
.95005 4e-05 L
.95008 4e-05 L
.95015 4e-05 L
.95022 4e-05 L
.95025 4e-05 L
.95029 4e-05 L
.95036 4e-05 L
Mistroke
.9504 4e-05 L
.95044 4e-05 L
.95048 4e-05 L
.95052 4e-05 L
.95056 4e-05 L
.9506 4e-05 L
.95064 4e-05 L
.95068 4e-05 L
.95072 4e-05 L
.95076 4e-05 L
.9508 4e-05 L
.95084 4e-05 L
.95091 4e-05 L
.95094 4e-05 L
.95098 4e-05 L
.95104 4e-05 L
.95111 4e-05 L
.95118 4e-05 L
.95124 4e-05 L
.9513 4e-05 L
.95138 4e-05 L
.95141 4e-05 L
.95145 4e-05 L
.95152 4e-05 L
.95156 4e-05 L
.9516 4e-05 L
.95163 4e-05 L
.95168 4e-05 L
.95175 4e-05 L
.95179 4e-05 L
.95182 4e-05 L
.95189 4e-05 L
.95195 4e-05 L
.95203 4e-05 L
.9521 4e-05 L
.95216 4e-05 L
.95222 4e-05 L
.95229 4e-05 L
.95235 4e-05 L
.95241 4e-05 L
.95248 4e-05 L
.95252 4e-05 L
.95256 4e-05 L
.95262 4e-05 L
.95266 4e-05 L
.9527 4e-05 L
.95274 4e-05 L
.95278 4e-05 L
.95284 4e-05 L
.95288 4e-05 L
Mistroke
.95292 4e-05 L
.95299 4e-05 L
.95305 4e-05 L
.95312 4e-05 L
.95319 4e-05 L
.95325 4e-05 L
.95331 4e-05 L
.95338 4e-05 L
.95344 4e-05 L
.9535 4e-05 L
.95355 4e-05 L
.95361 4e-05 L
.95367 4e-05 L
.95373 4e-05 L
.9538 4e-05 L
.95386 4e-05 L
.95392 4e-05 L
.95399 4e-05 L
.95403 4e-05 L
.95406 4e-05 L
.95413 4e-05 L
.9542 4e-05 L
.95426 4e-05 L
.95433 4e-05 L
.9544 4e-05 L
.95447 4e-05 L
.95453 4e-05 L
.95459 4e-05 L
.95465 4e-05 L
.95471 4e-05 L
.95478 4e-05 L
.95485 4e-05 L
.95491 4e-05 L
.95498 4e-05 L
.95505 4e-05 L
.95509 4e-05 L
.95513 4e-05 L
.9552 4e-05 L
.95527 4e-05 L
.95533 4e-05 L
.95539 4e-05 L
.95546 4e-05 L
.95552 4e-05 L
.95558 4e-05 L
.95563 4e-05 L
.95569 4e-05 L
.95575 4e-05 L
.95581 4e-05 L
.95588 4e-05 L
.95594 4e-05 L
Mistroke
.956 4e-05 L
.95607 4e-05 L
.9561 4e-05 L
.95614 4e-05 L
.9562 4e-05 L
.95627 4e-05 L
.95634 4e-05 L
.95641 4e-05 L
.95648 4e-05 L
.95654 4e-05 L
.9566 4e-05 L
.95666 4e-05 L
.95673 4e-05 L
.95679 4e-05 L
.95686 4e-05 L
.95693 4e-05 L
.95699 4e-05 L
.95706 4e-05 L
.95713 4e-05 L
.95717 4e-05 L
.95721 4e-05 L
.95728 4e-05 L
.95734 4e-05 L
.9574 4e-05 L
.95747 4e-05 L
.95753 4e-05 L
.95759 4e-05 L
.95765 4e-05 L
.95771 4e-05 L
.95776 4e-05 L
.95783 4e-05 L
.95789 4e-05 L
.95796 4e-05 L
.95802 4e-05 L
.95808 4e-05 L
.95814 4e-05 L
.95818 4e-05 L
.95822 4e-05 L
.95828 4e-05 L
.95835 4e-05 L
.95842 4e-05 L
.95849 4e-05 L
.95856 4e-05 L
.95862 4e-05 L
.95868 4e-05 L
.95874 4e-05 L
.95881 4e-05 L
.95887 4e-05 L
.95894 4e-05 L
.95901 4e-05 L
Mistroke
.95907 4e-05 L
.95913 4e-05 L
.95921 4e-05 L
.95925 4e-05 L
.95928 4e-05 L
.95936 4e-05 L
.95942 4e-05 L
.95948 4e-05 L
.95955 4e-05 L
.95961 4e-05 L
.95967 4e-05 L
.95973 4e-05 L
.95979 4e-05 L
.95984 4e-05 L
.95991 4e-05 L
.95997 4e-05 L
.96004 4e-05 L
.9601 4e-05 L
.96016 4e-05 L
.96022 4e-05 L
.96026 4e-05 L
.9603 4e-05 L
.96036 4e-05 L
.96043 4e-05 L
.9605 4e-05 L
.96057 4e-05 L
.96064 4e-05 L
.9607 4e-05 L
.96076 4e-05 L
.96082 4e-05 L
.96089 4e-05 L
.96095 4e-05 L
.96102 4e-05 L
.96109 4e-05 L
.96115 4e-05 L
.96122 4e-05 L
.96129 4e-05 L
.96133 4e-05 L
.96137 4e-05 L
.96144 4e-05 L
.96151 4e-05 L
.96156 4e-05 L
.96163 4e-05 L
.96169 4e-05 L
.96176 4e-05 L
.96182 4e-05 L
.96187 4e-05 L
.96193 4e-05 L
.96199 4e-05 L
.96205 4e-05 L
Mistroke
.96212 4e-05 L
.96218 4e-05 L
.96224 4e-05 L
.96231 4e-05 L
.96234 4e-05 L
.96238 4e-05 L
.96244 4e-05 L
.96251 4e-05 L
.96258 4e-05 L
.96262 4e-05 L
.96265 4e-05 L
.96272 4e-05 L
.96278 4e-05 L
.96285 4e-05 L
.9629 4e-05 L
.96297 4e-05 L
.96303 4e-05 L
.9631 4e-05 L
.96314 4e-05 L
.96317 4e-05 L
.96325 4e-05 L
.96329 4e-05 L
.96332 4e-05 L
.96339 4e-05 L
.96346 4e-05 L
.96353 4e-05 L
.96359 4e-05 L
.96365 4e-05 L
.96371 4e-05 L
.96377 4e-05 L
.96382 4e-05 L
.96389 4e-05 L
.96396 4e-05 L
.96402 4e-05 L
.96408 4e-05 L
.96415 4e-05 L
.96421 4e-05 L
.96427 4e-05 L
.96433 4e-05 L
.9644 4e-05 L
.96447 4e-05 L
.96453 4e-05 L
.9646 4e-05 L
.96467 4e-05 L
.96474 4e-05 L
.96477 4e-05 L
.96481 4e-05 L
.96485 4e-05 L
.96489 4e-05 L
.96496 4e-05 L
Mistroke
.96502 4e-05 L
.96509 4e-05 L
.96516 4e-05 L
.96522 4e-05 L
.96529 4e-05 L
.96535 4e-05 L
.9654 4e-05 L
.96547 4e-05 L
.96554 4e-05 L
.96561 4e-05 L
.96567 4e-05 L
.96574 4e-05 L
.96581 4e-05 L
.96588 4e-05 L
.96594 4e-05 L
.96601 4e-05 L
.96605 4e-05 L
.96609 4e-05 L
.96616 4e-05 L
.96619 4e-05 L
.96623 4e-05 L
.96627 4e-05 L
.96631 4e-05 L
.96638 4e-05 L
.96642 4e-05 L
.96645 4e-05 L
.96649 4e-05 L
.96654 4e-05 L
.96657 4e-05 L
.96661 4e-05 L
.96665 4e-05 L
.96669 4e-05 L
.96675 4e-05 L
.96682 4e-05 L
.96689 4e-05 L
.96696 4e-05 L
.96703 4e-05 L
.96709 4e-05 L
.96715 4e-05 L
.96721 4e-05 L
.96728 4e-05 L
.96734 4e-05 L
.96741 4e-05 L
.96748 4e-05 L
.96754 4e-05 L
.96761 4e-05 L
.96768 4e-05 L
.96772 4e-05 L
.96776 4e-05 L
.96783 4e-05 L
Mistroke
.9679 4e-05 L
.96795 4e-05 L
.96802 4e-05 L
.96808 4e-05 L
.96815 4e-05 L
.9682 4e-05 L
.96826 4e-05 L
.96832 4e-05 L
.96838 4e-05 L
.96844 4e-05 L
.96851 4e-05 L
.96857 4e-05 L
.96863 4e-05 L
.96869 4e-05 L
.96873 4e-05 L
.96877 4e-05 L
.96883 4e-05 L
.9689 4e-05 L
.96897 4e-05 L
.96904 4e-05 L
.96911 4e-05 L
.96917 4e-05 L
.96923 4e-05 L
.96929 4e-05 L
.96936 4e-05 L
.96942 4e-05 L
.96949 4e-05 L
.96956 4e-05 L
.96962 4e-05 L
.96969 4e-05 L
.96976 4e-05 L
.9698 4e-05 L
.96984 4e-05 L
.96991 4e-05 L
.96998 4e-05 L
.97003 4e-05 L
.9701 4e-05 L
.97017 4e-05 L
.97023 4e-05 L
.97029 4e-05 L
.97034 4e-05 L
.9704 4e-05 L
.97046 4e-05 L
.97052 4e-05 L
.97059 4e-05 L
.97065 4e-05 L
.97071 4e-05 L
.97078 4e-05 L
.97082 4e-05 L
.97085 4e-05 L
Mistroke
.97091 4e-05 L
.97098 4e-05 L
.97105 4e-05 L
.97109 4e-05 L
.97112 4e-05 L
.97119 4e-05 L
.97125 4e-05 L
.97132 4e-05 L
.97137 4e-05 L
.97144 4e-05 L
.9715 4e-05 L
.97157 4e-05 L
.97161 4e-05 L
.97164 4e-05 L
.97172 4e-05 L
.97176 4e-05 L
.97179 4e-05 L
.97186 4e-05 L
.97193 4e-05 L
.972 4e-05 L
.97206 4e-05 L
.97212 4e-05 L
.97218 4e-05 L
.97224 4e-05 L
.97229 4e-05 L
.97236 4e-05 L
.97243 4e-05 L
.97249 4e-05 L
.97255 4e-05 L
.97262 4e-05 L
.97268 4e-05 L
.97274 4e-05 L
.9728 4e-05 L
.97287 4e-05 L
.97294 4e-05 L
.973 4e-05 L
.97307 4e-05 L
.97314 4e-05 L
.97321 4e-05 L
.97324 4e-05 L
.97328 4e-05 L
.97332 4e-05 L
.97336 4e-05 L
.97342 4e-05 L
.97349 4e-05 L
.97356 4e-05 L
.97363 4e-05 L
.97369 4e-05 L
.97376 4e-05 L
.97382 4e-05 L
Mistroke
.97387 4e-05 L
.97394 4e-05 L
.97401 4e-05 L
.97408 4e-05 L
.97414 4e-05 L
.97421 4e-05 L
.97428 4e-05 L
.97435 4e-05 L
.97441 4e-05 L
.97448 4e-05 L
.97452 4e-05 L
.97456 4e-05 L
.97463 4e-05 L
.97466 4e-05 L
.9747 4e-05 L
.97474 4e-05 L
.97478 4e-05 L
.97485 4e-05 L
.97489 4e-05 L
.97492 4e-05 L
.97496 4e-05 L
.975 4e-05 L
.97504 4e-05 L
.97508 4e-05 L
.97512 4e-05 L
.97515 4e-05 L
.97522 4e-05 L
.97529 4e-05 L
.97536 4e-05 L
.97543 4e-05 L
.9755 4e-05 L
.97556 4e-05 L
.97562 4e-05 L
.97568 4e-05 L
.97575 4e-05 L
.97581 4e-05 L
.97588 4e-05 L
.97595 4e-05 L
.97601 4e-05 L
.97607 4e-05 L
.97615 4e-05 L
.97619 4e-05 L
.97622 4e-05 L
.9763 4e-05 L
.97636 4e-05 L
.97642 4e-05 L
.97649 4e-05 L
.97655 4e-05 L
.97661 4e-05 L
.97667 4e-05 L
Mistroke
.97673 4e-05 L
.97678 4e-05 L
.97685 4e-05 L
.97691 4e-05 L
.97697 4e-05 L
.97704 4e-05 L
.9771 4e-05 L
.97716 4e-05 L
.9772 4e-05 L
.97724 4e-05 L
.9773 4e-05 L
.97737 4e-05 L
.97744 4e-05 L
.97751 4e-05 L
.97758 4e-05 L
.97764 4e-05 L
.9777 4e-05 L
.97776 4e-05 L
.97783 4e-05 L
.97789 4e-05 L
.97796 4e-05 L
.97803 4e-05 L
.97809 4e-05 L
.97816 4e-05 L
.97823 4e-05 L
.97827 4e-05 L
.9783 4e-05 L
.97838 4e-05 L
.97844 4e-05 L
.9785 4e-05 L
.97857 4e-05 L
.97863 4e-05 L
.9787 4e-05 L
.97875 4e-05 L
.97881 4e-05 L
.97887 4e-05 L
.97893 4e-05 L
.97899 4e-05 L
.97906 4e-05 L
.97912 4e-05 L
.97918 4e-05 L
.97924 4e-05 L
.97928 4e-05 L
.97932 4e-05 L
.97938 4e-05 L
.97945 4e-05 L
.97952 4e-05 L
.97955 4e-05 L
.97959 4e-05 L
.97965 4e-05 L
Mistroke
.97972 4e-05 L
.97978 4e-05 L
.97984 4e-05 L
.9799 4e-05 L
.97997 4e-05 L
.98004 4e-05 L
.98008 4e-05 L
.98011 4e-05 L
.98018 4e-05 L
.98022 4e-05 L
.98026 4e-05 L
.98033 4e-05 L
.9804 4e-05 L
.98047 4e-05 L
.98053 4e-05 L
.98059 4e-05 L
.98065 4e-05 L
.98071 4e-05 L
.98076 4e-05 L
.98082 4e-05 L
.98089 4e-05 L
.98096 4e-05 L
.98102 4e-05 L
.98108 4e-05 L
.98115 4e-05 L
.98121 4e-05 L
.98127 4e-05 L
.98134 4e-05 L
.98141 4e-05 L
.98147 4e-05 L
.98153 4e-05 L
.98161 4e-05 L
.98167 4e-05 L
.98171 4e-05 L
.98175 4e-05 L
.98179 4e-05 L
.98182 4e-05 L
.98189 4e-05 L
.98195 4e-05 L
.98202 4e-05 L
.9821 4e-05 L
.98216 4e-05 L
.98222 4e-05 L
.98228 4e-05 L
.98234 4e-05 L
.98241 4e-05 L
.98248 4e-05 L
.98255 4e-05 L
.98261 4e-05 L
.98267 4e-05 L
Mistroke
.98275 4e-05 L
.98281 4e-05 L
.98287 4e-05 L
.98295 4e-05 L
.98299 4e-05 L
.98302 4e-05 L
.98309 4e-05 L
.98313 4e-05 L
.98317 4e-05 L
.9832 4e-05 L
.98324 4e-05 L
.98331 4e-05 L
.98335 4e-05 L
.98339 4e-05 L
.98343 4e-05 L
.98347 4e-05 L
.98351 4e-05 L
.98355 4e-05 L
.98359 4e-05 L
.98362 4e-05 L
.98369 4e-05 L
.98376 4e-05 L
.98382 4e-05 L
.98389 4e-05 L
.98396 4e-05 L
.98403 4e-05 L
.98409 4e-05 L
.98415 4e-05 L
.98421 4e-05 L
.98427 4e-05 L
.98434 4e-05 L
.98441 4e-05 L
.98447 4e-05 L
.98454 4e-05 L
.98461 4e-05 L
.98465 4e-05 L
.98469 4e-05 L
.98476 4e-05 L
.98483 4e-05 L
.98489 4e-05 L
.98495 4e-05 L
.98502 4e-05 L
.98508 4e-05 L
.98514 4e-05 L
.98519 4e-05 L
.98525 4e-05 L
.98531 4e-05 L
.98537 4e-05 L
.98544 4e-05 L
.9855 4e-05 L
Mistroke
.98556 4e-05 L
.98563 4e-05 L
.98567 4e-05 L
.9857 4e-05 L
.98577 4e-05 L
.98583 4e-05 L
.9859 4e-05 L
.98597 4e-05 L
.98604 4e-05 L
.98611 4e-05 L
.98617 4e-05 L
.98623 4e-05 L
.98629 4e-05 L
.98635 4e-05 L
.98642 4e-05 L
.98649 4e-05 L
.98655 4e-05 L
.98662 4e-05 L
.98669 4e-05 L
.98673 4e-05 L
.98677 4e-05 L
.98684 4e-05 L
.98691 4e-05 L
.98697 4e-05 L
.98703 4e-05 L
.9871 4e-05 L
.98716 4e-05 L
.98722 4e-05 L
.98727 4e-05 L
.98733 4e-05 L
.98739 4e-05 L
.98745 4e-05 L
.98752 4e-05 L
.98758 4e-05 L
.98764 4e-05 L
.98771 4e-05 L
.98775 4e-05 L
.98778 4e-05 L
.98785 4e-05 L
.98792 4e-05 L
.98798 4e-05 L
.98802 4e-05 L
.98805 4e-05 L
.98812 4e-05 L
.98819 4e-05 L
.98825 4e-05 L
.9883 4e-05 L
.98837 4e-05 L
.98843 4e-05 L
.9885 4e-05 L
Mistroke
.98854 4e-05 L
.98858 4e-05 L
.98865 4e-05 L
.98869 4e-05 L
.98873 4e-05 L
.98879 4e-05 L
.98886 4e-05 L
.98893 4e-05 L
.98899 4e-05 L
.98905 4e-05 L
.98911 4e-05 L
.98917 4e-05 L
.98923 4e-05 L
.98929 4e-05 L
.98936 4e-05 L
.98942 4e-05 L
.98948 4e-05 L
.98955 4e-05 L
.98961 4e-05 L
.98967 4e-05 L
.98973 4e-05 L
.9898 4e-05 L
.98987 4e-05 L
.98993 4e-05 L
.99 4e-05 L
.99007 4e-05 L
.99014 4e-05 L
.99017 4e-05 L
.99021 4e-05 L
.99025 4e-05 L
.99029 4e-05 L
.99036 4e-05 L
.99042 4e-05 L
.99049 4e-05 L
.99056 4e-05 L
.99062 4e-05 L
.99069 4e-05 L
.99075 4e-05 L
.9908 4e-05 L
.99087 4e-05 L
.99094 4e-05 L
.99101 4e-05 L
.99107 4e-05 L
.99114 4e-05 L
.99121 4e-05 L
.99128 4e-05 L
.99134 4e-05 L
.99141 4e-05 L
.99145 4e-05 L
.99149 4e-05 L
Mistroke
.99156 4e-05 L
.99159 4e-05 L
.99163 4e-05 L
.99167 4e-05 L
.99171 4e-05 L
.99178 4e-05 L
.99181 4e-05 L
.99185 4e-05 L
.99189 4e-05 L
.99193 4e-05 L
.99197 4e-05 L
.99201 4e-05 L
.99205 4e-05 L
.99208 4e-05 L
.99215 4e-05 L
.99222 4e-05 L
.99229 4e-05 L
.99236 4e-05 L
.99243 4e-05 L
.99249 4e-05 L
.99255 4e-05 L
.99261 4e-05 L
.99267 4e-05 L
.99274 4e-05 L
.9928 4e-05 L
.99288 4e-05 L
.99294 4e-05 L
.993 4e-05 L
.99308 4e-05 L
.99312 4e-05 L
.99315 4e-05 L
.99322 4e-05 L
.99329 4e-05 L
.99335 4e-05 L
.99341 4e-05 L
.99348 4e-05 L
.99354 4e-05 L
.9936 4e-05 L
.99365 4e-05 L
.99371 4e-05 L
.99377 4e-05 L
.99384 4e-05 L
.9939 4e-05 L
.99397 4e-05 L
.99402 4e-05 L
.99409 4e-05 L
.99413 4e-05 L
.99416 4e-05 L
.99423 4e-05 L
.9943 4e-05 L
Mistroke
.99436 4e-05 L
.99444 4e-05 L
.9945 4e-05 L
.99457 4e-05 L
.99463 4e-05 L
.99469 4e-05 L
.99475 4e-05 L
.99482 4e-05 L
.99488 4e-05 L
.99495 4e-05 L
.99502 4e-05 L
.99508 4e-05 L
.99516 4e-05 L
.9952 4e-05 L
.99523 4e-05 L
.9953 4e-05 L
.99537 4e-05 L
.99543 4e-05 L
.99549 4e-05 L
.99556 4e-05 L
.99562 4e-05 L
.99568 4e-05 L
.99573 4e-05 L
.99579 4e-05 L
.99585 4e-05 L
.99592 4e-05 L
.99598 4e-05 L
.99605 4e-05 L
.9961 4e-05 L
.99617 4e-05 L
.99621 4e-05 L
.99624 4e-05 L
.99631 4e-05 L
.99638 4e-05 L
.99644 4e-05 L
.99648 4e-05 L
.99652 4e-05 L
.99658 4e-05 L
.99665 4e-05 L
.99671 4e-05 L
.99677 4e-05 L
.99683 4e-05 L
.9969 4e-05 L
.99696 4e-05 L
.997 4e-05 L
.99704 4e-05 L
.99711 4e-05 L
.99715 4e-05 L
.99719 4e-05 L
.99725 4e-05 L
Mistroke
.99732 4e-05 L
.99739 4e-05 L
.99745 4e-05 L
.99751 4e-05 L
.99757 4e-05 L
.99763 4e-05 L
.99769 4e-05 L
.99775 4e-05 L
.99782 4e-05 L
.99788 4e-05 L
.99794 4e-05 L
.99801 4e-05 L
.99807 4e-05 L
.99813 4e-05 L
.99819 4e-05 L
.99826 4e-05 L
.99833 4e-05 L
.99839 4e-05 L
.99846 4e-05 L
.99851 4e-05 L
.99855 4e-05 L
.9986 4e-05 L
.99866 4e-05 L
.9987 4e-05 L
.99874 4e-05 L
.99879 4e-05 L
.99884 4e-05 L
.99888 4e-05 L
.99893 4e-05 L
.99897 4e-05 L
.99902 4e-05 L
.99906 4e-05 L
.9991 4e-05 L
.99914 4e-05 L
.99918 4e-05 L
.99923 4e-05 L
.99928 4e-05 L
.99933 4e-05 L
.99938 4e-05 L
.99942 4e-05 L
.99946 4e-05 L
.99951 4e-05 L
.99956 4e-05 L
.99961 4e-05 L
.99966 4e-05 L
.99971 4e-05 L
.99975 4e-05 L
.9998 4e-05 L
.99986 4e-05 L
.99991 4e-05 L
Mistroke
.99996 4e-05 L
Mfstroke
.94766 .84358 m
.94978 .84521 L
.9521 .84699 L
.95427 .84866 L
.95636 .85027 L
.95858 .85197 L
.96072 .85362 L
.963 .85537 L
.96519 .85705 L
.9673 .85867 L
.96955 .86039 L
.97171 .86205 L
.97379 .86365 L
.976 .86534 L
.97813 .86698 L
.98039 .86871 L
.98257 .87038 L
.98467 .87199 L
.9869 .8737 L
.98905 .87535 L
.99133 .8771 L
.99353 .87878 L
.99565 .8804 L
.9979 .88213 L
.99996 .8837 L
s
1 1 .5 r
.94766 4e-05 m
.94772 4e-05 L
.94778 4e-05 L
.94785 4e-05 L
.94791 4e-05 L
.94797 4e-05 L
.94803 4e-05 L
.94809 4e-05 L
.94815 4e-05 L
.94822 4e-05 L
.94829 4e-05 L
.94835 4e-05 L
.94841 4e-05 L
.94848 4e-05 L
.94852 4e-05 L
.94855 4e-05 L
.94862 4e-05 L
.94869 4e-05 L
.94873 4e-05 L
.94877 4e-05 L
.94883 4e-05 L
.94887 4e-05 L
.94891 4e-05 L
.94895 4e-05 L
.94899 4e-05 L
.94902 4e-05 L
.94906 4e-05 L
.94913 4e-05 L
.9492 4e-05 L
.94926 4e-05 L
.94932 4e-05 L
.94938 4e-05 L
.94945 4e-05 L
.94951 4e-05 L
.94958 4e-05 L
.94965 4e-05 L
.94971 4e-05 L
.94978 4e-05 L
.94982 4e-05 L
.94986 4e-05 L
.9499 4e-05 L
.94994 4e-05 L
.95001 4e-05 L
.95005 4e-05 L
.95008 4e-05 L
.95015 4e-05 L
.95022 4e-05 L
.95025 4e-05 L
.95029 4e-05 L
.95036 4e-05 L
.9504 4e-05 L
.95044 4e-05 L
.95048 4e-05 L
.95052 4e-05 L
.95056 4e-05 L
.9506 4e-05 L
.95064 4e-05 L
.95068 4e-05 L
.95072 4e-05 L
.95076 4e-05 L
.9508 4e-05 L
.95084 4e-05 L
.95091 4e-05 L
.95094 4e-05 L
.95098 4e-05 L
.95104 4e-05 L
.95111 4e-05 L
.95118 4e-05 L
.95124 4e-05 L
.9513 4e-05 L
.95138 4e-05 L
.95141 4e-05 L
.95145 4e-05 L
.95152 4e-05 L
.95156 4e-05 L
.9516 4e-05 L
.95163 4e-05 L
.95168 4e-05 L
.95175 4e-05 L
.95179 4e-05 L
.95182 4e-05 L
.95189 4e-05 L
.95195 4e-05 L
.95203 4e-05 L
.9521 4e-05 L
.95216 4e-05 L
.95222 4e-05 L
.95229 4e-05 L
.95235 4e-05 L
.95241 4e-05 L
.95248 4e-05 L
.95252 4e-05 L
.95256 4e-05 L
.95262 4e-05 L
.95266 4e-05 L
.9527 4e-05 L
.95274 4e-05 L
.95278 4e-05 L
.95284 4e-05 L
.95288 4e-05 L
.95292 4e-05 L
.95299 4e-05 L
.95305 4e-05 L
.95312 4e-05 L
.95319 4e-05 L
.95325 4e-05 L
.95331 4e-05 L
.95338 4e-05 L
.95344 4e-05 L
.9535 4e-05 L
.95355 4e-05 L
.95361 4e-05 L
.95367 4e-05 L
.95373 4e-05 L
.9538 4e-05 L
.95386 4e-05 L
.95392 4e-05 L
.95399 4e-05 L
.95403 4e-05 L
.95406 4e-05 L
.95413 4e-05 L
.9542 4e-05 L
.95426 4e-05 L
.95433 4e-05 L
.9544 4e-05 L
.95447 4e-05 L
.95453 4e-05 L
.95459 4e-05 L
.95465 4e-05 L
.95471 4e-05 L
.95478 4e-05 L
.95485 4e-05 L
.95491 4e-05 L
.95498 4e-05 L
.95505 4e-05 L
.95509 4e-05 L
.95513 4e-05 L
.9552 4e-05 L
.95527 4e-05 L
.95533 4e-05 L
.95539 4e-05 L
.95546 4e-05 L
.95552 4e-05 L
.95558 4e-05 L
.95563 4e-05 L
.95569 4e-05 L
.95575 4e-05 L
.95581 4e-05 L
.95588 4e-05 L
.95594 4e-05 L
.956 4e-05 L
.95607 4e-05 L
.9561 4e-05 L
.95614 4e-05 L
.9562 4e-05 L
.95627 4e-05 L
.95634 4e-05 L
.95641 4e-05 L
.95648 4e-05 L
.95654 4e-05 L
.9566 4e-05 L
.95666 4e-05 L
.95673 4e-05 L
.95679 4e-05 L
.95686 4e-05 L
.95693 4e-05 L
.95699 4e-05 L
.95706 4e-05 L
.95713 4e-05 L
.95717 4e-05 L
.95721 4e-05 L
.95728 4e-05 L
.95734 4e-05 L
.9574 4e-05 L
.95747 4e-05 L
.95753 4e-05 L
.95759 4e-05 L
.95765 4e-05 L
.95771 4e-05 L
.95776 4e-05 L
.95783 4e-05 L
.95789 4e-05 L
.95796 4e-05 L
.95802 4e-05 L
.95808 4e-05 L
.95814 4e-05 L
.95818 4e-05 L
.95822 4e-05 L
.95828 4e-05 L
.95835 4e-05 L
.95842 4e-05 L
.95849 4e-05 L
.95856 4e-05 L
.95862 4e-05 L
.95868 4e-05 L
.95874 4e-05 L
.95881 4e-05 L
.95887 4e-05 L
.95894 4e-05 L
.95901 4e-05 L
.95907 4e-05 L
.95913 4e-05 L
.95921 4e-05 L
.95925 4e-05 L
.95928 4e-05 L
.95936 4e-05 L
.95942 4e-05 L
.95948 4e-05 L
.95955 4e-05 L
.95961 4e-05 L
.95967 4e-05 L
.95973 4e-05 L
.95979 4e-05 L
.95984 4e-05 L
.95991 4e-05 L
.95997 4e-05 L
.96004 4e-05 L
.9601 4e-05 L
.96016 4e-05 L
.96022 4e-05 L
.96026 4e-05 L
.9603 4e-05 L
.96036 4e-05 L
.96043 4e-05 L
.9605 4e-05 L
.96057 4e-05 L
.96064 4e-05 L
.9607 4e-05 L
.96076 4e-05 L
.96082 4e-05 L
.96089 4e-05 L
.96095 4e-05 L
.96102 4e-05 L
.96109 4e-05 L
.96115 4e-05 L
.96122 4e-05 L
.96129 4e-05 L
.96133 4e-05 L
.96137 4e-05 L
.96144 4e-05 L
.96151 4e-05 L
.96156 4e-05 L
.96163 4e-05 L
.96169 4e-05 L
.96176 4e-05 L
.96182 4e-05 L
.96187 4e-05 L
.96193 4e-05 L
.96199 4e-05 L
.96205 4e-05 L
.96212 4e-05 L
.96218 4e-05 L
.96224 4e-05 L
.96231 4e-05 L
.96234 4e-05 L
.96238 4e-05 L
.96244 4e-05 L
.96251 4e-05 L
.96258 4e-05 L
.96262 4e-05 L
.96265 4e-05 L
.96272 4e-05 L
.96278 4e-05 L
.96285 4e-05 L
.9629 4e-05 L
.96297 4e-05 L
.96303 4e-05 L
.9631 4e-05 L
.96314 4e-05 L
.96317 4e-05 L
.96325 4e-05 L
.96329 4e-05 L
.96332 4e-05 L
.96339 4e-05 L
.96346 4e-05 L
.96353 4e-05 L
.96359 4e-05 L
.96365 4e-05 L
.96371 4e-05 L
.96377 4e-05 L
.96382 4e-05 L
.96389 4e-05 L
.96396 4e-05 L
.96402 4e-05 L
.96408 4e-05 L
.96415 4e-05 L
.96421 4e-05 L
.96427 4e-05 L
.96433 4e-05 L
.9644 4e-05 L
.96447 4e-05 L
.96453 4e-05 L
.9646 4e-05 L
.96467 4e-05 L
.96474 4e-05 L
.96477 4e-05 L
.96481 4e-05 L
.96485 4e-05 L
.96489 4e-05 L
.96496 4e-05 L
.96502 4e-05 L
.96509 4e-05 L
.96516 4e-05 L
.96522 4e-05 L
.96529 4e-05 L
.96535 4e-05 L
.9654 4e-05 L
.96547 4e-05 L
.96554 4e-05 L
.96561 4e-05 L
.96567 4e-05 L
.96574 4e-05 L
.96581 4e-05 L
.96588 4e-05 L
.96594 4e-05 L
.96601 4e-05 L
.96605 4e-05 L
.96609 4e-05 L
.96616 4e-05 L
.96619 4e-05 L
.96623 4e-05 L
.96627 4e-05 L
.96631 4e-05 L
.96638 4e-05 L
.96642 4e-05 L
.96645 4e-05 L
.96649 4e-05 L
.96654 4e-05 L
.96657 4e-05 L
.96661 4e-05 L
.96665 4e-05 L
.96669 4e-05 L
.96675 4e-05 L
.96682 4e-05 L
.96689 4e-05 L
.96696 4e-05 L
.96703 4e-05 L
.96709 4e-05 L
.96715 4e-05 L
.96721 4e-05 L
.96728 4e-05 L
.96734 4e-05 L
.96741 4e-05 L
.96748 4e-05 L
.96754 4e-05 L
.96761 4e-05 L
.96768 4e-05 L
.96772 4e-05 L
.96776 4e-05 L
.96783 4e-05 L
.9679 4e-05 L
.96795 4e-05 L
.96802 4e-05 L
.96808 4e-05 L
.96815 4e-05 L
.9682 4e-05 L
.96826 4e-05 L
.96832 4e-05 L
.96838 4e-05 L
.96844 4e-05 L
.96851 4e-05 L
.96857 4e-05 L
.96863 4e-05 L
.96869 4e-05 L
.96873 4e-05 L
.96877 4e-05 L
.96883 4e-05 L
.9689 4e-05 L
.96897 4e-05 L
.96904 4e-05 L
.96911 4e-05 L
.96917 4e-05 L
.96923 4e-05 L
.96929 4e-05 L
.96936 4e-05 L
.96942 4e-05 L
.96949 4e-05 L
.96956 4e-05 L
.96962 4e-05 L
.96969 4e-05 L
.96976 4e-05 L
.9698 4e-05 L
.96984 4e-05 L
.96991 4e-05 L
.96998 4e-05 L
.97003 4e-05 L
.9701 4e-05 L
.97017 4e-05 L
.97023 4e-05 L
.97029 4e-05 L
.97034 4e-05 L
.9704 4e-05 L
.97046 4e-05 L
.97052 4e-05 L
.97059 4e-05 L
.97065 4e-05 L
.97071 4e-05 L
.97078 4e-05 L
.97082 4e-05 L
.97085 4e-05 L
.97091 4e-05 L
.97098 4e-05 L
.97105 4e-05 L
.97109 4e-05 L
.97112 4e-05 L
.97119 4e-05 L
.97125 4e-05 L
.97132 4e-05 L
.97137 4e-05 L
.97144 4e-05 L
.9715 4e-05 L
.97157 4e-05 L
.97161 4e-05 L
.97164 4e-05 L
.97172 4e-05 L
.97176 4e-05 L
.97179 4e-05 L
.97186 4e-05 L
.97193 4e-05 L
.972 4e-05 L
.97206 4e-05 L
.97212 4e-05 L
.97218 4e-05 L
.97224 4e-05 L
.97229 4e-05 L
.97236 4e-05 L
.97243 4e-05 L
.97249 4e-05 L
.97255 4e-05 L
.97262 4e-05 L
.97268 4e-05 L
.97274 4e-05 L
.9728 4e-05 L
.97287 4e-05 L
.97294 4e-05 L
.973 4e-05 L
.97307 4e-05 L
.97314 4e-05 L
.97321 4e-05 L
.97324 4e-05 L
.97328 4e-05 L
.97332 4e-05 L
.97336 4e-05 L
.97342 4e-05 L
.97349 4e-05 L
.97356 4e-05 L
.97363 4e-05 L
.97369 4e-05 L
.97376 4e-05 L
.97382 4e-05 L
.97387 4e-05 L
.97394 4e-05 L
.97401 4e-05 L
.97408 4e-05 L
.97414 4e-05 L
.97421 4e-05 L
.97428 4e-05 L
.97435 4e-05 L
.97441 4e-05 L
.97448 4e-05 L
.97452 4e-05 L
.97456 4e-05 L
.97463 4e-05 L
.97466 4e-05 L
.9747 4e-05 L
.97474 4e-05 L
.97478 4e-05 L
.97485 4e-05 L
.97489 4e-05 L
.97492 4e-05 L
.97496 4e-05 L
.975 4e-05 L
.97504 4e-05 L
.97508 4e-05 L
.97512 4e-05 L
.97515 4e-05 L
.97522 4e-05 L
.97529 4e-05 L
.97536 4e-05 L
.97543 4e-05 L
.9755 4e-05 L
.97556 4e-05 L
.97562 4e-05 L
.97568 4e-05 L
.97575 4e-05 L
.97581 4e-05 L
.97588 4e-05 L
.97595 4e-05 L
.97601 4e-05 L
.97607 4e-05 L
.97615 4e-05 L
.97619 4e-05 L
.97622 4e-05 L
.9763 4e-05 L
.97636 4e-05 L
.97642 4e-05 L
.97649 4e-05 L
.97655 4e-05 L
.97661 4e-05 L
.97667 4e-05 L
.97673 4e-05 L
.97678 4e-05 L
.97685 4e-05 L
.97691 4e-05 L
.97697 4e-05 L
.97704 4e-05 L
.9771 4e-05 L
.97716 4e-05 L
.9772 4e-05 L
.97724 4e-05 L
.9773 4e-05 L
.97737 4e-05 L
.97744 4e-05 L
.97751 4e-05 L
.97758 4e-05 L
.97764 4e-05 L
.9777 4e-05 L
.97776 4e-05 L
.97783 4e-05 L
.97789 4e-05 L
.97796 4e-05 L
.97803 4e-05 L
.97809 4e-05 L
.97816 4e-05 L
.97823 4e-05 L
.97827 4e-05 L
.9783 4e-05 L
.97838 4e-05 L
.97844 4e-05 L
.9785 4e-05 L
.97857 4e-05 L
.97863 4e-05 L
.9787 4e-05 L
.97875 4e-05 L
.97881 4e-05 L
.97887 4e-05 L
.97893 4e-05 L
.97899 4e-05 L
.97906 4e-05 L
.97912 4e-05 L
.97918 4e-05 L
.97924 4e-05 L
.97928 4e-05 L
.97932 4e-05 L
.97938 4e-05 L
.97945 4e-05 L
.97952 4e-05 L
.97955 4e-05 L
.97959 4e-05 L
.97965 4e-05 L
.97972 4e-05 L
.97978 4e-05 L
.97984 4e-05 L
.9799 4e-05 L
.97997 4e-05 L
.98004 4e-05 L
.98008 4e-05 L
.98011 4e-05 L
.98018 4e-05 L
.98022 4e-05 L
.98026 4e-05 L
.98033 4e-05 L
.9804 4e-05 L
.98047 4e-05 L
.98053 4e-05 L
.98059 4e-05 L
.98065 4e-05 L
.98071 4e-05 L
.98076 4e-05 L
.98082 4e-05 L
.98089 4e-05 L
.98096 4e-05 L
.98102 4e-05 L
.98108 4e-05 L
.98115 4e-05 L
.98121 4e-05 L
.98127 4e-05 L
.98134 4e-05 L
.98141 4e-05 L
.98147 4e-05 L
.98153 4e-05 L
.98161 4e-05 L
.98167 4e-05 L
.98171 4e-05 L
.98175 4e-05 L
.98179 4e-05 L
.98182 4e-05 L
.98189 4e-05 L
.98195 4e-05 L
.98202 4e-05 L
.9821 4e-05 L
.98216 4e-05 L
.98222 4e-05 L
.98228 4e-05 L
.98234 4e-05 L
.98241 4e-05 L
.98248 4e-05 L
.98255 4e-05 L
.98261 4e-05 L
.98267 4e-05 L
.98275 4e-05 L
.98281 4e-05 L
.98287 4e-05 L
.98295 4e-05 L
.98299 4e-05 L
.98302 4e-05 L
.98309 4e-05 L
.98313 4e-05 L
.98317 4e-05 L
.9832 4e-05 L
.98324 4e-05 L
.98331 4e-05 L
.98335 4e-05 L
.98339 4e-05 L
.98343 4e-05 L
.98347 4e-05 L
.98351 4e-05 L
.98355 4e-05 L
.98359 4e-05 L
.98362 4e-05 L
.98369 4e-05 L
.98376 4e-05 L
.98382 4e-05 L
.98389 4e-05 L
.98396 4e-05 L
.98403 4e-05 L
.98409 4e-05 L
.98415 4e-05 L
.98421 4e-05 L
.98427 4e-05 L
.98434 4e-05 L
.98441 4e-05 L
.98447 4e-05 L
.98454 4e-05 L
.98461 4e-05 L
.98465 4e-05 L
.98469 4e-05 L
.98476 4e-05 L
.98483 4e-05 L
.98489 4e-05 L
.98495 4e-05 L
.98502 4e-05 L
.98508 4e-05 L
.98514 4e-05 L
.98519 4e-05 L
.98525 4e-05 L
.98531 4e-05 L
.98537 4e-05 L
.98544 4e-05 L
.9855 4e-05 L
.98556 4e-05 L
.98563 4e-05 L
.98567 4e-05 L
.9857 4e-05 L
.98577 4e-05 L
.98583 4e-05 L
.9859 4e-05 L
.98597 4e-05 L
.98604 4e-05 L
.98611 4e-05 L
.98617 4e-05 L
.98623 4e-05 L
.98629 4e-05 L
.98635 4e-05 L
.98642 4e-05 L
.98649 4e-05 L
.98655 4e-05 L
.98662 4e-05 L
.98669 4e-05 L
.98673 4e-05 L
.98677 4e-05 L
.98684 4e-05 L
.98691 4e-05 L
.98697 4e-05 L
.98703 4e-05 L
.9871 4e-05 L
.98716 4e-05 L
.98722 4e-05 L
.98727 4e-05 L
.98733 4e-05 L
.98739 4e-05 L
.98745 4e-05 L
.98752 4e-05 L
.98758 4e-05 L
.98764 4e-05 L
.98771 4e-05 L
.98775 4e-05 L
.98778 4e-05 L
.98785 4e-05 L
.98792 4e-05 L
.98798 4e-05 L
.98802 4e-05 L
.98805 4e-05 L
.98812 4e-05 L
.98819 4e-05 L
.98825 4e-05 L
.9883 4e-05 L
.98837 4e-05 L
.98843 4e-05 L
.9885 4e-05 L
.98854 4e-05 L
.98858 4e-05 L
.98865 4e-05 L
.98869 4e-05 L
.98873 4e-05 L
.98879 4e-05 L
.98886 4e-05 L
.98893 4e-05 L
.98899 4e-05 L
.98905 4e-05 L
.98911 4e-05 L
.98917 4e-05 L
.98923 4e-05 L
.98929 4e-05 L
.98936 4e-05 L
.98942 4e-05 L
.98948 4e-05 L
.98955 4e-05 L
.98961 4e-05 L
.98967 4e-05 L
.98973 4e-05 L
.9898 4e-05 L
.98987 4e-05 L
.98993 4e-05 L
.99 4e-05 L
.99007 4e-05 L
.99014 4e-05 L
.99017 4e-05 L
.99021 4e-05 L
.99025 4e-05 L
.99029 4e-05 L
.99036 4e-05 L
.99042 4e-05 L
.99049 4e-05 L
.99056 4e-05 L
.99062 4e-05 L
.99069 4e-05 L
.99075 4e-05 L
.9908 4e-05 L
.99087 4e-05 L
.99094 4e-05 L
.99101 4e-05 L
.99107 4e-05 L
.99114 4e-05 L
.99121 4e-05 L
.99128 4e-05 L
.99134 4e-05 L
.99141 4e-05 L
.99145 4e-05 L
.99149 4e-05 L
.99156 4e-05 L
.99159 4e-05 L
.99163 4e-05 L
.99167 4e-05 L
.99171 4e-05 L
.99178 4e-05 L
.99181 4e-05 L
.99185 4e-05 L
.99189 4e-05 L
.99193 4e-05 L
.99197 4e-05 L
.99201 4e-05 L
.99205 4e-05 L
.99208 4e-05 L
.99215 4e-05 L
.99222 4e-05 L
.99229 4e-05 L
.99236 4e-05 L
.99243 4e-05 L
.99249 4e-05 L
.99255 4e-05 L
.99261 4e-05 L
.99267 4e-05 L
.99274 4e-05 L
.9928 4e-05 L
.99288 4e-05 L
.99294 4e-05 L
.993 4e-05 L
.99308 4e-05 L
.99312 4e-05 L
.99315 4e-05 L
.99322 4e-05 L
.99329 4e-05 L
.99335 4e-05 L
.99341 4e-05 L
.99348 4e-05 L
.99354 4e-05 L
.9936 4e-05 L
.99365 4e-05 L
.99371 4e-05 L
.99377 4e-05 L
.99384 4e-05 L
.9939 4e-05 L
.99397 4e-05 L
.99402 4e-05 L
.99409 4e-05 L
.99413 4e-05 L
.99416 4e-05 L
.99423 4e-05 L
.9943 4e-05 L
.99436 4e-05 L
.99444 4e-05 L
.9945 4e-05 L
.99457 4e-05 L
.99463 4e-05 L
.99469 4e-05 L
.99475 4e-05 L
.99482 4e-05 L
.99488 4e-05 L
.99495 4e-05 L
.99502 4e-05 L
.99508 4e-05 L
.99516 4e-05 L
.9952 4e-05 L
.99523 4e-05 L
.9953 4e-05 L
.99537 4e-05 L
.99543 4e-05 L
.99549 4e-05 L
.99556 4e-05 L
.99562 4e-05 L
.99568 4e-05 L
.99573 4e-05 L
.99579 4e-05 L
.99585 4e-05 L
.99592 4e-05 L
.99598 4e-05 L
.99605 4e-05 L
.9961 4e-05 L
.99617 4e-05 L
.99621 4e-05 L
.99624 4e-05 L
.99631 4e-05 L
.99638 4e-05 L
.99644 4e-05 L
.99648 4e-05 L
.99652 4e-05 L
.99658 4e-05 L
.99665 4e-05 L
.99671 4e-05 L
.99677 4e-05 L
.99683 4e-05 L
.9969 4e-05 L
.99696 4e-05 L
.997 4e-05 L
.99704 4e-05 L
.99711 4e-05 L
.99715 4e-05 L
.99719 4e-05 L
.99725 4e-05 L
.99732 4e-05 L
.99739 4e-05 L
.99745 4e-05 L
.99751 4e-05 L
.99757 4e-05 L
.99763 4e-05 L
.99769 4e-05 L
.99775 4e-05 L
.99782 4e-05 L
.99788 4e-05 L
.99794 4e-05 L
.99801 4e-05 L
.99807 4e-05 L
.99813 4e-05 L
.99819 4e-05 L
.99826 4e-05 L
.99833 4e-05 L
.99839 4e-05 L
.99846 4e-05 L
.99851 4e-05 L
.99855 4e-05 L
.9986 4e-05 L
.99866 4e-05 L
.9987 4e-05 L
.99874 4e-05 L
.99879 4e-05 L
.99884 4e-05 L
.99888 4e-05 L
.99893 4e-05 L
.99897 4e-05 L
.99902 4e-05 L
.99906 4e-05 L
.9991 4e-05 L
.99914 4e-05 L
.99918 4e-05 L
.99923 4e-05 L
.99928 4e-05 L
.99933 4e-05 L
.99938 4e-05 L
.99942 4e-05 L
.99946 4e-05 L
.99951 4e-05 L
.99956 4e-05 L
.99961 4e-05 L
.99966 4e-05 L
.99971 4e-05 L
.99975 4e-05 L
.9998 4e-05 L
.99986 4e-05 L
.99991 4e-05 L
.99996 4e-05 L
.99996 .8837 L
.9979 .88213 L
.99565 .8804 L
.99353 .87878 L
.99133 .8771 L
.98905 .87535 L
.9869 .8737 L
.98467 .87199 L
.98257 .87038 L
.98039 .86871 L
.97813 .86698 L
.976 .86534 L
.97379 .86365 L
.97171 .86205 L
.96955 .86039 L
.9673 .85867 L
.96519 .85705 L
.963 .85537 L
.96072 .85362 L
.95858 .85197 L
.95636 .85027 L
.95427 .84866 L
.9521 .84699 L
.94978 .84521 L
.94766 .84358 L
F
0 g
.94766 4e-05 m
.94772 4e-05 L
.94778 4e-05 L
.94785 4e-05 L
.94791 4e-05 L
.94797 4e-05 L
.94803 4e-05 L
.94809 4e-05 L
.94815 4e-05 L
.94822 4e-05 L
.94829 4e-05 L
.94835 4e-05 L
.94841 4e-05 L
.94848 4e-05 L
.94852 4e-05 L
.94855 4e-05 L
.94862 4e-05 L
.94869 4e-05 L
.94873 4e-05 L
.94877 4e-05 L
.94883 4e-05 L
.94887 4e-05 L
.94891 4e-05 L
.94895 4e-05 L
.94899 4e-05 L
.94902 4e-05 L
.94906 4e-05 L
.94913 4e-05 L
.9492 4e-05 L
.94926 4e-05 L
.94932 4e-05 L
.94938 4e-05 L
.94945 4e-05 L
.94951 4e-05 L
.94958 4e-05 L
.94965 4e-05 L
.94971 4e-05 L
.94978 4e-05 L
.94982 4e-05 L
.94986 4e-05 L
.9499 4e-05 L
.94994 4e-05 L
.95001 4e-05 L
.95005 4e-05 L
.95008 4e-05 L
.95015 4e-05 L
.95022 4e-05 L
.95025 4e-05 L
.95029 4e-05 L
.95036 4e-05 L
Mistroke
.9504 4e-05 L
.95044 4e-05 L
.95048 4e-05 L
.95052 4e-05 L
.95056 4e-05 L
.9506 4e-05 L
.95064 4e-05 L
.95068 4e-05 L
.95072 4e-05 L
.95076 4e-05 L
.9508 4e-05 L
.95084 4e-05 L
.95091 4e-05 L
.95094 4e-05 L
.95098 4e-05 L
.95104 4e-05 L
.95111 4e-05 L
.95118 4e-05 L
.95124 4e-05 L
.9513 4e-05 L
.95138 4e-05 L
.95141 4e-05 L
.95145 4e-05 L
.95152 4e-05 L
.95156 4e-05 L
.9516 4e-05 L
.95163 4e-05 L
.95168 4e-05 L
.95175 4e-05 L
.95179 4e-05 L
.95182 4e-05 L
.95189 4e-05 L
.95195 4e-05 L
.95203 4e-05 L
.9521 4e-05 L
.95216 4e-05 L
.95222 4e-05 L
.95229 4e-05 L
.95235 4e-05 L
.95241 4e-05 L
.95248 4e-05 L
.95252 4e-05 L
.95256 4e-05 L
.95262 4e-05 L
.95266 4e-05 L
.9527 4e-05 L
.95274 4e-05 L
.95278 4e-05 L
.95284 4e-05 L
.95288 4e-05 L
Mistroke
.95292 4e-05 L
.95299 4e-05 L
.95305 4e-05 L
.95312 4e-05 L
.95319 4e-05 L
.95325 4e-05 L
.95331 4e-05 L
.95338 4e-05 L
.95344 4e-05 L
.9535 4e-05 L
.95355 4e-05 L
.95361 4e-05 L
.95367 4e-05 L
.95373 4e-05 L
.9538 4e-05 L
.95386 4e-05 L
.95392 4e-05 L
.95399 4e-05 L
.95403 4e-05 L
.95406 4e-05 L
.95413 4e-05 L
.9542 4e-05 L
.95426 4e-05 L
.95433 4e-05 L
.9544 4e-05 L
.95447 4e-05 L
.95453 4e-05 L
.95459 4e-05 L
.95465 4e-05 L
.95471 4e-05 L
.95478 4e-05 L
.95485 4e-05 L
.95491 4e-05 L
.95498 4e-05 L
.95505 4e-05 L
.95509 4e-05 L
.95513 4e-05 L
.9552 4e-05 L
.95527 4e-05 L
.95533 4e-05 L
.95539 4e-05 L
.95546 4e-05 L
.95552 4e-05 L
.95558 4e-05 L
.95563 4e-05 L
.95569 4e-05 L
.95575 4e-05 L
.95581 4e-05 L
.95588 4e-05 L
.95594 4e-05 L
Mistroke
.956 4e-05 L
.95607 4e-05 L
.9561 4e-05 L
.95614 4e-05 L
.9562 4e-05 L
.95627 4e-05 L
.95634 4e-05 L
.95641 4e-05 L
.95648 4e-05 L
.95654 4e-05 L
.9566 4e-05 L
.95666 4e-05 L
.95673 4e-05 L
.95679 4e-05 L
.95686 4e-05 L
.95693 4e-05 L
.95699 4e-05 L
.95706 4e-05 L
.95713 4e-05 L
.95717 4e-05 L
.95721 4e-05 L
.95728 4e-05 L
.95734 4e-05 L
.9574 4e-05 L
.95747 4e-05 L
.95753 4e-05 L
.95759 4e-05 L
.95765 4e-05 L
.95771 4e-05 L
.95776 4e-05 L
.95783 4e-05 L
.95789 4e-05 L
.95796 4e-05 L
.95802 4e-05 L
.95808 4e-05 L
.95814 4e-05 L
.95818 4e-05 L
.95822 4e-05 L
.95828 4e-05 L
.95835 4e-05 L
.95842 4e-05 L
.95849 4e-05 L
.95856 4e-05 L
.95862 4e-05 L
.95868 4e-05 L
.95874 4e-05 L
.95881 4e-05 L
.95887 4e-05 L
.95894 4e-05 L
.95901 4e-05 L
Mistroke
.95907 4e-05 L
.95913 4e-05 L
.95921 4e-05 L
.95925 4e-05 L
.95928 4e-05 L
.95936 4e-05 L
.95942 4e-05 L
.95948 4e-05 L
.95955 4e-05 L
.95961 4e-05 L
.95967 4e-05 L
.95973 4e-05 L
.95979 4e-05 L
.95984 4e-05 L
.95991 4e-05 L
.95997 4e-05 L
.96004 4e-05 L
.9601 4e-05 L
.96016 4e-05 L
.96022 4e-05 L
.96026 4e-05 L
.9603 4e-05 L
.96036 4e-05 L
.96043 4e-05 L
.9605 4e-05 L
.96057 4e-05 L
.96064 4e-05 L
.9607 4e-05 L
.96076 4e-05 L
.96082 4e-05 L
.96089 4e-05 L
.96095 4e-05 L
.96102 4e-05 L
.96109 4e-05 L
.96115 4e-05 L
.96122 4e-05 L
.96129 4e-05 L
.96133 4e-05 L
.96137 4e-05 L
.96144 4e-05 L
.96151 4e-05 L
.96156 4e-05 L
.96163 4e-05 L
.96169 4e-05 L
.96176 4e-05 L
.96182 4e-05 L
.96187 4e-05 L
.96193 4e-05 L
.96199 4e-05 L
.96205 4e-05 L
Mistroke
.96212 4e-05 L
.96218 4e-05 L
.96224 4e-05 L
.96231 4e-05 L
.96234 4e-05 L
.96238 4e-05 L
.96244 4e-05 L
.96251 4e-05 L
.96258 4e-05 L
.96262 4e-05 L
.96265 4e-05 L
.96272 4e-05 L
.96278 4e-05 L
.96285 4e-05 L
.9629 4e-05 L
.96297 4e-05 L
.96303 4e-05 L
.9631 4e-05 L
.96314 4e-05 L
.96317 4e-05 L
.96325 4e-05 L
.96329 4e-05 L
.96332 4e-05 L
.96339 4e-05 L
.96346 4e-05 L
.96353 4e-05 L
.96359 4e-05 L
.96365 4e-05 L
.96371 4e-05 L
.96377 4e-05 L
.96382 4e-05 L
.96389 4e-05 L
.96396 4e-05 L
.96402 4e-05 L
.96408 4e-05 L
.96415 4e-05 L
.96421 4e-05 L
.96427 4e-05 L
.96433 4e-05 L
.9644 4e-05 L
.96447 4e-05 L
.96453 4e-05 L
.9646 4e-05 L
.96467 4e-05 L
.96474 4e-05 L
.96477 4e-05 L
.96481 4e-05 L
.96485 4e-05 L
.96489 4e-05 L
.96496 4e-05 L
Mistroke
.96502 4e-05 L
.96509 4e-05 L
.96516 4e-05 L
.96522 4e-05 L
.96529 4e-05 L
.96535 4e-05 L
.9654 4e-05 L
.96547 4e-05 L
.96554 4e-05 L
.96561 4e-05 L
.96567 4e-05 L
.96574 4e-05 L
.96581 4e-05 L
.96588 4e-05 L
.96594 4e-05 L
.96601 4e-05 L
.96605 4e-05 L
.96609 4e-05 L
.96616 4e-05 L
.96619 4e-05 L
.96623 4e-05 L
.96627 4e-05 L
.96631 4e-05 L
.96638 4e-05 L
.96642 4e-05 L
.96645 4e-05 L
.96649 4e-05 L
.96654 4e-05 L
.96657 4e-05 L
.96661 4e-05 L
.96665 4e-05 L
.96669 4e-05 L
.96675 4e-05 L
.96682 4e-05 L
.96689 4e-05 L
.96696 4e-05 L
.96703 4e-05 L
.96709 4e-05 L
.96715 4e-05 L
.96721 4e-05 L
.96728 4e-05 L
.96734 4e-05 L
.96741 4e-05 L
.96748 4e-05 L
.96754 4e-05 L
.96761 4e-05 L
.96768 4e-05 L
.96772 4e-05 L
.96776 4e-05 L
.96783 4e-05 L
Mistroke
.9679 4e-05 L
.96795 4e-05 L
.96802 4e-05 L
.96808 4e-05 L
.96815 4e-05 L
.9682 4e-05 L
.96826 4e-05 L
.96832 4e-05 L
.96838 4e-05 L
.96844 4e-05 L
.96851 4e-05 L
.96857 4e-05 L
.96863 4e-05 L
.96869 4e-05 L
.96873 4e-05 L
.96877 4e-05 L
.96883 4e-05 L
.9689 4e-05 L
.96897 4e-05 L
.96904 4e-05 L
.96911 4e-05 L
.96917 4e-05 L
.96923 4e-05 L
.96929 4e-05 L
.96936 4e-05 L
.96942 4e-05 L
.96949 4e-05 L
.96956 4e-05 L
.96962 4e-05 L
.96969 4e-05 L
.96976 4e-05 L
.9698 4e-05 L
.96984 4e-05 L
.96991 4e-05 L
.96998 4e-05 L
.97003 4e-05 L
.9701 4e-05 L
.97017 4e-05 L
.97023 4e-05 L
.97029 4e-05 L
.97034 4e-05 L
.9704 4e-05 L
.97046 4e-05 L
.97052 4e-05 L
.97059 4e-05 L
.97065 4e-05 L
.97071 4e-05 L
.97078 4e-05 L
.97082 4e-05 L
.97085 4e-05 L
Mistroke
.97091 4e-05 L
.97098 4e-05 L
.97105 4e-05 L
.97109 4e-05 L
.97112 4e-05 L
.97119 4e-05 L
.97125 4e-05 L
.97132 4e-05 L
.97137 4e-05 L
.97144 4e-05 L
.9715 4e-05 L
.97157 4e-05 L
.97161 4e-05 L
.97164 4e-05 L
.97172 4e-05 L
.97176 4e-05 L
.97179 4e-05 L
.97186 4e-05 L
.97193 4e-05 L
.972 4e-05 L
.97206 4e-05 L
.97212 4e-05 L
.97218 4e-05 L
.97224 4e-05 L
.97229 4e-05 L
.97236 4e-05 L
.97243 4e-05 L
.97249 4e-05 L
.97255 4e-05 L
.97262 4e-05 L
.97268 4e-05 L
.97274 4e-05 L
.9728 4e-05 L
.97287 4e-05 L
.97294 4e-05 L
.973 4e-05 L
.97307 4e-05 L
.97314 4e-05 L
.97321 4e-05 L
.97324 4e-05 L
.97328 4e-05 L
.97332 4e-05 L
.97336 4e-05 L
.97342 4e-05 L
.97349 4e-05 L
.97356 4e-05 L
.97363 4e-05 L
.97369 4e-05 L
.97376 4e-05 L
.97382 4e-05 L
Mistroke
.97387 4e-05 L
.97394 4e-05 L
.97401 4e-05 L
.97408 4e-05 L
.97414 4e-05 L
.97421 4e-05 L
.97428 4e-05 L
.97435 4e-05 L
.97441 4e-05 L
.97448 4e-05 L
.97452 4e-05 L
.97456 4e-05 L
.97463 4e-05 L
.97466 4e-05 L
.9747 4e-05 L
.97474 4e-05 L
.97478 4e-05 L
.97485 4e-05 L
.97489 4e-05 L
.97492 4e-05 L
.97496 4e-05 L
.975 4e-05 L
.97504 4e-05 L
.97508 4e-05 L
.97512 4e-05 L
.97515 4e-05 L
.97522 4e-05 L
.97529 4e-05 L
.97536 4e-05 L
.97543 4e-05 L
.9755 4e-05 L
.97556 4e-05 L
.97562 4e-05 L
.97568 4e-05 L
.97575 4e-05 L
.97581 4e-05 L
.97588 4e-05 L
.97595 4e-05 L
.97601 4e-05 L
.97607 4e-05 L
.97615 4e-05 L
.97619 4e-05 L
.97622 4e-05 L
.9763 4e-05 L
.97636 4e-05 L
.97642 4e-05 L
.97649 4e-05 L
.97655 4e-05 L
.97661 4e-05 L
.97667 4e-05 L
Mistroke
.97673 4e-05 L
.97678 4e-05 L
.97685 4e-05 L
.97691 4e-05 L
.97697 4e-05 L
.97704 4e-05 L
.9771 4e-05 L
.97716 4e-05 L
.9772 4e-05 L
.97724 4e-05 L
.9773 4e-05 L
.97737 4e-05 L
.97744 4e-05 L
.97751 4e-05 L
.97758 4e-05 L
.97764 4e-05 L
.9777 4e-05 L
.97776 4e-05 L
.97783 4e-05 L
.97789 4e-05 L
.97796 4e-05 L
.97803 4e-05 L
.97809 4e-05 L
.97816 4e-05 L
.97823 4e-05 L
.97827 4e-05 L
.9783 4e-05 L
.97838 4e-05 L
.97844 4e-05 L
.9785 4e-05 L
.97857 4e-05 L
.97863 4e-05 L
.9787 4e-05 L
.97875 4e-05 L
.97881 4e-05 L
.97887 4e-05 L
.97893 4e-05 L
.97899 4e-05 L
.97906 4e-05 L
.97912 4e-05 L
.97918 4e-05 L
.97924 4e-05 L
.97928 4e-05 L
.97932 4e-05 L
.97938 4e-05 L
.97945 4e-05 L
.97952 4e-05 L
.97955 4e-05 L
.97959 4e-05 L
.97965 4e-05 L
Mistroke
.97972 4e-05 L
.97978 4e-05 L
.97984 4e-05 L
.9799 4e-05 L
.97997 4e-05 L
.98004 4e-05 L
.98008 4e-05 L
.98011 4e-05 L
.98018 4e-05 L
.98022 4e-05 L
.98026 4e-05 L
.98033 4e-05 L
.9804 4e-05 L
.98047 4e-05 L
.98053 4e-05 L
.98059 4e-05 L
.98065 4e-05 L
.98071 4e-05 L
.98076 4e-05 L
.98082 4e-05 L
.98089 4e-05 L
.98096 4e-05 L
.98102 4e-05 L
.98108 4e-05 L
.98115 4e-05 L
.98121 4e-05 L
.98127 4e-05 L
.98134 4e-05 L
.98141 4e-05 L
.98147 4e-05 L
.98153 4e-05 L
.98161 4e-05 L
.98167 4e-05 L
.98171 4e-05 L
.98175 4e-05 L
.98179 4e-05 L
.98182 4e-05 L
.98189 4e-05 L
.98195 4e-05 L
.98202 4e-05 L
.9821 4e-05 L
.98216 4e-05 L
.98222 4e-05 L
.98228 4e-05 L
.98234 4e-05 L
.98241 4e-05 L
.98248 4e-05 L
.98255 4e-05 L
.98261 4e-05 L
.98267 4e-05 L
Mistroke
.98275 4e-05 L
.98281 4e-05 L
.98287 4e-05 L
.98295 4e-05 L
.98299 4e-05 L
.98302 4e-05 L
.98309 4e-05 L
.98313 4e-05 L
.98317 4e-05 L
.9832 4e-05 L
.98324 4e-05 L
.98331 4e-05 L
.98335 4e-05 L
.98339 4e-05 L
.98343 4e-05 L
.98347 4e-05 L
.98351 4e-05 L
.98355 4e-05 L
.98359 4e-05 L
.98362 4e-05 L
.98369 4e-05 L
.98376 4e-05 L
.98382 4e-05 L
.98389 4e-05 L
.98396 4e-05 L
.98403 4e-05 L
.98409 4e-05 L
.98415 4e-05 L
.98421 4e-05 L
.98427 4e-05 L
.98434 4e-05 L
.98441 4e-05 L
.98447 4e-05 L
.98454 4e-05 L
.98461 4e-05 L
.98465 4e-05 L
.98469 4e-05 L
.98476 4e-05 L
.98483 4e-05 L
.98489 4e-05 L
.98495 4e-05 L
.98502 4e-05 L
.98508 4e-05 L
.98514 4e-05 L
.98519 4e-05 L
.98525 4e-05 L
.98531 4e-05 L
.98537 4e-05 L
.98544 4e-05 L
.9855 4e-05 L
Mistroke
.98556 4e-05 L
.98563 4e-05 L
.98567 4e-05 L
.9857 4e-05 L
.98577 4e-05 L
.98583 4e-05 L
.9859 4e-05 L
.98597 4e-05 L
.98604 4e-05 L
.98611 4e-05 L
.98617 4e-05 L
.98623 4e-05 L
.98629 4e-05 L
.98635 4e-05 L
.98642 4e-05 L
.98649 4e-05 L
.98655 4e-05 L
.98662 4e-05 L
.98669 4e-05 L
.98673 4e-05 L
.98677 4e-05 L
.98684 4e-05 L
.98691 4e-05 L
.98697 4e-05 L
.98703 4e-05 L
.9871 4e-05 L
.98716 4e-05 L
.98722 4e-05 L
.98727 4e-05 L
.98733 4e-05 L
.98739 4e-05 L
.98745 4e-05 L
.98752 4e-05 L
.98758 4e-05 L
.98764 4e-05 L
.98771 4e-05 L
.98775 4e-05 L
.98778 4e-05 L
.98785 4e-05 L
.98792 4e-05 L
.98798 4e-05 L
.98802 4e-05 L
.98805 4e-05 L
.98812 4e-05 L
.98819 4e-05 L
.98825 4e-05 L
.9883 4e-05 L
.98837 4e-05 L
.98843 4e-05 L
.9885 4e-05 L
Mistroke
.98854 4e-05 L
.98858 4e-05 L
.98865 4e-05 L
.98869 4e-05 L
.98873 4e-05 L
.98879 4e-05 L
.98886 4e-05 L
.98893 4e-05 L
.98899 4e-05 L
.98905 4e-05 L
.98911 4e-05 L
.98917 4e-05 L
.98923 4e-05 L
.98929 4e-05 L
.98936 4e-05 L
.98942 4e-05 L
.98948 4e-05 L
.98955 4e-05 L
.98961 4e-05 L
.98967 4e-05 L
.98973 4e-05 L
.9898 4e-05 L
.98987 4e-05 L
.98993 4e-05 L
.99 4e-05 L
.99007 4e-05 L
.99014 4e-05 L
.99017 4e-05 L
.99021 4e-05 L
.99025 4e-05 L
.99029 4e-05 L
.99036 4e-05 L
.99042 4e-05 L
.99049 4e-05 L
.99056 4e-05 L
.99062 4e-05 L
.99069 4e-05 L
.99075 4e-05 L
.9908 4e-05 L
.99087 4e-05 L
.99094 4e-05 L
.99101 4e-05 L
.99107 4e-05 L
.99114 4e-05 L
.99121 4e-05 L
.99128 4e-05 L
.99134 4e-05 L
.99141 4e-05 L
.99145 4e-05 L
.99149 4e-05 L
Mistroke
.99156 4e-05 L
.99159 4e-05 L
.99163 4e-05 L
.99167 4e-05 L
.99171 4e-05 L
.99178 4e-05 L
.99181 4e-05 L
.99185 4e-05 L
.99189 4e-05 L
.99193 4e-05 L
.99197 4e-05 L
.99201 4e-05 L
.99205 4e-05 L
.99208 4e-05 L
.99215 4e-05 L
.99222 4e-05 L
.99229 4e-05 L
.99236 4e-05 L
.99243 4e-05 L
.99249 4e-05 L
.99255 4e-05 L
.99261 4e-05 L
.99267 4e-05 L
.99274 4e-05 L
.9928 4e-05 L
.99288 4e-05 L
.99294 4e-05 L
.993 4e-05 L
.99308 4e-05 L
.99312 4e-05 L
.99315 4e-05 L
.99322 4e-05 L
.99329 4e-05 L
.99335 4e-05 L
.99341 4e-05 L
.99348 4e-05 L
.99354 4e-05 L
.9936 4e-05 L
.99365 4e-05 L
.99371 4e-05 L
.99377 4e-05 L
.99384 4e-05 L
.9939 4e-05 L
.99397 4e-05 L
.99402 4e-05 L
.99409 4e-05 L
.99413 4e-05 L
.99416 4e-05 L
.99423 4e-05 L
.9943 4e-05 L
Mistroke
.99436 4e-05 L
.99444 4e-05 L
.9945 4e-05 L
.99457 4e-05 L
.99463 4e-05 L
.99469 4e-05 L
.99475 4e-05 L
.99482 4e-05 L
.99488 4e-05 L
.99495 4e-05 L
.99502 4e-05 L
.99508 4e-05 L
.99516 4e-05 L
.9952 4e-05 L
.99523 4e-05 L
.9953 4e-05 L
.99537 4e-05 L
.99543 4e-05 L
.99549 4e-05 L
.99556 4e-05 L
.99562 4e-05 L
.99568 4e-05 L
.99573 4e-05 L
.99579 4e-05 L
.99585 4e-05 L
.99592 4e-05 L
.99598 4e-05 L
.99605 4e-05 L
.9961 4e-05 L
.99617 4e-05 L
.99621 4e-05 L
.99624 4e-05 L
.99631 4e-05 L
.99638 4e-05 L
.99644 4e-05 L
.99648 4e-05 L
.99652 4e-05 L
.99658 4e-05 L
.99665 4e-05 L
.99671 4e-05 L
.99677 4e-05 L
.99683 4e-05 L
.9969 4e-05 L
.99696 4e-05 L
.997 4e-05 L
.99704 4e-05 L
.99711 4e-05 L
.99715 4e-05 L
.99719 4e-05 L
.99725 4e-05 L
Mistroke
.99732 4e-05 L
.99739 4e-05 L
.99745 4e-05 L
.99751 4e-05 L
.99757 4e-05 L
.99763 4e-05 L
.99769 4e-05 L
.99775 4e-05 L
.99782 4e-05 L
.99788 4e-05 L
.99794 4e-05 L
.99801 4e-05 L
.99807 4e-05 L
.99813 4e-05 L
.99819 4e-05 L
.99826 4e-05 L
.99833 4e-05 L
.99839 4e-05 L
.99846 4e-05 L
.99851 4e-05 L
.99855 4e-05 L
.9986 4e-05 L
.99866 4e-05 L
.9987 4e-05 L
.99874 4e-05 L
.99879 4e-05 L
.99884 4e-05 L
.99888 4e-05 L
.99893 4e-05 L
.99897 4e-05 L
.99902 4e-05 L
.99906 4e-05 L
.9991 4e-05 L
.99914 4e-05 L
.99918 4e-05 L
.99923 4e-05 L
.99928 4e-05 L
.99933 4e-05 L
.99938 4e-05 L
.99942 4e-05 L
.99946 4e-05 L
.99951 4e-05 L
.99956 4e-05 L
.99961 4e-05 L
.99966 4e-05 L
.99971 4e-05 L
.99975 4e-05 L
.9998 4e-05 L
.99986 4e-05 L
.99991 4e-05 L
Mistroke
.99996 4e-05 L
Mfstroke
.94766 .84358 m
.94978 .84521 L
.9521 .84699 L
.95427 .84866 L
.95636 .85027 L
.95858 .85197 L
.96072 .85362 L
.963 .85537 L
.96519 .85705 L
.9673 .85867 L
.96955 .86039 L
.97171 .86205 L
.97379 .86365 L
.976 .86534 L
.97813 .86698 L
.98039 .86871 L
.98257 .87038 L
.98467 .87199 L
.9869 .8737 L
.98905 .87535 L
.99133 .8771 L
.99353 .87878 L
.99565 .8804 L
.9979 .88213 L
.99996 .8837 L
s
.17495 4e-05 m
.1759 4e-05 L
.17677 4e-05 L
.17777 4e-05 L
.17872 4e-05 L
.17959 4e-05 L
.1804 4e-05 L
.18129 4e-05 L
.18223 4e-05 L
.18317 4e-05 L
.18419 4e-05 L
.18515 4e-05 L
.18603 4e-05 L
.18705 4e-05 L
.18763 4e-05 L
.18817 4e-05 L
.18915 4e-05 L
.19021 4e-05 L
.19073 4e-05 L
.19129 4e-05 L
.19229 4e-05 L
.19285 4e-05 L
.19337 4e-05 L
.19394 4e-05 L
.19455 4e-05 L
.19508 4e-05 L
.19565 4e-05 L
.19669 4e-05 L
.19771 4e-05 L
.19864 4e-05 L
.19955 4e-05 L
.20041 4e-05 L
.20134 4e-05 L
.20235 4e-05 L
.20335 4e-05 L
.20441 4e-05 L
.20531 4e-05 L
.20629 4e-05 L
.20687 4e-05 L
.2074 4e-05 L
.20798 4e-05 L
.2086 4e-05 L
.20964 4e-05 L
.21023 4e-05 L
.21078 4e-05 L
.21181 4e-05 L
.21274 4e-05 L
.21326 4e-05 L
.21383 4e-05 L
.21486 4e-05 L
Mistroke
.21548 4e-05 L
.21606 4e-05 L
.21659 4e-05 L
.21715 4e-05 L
.21777 4e-05 L
.21843 4e-05 L
.21899 4e-05 L
.2196 4e-05 L
.22018 4e-05 L
.2207 4e-05 L
.22131 4e-05 L
.22188 4e-05 L
.2229 4e-05 L
.22347 4e-05 L
.224 4e-05 L
.22495 4e-05 L
.22597 4e-05 L
.22693 4e-05 L
.22781 4e-05 L
.22878 4e-05 L
.22985 4e-05 L
.23039 4e-05 L
.23096 4e-05 L
.232 4e-05 L
.23257 4e-05 L
.2331 4e-05 L
.23367 4e-05 L
.23429 4e-05 L
.23531 4e-05 L
.2359 4e-05 L
.23644 4e-05 L
.23746 4e-05 L
.23839 4e-05 L
.23946 4e-05 L
.24048 4e-05 L
.2414 4e-05 L
.24239 4e-05 L
.24333 4e-05 L
.24419 4e-05 L
.24515 4e-05 L
.24619 4e-05 L
.24672 4e-05 L
.24728 4e-05 L
.2483 4e-05 L
.24886 4e-05 L
.24937 4e-05 L
.24994 4e-05 L
.25054 4e-05 L
.25154 4e-05 L
.25212 4e-05 L
Mistroke
.25265 4e-05 L
.25365 4e-05 L
.25456 4e-05 L
.25561 4e-05 L
.25661 4e-05 L
.25755 4e-05 L
.25841 4e-05 L
.25939 4e-05 L
.26032 4e-05 L
.26118 4e-05 L
.26197 4e-05 L
.26284 4e-05 L
.26376 4e-05 L
.26469 4e-05 L
.26568 4e-05 L
.26662 4e-05 L
.26747 4e-05 L
.26848 4e-05 L
.26904 4e-05 L
.26957 4e-05 L
.27053 4e-05 L
.27155 4e-05 L
.27248 4e-05 L
.27349 4e-05 L
.27454 4e-05 L
.27552 4e-05 L
.27645 4e-05 L
.27728 4e-05 L
.27825 4e-05 L
.27916 4e-05 L
.28016 4e-05 L
.28121 4e-05 L
.28211 4e-05 L
.2831 4e-05 L
.28416 4e-05 L
.28476 4e-05 L
.2853 4e-05 L
.28636 4e-05 L
.28736 4e-05 L
.2883 4e-05 L
.28915 4e-05 L
.29013 4e-05 L
.29105 4e-05 L
.2919 4e-05 L
.29269 4e-05 L
.29355 4e-05 L
.29446 4e-05 L
.29538 4e-05 L
.29637 4e-05 L
.2973 4e-05 L
Mistroke
.29815 4e-05 L
.29915 4e-05 L
.29971 4e-05 L
.30023 4e-05 L
.30119 4e-05 L
.3022 4e-05 L
.30317 4e-05 L
.30424 4e-05 L
.30525 4e-05 L
.30618 4e-05 L
.30711 4e-05 L
.30795 4e-05 L
.30891 4e-05 L
.30983 4e-05 L
.31083 4e-05 L
.31188 4e-05 L
.31278 4e-05 L
.31377 4e-05 L
.31484 4e-05 L
.31543 4e-05 L
.31598 4e-05 L
.31704 4e-05 L
.31804 4e-05 L
.31889 4e-05 L
.31983 4e-05 L
.32081 4e-05 L
.32173 4e-05 L
.32259 4e-05 L
.32338 4e-05 L
.32424 4e-05 L
.32515 4e-05 L
.32607 4e-05 L
.32706 4e-05 L
.32799 4e-05 L
.32884 4e-05 L
.32984 4e-05 L
.3304 4e-05 L
.33092 4e-05 L
.33187 4e-05 L
.33288 4e-05 L
.33387 4e-05 L
.33493 4e-05 L
.33594 4e-05 L
.33688 4e-05 L
.33781 4e-05 L
.33865 4e-05 L
.33962 4e-05 L
.34054 4e-05 L
.34154 4e-05 L
.34259 4e-05 L
Mistroke
.3435 4e-05 L
.34449 4e-05 L
.34555 4e-05 L
.34615 4e-05 L
.3467 4e-05 L
.34776 4e-05 L
.34876 4e-05 L
.34961 4e-05 L
.35055 4e-05 L
.35154 4e-05 L
.35246 4e-05 L
.35332 4e-05 L
.3541 4e-05 L
.35497 4e-05 L
.35588 4e-05 L
.3568 4e-05 L
.35779 4e-05 L
.35873 4e-05 L
.35957 4e-05 L
.36057 4e-05 L
.36114 4e-05 L
.36165 4e-05 L
.36261 4e-05 L
.36361 4e-05 L
.3646 4e-05 L
.36567 4e-05 L
.36669 4e-05 L
.36762 4e-05 L
.36847 4e-05 L
.3694 4e-05 L
.37037 4e-05 L
.37129 4e-05 L
.37229 4e-05 L
.37335 4e-05 L
.37426 4e-05 L
.37525 4e-05 L
.37632 4e-05 L
.37691 4e-05 L
.37746 4e-05 L
.37852 4e-05 L
.37952 4e-05 L
.38038 4e-05 L
.38132 4e-05 L
.3823 4e-05 L
.38323 4e-05 L
.38409 4e-05 L
.38488 4e-05 L
.38579 4e-05 L
.38665 4e-05 L
.38758 4e-05 L
Mistroke
.38857 4e-05 L
.3895 4e-05 L
.39035 4e-05 L
.39135 4e-05 L
.39191 4e-05 L
.39243 4e-05 L
.39338 4e-05 L
.39439 4e-05 L
.39538 4e-05 L
.39594 4e-05 L
.39645 4e-05 L
.3974 4e-05 L
.39841 4e-05 L
.39931 4e-05 L
.40015 4e-05 L
.40108 4e-05 L
.40208 4e-05 L
.40308 4e-05 L
.40365 4e-05 L
.40417 4e-05 L
.40524 4e-05 L
.40584 4e-05 L
.40638 4e-05 L
.40735 4e-05 L
.40841 4e-05 L
.40941 4e-05 L
.41032 4e-05 L
.41118 4e-05 L
.4121 4e-05 L
.41297 4e-05 L
.41377 4e-05 L
.4147 4e-05 L
.41571 4e-05 L
.41666 4e-05 L
.41755 4e-05 L
.41855 4e-05 L
.4195 4e-05 L
.42034 4e-05 L
.42126 4e-05 L
.42226 4e-05 L
.42331 4e-05 L
.42421 4e-05 L
.4252 4e-05 L
.42626 4e-05 L
.42725 4e-05 L
.42776 4e-05 L
.42832 4e-05 L
.42892 4e-05 L
.42947 4e-05 L
.43048 4e-05 L
Mistroke
.43141 4e-05 L
.43249 4e-05 L
.43351 4e-05 L
.43441 4e-05 L
.43538 4e-05 L
.43629 4e-05 L
.43712 4e-05 L
.43809 4e-05 L
.43915 4e-05 L
.44015 4e-05 L
.44107 4e-05 L
.44205 4e-05 L
.4431 4e-05 L
.44409 4e-05 L
.445 4e-05 L
.44606 4e-05 L
.44666 4e-05 L
.44722 4e-05 L
.44824 4e-05 L
.44875 4e-05 L
.44932 4e-05 L
.44987 4e-05 L
.45045 4e-05 L
.45149 4e-05 L
.45206 4e-05 L
.4526 4e-05 L
.45319 4e-05 L
.45382 4e-05 L
.45437 4e-05 L
.45496 4e-05 L
.45552 4e-05 L
.45603 4e-05 L
.45701 4e-05 L
.45805 4e-05 L
.45903 4e-05 L
.4601 4e-05 L
.46111 4e-05 L
.46204 4e-05 L
.46297 4e-05 L
.46381 4e-05 L
.46478 4e-05 L
.46569 4e-05 L
.4667 4e-05 L
.46775 4e-05 L
.46865 4e-05 L
.46964 4e-05 L
.47071 4e-05 L
.47131 4e-05 L
.47185 4e-05 L
.47291 4e-05 L
Mistroke
.47391 4e-05 L
.47477 4e-05 L
.47571 4e-05 L
.47669 4e-05 L
.47761 4e-05 L
.47847 4e-05 L
.47926 4e-05 L
.48012 4e-05 L
.48103 4e-05 L
.48196 4e-05 L
.48295 4e-05 L
.48388 4e-05 L
.48473 4e-05 L
.48572 4e-05 L
.48629 4e-05 L
.48681 4e-05 L
.48776 4e-05 L
.48877 4e-05 L
.48975 4e-05 L
.49082 4e-05 L
.49184 4e-05 L
.49278 4e-05 L
.49371 4e-05 L
.49455 4e-05 L
.49552 4e-05 L
.49643 4e-05 L
.49744 4e-05 L
.4985 4e-05 L
.4994 4e-05 L
.50039 4e-05 L
.50146 4e-05 L
.50206 4e-05 L
.5026 4e-05 L
.50366 4e-05 L
.50467 4e-05 L
.50552 4e-05 L
.50646 4e-05 L
.50745 4e-05 L
.50837 4e-05 L
.50923 4e-05 L
.51002 4e-05 L
.51093 4e-05 L
.51179 4e-05 L
.51272 4e-05 L
.51371 4e-05 L
.51464 4e-05 L
.51549 4e-05 L
.51649 4e-05 L
.51705 4e-05 L
.51757 4e-05 L
Mistroke
.51852 4e-05 L
.51953 4e-05 L
.52052 4e-05 L
.52108 4e-05 L
.52159 4e-05 L
.52254 4e-05 L
.52355 4e-05 L
.52445 4e-05 L
.52529 4e-05 L
.52622 4e-05 L
.52722 4e-05 L
.52822 4e-05 L
.52878 4e-05 L
.52931 4e-05 L
.53038 4e-05 L
.53097 4e-05 L
.53152 4e-05 L
.53249 4e-05 L
.53355 4e-05 L
.53454 4e-05 L
.53546 4e-05 L
.53632 4e-05 L
.53724 4e-05 L
.53811 4e-05 L
.5389 4e-05 L
.53983 4e-05 L
.54084 4e-05 L
.5418 4e-05 L
.54268 4e-05 L
.54369 4e-05 L
.54463 4e-05 L
.54547 4e-05 L
.54639 4e-05 L
.54739 4e-05 L
.54844 4e-05 L
.54935 4e-05 L
.55033 4e-05 L
.5514 4e-05 L
.55238 4e-05 L
.55289 4e-05 L
.55346 4e-05 L
.55405 4e-05 L
.5546 4e-05 L
.55561 4e-05 L
.55654 4e-05 L
.55756 4e-05 L
.55863 4e-05 L
.55954 4e-05 L
.56051 4e-05 L
.56142 4e-05 L
Mistroke
.56225 4e-05 L
.56322 4e-05 L
.56428 4e-05 L
.56527 4e-05 L
.56619 4e-05 L
.56717 4e-05 L
.56822 4e-05 L
.56922 4e-05 L
.57012 4e-05 L
.57119 4e-05 L
.57179 4e-05 L
.57234 4e-05 L
.57336 4e-05 L
.57388 4e-05 L
.57444 4e-05 L
.57499 4e-05 L
.57557 4e-05 L
.57661 4e-05 L
.57719 4e-05 L
.57772 4e-05 L
.57831 4e-05 L
.57894 4e-05 L
.57949 4e-05 L
.58008 4e-05 L
.58064 4e-05 L
.58116 4e-05 L
.58213 4e-05 L
.58317 4e-05 L
.58415 4e-05 L
.58522 4e-05 L
.58623 4e-05 L
.58716 4e-05 L
.58809 4e-05 L
.58893 4e-05 L
.5899 4e-05 L
.59081 4e-05 L
.59181 4e-05 L
.59287 4e-05 L
.59377 4e-05 L
.59476 4e-05 L
.59583 4e-05 L
.59642 4e-05 L
.59697 4e-05 L
.59803 4e-05 L
.59903 4e-05 L
.59988 4e-05 L
.60082 4e-05 L
.6018 4e-05 L
.60273 4e-05 L
.60358 4e-05 L
Mistroke
.60437 4e-05 L
.60524 4e-05 L
.60614 4e-05 L
.60707 4e-05 L
.60806 4e-05 L
.60899 4e-05 L
.60984 4e-05 L
.61084 4e-05 L
.6114 4e-05 L
.61192 4e-05 L
.61287 4e-05 L
.61388 4e-05 L
.61486 4e-05 L
.61594 4e-05 L
.61695 4e-05 L
.61789 4e-05 L
.61882 4e-05 L
.61966 4e-05 L
.62063 4e-05 L
.62154 4e-05 L
.62255 4e-05 L
.62361 4e-05 L
.62451 4e-05 L
.6255 4e-05 L
.62657 4e-05 L
.62717 4e-05 L
.62771 4e-05 L
.62877 4e-05 L
.62977 4e-05 L
.63063 4e-05 L
.63157 4e-05 L
.63255 4e-05 L
.63348 4e-05 L
.63434 4e-05 L
.63512 4e-05 L
.63603 4e-05 L
.6369 4e-05 L
.63782 4e-05 L
.63881 4e-05 L
.63975 4e-05 L
.64059 4e-05 L
.64159 4e-05 L
.64216 4e-05 L
.64267 4e-05 L
.64363 4e-05 L
.64463 4e-05 L
.64562 4e-05 L
.64618 4e-05 L
.6467 4e-05 L
.64764 4e-05 L
Mistroke
.64865 4e-05 L
.64955 4e-05 L
.65039 4e-05 L
.65132 4e-05 L
.65232 4e-05 L
.65332 4e-05 L
.65388 4e-05 L
.65441 4e-05 L
.65547 4e-05 L
.65607 4e-05 L
.65661 4e-05 L
.65759 4e-05 L
.65864 4e-05 L
.65964 4e-05 L
.66056 4e-05 L
.66141 4e-05 L
.66233 4e-05 L
.6632 4e-05 L
.66399 4e-05 L
.66492 4e-05 L
.66593 4e-05 L
.66689 4e-05 L
.66778 4e-05 L
.66878 4e-05 L
.66972 4e-05 L
.67057 4e-05 L
.67148 4e-05 L
.67248 4e-05 L
.67354 4e-05 L
.67444 4e-05 L
.67543 4e-05 L
.67649 4e-05 L
.67747 4e-05 L
.67798 4e-05 L
.67855 4e-05 L
.67914 4e-05 L
.67969 4e-05 L
.6807 4e-05 L
.68163 4e-05 L
.68265 4e-05 L
.68372 4e-05 L
.68463 4e-05 L
.68559 4e-05 L
.6865 4e-05 L
.68733 4e-05 L
.68831 4e-05 L
.68936 4e-05 L
.69036 4e-05 L
.69128 4e-05 L
.69226 4e-05 L
Mistroke
.69331 4e-05 L
.6943 4e-05 L
.69521 4e-05 L
.69627 4e-05 L
.69687 4e-05 L
.69742 4e-05 L
.69844 4e-05 L
.69896 4e-05 L
.69953 4e-05 L
.70008 4e-05 L
.70066 4e-05 L
.70169 4e-05 L
.70227 4e-05 L
.70281 4e-05 L
.70339 4e-05 L
.70403 4e-05 L
.70457 4e-05 L
.70516 4e-05 L
.70572 4e-05 L
.70624 4e-05 L
.70722 4e-05 L
.70825 4e-05 L
.70923 4e-05 L
.7103 4e-05 L
.71131 4e-05 L
.71224 4e-05 L
.71317 4e-05 L
.71401 4e-05 L
.71498 4e-05 L
.71589 4e-05 L
.71689 4e-05 L
.71795 4e-05 L
.71885 4e-05 L
.71984 4e-05 L
.7209 4e-05 L
.7215 4e-05 L
.72204 4e-05 L
.7231 4e-05 L
.72411 4e-05 L
.72496 4e-05 L
.7259 4e-05 L
.72688 4e-05 L
.7278 4e-05 L
.72866 4e-05 L
.72944 4e-05 L
.73031 4e-05 L
.73122 4e-05 L
.73214 4e-05 L
.73313 4e-05 L
.73406 4e-05 L
Mistroke
.73491 4e-05 L
.73591 4e-05 L
.73647 4e-05 L
.73699 4e-05 L
.73794 4e-05 L
.73895 4e-05 L
.73994 4e-05 L
.74101 4e-05 L
.74202 4e-05 L
.74296 4e-05 L
.74388 4e-05 L
.74473 4e-05 L
.7457 4e-05 L
.74661 4e-05 L
.74761 4e-05 L
.74867 4e-05 L
.74958 4e-05 L
.75057 4e-05 L
.75163 4e-05 L
.75223 4e-05 L
.75278 4e-05 L
.75384 4e-05 L
.75484 4e-05 L
.75569 4e-05 L
.75663 4e-05 L
.75762 4e-05 L
.75854 4e-05 L
.7594 4e-05 L
.76019 4e-05 L
.76105 4e-05 L
.76196 4e-05 L
.76289 4e-05 L
.76388 4e-05 L
.76481 4e-05 L
.76566 4e-05 L
.76666 4e-05 L
.76722 4e-05 L
.76774 4e-05 L
.76869 4e-05 L
.7697 4e-05 L
.77068 4e-05 L
.77124 4e-05 L
.77176 4e-05 L
.7727 4e-05 L
.77371 4e-05 L
.77461 4e-05 L
.77545 4e-05 L
.77638 4e-05 L
.77737 4e-05 L
.77837 4e-05 L
Mistroke
.77894 4e-05 L
.77947 4e-05 L
.78053 4e-05 L
.78113 4e-05 L
.78167 4e-05 L
.78264 4e-05 L
.7837 4e-05 L
.78469 4e-05 L
.78561 4e-05 L
.78647 4e-05 L
.78739 4e-05 L
.78825 4e-05 L
.78905 4e-05 L
.78998 4e-05 L
.79099 4e-05 L
.79194 4e-05 L
.79283 4e-05 L
.79383 4e-05 L
.79477 4e-05 L
.79562 4e-05 L
.79653 4e-05 L
.79753 4e-05 L
.79859 4e-05 L
.79949 4e-05 L
.80048 4e-05 L
.80154 4e-05 L
.80252 4e-05 L
.80303 4e-05 L
.8036 4e-05 L
.80419 4e-05 L
.80474 4e-05 L
.80575 4e-05 L
.80668 4e-05 L
.8077 4e-05 L
.80877 4e-05 L
.80967 4e-05 L
.81064 4e-05 L
.81155 4e-05 L
.81238 4e-05 L
.81335 4e-05 L
.81441 4e-05 L
.8154 4e-05 L
.81632 4e-05 L
.8173 4e-05 L
.81835 4e-05 L
.81935 4e-05 L
.82025 4e-05 L
.82131 4e-05 L
.82191 4e-05 L
.82247 4e-05 L
Mistroke
.82349 4e-05 L
.82406 4e-05 L
.82457 4e-05 L
.82512 4e-05 L
.8257 4e-05 L
.82673 4e-05 L
.82731 4e-05 L
.82785 4e-05 L
.82844 4e-05 L
.82907 4e-05 L
.82961 4e-05 L
.83021 4e-05 L
.83077 4e-05 L
.83128 4e-05 L
.83226 4e-05 L
.8333 4e-05 L
.83427 4e-05 L
.83534 4e-05 L
.83635 4e-05 L
.83728 4e-05 L
.83821 4e-05 L
.83905 4e-05 L
.84002 4e-05 L
.84093 4e-05 L
.84193 4e-05 L
.84298 4e-05 L
.84388 4e-05 L
.84487 4e-05 L
.84594 4e-05 L
.84654 4e-05 L
.84708 4e-05 L
.84814 4e-05 L
.84914 4e-05 L
.84999 4e-05 L
.85093 4e-05 L
.85191 4e-05 L
.85283 4e-05 L
.85369 4e-05 L
.85448 4e-05 L
.85534 4e-05 L
.85625 4e-05 L
.85718 4e-05 L
.85816 4e-05 L
.8591 4e-05 L
.85995 4e-05 L
.86094 4e-05 L
.86151 4e-05 L
.86202 4e-05 L
.86298 4e-05 L
.86399 4e-05 L
Mistroke
.86497 4e-05 L
.86604 4e-05 L
.86705 4e-05 L
.86799 4e-05 L
.86891 4e-05 L
.86976 4e-05 L
.87073 4e-05 L
.87164 4e-05 L
.87264 4e-05 L
.8737 4e-05 L
.8746 4e-05 L
.87559 4e-05 L
.87666 4e-05 L
.87726 4e-05 L
.8778 4e-05 L
.87886 4e-05 L
.87986 4e-05 L
.88072 4e-05 L
.88166 4e-05 L
.88264 4e-05 L
.88356 4e-05 L
.88442 4e-05 L
.88521 4e-05 L
.88607 4e-05 L
.88698 4e-05 L
.88791 4e-05 L
.8889 4e-05 L
.88983 4e-05 L
.89068 4e-05 L
.89168 4e-05 L
.89224 4e-05 L
.89276 4e-05 L
.89371 4e-05 L
.89472 4e-05 L
.8957 4e-05 L
.89626 4e-05 L
.89678 4e-05 L
.89772 4e-05 L
.89873 4e-05 L
.89963 4e-05 L
.90047 4e-05 L
.90139 4e-05 L
.90239 4e-05 L
.90339 4e-05 L
.90396 4e-05 L
.90448 4e-05 L
.90555 4e-05 L
.90614 4e-05 L
.90669 4e-05 L
.90766 4e-05 L
Mistroke
.90871 4e-05 L
.90971 4e-05 L
.91063 4e-05 L
.91148 4e-05 L
.9124 4e-05 L
.91327 4e-05 L
.91406 4e-05 L
.91499 4e-05 L
.916 4e-05 L
.91696 4e-05 L
.91784 4e-05 L
.91884 4e-05 L
.91979 4e-05 L
.92063 4e-05 L
.92155 4e-05 L
.92255 4e-05 L
.9236 4e-05 L
.9245 4e-05 L
.92549 4e-05 L
.92621 4e-05 L
.92687 4e-05 L
.9276 4e-05 L
.92837 4e-05 L
.92904 4e-05 L
.92966 4e-05 L
.93035 4e-05 L
.93109 4e-05 L
.93171 4e-05 L
.93239 4e-05 L
.9331 4e-05 L
.93375 4e-05 L
.93437 4e-05 L
.93493 4e-05 L
.93558 4e-05 L
.93619 4e-05 L
.93686 4e-05 L
.93758 4e-05 L
.93834 4e-05 L
.93906 4e-05 L
.93972 4e-05 L
.94033 4e-05 L
.94103 4e-05 L
.9417 4e-05 L
.94241 4e-05 L
.94318 4e-05 L
.9439 4e-05 L
.94455 4e-05 L
.94532 4e-05 L
.94615 4e-05 L
.94694 4e-05 L
Mistroke
.94766 4e-05 L
Mfstroke
.17495 4e-05 m
.20629 .04016 L
.24048 .0839 L
.27259 .12494 L
.30346 .16437 L
.33633 .2063 L
.36797 .24659 L
.40159 .28934 L
.43399 .3304 L
.46516 .36976 L
.49831 .41139 L
.53024 .45114 L
.56094 .48885 L
.59363 .52815 L
.62508 .5646 L
.65853 .6011 L
.69075 .63348 L
.72174 .66217 L
.75471 .69075 L
.78646 .71705 L
.8202 .74421 L
.85271 .7699 L
.88399 .79434 L
.91725 .82013 L
.94766 .84358 L
s
1 1 .5 r
.17495 4e-05 m
.1759 4e-05 L
.17677 4e-05 L
.17777 4e-05 L
.17872 4e-05 L
.17959 4e-05 L
.1804 4e-05 L
.18129 4e-05 L
.18223 4e-05 L
.18317 4e-05 L
.18419 4e-05 L
.18515 4e-05 L
.18603 4e-05 L
.18705 4e-05 L
.18763 4e-05 L
.18817 4e-05 L
.18915 4e-05 L
.19021 4e-05 L
.19073 4e-05 L
.19129 4e-05 L
.19229 4e-05 L
.19285 4e-05 L
.19337 4e-05 L
.19394 4e-05 L
.19455 4e-05 L
.19508 4e-05 L
.19565 4e-05 L
.19669 4e-05 L
.19771 4e-05 L
.19864 4e-05 L
.19955 4e-05 L
.20041 4e-05 L
.20134 4e-05 L
.20235 4e-05 L
.20335 4e-05 L
.20441 4e-05 L
.20531 4e-05 L
.20629 4e-05 L
.20687 4e-05 L
.2074 4e-05 L
.20798 4e-05 L
.2086 4e-05 L
.20964 4e-05 L
.21023 4e-05 L
.21078 4e-05 L
.21181 4e-05 L
.21274 4e-05 L
.21326 4e-05 L
.21383 4e-05 L
.21486 4e-05 L
.21548 4e-05 L
.21606 4e-05 L
.21659 4e-05 L
.21715 4e-05 L
.21777 4e-05 L
.21843 4e-05 L
.21899 4e-05 L
.2196 4e-05 L
.22018 4e-05 L
.2207 4e-05 L
.22131 4e-05 L
.22188 4e-05 L
.2229 4e-05 L
.22347 4e-05 L
.224 4e-05 L
.22495 4e-05 L
.22597 4e-05 L
.22693 4e-05 L
.22781 4e-05 L
.22878 4e-05 L
.22985 4e-05 L
.23039 4e-05 L
.23096 4e-05 L
.232 4e-05 L
.23257 4e-05 L
.2331 4e-05 L
.23367 4e-05 L
.23429 4e-05 L
.23531 4e-05 L
.2359 4e-05 L
.23644 4e-05 L
.23746 4e-05 L
.23839 4e-05 L
.23946 4e-05 L
.24048 4e-05 L
.2414 4e-05 L
.24239 4e-05 L
.24333 4e-05 L
.24419 4e-05 L
.24515 4e-05 L
.24619 4e-05 L
.24672 4e-05 L
.24728 4e-05 L
.2483 4e-05 L
.24886 4e-05 L
.24937 4e-05 L
.24994 4e-05 L
.25054 4e-05 L
.25154 4e-05 L
.25212 4e-05 L
.25265 4e-05 L
.25365 4e-05 L
.25456 4e-05 L
.25561 4e-05 L
.25661 4e-05 L
.25755 4e-05 L
.25841 4e-05 L
.25939 4e-05 L
.26032 4e-05 L
.26118 4e-05 L
.26197 4e-05 L
.26284 4e-05 L
.26376 4e-05 L
.26469 4e-05 L
.26568 4e-05 L
.26662 4e-05 L
.26747 4e-05 L
.26848 4e-05 L
.26904 4e-05 L
.26957 4e-05 L
.27053 4e-05 L
.27155 4e-05 L
.27248 4e-05 L
.27349 4e-05 L
.27454 4e-05 L
.27552 4e-05 L
.27645 4e-05 L
.27728 4e-05 L
.27825 4e-05 L
.27916 4e-05 L
.28016 4e-05 L
.28121 4e-05 L
.28211 4e-05 L
.2831 4e-05 L
.28416 4e-05 L
.28476 4e-05 L
.2853 4e-05 L
.28636 4e-05 L
.28736 4e-05 L
.2883 4e-05 L
.28915 4e-05 L
.29013 4e-05 L
.29105 4e-05 L
.2919 4e-05 L
.29269 4e-05 L
.29355 4e-05 L
.29446 4e-05 L
.29538 4e-05 L
.29637 4e-05 L
.2973 4e-05 L
.29815 4e-05 L
.29915 4e-05 L
.29971 4e-05 L
.30023 4e-05 L
.30119 4e-05 L
.3022 4e-05 L
.30317 4e-05 L
.30424 4e-05 L
.30525 4e-05 L
.30618 4e-05 L
.30711 4e-05 L
.30795 4e-05 L
.30891 4e-05 L
.30983 4e-05 L
.31083 4e-05 L
.31188 4e-05 L
.31278 4e-05 L
.31377 4e-05 L
.31484 4e-05 L
.31543 4e-05 L
.31598 4e-05 L
.31704 4e-05 L
.31804 4e-05 L
.31889 4e-05 L
.31983 4e-05 L
.32081 4e-05 L
.32173 4e-05 L
.32259 4e-05 L
.32338 4e-05 L
.32424 4e-05 L
.32515 4e-05 L
.32607 4e-05 L
.32706 4e-05 L
.32799 4e-05 L
.32884 4e-05 L
.32984 4e-05 L
.3304 4e-05 L
.33092 4e-05 L
.33187 4e-05 L
.33288 4e-05 L
.33387 4e-05 L
.33493 4e-05 L
.33594 4e-05 L
.33688 4e-05 L
.33781 4e-05 L
.33865 4e-05 L
.33962 4e-05 L
.34054 4e-05 L
.34154 4e-05 L
.34259 4e-05 L
.3435 4e-05 L
.34449 4e-05 L
.34555 4e-05 L
.34615 4e-05 L
.3467 4e-05 L
.34776 4e-05 L
.34876 4e-05 L
.34961 4e-05 L
.35055 4e-05 L
.35154 4e-05 L
.35246 4e-05 L
.35332 4e-05 L
.3541 4e-05 L
.35497 4e-05 L
.35588 4e-05 L
.3568 4e-05 L
.35779 4e-05 L
.35873 4e-05 L
.35957 4e-05 L
.36057 4e-05 L
.36114 4e-05 L
.36165 4e-05 L
.36261 4e-05 L
.36361 4e-05 L
.3646 4e-05 L
.36567 4e-05 L
.36669 4e-05 L
.36762 4e-05 L
.36847 4e-05 L
.3694 4e-05 L
.37037 4e-05 L
.37129 4e-05 L
.37229 4e-05 L
.37335 4e-05 L
.37426 4e-05 L
.37525 4e-05 L
.37632 4e-05 L
.37691 4e-05 L
.37746 4e-05 L
.37852 4e-05 L
.37952 4e-05 L
.38038 4e-05 L
.38132 4e-05 L
.3823 4e-05 L
.38323 4e-05 L
.38409 4e-05 L
.38488 4e-05 L
.38579 4e-05 L
.38665 4e-05 L
.38758 4e-05 L
.38857 4e-05 L
.3895 4e-05 L
.39035 4e-05 L
.39135 4e-05 L
.39191 4e-05 L
.39243 4e-05 L
.39338 4e-05 L
.39439 4e-05 L
.39538 4e-05 L
.39594 4e-05 L
.39645 4e-05 L
.3974 4e-05 L
.39841 4e-05 L
.39931 4e-05 L
.40015 4e-05 L
.40108 4e-05 L
.40208 4e-05 L
.40308 4e-05 L
.40365 4e-05 L
.40417 4e-05 L
.40524 4e-05 L
.40584 4e-05 L
.40638 4e-05 L
.40735 4e-05 L
.40841 4e-05 L
.40941 4e-05 L
.41032 4e-05 L
.41118 4e-05 L
.4121 4e-05 L
.41297 4e-05 L
.41377 4e-05 L
.4147 4e-05 L
.41571 4e-05 L
.41666 4e-05 L
.41755 4e-05 L
.41855 4e-05 L
.4195 4e-05 L
.42034 4e-05 L
.42126 4e-05 L
.42226 4e-05 L
.42331 4e-05 L
.42421 4e-05 L
.4252 4e-05 L
.42626 4e-05 L
.42725 4e-05 L
.42776 4e-05 L
.42832 4e-05 L
.42892 4e-05 L
.42947 4e-05 L
.43048 4e-05 L
.43141 4e-05 L
.43249 4e-05 L
.43351 4e-05 L
.43441 4e-05 L
.43538 4e-05 L
.43629 4e-05 L
.43712 4e-05 L
.43809 4e-05 L
.43915 4e-05 L
.44015 4e-05 L
.44107 4e-05 L
.44205 4e-05 L
.4431 4e-05 L
.44409 4e-05 L
.445 4e-05 L
.44606 4e-05 L
.44666 4e-05 L
.44722 4e-05 L
.44824 4e-05 L
.44875 4e-05 L
.44932 4e-05 L
.44987 4e-05 L
.45045 4e-05 L
.45149 4e-05 L
.45206 4e-05 L
.4526 4e-05 L
.45319 4e-05 L
.45382 4e-05 L
.45437 4e-05 L
.45496 4e-05 L
.45552 4e-05 L
.45603 4e-05 L
.45701 4e-05 L
.45805 4e-05 L
.45903 4e-05 L
.4601 4e-05 L
.46111 4e-05 L
.46204 4e-05 L
.46297 4e-05 L
.46381 4e-05 L
.46478 4e-05 L
.46569 4e-05 L
.4667 4e-05 L
.46775 4e-05 L
.46865 4e-05 L
.46964 4e-05 L
.47071 4e-05 L
.47131 4e-05 L
.47185 4e-05 L
.47291 4e-05 L
.47391 4e-05 L
.47477 4e-05 L
.47571 4e-05 L
.47669 4e-05 L
.47761 4e-05 L
.47847 4e-05 L
.47926 4e-05 L
.48012 4e-05 L
.48103 4e-05 L
.48196 4e-05 L
.48295 4e-05 L
.48388 4e-05 L
.48473 4e-05 L
.48572 4e-05 L
.48629 4e-05 L
.48681 4e-05 L
.48776 4e-05 L
.48877 4e-05 L
.48975 4e-05 L
.49082 4e-05 L
.49184 4e-05 L
.49278 4e-05 L
.49371 4e-05 L
.49455 4e-05 L
.49552 4e-05 L
.49643 4e-05 L
.49744 4e-05 L
.4985 4e-05 L
.4994 4e-05 L
.50039 4e-05 L
.50146 4e-05 L
.50206 4e-05 L
.5026 4e-05 L
.50366 4e-05 L
.50467 4e-05 L
.50552 4e-05 L
.50646 4e-05 L
.50745 4e-05 L
.50837 4e-05 L
.50923 4e-05 L
.51002 4e-05 L
.51093 4e-05 L
.51179 4e-05 L
.51272 4e-05 L
.51371 4e-05 L
.51464 4e-05 L
.51549 4e-05 L
.51649 4e-05 L
.51705 4e-05 L
.51757 4e-05 L
.51852 4e-05 L
.51953 4e-05 L
.52052 4e-05 L
.52108 4e-05 L
.52159 4e-05 L
.52254 4e-05 L
.52355 4e-05 L
.52445 4e-05 L
.52529 4e-05 L
.52622 4e-05 L
.52722 4e-05 L
.52822 4e-05 L
.52878 4e-05 L
.52931 4e-05 L
.53038 4e-05 L
.53097 4e-05 L
.53152 4e-05 L
.53249 4e-05 L
.53355 4e-05 L
.53454 4e-05 L
.53546 4e-05 L
.53632 4e-05 L
.53724 4e-05 L
.53811 4e-05 L
.5389 4e-05 L
.53983 4e-05 L
.54084 4e-05 L
.5418 4e-05 L
.54268 4e-05 L
.54369 4e-05 L
.54463 4e-05 L
.54547 4e-05 L
.54639 4e-05 L
.54739 4e-05 L
.54844 4e-05 L
.54935 4e-05 L
.55033 4e-05 L
.5514 4e-05 L
.55238 4e-05 L
.55289 4e-05 L
.55346 4e-05 L
.55405 4e-05 L
.5546 4e-05 L
.55561 4e-05 L
.55654 4e-05 L
.55756 4e-05 L
.55863 4e-05 L
.55954 4e-05 L
.56051 4e-05 L
.56142 4e-05 L
.56225 4e-05 L
.56322 4e-05 L
.56428 4e-05 L
.56527 4e-05 L
.56619 4e-05 L
.56717 4e-05 L
.56822 4e-05 L
.56922 4e-05 L
.57012 4e-05 L
.57119 4e-05 L
.57179 4e-05 L
.57234 4e-05 L
.57336 4e-05 L
.57388 4e-05 L
.57444 4e-05 L
.57499 4e-05 L
.57557 4e-05 L
.57661 4e-05 L
.57719 4e-05 L
.57772 4e-05 L
.57831 4e-05 L
.57894 4e-05 L
.57949 4e-05 L
.58008 4e-05 L
.58064 4e-05 L
.58116 4e-05 L
.58213 4e-05 L
.58317 4e-05 L
.58415 4e-05 L
.58522 4e-05 L
.58623 4e-05 L
.58716 4e-05 L
.58809 4e-05 L
.58893 4e-05 L
.5899 4e-05 L
.59081 4e-05 L
.59181 4e-05 L
.59287 4e-05 L
.59377 4e-05 L
.59476 4e-05 L
.59583 4e-05 L
.59642 4e-05 L
.59697 4e-05 L
.59803 4e-05 L
.59903 4e-05 L
.59988 4e-05 L
.60082 4e-05 L
.6018 4e-05 L
.60273 4e-05 L
.60358 4e-05 L
.60437 4e-05 L
.60524 4e-05 L
.60614 4e-05 L
.60707 4e-05 L
.60806 4e-05 L
.60899 4e-05 L
.60984 4e-05 L
.61084 4e-05 L
.6114 4e-05 L
.61192 4e-05 L
.61287 4e-05 L
.61388 4e-05 L
.61486 4e-05 L
.61594 4e-05 L
.61695 4e-05 L
.61789 4e-05 L
.61882 4e-05 L
.61966 4e-05 L
.62063 4e-05 L
.62154 4e-05 L
.62255 4e-05 L
.62361 4e-05 L
.62451 4e-05 L
.6255 4e-05 L
.62657 4e-05 L
.62717 4e-05 L
.62771 4e-05 L
.62877 4e-05 L
.62977 4e-05 L
.63063 4e-05 L
.63157 4e-05 L
.63255 4e-05 L
.63348 4e-05 L
.63434 4e-05 L
.63512 4e-05 L
.63603 4e-05 L
.6369 4e-05 L
.63782 4e-05 L
.63881 4e-05 L
.63975 4e-05 L
.64059 4e-05 L
.64159 4e-05 L
.64216 4e-05 L
.64267 4e-05 L
.64363 4e-05 L
.64463 4e-05 L
.64562 4e-05 L
.64618 4e-05 L
.6467 4e-05 L
.64764 4e-05 L
.64865 4e-05 L
.64955 4e-05 L
.65039 4e-05 L
.65132 4e-05 L
.65232 4e-05 L
.65332 4e-05 L
.65388 4e-05 L
.65441 4e-05 L
.65547 4e-05 L
.65607 4e-05 L
.65661 4e-05 L
.65759 4e-05 L
.65864 4e-05 L
.65964 4e-05 L
.66056 4e-05 L
.66141 4e-05 L
.66233 4e-05 L
.6632 4e-05 L
.66399 4e-05 L
.66492 4e-05 L
.66593 4e-05 L
.66689 4e-05 L
.66778 4e-05 L
.66878 4e-05 L
.66972 4e-05 L
.67057 4e-05 L
.67148 4e-05 L
.67248 4e-05 L
.67354 4e-05 L
.67444 4e-05 L
.67543 4e-05 L
.67649 4e-05 L
.67747 4e-05 L
.67798 4e-05 L
.67855 4e-05 L
.67914 4e-05 L
.67969 4e-05 L
.6807 4e-05 L
.68163 4e-05 L
.68265 4e-05 L
.68372 4e-05 L
.68463 4e-05 L
.68559 4e-05 L
.6865 4e-05 L
.68733 4e-05 L
.68831 4e-05 L
.68936 4e-05 L
.69036 4e-05 L
.69128 4e-05 L
.69226 4e-05 L
.69331 4e-05 L
.6943 4e-05 L
.69521 4e-05 L
.69627 4e-05 L
.69687 4e-05 L
.69742 4e-05 L
.69844 4e-05 L
.69896 4e-05 L
.69953 4e-05 L
.70008 4e-05 L
.70066 4e-05 L
.70169 4e-05 L
.70227 4e-05 L
.70281 4e-05 L
.70339 4e-05 L
.70403 4e-05 L
.70457 4e-05 L
.70516 4e-05 L
.70572 4e-05 L
.70624 4e-05 L
.70722 4e-05 L
.70825 4e-05 L
.70923 4e-05 L
.7103 4e-05 L
.71131 4e-05 L
.71224 4e-05 L
.71317 4e-05 L
.71401 4e-05 L
.71498 4e-05 L
.71589 4e-05 L
.71689 4e-05 L
.71795 4e-05 L
.71885 4e-05 L
.71984 4e-05 L
.7209 4e-05 L
.7215 4e-05 L
.72204 4e-05 L
.7231 4e-05 L
.72411 4e-05 L
.72496 4e-05 L
.7259 4e-05 L
.72688 4e-05 L
.7278 4e-05 L
.72866 4e-05 L
.72944 4e-05 L
.73031 4e-05 L
.73122 4e-05 L
.73214 4e-05 L
.73313 4e-05 L
.73406 4e-05 L
.73491 4e-05 L
.73591 4e-05 L
.73647 4e-05 L
.73699 4e-05 L
.73794 4e-05 L
.73895 4e-05 L
.73994 4e-05 L
.74101 4e-05 L
.74202 4e-05 L
.74296 4e-05 L
.74388 4e-05 L
.74473 4e-05 L
.7457 4e-05 L
.74661 4e-05 L
.74761 4e-05 L
.74867 4e-05 L
.74958 4e-05 L
.75057 4e-05 L
.75163 4e-05 L
.75223 4e-05 L
.75278 4e-05 L
.75384 4e-05 L
.75484 4e-05 L
.75569 4e-05 L
.75663 4e-05 L
.75762 4e-05 L
.75854 4e-05 L
.7594 4e-05 L
.76019 4e-05 L
.76105 4e-05 L
.76196 4e-05 L
.76289 4e-05 L
.76388 4e-05 L
.76481 4e-05 L
.76566 4e-05 L
.76666 4e-05 L
.76722 4e-05 L
.76774 4e-05 L
.76869 4e-05 L
.7697 4e-05 L
.77068 4e-05 L
.77124 4e-05 L
.77176 4e-05 L
.7727 4e-05 L
.77371 4e-05 L
.77461 4e-05 L
.77545 4e-05 L
.77638 4e-05 L
.77737 4e-05 L
.77837 4e-05 L
.77894 4e-05 L
.77947 4e-05 L
.78053 4e-05 L
.78113 4e-05 L
.78167 4e-05 L
.78264 4e-05 L
.7837 4e-05 L
.78469 4e-05 L
.78561 4e-05 L
.78647 4e-05 L
.78739 4e-05 L
.78825 4e-05 L
.78905 4e-05 L
.78998 4e-05 L
.79099 4e-05 L
.79194 4e-05 L
.79283 4e-05 L
.79383 4e-05 L
.79477 4e-05 L
.79562 4e-05 L
.79653 4e-05 L
.79753 4e-05 L
.79859 4e-05 L
.79949 4e-05 L
.80048 4e-05 L
.80154 4e-05 L
.80252 4e-05 L
.80303 4e-05 L
.8036 4e-05 L
.80419 4e-05 L
.80474 4e-05 L
.80575 4e-05 L
.80668 4e-05 L
.8077 4e-05 L
.80877 4e-05 L
.80967 4e-05 L
.81064 4e-05 L
.81155 4e-05 L
.81238 4e-05 L
.81335 4e-05 L
.81441 4e-05 L
.8154 4e-05 L
.81632 4e-05 L
.8173 4e-05 L
.81835 4e-05 L
.81935 4e-05 L
.82025 4e-05 L
.82131 4e-05 L
.82191 4e-05 L
.82247 4e-05 L
.82349 4e-05 L
.82406 4e-05 L
.82457 4e-05 L
.82512 4e-05 L
.8257 4e-05 L
.82673 4e-05 L
.82731 4e-05 L
.82785 4e-05 L
.82844 4e-05 L
.82907 4e-05 L
.82961 4e-05 L
.83021 4e-05 L
.83077 4e-05 L
.83128 4e-05 L
.83226 4e-05 L
.8333 4e-05 L
.83427 4e-05 L
.83534 4e-05 L
.83635 4e-05 L
.83728 4e-05 L
.83821 4e-05 L
.83905 4e-05 L
.84002 4e-05 L
.84093 4e-05 L
.84193 4e-05 L
.84298 4e-05 L
.84388 4e-05 L
.84487 4e-05 L
.84594 4e-05 L
.84654 4e-05 L
.84708 4e-05 L
.84814 4e-05 L
.84914 4e-05 L
.84999 4e-05 L
.85093 4e-05 L
.85191 4e-05 L
.85283 4e-05 L
.85369 4e-05 L
.85448 4e-05 L
.85534 4e-05 L
.85625 4e-05 L
.85718 4e-05 L
.85816 4e-05 L
.8591 4e-05 L
.85995 4e-05 L
.86094 4e-05 L
.86151 4e-05 L
.86202 4e-05 L
.86298 4e-05 L
.86399 4e-05 L
.86497 4e-05 L
.86604 4e-05 L
.86705 4e-05 L
.86799 4e-05 L
.86891 4e-05 L
.86976 4e-05 L
.87073 4e-05 L
.87164 4e-05 L
.87264 4e-05 L
.8737 4e-05 L
.8746 4e-05 L
.87559 4e-05 L
.87666 4e-05 L
.87726 4e-05 L
.8778 4e-05 L
.87886 4e-05 L
.87986 4e-05 L
.88072 4e-05 L
.88166 4e-05 L
.88264 4e-05 L
.88356 4e-05 L
.88442 4e-05 L
.88521 4e-05 L
.88607 4e-05 L
.88698 4e-05 L
.88791 4e-05 L
.8889 4e-05 L
.88983 4e-05 L
.89068 4e-05 L
.89168 4e-05 L
.89224 4e-05 L
.89276 4e-05 L
.89371 4e-05 L
.89472 4e-05 L
.8957 4e-05 L
.89626 4e-05 L
.89678 4e-05 L
.89772 4e-05 L
.89873 4e-05 L
.89963 4e-05 L
.90047 4e-05 L
.90139 4e-05 L
.90239 4e-05 L
.90339 4e-05 L
.90396 4e-05 L
.90448 4e-05 L
.90555 4e-05 L
.90614 4e-05 L
.90669 4e-05 L
.90766 4e-05 L
.90871 4e-05 L
.90971 4e-05 L
.91063 4e-05 L
.91148 4e-05 L
.9124 4e-05 L
.91327 4e-05 L
.91406 4e-05 L
.91499 4e-05 L
.916 4e-05 L
.91696 4e-05 L
.91784 4e-05 L
.91884 4e-05 L
.91979 4e-05 L
.92063 4e-05 L
.92155 4e-05 L
.92255 4e-05 L
.9236 4e-05 L
.9245 4e-05 L
.92549 4e-05 L
.92621 4e-05 L
.92687 4e-05 L
.9276 4e-05 L
.92837 4e-05 L
.92904 4e-05 L
.92966 4e-05 L
.93035 4e-05 L
.93109 4e-05 L
.93171 4e-05 L
.93239 4e-05 L
.9331 4e-05 L
.93375 4e-05 L
.93437 4e-05 L
.93493 4e-05 L
.93558 4e-05 L
.93619 4e-05 L
.93686 4e-05 L
.93758 4e-05 L
.93834 4e-05 L
.93906 4e-05 L
.93972 4e-05 L
.94033 4e-05 L
.94103 4e-05 L
.9417 4e-05 L
.94241 4e-05 L
.94318 4e-05 L
.9439 4e-05 L
.94455 4e-05 L
.94532 4e-05 L
.94615 4e-05 L
.94694 4e-05 L
.94766 4e-05 L
.94766 .84358 L
.91725 .82013 L
.88399 .79434 L
.85271 .7699 L
.8202 .74421 L
.78646 .71705 L
.75471 .69075 L
.72174 .66217 L
.69075 .63348 L
.65853 .6011 L
.62508 .5646 L
.59363 .52815 L
.56094 .48885 L
.53024 .45114 L
.49831 .41139 L
.46516 .36976 L
.43399 .3304 L
.40159 .28934 L
.36797 .24659 L
.33633 .2063 L
.30346 .16437 L
.27259 .12494 L
.24048 .0839 L
.20629 .04016 L
.17495 4e-05 L
F
0 g
.17495 4e-05 m
.1759 4e-05 L
.17677 4e-05 L
.17777 4e-05 L
.17872 4e-05 L
.17959 4e-05 L
.1804 4e-05 L
.18129 4e-05 L
.18223 4e-05 L
.18317 4e-05 L
.18419 4e-05 L
.18515 4e-05 L
.18603 4e-05 L
.18705 4e-05 L
.18763 4e-05 L
.18817 4e-05 L
.18915 4e-05 L
.19021 4e-05 L
.19073 4e-05 L
.19129 4e-05 L
.19229 4e-05 L
.19285 4e-05 L
.19337 4e-05 L
.19394 4e-05 L
.19455 4e-05 L
.19508 4e-05 L
.19565 4e-05 L
.19669 4e-05 L
.19771 4e-05 L
.19864 4e-05 L
.19955 4e-05 L
.20041 4e-05 L
.20134 4e-05 L
.20235 4e-05 L
.20335 4e-05 L
.20441 4e-05 L
.20531 4e-05 L
.20629 4e-05 L
.20687 4e-05 L
.2074 4e-05 L
.20798 4e-05 L
.2086 4e-05 L
.20964 4e-05 L
.21023 4e-05 L
.21078 4e-05 L
.21181 4e-05 L
.21274 4e-05 L
.21326 4e-05 L
.21383 4e-05 L
.21486 4e-05 L
Mistroke
.21548 4e-05 L
.21606 4e-05 L
.21659 4e-05 L
.21715 4e-05 L
.21777 4e-05 L
.21843 4e-05 L
.21899 4e-05 L
.2196 4e-05 L
.22018 4e-05 L
.2207 4e-05 L
.22131 4e-05 L
.22188 4e-05 L
.2229 4e-05 L
.22347 4e-05 L
.224 4e-05 L
.22495 4e-05 L
.22597 4e-05 L
.22693 4e-05 L
.22781 4e-05 L
.22878 4e-05 L
.22985 4e-05 L
.23039 4e-05 L
.23096 4e-05 L
.232 4e-05 L
.23257 4e-05 L
.2331 4e-05 L
.23367 4e-05 L
.23429 4e-05 L
.23531 4e-05 L
.2359 4e-05 L
.23644 4e-05 L
.23746 4e-05 L
.23839 4e-05 L
.23946 4e-05 L
.24048 4e-05 L
.2414 4e-05 L
.24239 4e-05 L
.24333 4e-05 L
.24419 4e-05 L
.24515 4e-05 L
.24619 4e-05 L
.24672 4e-05 L
.24728 4e-05 L
.2483 4e-05 L
.24886 4e-05 L
.24937 4e-05 L
.24994 4e-05 L
.25054 4e-05 L
.25154 4e-05 L
.25212 4e-05 L
Mistroke
.25265 4e-05 L
.25365 4e-05 L
.25456 4e-05 L
.25561 4e-05 L
.25661 4e-05 L
.25755 4e-05 L
.25841 4e-05 L
.25939 4e-05 L
.26032 4e-05 L
.26118 4e-05 L
.26197 4e-05 L
.26284 4e-05 L
.26376 4e-05 L
.26469 4e-05 L
.26568 4e-05 L
.26662 4e-05 L
.26747 4e-05 L
.26848 4e-05 L
.26904 4e-05 L
.26957 4e-05 L
.27053 4e-05 L
.27155 4e-05 L
.27248 4e-05 L
.27349 4e-05 L
.27454 4e-05 L
.27552 4e-05 L
.27645 4e-05 L
.27728 4e-05 L
.27825 4e-05 L
.27916 4e-05 L
.28016 4e-05 L
.28121 4e-05 L
.28211 4e-05 L
.2831 4e-05 L
.28416 4e-05 L
.28476 4e-05 L
.2853 4e-05 L
.28636 4e-05 L
.28736 4e-05 L
.2883 4e-05 L
.28915 4e-05 L
.29013 4e-05 L
.29105 4e-05 L
.2919 4e-05 L
.29269 4e-05 L
.29355 4e-05 L
.29446 4e-05 L
.29538 4e-05 L
.29637 4e-05 L
.2973 4e-05 L
Mistroke
.29815 4e-05 L
.29915 4e-05 L
.29971 4e-05 L
.30023 4e-05 L
.30119 4e-05 L
.3022 4e-05 L
.30317 4e-05 L
.30424 4e-05 L
.30525 4e-05 L
.30618 4e-05 L
.30711 4e-05 L
.30795 4e-05 L
.30891 4e-05 L
.30983 4e-05 L
.31083 4e-05 L
.31188 4e-05 L
.31278 4e-05 L
.31377 4e-05 L
.31484 4e-05 L
.31543 4e-05 L
.31598 4e-05 L
.31704 4e-05 L
.31804 4e-05 L
.31889 4e-05 L
.31983 4e-05 L
.32081 4e-05 L
.32173 4e-05 L
.32259 4e-05 L
.32338 4e-05 L
.32424 4e-05 L
.32515 4e-05 L
.32607 4e-05 L
.32706 4e-05 L
.32799 4e-05 L
.32884 4e-05 L
.32984 4e-05 L
.3304 4e-05 L
.33092 4e-05 L
.33187 4e-05 L
.33288 4e-05 L
.33387 4e-05 L
.33493 4e-05 L
.33594 4e-05 L
.33688 4e-05 L
.33781 4e-05 L
.33865 4e-05 L
.33962 4e-05 L
.34054 4e-05 L
.34154 4e-05 L
.34259 4e-05 L
Mistroke
.3435 4e-05 L
.34449 4e-05 L
.34555 4e-05 L
.34615 4e-05 L
.3467 4e-05 L
.34776 4e-05 L
.34876 4e-05 L
.34961 4e-05 L
.35055 4e-05 L
.35154 4e-05 L
.35246 4e-05 L
.35332 4e-05 L
.3541 4e-05 L
.35497 4e-05 L
.35588 4e-05 L
.3568 4e-05 L
.35779 4e-05 L
.35873 4e-05 L
.35957 4e-05 L
.36057 4e-05 L
.36114 4e-05 L
.36165 4e-05 L
.36261 4e-05 L
.36361 4e-05 L
.3646 4e-05 L
.36567 4e-05 L
.36669 4e-05 L
.36762 4e-05 L
.36847 4e-05 L
.3694 4e-05 L
.37037 4e-05 L
.37129 4e-05 L
.37229 4e-05 L
.37335 4e-05 L
.37426 4e-05 L
.37525 4e-05 L
.37632 4e-05 L
.37691 4e-05 L
.37746 4e-05 L
.37852 4e-05 L
.37952 4e-05 L
.38038 4e-05 L
.38132 4e-05 L
.3823 4e-05 L
.38323 4e-05 L
.38409 4e-05 L
.38488 4e-05 L
.38579 4e-05 L
.38665 4e-05 L
.38758 4e-05 L
Mistroke
.38857 4e-05 L
.3895 4e-05 L
.39035 4e-05 L
.39135 4e-05 L
.39191 4e-05 L
.39243 4e-05 L
.39338 4e-05 L
.39439 4e-05 L
.39538 4e-05 L
.39594 4e-05 L
.39645 4e-05 L
.3974 4e-05 L
.39841 4e-05 L
.39931 4e-05 L
.40015 4e-05 L
.40108 4e-05 L
.40208 4e-05 L
.40308 4e-05 L
.40365 4e-05 L
.40417 4e-05 L
.40524 4e-05 L
.40584 4e-05 L
.40638 4e-05 L
.40735 4e-05 L
.40841 4e-05 L
.40941 4e-05 L
.41032 4e-05 L
.41118 4e-05 L
.4121 4e-05 L
.41297 4e-05 L
.41377 4e-05 L
.4147 4e-05 L
.41571 4e-05 L
.41666 4e-05 L
.41755 4e-05 L
.41855 4e-05 L
.4195 4e-05 L
.42034 4e-05 L
.42126 4e-05 L
.42226 4e-05 L
.42331 4e-05 L
.42421 4e-05 L
.4252 4e-05 L
.42626 4e-05 L
.42725 4e-05 L
.42776 4e-05 L
.42832 4e-05 L
.42892 4e-05 L
.42947 4e-05 L
.43048 4e-05 L
Mistroke
.43141 4e-05 L
.43249 4e-05 L
.43351 4e-05 L
.43441 4e-05 L
.43538 4e-05 L
.43629 4e-05 L
.43712 4e-05 L
.43809 4e-05 L
.43915 4e-05 L
.44015 4e-05 L
.44107 4e-05 L
.44205 4e-05 L
.4431 4e-05 L
.44409 4e-05 L
.445 4e-05 L
.44606 4e-05 L
.44666 4e-05 L
.44722 4e-05 L
.44824 4e-05 L
.44875 4e-05 L
.44932 4e-05 L
.44987 4e-05 L
.45045 4e-05 L
.45149 4e-05 L
.45206 4e-05 L
.4526 4e-05 L
.45319 4e-05 L
.45382 4e-05 L
.45437 4e-05 L
.45496 4e-05 L
.45552 4e-05 L
.45603 4e-05 L
.45701 4e-05 L
.45805 4e-05 L
.45903 4e-05 L
.4601 4e-05 L
.46111 4e-05 L
.46204 4e-05 L
.46297 4e-05 L
.46381 4e-05 L
.46478 4e-05 L
.46569 4e-05 L
.4667 4e-05 L
.46775 4e-05 L
.46865 4e-05 L
.46964 4e-05 L
.47071 4e-05 L
.47131 4e-05 L
.47185 4e-05 L
.47291 4e-05 L
Mistroke
.47391 4e-05 L
.47477 4e-05 L
.47571 4e-05 L
.47669 4e-05 L
.47761 4e-05 L
.47847 4e-05 L
.47926 4e-05 L
.48012 4e-05 L
.48103 4e-05 L
.48196 4e-05 L
.48295 4e-05 L
.48388 4e-05 L
.48473 4e-05 L
.48572 4e-05 L
.48629 4e-05 L
.48681 4e-05 L
.48776 4e-05 L
.48877 4e-05 L
.48975 4e-05 L
.49082 4e-05 L
.49184 4e-05 L
.49278 4e-05 L
.49371 4e-05 L
.49455 4e-05 L
.49552 4e-05 L
.49643 4e-05 L
.49744 4e-05 L
.4985 4e-05 L
.4994 4e-05 L
.50039 4e-05 L
.50146 4e-05 L
.50206 4e-05 L
.5026 4e-05 L
.50366 4e-05 L
.50467 4e-05 L
.50552 4e-05 L
.50646 4e-05 L
.50745 4e-05 L
.50837 4e-05 L
.50923 4e-05 L
.51002 4e-05 L
.51093 4e-05 L
.51179 4e-05 L
.51272 4e-05 L
.51371 4e-05 L
.51464 4e-05 L
.51549 4e-05 L
.51649 4e-05 L
.51705 4e-05 L
.51757 4e-05 L
Mistroke
.51852 4e-05 L
.51953 4e-05 L
.52052 4e-05 L
.52108 4e-05 L
.52159 4e-05 L
.52254 4e-05 L
.52355 4e-05 L
.52445 4e-05 L
.52529 4e-05 L
.52622 4e-05 L
.52722 4e-05 L
.52822 4e-05 L
.52878 4e-05 L
.52931 4e-05 L
.53038 4e-05 L
.53097 4e-05 L
.53152 4e-05 L
.53249 4e-05 L
.53355 4e-05 L
.53454 4e-05 L
.53546 4e-05 L
.53632 4e-05 L
.53724 4e-05 L
.53811 4e-05 L
.5389 4e-05 L
.53983 4e-05 L
.54084 4e-05 L
.5418 4e-05 L
.54268 4e-05 L
.54369 4e-05 L
.54463 4e-05 L
.54547 4e-05 L
.54639 4e-05 L
.54739 4e-05 L
.54844 4e-05 L
.54935 4e-05 L
.55033 4e-05 L
.5514 4e-05 L
.55238 4e-05 L
.55289 4e-05 L
.55346 4e-05 L
.55405 4e-05 L
.5546 4e-05 L
.55561 4e-05 L
.55654 4e-05 L
.55756 4e-05 L
.55863 4e-05 L
.55954 4e-05 L
.56051 4e-05 L
.56142 4e-05 L
Mistroke
.56225 4e-05 L
.56322 4e-05 L
.56428 4e-05 L
.56527 4e-05 L
.56619 4e-05 L
.56717 4e-05 L
.56822 4e-05 L
.56922 4e-05 L
.57012 4e-05 L
.57119 4e-05 L
.57179 4e-05 L
.57234 4e-05 L
.57336 4e-05 L
.57388 4e-05 L
.57444 4e-05 L
.57499 4e-05 L
.57557 4e-05 L
.57661 4e-05 L
.57719 4e-05 L
.57772 4e-05 L
.57831 4e-05 L
.57894 4e-05 L
.57949 4e-05 L
.58008 4e-05 L
.58064 4e-05 L
.58116 4e-05 L
.58213 4e-05 L
.58317 4e-05 L
.58415 4e-05 L
.58522 4e-05 L
.58623 4e-05 L
.58716 4e-05 L
.58809 4e-05 L
.58893 4e-05 L
.5899 4e-05 L
.59081 4e-05 L
.59181 4e-05 L
.59287 4e-05 L
.59377 4e-05 L
.59476 4e-05 L
.59583 4e-05 L
.59642 4e-05 L
.59697 4e-05 L
.59803 4e-05 L
.59903 4e-05 L
.59988 4e-05 L
.60082 4e-05 L
.6018 4e-05 L
.60273 4e-05 L
.60358 4e-05 L
Mistroke
.60437 4e-05 L
.60524 4e-05 L
.60614 4e-05 L
.60707 4e-05 L
.60806 4e-05 L
.60899 4e-05 L
.60984 4e-05 L
.61084 4e-05 L
.6114 4e-05 L
.61192 4e-05 L
.61287 4e-05 L
.61388 4e-05 L
.61486 4e-05 L
.61594 4e-05 L
.61695 4e-05 L
.61789 4e-05 L
.61882 4e-05 L
.61966 4e-05 L
.62063 4e-05 L
.62154 4e-05 L
.62255 4e-05 L
.62361 4e-05 L
.62451 4e-05 L
.6255 4e-05 L
.62657 4e-05 L
.62717 4e-05 L
.62771 4e-05 L
.62877 4e-05 L
.62977 4e-05 L
.63063 4e-05 L
.63157 4e-05 L
.63255 4e-05 L
.63348 4e-05 L
.63434 4e-05 L
.63512 4e-05 L
.63603 4e-05 L
.6369 4e-05 L
.63782 4e-05 L
.63881 4e-05 L
.63975 4e-05 L
.64059 4e-05 L
.64159 4e-05 L
.64216 4e-05 L
.64267 4e-05 L
.64363 4e-05 L
.64463 4e-05 L
.64562 4e-05 L
.64618 4e-05 L
.6467 4e-05 L
.64764 4e-05 L
Mistroke
.64865 4e-05 L
.64955 4e-05 L
.65039 4e-05 L
.65132 4e-05 L
.65232 4e-05 L
.65332 4e-05 L
.65388 4e-05 L
.65441 4e-05 L
.65547 4e-05 L
.65607 4e-05 L
.65661 4e-05 L
.65759 4e-05 L
.65864 4e-05 L
.65964 4e-05 L
.66056 4e-05 L
.66141 4e-05 L
.66233 4e-05 L
.6632 4e-05 L
.66399 4e-05 L
.66492 4e-05 L
.66593 4e-05 L
.66689 4e-05 L
.66778 4e-05 L
.66878 4e-05 L
.66972 4e-05 L
.67057 4e-05 L
.67148 4e-05 L
.67248 4e-05 L
.67354 4e-05 L
.67444 4e-05 L
.67543 4e-05 L
.67649 4e-05 L
.67747 4e-05 L
.67798 4e-05 L
.67855 4e-05 L
.67914 4e-05 L
.67969 4e-05 L
.6807 4e-05 L
.68163 4e-05 L
.68265 4e-05 L
.68372 4e-05 L
.68463 4e-05 L
.68559 4e-05 L
.6865 4e-05 L
.68733 4e-05 L
.68831 4e-05 L
.68936 4e-05 L
.69036 4e-05 L
.69128 4e-05 L
.69226 4e-05 L
Mistroke
.69331 4e-05 L
.6943 4e-05 L
.69521 4e-05 L
.69627 4e-05 L
.69687 4e-05 L
.69742 4e-05 L
.69844 4e-05 L
.69896 4e-05 L
.69953 4e-05 L
.70008 4e-05 L
.70066 4e-05 L
.70169 4e-05 L
.70227 4e-05 L
.70281 4e-05 L
.70339 4e-05 L
.70403 4e-05 L
.70457 4e-05 L
.70516 4e-05 L
.70572 4e-05 L
.70624 4e-05 L
.70722 4e-05 L
.70825 4e-05 L
.70923 4e-05 L
.7103 4e-05 L
.71131 4e-05 L
.71224 4e-05 L
.71317 4e-05 L
.71401 4e-05 L
.71498 4e-05 L
.71589 4e-05 L
.71689 4e-05 L
.71795 4e-05 L
.71885 4e-05 L
.71984 4e-05 L
.7209 4e-05 L
.7215 4e-05 L
.72204 4e-05 L
.7231 4e-05 L
.72411 4e-05 L
.72496 4e-05 L
.7259 4e-05 L
.72688 4e-05 L
.7278 4e-05 L
.72866 4e-05 L
.72944 4e-05 L
.73031 4e-05 L
.73122 4e-05 L
.73214 4e-05 L
.73313 4e-05 L
.73406 4e-05 L
Mistroke
.73491 4e-05 L
.73591 4e-05 L
.73647 4e-05 L
.73699 4e-05 L
.73794 4e-05 L
.73895 4e-05 L
.73994 4e-05 L
.74101 4e-05 L
.74202 4e-05 L
.74296 4e-05 L
.74388 4e-05 L
.74473 4e-05 L
.7457 4e-05 L
.74661 4e-05 L
.74761 4e-05 L
.74867 4e-05 L
.74958 4e-05 L
.75057 4e-05 L
.75163 4e-05 L
.75223 4e-05 L
.75278 4e-05 L
.75384 4e-05 L
.75484 4e-05 L
.75569 4e-05 L
.75663 4e-05 L
.75762 4e-05 L
.75854 4e-05 L
.7594 4e-05 L
.76019 4e-05 L
.76105 4e-05 L
.76196 4e-05 L
.76289 4e-05 L
.76388 4e-05 L
.76481 4e-05 L
.76566 4e-05 L
.76666 4e-05 L
.76722 4e-05 L
.76774 4e-05 L
.76869 4e-05 L
.7697 4e-05 L
.77068 4e-05 L
.77124 4e-05 L
.77176 4e-05 L
.7727 4e-05 L
.77371 4e-05 L
.77461 4e-05 L
.77545 4e-05 L
.77638 4e-05 L
.77737 4e-05 L
.77837 4e-05 L
Mistroke
.77894 4e-05 L
.77947 4e-05 L
.78053 4e-05 L
.78113 4e-05 L
.78167 4e-05 L
.78264 4e-05 L
.7837 4e-05 L
.78469 4e-05 L
.78561 4e-05 L
.78647 4e-05 L
.78739 4e-05 L
.78825 4e-05 L
.78905 4e-05 L
.78998 4e-05 L
.79099 4e-05 L
.79194 4e-05 L
.79283 4e-05 L
.79383 4e-05 L
.79477 4e-05 L
.79562 4e-05 L
.79653 4e-05 L
.79753 4e-05 L
.79859 4e-05 L
.79949 4e-05 L
.80048 4e-05 L
.80154 4e-05 L
.80252 4e-05 L
.80303 4e-05 L
.8036 4e-05 L
.80419 4e-05 L
.80474 4e-05 L
.80575 4e-05 L
.80668 4e-05 L
.8077 4e-05 L
.80877 4e-05 L
.80967 4e-05 L
.81064 4e-05 L
.81155 4e-05 L
.81238 4e-05 L
.81335 4e-05 L
.81441 4e-05 L
.8154 4e-05 L
.81632 4e-05 L
.8173 4e-05 L
.81835 4e-05 L
.81935 4e-05 L
.82025 4e-05 L
.82131 4e-05 L
.82191 4e-05 L
.82247 4e-05 L
Mistroke
.82349 4e-05 L
.82406 4e-05 L
.82457 4e-05 L
.82512 4e-05 L
.8257 4e-05 L
.82673 4e-05 L
.82731 4e-05 L
.82785 4e-05 L
.82844 4e-05 L
.82907 4e-05 L
.82961 4e-05 L
.83021 4e-05 L
.83077 4e-05 L
.83128 4e-05 L
.83226 4e-05 L
.8333 4e-05 L
.83427 4e-05 L
.83534 4e-05 L
.83635 4e-05 L
.83728 4e-05 L
.83821 4e-05 L
.83905 4e-05 L
.84002 4e-05 L
.84093 4e-05 L
.84193 4e-05 L
.84298 4e-05 L
.84388 4e-05 L
.84487 4e-05 L
.84594 4e-05 L
.84654 4e-05 L
.84708 4e-05 L
.84814 4e-05 L
.84914 4e-05 L
.84999 4e-05 L
.85093 4e-05 L
.85191 4e-05 L
.85283 4e-05 L
.85369 4e-05 L
.85448 4e-05 L
.85534 4e-05 L
.85625 4e-05 L
.85718 4e-05 L
.85816 4e-05 L
.8591 4e-05 L
.85995 4e-05 L
.86094 4e-05 L
.86151 4e-05 L
.86202 4e-05 L
.86298 4e-05 L
.86399 4e-05 L
Mistroke
.86497 4e-05 L
.86604 4e-05 L
.86705 4e-05 L
.86799 4e-05 L
.86891 4e-05 L
.86976 4e-05 L
.87073 4e-05 L
.87164 4e-05 L
.87264 4e-05 L
.8737 4e-05 L
.8746 4e-05 L
.87559 4e-05 L
.87666 4e-05 L
.87726 4e-05 L
.8778 4e-05 L
.87886 4e-05 L
.87986 4e-05 L
.88072 4e-05 L
.88166 4e-05 L
.88264 4e-05 L
.88356 4e-05 L
.88442 4e-05 L
.88521 4e-05 L
.88607 4e-05 L
.88698 4e-05 L
.88791 4e-05 L
.8889 4e-05 L
.88983 4e-05 L
.89068 4e-05 L
.89168 4e-05 L
.89224 4e-05 L
.89276 4e-05 L
.89371 4e-05 L
.89472 4e-05 L
.8957 4e-05 L
.89626 4e-05 L
.89678 4e-05 L
.89772 4e-05 L
.89873 4e-05 L
.89963 4e-05 L
.90047 4e-05 L
.90139 4e-05 L
.90239 4e-05 L
.90339 4e-05 L
.90396 4e-05 L
.90448 4e-05 L
.90555 4e-05 L
.90614 4e-05 L
.90669 4e-05 L
.90766 4e-05 L
Mistroke
.90871 4e-05 L
.90971 4e-05 L
.91063 4e-05 L
.91148 4e-05 L
.9124 4e-05 L
.91327 4e-05 L
.91406 4e-05 L
.91499 4e-05 L
.916 4e-05 L
.91696 4e-05 L
.91784 4e-05 L
.91884 4e-05 L
.91979 4e-05 L
.92063 4e-05 L
.92155 4e-05 L
.92255 4e-05 L
.9236 4e-05 L
.9245 4e-05 L
.92549 4e-05 L
.92621 4e-05 L
.92687 4e-05 L
.9276 4e-05 L
.92837 4e-05 L
.92904 4e-05 L
.92966 4e-05 L
.93035 4e-05 L
.93109 4e-05 L
.93171 4e-05 L
.93239 4e-05 L
.9331 4e-05 L
.93375 4e-05 L
.93437 4e-05 L
.93493 4e-05 L
.93558 4e-05 L
.93619 4e-05 L
.93686 4e-05 L
.93758 4e-05 L
.93834 4e-05 L
.93906 4e-05 L
.93972 4e-05 L
.94033 4e-05 L
.94103 4e-05 L
.9417 4e-05 L
.94241 4e-05 L
.94318 4e-05 L
.9439 4e-05 L
.94455 4e-05 L
.94532 4e-05 L
.94615 4e-05 L
.94694 4e-05 L
Mistroke
.94766 4e-05 L
Mfstroke
.17495 4e-05 m
.20629 .04016 L
.24048 .0839 L
.27259 .12494 L
.30346 .16437 L
.33633 .2063 L
.36797 .24659 L
.40159 .28934 L
.43399 .3304 L
.46516 .36976 L
.49831 .41139 L
.53024 .45114 L
.56094 .48885 L
.59363 .52815 L
.62508 .5646 L
.65853 .6011 L
.69075 .63348 L
.72174 .66217 L
.75471 .69075 L
.78646 .71705 L
.8202 .74421 L
.85271 .7699 L
.88399 .79434 L
.91725 .82013 L
.94766 .84358 L
s
.17495 .26716 m
.20629 .29099 L
.24048 .31699 L
.27259 .34145 L
.30346 .36501 L
.33633 .39013 L
.36797 .41437 L
.40159 .44022 L
.43399 .46525 L
.46516 .48947 L
.49831 .51548 L
.53024 .54087 L
.56094 .56577 L
.59363 .59316 L
.62508 .62089 L
.65853 .65262 L
.69075 .68596 L
.72174 .72049 L
.75471 .75918 L
.78646 .79765 L
.8202 .83931 L
.85271 .87993 L
.88399 .9193 L
.91725 .96138 L
.94766 .99996 L
s
.17495 .99996 m
.20629 .99996 L
.24048 .99996 L
.27259 .99996 L
.30346 .99996 L
.33633 .99996 L
.36797 .99996 L
.40159 .99996 L
.43399 .99996 L
.46516 .99996 L
.49831 .99996 L
.53024 .99996 L
.56094 .99996 L
.59363 .99996 L
.62508 .99996 L
.65853 .99996 L
.69075 .99996 L
.72174 .99996 L
.75471 .99996 L
.78646 .99996 L
.8202 .99996 L
.85271 .99996 L
.88399 .99996 L
.91725 .99996 L
.94766 .99996 L
s
1 1 .5 r
.17495 .26716 m
.20629 .29099 L
.24048 .31699 L
.27259 .34145 L
.30346 .36501 L
.33633 .39013 L
.36797 .41437 L
.40159 .44022 L
.43399 .46525 L
.46516 .48947 L
.49831 .51548 L
.53024 .54087 L
.56094 .56577 L
.59363 .59316 L
.62508 .62089 L
.65853 .65262 L
.69075 .68596 L
.72174 .72049 L
.75471 .75918 L
.78646 .79765 L
.8202 .83931 L
.85271 .87993 L
.88399 .9193 L
.91725 .96138 L
.94766 .99996 L
.94766 .99996 L
.91725 .99996 L
.88399 .99996 L
.85271 .99996 L
.8202 .99996 L
.78646 .99996 L
.75471 .99996 L
.72174 .99996 L
.69075 .99996 L
.65853 .99996 L
.62508 .99996 L
.59363 .99996 L
.56094 .99996 L
.53024 .99996 L
.49831 .99996 L
.46516 .99996 L
.43399 .99996 L
.40159 .99996 L
.36797 .99996 L
.33633 .99996 L
.30346 .99996 L
.27259 .99996 L
.24048 .99996 L
.20629 .99996 L
.17495 .99996 L
F
0 g
.17495 .26716 m
.20629 .29099 L
.24048 .31699 L
.27259 .34145 L
.30346 .36501 L
.33633 .39013 L
.36797 .41437 L
.40159 .44022 L
.43399 .46525 L
.46516 .48947 L
.49831 .51548 L
.53024 .54087 L
.56094 .56577 L
.59363 .59316 L
.62508 .62089 L
.65853 .65262 L
.69075 .68596 L
.72174 .72049 L
.75471 .75918 L
.78646 .79765 L
.8202 .83931 L
.85271 .87993 L
.88399 .9193 L
.91725 .96138 L
.94766 .99996 L
s
.17495 .99996 m
.20629 .99996 L
.24048 .99996 L
.27259 .99996 L
.30346 .99996 L
.33633 .99996 L
.36797 .99996 L
.40159 .99996 L
.43399 .99996 L
.46516 .99996 L
.49831 .99996 L
.53024 .99996 L
.56094 .99996 L
.59363 .99996 L
.62508 .99996 L
.65853 .99996 L
.69075 .99996 L
.72174 .99996 L
.75471 .99996 L
.78646 .99996 L
.8202 .99996 L
.85271 .99996 L
.88399 .99996 L
.91725 .99996 L
.94766 .99996 L
s
1 .5 0 r
.01 w
.86272 .04709 Mdot
.71763 .09415 Mdot
.4902 .29806 Mdot
.43138 .22747 Mdot
.52549 .36472 Mdot
.72155 .10591 Mdot
.40785 .27845 Mdot
.42746 .31766 Mdot
.72155 .10591 Mdot
.251 .17257 Mdot
.05102 .03141 Mdot
.48235 .31374 Mdot
.49412 .32158 Mdot
.07454 .05494 Mdot
.24708 .24316 Mdot
.42746 .19218 Mdot
.07062 .01572 Mdot
.08239 .05886 Mdot
.06278 .07062 Mdot
.43138 .20002 Mdot
.01572 .00396 Mdot
.08239 .07062 Mdot
.02749 .02749 Mdot
.49804 .32943 Mdot
.01572 4e-05 Mdot
.03533 .04709 Mdot
.02749 .02357 Mdot
.83135 .79998 Mdot
.39217 .28237 Mdot
.01572 .02357 Mdot
.16865 .13728 Mdot
.0118 .01572 Mdot
.45883 .25884 Mdot
.01965 .02357 Mdot
.02749 .04317 Mdot
.03533 .03533 Mdot
.8039 .79213 Mdot
.40393 .27061 Mdot
.00788 .02357 Mdot
.05494 .03925 Mdot
.03533 .03141 Mdot
.65097 .6196 Mdot
.0667 .02749 Mdot
.02749 .03533 Mdot
.07062 .05494 Mdot
.04317 .04317 Mdot
.74116 .72155 Mdot
.05494 .02357 Mdot
.01572 .01965 Mdot
.0667 .05102 Mdot
.03925 .03533 Mdot
.8235 .8039 Mdot
.18042 .08631 Mdot
.01572 .02357 Mdot
.06278 .05102 Mdot
.51372 .46275 Mdot
.73724 .71371 Mdot
.84703 .04709 Mdot
.01572 .02357 Mdot
.03925 .03533 Mdot
.74508 .6941 Mdot
.02357 .01965 Mdot
.81174 .8235 Mdot
.0118 .02357 Mdot
.02749 .03533 Mdot
.11768 .09415 Mdot
.87448 .84703 Mdot
.84311 .8235 Mdot
.32943 .06278 Mdot
.01965 .01572 Mdot
.03925 .05102 Mdot
.90193 .89801 Mdot
.06278 .06278 Mdot
.83527 .84703 Mdot
4e-05 4e-05 Mdot
.02357 .02357 Mdot
.07062 .05102 Mdot
.89801 .90585 Mdot
.05886 .07846 Mdot
.81174 .82743 Mdot
.00788 .0118 Mdot
.01572 .02357 Mdot
.76076 .70194 Mdot
.90193 .90585 Mdot
.83135 .83527 Mdot
.62352 .59215 Mdot
4e-05 .0118 Mdot
.02357 .03141 Mdot
.89017 .8784 Mdot
.88232 .88232 Mdot
.68234 .65097 Mdot
.59999 .51765 Mdot
.01965 .01965 Mdot
.02749 .03533 Mdot
.89017 .8784 Mdot
.88232 .88624 Mdot
.67057 .62352 Mdot
.54902 .48628 Mdot
.05102 .05102 Mdot
.02357 .02749 Mdot
.89801 .89409 Mdot
.88232 .88232 Mdot
.11376 .10199 Mdot
.75684 .72547 Mdot
.05494 .03533 Mdot
.02357 .02749 Mdot
.89017 .8784 Mdot
.87448 .88624 Mdot
.01965 .03141 Mdot
.81566 .83135 Mdot
.08631 .03925 Mdot
.02357 .02749 Mdot
.86664 .86664 Mdot
.8784 .88232 Mdot
.04317 .04317 Mdot
.81566 .82743 Mdot
.00788 .00788 Mdot
.0118 .0118 Mdot
.75292 .67057 Mdot
.82743 .81958 Mdot
.85095 .84703 Mdot
.78429 .77253 Mdot
.00396 .0118 Mdot
.05494 .04709 Mdot
.07062 .0667 Mdot
.87448 .86272 Mdot
.86664 .86664 Mdot
.75292 .71371 Mdot
.14905 .08239 Mdot
.04317 .03141 Mdot
.02749 .03925 Mdot
.88624 .8784 Mdot
.05886 .0667 Mdot
.06278 .0667 Mdot
.83135 .84311 Mdot
.03533 .03533 Mdot
.05102 .04317 Mdot
.85095 .83135 Mdot
.07454 .07846 Mdot
.85487 .85487 Mdot
.80782 .79606 Mdot
.09415 4e-05 Mdot
.04317 .03533 Mdot
.02749 .03141 Mdot
.78821 .78429 Mdot
.03925 .04317 Mdot
.02749 .03141 Mdot
.77253 .78429 Mdot
.02357 .02357 Mdot
.05494 .03925 Mdot
.84311 .83527 Mdot
.05102 .05886 Mdot
.84703 .84703 Mdot
.70194 .67057 Mdot
.10983 .00788 Mdot
.04317 .04317 Mdot
.02749 .02357 Mdot
.18826 .18826 Mdot
.03533 .03141 Mdot
.03925 .03925 Mdot
.81958 .83135 Mdot
.02357 .03141 Mdot
.05102 .03925 Mdot
.85095 .84703 Mdot
.07062 .05886 Mdot
.82743 .8039 Mdot
.72939 .6941 Mdot
.28629 .18826 Mdot
.03925 .03925 Mdot
.07846 .05886 Mdot
.09023 .09023 Mdot
.03925 .04317 Mdot
.19218 .14513 Mdot
.81566 .82743 Mdot
.00788 .01572 Mdot
.05102 .04317 Mdot
.83919 .83919 Mdot
.07846 .0667 Mdot
.00396 .00788 Mdot
.33727 .3255 Mdot
.47843 .47059 Mdot
.01572 .02357 Mdot
.06278 .04317 Mdot
.41961 .41961 Mdot
.03141 .02357 Mdot
.84311 .84311 Mdot
.62352 .60783 Mdot
.1412 .13336 Mdot
.04709 .04317 Mdot
.74116 .70979 Mdot
.07062 .05886 Mdot
.03925 .03141 Mdot
.15689 .13336 Mdot
.75292 .76469 Mdot
.00396 .0118 Mdot
.05886 .03925 Mdot
.85095 .85487 Mdot
.66273 .60783 Mdot
.00788 .00396 Mdot
.1765 .18434 Mdot
.29413 .27453 Mdot
.0118 .02749 Mdot
.07062 .05102 Mdot
.05494 .05886 Mdot
.84703 .79998 Mdot
.6196 .58431 Mdot
.65881 .64313 Mdot
.62744 .63528 Mdot
.04317 .03533 Mdot
.88624 .88624 Mdot
.08239 .03925 Mdot
.04317 .04317 Mdot
.0667 .05494 Mdot
.77253 .78037 Mdot
.00788 .02357 Mdot
.04709 .03533 Mdot
.65489 .62352 Mdot
.88624 .87448 Mdot
.00788 .01572 Mdot
.22355 .21179 Mdot
.45098 .44314 Mdot
.00788 .02749 Mdot
.07062 .05494 Mdot
.05102 .05494 Mdot
.8784 .88232 Mdot
.77645 .75684 Mdot
.66273 .64313 Mdot
.48235 .50196 Mdot
.03925 .04317 Mdot
.88232 .89409 Mdot
.85095 .81566 Mdot
.23924 .1961 Mdot
.03533 .04709 Mdot
.80782 .81958 Mdot
.00396 .00396 Mdot
.04709 .03925 Mdot
.1216 .09415 Mdot
.8784 .86664 Mdot
.02357 .02749 Mdot
.01572 .02749 Mdot
.60783 .61568 Mdot
.00396 .02749 Mdot
.07454 .05886 Mdot
.11376 .09415 Mdot
.87448 .87056 Mdot
.83527 .83135 Mdot
.68626 .6745 Mdot
.75292 .72547 Mdot
.04709 .06278 Mdot
.88232 .89017 Mdot
.88232 .86272 Mdot
.52941 .48628 Mdot
.04709 .04709 Mdot
.83527 .84311 Mdot
.00788 .01965 Mdot
.04709 .04709 Mdot
.07846 .05886 Mdot
.88232 .8784 Mdot
.02357 .02357 Mdot
.04709 .05102 Mdot
.57646 .58039 Mdot
.00788 .0118 Mdot
.09023 .06278 Mdot
.25884 .20787 Mdot
.80782 .77645 Mdot
.81174 .8039 Mdot
.23139 .21963 Mdot
.65489 .27061 Mdot
.03141 .05494 Mdot
.8588 .86664 Mdot
.86664 .86272 Mdot
.23531 .21963 Mdot
4e-05 .00396 Mdot
.8235 .83527 Mdot
.0118 .01572 Mdot
.05886 .07062 Mdot
.05886 .04709 Mdot
.1961 .18434 Mdot
.02357 .02357 Mdot
.02357 .02749 Mdot
.83135 .86664 Mdot
4e-05 4e-05 Mdot
.05102 .03533 Mdot
.1765 .14513 Mdot
.08239 .03925 Mdot
.55686 .47451 Mdot
.03533 .05102 Mdot
.21179 .22355 Mdot
.0118 .0118 Mdot
.8784 .89017 Mdot
.85095 .85095 Mdot
.71371 .68626 Mdot
.03925 .03533 Mdot
.6196 .61176 Mdot
.36864 .35687 Mdot
.03533 .04709 Mdot
.06278 .04317 Mdot
.10591 .08631 Mdot
.03925 .05102 Mdot
4e-05 .0118 Mdot
.81958 .83527 Mdot
.0118 .00788 Mdot
.04317 .04709 Mdot
.08631 .0667 Mdot
.07062 .03925 Mdot
.03141 .02357 Mdot
.02357 .02749 Mdot
.74508 .76861 Mdot
.00396 .00396 Mdot
.54509 .49412 Mdot
.84311 .83919 Mdot
.8235 .8235 Mdot
.8039 .79213 Mdot
.01965 .01572 Mdot
.34119 .24708 Mdot
.00788 .02357 Mdot
.22355 .20002 Mdot
.8588 .83919 Mdot
.04709 .05494 Mdot
.00396 .01965 Mdot
.63136 .61568 Mdot
.28629 .31374 Mdot
.03141 .04317 Mdot
.04317 .04317 Mdot
.17257 .11376 Mdot
.02749 .03533 Mdot
.00788 .0118 Mdot
.77253 .8039 Mdot
4e-05 4e-05 Mdot
.06278 .04709 Mdot
.84311 .82743 Mdot
.86272 .85095 Mdot
.50588 .44314 Mdot
.03141 .03533 Mdot
.5647 .59999 Mdot
.00396 4e-05 Mdot
.8784 .89017 Mdot
.1412 .11376 Mdot
.04317 .03141 Mdot
.03141 .03141 Mdot
.03533 .04317 Mdot
.73724 .1412 Mdot
4e-05 .01965 Mdot
.61568 .55686 Mdot
.87056 .84703 Mdot
.07454 .07846 Mdot
.00396 .0118 Mdot
.60391 .60391 Mdot
.00396 .00396 Mdot
.03533 .03925 Mdot
.40001 .31374 Mdot
.73332 .72155 Mdot
.03141 .02749 Mdot
.00396 .0118 Mdot
.83135 .85487 Mdot
.00396 .00396 Mdot
.68234 .65097 Mdot
.29021 .24708 Mdot
.81566 .77645 Mdot
.81566 .81174 Mdot
.01965 .02357 Mdot
.53333 .54509 Mdot
.00396 .00396 Mdot
.13336 .08239 Mdot
.76469 .71763 Mdot
.85487 .85095 Mdot
.00788 .02357 Mdot
.02749 .03925 Mdot
.36864 .37648 Mdot
.0118 .03141 Mdot
.84311 .83919 Mdot
.8235 .79213 Mdot
.07846 .06278 Mdot
.01572 .03141 Mdot
.65489 .65881 Mdot
.00396 .00396 Mdot
.05102 .04317 Mdot
.8039 .78429 Mdot
.86664 .86272 Mdot
.45098 .36864 Mdot
.00396 .01965 Mdot
.78429 .82743 Mdot
.00396 .00396 Mdot
.79998 .80782 Mdot
.84311 .85095 Mdot
.8588 .8588 Mdot
.09415 .06278 Mdot
.01572 .02357 Mdot
.59215 .56078 Mdot
4e-05 4e-05 Mdot
.80782 .81566 Mdot
.78429 .72155 Mdot
.85095 .85487 Mdot
.00788 .01965 Mdot
.05494 .07454 Mdot
.11768 .11768 Mdot
.0118 .03141 Mdot
.04709 .04317 Mdot
.90193 .90977 Mdot
.05102 .05494 Mdot
.00396 .00788 Mdot
.69802 .70587 Mdot
4e-05 4e-05 Mdot
.04709 .03925 Mdot
.08631 .07454 Mdot
.86272 .8588 Mdot
.82743 .82743 Mdot
4e-05 .01965 Mdot
.78429 .8235 Mdot
4e-05 .00396 Mdot
.18826 .18042 Mdot
.08239 .05102 Mdot
.79998 .78821 Mdot
.01965 .02749 Mdot
.02357 .03925 Mdot
.68626 .05886 Mdot
.01572 .02749 Mdot
.05886 .04709 Mdot
.89017 .89017 Mdot
.82743 .83135 Mdot
.00788 .01965 Mdot
.04317 .04709 Mdot
4e-05 4e-05 Mdot
.0118 .01965 Mdot
.05102 .05494 Mdot
.77645 .79213 Mdot
.20394 .14513 Mdot
.00396 .01572 Mdot
.78429 .81566 Mdot
.00396 .00396 Mdot
.05886 .03533 Mdot
.08239 .0667 Mdot
.09415 .08239 Mdot
.8039 .81174 Mdot
.00396 .01572 Mdot
.49412 .52549 Mdot
.00396 .01572 Mdot
.03141 .03141 Mdot
.85487 .85487 Mdot
.84311 .81958 Mdot
.00788 .01965 Mdot
.03533 .04709 Mdot
.40001 .36472 Mdot
.03925 .03925 Mdot
.04709 .04709 Mdot
.38432 .40001 Mdot
.0667 .05886 Mdot
.00396 .0118 Mdot
.55294 .51765 Mdot
4e-05 .00396 Mdot
.00788 .01965 Mdot
.05102 .04317 Mdot
.08239 .07062 Mdot
.8235 .8039 Mdot
.00788 .02357 Mdot
.82743 .8588 Mdot
.00396 .01965 Mdot
.04317 .03533 Mdot
.85095 .85487 Mdot
.27453 .22355 Mdot
.37648 .35687 Mdot
.00788 .02357 Mdot
.40001 .39609 Mdot
4e-05 .0118 Mdot
.05102 .04317 Mdot
.23924 .23531 Mdot
.1961 .18826 Mdot
.00396 .0118 Mdot
.04709 .05102 Mdot
.08631 .08631 Mdot
.03141 .04709 Mdot
.03925 .04709 Mdot
.08239 .05494 Mdot
.05494 .05494 Mdot
.00396 .00788 Mdot
.41961 .40393 Mdot
4e-05 .00396 Mdot
.0118 .01572 Mdot
.82743 .8039 Mdot
.07454 .04709 Mdot
.81174 .8235 Mdot
4e-05 .01572 Mdot
.749 .78037 Mdot
.00396 .01965 Mdot
.05494 .04709 Mdot
.3608 .35687 Mdot
.77253 .75684 Mdot
.22747 .1961 Mdot
.03925 .04709 Mdot
.67842 .07454 Mdot
.36472 .36864 Mdot
.04709 .05102 Mdot
.15297 .12944 Mdot
.42354 .38824 Mdot
.00396 .0118 Mdot
.05886 .06278 Mdot
.00788 .00396 Mdot
.01572 .01965 Mdot
.25884 .21179 Mdot
.04709 .02357 Mdot
.51372 .47059 Mdot
.00396 .01572 Mdot
.63136 .63528 Mdot
.0118 .02749 Mdot
.01965 .02357 Mdot
.77645 .77253 Mdot
.8784 .8784 Mdot
.81958 .82743 Mdot
.00788 .02357 Mdot
.64705 .67842 Mdot
4e-05 .00788 Mdot
.03533 .03925 Mdot
.84703 .85095 Mdot
.84703 .85095 Mdot
.6392 .62352 Mdot
.05102 .05102 Mdot
.70587 .749 Mdot
.0118 .04317 Mdot
.01572 .01965 Mdot
.08239 .06278 Mdot
.47843 .47059 Mdot
.00396 .0118 Mdot
.16081 .15689 Mdot
.0118 .01572 Mdot
.01572 .02749 Mdot
.83527 .81174 Mdot
.8588 .86272 Mdot
.83527 .83527 Mdot
.00396 .01572 Mdot
.66273 .68234 Mdot
.00396 .00788 Mdot
.01572 .02749 Mdot
.8235 .8039 Mdot
.8588 .85487 Mdot
.81958 .83135 Mdot
.00396 .00788 Mdot
.33335 .34511 Mdot
.00788 .0118 Mdot
.01965 .01965 Mdot
.16865 .11768 Mdot
.84703 .85095 Mdot
.09023 .08631 Mdot
.0667 .07454 Mdot
.70979 .749 Mdot
.01572 .01965 Mdot
.03141 .04317 Mdot
.86272 .86664 Mdot
.07062 .07062 Mdot
4e-05 .00396 Mdot
.04709 .05494 Mdot
.00396 .00396 Mdot
.0118 .01965 Mdot
.13336 .13336 Mdot
.84703 .85487 Mdot
.76469 .749 Mdot
.00396 .00788 Mdot
.69018 .70979 Mdot
.00396 .00788 Mdot
.00396 .01572 Mdot
.16081 .17257 Mdot
.22747 .24316 Mdot
.83135 .83527 Mdot
.00396 .00396 Mdot
.51372 .53725 Mdot
.00396 .0118 Mdot
.01572 .02357 Mdot
.79213 .76076 Mdot
.84703 .86272 Mdot
.04317 .03533 Mdot
.02357 .04709 Mdot
.45098 .43138 Mdot
.0118 .02357 Mdot
.02357 .03925 Mdot
.85095 .85095 Mdot
.04317 .03141 Mdot
.00396 .00396 Mdot
.04709 .05886 Mdot
.00396 .00788 Mdot
.01965 .02749 Mdot
.03533 .03925 Mdot
.21179 .23139 Mdot
.04317 .05886 Mdot
.0118 .01572 Mdot
.07454 .09023 Mdot
.00396 .00396 Mdot
.01572 .03141 Mdot
.08239 .09023 Mdot
.65881 .61568 Mdot
.8235 .8235 Mdot
.00396 .00788 Mdot
.76861 .8235 Mdot
.00396 .00396 Mdot
.01572 .02749 Mdot
.83527 .84703 Mdot
.84703 .84703 Mdot
.5098 .5098 Mdot
.70194 .70194 Mdot
.60783 .05494 Mdot
.00788 .01572 Mdot
.03533 .05886 Mdot
.74508 .75684 Mdot
.84703 .84703 Mdot
.00396 .0118 Mdot
.03141 .05494 Mdot
.08239 .10983 Mdot
.0118 .03925 Mdot
.03533 .04317 Mdot
.09807 .0667 Mdot
.07062 .07846 Mdot
4e-05 .00396 Mdot
.03533 .06278 Mdot
.00396 .00396 Mdot
.00788 .01965 Mdot
.06278 .04709 Mdot
.86664 .87448 Mdot
.05886 .05886 Mdot
.00396 .00396 Mdot
.76469 .8039 Mdot
4e-05 4e-05 Mdot
.00788 .02749 Mdot
.84311 .85095 Mdot
.85095 .86272 Mdot
.81566 .81566 Mdot
.00396 .00788 Mdot
.50588 .53333 Mdot
.00788 .02357 Mdot
.01572 .02749 Mdot
.12944 .12944 Mdot
.83527 .84311 Mdot
.01965 .02749 Mdot
4e-05 .0118 Mdot
.3608 .40001 Mdot
.00788 .03533 Mdot
.02749 .03141 Mdot
.85487 .83527 Mdot
.07846 .09807 Mdot
.00788 .01572 Mdot
.01572 .04317 Mdot
.00396 4e-05 Mdot
.0118 .03533 Mdot
.51372 .46667 Mdot
.86664 .87056 Mdot
.04317 .06278 Mdot
.00396 .0118 Mdot
.09023 .09415 Mdot
.00396 .00396 Mdot
.00396 .01572 Mdot
.84311 .85487 Mdot
.37648 .39609 Mdot
.05886 .0667 Mdot
.00396 .00788 Mdot
.81566 .87056 Mdot
.00788 .0118 Mdot
.00788 .03141 Mdot
.67842 .64705 Mdot
.85095 .8588 Mdot
.81174 .81174 Mdot
4e-05 .0118 Mdot
.41177 .05102 Mdot
.00788 .02357 Mdot
.03533 .04317 Mdot
.85487 .86272 Mdot
.0667 .07062 Mdot
.00396 .0118 Mdot
.01572 .05102 Mdot
.00396 .00396 Mdot
.00396 .00788 Mdot
.0667 .04317 Mdot
.68234 .69802 Mdot
.03141 .05102 Mdot
.00396 .0118 Mdot
.02749 .05102 Mdot
4e-05 .00396 Mdot
.0118 .02749 Mdot
.83135 .83919 Mdot
.61176 .58823 Mdot
.02749 .05886 Mdot
.00396 .01965 Mdot
.79606 .8235 Mdot
.00788 .00788 Mdot
.00396 .02749 Mdot
.84703 .84311 Mdot
.49412 .51372 Mdot
.03533 .05102 Mdot
.00396 .01965 Mdot
.41961 .42354 Mdot
4e-05 .0118 Mdot
.02357 .03533 Mdot
.83919 .85095 Mdot
.06278 .07454 Mdot
.55294 .55686 Mdot
.00396 .02357 Mdot
.00788 .00788 Mdot
.00396 .02357 Mdot
.03925 .03533 Mdot
.1412 .12944 Mdot
.04709 .0667 Mdot
.00396 .01572 Mdot
.00788 .03925 Mdot
.00788 .00788 Mdot
4e-05 .00788 Mdot
.69802 .67842 Mdot
.8588 .85487 Mdot
.07062 .08239 Mdot
.00396 .00788 Mdot
.03925 .05494 Mdot
.00396 .01572 Mdot
4e-05 .02357 Mdot
.84703 .86272 Mdot
.08631 .10199 Mdot
.03533 .05494 Mdot
4e-05 .00396 Mdot
.52157 .56862 Mdot
.00396 .00788 Mdot
.02357 .02749 Mdot
.1412 .15689 Mdot
.02357 .02357 Mdot
.02749 .04317 Mdot
4e-05 .02357 Mdot
.0118 4e-05 Mdot
.00396 .01572 Mdot
.03925 .04709 Mdot
.08631 .09023 Mdot
.59999 .57254 Mdot
.01572 .03533 Mdot
.01965 .03925 Mdot
.00788 .00788 Mdot
.00396 .01572 Mdot
.15297 .13728 Mdot
.25884 .28629 Mdot
.79606 .77645 Mdot
.00396 .01572 Mdot
4e-05 .02357 Mdot
.00396 .0118 Mdot
.00396 .01965 Mdot
.5647 .59607 Mdot
.05494 .04709 Mdot
.76469 .75292 Mdot
.00396 .00396 Mdot
.56862 .59215 Mdot
.00396 .00396 Mdot
.02749 .04317 Mdot
.21963 .21571 Mdot
.85095 .8588 Mdot
.06278 .05102 Mdot
.00396 .0118 Mdot
.28237 .26668 Mdot
.00788 .01572 Mdot
.04317 .05886 Mdot
.07062 .08631 Mdot
.83919 .85487 Mdot
.0118 .02749 Mdot
.0118 .03141 Mdot
.00396 4e-05 Mdot
.00396 .01965 Mdot
.04709 .0667 Mdot
.0118 .0118 Mdot
.83135 .84703 Mdot
4e-05 .00788 Mdot
.00396 .03533 Mdot
.00788 .00396 Mdot
.00396 .00788 Mdot
.05886 .04317 Mdot
.8784 .86664 Mdot
.83919 .83919 Mdot
4e-05 .0118 Mdot
.04709 .05102 Mdot
.00396 .00788 Mdot
.00788 .02749 Mdot
.84703 .85487 Mdot
.8588 .87056 Mdot
.81566 .82743 Mdot
4e-05 .00396 Mdot
.47843 .49804 Mdot
4e-05 .00396 Mdot
.02357 .03925 Mdot
.10591 .11768 Mdot
.85487 .86664 Mdot
.34903 .32943 Mdot
4e-05 .0118 Mdot
.00396 .00788 Mdot
.00396 .00788 Mdot
.04317 .05102 Mdot
.82743 .81958 Mdot
.83527 .84311 Mdot
4e-05 .01572 Mdot
.00396 .02749 Mdot
.00396 .00788 Mdot
.00396 .01572 Mdot
.54902 .54117 Mdot
.8784 .89017 Mdot
.8235 .84311 Mdot
.00396 .0118 Mdot
.0118 .02749 Mdot
.00396 .00396 Mdot
.00788 .02357 Mdot
.85095 .86272 Mdot
.87448 .8784 Mdot
.83135 .84311 Mdot
.00396 .01572 Mdot
.53725 .54902 Mdot
4e-05 4e-05 Mdot
.0118 .03141 Mdot
.34903 .31766 Mdot
.72939 .76469 Mdot
.81958 .82743 Mdot
.00396 .03141 Mdot
.55294 .03141 Mdot
.00396 .01572 Mdot
.03141 .04709 Mdot
.87056 .88232 Mdot
.11768 .13728 Mdot
.10591 .11376 Mdot
.02357 .05102 Mdot
.01572 .00788 Mdot
.00788 .01965 Mdot
.04317 .0667 Mdot
.89017 .90585 Mdot
.03141 .05102 Mdot
.0118 .01965 Mdot
.00396 .02749 Mdot
4e-05 4e-05 Mdot
.00788 .00396 Mdot
.05494 .07062 Mdot
.86664 .8784 Mdot
.36864 .33727 Mdot
.02357 .03925 Mdot
.00396 .02749 Mdot
.00396 .00396 Mdot
.00396 .00788 Mdot
.50196 .52157 Mdot
.66273 .70587 Mdot
.09415 .10983 Mdot
.00396 .02749 Mdot
4e-05 .01572 Mdot
.0118 .00788 Mdot
.00396 .00788 Mdot
.3804 .3608 Mdot
.11376 .13336 Mdot
.03533 .04709 Mdot
.0118 .04317 Mdot
.56078 .56862 Mdot
4e-05 .00396 Mdot
.00788 .02749 Mdot
.90193 .90585 Mdot
.42746 .41961 Mdot
.64313 .63136 Mdot
.00788 .03141 Mdot
.12552 .11768 Mdot
.00788 .01572 Mdot
.01965 .03533 Mdot
.89017 .89801 Mdot
.87056 .87056 Mdot
.83135 .83135 Mdot
.01965 .03925 Mdot
.56078 .02357 Mdot
.00396 .01572 Mdot
.03141 .05494 Mdot
.88232 .89409 Mdot
.85095 .8588 Mdot
.08239 .09807 Mdot
4e-05 .00396 Mdot
.00788 .00396 Mdot
4e-05 4e-05 Mdot
.03533 .05494 Mdot
.27453 .31766 Mdot
.69018 .70979 Mdot
.00788 .04317 Mdot
.00788 .0118 Mdot
.00396 .00788 Mdot
.00396 .00396 Mdot
.09023 .10591 Mdot
.07454 .09415 Mdot
.03925 .05494 Mdot
.00396 .03533 Mdot
.0118 .03533 Mdot
4e-05 .00396 Mdot
.00788 .01572 Mdot
.84703 .85095 Mdot
.14905 .1412 Mdot
.03141 .05102 Mdot
.00788 .04317 Mdot
.00396 .02749 Mdot
4e-05 .00396 Mdot
4e-05 .00788 Mdot
.8588 .87056 Mdot
.86272 .8784 Mdot
.37648 .34903 Mdot
.00396 .03141 Mdot
.23531 .251 Mdot
.00396 .00788 Mdot
.00396 .00396 Mdot
.87448 .88232 Mdot
.85095 .86272 Mdot
.81958 .84311 Mdot
.00396 .02749 Mdot
.40001 .40785 Mdot
.00396 .0118 Mdot
4e-05 .00788 Mdot
.27061 .31374 Mdot
.64705 .69018 Mdot
.07454 .10199 Mdot
.01572 .04317 Mdot
.05102 .01965 Mdot
.00788 .0118 Mdot
.00788 .03925 Mdot
.08239 .08239 Mdot
.05886 .09415 Mdot
.01572 .03925 Mdot
.02357 .04317 Mdot
.03533 4e-05 Mdot
.00396 .0118 Mdot
.01965 .02357 Mdot
.07846 .08631 Mdot
.0667 .09415 Mdot
4e-05 .01965 Mdot
.03925 .06278 Mdot
.00396 .00396 Mdot
4e-05 .02357 Mdot
.83135 .83919 Mdot
.50196 .5098 Mdot
.38824 .3804 Mdot
.00396 .01965 Mdot
.02357 .05102 Mdot
.00396 .00396 Mdot
.02749 .04709 Mdot
.83919 .85487 Mdot
.86664 .87056 Mdot
.85095 .86272 Mdot
.00396 .01965 Mdot
.00396 .03141 Mdot
.00788 .00788 Mdot
.01572 .03141 Mdot
.64313 .67057 Mdot
.70979 .72547 Mdot
.22747 .27453 Mdot
.00788 .03141 Mdot
.02357 .03925 Mdot
.0118 .0118 Mdot
.00396 .0118 Mdot
.0667 .08239 Mdot
.01572 .03141 Mdot
.02357 .03533 Mdot
.00788 .02749 Mdot
.34903 .35295 Mdot
4e-05 4e-05 Mdot
.00396 .01572 Mdot
.07062 .08239 Mdot
.44314 .42354 Mdot
.21963 .20787 Mdot
.00396 .03141 Mdot
.00396 .00396 Mdot
.00396 .00396 Mdot
.03141 .03141 Mdot
.08239 .10199 Mdot
.83527 .84311 Mdot
.01572 .0118 Mdot
.0118 .03141 Mdot
.59215 .0118 Mdot
.0118 .03925 Mdot
.81958 .81958 Mdot
.04709 .07454 Mdot
.8235 .85487 Mdot
.02749 .05886 Mdot
.03533 .04709 Mdot
4e-05 .00396 Mdot
.00788 .03925 Mdot
.82743 .83919 Mdot
.05886 .07454 Mdot
.40785 .41961 Mdot
.00396 .03533 Mdot
.04317 .0667 Mdot
.00788 .00788 Mdot
4e-05 .00788 Mdot
.18826 .21571 Mdot
.22355 .27061 Mdot
.85095 .8588 Mdot
.00396 .02357 Mdot
.00396 .03533 Mdot
.00396 .00396 Mdot
.00788 .03533 Mdot
.0118 .02357 Mdot
.36472 .41177 Mdot
.84703 .85095 Mdot
.0118 .02749 Mdot
.00788 .01965 Mdot
.0118 .00788 Mdot
.01572 .02749 Mdot
.76469 .73332 Mdot
.1216 .1765 Mdot
.83135 .84311 Mdot
.00396 .02749 Mdot
.38432 .38824 Mdot
.00396 .00396 Mdot
.06278 .0667 Mdot
.86272 .88232 Mdot
.03141 .05102 Mdot
.83919 .84703 Mdot
.0118 .03141 Mdot
4e-05 4e-05 Mdot
.00788 .02357 Mdot
.80782 .79606 Mdot
.85487 .87056 Mdot
.72939 .71763 Mdot
.84311 .85487 Mdot
.01572 .03925 Mdot
.03925 .01572 Mdot
.28629 .30982 Mdot
.81958 .82743 Mdot
.65489 .66665 Mdot
.85095 .85487 Mdot
.67057 .69018 Mdot
.01965 .04317 Mdot
.00396 .00396 Mdot
.03533 .06278 Mdot
.11376 .11768 Mdot
.0667 .07454 Mdot
.85095 .8588 Mdot
.01965 .05102 Mdot
.01965 .03533 Mdot
.10983 .11376 Mdot
.00396 .02749 Mdot
.76076 .75684 Mdot
.0667 .08631 Mdot
.80782 .83919 Mdot
4e-05 .02749 Mdot
.00788 .03533 Mdot
.00396 .00396 Mdot
.0118 .04317 Mdot
.51372 .55294 Mdot
.06278 .07846 Mdot
.10983 .15689 Mdot
.0118 .03533 Mdot
4e-05 .02357 Mdot
.00396 .00788 Mdot
.01965 .03533 Mdot
.05886 .07846 Mdot
.62744 .6196 Mdot
.0667 .09807 Mdot
4e-05 .01572 Mdot
.45098 .46275 Mdot
4e-05 .00396 Mdot
.31766 .30198 Mdot
.36864 .3608 Mdot
.87056 .8784 Mdot
.76469 .76076 Mdot
4e-05 .01572 Mdot
.00396 .00396 Mdot
4e-05 .00788 Mdot
.83135 .83919 Mdot
.86272 .8784 Mdot
.86664 .87056 Mdot
.79606 .81566 Mdot
.00396 .01572 Mdot
4e-05 .00788 Mdot
.00396 .01965 Mdot
.08631 .07062 Mdot
.08631 .10591 Mdot
.40785 .45883 Mdot
.03141 .05494 Mdot
.00396 .01572 Mdot
.1216 .03141 Mdot
.00788 .02357 Mdot
.83135 .83527 Mdot
.06278 .08631 Mdot
.09415 .1216 Mdot
.00788 .02749 Mdot
.00788 .03141 Mdot
.00396 .00396 Mdot
.02357 .04317 Mdot
.07062 .09415 Mdot
.07846 .09023 Mdot
.06278 .07454 Mdot
.00788 .03533 Mdot
.00396 .03141 Mdot
.00396 4e-05 Mdot
.00788 .02357 Mdot
.0118 .01965 Mdot
.30982 .30982 Mdot
.20787 .18826 Mdot
.00396 .02749 Mdot
.00788 .03533 Mdot
4e-05 .00396 Mdot
.0118 .03533 Mdot
.62744 .61176 Mdot
.8588 .86664 Mdot
.84311 .82743 Mdot
.00788 .04317 Mdot
.03141 .03925 Mdot
4e-05 4e-05 Mdot
.01965 .03925 Mdot
.85095 .86272 Mdot
.85487 .87448 Mdot
.70979 .75292 Mdot
.00396 .02357 Mdot
.10199 .11376 Mdot
.00788 .00788 Mdot
.41569 .42354 Mdot
.1961 .24316 Mdot
.14905 .20002 Mdot
.0667 .10591 Mdot
4e-05 .00788 Mdot
4e-05 4e-05 Mdot
.00396 .0118 Mdot
.81566 .81958 Mdot
.05494 .06278 Mdot
.05102 .07454 Mdot
.05102 .07846 Mdot
4e-05 .01572 Mdot
4e-05 .00396 Mdot
.00396 .00788 Mdot
.76469 .76861 Mdot
.05494 .0667 Mdot
.1216 .12552 Mdot
4e-05 .00788 Mdot
.00396 .0118 Mdot
.01572 .01572 Mdot
.00396 .01572 Mdot
.82743 .83527 Mdot
.05494 .05886 Mdot
.73724 .73332 Mdot
4e-05 .00788 Mdot
4e-05 .0118 Mdot
.00396 .00396 Mdot
.00396 .01965 Mdot
.8039 .79213 Mdot
.03533 .05494 Mdot
.86664 .87056 Mdot
.00396 .01572 Mdot
.00396 .02357 Mdot
.16081 .03141 Mdot
4e-05 .01965 Mdot
.81174 .83527 Mdot
.05494 .07846 Mdot
.84311 .84703 Mdot
.03141 .05102 Mdot
.00396 .03141 Mdot
.00788 4e-05 Mdot
.00788 .03141 Mdot
.16473 .20394 Mdot
.05494 .07454 Mdot
.74116 .74508 Mdot
.0118 .03533 Mdot
.00396 .02357 Mdot
.00396 4e-05 Mdot
.0118 .03925 Mdot
.03533 .0667 Mdot
.0667 .09807 Mdot
.8235 .8235 Mdot
4e-05 .01572 Mdot
.00396 .03141 Mdot
4e-05 4e-05 Mdot
.0118 .04317 Mdot
.03141 .05886 Mdot
.07062 .11768 Mdot
.85095 .85487 Mdot
4e-05 .01572 Mdot
.09023 .09415 Mdot
.00396 .00396 Mdot
.00396 .02749 Mdot
.05102 .07454 Mdot
.05886 .10199 Mdot
.85487 .86272 Mdot
.00396 .02749 Mdot
.07846 .08239 Mdot
.00396 .00396 Mdot
.01572 .03141 Mdot
.04317 .06278 Mdot
.06278 .08239 Mdot
.8588 .86664 Mdot
.00788 .02749 Mdot
4e-05 .00396 Mdot
.00788 .0118 Mdot
.31374 .30982 Mdot
.04709 .05886 Mdot
.24708 .25492 Mdot
.8588 .86664 Mdot
.00396 .02357 Mdot
.00396 .00396 Mdot
4e-05 .00396 Mdot
.83135 .83135 Mdot
.04709 .0667 Mdot
.86664 .87056 Mdot
.85487 .86272 Mdot
.0118 .03141 Mdot
.0118 .01965 Mdot
.00396 .0118 Mdot
.8235 .82743 Mdot
.05102 .07062 Mdot
.87056 .87448 Mdot
.85487 .86272 Mdot
.01572 .03533 Mdot
.00788 .00788 Mdot
.00396 .01572 Mdot
.8039 .8039 Mdot
.05886 .07062 Mdot
.87056 .8784 Mdot
.85487 .86272 Mdot
.00788 .03141 Mdot
4e-05 4e-05 Mdot
4e-05 .01965 Mdot
.1412 .1412 Mdot
.05102 .0667 Mdot
.87056 .8784 Mdot
.6392 .66273 Mdot
.0118 .04317 Mdot
.1216 .00788 Mdot
.00396 .02749 Mdot
.03925 .05494 Mdot
.07454 .10199 Mdot
.76469 .79606 Mdot
.03925 .0667 Mdot
.02749 .05494 Mdot
.23531 .22355 Mdot
.00396 .03925 Mdot
.05886 .07846 Mdot
.40001 .39609 Mdot
.11376 .16473 Mdot
.0118 .02749 Mdot
.05886 .07846 Mdot
.0118 .0118 Mdot
.00788 .03925 Mdot
.05494 .07454 Mdot
.8588 .86272 Mdot
.04709 .07454 Mdot
.01572 .02749 Mdot
.21963 .22747 Mdot
.05494 .05102 Mdot
.00788 .04317 Mdot
.03925 .05494 Mdot
.87448 .89017 Mdot
.07062 .08239 Mdot
.00788 .02749 Mdot
.47843 .49804 Mdot
4e-05 .00396 Mdot
.01572 .04709 Mdot
.04709 .06278 Mdot
.86664 .8784 Mdot
.00396 .0118 Mdot
.0118 .02749 Mdot
.33335 .35687 Mdot
4e-05 4e-05 Mdot
.00788 .03533 Mdot
.03925 .05494 Mdot
.87448 .88232 Mdot
.37256 .3608 Mdot
.00396 .01965 Mdot
.3059 .32158 Mdot
.00788 .00396 Mdot
.0118 .03925 Mdot
.04317 .05886 Mdot
.87056 .88232 Mdot
.78429 .76861 Mdot
.00788 .03533 Mdot
.0118 .03533 Mdot
4e-05 4e-05 Mdot
.00788 .03925 Mdot
.04317 .05886 Mdot
.69018 .72547 Mdot
.85095 .85095 Mdot
.0118 .03533 Mdot
.01965 .04709 Mdot
4e-05 4e-05 Mdot
.01965 .04317 Mdot
.03925 .05886 Mdot
.11376 .13728 Mdot
.83527 .84311 Mdot
.00788 .03141 Mdot
.00396 .02357 Mdot
.00396 .00396 Mdot
.0118 .02749 Mdot
.06278 .09415 Mdot
.72155 .71371 Mdot
.83919 .84703 Mdot
.01965 .03141 Mdot
.00396 .01572 Mdot
4e-05 4e-05 Mdot
.0118 .02749 Mdot
.06278 .0667 Mdot
.86664 .87448 Mdot
.83919 .84703 Mdot
.02357 .03925 Mdot
.0118 .02749 Mdot
.00788 .01572 Mdot
.02357 .05102 Mdot
.72547 .71371 Mdot
.72547 .76076 Mdot
.83919 .84703 Mdot
.01965 .04709 Mdot
.00396 .00788 Mdot
.00396 .0118 Mdot
.03141 .05102 Mdot
.86272 .87056 Mdot
.17257 .21963 Mdot
.84311 .86272 Mdot
.0118 .04317 Mdot
.0118 .01572 Mdot
.00396 .0118 Mdot
.02749 .05886 Mdot
.8588 .87448 Mdot
.01965 .03533 Mdot
.72939 .749 Mdot
.00788 .03533 Mdot
.00788 .0118 Mdot
.00396 .00788 Mdot
.04317 .07846 Mdot
.86272 .87056 Mdot
.65881 .65881 Mdot
.75292 .76076 Mdot
.00396 .02357 Mdot
.00396 .00788 Mdot
4e-05 .0118 Mdot
.05886 .09023 Mdot
.84703 .87056 Mdot
.8784 .8784 Mdot
.83527 .83919 Mdot
.00788 .02749 Mdot
.00396 .00396 Mdot
.00788 .01965 Mdot
.08631 .1216 Mdot
.3059 .37256 Mdot
.87056 .87448 Mdot
.83919 .84703 Mdot
.01572 .03141 Mdot
.00788 .00788 Mdot
4e-05 .00788 Mdot
.18042 .20787 Mdot
.06278 .10983 Mdot
.86664 .87448 Mdot
.56078 .59215 Mdot
.16081 .16473 Mdot
.00396 .00396 Mdot
.00788 .01965 Mdot
.34903 .3608 Mdot
.08239 .10591 Mdot
.84703 .85487 Mdot
.67057 .68234 Mdot
.76469 .76861 Mdot
.01572 .00396 Mdot
4e-05 .0118 Mdot
.47059 .49412 Mdot
.11376 .11376 Mdot
.8235 .85095 Mdot
.82743 .83135 Mdot
.5098 .52941 Mdot
.76076 .00396 Mdot
.00396 .01965 Mdot
.24316 .27845 Mdot
.56862 .56862 Mdot
.4902 .54509 Mdot
.8235 .83135 Mdot
.25884 .29021 Mdot
.52157 .00396 Mdot
.00396 .02357 Mdot
.09415 .12944 Mdot
.74116 .73724 Mdot
.14905 .21571 Mdot
.81958 .83135 Mdot
.11376 .1412 Mdot
.51765 .00396 Mdot
.03141 .05102 Mdot
.0667 .09807 Mdot
.86272 .86664 Mdot
.10199 .14905 Mdot
.81958 .83135 Mdot
.12944 .14513 Mdot
.52549 .01572 Mdot
.00788 .02357 Mdot
.01965 .03925 Mdot
.8588 .87448 Mdot
.01572 .03141 Mdot
.8235 .83135 Mdot
.32158 .33727 Mdot
.52157 .0118 Mdot
.00788 .01965 Mdot
.04317 .04317 Mdot
.79606 .83135 Mdot
.09023 .09415 Mdot
.8235 .82743 Mdot
.54509 .5647 Mdot
.52157 .0118 Mdot
.00788 .02749 Mdot
.31374 .30982 Mdot
.43138 .49412 Mdot
.61176 .61176 Mdot
.8235 .82743 Mdot
.67057 .68626 Mdot
.51765 .00396 Mdot
.00396 .02357 Mdot
.62352 .6196 Mdot
.14513 .20394 Mdot
.77645 .77645 Mdot
.81566 .83135 Mdot
.75684 .76076 Mdot
.52549 .00788 Mdot
4e-05 .01965 Mdot
.79606 .79606 Mdot
.09023 .12944 Mdot
.86272 .86664 Mdot
.76469 .79606 Mdot
.75684 .75292 Mdot
.52157 .00788 Mdot
.00396 .03141 Mdot
.81566 .81566 Mdot
.08239 .10199 Mdot
.8784 .88232 Mdot
.53333 .57646 Mdot
.74508 .74508 Mdot
.51372 .00396 Mdot
.00788 .03141 Mdot
.81958 .8235 Mdot
.10983 .11376 Mdot
.89801 .89801 Mdot
.23924 .30198 Mdot
.74116 .74116 Mdot
.50588 .00396 Mdot
.00396 .01965 Mdot
.81958 .8235 Mdot
.1765 .15689 Mdot
.91761 .92154 Mdot
.09415 .16081 Mdot
.76076 .76469 Mdot
.5098 .00788 Mdot
.00396 .02357 Mdot
.83135 .83527 Mdot
.251 .21571 Mdot
.9333 .93722 Mdot
.04709 .10199 Mdot
.749 .75292 Mdot
.51765 .00788 Mdot
.00396 .02357 Mdot
.82743 .83527 Mdot
.28629 .251 Mdot
.94898 .95683 Mdot
.03533 .0667 Mdot
.70979 .71763 Mdot
.51372 .00788 Mdot
.00396 .02749 Mdot
.80782 .8235 Mdot
.25492 .23139 Mdot
.93722 .95291 Mdot
.05102 .0667 Mdot
.73724 .74508 Mdot
.51765 .00788 Mdot
.00396 .02749 Mdot
.71763 .74116 Mdot
.29413 .27453 Mdot
.93722 .95683 Mdot
.05886 .08239 Mdot
.749 .76469 Mdot
.5098 .00396 Mdot
.00396 .01965 Mdot
.53333 .5647 Mdot
.27453 .25884 Mdot
.89409 .95291 Mdot
.05102 .07846 Mdot
.67057 .69018 Mdot
.5098 .00396 Mdot
.00396 .02357 Mdot
.30198 .30982 Mdot
.21179 .1961 Mdot
.40393 .5098 Mdot
.05886 .07454 Mdot
.59215 .59999 Mdot
.5098 4e-05 Mdot
.00788 .03141 Mdot
.18434 .1765 Mdot
.12552 .12944 Mdot
.14513 .21963 Mdot
.0667 .03925 Mdot
.76469 .77645 Mdot
.50196 4e-05 Mdot
.01572 .04709 Mdot
.30198 .29413 Mdot
.07062 .09023 Mdot
.08631 .11376 Mdot
.10591 .00396 Mdot
.79213 .81566 Mdot
.50588 4e-05 Mdot
.01965 .04709 Mdot
.69018 .69018 Mdot
.06278 .07846 Mdot
.08239 .09807 Mdot
.34119 .10983 Mdot
.67057 .70194 Mdot
.01572 .00396 Mdot
.1412 .15689 Mdot
.78821 .79213 Mdot
.08239 .08239 Mdot
.09807 .09807 Mdot
.47843 .18434 Mdot
.72939 .74508 Mdot
.01965 .00396 Mdot
.10591 .13336 Mdot
.8235 .82743 Mdot
.1412 .13336 Mdot
.1412 .11376 Mdot
.28629 .04709 Mdot
.68234 .69018 Mdot
.01965 .00788 Mdot
.03533 .07062 Mdot
.76469 .8039 Mdot
.20787 .18042 Mdot
.22355 .16473 Mdot
.10591 .00396 Mdot
.64705 .65881 Mdot
.01572 .00396 Mdot
.03533 .05494 Mdot
.4353 .50196 Mdot
.28629 .23924 Mdot
.32943 .26276 Mdot
.05494 .0118 Mdot
.60783 .61568 Mdot
.01572 4e-05 Mdot
.39217 .39609 Mdot
.1216 .18826 Mdot
.28629 .251 Mdot
.60391 .58039 Mdot
.04317 .03533 Mdot
.58823 .59999 Mdot
.02749 .00788 Mdot
.25884 .27453 Mdot
.07846 .10591 Mdot
.21571 .18826 Mdot
.63136 .64705 Mdot
.04709 .05886 Mdot
.59607 .6196 Mdot
.01965 .00396 Mdot
.30982 .33727 Mdot
.10983 .10983 Mdot
.24708 .20787 Mdot
.64705 .67057 Mdot
.04317 .07846 Mdot
.58039 .60783 Mdot
.01965 .00396 Mdot
.05102 .07846 Mdot
.14905 .13728 Mdot
.24708 .21571 Mdot
.75292 .77645 Mdot
.03533 .07454 Mdot
.55294 .57646 Mdot
.01572 .00396 Mdot
4e-05 .02749 Mdot
.12552 .12944 Mdot
.15297 .14905 Mdot
.70587 .75292 Mdot
.05102 .07454 Mdot
.56862 .58431 Mdot
.01572 .00396 Mdot
.00788 .03141 Mdot
.10591 .12552 Mdot
.10199 .11376 Mdot
.49804 .55294 Mdot
.0667 .07846 Mdot
.65489 .6745 Mdot
.02357 .00788 Mdot
.00788 .03533 Mdot
.03533 .05494 Mdot
.09807 .10983 Mdot
.58039 .63528 Mdot
.05886 .0667 Mdot
.66665 .6941 Mdot
.01572 .00396 Mdot
.0118 .03925 Mdot
.00396 .00788 Mdot
.10983 .10983 Mdot
.45883 .52941 Mdot
.06278 .07062 Mdot
.60783 .63528 Mdot
.0118 .00396 Mdot
4e-05 .0118 Mdot
.10983 .11768 Mdot
.1412 .13728 Mdot
.21963 .25884 Mdot
.07846 .09023 Mdot
.66665 .68234 Mdot
.01965 4e-05 Mdot
.00788 .0118 Mdot
.33727 .34511 Mdot
.21571 .19218 Mdot
.31374 .31374 Mdot
.26668 .27453 Mdot
.80782 .8235 Mdot
.03141 .00788 Mdot
.00396 .02357 Mdot
.59215 .59607 Mdot
.29021 .25492 Mdot
.31766 .3255 Mdot
.58431 .58823 Mdot
.74508 .78821 Mdot
.01965 4e-05 Mdot
.01965 .03925 Mdot
.76861 .77253 Mdot
.23531 .21571 Mdot
.19218 .21179 Mdot
.77253 .77253 Mdot
.63528 .68626 Mdot
.04317 .00396 Mdot
.10591 .13336 Mdot
.81566 .81958 Mdot
.18042 .15297 Mdot
.1216 .12944 Mdot
.79606 .79998 Mdot
.65097 .6745 Mdot
.05494 .00396 Mdot
.01965 .05102 Mdot
.8235 .83527 Mdot
.18826 .16081 Mdot
.18826 .18042 Mdot
.81566 .8235 Mdot
.69018 .71371 Mdot
.0667 .00396 Mdot
4e-05 .02357 Mdot
.37256 .41177 Mdot
.28237 .22747 Mdot
.24708 .23531 Mdot
.81958 .82743 Mdot
.53725 .58431 Mdot
.46275 .0667 Mdot
.00396 .02357 Mdot
.08631 .12552 Mdot
.38432 .32943 Mdot
.27453 .26276 Mdot
.81566 .8235 Mdot
.03533 .09807 Mdot
.1216 .00396 Mdot
.00396 .02749 Mdot
.08631 .09023 Mdot
.33727 .30198 Mdot
.23924 .23531 Mdot
.80782 .82743 Mdot
.02357 .06278 Mdot
.0118 .00396 Mdot
.02357 .04317 Mdot
.11376 .11376 Mdot
.29413 .28629 Mdot
.28629 .04317 Mdot
.09023 .13728 Mdot
.08631 .1412 Mdot
4e-05 4e-05 Mdot
.00788 .02749 Mdot
.07454 .09807 Mdot
.25492 .23531 Mdot
.67842 .05102 Mdot
.60391 .61568 Mdot
.00396 .03141 Mdot
.03925 .03533 Mdot
.01572 .03533 Mdot
.11376 .10591 Mdot
.23531 .20002 Mdot
.12552 .0118 Mdot
.83527 .86664 Mdot
.0118 .03925 Mdot
4e-05 4e-05 Mdot
.04317 .05494 Mdot
.16081 .12552 Mdot
.21179 .1765 Mdot
.02357 .05494 Mdot
.8784 .90585 Mdot
.0118 .01965 Mdot
.00788 .00396 Mdot
.07454 .09415 Mdot
.19218 .16865 Mdot
.24708 .20002 Mdot
.68234 .67842 Mdot
.90193 .93722 Mdot
.04709 .03533 Mdot
.00396 .01572 Mdot
.04709 .05102 Mdot
.67057 .69018 Mdot
.34903 .27845 Mdot
.80782 .81958 Mdot
.81958 .8588 Mdot
.37648 .00396 Mdot
.00396 .02749 Mdot
.14513 .12552 Mdot
.53725 .49412 Mdot
.46667 .37256 Mdot
.07846 .10591 Mdot
.07846 .10591 Mdot
.01572 .00788 Mdot
.03925 .05494 Mdot
.52157 .45883 Mdot
.57646 .55294 Mdot
.5098 .45491 Mdot
.78037 .81566 Mdot
.05886 .07062 Mdot
.00396 .00788 Mdot
.12552 .10983 Mdot
.73332 .69802 Mdot
.65881 .64705 Mdot
.5098 .47451 Mdot
.77645 .82743 Mdot
.02749 .03925 Mdot
.00396 .00396 Mdot
.34119 .29021 Mdot
.80782 .79606 Mdot
.84703 .8588 Mdot
.4902 .47451 Mdot
.83135 .87448 Mdot
.00396 4e-05 Mdot
.10591 .12552 Mdot
.55294 .52941 Mdot
.89409 .92546 Mdot
.83527 .85095 Mdot
.4902 .47843 Mdot
.749 .8039 Mdot
.23924 .07062 Mdot
.16473 .15297 Mdot
.64705 .65881 Mdot
.44314 .46275 Mdot
.52941 .53333 Mdot
.47843 .46275 Mdot
.05886 .10199 Mdot
.01572 .0118 Mdot
.52157 .50588 Mdot
.43138 .41569 Mdot
.43922 .38824 Mdot
.5647 .55686 Mdot
.46275 .43922 Mdot
.01572 .00788 Mdot
.01965 .02357 Mdot
.51372 .49804 Mdot
.45098 .37648 Mdot
.47059 .41569 Mdot
.4902 .43138 Mdot
.43922 .44706 Mdot
.67057 .06278 Mdot
.4902 .47843 Mdot
.46667 .39217 Mdot
.46667 .38824 Mdot
.59607 .60391 Mdot
.4902 .42746 Mdot
.0667 .07846 Mdot
.03533 .01965 Mdot
.40001 .33727 Mdot
.45491 .36472 Mdot
.47843 .42354 Mdot
.45491 .3804 Mdot
.58039 .54509 Mdot
.08631 .05102 Mdot
.4353 .40393 Mdot
.45098 .36472 Mdot
.44706 .36864 Mdot
.46275 .39217 Mdot
.38432 .28629 Mdot
.45883 .45883 Mdot
.08631 .04317 Mdot
.47059 .37256 Mdot
.44706 .37256 Mdot
.46275 .40001 Mdot
.47059 .36472 Mdot
.44706 .34903 Mdot
.09415 .07846 Mdot
.43138 .39217 Mdot
.48235 .38432 Mdot
.45098 .36864 Mdot
.45883 .38432 Mdot
.42354 .3255 Mdot
.45883 .3804 Mdot
.09415 .04317 Mdot
.45098 .34903 Mdot
.47451 .38824 Mdot
.46667 .40001 Mdot
.41961 .3059 Mdot
.47059 .38824 Mdot
.3804 .3608 Mdot
.40393 .34511 Mdot
.46667 .3804 Mdot
.45883 .39609 Mdot
.47059 .40393 Mdot
.45098 .34511 Mdot
.40393 .29021 Mdot
.31766 .21571 Mdot
.46667 .36472 Mdot
.46667 .36472 Mdot
.58823 .55294 Mdot
.42354 .30982 Mdot
.45883 .34903 Mdot
.38824 .38824 Mdot
.43922 .33727 Mdot
.45883 .35687 Mdot
.47843 .4353 Mdot
.46275 .43138 Mdot
.46667 .37648 Mdot
.41569 .3059 Mdot
.41177 .29806 Mdot
.45098 .35295 Mdot
.48628 .41569 Mdot
.23924 .21963 Mdot
.42746 .33335 Mdot
.45491 .37256 Mdot
.28629 .21963 Mdot
.47451 .37256 Mdot
.47059 .37256 Mdot
.35295 .32943 Mdot
.42354 .3804 Mdot
.45491 .36472 Mdot
.31766 .24708 Mdot
.3804 .27845 Mdot
.46667 .35295 Mdot
.29021 .25884 Mdot
.58823 .54509 Mdot
.46275 .35295 Mdot
.45098 .34511 Mdot
.27061 .02749 Mdot
.46667 .3608 Mdot
.42746 .36864 Mdot
.55294 .56862 Mdot
.44706 .34903 Mdot
.45098 .34511 Mdot
.29021 .21571 Mdot
.42746 .3608 Mdot
.46275 .35687 Mdot
.40393 .32943 Mdot
.59607 .54117 Mdot
.44314 .34903 Mdot
.43138 .37256 Mdot
.42354 .32943 Mdot
.47059 .34903 Mdot
.30198 .25492 Mdot
.68234 .62352 Mdot
.47451 .3804 Mdot
.46667 .38824 Mdot
.38824 .251 Mdot
.43922 .35295 Mdot
.32943 .29021 Mdot
.40393 .25884 Mdot
.40393 .25492 Mdot
.46667 .37256 Mdot
.31374 .251 Mdot
.41569 .35295 Mdot
.49804 .40001 Mdot
.44314 .23924 Mdot
.48235 .38432 Mdot
.48628 .37256 Mdot
.41961 .34511 Mdot
.69802 .04709 Mdot
.38432 .27453 Mdot
.40393 .29413 Mdot
.40001 .32943 Mdot
.4353 .30198 Mdot
.43922 .33727 Mdot
.40785 .36864 Mdot
.4902 .44706 Mdot
.51372 .41569 Mdot
.47843 .30198 Mdot
.36472 .27453 Mdot
.50196 .38824 Mdot
.39217 .32158 Mdot
.52157 .47843 Mdot
.4353 .33727 Mdot
.47059 .30982 Mdot
.32158 .28629 Mdot
.5098 .38432 Mdot
.37648 .3059 Mdot
.42354 .17257 Mdot
.52549 .48628 Mdot
.41177 .27453 Mdot
.67842 .63528 Mdot
.50196 .39609 Mdot
.37256 .28629 Mdot
.46667 .42746 Mdot
.58431 .57254 Mdot
.43138 .23924 Mdot
.48628 .34903 Mdot
.52941 .38432 Mdot
.41569 .30982 Mdot
.47451 .45883 Mdot
.60783 .59999 Mdot
.50196 .44706 Mdot
.6196 .55294 Mdot
.58039 .40785 Mdot
.45098 .33727 Mdot
.49412 .46275 Mdot
.61176 .59215 Mdot
.5647 .52157 Mdot
.47843 .41961 Mdot
.65881 .47843 Mdot
.47843 .3804 Mdot
.52549 .50196 Mdot
.60391 .57646 Mdot
.60391 .57646 Mdot
.48235 .38432 Mdot
.78429 .65097 Mdot
.5647 .50588 Mdot
.53333 .52941 Mdot
.52941 .50196 Mdot
.63136 .60783 Mdot
.49804 .35295 Mdot
.83919 .77645 Mdot
.59999 .56078 Mdot
.53725 .52549 Mdot
.65097 .64313 Mdot
.62744 .60783 Mdot
.56078 .50196 Mdot
.88232 .83919 Mdot
.64705 .58823 Mdot
.50588 .47843 Mdot
.68626 .68234 Mdot
.67842 .67842 Mdot
.99604 .95291 Mdot
.83135 .83135 Mdot
.60783 .59215 Mdot
.749 .1216 Mdot
.69018 .69018 Mdot
.79998 .8039 Mdot
.99212 .99212 Mdot
.70979 .69018 Mdot
.54117 .53333 Mdot
.72155 .71371 Mdot
.72155 .71763 Mdot
.99604 .99604 Mdot
.81174 .81174 Mdot
.62744 .61176 Mdot
.69802 .69018 Mdot
.73724 .73724 Mdot
.95291 .96075 Mdot
.92546 .92154 Mdot
.65881 .65097 Mdot
.67057 .64705 Mdot
.76861 .76076 Mdot
.94114 .93722 Mdot
.92546 .92546 Mdot
.61568 .59999 Mdot
.76861 .76469 Mdot
.83919 .83919 Mdot
.99212 .99212 Mdot
.84311 .85487 Mdot
.88624 .08239 Mdot
.8039 .79998 Mdot
.95291 .95683 Mdot
.94898 .95291 Mdot
.41177 .26276 Mdot
.81566 .81566 Mdot
.94506 .94114 Mdot
.94114 .95291 Mdot
.76076 .15297 Mdot
.8235 .82743 Mdot
.99212 .9882 Mdot
.72547 .72155 Mdot
.59999 .52157 Mdot
.97643 .9882 Mdot
.59999 .57254 Mdot
.56078 .44706 Mdot
.72547 .70194 Mdot
.81958 .21179 Mdot
.628 .126 .941 r
.78429 .20394 Mdot
.4353 .38824 Mdot
.74508 .68234 Mdot
.75684 .73332 Mdot
.63528 .54117 Mdot
.43138 .44314 Mdot
.72155 .68234 Mdot
.70979 .63528 Mdot
.75292 .75684 Mdot
.79213 .78429 Mdot
.71763 .62744 Mdot
.83135 .80782 Mdot
.81566 .83135 Mdot
.58823 .43922 Mdot
.68626 .61176 Mdot
.63136 .6392 Mdot
.81958 .82743 Mdot
.63528 .51372 Mdot
.66273 .60391 Mdot
.749 .75292 Mdot
.79998 .80782 Mdot
.62352 .48235 Mdot
.76469 .66665 Mdot
.83135 .81566 Mdot
.81174 .83135 Mdot
.83527 .05102 Mdot
.60391 .54509 Mdot
.75684 .72939 Mdot
.3059 .43138 Mdot
.79606 .81174 Mdot
.6392 .51372 Mdot
.80782 .72547 Mdot
.70979 .68626 Mdot
.83135 .83919 Mdot
.749 .77253 Mdot
.73332 .63136 Mdot
.80782 .72939 Mdot
.73332 .70587 Mdot
.81566 .8235 Mdot
.52549 .21571 Mdot
.73724 .64705 Mdot
.78429 .70587 Mdot
.72939 .72547 Mdot
.81566 .85487 Mdot
.82743 .05102 Mdot
.74508 .66273 Mdot
.79213 .70979 Mdot
.83135 .81174 Mdot
.8235 .84703 Mdot
.49804 .54117 Mdot
.71763 .6196 Mdot
.81566 .81958 Mdot
.80782 .76861 Mdot
.83919 .85095 Mdot
.79606 .81566 Mdot
.65881 .57646 Mdot
.75684 .64705 Mdot
.76469 .71763 Mdot
.73724 .77253 Mdot
.78037 .8039 Mdot
.59215 .45883 Mdot
.70979 .61568 Mdot
.79606 .70194 Mdot
.70587 .67842 Mdot
.83919 .86664 Mdot
.75684 .81566 Mdot
.68626 .59999 Mdot
.74508 .63136 Mdot
.75684 .68626 Mdot
.44706 .52157 Mdot
.79213 .8235 Mdot
.56078 .41177 Mdot
.67842 .58431 Mdot
.76469 .6745 Mdot
.84703 .81174 Mdot
.22355 .36864 Mdot
.81174 .83919 Mdot
.61176 .49804 Mdot
.70979 .60391 Mdot
.78821 .6941 Mdot
.77645 .749 Mdot
.83135 .85487 Mdot
.73724 .76076 Mdot
.58039 .5098 Mdot
.43922 .39609 Mdot
.76076 .66665 Mdot
.77645 .75684 Mdot
.83527 .8588 Mdot
.57646 .62352 Mdot
.1412 .09415 Mdot
.57646 .53333 Mdot
.75292 .65489 Mdot
.76861 .74116 Mdot
.83135 .85487 Mdot
.34903 .40001 Mdot
.15297 .08239 Mdot
.62352 .54117 Mdot
.76469 .66665 Mdot
.6941 .67057 Mdot
.83527 .86664 Mdot
.26276 .34511 Mdot
.26276 .1765 Mdot
.61176 .53725 Mdot
.77645 .68234 Mdot
.8235 .79998 Mdot
.83919 .84703 Mdot
.79213 .84311 Mdot
.61568 .51372 Mdot
.65881 .53333 Mdot
.76076 .65881 Mdot
.70587 .64313 Mdot
.5098 .48628 Mdot
.77645 .75292 Mdot
.56862 .47843 Mdot
.6392 .5098 Mdot
.74508 .6392 Mdot
.70587 .61568 Mdot
.38824 .37256 Mdot
.81174 .83527 Mdot
.44314 .32943 Mdot
.6196 .50196 Mdot
.41569 .40001 Mdot
.749 .65881 Mdot
.64313 .61568 Mdot
.64313 .66665 Mdot
.46667 .5098 Mdot
.61176 .50196 Mdot
.61568 .43922 Mdot
.76861 .67057 Mdot
.75684 .69018 Mdot
.02749 .03925 Mdot
.72939 .58431 Mdot
.51765 .44314 Mdot
.61568 .46667 Mdot
.72547 .6196 Mdot
.73724 .63528 Mdot
.03533 .04317 Mdot
.8039 .82743 Mdot
.54509 .55686 Mdot
.62352 .51765 Mdot
.61176 .43922 Mdot
.76861 .68234 Mdot
.64313 .57254 Mdot
.01965 .02357 Mdot
.79213 .71763 Mdot
.5647 .48628 Mdot
.59999 .44314 Mdot
.70979 .57646 Mdot
.73332 .63136 Mdot
.01965 .03141 Mdot
.24316 .25884 Mdot
.66273 .68234 Mdot
.58823 .47451 Mdot
.61176 .41569 Mdot
.76076 .68626 Mdot
.6196 .57254 Mdot
.01965 .02749 Mdot
.59607 .03925 Mdot
.73332 .75684 Mdot
.59607 .45491 Mdot
.65489 .50196 Mdot
.46667 .43138 Mdot
.02749 .03925 Mdot
.02357 .03141 Mdot
.27845 .31766 Mdot
.59607 .53333 Mdot
.57254 .37648 Mdot
.72155 .60391 Mdot
.71763 .63136 Mdot
.03141 .03925 Mdot
.58823 .59215 Mdot
.82743 .05102 Mdot
.58039 .48235 Mdot
.62744 .43922 Mdot
.49412 .45883 Mdot
.07454 .05494 Mdot
.3059 .40393 Mdot
.59215 .1961 Mdot
.77645 .80782 Mdot
.59999 .47843 Mdot
.65097 .49412 Mdot
.54509 .51372 Mdot
.04317 .05102 Mdot
.28629 .42354 Mdot
.62744 .0118 Mdot
.8235 .83527 Mdot
.58823 .43138 Mdot
.68234 .54902 Mdot
.76469 .68234 Mdot
.11376 .11768 Mdot
.28237 .33727 Mdot
.43922 .38824 Mdot
.56862 .51765 Mdot
.56862 .37648 Mdot
.72547 .6196 Mdot
.61176 .57646 Mdot
.23531 .38432 Mdot
.02357 .03925 Mdot
.53725 .52941 Mdot
.58823 .53725 Mdot
.59215 .40393 Mdot
.76076 .66273 Mdot
.0667 .0667 Mdot
.81958 .8235 Mdot
.67057 .71371 Mdot
.74508 .76469 Mdot
.57254 .48628 Mdot
.63528 .47451 Mdot
.78821 .70194 Mdot
.05886 .05102 Mdot
.68234 .68626 Mdot
.59215 .08239 Mdot
.77253 .81566 Mdot
.59607 .50588 Mdot
.66665 .55686 Mdot
.78821 .72155 Mdot
.34119 .39217 Mdot
.749 .79213 Mdot
.50196 .02357 Mdot
.57646 .60783 Mdot
.58039 .47451 Mdot
.69018 .57646 Mdot
.77645 .69802 Mdot
.24316 .41961 Mdot
.27845 .38432 Mdot
.46275 .03925 Mdot
.66273 .67842 Mdot
.57646 .46275 Mdot
.69802 .59215 Mdot
.76076 .68234 Mdot
.6196 .58039 Mdot
.79606 .8588 Mdot
.39217 .01572 Mdot
.81566 .84703 Mdot
.5647 .42354 Mdot
.70587 .61176 Mdot
.25884 .23139 Mdot
.45491 .41961 Mdot
.81958 .85487 Mdot
.43922 .04709 Mdot
.6941 .70194 Mdot
.5647 .38824 Mdot
.70979 .61176 Mdot
.08239 .0667 Mdot
.04317 .05102 Mdot
.8235 .8588 Mdot
.37256 .02749 Mdot
.55294 .54117 Mdot
.55686 .39609 Mdot
.72155 .62744 Mdot
.09023 .05886 Mdot
.02357 .04317 Mdot
.82743 .85487 Mdot
.30198 .00396 Mdot
.5647 .54117 Mdot
.56862 .41569 Mdot
.71371 .62744 Mdot
.09415 .05886 Mdot
.02357 .03533 Mdot
.74116 .77253 Mdot
.38432 .01572 Mdot
.56862 .54902 Mdot
.5647 .41177 Mdot
.72939 .64313 Mdot
.30198 .29806 Mdot
.02749 .03533 Mdot
.37648 .42354 Mdot
.51765 .05886 Mdot
.58431 .56078 Mdot
.59215 .45491 Mdot
.74116 .65881 Mdot
.27061 .46275 Mdot
.11768 .12552 Mdot
.07846 .1216 Mdot
.49412 .06278 Mdot
.58431 .56078 Mdot
.59999 .46275 Mdot
.73724 .65489 Mdot
.30198 .49804 Mdot
.34903 .43922 Mdot
.07062 .11376 Mdot
.44706 .02357 Mdot
.59215 .56078 Mdot
.62352 .49804 Mdot
.72939 .64705 Mdot
.58431 .69802 Mdot
.16865 .36472 Mdot
.06278 .10983 Mdot
.47451 .02357 Mdot
.58431 .55686 Mdot
.62744 .50588 Mdot
.72547 .64705 Mdot
.74116 .76469 Mdot
.41177 .53333 Mdot
.07062 .10199 Mdot
.43138 .00788 Mdot
.58823 .56862 Mdot
.6196 .5098 Mdot
.72939 .63528 Mdot
.74508 .70979 Mdot
.77253 .78037 Mdot
.0667 .08631 Mdot
.47451 .03141 Mdot
.54902 .53333 Mdot
.63528 .52549 Mdot
.72547 .63136 Mdot
.72939 .6745 Mdot
.62352 .58431 Mdot
.07454 .09807 Mdot
.55686 .08239 Mdot
.53333 .51372 Mdot
.62744 .52549 Mdot
.72155 .63528 Mdot
.6745 .62352 Mdot
.50196 .45883 Mdot
.0667 .09807 Mdot
.57254 .15689 Mdot
.52941 .50196 Mdot
.6392 .54117 Mdot
.73332 .64313 Mdot
.26276 .24316 Mdot
.16865 .15297 Mdot
.05494 .08239 Mdot
.58039 .29021 Mdot
.50588 .47843 Mdot
.6392 .55294 Mdot
.72547 .63528 Mdot
.11768 .10199 Mdot
.05494 .06278 Mdot
.05494 .08239 Mdot
.65881 .50588 Mdot
.50588 .48235 Mdot
.6392 .54902 Mdot
.72547 .63136 Mdot
.10199 .08239 Mdot
.05886 .05102 Mdot
.05494 .08239 Mdot
.63528 .58039 Mdot
.49804 .47451 Mdot
.64313 .54509 Mdot
.73332 .65097 Mdot
.10983 .09023 Mdot
.22355 .21179 Mdot
.04709 .0667 Mdot
.54509 .53333 Mdot
.48628 .46667 Mdot
.63528 .54117 Mdot
.73332 .64313 Mdot
.23531 .23531 Mdot
.18826 .25884 Mdot
.03925 .06278 Mdot
.72547 .73724 Mdot
.46275 .46275 Mdot
.61568 .52941 Mdot
.72155 .62744 Mdot
.3059 .30982 Mdot
.31374 .34119 Mdot
.0667 .09023 Mdot
.56862 .60783 Mdot
.6941 .70194 Mdot
.61568 .54117 Mdot
.70979 .61568 Mdot
.47059 .50196 Mdot
.04709 .04317 Mdot
.31374 .34119 Mdot
.41961 .50196 Mdot
.76469 .78037 Mdot
.62744 .56078 Mdot
.71763 .63136 Mdot
.47059 .56862 Mdot
.04709 .05886 Mdot
.35687 .42746 Mdot
.73332 .81174 Mdot
.76076 .78429 Mdot
.65097 .58039 Mdot
.70194 .60783 Mdot
.30982 .45883 Mdot
.07846 .07846 Mdot
.45491 .52549 Mdot
.47451 .58039 Mdot
.65097 .66665 Mdot
.64705 .58431 Mdot
.70194 .6196 Mdot
.66273 .70587 Mdot
.1765 .16473 Mdot
.63136 .69018 Mdot
.79606 .87448 Mdot
.51765 .52549 Mdot
.65489 .59215 Mdot
.69018 .61568 Mdot
.77253 .72547 Mdot
.27453 .25884 Mdot
.41961 .49412 Mdot
.79213 .84703 Mdot
.5098 .51765 Mdot
.64313 .59999 Mdot
.68234 .59607 Mdot
.78037 .70979 Mdot
.30982 .3059 Mdot
.03925 .07846 Mdot
.77645 .83135 Mdot
.45883 .47059 Mdot
.65489 .60783 Mdot
.6745 .58823 Mdot
.78037 .71371 Mdot
.30198 .30198 Mdot
.0118 .02749 Mdot
.8039 .84311 Mdot
.42354 .45098 Mdot
.65097 .61568 Mdot
.67842 .58823 Mdot
.78429 .72155 Mdot
.30198 .3059 Mdot
.01572 .03533 Mdot
.79213 .83919 Mdot
.46275 .50588 Mdot
.6392 .60783 Mdot
.66273 .57646 Mdot
.78821 .72155 Mdot
.62352 .59999 Mdot
.38824 .42354 Mdot
.79606 .85095 Mdot
.65489 .70979 Mdot
.63136 .59215 Mdot
.65489 .56078 Mdot
.76076 .6941 Mdot
.68626 .64705 Mdot
.65097 .66273 Mdot
.79213 .8235 Mdot
.54902 .55294 Mdot
.61176 .5647 Mdot
.64313 .55294 Mdot
.75684 .69018 Mdot
.72547 .6745 Mdot
.63136 .60391 Mdot
.79606 .83135 Mdot
.56078 .40785 Mdot
.56862 .52549 Mdot
.64313 .54902 Mdot
.75292 .67057 Mdot
.70979 .67057 Mdot
.60391 .54902 Mdot
.8039 .85487 Mdot
.26668 .21963 Mdot
.5647 .53725 Mdot
.6392 .54117 Mdot
.74116 .66665 Mdot
.71763 .6941 Mdot
.61176 .56078 Mdot
.74508 .80782 Mdot
.16865 .21179 Mdot
.5647 .55294 Mdot
.61568 .52157 Mdot
.73724 .67842 Mdot
.73332 .69802 Mdot
.6196 .56862 Mdot
.25492 .3255 Mdot
.59215 .63136 Mdot
.56078 .56078 Mdot
.61568 .52941 Mdot
.73724 .67842 Mdot
.72939 .6941 Mdot
.63528 .59607 Mdot
.02357 .05886 Mdot
.6392 .65881 Mdot
.6941 .71371 Mdot
.62744 .54902 Mdot
.73724 .66273 Mdot
.72939 .69802 Mdot
.61176 .57646 Mdot
.00788 .02749 Mdot
.48628 .51372 Mdot
.42746 .44706 Mdot
.62352 .56078 Mdot
.72547 .65489 Mdot
.75684 .73332 Mdot
.12944 .14513 Mdot
.26668 .29806 Mdot
.52941 .60783 Mdot
.65097 .6745 Mdot
.60783 .55686 Mdot
.70194 .6392 Mdot
.76469 .72939 Mdot
.05494 .06278 Mdot
.59215 .59607 Mdot
.76861 .83527 Mdot
.30198 .33335 Mdot
.62352 .58823 Mdot
.69802 .6392 Mdot
.749 .71371 Mdot
.04709 .05886 Mdot
.04317 .05102 Mdot
.78821 .84703 Mdot
.45098 .49804 Mdot
.64313 .61176 Mdot
.6745 .60391 Mdot
.75684 .71371 Mdot
.07846 .09415 Mdot
.01572 .03141 Mdot
.77645 .83527 Mdot
.55686 .59215 Mdot
.61176 .59999 Mdot
.65881 .59215 Mdot
.749 .70587 Mdot
.28237 .27453 Mdot
.00788 .02357 Mdot
.79213 .84311 Mdot
.58039 .63136 Mdot
.6196 .59607 Mdot
.65881 .57646 Mdot
.73724 .69802 Mdot
.68626 .66665 Mdot
.01572 .03925 Mdot
.6941 .70979 Mdot
.66273 .60391 Mdot
.59999 .58039 Mdot
.64705 .56078 Mdot
.72939 .68626 Mdot
.72547 .69802 Mdot
.01572 .03533 Mdot
.01965 .06278 Mdot
.21179 .12944 Mdot
.58823 .58431 Mdot
.63528 .53725 Mdot
.74508 .69018 Mdot
.72939 .69802 Mdot
.02357 .04709 Mdot
.00396 .04317 Mdot
.08239 .18434 Mdot
.55686 .5647 Mdot
.6196 .53333 Mdot
.72939 .66273 Mdot
.75292 .72547 Mdot
.03925 .05494 Mdot
.00396 .04709 Mdot
.10983 .20002 Mdot
.81958 .85487 Mdot
.60783 .54117 Mdot
.68626 .61176 Mdot
.75684 .72939 Mdot
.02749 .05102 Mdot
.44706 .49412 Mdot
.65881 .70194 Mdot
.35295 .38824 Mdot
.58039 .54117 Mdot
.6392 .55686 Mdot
.76076 .73332 Mdot
.03141 .04709 Mdot
.4353 .53333 Mdot
.29806 .40393 Mdot
.69018 .72547 Mdot
.56078 .52549 Mdot
.6196 .51765 Mdot
.76861 .75292 Mdot
.04317 .05494 Mdot
.03533 .07846 Mdot
.78037 .85095 Mdot
.34903 .37256 Mdot
.59215 .55294 Mdot
.59607 .49412 Mdot
.59215 .58823 Mdot
.05102 .07454 Mdot
.01572 .03533 Mdot
.77253 .84311 Mdot
.48628 .52157 Mdot
.58431 .54509 Mdot
.61176 .50588 Mdot
.66665 .64705 Mdot
.11376 .1412 Mdot
.00788 .03141 Mdot
.77645 .86272 Mdot
.73724 .78821 Mdot
.58823 .56862 Mdot
.60783 .50196 Mdot
.71371 .67057 Mdot
.62744 .63528 Mdot
.00396 .03533 Mdot
.45491 .62352 Mdot
.59215 .53725 Mdot
.55686 .55294 Mdot
.59607 .48235 Mdot
.6392 .58431 Mdot
.70587 .68234 Mdot
.0118 .03533 Mdot
.08239 .3255 Mdot
.32943 .3059 Mdot
.56862 .55294 Mdot
.57254 .48235 Mdot
.62352 .5647 Mdot
.70587 .69802 Mdot
.03141 .05102 Mdot
.04709 .25884 Mdot
.30198 .29806 Mdot
.54117 .55294 Mdot
.58431 .4902 Mdot
.6392 .57254 Mdot
.72939 .71371 Mdot
.02749 .03533 Mdot
.47843 .54509 Mdot
.39217 .37648 Mdot
.48628 .50196 Mdot
.55686 .48628 Mdot
.60391 .51765 Mdot
.75684 .73724 Mdot
.02749 .04317 Mdot
.72939 .79213 Mdot
.48628 .4902 Mdot
.40393 .43922 Mdot
.55294 .50196 Mdot
.58823 .48628 Mdot
.75684 .74116 Mdot
.03533 .04709 Mdot
.56078 .74508 Mdot
.73724 .76861 Mdot
.33335 .38824 Mdot
.53725 .49412 Mdot
.57646 .44314 Mdot
.77645 .75292 Mdot
.03141 .04709 Mdot
.14513 .37648 Mdot
.40393 .49412 Mdot
.45883 .51765 Mdot
.53333 .50588 Mdot
.5647 .4353 Mdot
.75292 .73724 Mdot
.04709 .05886 Mdot
.31766 .45098 Mdot
.39609 .47843 Mdot
.73724 .78821 Mdot
.55294 .53725 Mdot
.5647 .44706 Mdot
.74116 .71763 Mdot
.03533 .04317 Mdot
.30982 .37648 Mdot
.78037 .83527 Mdot
.75684 .8235 Mdot
.53725 .5098 Mdot
.54902 .4353 Mdot
.63136 .58431 Mdot
.10983 .13336 Mdot
.14513 .18042 Mdot
.37256 .45491 Mdot
.64705 .58431 Mdot
.5647 .54902 Mdot
.54117 .42746 Mdot
.61176 .55294 Mdot
.72155 .70587 Mdot
.03925 .0667 Mdot
.42746 .47451 Mdot
.23924 .27453 Mdot
.53725 .53333 Mdot
.52941 .41961 Mdot
.60391 .53333 Mdot
.72547 .72547 Mdot
.10591 .1412 Mdot
.81174 .86272 Mdot
.3608 .36472 Mdot
.47843 .4902 Mdot
.54117 .45098 Mdot
.59215 .51765 Mdot
.73724 .73724 Mdot
.62744 .65489 Mdot
.64313 .73332 Mdot
.25492 .34119 Mdot
.1216 .14905 Mdot
.54902 .49804 Mdot
.63136 .57254 Mdot
.74508 .74116 Mdot
.58431 .62744 Mdot
.31374 .40393 Mdot
.4353 .49804 Mdot
.33335 .36472 Mdot
.55686 .52941 Mdot
.58823 .50588 Mdot
.749 .74508 Mdot
.12944 .16865 Mdot
.56078 .58431 Mdot
.12552 .29806 Mdot
.18434 .18434 Mdot
.54117 .52157 Mdot
.59215 .50196 Mdot
.749 .749 Mdot
.1216 .18042 Mdot
.37648 .40393 Mdot
.63528 .68234 Mdot
.11376 .1216 Mdot
.49412 .48628 Mdot
.59999 .50196 Mdot
.58039 .57646 Mdot
.14513 .21179 Mdot
.13336 .17257 Mdot
.43922 .52157 Mdot
.22355 .21571 Mdot
.49804 .4902 Mdot
.55294 .45883 Mdot
.5647 .53725 Mdot
.64705 .66665 Mdot
.10591 .12944 Mdot
.78821 .83135 Mdot
.70587 .08239 Mdot
.5098 .50196 Mdot
.56862 .46667 Mdot
.66665 .62352 Mdot
.71371 .70194 Mdot
.14905 .18434 Mdot
.11376 .18042 Mdot
.07062 .18826 Mdot
.48235 .48628 Mdot
.54902 .45098 Mdot
.67057 .62744 Mdot
.72939 .73332 Mdot
.12552 .16865 Mdot
.00788 .04709 Mdot
.04709 .1961 Mdot
.47451 .4902 Mdot
.54117 .45491 Mdot
.68626 .65881 Mdot
.73332 .72155 Mdot
.15297 .18434 Mdot
.00396 .03141 Mdot
.07846 .20787 Mdot
.43138 .43922 Mdot
.52941 .48235 Mdot
.65881 .63528 Mdot
.74508 .749 Mdot
.20394 .25492 Mdot
.00788 .02749 Mdot
.39609 .42746 Mdot
.21179 .23531 Mdot
.50588 .47059 Mdot
.64705 .61176 Mdot
.72155 .71763 Mdot
.35687 .47451 Mdot
.00788 .04709 Mdot
.46275 .45883 Mdot
.08631 .09807 Mdot
.43922 .41569 Mdot
.6392 .59999 Mdot
.71763 .70979 Mdot
.23924 .39217 Mdot
.00788 .04317 Mdot
.47059 .48235 Mdot
.20787 .22747 Mdot
.42746 .41569 Mdot
.61176 .5647 Mdot
.71763 .71371 Mdot
.28629 .43138 Mdot
.02357 .04317 Mdot
.44706 .48628 Mdot
.1961 .18042 Mdot
.44314 .41961 Mdot
.61176 .56078 Mdot
.72155 .72939 Mdot
.6745 .68626 Mdot
.04317 .0667 Mdot
.18042 .22747 Mdot
.31374 .26276 Mdot
.47451 .46275 Mdot
.59215 .52549 Mdot
.70587 .71763 Mdot
.71371 .70587 Mdot
.06278 .10199 Mdot
.00396 .03533 Mdot
.31374 .33727 Mdot
.42354 .4353 Mdot
.54902 .48628 Mdot
.70979 .70979 Mdot
.69018 .67842 Mdot
.07062 .10591 Mdot
.16081 .20394 Mdot
.34119 .37256 Mdot
.40393 .40001 Mdot
.56862 .49412 Mdot
.67057 .65097 Mdot
.71371 .72155 Mdot
.03141 .05886 Mdot
.5098 .53725 Mdot
.40393 .40001 Mdot
.34903 .35687 Mdot
.54902 .48628 Mdot
.68626 .65489 Mdot
.70979 .70979 Mdot
.01965 .03925 Mdot
.03141 .07454 Mdot
.10983 .18434 Mdot
.29806 .32158 Mdot
.51765 .50196 Mdot
.6941 .66665 Mdot
.68626 .6941 Mdot
.02357 .05102 Mdot
.00396 .04317 Mdot
.44314 .43922 Mdot
.30198 .31766 Mdot
.45491 .43922 Mdot
.66273 .63528 Mdot
.72939 .73332 Mdot
.00788 .03533 Mdot
.00396 .02749 Mdot
.47843 .47451 Mdot
.1216 .11376 Mdot
.43922 .43138 Mdot
.6392 .59607 Mdot
.71371 .72155 Mdot
.03533 .05886 Mdot
.00788 .03533 Mdot
.59999 .69018 Mdot
.34511 .31766 Mdot
.45491 .44706 Mdot
.6196 .55294 Mdot
.70194 .69018 Mdot
.03925 .0667 Mdot
.04317 .08631 Mdot
.04709 .09415 Mdot
.27845 .32158 Mdot
.38432 .38824 Mdot
.59999 .53725 Mdot
.58823 .56078 Mdot
.34903 .38432 Mdot
.5647 .57646 Mdot
.42746 .49804 Mdot
.05494 .23531 Mdot
.31766 .33335 Mdot
.55294 .50196 Mdot
.54902 .49412 Mdot
.68234 .69802 Mdot
.59215 .62352 Mdot
.8039 .90585 Mdot
.08631 .20394 Mdot
.27453 .29413 Mdot
.52549 .49412 Mdot
.61568 .58823 Mdot
.66273 .6745 Mdot
.4902 .62352 Mdot
.18826 .40001 Mdot
.43922 .4353 Mdot
.27453 .27453 Mdot
.50196 .47451 Mdot
.66273 .62744 Mdot
.69802 .72155 Mdot
.18826 .46275 Mdot
.12944 .39217 Mdot
.47451 .46667 Mdot
.39609 .38824 Mdot
.44314 .4353 Mdot
.6196 .57646 Mdot
.70587 .70587 Mdot
.33335 .48628 Mdot
.12944 .36472 Mdot
.48628 .4902 Mdot
.37648 .37648 Mdot
.44314 .43922 Mdot
.57254 .50196 Mdot
.69802 .69802 Mdot
.07062 .09023 Mdot
.18042 .22747 Mdot
.749 .80782 Mdot
.27845 .30982 Mdot
.38432 .3804 Mdot
.52157 .4353 Mdot
.6196 .60391 Mdot
.02357 .04709 Mdot
.32943 .34903 Mdot
.15689 .34511 Mdot
.40393 .42354 Mdot
.29806 .30982 Mdot
.46275 .40001 Mdot
.65489 .64313 Mdot
.06278 .09415 Mdot
.58039 .58039 Mdot
.10199 .13728 Mdot
.41569 .39609 Mdot
.12552 .1412 Mdot
.45098 .43138 Mdot
.65489 .63136 Mdot
.65881 .66273 Mdot
.12552 .1961 Mdot
.03141 .05494 Mdot
.44706 .43138 Mdot
.28237 .29413 Mdot
.45491 .44314 Mdot
.55294 .49804 Mdot
.66665 .65489 Mdot
.07846 .12944 Mdot
.03533 .07062 Mdot
.46275 .46275 Mdot
.38824 .38824 Mdot
.49804 .4902 Mdot
.57254 .5098 Mdot
.68626 .6941 Mdot
.38824 .51765 Mdot
.26668 .32158 Mdot
.48628 .48628 Mdot
.26276 .27453 Mdot
.41961 .42354 Mdot
.47843 .37648 Mdot
.65097 .66273 Mdot
.22355 .48235 Mdot
.67842 .6941 Mdot
.03141 .07846 Mdot
.07454 .23531 Mdot
.35295 .37256 Mdot
.4902 .39609 Mdot
.71371 .71763 Mdot
.24316 .33335 Mdot
.48235 .58431 Mdot
.00396 .03925 Mdot
.05494 .23531 Mdot
.30982 .33727 Mdot
.4353 .3804 Mdot
.6745 .65881 Mdot
.05102 .07846 Mdot
.04317 .08631 Mdot
.00788 .05886 Mdot
.0667 .29021 Mdot
.22355 .23139 Mdot
.39609 .38824 Mdot
.53725 .50196 Mdot
.5098 .54509 Mdot
.56862 .6392 Mdot
.03533 .09415 Mdot
.09023 .28629 Mdot
.31766 .30198 Mdot
.47059 .47843 Mdot
.58039 .53333 Mdot
.6941 .70587 Mdot
.32158 .54117 Mdot
.42746 .48628 Mdot
.31374 .3608 Mdot
.40001 .31374 Mdot
.47843 .48628 Mdot
.5647 .50588 Mdot
.70979 .72155 Mdot
.32943 .50588 Mdot
.77645 .84311 Mdot
.00396 .03533 Mdot
.40785 .39217 Mdot
.37648 .38824 Mdot
.52941 .47059 Mdot
.69018 .70587 Mdot
.0667 .08631 Mdot
.63528 .66665 Mdot
.10591 .13728 Mdot
.42354 .41569 Mdot
.3059 .3255 Mdot
.4353 .38824 Mdot
.59215 .57646 Mdot
.20787 .22747 Mdot
.15297 .39217 Mdot
.09023 .13728 Mdot
.09807 .23139 Mdot
.26668 .27061 Mdot
.3804 .33335 Mdot
.82743 .8235 Mdot
.07062 .09023 Mdot
.27453 .35687 Mdot
.02357 .04709 Mdot
.45098 .47059 Mdot
.22747 .21571 Mdot
.44706 .44706 Mdot
.51372 .4902 Mdot
.65881 .66273 Mdot
.03925 .07454 Mdot
.00396 .03141 Mdot
.17257 .34511 Mdot
.29806 .28237 Mdot
.46275 .47059 Mdot
.59607 .54117 Mdot
.70587 .71371 Mdot
.07454 .1216 Mdot
.01965 .05494 Mdot
.06278 .31374 Mdot
.18434 .27453 Mdot
.43138 .46667 Mdot
.52549 .47059 Mdot
.68234 .69018 Mdot
.10983 .19218 Mdot
.64313 .71763 Mdot
.05494 .10591 Mdot
.05494 .25884 Mdot
.33727 .37648 Mdot
.5098 .45098 Mdot
.66273 .66665 Mdot
.03925 .0667 Mdot
.49804 .54902 Mdot
.71371 .73724 Mdot
.12944 .23924 Mdot
.27453 .27845 Mdot
.41961 .40001 Mdot
.53725 .52941 Mdot
.08239 .12944 Mdot
.71371 .73724 Mdot
.04317 .07846 Mdot
.18434 .30198 Mdot
.08631 .08239 Mdot
.41569 .40785 Mdot
.54509 .52941 Mdot
.70587 .71371 Mdot
.65881 .72547 Mdot
.16081 .31374 Mdot
.41569 .4902 Mdot
.30198 .27845 Mdot
.3804 .40001 Mdot
.57646 .54509 Mdot
.69802 .71371 Mdot
.34119 .53333 Mdot
.01965 .05886 Mdot
.20002 .37648 Mdot
.27061 .3059 Mdot
.03533 .0667 Mdot
.51372 .45883 Mdot
.63136 .63528 Mdot
.43138 .62744 Mdot
.55294 .59607 Mdot
.21963 .31374 Mdot
.21571 .28237 Mdot
.13728 .17257 Mdot
.45491 .42354 Mdot
.54117 .52549 Mdot
.06278 .10983 Mdot
.59999 .62744 Mdot
.05494 .07454 Mdot
.44314 .4353 Mdot
.251 .25884 Mdot
.41177 .41177 Mdot
.50588 .48235 Mdot
.29413 .32943 Mdot
.59999 .62352 Mdot
.02357 .05494 Mdot
.48235 .47843 Mdot
.28237 .26276 Mdot
.38432 .40393 Mdot
.55686 .53725 Mdot
.69018 .69802 Mdot
.71763 .73332 Mdot
.03533 .07846 Mdot
.44314 .46275 Mdot
.12944 .01572 Mdot
.3059 .32943 Mdot
.58431 .55294 Mdot
.69018 .70587 Mdot
.66273 .6745 Mdot
.6196 .67057 Mdot
.29413 .3059 Mdot
.11768 .1765 Mdot
.31374 .35687 Mdot
.52157 .47451 Mdot
.5098 .5098 Mdot
.23139 .39609 Mdot
.65489 .74508 Mdot
.02749 .07454 Mdot
.37648 .37256 Mdot
.26276 .28629 Mdot
.44706 .42354 Mdot
.50196 .47843 Mdot
.05102 .07062 Mdot
.63136 .68234 Mdot
.00396 .03533 Mdot
.46667 .46275 Mdot
.0667 .0667 Mdot
.40785 .42354 Mdot
.46275 .45491 Mdot
.66273 .68626 Mdot
.66273 .67842 Mdot
.11376 .1765 Mdot
.4353 .43138 Mdot
.09807 .01572 Mdot
.29021 .30982 Mdot
.49412 .45491 Mdot
.65097 .66273 Mdot
.64313 .67057 Mdot
.5098 .59215 Mdot
4e-05 .02749 Mdot
.05886 .17257 Mdot
.27453 .31766 Mdot
.55294 .51765 Mdot
.50196 .50588 Mdot
.35295 .46667 Mdot
.80782 .85487 Mdot
.00396 .03141 Mdot
.04709 .20002 Mdot
.28237 .32158 Mdot
.50588 .47843 Mdot
.4902 .48235 Mdot
.03533 .05102 Mdot
.64705 .77253 Mdot
.00396 .02749 Mdot
.11768 .24708 Mdot
.27061 .29021 Mdot
.44706 .43922 Mdot
.4353 .43922 Mdot
.31766 .35687 Mdot
.72939 .81958 Mdot
4e-05 .03141 Mdot
.42746 .41177 Mdot
.21963 .19218 Mdot
.33727 .34903 Mdot
.33727 .33335 Mdot
.63136 .64705 Mdot
.67842 .70194 Mdot
4e-05 .03141 Mdot
.02749 .05494 Mdot
.65489 .1216 Mdot
.24708 .28237 Mdot
.49412 .44314 Mdot
.5647 .57254 Mdot
.0667 .13336 Mdot
.00396 .03533 Mdot
.26276 .34119 Mdot
.35295 .34119 Mdot
.27061 .30982 Mdot
.51765 .49412 Mdot
.4902 .48235 Mdot
.03925 .07062 Mdot
.02357 .08239 Mdot
.21179 .40785 Mdot
.03533 .21963 Mdot
.10199 .13336 Mdot
.44706 .45098 Mdot
.47059 .45098 Mdot
.65097 .6745 Mdot
.62352 .68626 Mdot
.11376 .16865 Mdot
.42354 .45098 Mdot
.39609 .38824 Mdot
.39217 .41569 Mdot
.50196 .4902 Mdot
.57254 .59607 Mdot
.65881 .68234 Mdot
.40785 .44706 Mdot
.13728 .25884 Mdot
.80782 .03533 Mdot
.27453 .3059 Mdot
.45098 .41961 Mdot
.5647 .5647 Mdot
.03533 .06278 Mdot
.07454 .1216 Mdot
.00396 .02357 Mdot
.36864 .35295 Mdot
.27453 .3059 Mdot
.52549 .50588 Mdot
.83919 .87448 Mdot
.04709 .07454 Mdot
.00788 .04709 Mdot
.05886 .12944 Mdot
.21179 .26276 Mdot
.20002 .20787 Mdot
.40785 .40393 Mdot
.49804 .47451 Mdot
.61568 .63528 Mdot
.00396 .03925 Mdot
.3608 .52941 Mdot
.40393 .39217 Mdot
.12944 .13728 Mdot
.39609 .41961 Mdot
.50588 .48628 Mdot
.5647 .58039 Mdot
.06278 .11376 Mdot
.16473 .23924 Mdot
.0667 .07062 Mdot
.63528 .03141 Mdot
.28629 .31766 Mdot
.47451 .43138 Mdot
.59215 .60391 Mdot
.04709 .07454 Mdot
.20787 .31374 Mdot
.00788 .03141 Mdot
.38824 .35687 Mdot
.25492 .28237 Mdot
.46275 .4353 Mdot
.53333 .53333 Mdot
.26668 .29413 Mdot
.19218 .4353 Mdot
.00396 .04709 Mdot
.40393 .3804 Mdot
.16473 .17257 Mdot
.33727 .32158 Mdot
.53333 .52941 Mdot
.749 .76861 Mdot
.25492 .3608 Mdot
.00396 .03141 Mdot
.40785 .39217 Mdot
.32943 .3059 Mdot
.37648 .40001 Mdot
.47451 .46275 Mdot
.53725 .55294 Mdot
.03925 .0667 Mdot
.31374 .48628 Mdot
.0667 .09807 Mdot
.64705 .10983 Mdot
.04317 .09023 Mdot
.45098 .42746 Mdot
.57646 .58823 Mdot
.09415 .1412 Mdot
.13336 .18826 Mdot
.30198 .37648 Mdot
.36864 .34511 Mdot
.24316 .29021 Mdot
.49804 .47451 Mdot
.51372 .50588 Mdot
.77645 .79213 Mdot
.11768 .22355 Mdot
.24708 .3608 Mdot
.41177 .3804 Mdot
.24708 .25492 Mdot
.42746 .41961 Mdot
.4902 .48235 Mdot
.6196 .65097 Mdot
.46667 .61176 Mdot
.02357 .05102 Mdot
.41177 .39217 Mdot
.27453 .23924 Mdot
.33335 .34119 Mdot
.48628 .46667 Mdot
.76861 .78429 Mdot
.13336 .16473 Mdot
.00788 .04317 Mdot
.18434 .20394 Mdot
.62352 .00788 Mdot
.24708 .27845 Mdot
.47843 .45098 Mdot
.60391 .62352 Mdot
.05494 .08631 Mdot
.54117 .65881 Mdot
4e-05 .02749 Mdot
.38824 .3608 Mdot
.04709 .06278 Mdot
.51372 .50196 Mdot
.46667 .46275 Mdot
.42354 .47451 Mdot
.29413 .40393 Mdot
.12944 .18826 Mdot
.41177 .40001 Mdot
.26668 .26276 Mdot
.42354 .4353 Mdot
.46275 .45098 Mdot
.63136 .66665 Mdot
.29413 .34119 Mdot
.08631 .30982 Mdot
.38824 .37256 Mdot
.15297 .1216 Mdot
.27845 .31766 Mdot
.46667 .45883 Mdot
.78037 .78821 Mdot
.02357 .07062 Mdot
.00396 .04317 Mdot
.00396 .0118 Mdot
.32158 .28629 Mdot
.30198 .32158 Mdot
.54902 .53333 Mdot
.38432 .43922 Mdot
.07454 .11768 Mdot
.83527 .8784 Mdot
4e-05 .01572 Mdot
.40001 .36472 Mdot
.22747 .25492 Mdot
.46667 .46275 Mdot
.47843 .48235 Mdot
.27453 .34511 Mdot
.28629 .52157 Mdot
.00396 .03533 Mdot
.40393 .37648 Mdot
.23139 .1961 Mdot
.41177 .42746 Mdot
.47843 .47451 Mdot
.80782 .84311 Mdot
.15689 .21963 Mdot
.00788 .05494 Mdot
.33335 .37648 Mdot
.08631 4e-05 Mdot
.35295 .38824 Mdot
.48628 .45883 Mdot
.58431 .60391 Mdot
.05494 .10199 Mdot
.16081 .21571 Mdot
.00788 .02749 Mdot
.37648 .3608 Mdot
.29806 .32158 Mdot
.51765 .50196 Mdot
.50588 .55686 Mdot
.21571 .38432 Mdot
.8235 .87056 Mdot
.21179 .31374 Mdot
.40001 .3804 Mdot
.251 .25492 Mdot
.30198 .31374 Mdot
.49412 .4902 Mdot
.69018 .72547 Mdot
.85487 .91761 Mdot
.01572 .05102 Mdot
.41177 .39609 Mdot
.08631 .05102 Mdot
.37256 .38824 Mdot
.8235 .83135 Mdot
.77253 .8039 Mdot
.02749 .07062 Mdot
.00788 .04317 Mdot
.08631 .23531 Mdot
.33335 .26668 Mdot
.1216 .14905 Mdot
.54902 .5098 Mdot
.52549 .54117 Mdot
.48235 .52157 Mdot
.81566 .85095 Mdot
.01572 .04709 Mdot
.3804 .35687 Mdot
.13336 .16473 Mdot
.42354 .42354 Mdot
.18434 .35295 Mdot
.31374 .33727 Mdot
.83527 .87056 Mdot
.60783 .72939 Mdot
.40785 .39609 Mdot
.28237 .25492 Mdot
.40393 .41961 Mdot
.47059 .45883 Mdot
.84703 .88624 Mdot
.23139 .44314 Mdot
.17257 .35687 Mdot
.41177 .38824 Mdot
.251 .05494 Mdot
.41177 .43138 Mdot
.49804 .50588 Mdot
.56078 .58823 Mdot
.0667 .09415 Mdot
.18826 .24708 Mdot
.37256 .45491 Mdot
.3804 .34511 Mdot
.28629 .30198 Mdot
.4902 .47451 Mdot
.72939 .749 Mdot
.30198 .55294 Mdot
.82743 .86272 Mdot
.53725 .59215 Mdot
.40393 .3804 Mdot
.08239 .10199 Mdot
.16081 .18434 Mdot
.10591 .32943 Mdot
.6941 .79606 Mdot
.83527 .86664 Mdot
.58823 .65881 Mdot
.40785 .38824 Mdot
.26668 .1961 Mdot
.34511 .38824 Mdot
.47059 .48235 Mdot
.8235 .84703 Mdot
.16865 .40001 Mdot
.61568 .72939 Mdot
.42746 .42354 Mdot
.37256 .32943 Mdot
.37648 .41569 Mdot
.56862 .54509 Mdot
.68626 .71371 Mdot
.05102 .09023 Mdot
.8235 .8588 Mdot
.57646 .60391 Mdot
.38432 .36472 Mdot
.33335 .36472 Mdot
.39217 .38432 Mdot
.48628 .4902 Mdot
.23531 .47843 Mdot
.83527 .87448 Mdot
.74508 .79606 Mdot
.41569 .39609 Mdot
.04709 .0118 Mdot
.22355 .24316 Mdot
.45883 .47451 Mdot
.85487 .88232 Mdot
.84703 .8784 Mdot
.65881 .76076 Mdot
.43138 .42354 Mdot
.3608 .3059 Mdot
.1412 .18434 Mdot
.57254 .55294 Mdot
.60783 .64705 Mdot
.20787 .47059 Mdot
.82743 .86664 Mdot
.49412 .51765 Mdot
.39217 .37256 Mdot
.30982 .35687 Mdot
.46275 .44314 Mdot
.56862 .58431 Mdot
.1216 .20002 Mdot
.83135 .86272 Mdot
.62352 .66273 Mdot
.41177 .40785 Mdot
.21571 .18042 Mdot
.47451 .49804 Mdot
.21179 .44314 Mdot
.84703 .89017 Mdot
.85487 .88624 Mdot
.37256 .48235 Mdot
.41961 .41569 Mdot
.14513 .02749 Mdot
.40393 .43138 Mdot
.62352 .61176 Mdot
.67057 .6941 Mdot
.85487 .88624 Mdot
.81958 .8588 Mdot
.53725 .55294 Mdot
.39609 .3608 Mdot
.18434 .21179 Mdot
.53333 .52549 Mdot
.84311 .86272 Mdot
.72155 .91369 Mdot
.83919 .87056 Mdot
.78429 .8235 Mdot
.41569 .38824 Mdot
.25884 .26668 Mdot
.4353 .45098 Mdot
.58431 .61176 Mdot
.83135 .8784 Mdot
.85487 .88232 Mdot
.56078 .63136 Mdot
.43138 .41177 Mdot
.15297 .07454 Mdot
.40785 .43922 Mdot
.53333 .6392 Mdot
.6941 .73332 Mdot
.85487 .88624 Mdot
.83135 .87448 Mdot
.55686 .57646 Mdot
.37256 .34511 Mdot
.36472 .40393 Mdot
.50588 .49412 Mdot
.61176 .63528 Mdot
.72155 .85487 Mdot
.85487 .88232 Mdot
.65881 .6941 Mdot
.40785 .39217 Mdot
.13336 .1216 Mdot
.33335 .34511 Mdot
.61568 .64705 Mdot
.78821 .90977 Mdot
.8588 .88624 Mdot
.54509 .64705 Mdot
.45883 .4353 Mdot
.13728 .09023 Mdot
.20787 .251 Mdot
.12944 .46667 Mdot
.98035 .99996 Mdot
.87448 .90193 Mdot
.83919 .90193 Mdot
.58823 .61176 Mdot
.39217 .35687 Mdot
.35687 .40001 Mdot
.56862 .57254 Mdot
.84703 .86664 Mdot
.91761 .94506 Mdot
.85095 .89801 Mdot
.79606 .81958 Mdot
.41177 .39217 Mdot
.32943 .35295 Mdot
.45491 .45098 Mdot
.76469 .81566 Mdot
.91369 .94506 Mdot
.86272 .89801 Mdot
.64705 .72155 Mdot
.47451 .46667 Mdot
.10983 .06278 Mdot
.29413 .3059 Mdot
.14905 .52157 Mdot
.99996 .99996 Mdot
.88232 .91369 Mdot
.77253 .86272 Mdot
.68234 .69802 Mdot
.40393 .36472 Mdot
.29806 .32943 Mdot
.56078 .56078 Mdot
.94898 .96467 Mdot
.91369 .95291 Mdot
.83919 .88232 Mdot
.76469 .79998 Mdot
.44314 .42746 Mdot
.3255 .34119 Mdot
.50196 .50588 Mdot
.87448 .89801 Mdot
.92154 .9882 Mdot
.84703 .88624 Mdot
.35687 .4902 Mdot
.4902 .49412 Mdot
.18434 .11768 Mdot
.19218 .22355 Mdot
.23531 .6392 Mdot
.94506 .95683 Mdot
.84703 .89017 Mdot
.81566 .87056 Mdot
.62352 .64705 Mdot
.42354 .38824 Mdot
.31374 .34119 Mdot
.64705 .65489 Mdot
.99604 .99996 Mdot
.87448 .90977 Mdot
.82743 .87448 Mdot
.4902 .52941 Mdot
.46667 .46275 Mdot
.11376 .1216 Mdot
.57254 .59215 Mdot
.88232 .91369 Mdot
.89409 .9882 Mdot
.83135 .8784 Mdot
.43138 .54902 Mdot
.46275 .46667 Mdot
.23531 .12552 Mdot
.22355 .23924 Mdot
.3059 .69802 Mdot
.52157 .65489 Mdot
.85095 .89017 Mdot
.8235 .89017 Mdot
.53333 .54509 Mdot
.44706 .42746 Mdot
.06278 .10983 Mdot
.76861 .77645 Mdot
.76861 .82743 Mdot
.86664 .90193 Mdot
.83135 .97643 Mdot
.58039 .65489 Mdot
.43922 .43138 Mdot
.18042 .18042 Mdot
.64313 .65097 Mdot
.80782 .85095 Mdot
.81174 .92546 Mdot
.64705 .92938 Mdot
.33335 .63528 Mdot
.50588 .52157 Mdot
.23531 .12944 Mdot
.15297 .22355 Mdot
.23924 .61176 Mdot
.84703 .89409 Mdot
.62352 .90977 Mdot
.18042 .60391 Mdot
.34903 .54509 Mdot
.60783 .6196 Mdot
.22747 .251 Mdot
.69802 .72155 Mdot
.85487 .88624 Mdot
.749 .94506 Mdot
.17257 .5098 Mdot
.09807 .41177 Mdot
.42746 .40785 Mdot
.13336 .13336 Mdot
.6392 .65489 Mdot
.85095 .8784 Mdot
.71763 .94114 Mdot
.43138 .91369 Mdot
.04709 .18042 Mdot
.14905 .38824 Mdot
.12552 .02749 Mdot
.23924 .25884 Mdot
.15689 .41177 Mdot
.70979 .93722 Mdot
.66665 .99996 Mdot
.03141 .08631 Mdot
.03925 .18042 Mdot
.60391 .62352 Mdot
.37648 .41569 Mdot
.62744 .65097 Mdot
.5647 .8784 Mdot
.8588 .99996 Mdot
.03141 .09415 Mdot
.02749 .08239 Mdot
.34119 .47059 Mdot
.25884 .26276 Mdot
.60391 .62744 Mdot
.59607 .86272 Mdot
.83527 .99212 Mdot
.0667 .20394 Mdot
.32158 .3804 Mdot
.03925 .16081 Mdot
.04709 .03141 Mdot
.53333 .57254 Mdot
.54117 .78821 Mdot
.59999 .99604 Mdot
.15689 .48235 Mdot
.53725 .55686 Mdot
4e-05 .02357 Mdot
.37648 .3255 Mdot
.47451 .5098 Mdot
.62744 .74116 Mdot
.4902 .98035 Mdot
.18434 .44706 Mdot
.41961 .52157 Mdot
.57646 .59607 Mdot
.21963 .45883 Mdot
.27845 .28237 Mdot
.64705 .67842 Mdot
.45098 .97251 Mdot
.21571 .47843 Mdot
.06278 .10591 Mdot
.57254 .62744 Mdot
.0118 .05886 Mdot
.20394 .1765 Mdot
.58431 .60391 Mdot
.28237 .84311 Mdot
.27453 .52549 Mdot
.31766 .67842 Mdot
.58039 .64705 Mdot
.13728 .1765 Mdot
.22355 .1765 Mdot
.47451 .50196 Mdot
.21179 .73332 Mdot
.28237 .54117 Mdot
.57254 .99604 Mdot
.59999 .67057 Mdot
4e-05 .0118 Mdot
.6941 .07454 Mdot
.40001 .43922 Mdot
.21963 .6941 Mdot
.22747 .4902 Mdot
.54902 .94898 Mdot
.34903 .45491 Mdot
.31374 .36864 Mdot
.0667 .18042 Mdot
.37648 .40393 Mdot
.20002 .65881 Mdot
.18826 .45098 Mdot
.5098 .9333 Mdot
.05886 .09807 Mdot
.21179 .29021 Mdot
.59607 .63136 Mdot
.43138 .4353 Mdot
.16865 .61176 Mdot
.11376 .52157 Mdot
.44314 .9333 Mdot
.11768 .26668 Mdot
.10591 .20394 Mdot
.42746 .45883 Mdot
.40001 .33335 Mdot
.18042 .58039 Mdot
.1765 .45883 Mdot
.40001 .92154 Mdot
.46667 .95291 Mdot
.04317 .09807 Mdot
.47451 .4902 Mdot
.31374 .21179 Mdot
.1412 .47451 Mdot
.03925 .3059 Mdot
.37256 .89017 Mdot
.66273 .99604 Mdot
.05886 .10983 Mdot
.00396 .04709 Mdot
.55686 .09023 Mdot
.1765 .38824 Mdot
.13336 .33727 Mdot
.33727 .83527 Mdot
.88624 .99996 Mdot
.05102 .12552 Mdot
.00396 .03141 Mdot
.14513 .23924 Mdot
.40393 .47843 Mdot
.10199 .29806 Mdot
.28629 .79213 Mdot
.87448 .98035 Mdot
.0667 .14905 Mdot
.01965 .06278 Mdot
.42354 .50196 Mdot
.38432 .40393 Mdot
.10199 .25884 Mdot
.19218 .70979 Mdot
.64705 .89409 Mdot
.1412 .38824 Mdot
.06278 .18826 Mdot
.02749 .10591 Mdot
.38824 .39609 Mdot
.1216 .34903 Mdot
.23139 .76861 Mdot
.54509 .96075 Mdot
.25492 .68626 Mdot
.12552 .41177 Mdot
.01965 .06278 Mdot
.38432 .36864 Mdot
.11768 .4353 Mdot
.22747 .79213 Mdot
.48235 .97251 Mdot
.27845 .76076 Mdot
.1765 .58431 Mdot
.03141 .05886 Mdot
.36472 .30982 Mdot
.09415 .41961 Mdot
.41569 .95291 Mdot
.41569 .9333 Mdot
.31374 .76861 Mdot
.1961 .62352 Mdot
.03141 .1412 Mdot
.35295 .25884 Mdot
.09415 .41961 Mdot
.25884 .81958 Mdot
.37648 .88624 Mdot
.31766 .72547 Mdot
.24708 .53333 Mdot
.09415 .40393 Mdot
.34903 .24708 Mdot
.10591 .45098 Mdot
.23531 .78037 Mdot
.3608 .86664 Mdot
.38432 .61176 Mdot
.4902 .57646 Mdot
.13336 .47451 Mdot
.34119 .23139 Mdot
.11768 .4902 Mdot
.22355 .749 Mdot
.34119 .83135 Mdot
.52157 .57646 Mdot
.70979 .70979 Mdot
.18826 .39609 Mdot
.34511 .17257 Mdot
.13728 .51765 Mdot
.26276 .78429 Mdot
.34511 .76861 Mdot
.59607 .60391 Mdot
.77253 .77253 Mdot
.35295 .40001 Mdot
.34119 .1216 Mdot
.15297 .54509 Mdot
.23139 .73332 Mdot
.41177 .62744 Mdot
.67057 .6745 Mdot
.78429 .80782 Mdot
.3804 .37256 Mdot
.23531 .07454 Mdot
.14905 .55686 Mdot
.21179 .71371 Mdot
.55294 .57254 Mdot
.8784 .88232 Mdot
.49412 .52549 Mdot
.36472 .34903 Mdot
.07454 .12944 Mdot
.16081 .58039 Mdot
.1412 .61568 Mdot
.59607 .59215 Mdot
.5647 .58823 Mdot
.41961 .37648 Mdot
.34903 .31766 Mdot
.07846 .21571 Mdot
.16081 .58823 Mdot
.21963 .51765 Mdot
.78821 .78821 Mdot
.45098 .40393 Mdot
.39609 .29021 Mdot
.34119 .29806 Mdot
.03533 .09023 Mdot
.14905 .59215 Mdot
.52157 .53333 Mdot
.54902 .58039 Mdot
.41177 .3059 Mdot
.3804 .28629 Mdot
.3255 .28629 Mdot
.09807 .36864 Mdot
.18826 .62352 Mdot
.60783 .59999 Mdot
.43922 .37256 Mdot
.36472 .24316 Mdot
.39609 .30982 Mdot
.3059 .251 Mdot
.13336 .52157 Mdot
.28237 .52549 Mdot
.60783 .63136 Mdot
.39217 .29021 Mdot
.37256 .25884 Mdot
.38432 .28629 Mdot
.27845 .20394 Mdot
.09415 .47843 Mdot
.56078 .57646 Mdot
.3608 .27845 Mdot
.38824 .26276 Mdot
.3608 .25492 Mdot
.36864 .25884 Mdot
.14513 .03533 Mdot
.12944 .53333 Mdot
.76076 .749 Mdot
.40393 .28629 Mdot
.37256 .251 Mdot
.39609 .29413 Mdot
.35687 .251 Mdot
.07846 .15689 Mdot
.1765 .43138 Mdot
.39609 .3804 Mdot
.41569 .31766 Mdot
.36864 .251 Mdot
.3804 .29021 Mdot
.33727 .27845 Mdot
.12552 .45098 Mdot
.56862 .5647 Mdot
.46275 .38432 Mdot
.43922 .33335 Mdot
.37256 .251 Mdot
.37648 .27453 Mdot
.27845 .20002 Mdot
.11768 .49412 Mdot
.68626 .6941 Mdot
.52157 .46275 Mdot
.41961 .32943 Mdot
.35687 .23531 Mdot
.41569 .33335 Mdot
.33727 .24316 Mdot
.15297 .42354 Mdot
.52549 .45491 Mdot
.55686 .49412 Mdot
.39217 .31374 Mdot
.3608 .27453 Mdot
.36864 .28629 Mdot
.1412 .02749 Mdot
.65097 .64313 Mdot
.57254 .59607 Mdot
.45098 .39609 Mdot
.40785 .34903 Mdot
.41569 .3804 Mdot
.34903 .3059 Mdot
.16473 .52549 Mdot
.35687 .31374 Mdot
.42746 .39217 Mdot
.52157 .48235 Mdot
.34119 .32158 Mdot
.37256 .32158 Mdot
.41961 .36472 Mdot
.251 .43138 Mdot
.39609 .28629 Mdot
.41569 .31766 Mdot
.23139 .21571 Mdot
.27061 .24316 Mdot
.44706 .38432 Mdot
.38432 .29806 Mdot
.55686 .54902 Mdot
.38432 .25492 Mdot
.47059 .41961 Mdot
.33335 .3059 Mdot
.22355 .18042 Mdot
.34119 .3059 Mdot
.26668 .6196 Mdot
.40393 .30982 Mdot
.40393 .29021 Mdot
.43138 .40001 Mdot
.39217 .33335 Mdot
.41177 .3608 Mdot
.44314 .40785 Mdot
.45098 .42746 Mdot
.41177 .27453 Mdot
.39609 .33335 Mdot
.51372 .47059 Mdot
.43922 .33335 Mdot
.37648 .32158 Mdot
.65489 .04709 Mdot
.40393 .28629 Mdot
.40001 .25884 Mdot
.70979 .6941 Mdot
.41961 .26668 Mdot
.39609 .3059 Mdot
.50196 .46667 Mdot
.38824 .31766 Mdot
.41177 .29021 Mdot
.40393 .31374 Mdot
.5098 .43922 Mdot
.3804 .26276 Mdot
.42354 .40001 Mdot
.35687 .1765 Mdot
.40785 .28237 Mdot
.39217 .27453 Mdot
.44314 .39217 Mdot
.37256 .251 Mdot
.42354 .3255 Mdot
.54902 .52549 Mdot
.3059 .16865 Mdot
.40393 .27061 Mdot
.78429 .76469 Mdot
.34511 .33335 Mdot
.43138 .3804 Mdot
.59607 .59215 Mdot
.30982 .18826 Mdot
.41569 .29806 Mdot
.40001 .21963 Mdot
.45491 .40393 Mdot
.48235 .43922 Mdot
.62352 .61568 Mdot
.38432 .27845 Mdot
.34119 .14513 Mdot
.36864 .1961 Mdot
.45883 .38824 Mdot
.44706 .37256 Mdot
.52157 .46667 Mdot
.59607 .59607 Mdot
.35687 .27845 Mdot
.43922 .33727 Mdot
.3804 .23531 Mdot
.63136 .64313 Mdot
.48628 .41177 Mdot
.71371 .71763 Mdot
.23924 .16473 Mdot
.41569 .28629 Mdot
.46275 .3608 Mdot
.59999 .57254 Mdot
.53725 .52157 Mdot
.78821 .79606 Mdot
.37256 .19218 Mdot
.40785 .29413 Mdot
.44706 .32158 Mdot
.53725 .42354 Mdot
.64705 .6392 Mdot
.89017 .89409 Mdot
.33727 .07846 Mdot
.41569 .32943 Mdot
.45883 .34511 Mdot
.45883 .29806 Mdot
.59607 .48628 Mdot
.92154 .93722 Mdot
.35687 .09023 Mdot
.39609 .33335 Mdot
.46275 .36864 Mdot
.56078 .42746 Mdot
.89017 .81566 Mdot
.8588 .89017 Mdot
.34511 .1961 Mdot
.38824 .32158 Mdot
.45491 .37648 Mdot
.63136 .55294 Mdot
.99604 .9882 Mdot
.81566 .84703 Mdot
.34903 .30198 Mdot
.4902 .43922 Mdot
.52941 .45098 Mdot
.88232 .84703 Mdot
.99212 .99604 Mdot
.73724 .74116 Mdot
.43138 .38824 Mdot
.47843 .42746 Mdot
.61176 .56078 Mdot
.99212 .99212 Mdot
.87448 .89409 Mdot
.35687 .16473 Mdot
.42746 .3608 Mdot
.57646 .55294 Mdot
.99604 .99212 Mdot
.89409 .90977 Mdot
.76861 .78037 Mdot
.47451 .43138 Mdot
.59607 .58431 Mdot
.99996 .99212 Mdot
.97251 .98035 Mdot
.8235 .82743 Mdot
.45098 .41569 Mdot
.57646 .55294 Mdot
.92154 .92154 Mdot
.97643 .98035 Mdot
.83527 .84311 Mdot
.43138 .38824 Mdot
.60783 .59215 Mdot
.90193 .90585 Mdot
.92154 .92938 Mdot
.83135 .84703 Mdot
.46275 .43138 Mdot
.67057 .66273 Mdot
.9882 .99212 Mdot
.9333 .92938 Mdot
.52549 .44314 Mdot
.53725 .51372 Mdot
.89801 .90585 Mdot
.96075 .96075 Mdot
.85095 .85487 Mdot
.48235 .43922 Mdot
.74508 .74508 Mdot
.96859 .96467 Mdot
.89017 .89017 Mdot
.38824 .25492 Mdot
.72547 .72547 Mdot
.9333 .93722 Mdot
.90193 .90977 Mdot
.4902 .41569 Mdot
.83527 .83919 Mdot
.91761 .92938 Mdot
.77253 .18826 Mdot
.69018 .68626 Mdot
.94114 .94114 Mdot
.78037 .20787 Mdot
.69802 .6745 Mdot
.65881 .59607 Mdot
.49804 .32158 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol00000ogl00?mo00030?mo00<0Oooo103oO`0207ooo`80
ogl000<0Oooo0?mo003oO`00101oool20:0Pl080ogl000<0Oooo0?mo003oO`000`1oool20?mo00h0
Oooo00?o00000?ooO`3oogl0803oogl20:0Pl1@0oomo0P3oO`0R0?ooO`L0ogl0@`3oogl20?mo04<0
oomo0Ol00001ooooo`0000?o00000?mo003oO`001`3oO`000`1oool0ogl00?mo000207ooo`80ogl0
00<0Oooo0?mo003oO`002@1oool30?mo0080Oooo0P3oO`0>07ooo`03ogooool00000oomo0200oomo
0P2P8?0D0?ooO`80ogl03@3oogl20:0Pl1@0oomo1`3oO`0K0?ooO`80X23`9@3oogl20?mo04<0oomo
0Ol00001ooooo`0000?o00000?mo003oO`001`3oO`0207ooo`80X23`00<0Oooo0?mo003oO`003@1o
ool20?mo0080Oooo0`3oO`0=07ooo`;oOooo00?o00000?ooO`3oogl0@`3oogl20:0Pl1D0oomo1P3o
O`0B0?ooO`80ogl01`3oogl30:0Pl6T0oomo0Ol00001ooooo`0000?o00000?mo003oO`000`3oO`04
07ooo`80ogl00P2P8?000`1oool0ogl00?mo000207ooo`80ogl01P1oool20:0Pl0H0Oooo00<0ogl0
0:0Pl02P8?00301oool3ogooo`03o`00003oogl0oomo03D0oomo102P8?0S0?ooO`<0ogl04P3oogl2
0?mo00P0oomo0P2P8?1Y0?ooO`7o00000Oooool00003o`00003oO`00ogl000D0ogl000D0Oooo0?mo
003oO`00ogl007ooo`020?mo00@0Oooo0P3oO`0607ooo`80X23`1`1oool20:0Pl0`0Oooo1?moool0
0ol00000oomo0?ooO`0d0?ooO`@0X23`903oogl20?mo08L0oomo0Ol00001ooooo`0000Co00000:0P
l02P8?00ogl00P2P8?050?mo000307ooo`3oO`00ogl000<0ogl08@1oool5ogooo`03o`00003oogl0
oomo04D0oomo0P2P8?060?ooO`80X23`1P3oogl20:0Pl0l0oomo0P3oO`1l0?ooO`7o00000Oooool0
0003o`00002P8?00X23`00<0X23`103oO`0207ooo`80ogl000@0Oooo0?mo003oO`00Oooo0P3oO`0?
07ooo`80X23`0P1oool30:0Pl0P0Oooo1Omoool00ol00000oomo0?ooO`0B0?ooO`80ogl0703oogl2
0:0Pl1<0oomo0P2P8?060?ooO`80X23`1P3oogl20:0Pl0l0oomo0P3oO`1l0?ooO`7o00000Oooool0
0003o`00002P8?00X23`00<0X23`103oO`0807ooo`80ogl03`1oool20:0Pl080Oooo0`2P8?0807oo
o`KoOooo00?o00000?ooO`3oogl04@3oogl20?mo01`0oomo0P2P8?2b0?ooO`7o00000Oooool00003
o`00002P8?00X23`00D0X23`103oO`020:0Pl0030?mo001oool0Oooo0140Oooo0P3oO`0907ooo`80
ogl00`1oool7ogooo`03o`00003oogl0oomo04/0oomo0P2P8?0D0?ooO`80ogl05P3oogl20:0Pl6L0
oomo0Ol00001ooooo`0000?o00000:0Pl02P8?001P2P8?030?mo0080X23`103oO`0@07ooo`80ogl0
101oool20:0Pl0<0Oooo0P3oO`0307ooo`SoOooo00?o00000?ooO`3oogl0BP3oogl20:0Pl1@0oomo
0P3oO`0F0?ooO`80X23`;`3oogl20:0Pl3H0oomo0Ol00001ooooo`0000?o00000:0Pl02P8?001`2P
8?0;0?mo000307ooo`3oO`00ogl00080ogl03P1oool20:0Pl0P0Oooo2Omoool00ol00000oomo0?oo
O`150?ooO`80X23`9@3oogl20:0Pl3X0oomo0P2P8?0f0?ooO`7o00000Oooool00003o`00002P8?00
X23`00P0X23`00<0ogl00:0Pl02P8?001`3oO`000`1oool0ogl00?mo00040?mo01H0Oooo2Omoool0
0ol00000oomo0?ooO`0C0?ooO`80ogl0<03oogl20:0Pl2D0oomo0P2P8?1b0?ooO`7o00000Oooool0
0003o`00002P8?00X23`0080X23`00<0ogl00:0Pl02P8?000`2P8?000`3oO`00X23`0:0Pl0080?mo
0080Oooo103oO`0F07ooo`[oOooo00?o00000?ooO`3oogl04P3oogl20?mo02X0oomo0P2P8?0l0?oo
O`80X23`2P3oogl20?mo02T0oomo0P3oO`020?ooO`80ogl09P3oogl1o`00007ooooo00000ol00000
X23`0:0Pl0020:0Pl0030?mo002P8?00X23`00D0X23`0`3oO`020:0Pl0H0ogl00P2P8?0H07ooo`_o
Oooo00?o00000?ooO`3oogl04@3oogl20?mo0280oomo0P3oO`060?ooO`80X23`?03oogl20:0Pl0@0
oomo0P3oO`040?ooO`80ogl08`3oogl40:0Pl080oomo0P3oO`020?ooO`80ogl09P3oogl1o`00007o
oooo00000ol00000X23`0:0Pl00:0:0Pl0<0ogl00P2P8?020?mo0080X23`0P3oO`020:0Pl1P0Oooo
3?moool00ol00000oomo0?ooO`060?ooO`80X23`;03oogl20?mo03H0oomo0P3oO`0B0?ooO`80ogl0
:@3oogl40:0Pl2h0oomo0Ol00001ooooo`0000?o00000:0Pl02P8?002`2P8?060?mo0080X23`0P3o
O`00101oool0X23`0:0Pl02P8?0F07ooo`coOooo00?o00000?ooO`3oogl01P3oogl20:0Pl4X0oomo
0P2P8?0H0?ooO`80ogl05@3oogl20?mo05P0oomo0Ol00001ooooo`0000?o00000:0Pl02P8?00202P
8?000`3oO`00X23`0:0Pl00:0?mo000407ooo`2P8?00X23`0:0Pl1H0Oooo3Omoool00ol00000oomo
0?ooO`1A0?ooO`80X23`;`3oogl20?mo05P0oomo0Ol00001ooooo`0000Co000007ooo`1oool0Oooo
0P2P8?020?mo000307ooo`2P8?00X23`00<0X23`00<0Oooo0:0Pl02P8?000P3oO`0207ooo`<0ogl0
00@0Oooo0?mo003oO`00ogl00P1oool20:0Pl180Oooo3_moool00ol00000oomo0?ooO`0J0?ooO`80
ogl0;@3oogl20:0Pl340oomo0P3oO`1M0?ooO`7o00000Oooool00004o`00001oool0Oooo07ooo`80
X23`0P3oO`000`1oool0X23`0:0Pl0030:0Pl0040?mo002P8?00X23`0?mo0080X23`0P3oO`020:0P
l0D0ogl000<0Oooo0:0Pl02P8?004P1oool?ogooo`03o`00003oogl0oomo01T0oomo0P3oO`0T0?oo
O`80ogl01`3oogl20:0Pl340oomo0P3oO`1M0?ooO`7o00000Oooool00003o`00001oool0Oooo00<0
Oooo2@2P8?030?mo0080X23`0P3oO`020:0Pl080ogl000<0Oooo0?mo003oO`005@1oool@ogooo`03
o`00003oO`00ogl003h0oomo0P3oO`2I0?ooO`7o00000Oooool00003o`00001oool0Oooo00<0Oooo
2`2P8?001@3oO`00X23`0:0Pl03oO`00Oooo00@0ogl04@1oool20:0Pl0D0Oooo4?moool20:0Pl003
0?mo003oogl0oomo07X0oomo0P3oO`030?ooO`80X23`EP3oogl1o`00007ooooo00000ol00000Oooo
07ooo`0407ooo`X0X23`103oO`020:0Pl00307ooo`3oO`00ogl00080ogl03`1oool20:0Pl0D0Oooo
4?moool20:0Pl1/0oomo0P2P8?1P0?ooO`80ogl00`3oogl20:0Pl5H0oomo0Ol00001ooooo`0000?o
000007ooo`1oool00`1oool;0:0Pl0@0ogl00P2P8?000`3oO`00X23`0:0Pl0020?mo0080X23`1`1o
ool20?mo0080Oooo0P3oO`020:0Pl0D0Oooo4_moool00ol00000oomo0?ooO`0H0?ooO`80X23`?@3o
ogl20:0Pl0T0oomo0P2P8?0N0?ooO`80X23`<P3oogl20?mo01l0oomo0Ol00001ooooo`0000?o0000
07ooo`1oool00`1oool40:0Pl00307ooo`2P8?00X23`0080Oooo0P2P8?000`3oO`00X23`0:0Pl004
0?mo0080X23`0P3oO`020:0Pl0030?mo001oool0Oooo00@0Oooo0P3oO`0207ooo`80ogl00P2P8?05
07ooo`80ogl04Omoool00ol00000oomo0?ooO`1F0?ooO`80X23`2@3oogl20:0Pl1h0oomo0P2P8?0b
0?ooO`80ogl07`3oogl1o`00007ooooo00000ol00000Oooo07ooo`0507ooo`T0X23`00@0ogl00:0P
l02P8?00X23`1P3oO`0207ooo`030?mo002P8?00X23`00H0Oooo0P2P8?0:07ooo`80ogl04Omoool0
0ol00000oomo0?ooO`0M0?ooO`80X23`=`3oogl20:0Pl7h0oomo0Ol00001ooooo`0000?o000007oo
o`1oool01@1oool70:0Pl00307ooo`3oO`00X23`00D0X23`103oO`0307ooo`80X23`103oO`0207oo
o`<0X23`2@1ooolDogooo`03o`00003oogl0oomo01`0oomo0P2P8?0g0?ooO`80X23`;@3oogl20?mo
04l0oomo0Ol00001ooooo`0000?o000007ooo`1oool01@1oool30:0Pl00307ooo`2P8?00X23`0080
Oooo00D0ogl00:0Pl02P8?00X23`0?mo00020:0Pl080Oooo0P3oO`0407ooo`D0ogl00`1oool20:0P
l0T0Oooo5Omoool00ol00000oomo0?ooO`230?ooO`80ogl0C`3oogl1o`00007ooooo00000ol00000
Oooo07ooo`0607ooo`80ogl00P2P8?0307ooo`H0X23`0P3oO`020:0Pl00307ooo`3oO`00ogl001D0
Oooo5_moool00ol00000oomo0?ooO`3C0?ooO`7o00000Oooool00003o`00001oool0Oooo00H0Oooo
0P3oO`020:0Pl0030?mo001oool0X23`00X0X23`00<0Oooo0?mo003oO`000P1oool00`3oO`00X23`
0:0Pl00@07oooaOoOooo00?o00000?ooO`3oogl0dP3oogl1o`00007ooooo00000ol00000Oooo07oo
o`0407ooo`80X23`0`1oool20?mo000307ooo`2P8?00X23`00@0X23`00<0ogl00:0Pl02P8?000`3o
O`0407ooo`030?mo002P8?00X23`0100Oooo6?moool00ol00000oomo0?ooO`210?ooO`80ogl0CP3o
ogl1o`00007ooooo00000ol00000Oooo07ooo`0407ooo`80X23`1P1oool60:0Pl0P0ogl000@0Oooo
0?mo003oO`00ogl00P1oool20?mo00d0Oooo6?moool00ol00000oomo0?ooO`0D0?ooO`80ogl0E@3o
ogl20:0Pl1@0oomo0P3oO`1>0?ooO`7o00000Oooool00003o`00001oool0Oooo00d0Oooo1@2P8?00
0`1oool0ogl00?mo00090?mo000407ooo`2P8?00X23`0?mo0080Oooo0P3oO`0707ooo`80ogl06Omo
ool00ol00000oomo0?ooO`0C0?ooO`80ogl0E@3oogl20:0Pl6@0oomo0Ol00001ooooo`0000?o0000
07ooo`1oool03P1oool50:0Pl080Oooo0P3oO`0207ooo`<0ogl00P2P8?00103oO`00X23`0:0Pl03o
O`0207ooo`80ogl01P1oool30?mo00;oOooo0P2P8?0Fogooo`03o`00003oogl0oomo0<l0oomo0Ol0
0001ooooo`0000?o000007ooo`1oool0401oool01@3oO`00X23`0:0Pl02P8?00Oooo00@0ogl000<0
Oooo0?mo003oO`000P2P8?00103oO`00Oooo0?mo003oO`020:0Pl0@0Oooo0P2P8?0207ooo`80ogl0
00<0Ooooogoooomoool00P2P8?0Gogooo`03o`00003oogl0oomo0140oomo0P2P8?1H0?ooO`80X23`
6@3oogl20?mo04H0oomo0Ol00001ooooo`0000?o000007ooo`1oool02P1oool20:0Pl0D0Oooo0`2P
8?000`1oool0ogl00?mo00020?mo000307ooo`3oO`00ogl000<0X23`0P3oO`00101oool0X23`0:0P
l01oool20?mo000307ooo`2P8?00X23`0080ogl00`1oool@ogooo`80X23`2_moool00ol00000oomo
0?ooO`0@0?ooO`80X23`F03oogl20:0Pl1T0oomo0P3oO`160?ooO`7o00000Oooool00003o`00001o
ool0Oooo00X0Oooo0P2P8?0907ooo`80ogl00`1oool20?mo000307ooo`2P8?00X23`0080ogl0101o
ool20?mo00<0Oooo0P3oO`0307oooa3oOooo0P2P8?0:ogooo`03o`00003oogl0oomo0<d0oomo0Ol0
0001ooooo`0000?o000007ooo`1oool03@1oool20:0Pl080Oooo102P8?001@1oool0ogl00?mo003o
O`00Oooo0080X23`0`1oool40?mo000307ooo`3oO`00ogl00080Oooo0P3oO`0507ooo`WoOooo0P2P
8?05ogooo`80X23`2omoool00ol00000oomo0?ooO`3<0?ooO`7o00000Oooool00003o`00001oool0
Oooo00d0Oooo202P8?00101oool0ogl00?mo003oO`040:0Pl0030?mo001oool0ogl00080ogl00P2P
8?020?mo0080Oooo0`3oO`0407ooo`WoOooo0P2P8?05ogooo`80X23`3?moool00ol00000oomo0?oo
O`3;0?ooO`7o00000Oooool000;o0000401oool20:0Pl0D0Oooo0P2P8?000`1oool0X23`0:0Pl002
0:0Pl080ogl00P1oool30:0Pl0L0ogl000@0Oooo0?mo003oO`00Oooo7omoool00ol00000oomo0?oo
O`3:0?ooO`7o00000Oooool00004o`000?ooogoo0000o`0000@0Oooo0P2P8?0>07ooo`030?mo002P
8?00X23`00H0X23`00<0ogl007ooo`2P8?000P2P8?000`1oool0ogl00?mo00040?mo0080Oooo0P3o
O`000`1oooooOoooogooo`0Mogooo`03o`00003oogl0oomo07h0oomo0P3oO`1:0?ooO`7o00000Ooo
ool00005o`000?ooogoooomoooooOol000000`1oool20:0Pl0h0Oooo0P3oO`020:0Pl00307ooo`2P
8?00X23`0080X23`0P1oool30:0Pl00307ooo`3oO`00ogl00080ogl01P1oool20?mo00?oOooo0P3o
O`000omoool0ogl00?mo000Gogooo`03o`00003oogl0oomo00`0oomo0P2P8?1_0?ooO`80ogl0BP3o
ogl1o`00007ooooo00000ol0003ooomoooooO`02ooooO`03o`00001oool0Oooo00X0Oooo0P2P8?08
07ooo`80ogl0101oool40:0Pl0D0Oooo0P3oO`0407ooo`80ogl00omoool20?mo0003ogooo`3oO`00
ogl001SoOooo00?o00000?ooO`3oogl02`3oogl20:0Pl;/0oomo0Ol00001ooooo`0000?o0000oooo
Ooooogl00oooogl00ol00000Oooo07ooo`0907ooo`80X23`201oool20?mo00@0Oooo0P2P8?0707oo
o`80ogl000D0Oooo0?mo002P8?00X23`07ooo`020?mo023oOooo00?o00000?ooO`3oogl0PP3oogl2
0?mo04<0oomo0Ol00001ooooo`0000?o0000ooooOoooogl01?ooogl00ol00000Oooo07ooo`0;07oo
o`80X23`1`1oool20?mo00L0Oooo0P3oO`0407ooo`80ogl00P2P8?030?mo023oOooo00?o00000?oo
O`3oogl0C03oogl20:0Pl3@0oomo0P3oO`130?ooO`7o00000Oooool00003o`000?ooogoooomo00Go
oomo0_l0000;07ooo`80X23`1`1oool20?mo00L0Oooo0P3oO`0407ooo`80ogl00P1oool20?mo02;o
Oooo00?o00000?ooO`3oogl0B`3oogl20:0Pl7T0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0
1oooogl20:0Pl0h0Oooo0P3oO`0F07ooo`?oOooo0P3oO`0Oogooo`03o`00003oogl0oomo0<D0oomo
0Ol00001ooooo`0000?o0000ooooOoooogl01oooogl20:0Pl0h0Oooo0P3oO`0307ooo`80ogl0101o
ool20:0Pl0H0Oooo0P3oO`0207ooo`80X23`0_moool20?mo00SoOooo0P3oO`02ogooo`80X23`4_mo
ool00ol00000oomo0?ooO`0;0?ooO`80X23`]`3oogl1o`00007ooooo00000ol0003ooomoooooO`09
ooooO`;o00004@1oool20:0Pl080Oooo102P8?0607ooo`80ogl00P1oool20:0Pl0?oOooo0P3oO`07
ogooo`80ogl00_moool20:0Pl17oOooo0P2P8?0=0?ooO`80X23`]`3oogl1o`00007ooooo00000ol0
003ooomoooooO`0;ooooO`04o`00001oool0X23`0:0Pl0d0Oooo0P2P8?0207ooo`D0X23`1@1oool0
0`3oO`00X23`0:0Pl00207ooo`CoOooo0P3oO`0?ogooo`80ogl03Omoool20:0Pl003o`00003oogl0
oomo00L0oomo0P2P8?0D0?ooO`80ogl0Y03oogl1o`00007ooooo00000ol0003ooomoooooO`0<oooo
O`03o`00002P8?00X23`00d0Oooo0`2P8?020?mo000407ooo`2P8?00X23`0:0Pl0D0Oooo00<0ogl0
0:0Pl02P8?000P1oool2ogooo`80ogl00omoool20:0Pl080ogl00_moool20:0Pl0KoOooo0P3oO`00
0omoool0X23`0:0Pl00=ogooo`03o`00003oogl0oomo00H0oomo0P2P8?000`3oogl0X23`0:0Pl00A
0?ooO`80ogl0Y03oogl1o`00007ooooo00000ol0003ooomoooooO`07ooooO`@0X23`0_ooogl2o`00
0080X23`2`1oool50:0Pl080Oooo102P8?0807ooo`80X23`0`3oO`040:0Pl080ogl0102P8?09ogoo
o`80X23`3_moool00ol00000oomo0?ooO`080?ooO`80X23`]`3oogl1o`00007ooooo00000ol0003o
oomoooooO`07ooooO`@0X23`1?ooogl20:0Pl080Oooo0P2P8?0607ooo`<0X23`00<0Oooo0:0Pl02P
8?000`1oool80:0Pl080Oooo00<0ogl00:0Pl02P8?000P2P8?00103oO`00X23`0:0Pl?moool20?mo
0003ogooo`2P8?00X23`0080X23`6Omoool00ol00000oomo0?ooO`0[0?ooO`80ogl0U03oogl1o`00
007ooooo00000ol0003ooomoooooO`0>ooooO`@0X23`00<0Oooo0:0Pl02P8?001P1oool20:0Pl080
Oooo0P3oO`0;0:0Pl080Oooo0P3oO`000omoool0X23`0:0Pl0030?mo0004ogooo`3oO`00ogl0ogoo
o`80ogl04_moool20?mo00GoOooo0P2P8?000omooooo00000?ooO`0[0?ooO`80ogl0DP3oogl20:0P
l400oomo0Ol00001ooooo`0000?o0000ooooOoooogl03_ooogl40:0Pl003o`00001oool0Oooo00X0
Oooo0P3oO`030:0Pl0/0Oooo0omoool40?mo0004ogooo`3oO`00ogl0ogooo`80ogl04_moool20?mo
00GoOooo0P2P8?02ogooo`03o`00003oogl0oomo07d0oomo0P2P8?100?ooO`7o00000Oooool00003
o`000?ooogoooomo01?ooomo00?o000007ooo`1oool01@1oool20:0Pl180Oooo2omoool00`3oO`00
X23`0:0Pl00Mogooo`03o`00003oogl0oomo00X0oomo0P2P8?0=0?ooO`80ogl0X`3oogl1o`00007o
oooo00000ol0003ooomoooooO`09ooooO`80X23`2Oooogl2o`0000D0Oooo0P2P8?0307ooo`80X23`
3@1oool9ogooo`<0ogl00P2P8?000`3oO`00X23`0:0Pl0020?mo00KoOooo0P2P8?0@ogooo`03o`00
003oogl0oomo0080oomo0P2P8?040?ooO`@0X23`3@3oogl20?mo02h0oomo0P2P8?1c0?ooO`7o0000
0Oooool00003o`000?ooogoooomo00Wooomo0P2P8?0;ooooO`03o`00001oool0Oooo0080Oooo0P2P
8?0207ooo`<0X23`101oool20?mo00L0Oooo2Omoool20?mo00;oOooo0P3oO`020:0Pl080ogl000?o
Oooo0?mo003oO`000omoool20:0Pl0;oOooo0P2P8?0=ogooo`04o`00003oogl0oomo0?ooO`80X23`
103oogl20:0Pl100oomo0P3oO`0]0?ooO`80X23`L`3oogl1o`00007ooooo00000ol0003ooomooooo
O`09ooooO`80X23`1?ooogl20:0Pl0Cooomo0P2P8?000ol00000Oooo07ooo`030:0Pl080Oooo0P2P
8?0407ooo`<0ogl00P1oool20:0Pl0030?mo001oool0Oooo00;oOooo0P2P8?09ogooo`80ogl000?o
Oooo0?mo003oO`000_moool20?mo00OoOooo0P2P8?0>ogooo`03o`00003oogl0oomo01P0oomo0P3o
O`1T0?ooO`80X23`?03oogl1o`00007ooooo00000ol0003ooomoooooO`0?ooooO`80X23`00Cooomo
0:0Pl02P8?3ooomo0P2P8?000oooogoo0000o`0000020:0Pl0T0Oooo0P3oO`0307ooo`80X23`00<0
ogl007ooo`1oool00P3oO`020:0Pl0;oOooo0P2P8?04ogooo`80ogl01_moool20?mo0003ogooo`3o
O`00ogl000CoOooo0P2P8?0?ogooo`03o`00003oogl0oomo07`0oomo0`2P8?0l0?ooO`7o00000Ooo
ool00003o`000?ooogoooomo01;ooomo0P2P8?06ooooO`03o`00001oool0Oooo00P0Oooo0P2P8?05
07ooo`80X23`00<0Oooo0?mo003oO`000P2P8?020?mo0080X23`1?moool00`3oO`00X23`0:0Pl005
ogooo`80ogl000?oOooo0?mo003oO`003_moool20:0Pl0GoOooo00?o00000?ooO`3oogl0O03oogl2
0:0Pl0T0oomo0P3oO`0b0?ooO`7o00000Oooool00003o`000?ooogoooomo01;ooomo0P2P8?07oooo
O`03o`00001oool0Oooo00L0Oooo0P2P8?000`3oO`00Oooo07ooo`040:0Pl00307oooomoooooOooo
0080X23`0P3oO`06ogooo`030?mo002P8?00X23`0080X23`00<0ogl0ogoooomoool01@3oO`07ogoo
o`80ogl01Omoool20:0Pl0030?mo0?moooooOooo00?oOooo00?o00000?ooO`3oogl0<@3oogl20:0P
l5<0oomo0P3oO`0b0?ooO`7o00000Oooool00003o`000?ooogoooomo00Kooomo0P2P8?0:ooooO`80
X23`2?ooogl00ol00000Oooo07ooo`0607ooo`<0ogl000D0Oooo0:0Pl02P8?00X23`07ooo`020?mo
00?oOooo0P3oO`07ogooo`030?mo002P8?00X23`0080X23`0P3oO`001?moool0ogl00?mo003oO`02
ogooo`80X23`1?moool30?mo00KoOooo0P3oO`06ogooo`03o`00003oogl0oomo00`0oomo0P2P8?0R
0?ooO`80X23`Q`3oogl1o`00007ooooo00000ol0003ooomoooooO`06ooooO`80X23`5Oooogl00ol0
0000Oooo07ooo`0507ooo`80ogl00P1oool20:0Pl080Oooo0P3oO`0?ogooo`@0ogl01_moool20:0P
l0CoOooo0P3oO`0@ogooo`03o`00003oogl0oomo00/0oomo0P2P8?2[0?ooO`7o00000Oooool00003
o`000?ooogoooomo01gooomo0P2P8?000ol00000Oooo07ooo`0607ooo`80X23`1@1oool4ogooo`80
X23`0omoool20?mo00GoOooo0P3oO`09ogooo`80ogl05Omoool00ol00000oomo0?ooO`2g0?ooO`7o
00000Oooool00003o`000?ooogoooomo01gooomo0P2P8?000oooogoo000007ooo`0607ooo`80X23`
1@1oool20:0Pl0;oOooo0P2P8?02ogooo`80X23`00@0ogl0ogooo`3oO`00ogl00_moool20?mo00Wo
Oooo0P3oO`000omoool0ogl00?mo000Cogooo`03o`00003oogl0oomo0180oomo0P3oO`2R0?ooO`7o
00000Oooool00003o`000?ooogoooomo01Sooomo0P2P8?07ooooO`03o`00001oool0Oooo00/0Oooo
0P2P8?06ogooo`80X23`00<0ogl0ogooo`3oO`000P2P8?07ogooo`030?mo002P8?00X23`00GoOooo
0P3oO`0?ogooo`80X23`0_moool00ol00000oomo0?ooO`0B0?ooO`80ogl0XP3oogl1o`00007ooooo
00000ol0003ooomoooooO`0<ooooO`80X23`0oooogl20:0Pl0;ooomo0P2P8?000oooogl0X23`0:0P
l008ooooO`;o00002`1oool9ogooo`80X23`0_moool20:0Pl005ogooo`2P8?00X23`0?mo0?moool0
0`3oO`020:0Pl1KoOooo0P2P8?02ogooo`80X23`1@3oogl20:0Pl;00oomo0Ol00001ooooo`0000?o
0000ooooOoooogl03?ooogl20:0Pl0?ooomo0P2P8?02ooooO`80X23`2_ooogl20:0Pl004ooooOol0
0000X23`0:0Pl0@0Oooo0P2P8?0207ooo`WoOooo0P2P8?02ogooo`80X23`00GoOooo0:0Pl02P8?00
ogl0ogooo`040?mo00?oOooo0P2P8?02ogooo`80ogl04_moool20:0Pl003o`00003oogl0oomo0080
oomo0P2P8?0<0?ooO`80ogl00P3oogl20?mo09h0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0
8Oooogl20:0Pl0;ooomo0P2P8?0407ooo`80X23`0P1oool5ogooo`80ogl01_moool20:0Pl0030?mo
0?moooooOooo00;oOooo0P3oO`02ogooo`D0X23`0_moool20?mo00coOooo0P2P8?06ogooo`80X23`
4@3oogl20?mo0080oomo0P3oO`2N0?ooO`7o00000Oooool00003o`000?ooogoooomo01gooomo0P2P
8?08ooooO`03o`00001oool0Oooo00D0Oooo0omoool20:0Pl080ogl01_moool20:0Pl0030?mo0?mo
ooooOooo00;oOooo0P3oO`02ogooo`@0X23`1?moool20?mo00KoOooo0P3oO`03ogooo`80X23`0P3o
O`020:0Pl0;oOooo0P2P8?000ol00000oomo0?ooO`2b0?ooO`7o00000Oooool00003o`000?ooogoo
oomo01gooomo0P2P8?09ooooO`03o`00001oool0Oooo00@0Oooo0omoool20:0Pl0?oOooo0P2P8?04
ogooo`80X23`0P3oO`0=ogooo`<0ogl00_moool20:0Pl004ogooo`3oO`00ogl00?mo00GoOooo0P3o
O`040:0Pl003ogooo`2P8?00X23`0080X23`0P3oogl20?mo0:h0oomo0Ol00001ooooo`0000?o0000
ooooOoooogl0:Oooogl2o`0000@0Oooo2?moool20:0Pl0CoOooo0P2P8?020?mo00goOooo0P3oO`03
ogooo`80X23`00?oOooo0?mo003oO`002_moool20:0Pl003ogooo`2P8?00X23`0080X23`0P3oogl2
0?mo0:h0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0:oooogl01?l00000Oooo07ooo`1oool7
ogooo`80X23`1Omoool20:0Pl0CoOooo0`2P8?07ogooo`80X23`0P3oO`000omoool0ogl00?mo000?
ogooo`80X23`0omoool00ol00000oomo0:0Pl0020:0Pl0<0oomo0P3oO`2Y0?ooO`7o00000Oooool0
0003o`000?ooogoooomo00Wooomo0P2P8?000oooogl0X23`0:0Pl00;ooooO`80X23`2?ooogl20:0P
l0Oooomo00?o000007ooo`1oool00omoool20:0Pl0;oOooo0P2P8?03ogooo`80ogl00P2P8?000omo
ool0X23`0:0Pl0040:0Pl0CoOooo0P2P8?000omoool0X23`0:0Pl0020?mo0003ogooo`3oO`00ogl0
00goOooo202P8?001Ol00000X23`0:0Pl02P8?00oomo0080X23`0P3oO`0=0?ooO`80ogl0VP3oogl1
o`00007ooooo00000ol0003ooomoooooO`09ooooO`80X23`00?ooomo0:0Pl02P8?002oooogl20:0P
l0Sooomo0P2P8?08ooooO`;o00000omoool20:0Pl0CoOooo0P2P8?000omoool0ogl00?mo0003ogoo
o`<0X23`00?oOooo0:0Pl02P8?001P2P8?000omoool0X23`0:0Pl0020?mo00GoOooo0P2P8?02ogoo
o`80ogl01Omoool20:0Pl0;oOooo202P8?000`3oogl0X23`0:0Pl0040?mo00/0oomo0P3oO`2J0?oo
O`7o00000Oooool00003o`000?ooogoooomo01gooomo0P2P8?0@ooooO`;o00001omoool20:0Pl0co
Oooo102P8?020?mo0003ogooo`2P8?00X23`00OoOooo0P2P8?02ogooo`030?mo002P8?00X23`00co
Oooo102P8?050?ooO`80ogl00P2P8?2U0?ooO`7o00000Oooool00003o`000?ooogoooomo01gooomo
0P2P8?0@ooooO`80oomo00?o0000ogoooomoool02?moool20?mo00SoOooo102P8?03ogooo`80ogl0
3?moool20:0Pl0koOooo00?o00000?ooO`3oogl00P3oogl20:0Pl080oomo0P2P8?120?ooO`80ogl0
H@3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooO`80oomo0P2P8?09ogooo`<0ogl000?o
Oooo0:0Pl02P8?001?moool00`3oO`00X23`0:0Pl0030:0Pl004ogooo`2P8?00X23`ogooo`80ogl0
4Omoool20:0Pl0030?mo0?moooooOooo0080X23`0P3oO`020:0Pl080oomo102P8?140?ooO`80ogl0
H@3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooO`80oomo0P2P8?02o`0000SoOooo0P3o
O`001?moool0X23`0:0Pl03oO`020:0Pl005ogooo`3oO`00X23`0:0Pl03oO`000P2P8?001?moool0
X23`0:0Pl?moool20?mo0080X23`2?moool20:0Pl0;oOooo0P3oO`030:0Pl0030?mo0?moooooOooo
00H0X23`0`3oogl00`3oO`00X23`0:0Pl02W0?ooO`7o00000Oooool00003o`000?ooogoooomo02oo
oomo1P3oogl00ol0003oOoooogooo`02ogooo`80X23`1Omoool20?mo00@0X23`0omoool40:0Pl0?o
Oooo0`2P8?08ogooo`80X23`0_moool20?mo00<0X23`1?moool00`3oO`00X23`0:0Pl0020?mo00<0
oomo0P2P8?2X0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo1`3oogl01?l0003oOooo
ogoooomoool20:0Pl0OoOooo102P8?05ogooo`80X23`0omoool20:0Pl1WoOooo0P3oO`000ol00000
oomo0?ooO`020:0Pl:P0oomo0Ol00001ooooo`0000?o0000ooooOoooogl05_ooogl20:0Pl1Oooomo
203oogl00ol0003oOoooogooo`0<ogooo`030?mo002P8?00X23`00OoOooo0P3oO`06ogooo`<0X23`
2_moool20:0Pl080ogl00`2P8?001?moool0X23`0:0Pl?l000020:0Pl0030?ooO`2P8?00X23`0:H0
oomo0Ol00001ooooo`0000?o0000ooooOoooogl03oooogl20:0Pl0Gooomo0P2P8?0GooooO`T0oomo
0P2P8?07ogooo`80X23`0omoool00`3oO`00X23`0:0Pl0020:0Pl0GoOooo0P3oO`06ogooo`<0X23`
00<0ogl0ogoooomoool00P3oO`05ogooo`80X23`0P3oO`060:0Pl003ogooo`2P8?00X23`00<0X23`
;@3oogl20:0Pl7L0oomo0Ol00001ooooo`0000?o0000ooooOoooogl03oooogl20:0Pl1kooomo2@3o
ogl20:0Pl003o`000?moooooOooo00CoOooo0P2P8?03ogooo`80ogl0102P8?000omoool0X23`0:0P
l003ogooo`80ogl01_moool20?mo00;oOooo0P3oO`09ogooo`80X23`00GoOooo0:0Pl02P8?00X23`
ogooo`040:0Pl2h0oomo0P2P8?1g0?ooO`7o00000Oooool00003o`000?ooogoooomo01Wooomo0P2P
8?05ooooO`80X23`3Oooogl<0?ooO`03o`000?moooooOooo00[oOooo102P8?000omoool0X23`0:0P
l003ogooo`80X23`2_moool20:0Pl0[oOooo0P2P8?001Omoool0X23`0:0Pl?moool0ogl000@0X23`
2P3oogl20:0Pl0L0oomo0P3oO`2A0?ooO`7o00000Oooool00003o`000?ooogoooomo01Wooomo0P2P
8?05ooooO`80X23`3Oooogl20?ooO`80X23`2@3oogl01?l0003oOoooogoooomoool20?mo00KoOooo
0P2P8?04ogooo`80X23`0_moool20:0Pl0?oOooo0P2P8?03ogooo`80ogl0102P8?08ogooo`80X23`
1_moool00`3oO`00X23`0:0Pl0040?ooO`80ogl0103oogl20:0Pl0@0oomo0P3oO`000`3oogl0ogl0
0?mo002A0?ooO`7o00000Oooool00003o`000?ooogoooomo00Oooomo0P2P8?0VooooO`80oomo0P2P
8?0:0?ooO`;o000000?oOooo0?mo003oO`001omoool30:0Pl0;oOooo1P2P8?000omoool0X23`0:0P
l0020:0Pl005ogooo`2P8?00X23`0:0Pl03oO`00102P8?000omoool0X23`0:0Pl003ogooo`80ogl0
0omoool20:0Pl0?oOooo0P2P8?020?mo00<0oomo0P3oO`0:0?ooO`80ogl0U03oogl1o`00007ooooo
00000ol0003ooomoooooO`07ooooO`80X23`3?ooogl20:0Pl1Sooomo403oogl00ol0003oOoooogoo
o`07ogooo`D0X23`00<0ogl00:0Pl02P8?001P2P8?000`3oO`3oOoooogooo`030:0Pl003ogooo`2P
8?00X23`0080X23`00CoOooo0:0Pl02P8?00X23`0_moool20?mo00?oOooo0P2P8?000omoool0X23`
0:0Pl0020:0Pl0<0ogl0303oogl20?mo09H0oomo0Ol00001ooooo`0000?o0000ooooOoooogl03_oo
ogl20:0Pl0Gooomo0P2P8?0CooooO`80X23`0oooogl80?ooO`<0X23`00<0oomo0:0Pl02P8?000`3o
ogl00ol0003oOoooogooo`06ogooo`80X23`00CoOooo0:0Pl02P8?00ogl01P2P8?030?mo00[oOooo
102P8?06ogooo`H0X23`00?oOooo0?mo003oO`000P3oO`0<0?ooO`80ogl000<0oomo0?mo003oO`00
T`3oogl1o`00007ooooo00000ol0003ooomoooooO`0>ooooO`80X23`6_ooogl20:0Pl0?ooomo203o
ogl30:0Pl0030?ooO`2P8?00X23`00@0oomo00?o0000ogoooomoool01Omoool20?mo00?oOooo0P3o
O`02ogooo`80X23`0_moool20?mo00[oOooo0P2P8?08ogooo`H0X23`0omoool00ol00000oomo0?oo
O`0>0?ooO`80ogl0T`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOa<0oomo0_l00006
ogooo`H0X23`0_moool20:0Pl0_oOooo0`2P8?09ogooo`80X23`1_moool20:0Pl003ogooo`3oO`00
ogl00:<0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooooglE0?ooO`04o`000?moooooOooo
ogooo`P0X23`00GoOooo0:0Pl02P8?00X23`0?mo0007ogooo`H0X23`1Omoool30:0Pl004ogooo`2P
8?00X23`0?mo00GoOooo0P2P8?000omoool0ogl00?mo00040?ooO`80X23`2`3oogl20?mo0080X23`
SP3oogl1o`00007ooooo00000ol0003ooomoooooO`0CooooO`80X23`6_oooglF0?ooO`80X23`00?o
Oooo0:0Pl02P8?000_moool30:0Pl0;oOooo102P8?02ogooo`80ogl00omoool40:0Pl0OoOooo0`2P
8?001?moool0X23`0:0Pl03oO`07ogooo`80X23`00?oOoooo`00003oogl00P3oogl20:0Pl0/0oomo
0P3oO`020:0Pl8h0oomo0Ol00001ooooo`0000?o0000ooooOoooogl04oooogl20:0Pl0Gooomo0P2P
8?0CooooOaH0oomo0P2P8?000ol0003oOoooogooo`06ogooo`D0X23`0_moool20?mo00?oOooo0P3o
O`02ogooo`<0ogl01?moool30:0Pl080ogl00_moool40?mo0003ogooo`2P8?00X23`0080X23`0_mo
ool01?l00000oomo0:0Pl02P8?0>0?ooO`80ogl0SP3oogl1o`00007ooooo00000ol0003ooomooooo
O`0JooooO`80X23`4ooooglB0?ooO`80X23`1@3oogl00ol0003oOoooogooo`05ogooo`D0X23`0_mo
ool20:0Pl0?oOooo0P2P8?000omoool0X23`0:0Pl0020?mo00CoOooo102P8?000`3oO`00X23`0:0P
l0020:0Pl080ogl000CoOooo0:0Pl02P8?00X23`0P3oO`000omooooo00000:0Pl0020:0Pl0h0oomo
0P3oO`2>0?ooO`7o00000Oooool00003o`000?ooogoooomo02;ooomo0P2P8?0;ooooOa80oomo0P2P
8?060?ooO`04o`000?moooooOoooogooo`80X23`0omoool20:0Pl003ogooo`2P8?00X23`0080X23`
00<0ogl0ogoooomoool00P2P8?000omoool0X23`0:0Pl004ogooo`80ogl00_moool20:0Pl003ogoo
o`2P8?00X23`0080X23`0omoool20:0Pl005ogooo`3oO`00ogl0ogooo`3oO`000P2P8?000`3oogl0
ogl00?mo002L0?ooO`7o00000Oooool00003o`000?ooogoooomo02;ooomo0P2P8?0;ooooOaH0oomo
102P8?00103oogoo0000ogoooomoool20:0Pl003ogooo`2P8?00X23`00?oOooo0`2P8?000`3oO`00
X23`0:0Pl0020:0Pl0CoOooo0P2P8?02ogooo`80ogl01omoool20?mo00WoOooo00@0ogl00:0Pl02P
8?00oomo0P3oO`2L0?ooO`7o00000Oooool00003o`000?ooogoooomo02Wooomo0P2P8?02ooooO`80
X23`5P3oogl40:0Pl0040?ooO`2P8?00X23`o`0000?oOooo0P2P8?04ogooo`80X23`00?oOooo0:0P
l02P8?000P2P8?00103oO`3oOoooogoooomoool20:0Pl0;oOooo1P2P8?05ogooo`80ogl00_moool2
0?mo00KoOooo00?o00000?mo003oO`000P2P8?2J0?ooO`7o00000Oooool00003o`000?ooogoooomo
02Wooomo0P2P8?02ooooO`80X23`603oogl20:0Pl0050?ooO`2P8?00X23`0?ooOol000003Omoool2
0:0Pl0030?mo0?moooooOooo00GoOooo1P2P8?05ogooo`80ogl00_moool20?mo00KoOooo00?o0000
0?mo003oO`000P2P8?2J0?ooO`7o00000Oooool00003o`000?ooogoooomo01oooomo0P2P8?0>oooo
Oal0oomo0_l0000:ogooo`@0X23`1_moool20:0Pl0;oOooo0P3oO`07ogooo`80X23`2?moool60?mo
0080oomo0P3oO`020?ooO`80ogl0TP3oogl1o`00007ooooo00000ol0003ooomoooooO`0OooooO`80
X23`3_ooogl20?ooO`80X23`7@3oogl00ol0003oOoooogooo`07ogooo`@0X23`0_moool20?mo00;o
Oooo0`2P8?000omoool0ogl00?mo0007ogooo`80X23`0P3oO`05ogooo`/0ogl00P3oogl20?mo0080
oomo0P3oO`2>0?ooO`7o00000Oooool00003o`000?ooogoooomo02gooomo0P2P8?020?ooO`80X23`
5`3oogl20:0Pl0D0oomo0_l00002ogooo`@0X23`00CoOooo0:0Pl02P8?00ogl00omoool20:0Pl003
ogooo`3oO`00ogl00080X23`00?oOooo0?mo002P8?00102P8?05ogooo`80ogl01Omoool20?mo0003
ogooo`3oO`00ogl000D0ogl01`3oogl20?mo08h0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0
;Oooogl20:0Pl1@0oomo102P8?030?ooO`80X23`1`3oogl00ol0003oOooo0:0Pl0030:0Pl0;oOooo
0P3oO`03ogooo`80X23`00?oOooo0?mo003oO`000`3oO`070:0Pl0?oOooo0P2P8?02ogooo`80X23`
1omoool00`3oO`00X23`0:0Pl0020?mo09L0oomo0Ol00001ooooo`0000?o0000ooooOoooogl08Ooo
ogl20:0Pl0Wooomo0P2P8?000oooogl0oomo0?ooO`0B0?ooO`@0X23`3@3oogl2o`000080X23`0omo
ool20:0Pl0?oOooo0P3oO`000omoool0X23`0:0Pl0030?mo0100X23`1Omoool30?mo0080X23`0`3o
O`0=0?ooO`80ogl0Q`3oogl1o`00007ooooo00000ol0003ooomoooooO`0HooooO`80X23`1oooogl2
0:0Pl0Wooomo0P2P8?000oooogl0oomo0?ooO`0;0?ooO`80X23`603oogl20:0Pl0?oOooo0P2P8?06
ogooo`80X23`00<0ogl0ogoooomoool00_moool20:0Pl0;oOooo102P8?00103oO`3oOooo0:0Pl02P
8?020?mo00CoOooo103oO`020:0Pl0<0ogl03@3oogl20?mo08L0oomo0Ol00001ooooo`0000?o0000
ooooOoooogl06?ooogl20:0Pl1Gooomo3@3oogl20:0Pl1D0oomo0P3oO`000`3oogl0X23`0:0Pl006
ogooo`D0X23`00?oOooo0?mo003oO`000_moool60:0Pl0?oOooo0P3oO`03ogooo`<0ogl000?oOooo
0:0Pl02P8?000P2P8?020?mo0080X23`103oO`000`3oogl0ogl00?mo002B0?ooO`7o00000Oooool0
0003o`000?ooogoooomo02Gooomo0P2P8?08ooooO`H0oomo0P2P8?0K0?ooO`80X23`00@0ogl00:0P
l02P8?00oomo0_l000000omoool0X23`0:0Pl0060:0Pl0;oOooo0P3oO`000omoool0X23`0:0Pl004
0:0Pl0;oOooo0P2P8?02ogooo`80X23`00CoOooo0?mo003oO`3oOooo1P2P8?02ogooo`<0ogl00P2P
8?020?mo01H0oomo0`2P8?1i0?ooO`7o00000Oooool00003o`000?ooogoooomo02Gooomo0P2P8?08
ooooO`H0oomo0P2P8?0K0?ooO`80X23`00<0oomo0:0Pl02P8?000`3oogl01?l00000X23`0:0Pl02P
8?07ogooo`80ogl000?oOooo0:0Pl02P8?000_moool20:0Pl0;oOooo0P2P8?02ogooo`80X23`1omo
ool00`3oO`00X23`0:0Pl002ogooo`80ogl000<0oomo0:0Pl02P8?00603oogl30:0Pl7T0oomo0Ol0
0001ooooo`0000?o0000ooooOoooogl0;ooooglY0?ooO`80X23`00<0oomoo`000?moool03Omoool2
0:0Pl0030?mo002P8?00X23`00H0X23`0P3oO`040:0Pl0?oOooo0`3oO`000omoool0ogl00?mo0003
0?mo09@0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogl;0?ooO`80X23`0`3oogl20:0P
l0/0oomo0P2P8?0:0?ooO`80X23`0P3oogl01?l0003oOoooogoooomoool20:0Pl0SoOooo2`2P8?02
0?mo00@0X23`00?oOooo0:0Pl02P8?000P3oO`020:0Pl0H0ogl01P3oogl20?mo00@0oomo0P3oO`25
0?ooO`7o00000Oooool00003o`000?ooogoooomo02Cooomo102P8?06ooooO`80X23`2P3oogl20:0P
l0<0oomo0P2P8?0;0?ooO`80X23`3@3oogl20:0Pl0;o0000102P8?04ogooo`P0X23`0_moool=0:0P
l004ogooo`2P8?00X23`0:0Pl0H0ogl0103oogl40?mo00@0oomo0P3oO`080?ooO`80X23`N`3oogl1
o`00007ooooo00000ol0003ooomoooooO`0QooooO`80X23`00?ooomo0:0Pl02P8?00102P8?04oooo
O`80X23`403oogl20:0Pl1T0oomo0P2P8?000`3oogl0X23`0:0Pl0030:0Pl0CoOooo202P8?000omo
ool0X23`0:0Pl00;0:0Pl0;oOooo0P2P8?050?mo0003ogooool00000oomo00<0oomo0P3oO`0@0?oo
O`80X23`N`3oogl1o`00007ooooo00000ol0003ooomoooooO`0QooooO`80X23`1Oooogl20:0Pl0Go
oomo0`3oogl20:0Pl0X0oomo102P8?0L0?ooO`80X23`00?o0000ogoooomoool01Omoool20?mo0003
ogooo`2P8?00X23`00<0ogl01@2P8?001Omoool0X23`0:0Pl03oO`3oOooo00D0X23`1@3oO`03ogoo
o`03o`00002P8?00X23`0080oomo0P3oO`0=0?ooO`80X23`OP3oogl1o`00007ooooo00000ol0003o
oomoooooO`0/ooooO`80X23`00Cooomo0?ooO`3oogl0oomo0P2P8?0:0?ooO`80X23`803oogl40:0P
l0040?mo0?moooooOoooogooo`D0X23`0`3oO`090:0Pl004ogooo`2P8?00X23`ogooo`80X23`00<0
ogl00:0Pl02P8?000P3oO`04ogooo`80X23`00@0oomo0?mo003oO`00ogl03@3oogl20:0Pl7h0oomo
0Ol00001ooooo`0000?o0000ooooOoooogl05oooogl20:0Pl1?ooomo0P2P8?001?ooogl0oomo0?oo
O`3oogl20:0Pl1`0oomo1@2P8?000`3oogl0X23`0:0Pl0080?ooO`H0X23`0_moool40:0Pl0CoOooo
2@2P8?020?mo00;oOooo1@2P8?030?mo00CoOooo00Co00000?ooO`3oO`00ogl06@3oogl20:0Pl7<0
oomo0Ol00001ooooo`0000?o0000ooooOoooogl05oooogl20:0Pl1Kooomo2@3oogl20:0Pl1H0oomo
1@2P8?000`3oogl0X23`0:0Pl00<0?ooO`80X23`0_moool40:0Pl0;oOooo0P3oO`000omoool0X23`
0:0Pl0020:0Pl0040?mo002P8?00X23`ogooo`80ogl01@2P8?03ogooo`80ogl01Omoool00ol00000
oomo0?ooO`0@0?ooO`80X23`0`3oogl20?mo0080oomo0P2P8?1c0?ooO`7o00000Oooool00003o`00
0?ooogoooomo02oooomo2@3oogl20:0Pl2/0oomo00?o0000ogoooomoool01_moool20?mo00;oOooo
0`2P8?000omoool0X23`0:0Pl003ogooo`80X23`3_moool00ol00000oomo0?ooO`0?0?ooO`80X23`
0`3oogl20?mo07L0oomo0Ol00001ooooo`0000?o0000ooooOoooogl06?ooogl20:0Pl0Kooomo0P2P
8?07ooooO`80X23`1?ooogle0?ooO`80ogl000?o00000?mo003oO`002Omoool20:0Pl0;oOooo0`2P
8?0>ogooo`80X23`0omoool00ol00000oomo0?ooO`0>0?ooO`<0X23`N`3oogl1o`00007ooooo0000
0ol0003ooomoooooO`0HooooO`80X23`1_ooogl20:0Pl0Oooomo0P2P8?04ooooOcD0oomo0P3oO`00
103oogl0ogl00:0Pl02P8?02ogooo`80X23`1?moool70:0Pl004ogooo`2P8?00X23`ogooo`80X23`
1?moool20?mo00;oOooo0`2P8?02ogooo`03o`00003oogl0oomo0080ogl0303oogl40:0Pl0X0oomo
0P2P8?1^0?ooO`7o00000Oooool00003o`000?ooogoooomo01Oooomo0P2P8?0FooooOa80oomo0P2P
8?0U0?ooO`80X23`0_moool30:0Pl005ogooo`2P8?00X23`0?mo0?moool0102P8?000`3oO`3oOooo
0:0Pl0050:0Pl0?oOooo0P2P8?030?mo0080X23`0omoool01?l00000oomo0?mo003oO`030?ooO`80
X23`2@3oogl20:0Pl0X0oomo0P2P8?1^0?ooO`7o00000Oooool00003o`000?ooogoooomo01Oooomo
0P2P8?0?ooooO`80X23`1OoooglB0?ooO`80X23`2`3oogl20:0Pl1P0oomo0P2P8?000ol00000X23`
0:0Pl0020:0Pl005ogooo`2P8?00X23`0:0Pl03oO`001@2P8?02ogooo`D0X23`0omoool20:0Pl080
ogl01omoool00ol00000oomo0?ooO`030?ooO`@0X23`1P3oogl20:0Pl7/0oomo0Ol00001ooooo`00
00?o0000ooooOoooogl0:?ooogl20:0Pl0Gooomo7`3oogl20:0Pl180oomo0P2P8?040?ooO`80X23`
00<0oomo0:0Pl02P8?000P2P8?000omoool0X23`0:0Pl0070:0Pl0;oOooo1@2P8?02ogooo`80ogl0
00CoOooo0:0Pl02P8?3oOooo0P3oO`05ogooo`03o`00003oogl0oomo00@0oomo0`2P8?040?ooO`<0
X23`N`3oogl1o`00007ooooo00000ol0003ooomoooooO`0^ooooO`80X23`503oogl20:0Pl0P0oomo
0P2P8?030?ooO`80X23`3@3oogl20:0Pl0T0oomo0P2P8?000omoool0X23`0:0Pl0020:0Pl0GoOooo
1P2P8?000omoool0X23`0:0Pl0050:0Pl003ogooo`3oO`00ogl000KoOooo00?o00000?ooO`3oogl0
103oogl20:0Pl0@0oomo0P2P8?050?ooO`80X23`M@3oogl1o`00007ooooo00000ol0003ooomooooo
O`0MooooO`80X23`3oooogl20:0Pl0<0oomo0P2P8?0?0?ooO`80X23`203oogl20:0Pl0<0oomo0P2P
8?0I0?ooO`03o`000?moool0X23`00<0X23`00?oOooo0:0Pl02P8?003`2P8?00103oO`3oOooo0?mo
003oO`07ogooo`80X23`1P3oogl20:0Pl0<0oomo0P2P8?040?ooO`80X23`M@3oogl1o`00007ooooo
00000ol0003ooomoooooO`0MooooO`80X23`4?ooogl40?ooO`80X23`:`3oogl20:0Pl0P0oomo0P2P
8?020?ooO`D0X23`0_moool=0:0Pl0?oOooo00<0ogl00:0Pl02P8?000P2P8?04ogooo`80X23`00?o
Oooo0:0Pl02P8?001P3oogl20:0Pl0<0oomo0P2P8?040?ooO`80X23`1@3oogl30:0Pl080oomo0P2P
8?1Y0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo<@3oogl20:0Pl0P0oomo0P2P8?02
0?ooO`D0X23`1?moool90:0Pl080ogl01?moool40:0Pl0CoOooo0P2P8?02ogooo`03o`00003oogl0
oomo00l0oomo0P2P8?050?ooO`<0X23`0P3oogl20:0Pl6T0oomo0Ol00001ooooo`0000?o0000oooo
Ooooogl0;oooogl90?ooO`80X23`103oogl20:0Pl380oomo00?o0000ogoooomoool00_moool20:0P
l0CoOooo00<0ogl00:0Pl02P8?000P2P8?07ogooo`80X23`0_moool20?mo0003ogooo`2P8?00X23`
0080X23`3@3oogl20:0Pl0D0oomo0P2P8?1a0?ooO`7o00000Oooool00003o`000?ooogoooomo02oo
oomo0P3oogl20:0Pl0D0oomo0P2P8?040?ooO`80X23`<@3oogl20:0Pl003o`000?moooooOooo00<0
X23`00?oOooo0?mo003oO`001P2P8?06ogooo`040?mo002P8?00X23`ogooo`<0ogl000?oOooo0:0P
l02P8?000P2P8?000ol00000oomo0?ooO`060?ooO`040?mo002P8?00X23`0?ooO`80X23`1@3oogl2
0:0Pl740oomo0Ol00001ooooo`0000?o0000ooooOoooogl06_ooogl20:0Pl0Cooomo0P2P8?0=oooo
O`80oomo0`2P8?0S0?ooO`80X23`603oogl20:0Pl0030?ooOol00000X23`0080X23`00CoOooo0:0P
l02P8?00ogl01P2P8?000omoool0X23`0:0Pl0020:0Pl003ogooo`3oO`00ogl000;oOooo0P3oO`02
0:0Pl0CoOooo0P2P8?000`3oogl0X23`0:0Pl0020:0Pl080oomo00<0ogl00:0Pl02P8?00N`3oogl1
o`00007ooooo00000ol0003ooomoooooO`0JooooO`80X23`1?ooogl20:0Pl0gooomo0`3oogl20:0P
l2<0oomo0P2P8?070?ooO`80X23`1@3oogl20:0Pl0`0oomo0P2P8?02ogooo`80X23`00?oOooo0:0P
l02P8?00102P8?000omoool0X23`0:0Pl0020:0Pl0;oOooo0P2P8?03ogooo`80X23`0_moool40:0P
l0030?ooO`2P8?00X23`0080X23`2`3oogl30:0Pl780oomo0Ol00001ooooo`0000?o0000ooooOooo
ogl0;_ooogl20:0Pl0/0oomo0P2P8?0H0?ooO`80X23`2@3oogl20:0Pl0D0oomo0P2P8?080?ooO`80
ogl00`3oogl20:0Pl0OoOooo00<0ogl00:0Pl02P8?000`2P8?000`3oO`3oOooo0:0Pl0030:0Pl004
ogooo`2P8?00X23`0?mo0080X23`00<0ogl00:0Pl02P8?000_moool01?l00000X23`0:0Pl03oogl2
0:0Pl0X0oomo0`2P8?1b0?ooO`7o00000Oooool00003o`000?ooogoooomo02kooomo0P2P8?020?oo
O`80X23`1`3oogl20:0Pl0`0oomo0P2P8?0:0?ooO`80X23`6P3oogl20?mo00<0oomo0P2P8?000ol0
003oOoooogooo`020:0Pl0<0ogl01P2P8?000`3oO`00X23`0:0Pl0020:0Pl004ogooo`2P8?00X23`
ogooo`@0X23`1?moool00ol00000oomo0?ooO`020:0Pl0D0oomo0P2P8?030?ooO`@0X23`L@3oogl1
o`00007ooooo00000ol0003ooomoooooO`0QooooO`80X23`3?ooogl30?ooO`80X23`5@3oogl20:0P
l1H0oomo0P2P8?0D0?ooO`80X23`0_l000020:0Pl080ogl000?oOooo0:0Pl02P8?00102P8?000`3o
O`00X23`0:0Pl0020?mo0004ogooo`2P8?00X23`ogooo`80ogl00P2P8?05ogooo`03o`00003oogl0
oomo00@0oomo102P8?050?ooO`80X23`0P3oogl20:0Pl6d0oomo0Ol00001ooooo`0000?o0000oooo
Ooooogl08Oooogl20:0Pl0cooomo203oogl20:0Pl2D0oomo0P2P8?000`3oogl0X23`0:0Pl00D0?oo
O`80X23`0P3oogl00ol0003oOooo0:0Pl0040:0Pl0;oOooo0P2P8?000`3oO`00X23`0:0Pl003ogoo
o`X0X23`0_moool00ol00000oomo0?ooO`040?ooO`80X23`2`3oogl20:0Pl6d0oomo0Ol00001oooo
o`0000?o0000ooooOoooogl0;oooogl80?ooO`80X23`9@3oogl20:0Pl1`0oomo00?o00000:0Pl02P
8?000`2P8?03ogooo`80ogl01_moool40:0Pl003ogooo`2P8?00X23`0080X23`0omoool00ol00000
oomo0?ooO`1o0?ooO`7o00000Oooool00003o`000?ooogoooomo02;ooomo102P8?09ooooOc<0oomo
0P2P8?0A0?ooO`<0X23`1@3oogl2o`000080X23`1?moool20:0Pl004ogooo`2P8?00X23`ogooo`<0
X23`0P3oO`000omoool0X23`0:0Pl007ogooo`03o`00003oO`00ogl000D0oomo102P8?0<0?ooO`80
X23`I`3oogl1o`00007ooooo00000ol0003ooomoooooO`0GooooO`80X23`2Oooogl40:0Pl0Wooomo
2`3oogl20:0Pl0<0oomo0P2P8?0Q0?ooO`80X23`2@3oogl20:0Pl0030?ooO`2P8?00X23`00<0oomo
0`2P8?070?ooO`80X23`0_moool70:0Pl003ogooo`2P8?00X23`0080X23`00@0ogl0ogooo`2P8?00
X23`1omoool00ol00000ogl00?mo00020?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?020?ooO`80
X23`203oogl20:0Pl0D0oomo0P3oO`1P0?ooO`7o00000Oooool00003o`000?ooogoooomo01Oooomo
0P2P8?0@ooooO`80X23`1?ooogl;0?ooO`@0X23`00<0oomo0:0Pl02P8?009P3oogl20:0Pl0@0oomo
0P2P8?000`3oogl0X23`0:0Pl00>0?ooO`03o`000?moooooOooo00L0X23`0_moool30:0Pl0;oOooo
0P2P8?000omoool0X23`0:0Pl005ogooo`04o`00003oogl0oomo0?ooO`D0X23`0`3oogl30:0Pl0D0
oomo0P2P8?080?ooO`80ogl0H03oogl1o`00007ooooo00000ol0003ooomoooooO`0YooooO`80X23`
1?ooogl=0?ooO`80X23`603oogl20:0Pl0<0oomo0P2P8?0:0?ooO`80X23`3@3oogl20:0Pl0@0oomo
0P2P8?030?ooO`03o`000?moool0X23`00L0X23`0_moool30:0Pl004ogooo`2P8?00X23`0?mo0080
X23`0omoool40:0Pl0030?ooO`2P8?00X23`00H0X23`00<0oomo0:0Pl02P8?001P3oogl20:0Pl6X0
oomo0Ol00001ooooo`0000?o0000ooooOoooogl07Oooogl20:0Pl13ooomo3P3oogl20:0Pl1L0oomo
0P2P8?030?ooO`80X23`1@3oogl20:0Pl0l0oomo0P2P8?000`3oogl0X23`0:0Pl0040?ooO`80X23`
103oogl2o`0000d0X23`00?oOooo0?mo003oO`000P3oO`03ogooo`@0X23`00?o00000:0Pl02P8?00
0P2P8?001@3oogl0X23`0:0Pl02P8?00oomo0080X23`LP3oogl1o`00007ooooo00000ol0003ooomo
ooooO`0MooooO`80X23`4?ooogl>0?ooO`80X23`8`3oogl20:0Pl0`0oomo0P2P8?001@3oogl0X23`
0:0Pl02P8?00oomo0080ogl00`3oogl20:0Pl0D0oomo00<0ogl00:0Pl02P8?003P2P8?02ogooo`80
X23`00<0ogl00:0Pl02P8?000P2P8?001?l00000oomo0:0Pl02P8?020?ooO`80X23`0P3oogl20:0P
l0d0oomo0P2P8?1S0?ooO`7o00000Oooool00003o`000?ooogoooomo01gooomo0P2P8?0@ooooOb<0
oomo0P2P8?0L0?ooO`80X23`0P3oogl40:0Pl0040?mo002P8?00X23`0?ooO`<0X23`103oogl01@3o
O`00X23`0:0Pl03oO`3oOooo0080X23`0omoool20:0Pl0030?mo002P8?00X23`0080X23`0_moool2
0:0Pl0030?mo002P8?00X23`0080X23`00CoOoooo`00002P8?00X23`1P3oogl20:0Pl080oomo0P2P
8?020?ooO`80X23`1@3oogl20:0Pl6<0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooooglS
0?ooO`80X23`803oogl40:0Pl0030?ooO`2P8?00X23`0080oomo0P2P8?040?ooO`<0X23`00<0ogl0
0:0Pl02P8?001Omoool40:0Pl080ogl0102P8?001Omoool0X23`0:0Pl02P8?3oOooo0080ogl000?o
00000:0Pl02P8?00103oogl;0:0Pl0L0oomo0P2P8?1Q0?ooO`7o00000Oooool00003o`000?ooogoo
oomo02oooomoA@3oogl30:0Pl080oomo0P3oO`080?ooO`<0X23`00<0ogl00:0Pl02P8?001Omoool4
0:0Pl080ogl0102P8?02ogooo`80X23`00CoOooo0?mo003oO`3oOooo0P2P8?040?ooO`T0X23`2@3o
ogl20:0Pl640oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogl[0?ooO`80X23`903oogl2
0:0Pl0L0oomo0_l000030:0Pl004ogooo`2P8?00X23`0?mo0080X23`00?oOooo0:0Pl02P8?001omo
ool20:0Pl004ogooool00000oomo0?ooO`80X23`00<0oomo0:0Pl02P8?000P3oogl20:0Pl0<0oomo
0P2P8?070?ooO`80X23`H03oogl1o`00007ooooo00000ol0003ooomoooooO`0]ooooO`80X23`:`3o
ogl20:0Pl1@0oomo0P3oO`0>0?ooO`H0X23`1@3oogl60:0Pl0040?mo002P8?00X23`ogooo`<0X23`
00?oOooo0:0Pl02P8?000omoool80:0Pl0030?ooO`2P8?00X23`0080oomo102P8?00103oogl0X23`
0:0Pl03oogl20:0Pl0@0oomo0P2P8?1P0?ooO`7o00000Oooool00003o`000?ooogoooomo02gooomo
0P2P8?110?ooO`80ogl0403oogl40:0Pl0030?ooO`2P8?00X23`0080ogl000<0oomo0?mo003oO`00
0P2P8?05ogooo`H0X23`1Omoool40:0Pl0P0oomo0`2P8?030?ooO`<0X23`IP3oogl1o`00007ooooo
00000ol0003ooomoooooO`0SooooO`80X23`2_ooogl<0?ooO`80X23`;P3oogl20:0Pl180oomo0P2P
8?060?ooO`@0X23`0`3oogl20:0Pl0GoOooo1`2P8?03ogooo`80X23`0omoool01Ol00000oomo0:0P
l02P8?00ogl00080X23`00<0oomo0:0Pl02P8?000`2P8?00103oogl0X23`0:0Pl02P8?1V0?ooO`7o
00000Oooool00003o`000?ooogoooomo01cooomo0P2P8?04ooooO`<0X23`00?ooomo0:0Pl02P8?00
1oooogl<0?ooO`80X23`4@3oogl20:0Pl1/0oomo0P2P8?070?ooO`80X23`103oogl40:0Pl0030?oo
O`2P8?00X23`00D0oomo1@2P8?000`3oogl0ogl00:0Pl0020:0Pl0KoOooo0`2P8?000omoool0X23`
0:0Pl002ogooo`030?mo002P8?00X23`00CoOooo00Co00000:0Pl02P8?00ogl00P2P8?000`3oogl0
X23`0:0Pl0030:0Pl6X0oomo0Ol00001ooooo`0000?o0000ooooOoooogl07?ooogl20:0Pl0Cooomo
0P2P8?02ooooO`80X23`0oooogl20:0Pl0;ooomo6`3oogl20:0Pl0040?ooO`2P8?00X23`0:0Pl2@0
oomo0P2P8?040?ooO`H0X23`1P3oogl50:0Pl0050?ooO`3oO`00X23`0:0Pl03oogl00P2P8?03ogoo
o`H0X23`0_moool40:0Pl0GoOooo0P2P8?020?mo0080oomo0P2P8?020?ooO`@0X23`I`3oogl1o`00
007ooooo00000ol0003ooomoooooO`0[ooooO`80X23`0_oooglK0?ooO`80X23`00<0oomo0:0Pl02P
8?00503oogl20:0Pl1T0oomo0P2P8?000`3oO`00oomo0?ooO`050?ooO`<0X23`0`3oogl20?mo0080
X23`0omoool<0:0Pl0GoOooo0P2P8?040?ooO`80X23`0P3oogl40:0Pl6L0oomo0Ol00001ooooo`00
00?o0000ooooOoooogl08Oooogl20:0Pl0cooomo503oogl20:0Pl1T0oomo0P2P8?030?ooO`80X23`
3@3oogl20:0Pl0D0oomo0P2P8?040?ooO`80ogl01`3oogl20:0Pl0<0oomo0`3oO`001@3oogl0X23`
0:0Pl?moool0ogl000P0X23`1?moool30:0Pl0?oOooo102P8?00103oogl0X23`0:0Pl02P8?0:0?oo
O`80X23`H03oogl1o`00007ooooo00000ol0003ooomoooooO`0QooooO`80X23`3?oooglD0?ooO`80
X23`6@3oogl20:0Pl180oomo0P2P8?050?ooO`80X23`4P3oogl20?mo0080oomo0P2P8?000ol00000
ogl00:0Pl0050:0Pl0KoOooo0`2P8?03ogooo`@0X23`0P3oogl20:0Pl0X0oomo0P2P8?1P0?ooO`7o
00000Oooool00003o`000?ooogoooomo02oooomoG`3oogl20:0Pl0050?mo003oogl0oomo0?ooOol0
00001Omoool30:0Pl003ogooo`2P8?00X23`00CoOooo1P2P8?000`3oogl0X23`0:0Pl0050?ooO`80
X23`I`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOah0oomo0P2P8?090?ooO`80X23`
<@3oogl20:0Pl0050?ooO`2P8?00X23`0?mo003oogl00P2P8?000`3oogoo0000o`000002ogooo`05
0?mo002P8?00X23`0:0Pl?moool00P2P8?02ogooo``0X23`00@0oomo0:0Pl02P8?00oomo0`2P8?1V
0?ooO`7o00000Oooool00003o`000?ooogoooomo02Sooomo0P2P8?05ooooOah0oomo0P2P8?090?oo
O`80X23`1P3oogl20:0Pl2<0oomo0P2P8?00103oogl0ogl00?mo003oogl20:0Pl0030?ooO`2P8?00
X23`0080oomo0P2P8?001P3oogl0X23`0:0Pl?l0003oOooo0?mo0080X23`0_moool70:0Pl0030?mo
0?moool0X23`00H0X23`00@0oomo0:0Pl02P8?00oomo102P8?1U0?ooO`7o00000Oooool00003o`00
0?ooogoooomo02Sooomo0P2P8?05ooooOc40oomo0P2P8?0E0?ooO`80X23`303oogl20:0Pl0040?oo
O`3oO`00ogl00?ooO`80X23`00<0oomo0:0Pl02P8?001@3oogl20:0Pl0040?mo0?l0003oOoooogoo
o`80X23`00?oOooo0:0Pl02P8?001@2P8?00103oO`3oOoooogoooomoool20:0Pl003ogooool00000
oomo0080oomo0P2P8?00103oogl0X23`0:0Pl02P8?090?ooO`80X23`FP3oogl1o`00007ooooo0000
0ol0003ooomoooooO`0_ooooOb<0oomo0P2P8?0S0?ooO`80X23`4P3oogl20:0Pl080oomo0P3oO`05
0?ooO`L0X23`00?oOooo0:0Pl02P8?001@2P8?00103oO`00X23`0:0Pl?moool60:0Pl0030?ooO`2P
8?00X23`00@0X23`2@3oogl20:0Pl5X0oomo0Ol00001ooooo`0000?o0000ooooOoooogl09_ooogl2
0:0Pl0Oooomo8`3oogl20:0Pl3L0oomo0P3oO`020:0Pl080ogl01@3oogl70:0Pl003ogooo`2P8?00
X23`00D0X23`00<0ogl00:0Pl02P8?000_moool50:0Pl080oomo1@2P8?050?ooO`80X23`GP3oogl1
o`00007ooooo00000ol0003ooomoooooO`0VooooO`80X23`1oooogmN0?ooO`80X23`1`3oogl40:0P
l080ogl000CoOooo0:0Pl02P8?00ogl00omoool50:0Pl080ogl00`2P8?000`3oO`3o00000:0Pl002
0:0Pl0030?ooO`2P8?00X23`0080X23`00@0oomo0:0Pl02P8?00oomo0P2P8?1N0?ooO`7o00000Ooo
ool00003o`000?ooogoooomo02oooomoIP3oogl20?mo00040?ooO`3oO`00ogl00?ooO`H0X23`0_mo
ool50:0Pl080ogl000?oOooo0:0Pl02P8?000_moool30:0Pl0<0oomo0P2P8?000`3oogl0X23`0:0P
l01Q0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomoIP3oogl20?mo00040?ooO`3oO`00
ogl00?ooO`80X23`00Co00000:0Pl02P8?00X23`2_moool20:0Pl0;oOooo0P2P8?1Z0?ooO`7o0000
0Oooool00003o`000?ooogoooomo02oooomoE03oogl20:0Pl0`0oomo0P3oO`070?ooO`80ogl000<0
oomo0?mo003oO`000P3oO`03ogooo`80X23`1omoool20:0Pl003ogooool00000oomo06T0oomo0Ol0
0001ooooo`0000?o0000ooooOoooogl0;oooogmD0?ooO`80X23`303oogl20?mo0080oomo0P2P8?03
0?ooO`80X23`00<0oomo0?mo002P8?000P2P8?02ogooo`030?mo002P8?00X23`00;oOooo0P2P8?03
ogooo`80X23`0_moool50:0Pl6D0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogmI0?oo
O`80X23`1`3oogl20:0Pl080oomo0P2P8?030?ooO`L0X23`00Go00000:0Pl02P8?00ogl0ogooo`04
0:0Pl0030?mo002P8?00X23`0080X23`0_moool50:0Pl0<0oomo0`2P8?060?ooO`80X23`0`3oogl2
0:0Pl580oomo0Ol00001ooooo`0000?o0000ooooOoooogl0:_ooogl20:0Pl0?ooomo0P2P8?1C0?oo
O`80X23`0P3oogl20:0Pl0L0oomo0P2P8?020?ooO`80ogl00P3oogl70:0Pl0040?ooO`3oO`00X23`
0:0Pl0;oOooo102P8?000`3oO`00X23`0:0Pl0020:0Pl0?oOooo0P2P8?020?ooO`80X23`00@0oomo
0:0Pl02P8?00X23`1P3oogl20:0Pl0<0oomo0P2P8?1B0?ooO`7o00000Oooool00003o`000?ooogoo
oomo02[ooomo0P2P8?02ooooO`<0X23`D`3oogl40:0Pl0h0oomo0P3oO`000`3oogl0X23`0:0Pl002
0?ooO`@0X23`00<0ogl00:0Pl02P8?000P2P8?001Omoool0X23`0:0Pl02P8?00ogl000;oOooo2`2P
8?060?ooO`80X23`3@3oogl20:0Pl4`0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0:_ooogl2
0:0Pl0;ooomo0P2P8?1F0?ooO`80X23`3P3oogl20?mo00D0oomo1P2P8?000`3oO`00X23`0:0Pl003
0:0Pl0;oOooo00@0ogl00:0Pl02P8?00ogl0202P8?060?ooO`<0X23`3@3oogl20:0Pl4`0oomo0Ol0
0001ooooo`0000?o0000ooooOoooogl09_ooogl20:0Pl0;ooomo0P2P8?03ooooOel0oomo0P2P8?06
0?ooO`80X23`0`3oogl80:0Pl0030?mo002P8?00X23`00<0X23`00?oOooo0:0Pl02P8?000P2P8?00
0omoool0X23`0:0Pl0020:0Pl0;oOooo0P3oO`00103oogl0X23`0:0Pl02P8?020?ooO`<0X23`103o
ogl20:0Pl5D0oomo0Ol00001ooooo`0000?o0000ooooOoooogl09_ooogl20:0Pl0OooomoG`3oogl2
0:0Pl0H0oomo0P2P8?020?ooO`<0X23`0`3oO`030:0Pl0030?ooO`2P8?00X23`00<0X23`00CoOooo
0:0Pl02P8?00ogl00P2P8?020?mo00@0X23`0_moool01?l00000X23`0:0Pl02P8?040?ooO`80X23`
0`3oogl20:0Pl5D0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogm[0?ooO`80X23`0P3o
ogl20?mo00<0X23`0`3oogl30:0Pl004o`000?moooooOoooogooo`80X23`0omoool30:0Pl0?oOooo
00?o00000:0Pl02P8?00103oogl20:0Pl5X0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooo
ogm_0?ooO`80ogl0103oogl40?mo0080oomo0`2P8?00103oO`3oOooo0:0Pl02P8?02ogooo`<0X23`
0omoool2o`0000H0oomo0P2P8?1H0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo0P2P
8?1]0?ooO`80ogl000<0oomo0:0Pl02P8?000P2P8?001@3oO`00X23`0:0Pl02P8?00ogl000`0X23`
1?moool20:0Pl0030?ooO`2P8?00X23`0080oomo0P2P8?040?ooO`80X23`0P3oogl20:0Pl4h0oomo
0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogl20:0Pl6<0oomo0P2P8?090?ooO`H0X23`00@0
oomo0:0Pl02P8?00X23`0P3oO`00103oogoo00000:0Pl02P8?020?mo00@0X23`0omoool40:0Pl003
o`00002P8?00X23`00H0oomo102P8?020?ooO`80X23`CP3oogl1o`00007ooooo00000ol0003ooomo
ooooO`0/ooooO`80X23`00?ooomo0?ooO`3oogl03`3oogl20:0Pl2P0oomo0P2P8?0F0?ooO`80X23`
403oogl20:0Pl0T0oomo1`2P8?050?ooO`@0ogl00P2P8?020?mo00@0X23`00?oOooo0:0Pl02P8?00
0P3oO`000omooooo00000?ooO`020?ooO`80X23`0P3oogl40:0Pl580oomo0Ol00001ooooo`0000?o
0000ooooOoooogl09?ooogl20:0Pl0Kooomo0P2P8?000oooogl0oomo0?ooO`0?0?ooO`80X23`:03o
ogl20:0Pl1H0oomo0P2P8?0O0?ooO`<0X23`0`3oogl60?mo0080X23`0P3oO`000omoool0X23`0:0P
l0020:0Pl003ogooo`3oO`00ogl000?oOooo00?o00000?ooO`3oogl00`2P8?020?ooO`<0X23`DP3o
ogl1o`00007ooooo00000ol0003ooomoooooO`0TooooO`80X23`2OoooglI0?ooO`80X23`G@3oogl3
0?mo0080X23`0`3oogl20:0Pl080ogl000?oOooo0:0Pl02P8?000P2P8?000omoool0ogl00?mo0004
ogooo`03o`00003oogl0oomo0080X23`00<0oomo0:0Pl02P8?000P2P8?000`3oogl0X23`0:0Pl002
0:0Pl4d0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogl30?ooO`@0X23`4P3oogl20:0P
l3@0oomo0P2P8?080?ooO`80X23`5`3oogl20:0Pl0<0oomo1P2P8?030?ooO`<0ogl000CoOooo0?mo
003oO`3oOooo103oO`000omoool0X23`0:0Pl0020:0Pl080ogl0103oogl20:0Pl0<0oomo102P8?1=
0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo0`3oogl40:0Pl3`0oomo0P2P8?030?oo
O`80X23`1@3oogl20:0Pl0P0oomo0P2P8?0F0?ooO`D0X23`00<0oomo0:0Pl02P8?000`2P8?060?oo
O`04o`000?moool0ogl00?mo00?oOooo0P3oO`050:0Pl080ogl000?o00000?ooO`3oogl0103oogl5
0:0Pl4h0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogm30?ooO`80X23`0`3oogl20:0P
l2L0oomo0P2P8?000`3oogl0X23`0:0Pl0030?ooO`<0X23`1`3oogl00ol0003oOoooogooo`05ogoo
o`@0X23`1?moool00ol00000oomo0?ooO`030?ooO`D0X23`CP3oogl1o`00007ooooo00000ol0003o
oomoooooO`0_ooooOfh0oomo0P2P8?030?ooO`80X23`0P3oogl30:0Pl0030?ooO`2P8?00X23`00L0
oomo00?o00000?mo003oO`000_moool20:0Pl0WoOooo0_l000050?ooO`H0X23`00<0oomo0:0Pl02P
8?00B03oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOb`0oomo0P2P8?100?ooO`80X23`
0`3oogl20:0Pl080oomo0`2P8?000`3oogl0X23`0:0Pl0020:0Pl080oomo0`2P8?000`3oogl0ogl0
0?mo0002ogooo`@0X23`0_moool20?mo00GoOooo00Go00000?ooO`2P8?00X23`0?ooO`090:0Pl4P0
oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogl@0?ooO`80X23`6P3oogl20:0Pl3P0oomo
0P2P8?080?ooO`80X23`00<0oomo0?mo003oO`001P3oogl0103oO`00X23`0:0Pl02P8?020?ooO`<0
X23`0P3oogl20:0Pl0;oOooo0`2P8?02ogooo`80ogl01?moool50:0Pl080oomo202P8?180?ooO`7o
00000Oooool00003o`000?ooogoooomo02oooomo403oogl20:0Pl5@0oomo0P2P8?080?ooO`80X23`
403oogl20:0Pl080oomo1@2P8?020?mo00SoOooo102P8?050?ooO`<0X23`00<0oomo0:0Pl02P8?00
B03oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOfT0oomo0P2P8?080?ooO`80X23`1P3o
ogl40:0Pl0030?ooO`2P8?00X23`0080X23`0`3oogl40:0Pl0030?mo002P8?00X23`00<0ogl000?o
Oooo0:0Pl02P8?000omoool20:0Pl004o`00003oogl0oomo0?ooO`D0X23`103oogl20:0Pl4@0oomo
0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogmY0?ooO`80X23`203oogl20:0Pl0H0oomo2@2P
8?000`3oogl0X23`0:0Pl0020?ooO`03o`00003oO`00ogl000<0X23`0`3oO`020:0Pl0KoOooo00?o
00000?ooO`3oogl01@2P8?040?ooO`80X23`1P3oogl20?mo03`0oomo0Ol00001ooooo`0000?o0000
ooooOoooogl0;oooogmR0?ooO`80X23`3`3oogl20:0Pl0T0oomo0P2P8?00103oogl0X23`0:0Pl03o
ogl40:0Pl080oomo0P3oO`030:0Pl003ogooo`3oO`00ogl00080X23`1omoool00ol00000oomo0:0P
l0040:0Pl0<0oomo0P2P8?070?ooO`80ogl0?03oogl1o`00007ooooo00000ol0003ooomoooooO`0_
ooooO`H0oomo0P2P8?1J0?ooO`80X23`103oogl20:0Pl0T0oomo102P8?0:0?ooO`80X23`00<0oomo
0:0Pl02P8?000P2P8?00103oogl0ogl00?mo003oO`040:0Pl0;oOooo0P2P8?08ogooo`04o`00002P
8?00X23`0?ooO`<0X23`00<0oomo0:0Pl02P8?000`2P8?130?ooO`7o00000Oooool00003o`000?oo
ogoooomo02oooomo1P3oogl20:0Pl600oomo0P2P8?0;0?ooO`80X23`3@3oogl20:0Pl080ogl000H0
oomo0?mo003oO`00ogl00?ooOol000020:0Pl0;oOooo0P2P8?09ogooo`04o`00003oogl0oomo0?oo
O`80X23`00@0oomo0:0Pl02P8?00oomo0P2P8?130?ooO`7o00000Oooool00003o`000?ooogoooomo
02oooomoP03oogl20:0Pl080oomo0P3oO`00103oogl0X23`0:0Pl03oogl20:0Pl0030?ooO`2P8?00
X23`00ooOooo1P2P8?030?ooO`80X23`@`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_oooo
Oh00oomo2@2P8?000`3oO`00X23`0:0Pl0030:0Pl003o`000?moooooOooo00@0X23`2?moool60:0P
l0<0oomo0`2P8?120?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomoN@3oogl20:0Pl0<0
oomo0P2P8?020?ooO`L0X23`0P3oO`020:0Pl0<0oomo00?o0000ogooo`2P8?000`2P8?020?mo00<0
X23`1Omoool00ol00000X23`0:0Pl0020?ooO`H0X23`@@3oogl1o`00007ooooo00000ol0003ooomo
ooooO`0_ooooOgT0oomo0P2P8?030?ooO`80X23`1@3oogl40:0Pl080ogl0102P8?020?ooO`03o`00
003oO`00ogl000<0X23`00@0ogl00:0Pl02P8?00X23`0_moool30:0Pl003ogooool00000oomo0080
oomo0P2P8?00103oogl0X23`0:0Pl02P8?110?ooO`7o00000Oooool00003o`000?ooogoooomo02oo
oomo:03oogl20:0Pl5`0oomo0`2P8?020?mo00@0X23`103oO`060:0Pl0CoOooo1@2P8?000ol00000
oomo0?ooO`030?ooO`80X23`@P3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooObP0oomo
0P2P8?1H0?ooO`<0X23`00<0oomo0:0Pl02P8?000P3oogl30:0Pl0H0ogl00P2P8?020?mo0080X23`
0omoool20:0Pl0;oOooo102P8?030?ooO`H0X23`?`3oogl1o`00007ooooo00000ol0003ooomooooo
O`0_ooooOaH0oomo0P2P8?1X0?ooO`D0X23`1@3oogl30:0Pl0030?mo002P8?00X23`0080X23`00<0
ogl00:0Pl02P8?000_moool30:0Pl0030?mo0?moool0X23`00<0X23`0_moool20:0Pl003o`00003o
ogl0X23`00H0X23`?`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOaH0oomo0P2P8?1Q
0?ooO`80X23`1@3oogl40:0Pl0040?mo003oogl0ogl00?mo00<0oomo0P2P8?000`3oO`00X23`0:0P
l0020:0Pl0040?ooO`2P8?00X23`0?mo00@0X23`00@0ogl0ogoooomoooooOooo0P2P8?02ogooo`80
X23`00?oOoooo`00002P8?000P2P8?130?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo
N@3oogl20:0Pl0L0oomo0P2P8?020?ooO`80ogl01@3oogl20?mo00040?ooO`2P8?00X23`0?ooO`<0
ogl00P2P8?020?mo00SoOooo0P2P8?02ogooo`80X23`A03oogl1o`00007ooooo00000ol0003ooomo
ooooO`0_ooooO``0oomo0P2P8?1l0?ooO`80X23`00<0ogl00:0Pl02P8?000P2P8?000`3oogl0X23`
0:0Pl0020?ooO`05o`000?moool0X23`0:0Pl?moool00P2P8?000omoool0X23`0:0Pl002ogooo`80
ogl00omoool20:0Pl0H0oomo0P2P8?0k0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo
303oogl20:0Pl1H0oomo0P2P8?1>0?ooO`80X23`503oogl20:0Pl0030?mo002P8?00X23`00/0X23`
00?oOooo0:0Pl02P8?001@2P8?020?mo00?oOooo0P2P8?001?l00000oomo0:0Pl02P8?020?ooO`80
X23`>`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOb@0oomo0P2P8?1>0?ooO`80X23`
503oogl20:0Pl0030?ooO`3oO`00ogl000<0X23`00<0oomo0:0Pl02P8?001P2P8?02ogooo`D0X23`
1Omoool20?mo0004ogooool00000X23`0:0Pl080oomo102P8?0i0?ooO`7o00000Oooool00003o`00
0?ooogoooomo02oooomoRP3oogl30:0Pl080ogl00P2P8?020?ooO`<0X23`00<0ogl00:0Pl02P8?00
0P2P8?001?moool0X23`0:0Pl03oO`020:0Pl0?oOooo0P2P8?000omoool0ogl00?mo0003ogooo`03
o`00003oogl0X23`00@0X23`>@3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooO`@0oomo
0P2P8?230?ooO`@0X23`1P3oogl30:0Pl0030?mo002P8?00X23`00D0X23`00CoOooo0:0Pl02P8?00
ogl0102P8?07ogooo`D0X23`>P3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooO`@0oomo
0P2P8?030?ooO`80X23`OP3oogl20:0Pl080oomo0P2P8?030?ooO`P0X23`00@0oomo0:0Pl02P8?00
ogl00P2P8?020?mo00H0X23`1Omoool20:0Pl0030?ooO`2P8?00X23`03X0oomo0Ol00001ooooo`00
00?o0000ooooOoooogl0;oooogl90?ooO`80X23`NP3oogl20:0Pl0H0oomo0P2P8?030?ooO`h0X23`
00@0ogl00:0Pl02P8?3oOooo1P2P8?03ogooo`80X23`00?o00000:0Pl02P8?00>P3oogl1o`00007o
oooo00000ol0003ooomoooooO`0_ooooOhD0oomo0`2P8?0=0?ooO`H0X23`00@0oomo0:0Pl02P8?00
ogl0102P8?05ogooo`80X23`1?moool40:0Pl3X0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0
;oooogn60?ooO`80X23`3@3oogl20:0Pl0040?ooO`2P8?00X23`0:0Pl080oomo0P3oO`020:0Pl080
ogl02omoool30:0Pl003ogooool00000oomo03P0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0
;ooooglX0?ooO`80X23`H03oogl20:0Pl0L0oomo0P2P8?030?ooO`80ogl00`3oogl30:0Pl0GoOooo
0P2P8?000`3oO`3oOoooogooo`020:0Pl0OoOooo00?o00000:0Pl02P8?00=P3oogl1o`00007ooooo
00000ol0003ooomoooooO`0_ooooObP0oomo0P2P8?1A0?ooO`@0X23`2`3oogl20:0Pl0L0oomo0P2P
8?030?ooO`80ogl00P3oogl40:0Pl0GoOooo1`2P8?08ogooo`80X23`=P3oogl1o`00007ooooo0000
0ol0003ooomoooooO`0_ooooO`T0oomo0P2P8?040?ooO`80X23`JP3oogl40:0Pl0H0oomo0P2P8?0=
0?ooO`80X23`1@3oogl50:0Pl080ogl01?moool40:0Pl0[oOooo0P2P8?000ol00000oomo0?ooO`0c
0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo2@3oogl20:0Pl0@0oomo0P2P8?1d0?oo
O`80X23`3@3oogl20:0Pl0<0oomo2@2P8?000`3oO`3oOoooogooo`040:0Pl0030?mo0?moooooOooo
00_oOooo00?o00000?ooO`3oogl0<P3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOh40
oomo0P2P8?0F0?ooO`80X23`0P3oO`020:0Pl0030?ooO`2P8?00X23`0080X23`00GoOooo0:0Pl02P
8?00X23`ogooo`020:0Pl0goOooo00?o00000?ooO`3oogl0<@3oogl1o`00007ooooo00000ol0003o
oomoooooO`0_ooooOfh0oomo0P2P8?0A0?ooO`80X23`1P3oogl20:0Pl100oomo0P3oO`000`3oogl0
ogl00?mo00080:0Pl003ogooo`2P8?00X23`00koOooo0_l0000a0?ooO`7o00000Oooool00003o`00
0?ooogoooomo02oooomo3@3oogl20:0Pl5l0oomo0P2P8?0I0?ooO`80X23`303oogl30?mo00@0oomo
0P2P8?020?mo00@0X23`00GoOooo0:0Pl02P8?00ogl0ogooo`020:0Pl0koOooo00?o00000?ooO`3o
ogl0;P3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooO`d0oomo0P2P8?280?ooO`<0ogl0
103oogl20:0Pl080oomo102P8?000`3oO`00X23`0:0Pl0040:0Pl0ooOooo00?o00000?ooO`3oogl0
;@3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOiL0oomo0`3oO`0:0?ooO`80X23`0`3o
O`040:0Pl13oOooo0_l0000]0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomoW`3oogl2
0:0Pl0040?ooO`3oO`00ogl00?ooO`80X23`0P3oO`001?moool0ogl00:0Pl02P8?0Bogooo`03o`00
003oogl0oomo02X0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooooglM0?ooO`80X23`J`3o
ogl20:0Pl140oomo0P3oO`030:0Pl080ogl000<0oomo0:0Pl02P8?00103oO`020:0Pl0?oOooo0P3o
O`0>ogooo`03o`00003oogl0oomo02T0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooooglM
0?ooO`80X23`J`3oogl20:0Pl140oomo0`3oO`040:0Pl0L0ogl00omoool20:0Pl080ogl03omoool0
0ol00000oomo0?ooO`0X0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo3`3oogl20:0P
l1H0oomo0P2P8?070?ooO`80X23`K03oogl20?mo00H0X23`1@3oO`03ogooo`80X23`1?moool20:0P
l0coOooo0_l0000X0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomo3`3oogl20:0Pl1H0
oomo0P2P8?070?ooO`80X23`E03oogl20:0Pl1P0oomo0`2P8?000`3oO`00X23`0:0Pl0020?ooO`80
ogl00P2P8?00103oO`3oOooo0?mo003oO`04ogooo`80X23`3_moool00ol00000oomo0?ooO`0U0?oo
O`7o00000Oooool00003o`000?ooogoooomo02oooomoQP3oogl20:0Pl1P0oomo0`2P8?001P3oogl0
X23`0:0Pl03oO`00oomo0?mo00<0X23`00D0ogl0ogooo`3oO`00ogl0ogooo`020?mo0004ogooo`3o
O`00ogl0ogooo`80ogl01?moool20?mo00KoOooo00?o00000?ooO`3oogl0903oogl1o`00007ooooo
00000ol0003ooomoooooO`0_ooooOa00oomo0P2P8?2B0?ooO`<0ogl000<0oomo0:0Pl02P8?000P2P
8?000`3oO`3oOoooogooo`02ogooo`80ogl000CoOooo0?mo003oO`3oOooo0P3oO`04ogooo`80ogl0
1omoool2o`0002@0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogl@0?ooO`80X23`1P3o
ogl20:0Pl8X0oomo0P3oO`000`3oogl0X23`0:0Pl0030:0Pl0?oOooo00@0ogl00:0Pl02P8?3oOooo
0P3oO`0Cogooo`03o`00003oogl0oomo0240oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooo
oglH0?ooO`80X23`S@3oogl40:0Pl0050?mo0?l0003oOoooogooo`3oO`000P2P8?000omoool0ogl0
0?mo000Dogooo`03o`00003oogl0oomo0200oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooo
ogmX0?ooO`80X23`=P3oogl20:0Pl080ogl02@3oogl40:0Pl003ogooo`3oO`00ogl001KoOooo00?o
00000?ooO`3oogl07`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooO`h0oomo0P2P8?0?
0?ooO`80X23`A`3oogl20:0Pl3@0oomo102P8?020?mo0080X23`1@3oogl60:0Pl004ogooo`3oO`00
ogl00?mo00CoOooo0P3oO`0@ogooo`;o00007`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_
ooooO`h0oomo0P2P8?0?0?ooO`80X23`L`3oogl20:0Pl0P0oomo0P2P8?020?ooO`@0X23`0P3oogl2
0?mo00030?ooO`2P8?00X23`0080oomo0P2P8?050?mo00?oOooo0P3oO`0Bogooo`03o`00003oogl0
oomo01`0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooognD0?ooO`80X23`303oogl20:0P
l0@0oomo0P2P8?050?ooO`80X23`1@3oO`03ogooo`80X23`0P3oO`03ogooo`80ogl03?moool00ol0
0000oomo0?ooO`0K0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomoY03oogl20?mo0080
oomo102P8?001@3oogl0X23`0:0Pl03oogoo000000@0ogl000CoOooo0?mo003oO`3oOooo0P2P8?02
0?mo00?oOooo0P3oO`0=ogooo`03o`00003oogl0oomo01X0oomo0Ol00001ooooo`0000?o0000oooo
Ooooogl0;oooognR0?ooO`@0X23`0P3oogl20?mo00H0X23`00H0oomoo`00002P8?00X23`0?mo0?mo
ool20?mo0003ogooo`3oO`00ogl00080X23`4omoool2o`0001X0oomo0Ol00001ooooo`0000?o0000
ooooOoooogl0;oooognO0?ooO`80X23`00<0oomo0:0Pl02P8?000P2P8?050?ooO`80X23`00@0oomo
0:0Pl02P8?00oomo0`2P8?000`3oO`3oOooo0?mo00020?mo00;oOooo0P2P8?000`3oO`3oOoooogoo
o`020:0Pl13oOooo00?o00000?ooO`3oogl05`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_
ooooOil0oomo0P2P8?050?ooO`H0X23`00<0oomo0?mo003oO`000P3oO`020:0Pl0H0ogl00_moool2
0:0Pl0030?mo0?moooooOooo0080X23`00<0ogl0ogoooomoool01omoool20:0Pl0GoOooo00?o0000
0?ooO`3oogl05P3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOjH0oomo1P2P8?000`3o
ogl0ogl00?mo00020?mo0080X23`00@0oomo0?mo003oO`3oOooo0P3oO`02ogooo`80X23`1?moool2
0?mo00WoOooo0P2P8?06ogooo`03o`00003oogl0oomo01D0oomo0Ol00001ooooo`0000?o0000oooo
Ooooogl0;ooooglG0?ooO`80X23`Q@3oogl20:0Pl140oomo0P2P8?00103oogl0ogl00?mo0?moool2
0:0Pl0<0ogl00omoool20?mo01CoOooo0_l0000E0?ooO`7o00000Oooool00003o`000?ooogoooomo
02oooomo5`3oogl20:0Pl8D0oomo0P2P8?060?ooO`80X23`00<0oomo0?mo003oO`000`3oogl50:0P
l0040?ooO`3oO`00ogl00?mo00D0X23`0omoool20?mo01KoOooo00?o00000?ooO`3oogl04P3oogl1
o`00007ooooo00000ol0003ooomoooooO`0_ooooOjH0oomo0P2P8?000`3oogl0X23`0:0Pl0020?mo
00030?ooO`2P8?00X23`0080X23`00<0ogl00:0Pl02P8?000P3oO`050:0Pl0?oOooo0P3oO`0Gogoo
o`03o`00003oogl0oomo0140oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogl_0?ooO`80
X23`N03oogl40:0Pl0030?ooO`3oO`00X23`00D0X23`00<0ogl00:0Pl02P8?000`2P8?030?mo0003
ogooo`3oO`00ogl00080ogl05_moool00ol00000oomo0?ooO`0@0?ooO`7o00000Oooool00003o`00
0?ooogoooomo02oooomo;@3oogl40:0Pl7P0oomo2P2P8?030?ooO`D0X23`0`3oO`000omoool0ogl0
0?mo00030?mo01KoOooo00?o00000?ooO`3oogl03`3oogl1o`00007ooooo00000ol0003ooomooooo
O`0_ooooObd0oomo0P2P8?1j0?ooO`H0X23`00<0oomo0:0Pl02P8?000P3oogl20?mo0080X23`00<0
ogl00:0Pl02P8?000`2P8?030?mo0004ogooo`3oO`00ogl00?mo00GoOooo0P3oO`0?ogooo`03o`00
003oogl0oomo00h0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooooglN0?ooO`80X23`RP3o
ogl30:0Pl0<0oomo0P2P8?000`3oogl0X23`0:0Pl0030:0Pl0<0ogl00`2P8?040?mo0003ogooo`3o
O`00ogl000GoOooo0P3oO`0@ogooo`03o`00003oogl0oomo00d0oomo0Ol00001ooooo`0000?o0000
ooooOoooogl0;ooooglN0?ooO`80X23`RP3oogl30:0Pl080oomo0`2P8?001@3oogl0X23`0:0Pl02P
8?00oomo00P0X23`103oO`03ogooo`@0ogl00P2P8?0Aogooo`?o0000303oogl1o`00007ooooo0000
0ol0003ooomoooooO`0_ooooOjl0oomo0`2P8?050?ooO`P0X23`103oO`03ogooo`@0ogl00P2P8?0C
ogooo`;o00002`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOjd0oomo0P2P8?020?oo
O`80X23`00@0oomo0:0Pl02P8?00oomo0P2P8?020?mo00040?ooO`3oO`00X23`0:0Pl0L0ogl06_mo
ool2o`0000X0oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooognL0?ooO`80X23`3`3oogl2
0:0Pl080oomo1@2P8?000`3oogl0X23`0:0Pl0060:0Pl080ogl00P2P8?030?mo01coOooo00?o0000
0?ooO`3oogl01`3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOi`0oomo0P2P8?0C0?oo
O`D0X23`00<0oomo0:0Pl02P8?001@2P8?030?mo0080X23`0`3oO`0Mogooo`;o00001`3oogl1o`00
007ooooo00000ol0003ooomoooooO`0_ooooOgP0oomo0P2P8?0`0?ooO`<0X23`103oogl20:0Pl0<0
oomo202P8?000ol00000X23`0:0Pl0060?mo0003ogooo`3oO`00ogl00080ogl06?moool2o`0000H0
oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogld0?ooO`80X23`@P3oogl20:0Pl300oomo
0`2P8?090?ooO`80X23`0P3oogl80:0Pl0D0ogl000?oOooo0?mo003oO`000P3oO`0Iogooo`;o0000
1@3oogl1o`00007ooooo00000ol0003ooomoooooO`0_ooooOc@0oomo0P2P8?210?ooO`P0X23`00?o
00000:0Pl02P8?002@3oO`0Logooo`03o`00003oogl0oomo0080oomo0Ol00001ooooo`0000?o0000
ooooOoooogl0;oooogna0?ooO`80X23`103oogl80:0Pl0030?ooO`3oO`00ogl000P0ogl000?oOooo
0?mo003oO`006omoool2o`000080oomo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogm_0?oo
O`80X23`@03oogl20:0Pl0L0oomo1@2P8?00103oogl0X23`0:0Pl02P8?0;0?mo01_oOooo0_l00001
0?ooO`7o00000Oooool00003o`000?ooogoooomo02oooomoK`3oogl20:0Pl4X0oomo0`2P8?020?oo
O`<0X23`00?oOooo0?mo003oO`00203oO`0Mogooo`;o00000Oooool00003o`000?ooogoooomo02oo
oomo_@3oogl20:0Pl0<0oomo0P2P8?050?mo0080X23`00<0ogl0ogoooomoool07_moool1o`00007o
oooo00000ol0003ooomoooooO`0_ooooOcT0oomo0P2P8?220?ooO`80X23`00<0oomo0:0Pl02P8?00
0`2P8?040?mo0080X23`0P3oO`0Oogooo`7o00000Oooool00003o`000?ooogoooomo02oooomo>03o
ogl30:0Pl7h0oomo0P2P8?050?ooO`D0X23`0omoool40?mo0080X23`7_moool1o`00007ooooo0000
0ol0003ooomoooooO`0_ooooOcP0oomo0P2P8?1<0?ooO`80X23`<@3oogl20:0Pl0D0oomo1@2P8?00
0ol0003oOoooogooo`020:0Pl080ogl00P2P8?020?mo01coOooo0Ol00001ooooo`0000?o0000oooo
Ooooogl0;oooogn60?ooO`80X23`>03oogl30:0Pl0050?ooO`2P8?00X23`o`000?moool00P2P8?02
0?mo0080X23`0`3oO`0Kogooo`7o00000Oooool00003o`000?ooogoooomo02oooomo_@3oogl20:0P
l080oomo0P2P8?001@3oogl0X23`0:0Pl02P8?3o00000080X23`0_moool50?mo01_oOooo0Ol00001
ooooo`0000?o0000ooooOoooogl0;oooognc0?ooO`80X23`203oogl20:0Pl0H0oomo0P2P8?001Ol0
0000X23`0:0Pl03oO`3oOooo0080ogl00`2P8?0Kogooo`7o00000Oooool00003o`000?ooogoooomo
02oooomoP03oogl20:0Pl2d0oomo0P2P8?020?ooO`80X23`4`3oogl20:0Pl0030?mo0?moool0ogl0
00@0X23`6omoool1o`00007ooooo00000ol0003ooomoooooO`0_ooooOdP0oomo0P2P8?0f0?ooO`80
X23`6P3oogl20:0Pl140oomo0P2P8?0G0?ooO`@0X23`00?oOooo0:0Pl02P8?000P2P8?0Kogooo`7o
00000Oooool00003o`000?ooogoooomo02oooomoB03oogl20:0Pl580oomo0P2P8?0/0?ooO`80X23`
8?moool1o`00007ooooo00000ol0003ooomoooooO`0_ooooOl80oomo0P2P8?070?ooO`03o`000?mo
ooooOooo01koOooo0Ol00001ooooo`0000?o0000ooooOoooogl0;ooooglo0?ooO`80X23`P@3oogl2
0:0Pl0L0oomo00?o0000ogoooomoool01_moool0103oO`00X23`0:0Pl03oO`0Dogooo`7o00000Ooo
ool00003o`000?ooogoooomo02oooomo?`3oogl20:0Pl7D0oomo0P2P8?0D0?ooO`03o`00003oO`00
ogl000GoOooo00@0ogl00:0Pl02P8?00ogl05?moool1o`00007ooooo00000ol0003ooomoooooO`0_
ooooOhH0oomo0P2P8?0^0?ooO`80X23`5@3oogl20?mo00GoOooo0`2P8?000`3oO`00X23`0:0Pl00B
ogooo`7o00000Oooool00003o`000?ooogoooomo02oooomoA03oogl20:0Pl0H0oomo0P2P8?0A0?oo
O`80X23`9@3oogl20:0Pl4H0oomo00?o0000ogoooomoool00omoool30:0Pl003ogooo`2P8?00X23`
01;oOooo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogm40?ooO`80X23`1P3oogl20:0Pl140
oomo0P2P8?0g0?ooO`80X23`=@3oogl20?mo00CoOooo0P2P8?001?moool0X23`0:0Pl?moool20?mo
00ooOooo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooognH0?ooO`80X23`00<0oomo0:0Pl02P
8?00<P3oogl20?mo00CoOooo0P2P8?001?moool0X23`0:0Pl?moool20:0Pl0030?mo0?moooooOooo
00coOooo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooognK0?ooO`80X23`1`3oogl20:0Pl2X0
oomo00?o0000ogoooomoool00`2P8?05ogooo`80X23`00<0ogl0ogoooomoool03?moool1o`00007o
oooo00000ol0003ooomoooooO`0_ooooOj@0oomo0P2P8?0[0?ooO`03o`000?moool0X23`0080X23`
5_moool1o`00007ooooo00000ol0003ooomoooooO`0_ooooOfX0oomo0P2P8?1V0?ooO`03o`000?mo
ooooOooo01OoOooo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogm40?ooO`80X23`3@3oogl2
0:0Pl1D0oomo0P2P8?1Q0?ooO`80ogl0103oogl20:0Pl0CoOooo1P3oO`0;ogooo`80ogl00Ol00001
ooooo`0000?o0000ooooOoooogl0;oooogm40?ooO`80X23`3@3oogl20:0Pl7P0oomo0P3oO`040?oo
O`80X23`1?moool30?mo0080X23`0P3oO`0:ogooo`80ogl00Ol00001ooooo`0000?o0000ooooOooo
ogl0;oooogmY0?ooO`80X23`JP3oogl01?l0003oOoooogoooomoool20?mo0003ogooo`2P8?00X23`
0080ogl00P2P8?0:ogooo`7o00000Oooool00003o`000?ooogoooomo02oooomoJ@3oogl20:0Pl6X0
oomo00?o0000ogoooomoool01Omoool20:0Pl0030?mo002P8?00X23`0080X23`2?moool1o`00007o
oooo00000ol0003ooomoooooO`0_ooooOmH0oomo00?o0000ogoooomoool01?moool20:0Pl0?oOooo
0P2P8?08ogooo`7o00000Oooool00003o`000?ooogoooomo02oooomoCP3oogl20:0Pl0L0oomo0P2P
8?1n0?ooO`03o`000?moooooOooo01;oOooo0Ol00001ooooo`0000?o0000ooooOoooogl0;oooogm>
0?ooO`80X23`1`3oogl20:0Pl680oomo0P2P8?0K0?ooO`03o`000?moooooOooo017oOooo0Ol00001
ooooo`0000?o0000ooooOoooogl0;oooognk0?ooO`80X23`6`3oogl00ol0003oOoooogooo`0Aogoo
o`7o00000Oooool00003o`000?ooogoooomo02oooomoF@3oogl20:0Pl6d0oomo0P2P8?0?0?ooO`03
o`000?moooooOooo00SoOooo0`2P8?05ogooo`7o00000Oooool00003o`000?ooogoooomo02oooomo
F@3oogl20:0Pl6d0oomo0P2P8?0@0?ooO`03o`000?moooooOooo00OoOooo0`2P8?05ogooo`7o0000
0Oooool00003o`000?ooogoooomo02oooomoc@3oogl20:0Pl0H0oomo0P2P8?030?ooO`03o`000?mo
ooooOooo00SoOooo0P3oO`02ogooo`040?mo002P8?00X23`o`00007ooooo00000ol0003ooomooooo
O`0_ooooOk`0oomo0P2P8?0?0?ooO`80X23`1P3oogl20:0Pl0@0oomo00?o0000ogoooomoool01omo
ool20?mo0003ogooo`2P8?00X23`0080X23`0Ol00001ooooo`0000?o0000ooooOoooogl0;oooognl
0?ooO`80X23`7P3oogl00ol0003oOoooogooo`09ogooo`@0X23`0Ol00001ooooo`00ool0000Po`00
007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, \
0.889355, 0.889355}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, 0.889355, \
0.889355}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1, pdf1, 
          pdf2, {Green, Blue}];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2, pdf1, 
          pdf2, {Green, Blue}];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1, obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45448 
%%ImageSize: 400 181.791 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0108209 0.238095 [
[ 0 0 0 0 ]
[ 1 .45448 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45448 L
0 .45448 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0108209 0.245293 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0108209 0.488926 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0108209 0.732558 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C834
59C9355AC9365CC9365CC9355ECD3B61D14389B25CBB9C81BD9F86BC9C80B29274B59678
51C337AD9173BCA285BCA48CBAA590B19B88B29D8A857668796F639486738A7A62887760
9B886D5AD1457FAF5953CA3E56C93D55C63A55C5382AE11B00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008CB65EB89A7CBA9D81
BEA588C7B095BDA38BC2A78FDCC7B5D8C9B9CCBEAEC9BAA9CEBEACBAA793AC9580C3AE9B
D2C3B5C0B5A8CBC1B6D6CEC8B6B3B2868484B0AAA842464C1D2E39626C6FA7A8A48F9190
9B9F9DC9CCC8B0B6B1BDC1BBC7C4BACAC1B5C4B7A9C1B0A2BCA797B59E8EB39A8784B163
59CD4256C93D51C33600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE318
59C6315BC734B69169B8946CBA9A72B89E7BD2BB9DCCB69CB6A28AD4C4AED2C4B0BAA996
BCAB97D7CBBCDDD1C5CBBDB1CFC2B7CFC7BCC5BDB1AEA393BDAE9ECCBFB2C3B6AAC6BBB1
D5D0CBC2C2BEB3B1ACBCB9B5A1A2A26E6E719E9A98B1B3B399A8AF90A4AEBBC9CEA9BAC4
3450655B7B915B7B8C627E8BBCCED2C8CFCFC9CCCACCCBC9CECBC8CEC9C7CEC9C6CEC9C4
CFCAC2CEC5BCC5B8AEBCAFA3B3A393AC978555CA4300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002CE31959C7325BCA3489B14FB8986BBD9C72
C09D76C19E7AC5A484CBAB8FC4A78DC0A88FD4C3ACCFBEA9B9A790B8A68FC2B5A2CAC0AE
BFB5A5D3CABED8D2C9C8BEB3BAAE9EC6BDAFCEC9BCC7C0B4CAC2B8D6D1CAD6D1CABBB3AC
C2BDB6B3B2ADB0AEA8ABA89FCAC8C1D3D3D1C0C1C1BCC0C1AAB9C2334D66536D838FA1B2
203A5412345182A2B6748E9CB0C6D0C1D0D5C7D0D3CBD1D4CAD0D2CDCFD3CCCFD1CCCED1
CCD0D1CACECFCCCECECCCDCCCACAC8CEC9C8C7BFBBC4B9B3BAABA0AF9A8859CE4550C236
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002DE3195BCA35B8946FBB9874BC9B76C09E7AC3A480C4A682C4A682
C7A885C5A987C6AB8DD1B7A0CFB7A0C9B198C7B099C8B29DC8B09DBEA894CEBEACD3CABC
BEB6A9A69D92AEA69DC6BDB5CAC1B7CBC3B9D8D5CDD6D6CEC1BEB5C0BCB3C8C2BBC2BAB3
BCB5ADD6D4CED6D6D0C7C7BFC0C1B9CBCFCD8690938891949BA3A94B5C6F455C6F9FB1BA
A9BCC785A0B29CBAC8B6D3DF648495ABC6D2C0CFD3C8D2D4C9D1D4CCD1D5CAD0D4CDD3D7
C6CED1C9CED1CBD0D3C9D0D3C9D0D3C7CCCFC9CBCEC9CBCEC7CAC9C7C7C3CAC6BFCBC1B8
C3AFA4A88E7E94755E47B52922D81100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC935
5ECC3ABA9670BC9974BC9D76BEA07BC0A07FC4A284C7A78AC7A98DC8AB8FC9AD90C9B090
CBB293CCB393CCB296CDB39ACEB69ECEB8A0CEB9A2D5C1AEE0CCBBC8B4A1C4AF9CBCAC9D
A79F90BEB7A9CDC5BCC7C2BDCDC8C3C6BCB5CBC4BCCDCCC4C3C1B9BFBCB4D7D5CEDADAD4
C6C6C1CBCCC7CDCFCABEBEB8B3B2A9B7B5AE979B9C9DA1A3B8BCB9CAD2D7B7C8D498AFBD
B8D1E14E6F8C254E6F799FB9284C667090A7BFD2DAC7D2D5C6CFD3C8D1D3C7D1D2CBD4D7
C7D1D2C9D0D2CCD1D4C8D0D3C7D1D3C8D0D3C8CED3BFC8CEBDC8CBC4CDCFC5CCCCC6C9C8
C7C5C4C7BEBCBDB1ACB1A1969D857489674F42B02100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BCA3486AE4FB79A72BDA37E
BEA281BD9F81BEA283C0A686C2A889C7AB8ECCAE92CCAF95CAAF98CEB49ECEB7A0CBB69E
CBB79FCEBAA0D0BAA2D3BAA3D5BFA9DAC8B3CFBEA8D2C0ABCEBCA7CBB4A0D0B7A4B9A99A
CEC7BBD9D4CACDC7BDCAC5BFAAA69FC7BFB5C7C0B6D8D7CEDBDAD5CECDC8CECDC7D9D7D3
CCCAC4C0BCB5C5C1BAC2BEB8C4C0B8C3BFB9D5D8D4CFD6D6B7BFC0C8D0D7687F9623476D
6D8EAE3F5F82143A6261839DA8C2D38EA8B8BDD3DDC6D5D9C6D2D6C7D1D3C8D2D4C6D0D2
C6D0D1C6CED0C8D0D4C8CFD5C4CDD2C2CCCEC6CED4C4CDD5C0CBD0C5CDD2C4CCCEC6CECE
C4CACBC5C7C9C0C2C4C1C1C0C4BFBAB9AAA29D877686694D3DAD1D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002CE41BB09268B3986EB99E77B79C77B79F7BBAA381
C0A887C1A888C4AB8BC6AD8FCAB398C8B196CEB89FCFBBA5CCBAA5D3C0ACD2C1ACD0BFAA
C9B8A5D0BFACD3C2AFD7C3B0D7C4B0D8C6B0D7C5ACD7C3AAD6C2AADDC7B3D7C1AEC3B2A3
B2A99FCDC7BEC7C0B6ABA69CBCB9B0DAD6CECAC7BFD3D2CBDADAD3CECBC4C2BBB2CCC5BE
D3CEC8C7C2BBD2CFC8DBD8D3D6D4D0CCCAC6CACBC8B7BFC2768489A9B3B88F9EAE46607F
7D94ADBDCEE0A5BBCE9BB6C9BAD3E295B2C36E8FA1BED6DFC8D6D9CCD6D8CCD4D9C9D1D4
C8D0D3C8CFD4CBD2D8C9D0D6C7CED4C5CCD2C4CDD3C4CDD6C4CED6C4CDD2C0CACDC3CCD0
C2CBCEC5CBCFC1C8CAC3C7CABEC1C4C1C3C3C1BEBBB7ACA4988471628D381ED50D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CE3185AC8335ACA36B0946CB59B76BAA17DBCA583BAA281BBA381BCA582BDA886
BEAA8AC2AD8FC8B295CDB89ECCB8A1CAB9A3CABAA6B7AA9AADA295A69A8BCABDABD4C3B0
D4C1ADD6C4B0DBC9B5DBC9B5DAC8B4DBC9B2DCC8B0DCC6AEDAC6AFDDCBB7D7C6B1D5C4AF
BCAF9EB9AFA4C1B8B1B8B2A9D7D4CCD8D7D1C4C1BAB9B5ABC7C3B9CFCBC2C7C2BAD2CCC6
DAD6D2D8D7D3C4C1BCD3CDC8D2CDC8C5C0BABBB6B0BFC0BEA4ACADB2B8BBCBD2D6C5D3E1
A2B6C7AABDCAA3BACC2B4E6E3A607F6185A01C435D9DBCCDC4D8DBCED9DACCD6D7CAD5D7
CAD3D8CAD3DACDD5DBC9D2D5C9D3D5CCD3D8C8CFD6C8CFD7C7CED6C6CDD5C2CBD0C0C9CF
C1CBCFC4CED0C4CDD0C0C8CCC1C7CCC2C6CABCC2C5C0C1C3C5C0BCAB9B90856D583BAB1E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058C833
85AE4FB7996FBB9C75B89C78B99F7DB9A380B7A380B8A384B7A383BDA987C1AD8AC1AD8C
C3AF91C8B298CDB79FCDB8A3CEBBA9D0BFAFC2B6A6B9AFA3D4C9C1A89E94C1B4A4DAC9B6
DECAB8DDC8B5DFCAB6DCC8B6DDCBB7DFCEB9E0CFB8E0CCB5E0CCB4DAC9B2D9C9B1D8C8B0
D2C5B0DED3C5E2D7CED0C6BCCBC2B6CAC4BAA6A49D9B9B95A6A8A0D8DAD2D8D7D1C4BEB8
CFCAC5CFCAC6BCB5AFC6BCB4CFC8C0D7D4CDC9C5BFCDCDC8D5D7D4C8CBCCADB1B4A4B1BD
2745603D5D788CA6BB2A4869183C5FA1C0D68AA7BA96B4C4C3DAE1CBD9DACCD7D9CAD4D6
C5CFD1C2CDD0C5D0D2C9D4D6C9D4D6CBD4D9C9D2D7C9D2D9C7CFD6C7D0D5C1CACFBFC8CD
BCC7CBC2CDD2C3CED4C1CAD1BFC8CDBFC7CCBDC5CBBDC1C9BDBFC5BDBCBFAEA9A68A796C
5E883600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE51A83AE4FB0956E
B89C78BC9F7DBFA282BDA283B9A083B6A084B5A082B7A284C0AB8CC1AD8CC9B393CAB697
C9B79CCDBBA1D3C0A7D1BDA6CFBCA9D0C1B1D6CEC1D9D5CFDCD7D3B3AAA0CCBDABD7C4AE
DDC8B3DECAB7DECCB8D9C7B5D9CAB8DCCEBDE0D0BDDFCDB7DECCB3DCCBB3DECEBADBCFBB
D4C8B3D4C5B4D4C5B6CFC1B2CBBFB0D6CDC3C2BFBBCBCBC88C9089CACDC5D2D1CAC0B8B1
C3BAB1D5D0C6D6D4CAC9C7BDCECDC4D8D9D2D4D6CFBBBBB4C2C4BF868B8E949A99ACB1B4
5D6F80536C80B0C4CFB3C7D58BA8BDA2C0D1B4D0E253768DA0C1D0C4D7DECAD4D6CAD3D6
C9D3D5C8D4D4C7D3D4C8D2D4C6D0D2C8D1D7C7CED6C6CFD7C5CED5C3CCD3C2C9CFC1C8D0
BCC5CCBDC6CDC2CBD2C2CBD0C3CCD3C3CAD3BEC7D0BBC2CBBBC1C8BEC4C9B8BEC3A7A6AB
7B736D55863700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002CE41958C934B0956CB09970B6A079
BAA17FBBA182BBA082BDA385BDA489B9A48CBAA58CBEA88BC8B192CAB294CCB498CDB89F
CEBBA3D1BFA7D4C0A8D3BCA5D1BDA6CDC1AFDEDBD0DCDDDADFDCDBD6CBC3D5C4B2D8C3AC
DBC6B0D9C7B1D7C9B4D7CDBFDDD6CDDFD9D0DCD2C5DECFBBDDCBB3DFCAB4DBC9B5D9C9B5
D8C8B4D8C6B1D8C8B6E1D4C5D3C8BAD3C7BCD4C9C4B1ABA6ABA79FC3BDB3D7D4CCD6D2CC
C7C1BAD8D6CDDADBD3D3D3CBC2BDB6CBC4BEC7C2BBB4AFA5BAB7B0B8BAB9B6B8B7BCBBB9
D2D8DCBDCED89CAEB6B1C4D046647E264C6C7CA0B9224764537A91C0D8E2CBD7DACCD4D7
CBD5D6CAD6D7C8D5D5CCD5D8CCD4D8CAD1D9C9D0DAC4CCD3C2CBD1BEC7CEBEC7CDBDC6CB
BBC4C8C1CACEC0C9CEC5CED3C7D0D5C5CED5C2CCD3BBC4CBB8C3C8BCC6CABFC7CFABB1BC
3F4652404042467D341AD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C73484AE51B3986FB1976FB59B74B59F78BAA482
B89E81BAA083BBA286BDA389C3AB92C3AD96C1AB92C5B095CAB599C9B499CAB49ACEB9A1
D2BFA8D2BEA9D1BCA7D1BBA6D4BEA9D4C5B1DDD8CAE0DED7DED8D1D5C7BAD7C5B2D8C3AC
D9C4AEC9BBA7B3AB9DBCBAB4CCCECCDADCDAE0DDD6DACFC0DCCCB7E0CBB5DDCAB5DBC9B4
DACAB3D7C7AED6C6B2DCD0C1D3C7BACEC0B2CFC1B6D6CCC2D3CBC3C7BFB8DCD9D1DBDAD4
CAC9C0C2BFB4CBC8BEC7C3BAC3BAB3C5BCB5DAD5D1D6D4CFC2C0BCD4D5D1D1D6D2A7ABA6
B3BABB5F74842C495F8CA3B6445F7B1033577D9FB69EBBCC7492A5B8D0DCC8D7D9CDD7D9
CCD6D8CBD6D8CBD6D8CDD5DACBD2D8CCD3DBC9D2D9C8CFD6C7CED3C1CACEBCC5C9B9C0C6
B6C0C2B7C2C6B9C4C6BFC9CDC4CFD3C6CFD7BFC9D2BFC8D0BBC6CCBAC4CDBFC8D1BDC6D0
7C8894717F8A62676B66594A1DD61000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0056C835AE936EB19672B39873B39974B49C77B69E7BB9A282B9A285
B79E87BAA28BBEA891C3AD97C3AC96C7B09CCAB59DCCB89ECCB79EC8B399CBB69CCDBBA1
CDBBA2CEBBA3D0BEA6D0BEA6D4C0A8D5C2ACD2C4B2D4C7B9D7C6B6D3BEA8D8C2AAD9C3AD
CCBBA9AEA391CDC6B9DAD8D3BFC1C2CED0D1DEDCD6D9D0C4DCCCBBDFCBB8DFCAB7DCC9B4
DAC8B2D8C6B0D5C3AFD2C1B0D2C2B1D0C1B1CEC2B4E0D7CFDFD8D2C6BEB6CAC1B6CECABF
C3BFB4BEB6ABD5CEC4DFDBD3D7D5CFC4C0BCD9D5D4DAD9D5BBB7B4B9B4B0B1B3AF767B7A
A8AAAC919BA853697E98ABBABFD1DE92AAC0849FB5B5CDDD86A3B56C8C9FC1D9E1C9D6D9
CBD5D7CBD5D7CAD3D8CDD6DBCDD6DBD0D7DCCCD5DACDD4DCCCD3DAC7CED4C2C9CFBEC7CC
BCC6C8BAC4C6B8C1C4AFB6BCB6BFC2BDC6CDBBC6CCBDC6CDC0CBD0BFC9D1BFCAD3BCC7D0
A6B4C08798A88B9CA69CA2A390827100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002AE31980AD4FAE9471B19776B39977B29B75B19C77B19B79B79E80BBA287B9A28A
B9A38DBEA893C5B09CC8B59FC6B39DCAB69FC9B49BC8B398C8B399C8B199CCB49CCAB59C
CCB89FCBB79ECBBAA0CDBDA2D2BEA6D2BCA7D4C1ABD3C0AAD7C1A7D3BDA0D8C1A5D8C4AD
B4A694BBB2A2D2CABEDDD8D1CCCCC8C4C3BDD9D2C8DCCDBDDECCB8DDC8B3DECAB4DEC9B4
D9C6AED9C6AED8C3AED1C0ACDDCDBDDDD0C1C9BCADCFC3B7CCC2B7C5B9ABBFB2A3D3CEC1
DBD8CFD3CCC5D1CBC5DBD8D3D7D8D3C1BCB7C1B8B3CAC4BFC1B9B5B6ADAAD4D1CFC5C7C5
B6B7B3CED0D0C9D4DBA0B2BBA9BCC57A93A8183B5C4F718D5778921A3E5DA6C5D9C7D7DD
C9D4D6CCD5DACCD3DBCCD5DCCDD6DACDD4DACCD5DCCCD3DCCDD6DDC7D0D5C6D0D2C4CDD2
BEC8CDC0C7CDBDC4C7B6BDC0B2BABDB3BCC1B4BEC1B8C3C5B5C0C3BFC9D1B7C5CEBCC9D3
B3C2D03A4B62334A603A515E6E76775B904400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C733
53C733A89067AD956FB09775B39978B59C7BB29C7BB19D7EB39F81BEA78BBDA68CC0A991
C3AE98C9B39CC9B39CC9B29CC8B19AC6B097C4AE93C7AF93C6B195C6B196C9B198CCB39B
CBB59DCCB99FCCBB9ECEBD9FD3BEA5D2BDA5D2BEA5D4C0A6D7C1A5D8C0A2D5BC9EDAC1A8
C2AE9AAB9D8CD2C7B9CAC2B6ACA598CBC1B2DBCCBADDCCB7DECBB4DECBB3DBC7B0DBC8B0
D8C7ADD6C3AAD4C1A9D1C2ABD3C2B0D4C2B2D0BCACCAB9A9D0C4B5DAD0C5C5BCB1CFCBBF
D9D9D1D7D5CFBDB7B0C2BDB6C7C6BEC9C3BFBEB4ADD5D0CBD8D6D3C3C1BEC9C8C5D4D5D2
B6B7B2A8A9A48F9BA130495E506D808099AB23406033536FB4CEE2728EA58FAEC1C2D7E1
C7D4DAC9D4DACBD4DBCDD6DDCFD8DFCED6DECDD6DDCBD3DCC9D2DAC2CDD2CAD4D8C8D0D5
C2CBD0C0C7CDC2CACEC2CACEBDC5CABBC2CBB6BEC4B6BFC4B6BFC6B9C3CCBDC7D1B0B9C6
B8C1D0738193667B8E4D647653657085858261914400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007BAA4BA79169
A7916AAC956FAF9773B09876B39A7AB49C7DB49E81B39E83BBA68DC0AA91C5AE95C6AF98
C4AF99C4B098C4AF96C6AF97C6AD95C5AB92C5AC92C5AE94C5B197C6B299CAB49ACCB49A
CCB59BCCB89DCEBA9FCFBBA1D0BBA2D3BDA5D1BBA3D3BDA5D4BEA2D6BEA1DABEA1DCBEA5
D9BFA8BCA995AC9C8DAFA090C8B8A5D9C8B2DCCAB4DDCBB5DBC9B3DAC8B2D8C5B0DAC6AF
D9C5ACD6C2A8D5C2AACFBDA6D0BDA7D2BFABD4C1AFC9B8A7D0C6B8DAD5CACCC6BBBBB3A5
C4BFB2C8C4B9C1BDB2BDB9AFD2D0CADCDAD6CEC9C5C4C0BBD1D1CCBFBCB8ABA5A0B9B5B2
8B8C899B9D98BABDC16372855D7485B7C8D2B0C2CF8FA8B9A0B8C8AAC2D6577992ABCADC
C1D4DBC8D2D8CCD3D9CCD5DACFD8DFCED8DECBD6DCCCD6DFCCD6DDC9D2D9C8D1D7C7CED7
C3CAD2C1C8D0C4CBD3C8D1D9C3CDD5C3C9D4BBC4CCBBC6CCBCC8CEBDC7D0C1CAD3B0B9C2
AEB6BF9FAAB592A3B198ACBB889BA59CA6AAA9A1993EB02500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A48B64A78F69A7916C
AB9370AE9574B09778B49B7CB49D7DB5A082B8A287BBA38BBFA38EC6AD97C8B29AC4AF98
C1AD95BFAE94BEAB8FC1AB90C4AB90C4AB8FC2AC92C2AD95C5B19AC9B59DCEB89ECDB59A
CEB69ACDB89ECCB9A0CDBAA2CDB9A2CFBAA2D3BEA6D3BFA6D5C0A7D6BFA5D8BFA4D7BCA1
DAC0A4D8C3A8D8C3ACD9C4AED8C3ACDCC7B1DCC7B2DFCAB4DDC9B1DAC7AFDAC7B0D9C3AC
D9C3AAD8C3A9D5C0A9D3BEA6D3BEA7D3BEABE0CFBCCDBCACC8B8A9C8BCAFC3B8ABC2B4A7
C4B9ADDDD8CFD9D5CEC4BEB8CAC4C0D5D1CDC9C2BEB4A9A1B8B0A7C2B9B6B6ADABC8C2BE
CECECBC1C2C0BDBCBDCED3DAB4C1CB95A1A9A0B1BD334F692B4E6E7F9EBC16395E648AA5
BFD7E1C9D4DACBD5D8CCD3D9CFD8DFCDD6DFCCD6DFCDD6DFCDD6DDCDD4DCCDD6DDC7CDD8
C7CED7C1CAD1C8D1D8C9D1DBC8D2DBC6CFD9C3CCD5C5CFD6C0CDD3B8C5CDBEC8D1B2BEC4
B0BAC0A0A6B1414D5E44596D5268756C7C8091979395847500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0028E11979A64CA68F6CA7916FA99171
AB9273AE9678B19B7EB29C7FBBA287C2A88CCAA98FC89C87C79782CDA48AC4A88EBEAA90
BBAA91BBAA8FBBA78AC1A98DC3AA8CC3AA8DC5AF95C5B199C7B29CC8B39DC8B399C9B196
CAB59ACCB9A1C5B6A0BEB39FBCB39FC3B8A4CBBEA8D1BFA8D2BEA6D6C0A5D7BEA5D9BFA5
D9C0A4D9C3A7D7C3A9D8C4ABDBC6AEDBC7AFDBC7AFDCC9B1DBC9B1DBC9B1D8C5ADD9C4AC
D9C2A9D9C1A9D6BDA6D4BCA6D3BAA4D0B9A4D0BAA7CDB9A6C9B5A4C9BAAADCD3C8D6CCC2
C1B5AAD4CCC0D2CDC3C4BDB2B7AFA4C2BAB0CEC6BFC1B8B0C2BCB4DAD6D2D4D2D0B9B7B3
CECFC9C4C5C0A1A09CACADAF566573364D5F96ACBA3C557214355997B5D086A2BB608096
BDD6E1C6D3D9CCD4D7CDD4DACFD6DCCED7DECBD6DCCBD4DDCED7E0CED7E0CBD4DDC4CDD6
C6CFD4C4CDD2C5CED4C6CFD8BFC9D1B7C3CCB4BEC8C5CFD6C5D0D6BEC9CFBDC8CEB6C1C7
B4BCC2B1B4BE565D6E5565794C606F6577817F8B8E9088843DB02800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A18866A18A689F8A68A18C6CA59173AA967B
B09D83B5A48AB3A28ABCA690C3A38EC69984D79482B65B4B9D3423BB644CCC987AC2A586
BBA688BCA68BBEA58CC1A78DC4AA8DC4AB8EC4AB91C4AD95C6B099C6B099C5B096C7B297
C2B29BA49B89817D707170656C6D656C6F678C8E81BCB4A2D1C1A8D6BFA7D8C0A8DAC2A9
D8BFA4D9C3A4D7C3A6D8C4A9D8C5ABDBC6ADDBC5AEDCC8B1DBC8B0DAC8B0D9C6AED9C4AC
D9C2AAD9C0A8D7BDA6D3BBA3D2BBA3D1BBA4CFB9A3D5C1ADCFBCACC8B8A8D5CABCD0C7BB
BDAFA1C1B2A2C8BDAECEC6B9C2BCB0C7C2B9DAD7D2D6D5D0B8B5B0CBC6C1CAC6C1ABA8A0
AFADA4ABABA88C8E8CB6B6B899A2AD586C7C9BAAB6BDCCD796AFBE8DA7BAA9C1D068879C
89AABBC3D5DECDD5D9CDD4DACFD6DCCED6DDCAD5DBC9D4DACBD6DDCBD5DFC9D4DDC5D0D6
C7D2D6C7D0D7C4CDD4C6CFD6C2CBD2B5BDC6A9B1B9B4BBC3C2CDD6BFCAD3C4CED8B8C1C9
B8C0C8BBC1C8909BA481939F8297A28DA0A9A1AFB6ACADB095837A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CC22F9885619A88679D8B6BA39173A59377AC9B82AE9E85
B2A38AB3A48DB6A68FBDA491C99A89A14E3DA52E1FB32418B42012A12912C98365C5A182
BDA386C2A78FC2A78EC4A98EC3A98BC4AA8CC4A98EC5AB91CDB49BC7AF95C5AE95BEAE97
8F87757272628A87789A94869A93887D7D7560645E74756BBEB5A1D3BEA6D7BFA7D7BFA8
D6BFA6DAC2A7D8C1A5D8C4A7D8C5A8DBC7ADDBC7AFDBC5AFDCC7AFDDC9B1D8C4ACD9C5AD
D8C3AAD6C0A7D9C1A7D5BDA3D5BFA7D3BEA6D0BBA4D3BFABD0BDABC8B6A2C4B59FC4B7A4
C7B8A8C1B3A3D6CFC3DBD8CFD8D6D0BFBCB5CBC9BFCBC8C0B3ACA5B0A79ECCC4BDC8C4BF
B3B1ABD4D4D3CACBCDB0B0AFC4C7C8C2CAD097A0A7A0AAB26B82932245646A8BA9345573
315473B8D3E2C9D7DBCCD3D8D1D8DECED6DFCDD7DDC9D4DACAD5DBCCD6DFC9D3DCC8D4DA
C9D4DAC3CCD5C6CFD8C6CFD8C7D0D8BFC5CFAEB5BDAEB7BEC0CCD4C0CED5C2CED6BFC8D1
C0CBD4BCC8D18494A1374C5B415966667E8685979EA4ACB3B0A9A840B42B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CC2309989649C8E6BA19274A19278A6967EAC9E85AB9D86B1A28A
B0A188B4A48BB6A28ABF9C87B6715EA83A27B12715B52110B22410B64B30D09475C4A285
C0A589C3A88CC2A78BC1A78AC3A98AC4A98BC6AB8DC6AB8DC8AD91C5AA91C1AC96968A7A
6D6D5F919283A39F8CA69F8AA9A18F9F9A8D7679725B615A92907FCEC0A5D4BFA4D5BFA4
D8C1A6DAC1A7DAC1A3D8C0A2DAC4A8DBC7AED8C7ADDCC8AFDCC8AFDBC8B0D8C6ADD6C5AB
D6C3AAD5C0A8D5BFA7D5BEA6D2BCA4CFBAA2CFB7A2CFB8A3CAB5A1CAB6A2C4B49DD2C5B3
E1D4C9C1B5AAC1B9ADCAC5BBC6C4BDB8B4AAB7B3A7D2CFC5D3CDC8B7B1ABD5D2C9D5D4CF
BCBAB6BCBAB6C2C1BEA8A7A1A0A19A939A9E3546566C7F8E849AAE17375A41607FA0BAD0
526F83A7C1CCC4D5DAC9D5D9CED5DBCED6DECCD5DDCBD4DBCBD4DACDD6DDC8D2DBCAD3DC
C9D2DBC4CDD7C4CED6C3CDD6C5CFD7C6CDD6BAC2C7ABB3B8C2CDD2C0CDD5C1CBD3C1CBD5
C2CFD8BECCD797A7B72F43583E56694A64726F858E96A3AA98989A62954D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0024DF179787649C8E6C9D8F72A1927BA49680A69A85A79B85AC9E87B1A18A
B2A189B6A48BB39B81BE91769C432DAE3720C54D33DA6B509D381DCB8164CB9F82C1A488
BFA589C0A789C1A88AC1A887C2A987C3A888C7AA89C7AA8AC5A88AC2A78BB3A48F676557
77796C9E9C89A6A08BA59E8CAAA291A8A0927F80775D675F737868CABEA6D3BCA0D6BCA2
D6BCA4DAC0A7DBC2A4DBC3A4DAC4A8D9C5ACDBC6AEDCC7AFDCC7B1D9C6AFD9C6AED7C3AA
D8C4AAD5C1A7D5C1A8D5C0A9D3BCA5D1B8A2D0B7A1CEB7A2CBB7A3D6C3B1C4B29FC5B4A3
CCBDAEC2B2A3BDAD9EB6AB9ECBC6BCD1CCC7BCBAB2D3D2CCD7D7D2C1BCB8B6AFA7C1BBB4
B2ACA4A59E95C0BCB58F8F8B9EA09CC7CCCE64717F647280C0CAD2ACB3BF8F959DBABBBC
B1B4B6909A9FC7D2D5CAD3D6CDD6D8CED6DBCBD5DAC8D4DBC8D3DBCAD3DCCAD3DCC9D2DB
C7D0D9C7CDD8C7CDD7C3CBD4C4CBD1C0C5C2C6CBC2C4CBC8C0CACEBECCD3BDCAD3C2CFD8
C2CFD8BECAD7AEBCCB7B8B9A7689976277827E939C9DACB4B6BBC0978C861BD40F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
22DD146699408C7D5B9586659B8D709B8E75A2967EA3977FA79C85A89B83A99980AE9D83
AC9A7FAF9D80B49D80BD9277A7583E982E14AB4A2BD58B69AF7554C79A7BC0A084BFA48A
BFA388BFA286BFA385BFA385C2A587C2A484C3A485C3A585C5A888C0A68B9588755C5D52
7A7F70989983A09C84A29E8A9E998B939084797C775A645E727769C6BBA3D1BCA1D6C0A5
D6BDA5D7BEA7DAC2A7DAC2A4D8C1A5D9C2A8DBC5ADDAC5ADDAC6AED9C5ADD8C4ABD6C3AA
D8C5ABD5C1A8D6C2AAD4BFAAD2BDA8D1BCA4CFBAA2CDB8A2C7B5A0CBB7A3C9B39EC5B09B
C2B09ECCBCAAC3B4A4BBAFA2D0CABFD6D5CFC4C2BCB6B1AAC1BBB3B7ADA7B1A49DC3B8B1
D2CCC6BFBAB5D1CDC8CFCBC9C2BCB9BAADAAC4AFB1B39697B38C8BC39392BB8782BA827C
B98481A67A7CBE9B9FC8AEB1CCC0C2CECDD1CFD3D8C9D1D7CAD4D9C7D0D6C7D0D7C9D2D9
CBD4DBC5CED7C7CED8C7CED7C9CDCDB1AE95ADA87DCBCAAEBFC6C0C2C9D1C2CBD5C1CDD9
B9C7D2C2CEDCBCC8D56A76864D5E6D63758076878F859299A1AAADBEBBBA43B83300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0021DC15
8473548777588B7C608D80659589709D917AA29680A39880A99E85A99C81A99A7EAB9A7C
AB9A7CAE9D7FB39F7FB99B7DC59779BA7F60B37C5AC59D7BBE9D7EBEA083BBA084BCA286
BFA386BE9F80C1A382BFA081BEA080C1A483BE9F7EC0A280C2A482BFA4868A7E6A595D52
6A7367838774898977898A7C82857B767C75646E6C57625D818272CBBFA7D0BFA3D2BEA3
D4BFA5D5BEA6D9C1A7D9C1A4DAC2A6DBC5AADBC6ADDAC7ADDAC7ABD8C3A8DAC5ADD8C4AC
D8C2ABD7C2ABD7C2ABD6C0ADD3BEA9CEBBA2D0BDA4CDB9A1C8B49DCAB59FC7B39BC7B29C
C3B29EDACEBDCCC0AFB9AC9DBCB1A2BFB7ACB7B0A5B0A69BC7C1B6D7D1CDC9C2BFC8C0BD
D7CFCDD1C5C2B8A19DC19B95B6817BAB635FA347479F33329F2423A42021A41C1CA31919
A2191C9E1C219B232A9F363DAB585EB78084C4A7AACFC5C8CFD1D3CAD2D6C5D0D5C9D2DB
CBD5DEC7D0D7C5CFD5C3CCD2C7CCCABAB89AA69D5DB3AB6ECBCBB2C6CACCC4CDD6BCC9D5
B2C1CCBBC9D4B7C3D06A76892A3C4E495F6D62748079888F7F898B9C9D9E88726700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00817154
837359887A60847B618B826A9990779F957CA2987FA39980A69C82A59A80A7997CAE9C7D
B19E7EB29F80B39F7FB59E7FB89E80BA9C7FBCA081BAA081B89E80B89F82B89F80B99D7D
BB9D7DBEA07EBEA07CBEA17EBEA17FBEA07CBE9E78C0A078C0A278BDA17B8E7C6455544B
5A635E676E686D736D6A726D67706B5D6A6654625F5B645AA7A38FCDBEA3D0BFA1D2C1A3
D2BFA3D4BFA4D7C2A7D8C2A5DCC4A9DCC5ABDAC6ADD7C5ABDCC9B0DAC5ACDBC6ADDAC7AE
D8C3ACD6C0A9D5BFA8D3BDA8D4BEA9D0BCA5CCBAA2CCB9A2CBB79FC9B59DC6B59CC4B29A
C2AE99C1B09DBFAF9BBDAC99BCAB98BDB4A4D6D0C6C7C0B9C4C0B7D4D5CED0CCC6B5A49D
C3A19CBC8480AD5B56A53733A1221DA31512A80E0FAC0C0EB20B0CB70C10B50B0DB70A10
B30A0EB30A10AE0910AD0C14A70F159D181D9A3337AA666BC8A4AAD4CBCECBD0D4CAD3DB
CAD5DCC9D4DAC5D0D5C5CED5C6CFD0CACCBCB6AE7CADA25CC7C190C9CBBCC1C9CDBAC5CF
B7C5CEB5C2CBBFCBD88C98A86573816577825C70787B8C9399A8ABA5ABAF96898300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001FDA145D913E7B6C53
7C6F5780765F847C668A846D958E779A927CA09882A19A80A49B82A89E85A99B82AC9B81
AD9C80AE9D81B09E80B29F81B4A080BAA384BAA183B89F80B59D7DB69E7CB49C77B49C77
B59C78BDA17FBA9C7ABB9C79BE9F7BBF9E79C09F76BE9D72BE9E6FBE9D70A58C6D5C5548
525855535E5D56636055615E515C59505B57545C52898776C4B7A0D0BCA2D2BFA1D2C0A3
D3BFA4D5BFA7D3BFA6D7C2A8D9C3A8D8C2A7DAC4ABD9C5ACDAC7AEDAC6AED6C4AED7C5AF
D8C4AED9C3ADD5BFA8D3BFA8D2BEA9CEBCA5CEBBA3CCB8A2CCB7A0CAB59EC7B59CC1B197
C1AE96BDAA95CAB8A6D2C1B0C2B1A1C3B7A8D6CFC5D3C8C1B2A49AC0ABA2C6A098B6726B
AB4740A42421AA1715AF0F10AF0A0CB2090AB4090AB4070BB6080AB7080AB70709BA080C
B7070AB3040AB3060AB5070AB2070AAD080DA90E149A111A972E37B2757AD1BBBFCECFD5
C8D1DAC7D1D9C4CFD5C6D1D7C4CFD2C4CDCBC2C3B0B1A87AA69A62BCBA95C0C6BCBEC7CC
B8C1C9B6C3CBB7C5CFA7B4C26978885C6E786D7F847F8C92929DA2A3A8ADACA6A21BD40F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00786951726953736C57
8C85748F8877857E6C8B8471958D7A9C9480A39984A49983A79C86A69A83A79A80AA9980
AB9A81B1A087AF9E82B2A184B3A184BCA88BBAA185B79E80B49B7BB39A77B19A73B29C75
B49D77B79C79BA9C78BA9A73BA9972BF9D76BF9D74BD9A6FBC9B69C0A06DBCA07589775C
5955464E564A555E536064597471647E76678E806CBDA990CBB599CFB99ED3BDA3D3BDA4
D3BDA5D4BCA4D3BDA5D5BFA6DAC3A9D8C4A8D8C4AADAC5ADDCC6AEDAC7AFD7C5ADD9C7AF
D6C3ABD6C1A9D6C2AAD4C1A9D0BEA6CDBDA3CDBCA2CBB9A0C9B49CC8B39CC8B49CC3AF97
C7B099C2AB97CCB9A8D4C4B4C8B7A8BCA899BCA899C1A497C69889BC7468AC433CA61E1B
AE1210B30D0BB50B0BB6090BB40608B5060BB30608B30607B40808B50808B50707B60608
B40406B60609B00406B30608B40608B00609AF060BAB070DA30B1295191DA25357C9ACB0
CDCDD3C6D0D9C5D0D9C5D0D6C3CED2C3CDD0C5CBC9C7C6B4A9A173A29D66C2C3A5C2C9C6
BEC6CCB5C0C9B7C3CDB3C1D03F5067293C505E727F82949C849096848B8E9894903DB229
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001CD81270684F6D6C5885877A
BDBDB6A7A59D868172918D7897917D9B9480A29A85A49B87A79D88A49880A89A80AA9B7F
AB9B80AFA084AF9F84B1A187B19F83B9A387B39B7DB59C7DB29978B59B76B49B73B49C74
B39C73B79E76BA9E73B99B6FBA9A6FBE9E75BB9870BD986CBD9968BF9D6CBF9E6EBA9C70
9E86637F70528D8165A08F74A99278B69D81C5A98AC8AC8ACCB293D0B99CD2BDA2D4BEA6
D3BDA4D4BFA4D3BEA3D5BFA7D8C2AADAC5ABD7C1A8DCC4ADD9C4AED9C7B2D4C4AFD4C5AF
D6C4AED4C2AAD5C3AAD2BFA6D2BEA6D0BCA4CEBAA1CCB89FCAB69EC8B49BC9B59CC7B39A
C5B098C9B29CC6AE9BC3AC99C2AB98C2A492C89C8AC68073B24B41A9231CB01410B30D0C
B90D0BB80B0BB6080AB5060BB6070CB5060BB40709B70A0BB30907B50B08B50907B50709
B6080AB4050AB00506AE0405B10707B10707AE0606AF060AAC060BA7090E951116954248
C5A6ACCDCBD2C8D0D6C4CFD5C1CCCFBFC8C4C4CBBFCBCCB3C4BF86A19949B7B278C7CAB7
C3CACCB7BFC6BAC4CDBBC6D35161733445575D7180697F8990A2A99FA9AE92918D3EB42D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF001BD711508939726F5C939788B5BFB7
C1C7C6B0B3AF86867A91907C94927D9B9782A09A87A29C88A19A84A49B81A89C82A99B80
A99B7EAC9E81AD9E83B2A186B19D7FB1997AB19779B09677B19774B49B74B19771B39A74
B39971B59870B49669BA9A69B79766BC9A6BC09A6EBE986BBD9968BE9C69BD9D6BBE9E6E
BE9D6FBE9F72BDA076BFA47CC3A67FC8A682C8A781C9AC83C9AF87CCB593D3BEA0D2BEA2
D1BDA2D3BEA5D4BEA7D5BEA6D7BFA8DAC2AAD8C1A8D7C4ACC9BCA8B1A8979F9789A29A8D
AEA89AC3BBA9CDC2ABD1C2A8CFBEA5D0BEA5CFBBA1CDB9A0CAB69DC9B69EC8B59DC7B39B
C6B19AC8B09CC7AC98C5A793CDA795CE9383BA5D51AA2924B31715BA0E0FBB0B0DBA090B
BB0A0AB8090AB9090BB50508B40608B50709B50909B60A0AB60909B70A09B80A0AB80A0B
B7090BB5060BB20509B20509AE0305AF0506B00607AD0305AC0408A9060CA3080D950F15
933E42C7A8ABCBCBCEC4CDD1C5CDCBAEAF9AAEA977B8AD62AFA339A79920A59C39C8C795
C5CBBDBEC7C9BCC5CDB7C0CA7A89926675816B7C857B8C948E9FA59CA9AEA8ABAB6A9C52
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004E863367604A6B685796998FB9C3BFBFCBCB
C2CCCDB8BCBB8A8B838D8D7B9795819D99869F9A87A19C89A09A83A39C82A49C82A89E83
A49679A99A7BAA997DAB9B7EAF9B7CB0997AAE9776A9916CAD946DB39872B59B76B09571
B3956FB7976DB9986AB69563B99863B99662BB9565BD9767BF9A68BE9C6AC1A070BF9F70
C09E6FC49F71C3A175C2A378C3A37AC6A57CC7A67EC9AB83C7AB84C8AE8CCFB698D2BCA0
D1BFA2CEBEA2D2BFA6D6BDA7D7BFA9DAC4ADD5C2AFB8AE9C8A8776908D7DA7A0939D958B
7C786F7C7C72B8B4A4CEC2ABCDBEA5CEBEA5CDBCA3CEBAA2CBB79ECAB59DC9B39DC7B29D
C7B19CCAAE9BCFA797D49E92CD7E73B03D35AF1B16BB1211BD0C0EBF0B0EBC0809BD090C
BA070ABB070CBB080BB70509B40608B30608B20707B40708B40408B6050AB7070AB7070A
B30507B10308B1070CB0040AB10509B20509AE0407AE0508AB0507AA0509A70409A4090C
931114984749D3BABACACECFC6CFCCC1C2AFB1A770AA9A3DA9991AA9980AA49511ABA33E
BDBE82C3CAAFBEC7BFB6C2C48A9AA63F55674D6877748E9891A4AA8893998C8E908A786D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00518633665F4B68655790918BBAC2C28FA0A4A9BBC1
C2CED2C4C8CB8B8D868D8E7F9696849C9A889D9A899E9C88A09B85A29C85A59C86AA9D86
A7977BAA9979AC9979B29E7FAF9B7CAD9978B19B79AE9975AE9874B19877B49B7AB29775
B49570BA9970B59467B89364B7925EB9945FBD9661BE9866C39F6EC5A172C3A073C19E71
C19F71C19F71C2A177C3A47DC6A780C7A780C8A881CCAD87CAAC87CCAF8DCDB394CEB69A
D0BDA0D0BFA2D4BFA6D6BDA7D9C0AAD6C0ACC3B3A57E796D999789B8B1A0C0B4A3C3B4A7
AFA49B74736D76776EC5BEACCFC0A9CFBFA6CFBFA5CDBBA1CDB89FCEB59FCCB39DCBB29C
CCAF9AD4A696D2837ABD5149B12923B71512BD0D0DC20B0FC0090DBE0A0DBD0B0BBA070A
BA070ABD080DBA070BB60609B40608B20608AF0507B3070BB1060AB20609B2070BB2080A
AE0909AB080AAC0A0EAB090EA9060AAE080DAE0708AD0508AB0608A80307A80307A80607
A1070B880D12A66668D1C6C7C5CFCEC3CDC7C3C5AFBAB481A89938A19009A69602A79A0C
A79F25B2AE55B7B985C3C9B4A9B3B13547513C56644F6975798F98A0AFB6A0A5A8897A72
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF001BD711665D476764548A8C85B4BABCB2BFC45A7178637D82
C1CFD3C8CCD09092908C8E829494859695869A98889D99869C9683A19A85A59B87A99B86
A6967DA89879AB9A7BAE9B7BA79472AB9975AA9775AE9C77AF9B77B19B79AF9676B09573
B49671B39369B69566B59260B99460B9935DBD9660BC9965BE9D69C3A172C5A377C5A277
C5A175C19E74C1A177C5A67EC5A880C7AA83C9AA86CCAE8AC9AB87CFB18FCBB091CDB596
CCB89AD2BEA2D3BEA6D5BFA7D8C1AAD6BFAF9C8F8475736BA4A299BCB7A8BEB5A5C2B8A9
B1AAA083847F5F6660AEAD9FCCBFABD1C0A7D0BDA4CFBBA3CEBAA3CDB7A1CFB6A1D1B29F
D8A595CF766CB7342CBD1F18C11510C30F0DC20D0BC1090BBF090BBC090BBA0909BA0A0A
B80809BA070AB70609B40607B30709B1070BAD080AAA090DA70C0DA00E0F9D13159D1C1F
9A242798282D95293092242B921B2097141B9D0E12A20C0FA5080BA70609A70405A90506
A604099B080F831C21BF9697C8CACAC1CECFC4CBCBC6C7B6ACA363A19018A99704AD9C04
AF9F08AC9F14A59A2CC0B96EB9B8886A70586C7A7568787C7180848F9DA09DA4A6A29793
1BD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004C873464645285887FA9AEAFBDC5CD909FA75C7076798C91
C6D1D7CBD2D68F95928B8F848F92849596889B97889F98869D96839F9683A29482A49582
A3947BA5977AA7987AA59476A79474B09B7BAE9978AC9771AE9970B09A72AD9671B49B78
B39671AF9167B59466B59361B7945FB7945EBB9460BF9965BE9B68C1A070C2A175C2A176
C19E74C09E74C4A379C5A57CC3A37AC5A57CC8A782CFAF8FCEB190CBAF8ECDB293D4BB9E
CEB99ED1BBA3D2BEA6D4C0A7D5C0A9D4C0AF897E7575736F93948FA9A89EAEAB9EAAA69A
9B9C94767E795B6760A2A496CDC1ADD0BEA7D0BEA7D1BFA8D2BEA9CEB6A2D5B2A1DDA094
C9635BB62621C21814C7130EC7110CC70F0CC50D0BC30B0BC00B0ABC0907BA0B09BA0A0A
B90909BC090CB60708B40A0AAF0F0DA40F0D9A16149B292B983E44924E58885665734E64
664E675C4A655A4B655F4F666E5568835B6B8D4F5A8C30398E141A9E0A10A5080BA9060B
A6040AA1040A920E128D3F42CFBDBDC5CBCFC2CBD2C2C9C5BEB990A69732A7930DA8970A
AE9E08AE9E04AA9A06B09F19A99C2977712B5F68536A7B7D889A9E8C979A848688968A84
3AAB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF001AD81262604C7D8378A1AAA9AEB8BCBCC6CEA3B0B7B1BEC4B9C4CA
C9D1D9CBD3D79EA4A28B8E859393849591839B93879D94859E95849E9582A0927FA39481
A39680A3947AA4957AA5957AA79478AF997AAE9676AB936EAD976DAD996FAA956EB39A77
B69B78B2936DB39366B2915FB3935DB5935DBA9561BD9765BF9C6BBE9D6EC09E72C3A076
C4A076C5A47BC5A67EC3A47DC4A47AC6A57BC9A881CBAC8ACBB190CBB190CBB293D1B89C
D3BAA2CFB8A0D6C0A8D2BEA5D6C1AAD8C2B08E83796F6F6E7D807F8A8F888C9189838B83
757E7B5F6F6A5C6960B0AF9FCFC2AED1BFACD1BEACD3C0ADD5BDAADAB4A3DF9C92C1504B
BA1F1DC61513C9120FC60D0AC60D0ACA110EC9100DC50C0EC20B0DBD0A0CB9090BB9090B
B80A0BB80D0DAE0D0DA31516A030329E4C5386566260496237335522295219234F1B2652
212E55303D633B496B3A4B6C32456838496C323C5B5A4D658856668D2F3A96121AA1090E
A5060AA305099E0A0D821316B88A8CC6C5C7C2CCD2C3CDCCC1C3A8A3974898891F645806
9E9312AC9E08AFA003AE9E04A696098D831E3D3F1E394A4D657B8494A2A8A5A8AA9A8F8D
3AAC2400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00655F47676C5E99A5A0ACB9BCB2BEC4BBC8CFBDCBD2C1CFD7C4D1D7
C8D1D7CCD2D5A7ADAB8A8C838E8E809995869A94869C95879D95859F95839E927FA0937E
A39781A3957DA3947BA5957BA7957AAC9478AA9172AB9570A8956BA9966BAC966EB09872
AC916DB0916CB19165B09360B1945FB3955FB89562BD9966BB9967C0A071C5A67AC7A67E
C7A57FC3A37DC3A681C6AA84C4A780C6A680C9AA85CBAE8CC9B18FCDB595CBB495D1B99D
D2B9A0CFB79ED3BDA4D4BFA7D6C0AAD7C1AFB4A4996A676362696867716F69737063706A
5E6D675B685F7F8678C4BEACD1C3AED4C3AFD6C3AFD7C1AEDFBBABDF9B8FBD4843BD1E1E
C91314CC1011CB0F0FCA0E0ECA0E0DCB0F0ECC100FC60C0DC30C0BBD0A0BBA0A0AB50C0A
AE0F0EA61D1EA53F42985B69674E6835355A16264E182C552F42665A6A89697289848595
9898A3969BA8A4AEBC94A6BA3451718CAFD16B8EA89EB3C98787998B6C7C954856921921
9F0A10A10409A0060A910D108D4346C6B8BCBFCACFC2CECFC5C9B3A59A5592832855490B
71680B988F0FACA20DAD9E06A797069D8F177B75346970636F7B807E898E98A1A3A7A6A4
47BE3800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0033AD225E60518D9790A9B6B7B3C1C8B7C5CDBAC9D1BECED6BDCED5BBCCD2
C5D3D8C9D2D5B3B8B88488818B8C809391849894889A94889F968AA095879E917FA2937E
A2937CA2927BA4967DA09177A39076AA9176AA8F72AD9573A8926CAA946BAE976FAC936D
AC9168AD9062B19160B2935FB39562B39462B69665BA9966BF9E6DC4A477C8AA82C8AA85
C5A583C6A785C3A684C4A886C7AB88C8AA88CBAD8DCBB092C9B091CAB495CAB699CEB99E
D2BCA2D0B8A0D2BCA4D5C1A9D5C2ABD6C2ADD5C1B0A6988C6C69616C6F69767B727D8276
7F827689887ABEB7A6D0C3B0D2C2AFD4C1B0D5BEAEDAB5A9E29C93C14A44C01E1CCE1517
D11114CD0F11CF1113CC0E0FCC0E10CE1012CC0C0FC80C0EC30C0CBD0E0CB2120FA81F1D
A9444898606F584A66232D56142855273C624D607776808C8C9196AEB1B4B5B9BCA9ABAD
CCCFD56471817A8D9E90A4BC0B284F2F547C7BA2BAA5C3D0C7D6DFC6C6D0B99EA79D565D
901A209E0A10A1060A99080D7F1B2093717BBFC5CFC3CCD2C3C6ADA49C4F8B7B1B6C5B13
7F731B4D4801959219A39B0DA19403A3940C978E2B8E92668A968C97A2A3869091888987
689B4E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00488234787E75A9B3B4B0BCC4B1BFC8B9C7D0BDCDD6BFD1DBAEC2C9B3C6CD
C3D4D9C6D1D6B8C1C28388848B8D82919185939185969286A0988DA09689A09586A19382
A2927FA4947DA3937BA29278A49277AB9378AB9174AF9576AC9472AB936EAD956DAB926A
AB9165AD9061B1915FB1915EB49562B49565B79767BC9C6ABD9D6DC1A175C6A67DC3A47E
C5A683C5A687C6A98AC6AA8BC7AD8CCBB090CBB094CAB196CCB498CAB498CDB89DCCB69C
D0BAA0CEB79DD2BEA4D3C2A9D5C2ABD7C2ADD9C4AED9C7B3C0B3A2B3AA9AB5AF9FB9B3A3
BFB6A5CEC2B0D3C4B3D6C6B6D7C6B6D5C1B2DDBAADE09B92BB453FC72422CF1716D01313
CF1111CF1111CF1110CD100ECB0F0ECD0F10CE0E13C90E0FBD100FAD1A19AB42449D6471
57486622305D162F5C32476A69738A8E919AB0B2B1C5C5C2ABACAACED1D2B3BBC28C959D
C6CED6556477384C61A9B9CB62758C4D678090ABBCB7CCD6C5D5DDCAD2DBD3D1D6C1A6AA
954A4F91151C9C070B9B070A820B117A444EAAABB6C2CBCEBDBD9DA49A3F958313826C0C
90801A4D46016261087471089B940FA19407A2961778721A696F3E8C9782ACB8B1A3A6A0
82756200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006F6D5EA3ACAAB2BEC3B5C1C9B6C4CBB8C6CEBBCBD5A7BBC480979FB3C8CF
BDD0D6C1CFD4C0C9CC868C898B8D848E90849392869491869D978C9A9285A197899F9383
9E917F9F927CA2967DA3967BA5967CA49278A99477AA9272AD9572AC946FAB926BAB9269
AB9065AC8E61AF8F5FB49463B29260B59462B69664B99968BE9D6EC0A074C0A279C2A680
C3A886C4A78BC5AA8EC5AA8DCAB092CBB394CBB295CAB197CCB49BCEB8A0CBB79DCCB79C
D4BFA3D0BBA0D0BCA2D4C0A7D6C1ABD7C4AED7C4AEDDC9B3D7C6B1D8C8B5D9C8B7D7C7B7
D7C6B6D8C7B6D7C8B6D7C8B8D6C2B4D9BAADE3A297BF4B44C2221DCD1614CF1311D01311
CF1211CE1111CC0F0ECC0F0DCC0F0DC90C0DC71212B81717B4383AAB6573675573253662
143261334D756D7C90A0A5A7CBC9C5B9B4B1C4C1BED1D0CFC6C2C5B8B1B3C9C3C7A29C9F
ACA4A2B3AEAFA5A8ACA1A7ACBAC7D25972886B89A1A4C0D2BAD0DCC7D4DDC9D1D8D1CED3
B89399882D34940E13990509900A0E7E3039897D87C2CCCDB6B895A5993CAA9715A58E07
A48F13645703554F0B4849086E6E0C968F0E9F93089B8F0C9C972887863B989B76A9AB9E
9D908400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF003AB62A92978EBAC7CBB2C2CAB5C4CDB3C3CCB4C5D09EB2BD7D949D81989EA0B5BC
82959CC2D0D8C5CED3868B8C8A8C859191869594879D998D9D988C9B93879B93859B9281
A09583A29584A09480A39881A59881A3937BA69377AC9576AF9577B09575AB906BAE936C
AB8E66AE8E63B09062B39464B59463B59363BA9568BD9B6DBD9C6FC0A076C5A882C2A988
C4AA8CC4AA8EC7AD92C6AC91CAB196CAB498C9B599CBB69BCBB89DCBB99ECCB89DCDB89D
D2BEA3D0BCA3D2BDA4D4BFA7D6C1ABD6C2ADD5C2ABDAC6ADD8C6AFD8C6B3D9C9B8D6C8B8
D7CAB8D5C6B4D4C5B2D4C2B2DABDB0E4AA9FC3564EBF221CCD1812D0140FCF100CCF110E
CF1210CE100FCC0F0FCD1010C80E0DC21515B72629B557647F5A743138651430612B4971
677B92AFB6BCB3B2AEB0ACA1D7D1C8D3C8C4B3A09EC9AAAABF9595B27D7DAD7473AC7270
B17B74C0938EC8ADAC8A8083B8BFCA2239590F2F58799AB4ABC3D1C7D5DDC9D3D9CDD3D8
CFC1C7A36B7185171F99090F970B0E81212969505CBFCAD0C1C5B5AEA467A9972AA8930C
A8930A928006867A135049046563116965069B910CA09305A6980BA7991C998F37908A5F
9588731CD40D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0069A454B6BDBDBBCAD4AFC2CCB7C8D3B4C6D19CB1BC76909A79939B8BA2A88CA1A6
A7B7BDC7D2DAC8D0D88F9396888B8690908798978B9F9B8F9B968A9891849D95869E9584
A29886A59A88A39885A29782A0937EA1927AA59479AA9576AB9273AE9471AD906AAE9069
B09268AE8F62B09062B29263B49364B69467B8966ABB996FBD9C73C6A681C8AA89C1A78A
C5AA90C4AA90C5AC90C8B093C7AF94CAB39BC8B298CAB499CDBA9CC9B89AC9B698CDB89B
D3BEA2D2BDA3D4BEA7D4BEA7D6C1ABD6C1ABD8C4ACDAC6AEDAC7B0D7C7B1D5C7B4D4C6B3
D5C6B2D6C5B1D3C2AED6BFADE5B5A9CE6C63BD2720CF1A15D51511D4170ED3150ED1110F
CE110FCE1210C8100EC31311BA1A19B74146AC7084554D791B3367213E6B5C6F8A92979F
A2A09BC3BDB4C4B8ADAC998EBA9B92BD8B87B16663A84344A52D319F1E219B17179B1417
9D1A1A9920219D3B3DAB686ABC9DA07A7988364762748CA1B6CBD4C8D5DCC8D1D8CAD2DA
D3D2D7BF9FA4852E38930C1499080D83171F603F4DA9B7C2BBC7C8C6C6B3ADA667A39327
A6930BA18E04A7971283760A5C55064A46019891139B90059D9104A69A0AA39618B0A351
A3936B3AAA1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A09E8DBFCBD0B4C4D1B2C3D2B1C2D1A2B4C2768E9B738F9A7C99A36A868D92A9AD
BECED4C7D2DBCAD2DA969CA0888B878F908696958999978A9F9A8E9C95889D9486A09787
9F9584A19886A39986A0947FA0937C9F9078A39379A89479AB9376AA9070A98E69AE9269
AD8F64AF9063B09063B39265B59368B8956BB49369BF9F76BD9F78C0A27DC2A585BFA387
C3A98EC1A98DC5AD90C4AE90C9B498C7B297CAB499C9B298CAB59ACAB69BCBB79DCDB9A0
D3BEA5D4BEA6D5BDA7D7BEA8D6BFA9D6C0ABD6C0ABD7C2ACDBC6B0D8C6B0D7C5AFD8C5AE
D6C4ADD8C6B0D8C2AEE2BBACDB8A83BB312DCB1C15D41911D41710D21510D31410CF110F
CA100FC61311B81917B12E2FB85C678262802C3B6E1B3C733E5B828791A0A6A19FAD9E94
B19D8FB59A8DBF948AB6716AAB4A46A22826A51515B31214B20B0FB0090EAC0708AB060A
AB0709AA080CA50B0F9813159B3E3BCA9E9FA5A3B15A7288B1CBDBC1D1DAC7D1D8C8D1DA
CBD1D9CFC2C995565F89121C97080F851017693C47919CA9B4C6CFBAC3C4BABCA7AAA25F
A3941FAC9B0BAE9F06A798099185106E6404988E10817707837B079E9508A49809A2941D
B6A55849BB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4A298BAC6CDB0BFCDB0C1D1A6B9C9798F9E6E89954A69724361686A8489A6BAC1
BFCFD6C5D0D8C8D1D89EA5A9878A86918F869593879795899A978B9992869C92869D9183
A19484A19584A29683A29480A1917C9F8F77A29179A59278A99274A99070AB906CAD8E66
AD8D61B08F64B19067B09168B6956CB5946AB3946ABB9E76BA9D77BEA07BC0A180C3A487
C6A98EC6AC91C5AB90C3AB8FC3AE93C8B398CAB39ACCB49CCDB79FCBB59DCBB69ECDB9A1
D1BCA5D3BEA6D2BCA5D2BCA4D8BFAAD8C1ACD5C0ABD7C3ABD8C4ABD6C3ABD7C5AED6C5AE
D8C7B0DAC8B2E0C3B0E8AA9DB8423BC6201CD11811D41811D4160FD51511D31310CC130F
C2140FB3211FB95860A5738859527A1B396F264B7C7086A2A4A7AAB3A99EB7A395BC9E8F
C39386BE746BAB413DA71F1EAD1112B30C0EB7090BB9080BB70609B4060AAF0405B00607
B10708AF0506B2070BAC080B9E0D109A353B956F811725465B7C97BDD4E2C5D1DAC7D0D9
C8D0D9D1CCD5AB7F88841E28950B13870B13753B48717786B4C9D3B7C5CCBDC4C3C2C0A5
A59D4DA79917AD9D04AA9B04A596089B8E06A0920B7D700C5F59008C880DA1970BA29509
A2911B50C11500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0093938BB7C4CDB0BDCDAABCCC849BA8718C984C6B742142466F8B8EA3B9BEB9CBD3
BACCD5B7C9D0C6D3D7A8B1B3868B8790918994948A95958B9592899A948A9890859A9183
9F95859C9382A39786A19482A29582A0917BA29278A79377AA9374A88F6FA88D69AB8F65
AD9063AF8F65B2926CAE906AB3966EB0956AB4986DBDA07ABC9E7CBA9C7BC1A283C6A78A
C7A98EC6AA92C8AD95C4AB93C4AE96C9B49BCDB79FCCB7A0CBB79FC9B59CCEBBA2CDBCA1
CEBDA2D0BDA4D1BDA4D4C1A7D6C3ABD4C1ABD4C1A8D7C3AAD5C1A9D9C6AEDAC9B2DACAB3
D8C8B2DBC6B3E9BEADCB6C61BF2821CF1914D21511D41711D5170FD5160FD1150EC41811
B62D29BB6D756B5B7D243769173B703D5D8590A0AEB2B0AEBAAE9FBAA893C3A290C98D80
B04F47A82220B11414B50B0DB6080ABA080BBC080BBA060BB70509B40608AE0304B00305
B00607B10406B00607B10507AE080B980A13AA57625C5067415A73B1C8D5C4D1D8C8D1DA
C8D2DBCFD1D9BEA5AC802D36900E16890A117C3A475F6372B0C6D2B5C4CDC1CDD1C5CBC6
BBB98AA5982DAC9D0DA89803A59602A09102A3920880730D5F5804615F078784119E960A
9F8F0A4CBE0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
73A0458B8C84B5C2CAB2C3D195AAB8728B985C798321404857767B4D696FA7BEC690A7B0
7B949B9EB4B9C6D5D9AFB9BB858D8A8F938C92938A96948B98948C9A968C9994889A9485
9C95839E9684A39586A39383A39381A0917BA6967CA9957AA89274AA9373A78F6AA88F68
AA8F65AD8E65AF8F68AF916AB1976FB3966FB99B76BA9D7ABB9E7DBB9E7FBFA284C4A789
C7AB8FC9AE93C6AC92C4AC93C5AF97C8B39ACBB79FCBB69FCEB7A1CDB69ECEB8A0D1BDA4
CFBEA4D0BFA6D1BFA7D2C0A8D3C0AAD6C2ACD6C2AAD8C4ACD9C6AFD9C7B0DCCAB3DBCAB6
D8C7B4DFC0B1E1998FB8362ECD201AD51A13D41610D6170FD5170ED0160DC61C14BC3C38
B474814C4C70183A6C244877617997A4A9ADBAB1A7C1B0A3C2AA9ACAA190C57C6FAC3A34
AF1917B70E0EBD0D0DB8080AB7060BBA070BBB070BB90409B70508B50609B00307B10408
B3060AB20509B10408B20509AE0508A6090D972B32A2839572869F9BB6C6C3D4DCC5D2DA
C4D2D9CAD3DAC3B6BC86414A8D111A8C0A118038454F5161B0C8D5B4C4CCC0CFD5C4CECF
BEC1A4AFA956A99B20A8970BA89805A29200A4940593850C5B53034848054B4D01908C13
9F910B92740A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AA8F688B8E87B3C3CAAABFCD7890A064808D28465154727B4B69705A767E87A0A8516A70
92AAAFBDCFD4C5D1D5B9C2C4838A898C908A94958C98978D97958999968A9C978A9B9385
9B94849D95869F93849D907EA2937DA4947CA3937AA5947AA49174A69271A48F6AA9926B
A88E65AE9065B2916AAE9069B2956EB79975BB9E7CB69C7BB79C7DBBA083BDA285C3A88A
C3AB8CC2AA8EC7AF95C5AD95C1A990C5AF96C9B39CCAB49DCBB49BD0B69DCEB69ECDB6A0
D0BCA8D0BEA8CFBDA7D3C1ABD6C3AFD6C2ADD6C3ADD4C2ACD8C7B0D7C6AED8C7B1D9C7B4
DCC3B3EBB6ABC35852C3251FD31D15D61A13D51811D2150DD0180FC41E15C24848AD778A
3B4570183E724A698E8E9EAEB1B0B0BFB0A4C5B1A1CAAEA1D09E93BF655DAB2924B11411
B70C0BBC0B0BBC0A0AB9080AB60709B60609B6050ABC070CB9070BB6070BAF0509B0060A
AE0609B3070BB10407B20507AE0406AA070A93181F7949680F1F4D2D4E73B6D0E0C2D3DB
C4D3DACAD3DCC6BDC592566089121D8B0912843A483F3F52AEC8D6B8CAD3BECCD4C3D0D6
C5CBC1BABA92C3BB6CAD9C29A7950AA79603A29301998B048F8514564E02514E07646204
979011947E1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AD926C919290A9B8C68FA5B66A8798304F5D45646E4C6B75506F76567177A4B8BFA3B5BD
9CB3BB889FA6C5D3D8C0C9CC878E8E8C8F8D90918C93928B98958D98948A9A95899A9486
9993839E96869C927F9F927CA0917AA4967CA2947AA4957BA69578A69372A6916EAA916D
AE916BAE9167B1946BAD9069B39772B69A77BCA281B79D7EBAA081BEA388C5AA90C0A789
C4AB8EC3AA90C6B095C7B095C3AB90C6AE92C6AE95C7B199C9B49BCEB69CCEB69DD0B9A3
D0BAA4D2BEA6D0BEA6D2C1A8D4C3ABD7C5AFD6C4AFD7C6B2D6C5AFD6C6AFD7C6B0D8C3B0
E2BDAEDE8D84B93028CF2017D61A13D51612D11411CF1711C41F17C14D4CA97B92344273
193F735D7998A8AEB4BBB3AAC1B1A3C4AE9DCBAD9ED6A095C05E57AD1E1BB6100FBB0B0D
BA0A0CBB080BBC090CBA090CB50608B5080AB40709B4090CAF0A0EA90D119E0E109E0E11
A40B0FAC070CAF0509B00609AF0508AB060A96141C804C681525531B3F65A3C2D4C0D2DB
C4D2DAC9D2DCCDC4CF97606C8715208C0A11863A4736374CA9C5D5B8CAD5BCCAD5C1CFD9
BECCD0C8D0C9C8C6A3B0A652A99A1BA39305A292019E90039D9208978D0F776C0C5F5700
8C840F98851400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A588608F8E8CA1B0BD8097A74C6A783655604D6B744E6C7457747986A0A791A6AEA2B6BF
778F976A8288C2D1D9C5CDD48B91938E939090928D95958F9B97929C9590978F87979285
9A97879B96849D95829E927FA0927CA3947DA1947BA2957BA59579A59272A79070AD9172
AF9472B19772AF936DAF936DB49774B79C79B59C7AB8A081B9A485B8A487BDA98CC0A98D
C5AD92C5AD95C5AD94C5AC92C7AD94C6AD94C9B198C6AF98C7B39ACAB69CCEB89FCFB9A1
CEBAA2D2BDA8D1BEA7D0BFA6D5C4AAD3C1A9D3C1ACD5C3B0D6C5B0D5C5ACD6C4ACDFC3AF
EAB5A5C0554AC4261BD51E14D51812D31614D11713C31B15BF49499E72893245761C457A
6B87A5AEB3B7BFB5A9C5B4A2C5B09EC9AB9AD1988DBD574FB4201CBF1212BD0B0BBC090C
BB080CBC080BBA070BB8090CB40A0AAE0B0CA40E0FA11E20A0363D9D4C568F505C92515C
9E3B429C0F14AD070CAE0309AE0407A9080B9820266F475F47618585ADCC8DADC1BED4DE
C4D3DAC8D1DBC7C3CC98637086141F8E0C14883A49332F47A8C2D5BACBD8BAC8D3BDCBD4
BECFD6C3D0D5BCC0AFABA267B1A43CA39415A59509A192039D91029D8E049F900E796D07
847A0A8F7E1042B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A07F5593918D97A6B1849CAA31505C4B6C74496A6D4D6B6E88A5AA546E7591A8B1899FA8
ACC4CB81969DC0D1D7C6D0D58C9596878E8B8F928D95958F99958E9D968F9990899A9286
9C95869C96859C95839B92809D927EA2967EA2957CA3957BA19176A69376A89276AC9377
AF9577B19979B29878B29876B29976B69F7AB7A17DBDA686BDA588BAA68BB7A289C5B095
C5AE93BFA98EC4AE93C5AC92C9AF94C9B094CBB39ACBB49DCDB79FCCB69DCBB39BCDB6A0
D0BBA7CEBCA7D1BFA8D2C0A7D1C0A7D2C0AAD3C0ADD4C1AFD6C4AFD6C4ABD9C4ACE1C0AD
E09789B73127CF1F15DB1D12D4170DD21712C61B16BC4140A7778D304373214D7F728EAA
B2B4B7C0B4A8C4B3A2C4B19ECAAF9CD39D90B8544EB31E1BC31413C40E10BE0A0CBB080C
BA0A0DBA080BB80B0CAE0D0DA214149D2E329E525E8359705245662F315A1D2752242347
81526696242CA9090FAE030AAF080A9D090AA040474A3653415F89416A9422476BB1CFE1
C2D4DBC7D3DBC8C4CE98637084121D8C0B14893B4B302C45A7C1D5B8CDD8B1C0C9BECCD4
C3D2D9C0CDD5BBC2C1B9B89EA7A269B0A652A094259E910D9C8D039E8C02A69608A19309
9B8D0D86720641B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
977141A299908F99A47C909E4C66714C6B7048686B7D9C9F506E728DA7AEADC6CE69868F
74909997B0B6C2D3DAC3D0D6959FA1878F8B90938D96978F98968E98948A969084999183
9791819A95859A94849990809D9582A19784A398839C9178A1957AA3947AA8957CAD987D
B0977AB29979B2997AB29A7AB79F7FB69D7DBCA584BBA685BBA688BBA88BBDA88EC4AE95
C5AD93C3AC92C5B095C4AE92CAB296CAB297C8B299C9B39BCBB59DC9B39BCAB39CCDB59F
CFB9A3CFBAA5D0BBA5CFBBA3D2BDA7D2BFA9D3C1ABD3C1AAD8C5ADD6C2A9DAC4ADE8BDAC
C7675CC52921D61C17DA1B14D51911C91B13BA3532B47B8B3847751A477B7795B2B7BBBB
C2B6A8C6B5A6C6B2A4CBAFA1D6A899BB5D54AE201CC31514C91211C30C0DC00C0FBA070A
B80909B60D0BAB1714A8393B9E5C696B536E313761152B5D193260435980606E8C7B7186
A36874981D24AA080CB0050BA9070A98181A985A6A2023453F5C816280A11737589BB8D0
BED2DDC8D4DCC8C1CD985E6D85101C8C0A13893E502A27439FBBD0B1C6D2B8CAD1B7C8CF
C0D2D8BAC9D2C1CDD4C2CBCABFC4B9BDBEA4A8A56E9B9234988B129E8F07A19203A39301
A7990F8B790621D90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
9A713CB5AA9C848E9597A9B5556D774E6A6F6F8B8F5C787C77939B9CB8C35F7C857D9AA0
809CA2607C81A3BABFC0D0D49DA8A9868E8B8D908A95958E92928A908F86969287958E80
9993839A94849D97879B94829E9784A29988A49B89A09681A69982A4957CAB987FAD987E
B19A7AAE9773AD9774AE9979B6A081BBA384BBA283BCA687B8A586B9A78ABDAB90C3AF95
C0AA8FC8AF95C7AF96C3AE91C7B295C6B195C4B096C7B39AC9B49CC9B29CCBB59ECCB69F
CDB8A1CDB9A5CDBBA5CFBDA5D0BFA6D2C0A9CFC0A9D0C0A9D7C5ADD6C3ACDBC1AEE9AFA0
B84039CC221ED31813D71B14D21F16BD2C25C276824C50771B477B6083A5B6BDC3C6BCB2
C7B5A7C8B5A5CDB1A2DAABA0C5766DAB2520BD1513C5100FC70F0FC20B0EBD090CBC0A0D
B50909B3201CB6555679576D2D3660122D5F203D6A5369888691A1C2C3CDCDC1C7B28486
A13D3EA20F11AD080AAB080B9A1013A24D594F3D5D122C556C8CAAB4CCDC9FB8CBA1BED2
BDD5DFC9D4DDC4BAC795596486121A890A12863E50292A459FBFD1B0C8D2BAC9D2BDCCD5
BFD0D8BFCDD6C2CFD7BFCBD3B8C3C9B7BFC2B7BEB2A7A9818A8838928A1D9E9213A3940A
A3950E7F6E0245B90C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4EBB24B5A7957E868BA0B2BB526B7264818669848970899091ADB54D6D76617F87A1BDC3
758F968AA3A88EA2A6C4D1D6A9B3B6848E8B8E938C97969192908B9290899692888E897D
9592839390819995869B95859C96859F9886A19885A29783A59882A89880AB977FAD957C
B29B7BB09978B19B7BB29D81B49E82BAA285B9A084BAA487B8A585BCA889BEA98DC4AF94
C5AD93C6AC92C3AA8FC2AD90C4AF94C5B095C5B096C7B199C8B29BCAB59ECAB69DCBB99F
C8B79ECCBAA2CEBCA4CBBAA1CFBEA5D1C0AAD0C1ADD2C2ADD4C3ABD1C0A8DDC0ABDB8F82
BA2E25D21F19D51812D51C15C2231BCA656A7663841A3F734E739AADB8C1C7BEB5CEBDAF
C9B6A7C8B4A3D4AEA1D18A82AA3531B91716C3100FC71012C60E0EC10A0CBE0B0EBA090C
B60A0BB82B2AAF5C653C2A4A2839615668858E96A3C6C5C7B3A6A3BC9F9EB983819E3C3B
A01214AB080CAA090B9B1213A04B54634B670D21513D649084AAC795B4C67EA1B53A617B
B4D6E5C7D3DEC1B6BF905259861116860B1083414F282E45A2C2D2B1C6D1B9C6D0C1CEDA
BCCCD6BFCDD6BECCD5BACAD2B1BFC8B3BDC7B4BEC4B1BBB7869178999F6FA2A1569C9328
988D0F85790864960E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB91FAD9B847D8487A5B6BF5B727A7B979D5B757C99B4BD4C6A725C7B8188A4AA8EA8B0
98B1BC879EA79CAFB6C4D0D6B2BBBF808B88868D868B8C888D8D8990908996948A8C8A7D
9390829893849892829893829C98859E99869F9885A49B86A89A84AA9982AF9A82B09980
B19C7FB29E7FB4A185B39F85B6A286BAA186BCA48AB8A489B8A487B7A486BFAB8FC6AF97
C4AC93C3AB91C2AC90C3AE92C4AE91C7AF95C5AE96C6B199C6B29AC7B49BC9B99DC9BA9D
CABA9FCBB9A1CFBDA5CEBCA4CEBBA4D0BDA8D1BFABD4C2ACD8C5ADD6C1AAE4BCAAC96B5F
C32721D31B14D71B14CD1E16C24342A67A92273F70385D8AA9B3C4C8BBB5CEBAACD0BBAC
CCB9A7C8B2A0D69F92A7463FB01F1DC21312C8100EC60E0EC31011BC0F11B41012B50D11
B70C0FAE0E10A82B2EA5626A9A8689A29C96AA9F94B59F95BC938CB66D699E2E2DA31211
A80907A60B0A9815179D4B565D48631325560B2A5C7595B82C4B6A1F3E5D6B8DA71E425D
A1C0D4C6D2DFBBAEB9884650891319840B118545562A324AA4C3D5B2C6D1AEBCC5BECBD6
B8C8D2B9CAD4BBCCD4B8C6CFAFBCC4B5BFC9B3BEC8B1BEC67C8F93778A8394A487A1A767
9B962F978E158D7C1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B718AB9374818784A8B8BF7C919B60788290ABB6607C854F6C7288A2A6A1BBC3718E99
5976807D959CBCCCD3C3CDD3B6BEC27B8381828783868883888A828D8A83929185939486
9493849895859894849B9587A19A8B9F9887A09986A49B88A89C87AA9A83AC9A81AF9B81
B19D82B3A086B29E84B39E83B7A086B8A088B8A28ABBA68AB8A084BAA588BDA78CC0AA92
BFA991C0AC91C1AC91C1AD92C0AB91C4AD96C4AE97C4AF98C6B39BC8B69DC8B79DC9B89E
CDBAA2CDB8A2CFBBA5D0BEA5CFBEA5D1BEA6D5C1AAD3C0A8D7C5AED6C0ABE8B8A6BA4C42
C9241DD71D14D31E14C02924CC7D8A4C4F772849799399B4D6B7B8DDADA3DBAC9FD9B3A6
CEB4A3D0AE9FC87970A42723BE1A1AC91112C50E0EBE100FB01D1CB23B3EAF494FA53239
A4181AAF1010AE1111A32925C88578B89785B79584BA8075A84A44A01E1BA9100EAA0B08
A20D0B97222493505C4C3E611027561837673C54748593A291A0AE667B8F9BB2C19FB9C9
AAC4D4C5D2E0B8A8B4833C468B1119850C157F45572C3752A9C7D9BBCBD8BAC7D0BDC9D5
BCCAD5BAC8D5BBCCD6BCCAD5B3C0C9B3BFCBB2BFCAAFBDCB5C707F293C41637364778361
8C934E9592289B8D1A40B20500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A68A62858B82A6B7BE8498A27E95A274909B48666F779197A6BDC55B757E7F99A0
9BB2B9BACED6BCCED5C3CED3BCC5C77B81808184808687808A8A808C8A7E8D8C7F959486
9291839693849B97889E97899E97899F9A88A29C89A59D8AA79C8BA99B89AC9A88B29D88
B09C84B29E85B39E84B49E82BCA38AB69F87B9A289BCA58AB7A286B9A489BDA98DBEAA90
C1AC94C1AC93BFAB90C0AC90C3AB93C7AD98C9AF9AC6B199C5B29AC7B59DC8B69ECAB8A1
CBB9A2CDBBA4CEBBA4D0BCA4D3BFA7D3BFA7D6C1ABD6C3ADD7C5B0D8C0ACECB2A3B43B2F
CF231AD41B11CB2118C54D50916C863945728980A2C0818CB84F4FB83C3AB6433ED38379
D9AC9FDCACA0B5524EB1201FC41615CA1110C31412B62B2AB2636D654C6946436270576C
AC646AA12426AF1011A9100FAF3830D37C71B65C54A22B27A51413AD0E0DAA0D0B99110E
97343885566B3030570D295A23456D92ACC4C1CFDBA5B0B6BEC9D1AEC2D07893A6A1C2D7
7093A6C1D4E3AE9CA780323A8C0E15820C157847572A3B54A6C4D6B7C8D4BCC9D4BECAD5
BECCD7C0CEDBBFCFD9BACBD5B3C1CAAFBEC9AABBC5ADBECC94A6B662737D88948F8F998C
8F977696944A9B8D2448BB0D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4885B93978D9BADB2879BA593ACB845656E6E8C9396B2BA58737E536F7692ACB2
A2BCC3A2BDC77C939BBCCBD0C3C9CD8084867E817D80817A86867E8D8C828C897D969186
9994889995889895869E988AA0998B9F9A89A39D8CA59F8EABA092AE9F93B4A193B39F8C
B5A088B6A089B59E86BAA28ABCA38DB9A18AB8A288B9A489B8A288BBA58CBDA88DC3AE93
C4B098C4B098BFAA92C2AC94C4AC95C7AD98C9B09BC7B29CC5B39CC7B59EC8B49EC9B49F
CEB9A4CCB9A2CEBCA5D1BFA9D1BFA9D0BEA9D2C0ACD5C3AFD4C3AFD7BDAAE7A899B13127
CF1F18D21C14BD231FD17882684E69A285A4B2596BB6282EC51E1FCA1C1AC11E1AAD322E
E19F99E0A8A4A9403EB51D1CC61412C81312BB1D1CC06069514062183165324D74707484
B18F90BF6664A21614B00C0AAE0E0DB11C1CAB1313AE0E10AC0B0CA3100F9A2426924852
59415D17235010325D557B9AACC6D6ADBCC3C4D0D896A7B193A6B1667E940B2B4C4B708E
41667DBBCFE1A8909D7F2833900E15800E1574495B31465EAFCEDDB5C8D5BBCBD8C0CCD9
C0CCD8C1CEDBC0CED9C0CED9BDC9D5B1C1CBACBEC8AABFCCA1BACA8FA8BB8DA3AFA1B3B6
B1BEB5A6A881978D404CC11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A584539E9D9193A0A7ACBFCB66808C5A798190AEB663828B4F6E7669848B7E989F
66838A59767D99AFB6B9C8CEC0C9CC838A8C797C7980817B83837E8B8B838F8D83928E82
9B97889D988C9A96899F9B8CA39C8CA69E8FB0A699B0A597B1A497B3A399B5A496B9A796
B6A590B7A38EB7A18AB69F87B9A38CBAA48CB49F87B8A58BB6A38AB8A58CBCA88FBBA88F
C3B199C3B098C1AB93C5AD95C2AB94C3AC96C6AD98C7B09BC6B19CC7B19EC9B49FCAB6A0
CCB6A0CDB9A1CDBAA3D1BEAAD1BEABD2C0ADD0BEAAD5C3AFD5C2AEDABEABE4A495B43329
CD1D15D31F18C03435BA73829D738AB55E70B9252DCD191DD01718CE1614C71A15AD2E2C
AF757BB890989F4244B2211FBF1313C30F11B3191ABB6270443354535B7CA19CA8BBA09D
C9978ED37871A71F1AB30B0CB7090BB80A0DB40D0CA90F0DA02221A04C537A526A31315A
0F245717335E4C6880A7BCC5C0CED19EA7AB9FAAB0495D6A5F748296A9B8486479628096
A3BECDBFCAD6A285907C1F29930E1582121B6A41533E536CB2D0E0BACBD7BBCCD8BECCD9
BFCCD8BFCAD6BECAD6BECAD7C0CFDCB2C2CFAEC2CCACC0CD738DA22F4F6A305067587480
8094979AA29499966F96845400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A47E47A7A1918C999E97ADB75C77818BA7B172909B496A7167888D47666A688488
6C858A97AFB68EA4ACB0C0C6BEC9CD899395757C797D7F7983827D8A89838A8A80929084
9C988C9F9A8F9F9B90A59F93ACA697ACA596B2A79AB3A89BB1A698B5A89AB5A597B2A291
AE9E8CB19F8BB39F8AB29E87B8A48BB7A388B8A489BCA88EBAA68CB7A489BBA88DBBA78F
C0AB95C1AC94BFA891C2AA93C3AD95C2AE96C7B099C9B19BC5AF98C7B29BC9B49ECBB6A2
D0BBA8D0BBA6D1BDA8D0BFA8CEBEA8D1C1ADD0BFADD6C5B1D5C2ADD9BFA9E6A999B0362A
CD2118D11F18CA4443B66874CF8391B12F36CC1D1FD31616D21615CD1613BC1C17B65158
69516B69637EA7656FA42629B91819C41113BC1215BB353EB55C69BB757DC07572B75A53
AD3C34AC201CB10F0EB80B0DB9090CB40C0BAC1F199B3936774751453E5E18295B132B5E
3A4D7079808F97989593938DB8BBB9B5B9B8A9B0B0C0CDD2ABBCC3ABBBC4B5CDDB89A6BA
9FBCCDBBC6D49D7C867C1A21910C118618205F3A4E4A5F79B5D0E1B7CAD2BBC9D2BBCBD8
BDCDD8C0CDD7C0CDD9C0CFDABFCFDCB7C9D7AEC2CDAFC1CE758B9C45617645637668818E
85969B828B888A8C80887E6C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00789B31A59B8684929694A8B2778F9A8DA9B649677360828847696C5D7D7E7D989B
A0B7BD8FA8B14760698CA0A5BECACE97A0A3757C787B7C7782827A84847C89887F8E8C81
969287A09992A39C94AAA199AAA298ADA59BAFA599B3A79BB2A69AB4A89AB5A698B1A190
B2A08EB39F8DB39E8AB59F89B8A28AB9A48BB7A38BBAA58DB7A289B9A48ABDA88FBCA690
BCA690BDA891C0A892C2A993C2AB94C5AF97C4AE96C6B099C6B09AC8B39CC7B59DC9B8A1
CCBBA4CDBBA4CDBBA5D0BEA9CEBDAAD0BFACCFBEAAD5C4AED3C1A9D7C2AAE7B6A4B1453A
C9251FD41F1BC72C2AF68084E1686BC22423D31C18D31815CE1714C11C16B43C3C9D6F84
2A3C655B708DC6A5AAAB5753A72824BA1817BE1212BC1215B4171BB21C1EAD1918B01816
B01411B41410B40F0DB80D0EB60A0BAB100DB54E4E5430421C2043192852414D737A748B
9B858BAB8B85B59288AF928BCEBFBCD6CFCFB7B8B8C2CBCFA5B6C17B919F8FAABD193A5A
3053737C8B9E96707B7C141B8F0A10841B2658384F526984B2D0E0B8CBD5BCCAD3BACBD8
BCCED9BDCED6BCCDD5BCCDD7BFD2DCB5C8D6ADC0CEB1C3D1A1B6C46B869799B5C294ACB6
A4B6BBAEB9BCA5ACAB8F8B862A9F1900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004CB81CA99A807E898AA1B5BE92A9B457737E5D7B845271765D7C8169888C425F66
839EA72D4951718B928A9CA0BAC5C9A2A9AD7176767B7B7780807A81817888877D8E8B80
938F859D9991A29D97A6A098ACA59DABA299AEA498B1A598AEA495ACA392AEA491B0A491
B1A28EB09F8BB39E8BB29D87B4A088B9A58CB7A38AB7A389BAA58ABDA58CBFA78FC2AC94
BDA992BFAA94C1A993C3AA93C2AB94C2AC95C5B099C5B098C5AF97C8B39BC9B69EC9B8A0
C8B8A0CABAA0CABAA1CDBDA4CCBCA4D0BFA9D4C1ABD2BFA7D0C0A7D2C2ACE1C0ADD18476
B93028CF231CCF211CCE2928D02A2BCF1D1AD21D17CC1F18BF261FBC4E4FAB7D92364673
1F4777889FB3C3B7B1D6AEA1C27C70AA3930AE1F1AB71A17BA1918B51614B11816A71715
A5201FA92D2BC03D3AAB1211B40D0DA51110A95057381C3643355386637AB07582A45056
9C3839982D2D9A2D2D9C363B9E4E54B37E82B6999AA19A9B65727C344C5B8CA2B44A637E
33516EABB4C68D5E667F1117900A10841E2951374D5F7892B6D2E1BACCD5BDCBD5B6C7D4
BBCED8B9CCD4B7C9D4BACCD8BDCFDBB7C9D7B3C6D2B8C9D6AFC3D32D495F47677B5D7889
7A919B90A1A89EABAEA9ACAC57443600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004AB417B29D81808788AABCC57E95A057737B5B788059767D71909637575C88A2A9
778E97445E6444595CA6B3B6BAC4C5A8B1B37175767A7C797F807A83837B89877D8D8B7F
928F839D998EA19D94A5A199ADA8A2A8A198ACA397B2A798AEA292A99F8EAEA492B3A795
B3A590B1A28EAE9D8AB09C85B5A188BAA48CB7A189B8A38BBCA78FBDA58EC3A993C4AC96
BEA892C0AA95C2AA94C3AC94C2AA93C2AB97C5AF9AC5AD97C8AF99CAB39CCAB49DC8B59D
C9B79FC9B8A0CCBCA2CEBEA4CEBEA4D0C0A7D4C1A9D3C0A7D1C0A7D2C3AED9C4B2E8BCAC
D27C6FBA382CC62820CA251FC6221DC2231CBC2E25BD4E4ABC7880887693304B7A1D4A7C
6888A6B2BABDC2B9ABC9B6A6CEB1A1D2A090C17B6FB25954AD4F4FAB4F54A5565CA2646E
9165767B5668BD78809D1D1FAF0C0FA30C0BD06367AC5C68A44653A02731A3161DA91015
A80A0EA8090EA8090FA60A129E0C14911319923437A67272C6BABDACB8C19CADB7B8CDDB
A1B6CA989AA9875057871317910A0E85212C4A344969829AB7D1DFBECEDABECCD6B4C6D3
B4CAD6B7CBD7B7CAD7B7CAD8BACCDAB9C9D6BBCAD7B9C8D6B0C2D45068824F6C854F6B80
6B839182949D7F8C92878C8E5C4E4300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB517B69E81888C8EA7B9C4627985657F88556F777F9CA23C5A5E79969B7F989E
768D94667D82A7B7BBB4BFC2BAC3C7B0B8BD767B7E7C7D7B80807B82807A87837B8D8980
938D859D968EA19C93A4A097ADA9A0A9A59BA6A294ABA494AEA394ACA092B1A497B3A494
B8A797B2A08FB09D89B49F88B5A189BBA68EB7A189BCA78EBAA78EBAA590BEA790C0A892
BDA68FC1A892C0A791C2AA93C3AD95C0AB94C2AE96C3AF97C4AF99C6B29DCAB7A1CDB9A4
CBB6A1CBB9A2CCBAA2CDBDA4CCBDA5CFBFA8D4C3ABD7C3ABD4C2ADD4C3B2D6C4B5DBC5B4
E6C2AFE4A696D2796CC66159C2635EC37779B58893817891415981224C7C3C668F8098B0
B8BCC1C2BAB3C4B8ABC6B9A9C7B8AAC7B2A4C4ACA1917B7C685A6A524F6A3D45632D3A5D
25375D383E5CA470809B1C22B10C0FB00B0DB61E21AA181EAC1118AE090FB2080FB2060C
B0060BAF050BAF030BAC020AA8040AA6070C9D0B0F8E1C22AA7176C8BEC87C8E9C8DA6B7
40586E5A5B6D7D404989101692090F85212F432F476D89A1B8D2DEBDCFD8BACBD5BACDD8
B9CDD8B7C9D7B8CAD6B9CDD8BCCEDABDCCD8BBCCD8B8CAD8B6C9DAA1B7CEA0BBCF9FB7C7
A0B5C0A8BBC3A3B1B8979DA25E524B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0028DB0BB094748D8E8FA4B5C07A919D58737D7D98A14B656D6A8588769093738E91
97B0B48BA3A99DB1B6B4C2C8BBC6CCB5BDC47A7F847879787E7E7986847D89867E8F8C82
948F849C978E9F9B929F9B94A6A39BA6A499A9A599ACA598AEA498AFA395B3A696B5A594
B7A694B4A290B5A28DB39F87B5A189BAA68FB6A18AB9A48CBDA991B9A58DBDA58EC0A891
C0A790C2AB93BDA78FBFA991BFA991C1AC94C2AE97C6B29DC4B29CC4B39BC8B89FC8B89E
CBB9A2CAB7A1CDBBA5CFBDA8D1BFABCFBEA8D3C2ABD6C4AED6C4B1D4C1B1D7C5B6D5C6B6
D7C8B7DCC5B6E1C3B8B59B9A80768258607C354F753257804C71957D96AEAEB8BFC0BCB8
C5BCB2C8BCB0C4B8AAC4B8AAC2B6A6C3B5A5BFB2A2BDB2A8AEA9A692939B838994828793
8E8D99A78F97A55758A11414B50B0CB40809B3070AB3070CB20709B2060AB30409B4040A
B4060AB4070AAE0406B10409AC0407AD0509AB070AA10A0F891A20A47381292F435B7486
607486635C6F803B468B0E1691070F892534402D45708EA4B8D2DEBBCED6BBCCD6B1C3CF
B8CBD6BCCFDCBCCED9BCCED8BCCED8BACCD8B6C9D4B7CAD9B1C8DD5B79944F728B6D8A9E
738A97869AA292A4AAA4AFB377706C27981000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A4835D93918FA1AFBB738A9769858F628087668187728B8E68838669858A
5E7C805C7A7D8CA6AAB1C4C9B6C5CCBAC4CB7E8589787B7A7C7D7885857E87877E8F8E82
959185A19B90A49C93A59E95A6A19AA6A298A8A499A9A396AEA698ACA191B3A796B5A595
B7A595B5A191B6A08EB39C86B79F89B9A38CB5A088B9A38CBBA58EBAA48DBDA68FC0A791
BCA58FBEA992C0AB92BFA991C2AC94C2AD96C3AF98C6B29DC7B39EC7B59EC9B8A1C8B7A0
C9B8A2CCBAA6CEBDAACEBDABD0BEABD1BFAAD3C1ACD2C0ACD5C3B0D7C5B4D9C8B7D5C6B8
D5C8BBD7C9BCD8C8BED0C4BEBAB4B6A7A9B4A7AEBBB1B8C2C0C0C3C5C0BDC9BFB6CABFB2
C9BCAFC8BAADC7BAACC5B8AAC6B8AAC7B9ACC0B5A6C1B6A6BEB6A6B8ADA1B4AB9EB4A99C
BCA499C188829D2D2AAD100FB50909B50709B40708B30608B4070BB30409B20308B6050B
B30507B40709B20809AF0506B00406AE0609AC0406A8050997090E933C44A5919E90A1B0
B8C8D1A797A27E313A8F0D1493080E8624353F2E497896AEB5CFDCBBCED6BCCDD7BCCCD9
B8CAD6BACCD8BDCFDBBDCFDBBDCFDCBBCDDBB8CAD6B8CBD8B5CBDF3A587543657F607F91
5B727E788B937B8A917E878D6F696924961000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A17C4F9A958E9AA7B28399A774919C62808985A1A75D797E617E85537076
56757767848686A2A6627C81A8BCC1BBC8CB858D8E7B7D7C7E7F7A81817A88877E8F8D82
9693879D988FA39C94A39C94A6A098A8A49BA7A499A8A498ACA59AACA497B3A797B4A395
B7A496B9A392B59E88B89F89B89F89BCA58FB6A089BBA28CBFA690B8A18AB8A28ABCA68F
BDA790BEAA92C2AD95BFAA92BFAC94BFAD96C3B099C5B09DC5B09CC7B39EC8B6A0C9B7A2
CDBBA7CDBBA9CCBBA9CFBDAAD0BEA9CFBDA7D0BEA9D3C2AED4C3B0D8C7B6D8C7B8D5C6B9
D3C5B8D5C7B9D4C7BAD4C8BBD0C5B9CDC4B9CCC3BACCC2B8CEC2B6CDBFB3CABEB1C8BCAF
C6B9ABC5B9ABC3BAACBDB5A7BEB7A8C1B8ACC0B7ABBCB4A5BAB1A1BAAE9EB6AB9ABBA496
C39187A74642A61614B30B0CB70A0CB5080AB2080AB10708B40709B6080AB50709B7060C
B40608B30608AF0507B00409B10507AD0305AE0509AB030AA2050C84121D946B7E8E9CB5
8796A7A8959D7E2B30940E1395080F8725353F2F487A9AB1B6CEDDBDCDD9BACCD6BBCDD9
BACCD6BDCDDABCCCD9BACCDAB6C9D7BACBD9BBCBDAB9CAD8B8CADB758CA18BA7BAA1BDC9
9CB2BC9EB0B8A5B4BA9EA8AE7B777A38671D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009C7440A69E91909CA5A6BAC766818D96B2BC6F8B945D7A814E6B71537477
62828488A5A85B777B55707597ABAFBCC9CE8F959A797C7B7E7E7A83827C8989828F8F86
9A978EA09B93A29D95A29C96A9A39FAAA5A0A6A297A9A298AFA89DACA499B2A699B2A393
B7A696B4A390B29F8BB39F8AB3A08BB4A28BB7A38CB9A38DBBA58EBBA58DBCA78EBCA68F
BCA690BFA994C2AC96BFAB93BEAB94BEAB95C2AE98C6B09BC7B19CC8B29DCBB6A1CCB7A3
CDB8A7CEB9ABCEBBABD1BFACCEBCA8CFBDA8D2C1ACD4C3B0D3C1AFD5C4B2D5C5B5D6C9B9
D5C8B8D5C8B8D3C8B8CFC7B5CFC6B8D0C5B9CFC3B7CDC2B6C9BFB3CAC2B4C9C0B2C8BEB2
C8BEB2C4BBADC2BBACB6B3A3BAB7A8BCB6AABCB4AAB8B0A4B5AE9EB6AB9DBBA699C4948D
AC4F4EA41A1CB00C0DB70A0CB50909B20809B20809B20809B40709B50709B30709B20409
B30A0CAD0A0CA9090BAB090DAF0A0EAE060BAC0408AA0207A5040A8C0A148B4E681B224B
2C43629B8A947A2228940A1195070E8723314333497899ADB5CFDEBCCDD9B4C6D0BBCDD7
BCCED8BDCDDABACBD6BDCFDBBBCDD9BACAD7B4C6D4B4C7D6B9CCDB7F94A9668196728F9F
7F99A383969D95A6A99DAAAD95999D48392E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A27740BAAEA188939C99AFBC87A2AD8BA6B177919B4D67704E6B70557578
4566686C888C94AFB3778F939EB0B4BECACD98A0A4767A7C7B7D7981827D8686818E8F87
9C9C949F9D969F9C959F9B96A39F9AA9A39DACA59CA9A297AEA79BAEA599AFA595B2A595
B6A696B3A090B2A08CB4A38FB5A38FB4A08BB8A38CB7A28AB6A28AB8A58DBCA990BAA68D
BAA68EBBA790C0AA96BDA994BDAB96BEAC96C1AD98C3AE99C7B29DC8B4A0CBB8A5CDBAA9
CCB9A8CDBBABD0BFAFD0BFACCDBDA6CFC0A9D1C1ACD4C3AFD4C3AFD3C3B1D4C5B6D5C8BB
D4C8BAD3C7B8D0C7B6CFC8B7D1C8BBD0C4BBCCC2B8C9C2B4C8C2B1C9C2B2C5BDAFC6BCB1
C5BBB2C2B9AFC2BBAFBFBAAEBDB8ACBAB4A8B8B2A4B5ADA0B7AD9FBBA89EC49690A94D4D
A61B1EB20E12B60A0EB6090BB70A0BB20809B20809B5080AB5090DB30A0DA90A0CA00B0E
9A1416962224983033992B3395151D9F090FA90509A90307A303078E060E8E4C62242D53
56738F9C8B977A2029960A1196050C861E2C4E384E7391A8B6D0E0BDCED9AABCC4B2C4CE
BCD0D9B4C6D4B8CBD9B8CAD5BACBD5BBCDD7BCCED9B5C8D8B2C4DA8298B32845604D6980
637C8A74868F7F8F957A878B7C83854A3F3700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004EBB24BDB09F7E8C92A6BBC99BB2C087A1AD617C864F6A73516C732A464B
223C405A747A627F856D888CB3C4C8BCC6CBA2A8AD76797B7B7C797E7D798887828E8E88
96988E999B909B9C919F9D94A49E97ABA49DADA59CAFA69DACA399ACA298AFA498B0A397
B4A396B4A092B39E8DB4A18CB6A18DB8A18EB7A28DB7A38CB4A28BB6A48EBAA68FBBA68E
BDA890BAA790BCA894BCA994BDAD96BEAD99BEAC98C1AF9AC6B59DC7B7A0C8B7A4CBB9A9
CAB7A8CCBBAACEBFACD0C1AECDBDA9CDBEAACFC1AED3C4B2D2C2B0D2C5B4D2C7B8D1C8B8
D2C9B8D1C8B8D1C8B9D0C8B8CDC5B8CCC2B9CCC3B9CAC3B6C7C3B1C5C0AFC6BEB2C8BEB7
C5BBB5C4BBB4C3BBB2C1B9AFBCB5ABB9B2A7B6B1A3BCB2A4BAA79CC79A95A74D4EA31B1D
B41112B70A0DB9090FB7090DB30709B10808B00807B10B0BA90C0C9E121498292E9A4B56
855769634E684F47655548617E4F5E932C35A10C12A80409A203078E0A12905265293457
9FBCD69E8B987A1E2595081197040C841724593B526F8BA2B4CFDFBFCFDAB9C7D2B7C9D4
BBCEDAB3C5D3B1C3D1B6C6D3B8CAD6B9CBD7BACEDAB9CADAB6C7DC92A7C26A829D8DA4BA
94A9B6A3B5BEA3B4BAA0ADB18A8F9352474227980E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004FB81EB8A690818B8FA8BCCA8EA6B47B97A45976814D69722441461C3639
7C9395849CA0658286547276758C8FBCC9CDABB2B5767A7A797B777C7D7883837E93928C
95968E989A9097988EA1A095A5A197AAA39BAAA29AAFA59DB0A69CAEA197AEA197B0A39A
B8A89CB2A092B5A190B6A18DB7A28DB5A08DB5A08CB7A28BB8A48BB9A48DBAA48DBCA68F
BEA991BCA68EBDA993BEAC95BCAC93BEAD96C2AF9AC1B09CC3B8A3C9C0AFCBC2B3C8BBAE
CCBCAECDBDABCDBEA9CDBEA8CCBDA6CEC1AACEC1ADD0C3B1D0C3B2CFC4B3CFC6B5D2C9B8
D0C6B6D3C8BBD1C7BBCFC6B8CEC4B9CCC3B9CDC4BBC9C1B8C7C1B4C7C1B4C7C0B6C7BFB8
C8BEB8C3B8B2C0B7B0BDB4ADBBB4ABB9B3A8B9B1A5BAACA2C59F99AE595BA21C1EB31013
B80C0EBA0B0EB80A0CB6080AB4090AAD0809A60E0C9D19189D393E915364634A682F335B
172D5B122C5E1B3661495F7C686677A3636C941219A3040B9C0306880D1184516415254A
304D6C867383781C2295080F99050D820E1B643F55647D95B2CFDEBACDD7BDCCD8BCCAD7
B6C7D4B9CCD9B8CBD9B7C9D8B5C7D5B7C9D7A5B7C5B6C8D7B9CADC889CB46D879E758FA1
7D95A181969F8CA0A698A8AE9BA4AA5A5352279A1300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0051B81AB29A7E878C8FADBECD8FA7B56F8D995878832F4D5518323672888D
6B828790A9B06580857B9699657B7EB8C8CBB1BABE777D7E7B7C797E7E7982827D878780
9192899B9D939B9C91A1A197A3A197A7A49AACA49CB1A7A0B3A89FB3A79DB1A59BB0A399
B6A79BB3A394B1A08FB5A38EB2A089B1A089B3A088B7A28BB8A28AB9A38BBAA48DBAA590
BBA78FBCA990BEAA92BEAB93BEAC94BFAE97BFAF9CB3A999C0BEB2D5D8D1DADCD9D0CFC9
C7BEB1CCBBAACFBEAACDBEA8CBBFA6CBC0AACDC0AECEC1B1CDC1B1CCC2B1CDC5B3CEC5B4
D1C6B6D0C4B6CFC4B6CDC3B6CCC3B7CCC4BAC6BEB6C9C0B9C8BFB6C8BFB6C9C0B8C7BEB7
C5BCB5BEB7B0BCB7AEBFB9AFBBB5ABB8AFA6BBAFA5C6A8A0B26866A12024B31115B90D0F
BB0C0EB8090EB70A0EB40A0DAC0E0F9A15169B3C3F956272554A6B20305F0F295A1B3963
445F7E7184988E9AA49FA6A9A99D9E9F6061901115A4060B9B06098E272A66465A172C4E
849CB38C7682761A2394081098040C7F08116F40525B6C83B2CFDDB9CED6BBCDD4BCCAD3
B9CAD2B9CCD6BACCD8B9CBD9B9CBD9B5C5D5A0B2C0B0C3D1B5C8D960799241637E34576C
557481748A9573868E76858D747F88575457269B1600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0050B615AD9170898C8DA9BBC87E98A56F8D994C6A75102C325C757A677F86
3E5A615A777D76909693ABB0768B90BAC7CDB9C1C77A8283797D7A7E7E7983827D86887E
9092859B9C90A1A096A4A099A9A49EABA59FAFA7A1B0A59FB0A49EB1A59CACA298AEA197
B1A397B0A394B5A494B3A090B09E8AB2A089B29E88B7A38BB49F87BAA38ABCA48DBBA68E
B8A68DBDAB92BBA791BFAB96BEAC97BDAD9BA69F8F9E9E91B3B8B2ACB4B5CED4D7D5D8D5
C4BDB2C7B9A8CCBCA9CDBDA8CABEA7CBBFAACCC0AECDC1B0CCC0B0CCC2B1CBC2B1CFC5B5
D0C4B7CFC5B7CEC6B6CCC5B5C9C1B5CAC1B9C8BEB8C8BEB7C8BFB8C7BEB7C9BFB8C6BDB6
C0B9B1BDB8AFBDB9AEB8B6AABCB9ACBDB4A9C2ADA4C28581A02B2CB31419B90D10B90B0D
B80A0CB80B0FB00C0EA512139E2F339B5E6C5A4E6D1F336110306325456F586E86848F98
9499999EA19AA19F96A69C95B89390983F419C1013A6060A95080A9A494F3A2F4C183556
98ACBC9D828B78192194071098040D8707117B3C4A535A6EB2D0DEBCD0DBBACBD4BACAD4
BBCBD5B9CBD6B9CDD7B9CBD7B8CAD6B4C6D4B3C5D3B0C4CFB2C6D588A0B54D6E836E8EA1
8CAAB596AFB98FA2AAA8B5BF75818E41444C4E3A2B00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AF8F68888785A1B1BE8198A669869423414B4A656C60777F3F575E
112A2F657F8544606758747A9DB2B9B5C4CBBBC6CB7E8789787F7D7F827C8A8D868A8D84
8E91869C9D929D9B94A4A09AA9A39DAAA39CAEA6A0AEA49FB0A59EB1A69DADA399ABA196
AEA196B0A193B2A191B29F8FB4A18DB5A08AB4A088B4A087B8A38ABAA48CBAA48DBAA68E
BBA78EBEAA91BEAA91BEAB94BDAC99B3A697938F82B8BAB0D8DDD8BFC6C7BFC4C4D0D0C9
C1B9ABC9BBAACBBCA9CDBEAACBBCA7CCBFA9CBC0ABCCC1AECEC3B2CDC1B0CEC4B2CEC4B4
D0C4B7CDC3B7CCC4B7CDC6B8C9C3B6CBC2B8C8BFB7CEC6BFCAC3BAC7C0B6C6BEB6C3BBB4
BEB9AFC0B9B1B9B2AABAB5ABBAB5AABBADA5C9A09AA44343AE191BBC1113BA0C0EBA0C0E
B60B0FAF10119E1B1DA14B547C5B752D35621030641F416D59738D8B98A0969B969D9D93
9C9A8CA4A295A8A296B19A93AE6E6C911A1EA4090DA2080A8C161984556810204822466B
7E94A299808473181D91080F99020B8F070F7D2D394D485DABC8DAB7CDDABACCD6B7C9D5
B9CAD6BACBD9BACBDAB8C8D7BAC8D5B9C7D6B5C6D3B3C5D3B2C5D3A1B5C7728C9E7D99A7
87A2AC8EA6AD90A3AA98A7B17E8F9D222E3950443800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A9865C9E9B9795A4B08EA6B546636F3E5C645C777F3B545C0F282D
627B7E8BA4A87D979C63818638565CA5BAC0BBC8CD8590937C84838386828C8E898E9089
8F92889FA0969B9A94A4A09BA6A19AABA39BAEA59FACA19CADA29BB0A69DAEA399AD9F95
AEA094B0A091B19F8FB4A191B4A08DB6A18BB4A088B4A088B7A38AB9A58CB8A48CBAA68E
BCAA92BBAA91BBAA90BCAB93BCAB97A89B8B9A9486B5B3A7C9C8C1B5B7B2B0B0A8C7BFB2
C5B9A6C9BBA5CABCA8CDBEACCDBDACCCBDAACBBFACCDC1B0CEC1B2CFC2B3CCC1B1CDC4B5
CDC3B8CDC3B8CEC4B9CEC6BBCAC4B8C9C3B7C9C3B7CCC5BBC8C2B9C5C0B5C6BFB4C5BDB3
C0BCB2C0BBB5BCB7B1C0B9B2C1B8B1C1A8A3BD7977A42222B81313BD0E10BB0C11B70F11
AA120FA52E2AAC666B5946601C2B5B1634664661858192A098A19E9C9E94A09F939E9C8F
A09F8EA5A193A89C91B085809233349F1014A4070B980C0F9845513F31540C2C5C325C82
4964778B7981731D21910A0F9B040D95050E7D1A275A4558A3BECEB7CFDBBCCDD9B8C8D5
B8C8D5BBC8D7BDCADBBCC9D8BCCAD7B8C8D7B5C7D3B2C6D1B3C8D6879FB0456479577688
66838E7B94997B8F947C8A926374811C2B36504A4000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AD8554AEA79E8F9EA77E94A23853607B97A23F5C650D272E597277
718B916C8890819AA0728A90768D929BAEB3BBC9CF8D9B9F7D86878C8F8C8F908D939490
999B939D9E969F9F97A3A29AA3A098A7A39AA9A39CABA29CADA49CAFA69CB0A298B1A096
B3A295B09E8FB09E8EB19E8FB39F8DB49F8BB19D86B19D85B4A087B9A68EB4A28BB7A590
BAA893BAA890BBA88FBCA991C0AE99B8A8978B8273A4A095A6A398979588BCB7A7CBBEAC
CCBBA7CBBBA7CABBA9CDBDADCDBCADCAB9A8CCBCABCDC0AFCEC1B1CBBEB1CDC1B4CDC3B7
CCC2B8CCC2B8CDC2B8CEC3BACCC3B8CBC2B8CBC2B9C9C1B8CAC3B9C5C0B5C6BFB4C8BFB6
C2BDB3BEBBB2B9B7B0BCB8B1C1B9B1D0ACA9A44749B11B1DBE1112BC0C10B60D0FA91310
B13F36CF837E98677070536C6256737D7E9391959B9A9D97A3A598A0A193A09E919D9E90
A4A293ABA297B5958E9E4F4E941416A5090D9E0A0D952A33754F6B112050254871A9CAE0
ABC0CB9C8E946F1F23920B1199030995020B810B167041538F9EAFB6CDDABBCCD9BCCAD7
B7C7D4B8C8D5B9C9D8B7C7D6BACAD9B8C8D7B3C5D3B2C5D3B5CAD87C94A86E8BA2557288
6D8A9788A2AAA0B4BA9EAEB58697A11E2D3858554D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AB7E4BB5AAA08B97A0899CAB758D9C67838F143138466064698389
4C69712B4950607E8394AFB4698186A7B9BDBBC8CE9AA5AA7F888A8B8F8F919290939390
91928D9C9C979E9E96A4A49AA6A59DA6A19BAAA49FADA49EAEA39CADA299AFA097B09F94
B29F92B09F90B09E8EB19E8EB39F8DB59F8CB39D87B4A088B2A089B4A58EB6A68FB7A790
B8A892B8A793BAA993BFAC97C5B19DC1AE9BB7A798A19688A9A291BCB5A2C8BBAACAB9A8
CEBEABCDBEADCDBDAECCBCADCDBEAEC9BCAACBBDABCCC0AFCAC0ADCBC0B0CAC1B3CAC2B6
CCC4BACCC3B9CEC3BBCDC3BCCEC3BBCBC1B8CAC0B8CABFBAC6BEB7C5BEB5C5BDB3C6BDB4
C0BAB1BCB9AFBBBAAFBEBAB1C2B4AECD9F9F9B2D32B5151ABF1013B90E11AD1412B53B34
DD8079BA60609B353C96283494353EA97070AD988FA29E92A19F92A5A298A2A095A3A193
A9A093B3968EA86562931B1DA30C0EA30A0A991F219156692626530E2A5C5F7E9995ADB6
A7B9BF9E959B73292F8C0B1298030898020A8B060F7529377B7585BBCEDCBACBD9BACAD7
B6C6D5B5C7D5B8CAD8B6C8D6B4C6D2B7C7D4B6C8D4B3C6D4B2C6D68AA0B2849FB0748E9D
768E98778E96869BA090A3A88C9EA61F303A5A5B56269A0F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0053BE28A69A8B828F96AEC1D0879FAF3E5B67314C54667F854A636A
0F29304A65685D797C456266819A9F94A8ADBCC8CDA8B1B67F878A8C91918D8F8D949590
9796929B98959F9D98A4A29DA5A19AA69F97A9A199ACA39CAEA49DACA299AEA299B1A496
B0A091B3A193B09D8FB19F8DB3A08CB29D89B39E88B39F87B19F88B4A48DB7A78EBBA991
BCA894BBA794BDAC98BFAE9AC1B09DC4B29CC6B3A1C2B1A1C7B7A5C7B9A6CABBA8C9B7A5
CCBBA8CBBCA9CCBEAECABEAECABEAFC7BAABCABEADCAC1ADCBC3B0C9C0AFCAC0B3CAC2B6
CBC3B8C9C1B8CAC0B9CDC3BDCCC1BACABFB6CAC0B8CAC2BAC4BDB5C7C0B8C1BAB2C3BCB4
C5BFB8BEBBB0BCB9AEC0B9B2C2B4AEC592929C272BB81519BC1011B41310AE2B24DF7871
AA3D3B9E191BA81114AC0D11A31216902A2AB18B849D9C939EA097A7A59CA39E95A79D93
B1938DA96162982023A30C10A7080AA11010BE595C6E425928284E43507095A2AD959EA3
8B989F716A747C3841890B129702079A020A92030B780D1B7C5261B4BCC9BBCCD6BBCCD6
B7C8D5B6C8D4B8CAD8B7CAD8B7CAD5B6C7D2B8CAD6B2C5D3B2C7D68CA4B64561755D7787
69828A687C835E7274697B7D687A811A2C395B605F279D1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0052BD23AA9B86808D92A7BDCA617D8B2C4B54627C82486166122B2F
455E627C949992ABAF9AB3B76D878D556D72BECCD3B7C0C781878D87898C8B8A8B939190
9998959B9A969C9B97A3A09AA8A39DA9A39CABA39BAEA59CACA199AFA29AAD9F98AFA196
A99B8EB3A496AF9F8FB09F8CB2A18DB5A38FB4A18BB29E86B6A28AB7A48CB8A68FBAA691
BAA491BFAA97BAA895C2B2A0C1B19FC5B4A1C4B2A0C3B1A0C4B3A2CAB9A9C8B8A6CBB9A7
CBB9A7CEBDABCDBDADCEC0B3CABDB1C7BBACC5BCABC5BEAACAC3B0C8C1B0CBC4B5C7C1B3
CCC6B8C7C1B4C8C2B7CBC4BAC9C1B8CAC4BBC9C4BAC9C4BDC6C1BBC4BFB9C2BEB7C0BCB5
BEBAB2BEBAB0BEB8AFBEB7AFC2B3ADC9989899282CB81519BB0F10AD140FD96058BC4A48
A21718AE0D11B10A0DB20B0DA90E119021257F5D67606D7693A09CA1A099AC9F97B6928E
A559589B2023A70C10A9050AA70408A20A0FA82A2F9D3A47924A5A9B6A75BFA4A8B8B1B3
B9BFC4958E9681444C890E159802089A02079502098C0914782834B7A4B0C2CBD5BFCDD8
BACBD5B7C6D3BBCBD8B8CAD8B3C7D4B6C8D4B7C9D5B3C5D3B0C5D3A4BCCE2C496066879B
6F8E99738C9579909580959A82969E1C303D5B64653A6C1E00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB81A9F8B6E7A8183ABBFCA3E59637591995C757C183035364F53
6E8A9058757C809CA38DA6AC6E868C687D82C1CED5C2CAD4858991898A8D8D8B8C908F8D
9697939797929B9994A09B96A6A19DA9A29FA9A19CADA39BACA299AFA49BAEA097B1A399
A99B8EAC9F90AF9E8FAF9D8BB19F8BB19F89B5A189B59E86B79F88B6A289BAA68DBDA791
BFA996BEA897BDA999BBA99BBCAB9CC1B0A0C6B4A4C3B0A1C8B5A6C6B3A3CAB7A5C9B8A4
CBBAA8CCBDAACDC1B0CBBFB0C9BCB0C7BCADC5BEACC2BBAAC8C0AFC7BFB0C6BFB0C5C1B2
C9C3B5C9C0B5C9C0B7C8C0B7C4BFB5CAC3BAC9C3BAC3BFB6C6C1B8C3BFB6C1BDB5C1BFB7
BFBCB3C1BDB4BDB8B0BCB5ADC1B3ADD0A8A79A373AB1171BBA1011AC110EE6605CAC2424
AE1013B40B0FB40E10AC0E109D131796435150436422395A8D9BA3A79B96B08681A14A48
9B1A1AA90D10AA0709AB0509A90307A90509A4060BA0080D9A0B129010188C2C30AF797C
A69798A89FA2834E52830F1797030B97010798020996050F800D17935A64CEC4CFC0CAD5
B9C8D5B8C7D4B2C3CDBACCD8B3C7D2B3C7D2B5C9D4B6C8D6B2C7D5ACC4D5637F937695AB
7493A7688397597687637F8F6A859515313E52626252453000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB616A78F6C888D8BA8B8C270878F7F99A3304B552D454C728991
526F792B4D5564848A607B807E9599A3B6BAC2CFD5C7D0D88A8F958B8D908D8C8D8C8A8A
92918E9696929A9995A29C99A49B9BA99F9FAAA19EAFA79FADA59CACA398AB9F96AB9F93
A99C8FAC9D8FAE9C8DB09D8CB09E8AB09E89B4A088BBA28CB99F89B8A38CB6A48DBAA793
BAA895BAA997BDAA99BDAA9ABEAD9CBDAC9AC4B2A1C5B2A3C5B2A2CCB9A8C9B8A6CBBCA9
C9B9A9C9BCABCBC0B0C8BFAFCCC0B2CABFB0C5BCADC4BAADC6BCAFC6BEAFC7C0B2C3C0B3
C7C3B8C9C1B7CAC1B8CAC2B8C7BFB6C8C0B7C9C3BAC6C2B9C4C1B8C5C1B8C0BEB4BEBDB3
BEBCB3BDBEB3BDBBB1BEB7AFC0B5B0CAB0ADAD6464A42025B51115B71112B9181AB41116
B50D11B30C0FAA0E109817189A434E785B7C19285A2C4069A297A3AF74759631329E1315
A90C0DAC0709AC0809A80307A90307AA030AA70105A60105A60308A6060B9C0B0D871A1E
AB7877A29090A174757D121996050E9A02099C030B98020C8C040D76151FAD818BCAC7D0
BBC9D5B6C8D2B3C5CFBBCDD9B7C9D5B7C9D5B7CBD7B5C9D8B2C9DE7C98B33957791D385E
0A224A051B4302173D0416380C223F09243854686A554D3C00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0050B814AA926A9B9F9BA0AFB99CB0BC516C7726424B68838B58737F
264751406267617F8249636695ADB098AEB3C3D3DAC9D2DB8D939A898D908E8E8F929291
9897959797949A99959D9996A49E9BA7A19EA7A19EABA6A1ABA49CAA9F96A99C94AA9D92
AC9D90AA9A8BAF9E8EB19F8DB19F8BB09F8AB3A18BB6A089B69E88BAA28BB9A48FB8A694
B7A996B9AB98BBAB9ABEAB9BBDAA99BFAC9AC0AE9DC6B3A4C8B5A6C8B6A5C9B8A6C8B7A6
C7B7A8C9BAADC9BBAEC9BDAFC9BFB0CCC2B4C6BCB0C5BCB1C2BAAFC4BCB2C9C2B7C3BFB4
C7C5B8C6C3B7C7C1B6C8C1B9C8C0B6C9C2B7C8C2B9C6C1B8C4BFB6C5C1B8BEBCB3C1C1B8
C1C1BAC1C1BAC2C0B9BDB8B2BEB8B1BEB2ADC6A09EA24C4FA12022B01819B11415B21418
AB1217A0151996262C9E5B696B5A7A1F2F5E2F3B6A8268859E505B9A1F23A81214AB070A
AF0808AF0808AA0607A80307A70208A70206A80309A60107A90408AE060DA9060C920A0F
93454A998087A6858B7A1D2691070F98020999020998020B92020B870813751E2AB5939E
C2C6CFB5C6CFB0C4CFB1C5D2B7C9D7B2C6D5AFC8D8A7C1DC6380A81A396B011B5000144D
001146000F3F010E3B000D37000F34021833475C6554544813CC0600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98D619B9B9696A5AF869DAB24414C728E97607C83325058
3E60652B4D4F7F9B9C98AEB3627A81516970B4C6CDC8D2DA91999F8A90938E9191909290
9798959B9C989D9C999D9C97A09F99A5A09BA39C99ABA5A0A8A199A9A097A89E94A99E93
A8998EAB9B8EAD9C8DB09F8CB2A08CAE9D89AF9D89B09D86B6A189B9A38CB6A18BB6A490
B9A994BBAA96BBA998BBA897BEAC98C0AE9AC1AF9EC1AF9FC5B4A4C7B6A5C8B7A6C6B7A6
C6B8A9C7B9ADCABCB0CABEAFC9BFAFCBC3B3C9C2B2C4BCAFC4BDB2C5BDB4C3BCB3C3BEB4
C3BFB4C5C1B6C5C0B5C7C0B6C4BEB2C6BFB5C7BFB6C7BFB9C5BEB7C5C1B8BFBEB5BFBFB9
BEBEB9BFBEBAC0BDB9BEB9B5BEB9B3BAB3ADBEAFAAC7A4A2B174709F48469A353897343A
98454D995E6E7C64813A406D1C2F6151537B936580932E3B9F1319AE0E11AE0909AB0507
AD0709AD0709A90506A80305A60105A70105A70206A60207A70208A90108A8040997060C
8D323E50384A998B997830398B0A1396010998030995010992010A8F020B830814762330
B0949EBEC7CEB5C7D0B8CAD7B7CADBB1C8DE7E9CBD24447502205B011A5900155100104A
010E44010E40010D3A000B36010E340112321B2F40535A5222980D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98552A5A19991A0AA7F94A14C66717390993A595F3B5D60
3154556C8C916D8B93718B919BB0B78B9EA6B0BFC7C8D3D89CA6A8878E918C92928F9392
9596949898949A9B959C9D989E9E989F9B97A39D99A8A19BAAA198A79F94A59C91A69A8E
A99A8CAB9A8CB09D8FB19D8CAE9A89AC9A87AE9C87AF9C85B49F87B39F86B4A08AB5A38E
BBA893BDA893C0AB98BBA793BDAB96BDAA98C0AC9CC1AF9FC1B0A0C6B6A5C5B6A3C3B7A4
C4B9A8C3B8AAC5B9ACC8BDAFC7BEB0CAC1B3C9C1B4C2BBB0C1BAB0C3BCB2C3BCB2C2BBB1
C4BDB2C7BFB5C4BCB4C6BDB5C7BEB5C8C1B9C7C1BAC4BFB8C2BFB7C3C1B7C1C1B9BFBFB9
BFC0BAC0C0BBBDBBB6C0BDB6BEBBB2BCB8AFBCB5AEBBAFAABEAEA8B09C9C7C6B756A6377
4F56732A3D66183367293A6D75648A924D62951E28AB1418AF0B0DB1070AAE070BAB0508
AB060AAC070BA90408A90409A9040AA80309A80409A80307A80307A80306A5030698070C
9237443D2A426E718485525C830F1797040B96010593000793000A94010C8D020D7F0A16
6E2F36B5B1B5B4C8D1B0C7D9A6BFDC58759F0B2A60011C5C00175A01145901135501114E
010F46010D41010D3E010C38010C33000E3005172E515A59219A1000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A87E42B2A99A89959C98ABB67F96A44F6B7736565C305155
6E8B9044606727434A5F7B828EA6AC7B8F96B6C7CEC5D1D8A7B1B6868E918E9395919595
9395939798949899949A9C979E9F9AA19E9BA49E9BA69D97A89E95A99F96A3988DA5978B
B1A093AA978AAD998BAF9A89B19C8AAD9B88AB9A83B09D85B29E85B5A189B6A48DB6A58F
B8A791B8A68FB9A792BAA693BEAC98BCAB97BCAA98BEAC9BBFAE9DC2B2A2C3B4A4BEB2A0
C0B8A5C3BBA8C2B9A8C2BBABC6BFAFC6BFB0C7BFB3C4BCB2C1BAAFC0BBAFC0BCB0C1BDB0
C6C0B2C8C0B6C7BFB7C7BFB7C6C0B6C0BEB3C4C2B8C4C2B8C1C1B7C0C0B7C1C0BABEBEB7
BDBEB6BFBFB7BBBAB3BFBCB5BCBBB1C0B9B2BAB3AEBCB5B1B4B2ABAFAFAC999EA3707F8E
5A6E855669877476949470889035469E1620AB0D12B20B10B2080CB1070EAF070DAC060A
AB060CAB060CA60409A60309A5050AA5060BA30508A50308A50207A80307A1030690060B
9648572E2647515E789B7B8677141C93070E98040995010894020993000A90020C850510
6E1F2A918898ABC4DA9AB7D73B5A8A04215D01195B01165B01185D02175B01135400104B
010E43000D40010D3D000C38000B31000D2E02132C38434A46362100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BD24BCAD9C7E878EB5C8D56983913858633B5C61607D82
486166172E327B9497718A8E687F86B3C5CCB2C1C8C1CED5B2BDC3848D908990928D9291
9496959796949A99959C99969E9D9A9F9C99A49F9AA69F98A59D93A39B90A59A8FA5988D
A7978DA7958AA89587A89683AD9B87AE9D89AA9A84AD9C84AF9C84B5A289B5A48BB4A48B
B7A78EB7A78EBAA992B9A894BCAA96BBAA96BDAA96BEAB96BCAC97BEAF9CC0B3A1BCB2A0
BCB3A0C3B8A4C3B7A5C1B8A8C1BBABC3BDADC5BEB0C9C1B6C2BBAFC1BBAEC0BCAFC0BCB0
C2BCB1C6BDB4C7BEB8C7BFBAC6C1B9C1BFB6C0C1B6C1C1B7C0C0B6C1C2B7BEBFB6BFC0B8
BEBFB7BEBFB7BBBCB4BABAB2BBB8B1BCB7B2B8B4B0BBB7B3B2B3ABAFB0AAADAFABAAADAD
A8A7ABB29EA7A86B76932531A8141CB30D13B5090FB50811B4060FB1060EB1090EAC070B
AA060CA7080D9D0A0E93090E900F15901317950C119D050BA30307A50306A00508890C15
8D546D161F484D6382A696A176252B900D1597030A96000A94010B93010B90010A86050E
7A2A3D322A4E6688B62B5085011E5E01185C00145802165B02185C01185A011551001248
01124004153C0C1F4307173C01103201122F04152F22313D4C423400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0056BF26B7A38F6F787CB1C5D04B677338596258777C516D72
152E32758D917B939AAAC1CBAFC4D0BBCFDBA9BAC4C4D0DABBC4CE838A91868E908C9392
9598979696959896949D99979F9D999C9B97A29F99A19B93A29A91A2988EA1958BA4948B
A49288A69289AA968AAB9687AD9A88AB9A85AE9D87B29E88B39F87B09F88AF9F89B3A28C
B6A48EB4A38CB6A68EB7A791B9A894BBA994BDAB95B9A78FBBAA93BEAE99BAAF9AB9B09C
BBB19DC0B4A0C2B6A3C0B7A6C0BAA9C2BDADC7C1B4C8C0B5C5BEB3BEBAAEC0BCB0C1BEB2
C3BEB3C6C0B6C4BFB6C4BFBAC4C0BCC4C3BCC3C2BAC2BFB7C2BFB6C2C1B7BEBFB4BFC1B7
BDC0B7BEC0B9BCBDB7B8B9B3B7B6B1B9B6B1B9B6B1B6B5B0B6B6ADADAEA6AFAEA8B0A8A3
BB9F9FA760659A212AAA1117B40D11B5090DB3080EB4070DB4070DB2070DAF0A0EA60A0D
9B0D12951B239539428E4D5D805466845663A04A52920B11A5060AA6040A98080C92333F
492E500D25547193B49DA3B2824D5483101795040C97010C94010B92010A8D000781050C
7B2F45201644041D5C011C6200176100145A001357011458011758011C570E2B5C1D375D
3951695066764F6275162842061C332139490920300F202E4D463E24960900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0053BA1DAA9175717474ACBFC8516C7745626B627F84173034
688185738D945C778299B2BF7A94A1748E988A9DA6C3D1DAC0C9D3888E958B9092919594
9195949496959795919C99949E9C979D9D98A19F9A9F9A92A39B90A49990A3968DA4948C
A5938BA99790A9978CAC988AAE9B8AAD9A88B09C89B49F8BB49F8BB29E89AF9C86B19F89
B3A18BB3A28BB5A58DB6A690B9A793B9A893B8A791B8A790B8A792BBAC97B8AA95AC9E8A
B5A592BDAF9CBAAD9BBEB5A5B9B3A3BEBAA9C3BEB1C7C0B5C5BEB5BDB9AEBCBAAEBFBDB0
BFBBAFC1BEB2C3C0B6C2BEB7C4C1BCC3C2BCC0C0B8C0BEB6C1BEB6BFBFB8C0C1BABDBFB8
BCC1BABBBDB8BCBEB8B7B8B2B8B9B1B9B6AFB8B8B0B8B8B0B4B4ACB1B0A6B5AEA7C0A3A1
A961649C2028AE1018B40B12B50B0EB4090FB3080EB3070DB0090BAA0A0F9D121595272E
934B5B7C57744B456C232D5D1926544D405F934A57920C14A10209A1040997171B9D5869
201C412A4A775D8CAE6D8CA389727E77181F91070E97020A9301099202098D02087E040E
7631491C144502165700155E01165B01175800165306235B1634653457815A80A07A9AAF
8BA4B093A8B35C7285061932213B4C4B64684053590E1D2A48494821960D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DC0C9F815D8C8B87A7B7BF5D75825E7A841A363B5D787B
6C878C5470794B65719EB5C1405A63859BA2C2D2D9C4D1D9C7D1D78B9298868B8D888C8D
848888878B898E8E899A98919B99929D9B979F9C979E98919E968CA1968D9F9188A4958E
A4938BA4948AA6968AA99789AA9788AE9988B09B88B19E88AF9D88AF9D88B09E87AD9C83
B2A089AF9D88B2A08CB3A18CB1A08CB3A28EB5A48EB4A58CB0A18AB1A28CB1A38EB3A38F
AE9D89AEA08BB0A492ABA190B2AB99BBB5A5BEB9ACBEB7ACC3BBB2BEB7AEBEBBAFBEBDB1
C0BDB1C0BEB2C0C0B5C4C2BAC3C2BBC2C3BEC5C5BFC2C2BBC0BFBABFC0BAC1C4BDBDC0B8
BCBFB7BEC0BABCBFB8BABDB6BABBB6BAB7B2B9B8B2B5B4AFB5B6AFB5B1ABC2ABA7AC6869
A02529AF1116B40C11B6090FB5080CB6090DB4080CAF0B109C0D0F982A309757656C5675
2E3567122964102C65253A6957517581495F8B19259E0710A4030AA1040AA41A21A34857
6C48616A6F8895AFC37792A49C97A1773139880C1395030B9401089100098A010B79071A
4E163B12114B02145901135B001559011A57092759375B8186A8C497B8D32A4C6781A1B7
7491A07794A62D4762011530506A75586F6D54646422303844484A21981100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009E7D53A5A39DA1B0BA839BA836535C48656A718D92
4D6A7146646C95B0B993AAB494ABB4A3B6BFC6D5DDC7D2DBCCD5DC8D969B7C8487787D7E
75797780827E8C8B8795928C98948D9E9A95A39C97A19790A1978E9F958CA0948A9D8F86
A19289A6958DA7968BA99889AB9988AA9885AB9A83AC9B84AB9983AC9B84AE9E85AE9D85
B19E86B5A08AB4A18BB19F87B2A088B19F88AD9D84AF9F85AF9E84AB9A81AB9A83AB9B84
AD9E87AB9E87ABA08AB1A794AFA794B0A897B4AD9EB6AEA2C2BAAFC4BFB3BDBBAFBDBBAF
C1BEB3BFBEB4BFC0B9BDBEB9C0C2BDC3C4C0C5C6C2C1C2BDBEBFBABDBFBBBEC2BBBCBFB6
BDBFB7C0BFBABDBFBBBABCB8BABCB9B5B4B2B9B8B4B4B5B0B5B5B0BEB0ACB8818299282D
AF1318B70B10B80B0EB40A0CB3070CB2090EA80D119E1F259E4F5C7156732C39690C2866
11326D36507C6F769393768B883B4B8C13209F0814A4040CA9060BA40108A1040B940914
87202BA06B75A19BA3B0BFC9A3A9B38B646E7A141D92070F95020A90000A860511600B29
240A3E0A155901145C01145A021D592748777A9BB9A1BCD1AFC7D98299AD5770846E8797
5D788833516B021E3D0F2B424660644F635C52635F3B494D3E4346219A1500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A38055A7A49E9CAAB5879FAC314D587591994B6870
3B595F88A6AB4A68716E8A95748E9995A9B3C4D3DEC0CBD5C8D0DA939BA27C8487767A7C
737674848480928F8C9C9593A098959F9793A49D969F978F9E968E9F978D9F94889E9085
A29086A49287A9978BA89687A99887A89884A99983A89780AE9B83AC9B82AA9A80AE9D84
AE9C84AF9D85B09E86AF9C83B19D84AB9A80A9987EAA987CAB977CA9977DAA9981AB9C85
AA9B83AC9E86AB9D88ACA18DAAA28DAAA290ACA596B5AFA1BBB4A7C1B9AFBDB9AFBFBBB3
C3BEB8BEBCB7A2A5A39197969FA4A4BCC0C0BFC1C0BEC1BFB0B5B29FA6A4A8AEAAB8BDB8
BCBFBABCBDBABABCBABCBDBEBBBCBDB8B8B6B4B6B1B3B4B1B5AFACC39F9F993D42A8181E
B50D13B80A10B80B0FB60A0EAD0A0EA010159B323B92607842436D122E680F346C3A5782
747C989B85949A5E698E272F970F17A0050DA40309A7030AA40308A70409A8040AA4040B
970911821E25B08C9599A6BA5A75908B8497732C35880C1392020A8D020B73081B3B0A35
0F1051041661001A5E0928614A6C949DBCD7ABC5D7ABBFCEB2C5D48297A799B2C094ACBD
4F6782071F450D284745637359727255666052605A414F5139424525A11D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A68254A6A09996A3AD748896758F9C5F7C853A575E
7D9AA04C6A72607E8675909A758D97A5B6BFC6D3DDC3CDD8C9D0DBA0A4AE7C8186727679
7B7E7E8B8C8A9392919793919D96939C958E9E998F9A958B9B968D9C948C9D9188A29087
A18E83A49186A69487A39283A69584A89784A99884A99884AA9782AB9981AA9B81AB9C82
AA9980A8957CAC987EAD997EAF9C81AF9F84AC9C81A9987DAB997FAB9980AA9B81AC9E85
A7997FAA9980AB9C85AB9F8AA9A18DA8A18EABA491AEA898B2AD9EB3ACA1BDB7ADBEBAB1
C1BEB8A9AAA5949994B2B8B5888E8DA9AEAEC2C4C5A2A5A4959A97A2A7A3A1A8A3848E8B
A3ADA9B6BDB9BABDBABEBFBDB7B7B5B7B8B4B5B6B1B2B1AEBEABABAF6C709B1D24B21016
B60B11B80B11B5090FB00C119B14199A445173577525366C0E327126477A6B79979C8B9C
9D687190333995161CA10B11A4040BA40309A40309A30208A40309A50409A50207A50309
9F030B830A138F5A676E768F1A39586C788C8B626B7A141A8B040B8605105A09261F0C45
07175F021B6213366F678EB4A6C6DCB0C7D8B1C5D4B3C5D4ABC0D23D5B7391B5D34C6B8F
14305B011B452A486173939D6B828360726E5260584856553440412CAB2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A47C4BA19A8F929EA5AABCC9849CA93C59646C8991
55727B5C7A84738F99788F97ABBDC6C4D0DAC6D1DCC5CFDAC7CFD9AAB2BA696E75727579
8385878F908F92918F96918F9D95939B96919A959093918A96938A9C948C9F91899F8F86
A18F85A18E82A18F81A69385A99686A89683A99782A79581AB9985A8967FA9977FAB9A7F
AB987CA79277B09B80B19C81AD9B80A9987CA9997AA89877AD9C80AA9A80A99A80A99B81
A8997FAB9A80AC9E85ADA28BABA08DA89D8BACA28EABA28EAEA897A9A394B5AFA3B9B6AB
C2BFB7AAAAA5888C87AEB5AF8A908DAFB2B0BABBBB8C8D8BBDBEB9BEC0BABCC0BAADB3B0
808988B5BDB9B9BAB5B9B8B3B9B8B3B6B5B1B6B5B0B9AEABC7A0A298373CAE181DB60B11
B60C10B50D10B00D129C181CA055625F5174162F6810336E475D878E849D98697491383F
8F151D9B0B11A3070EA8050DA7040AA50109A4030BA30208A10109A20108A60308A70409
A00309860610874C603C425B86A1B596A9B69B8D95762E34840D137E0919470E33121353
03165F011C5B4B749FA3C8E1AFC9D7B7CBD9B2C6D5B4C5D6AEC2D54F6D8A466C94163565
001C480D2C4C41606E5C757A53686852645E5362574D5B562D3A3A544E4500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0051BE29A397898A959EA8BDCB607B865B788257747E
58767F6C8992728D96A7BBC5BED0D8C1D0DBC3CFDAC5CFD9B2BDC6909BA26F767C737579
88878992909092908D938E8D9B959499949297928F8B8884908D859A92889C8F869F8E86
9E8B829F8C7FA29183A49383A89685A99782A5937DA4937DA4927CA7947DA7937BA8947A
AB987BA89579AF9C82AF9B82AA987EA49278AA967BA69273AA9779AA997EA7977EAA9C85
A4977FA69A81A9A089ACA28FAEA191AA9D8DA89B8AADA392ADA696AAA395A8A496AEAB9F
BEBDB3BCBBB39C9F97939B92A4ABA3BFC2BDB5B5B3959795C0C1BDBEBFBABCBEB8B4BAB7
7F8985B2BAB5B7BAB5B9B8B4B9B6B3B3B3AFB4B4AEBFB0AEB98285971F26B51117B90C12
B50C11AF0F13A01D23A35A6A554E72163168203C71717296997184943E4A91181FA00E15
A4070DA7040CA7020AA50309A30207A40309A6050BA40309A30208A60209A8050AA70309
A00509850A1488556D1A28499CC0DA6488A177889C8E6B757317226E0D26310B3A0B1454
0915531F2F633D6085A4C9DFAFC8D6B4C8D6B6C9D8B6C8DAAAC0D77694B60A2B59001E50
1C41645476877A949A6E82855D6E6F53635E5262584858562C3A3E56544E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004EB91FA59781869096A9BECA5E798473919A486771
65838B5C777F98AEB6BDCED8BDCED9C1D0DCC5D2DEABB6C3838D967B858980868A838687
88898890918D8E8E8A95919096918F98918F98928D827C758F88809D938A9D8F879D8B85
9E8A82A08D80A18E80A59384A69483A7937FA7927DA4907AA49078A8917AA9927BA8937B
A8957DAB9881A7947BAB987EA69579A39176A69277A79275A89375A9957AAA9A81AB9D85
A79C85A69B87AA9F8DACA190ACA291AEA393A69C8BA99F90A9A3999B9A8F9091869A9D94
B9BBB2BCBCB2BEBFB4C1C2B8BFC1B8C5C4BDBEBEB98B8C8BB3B6B6BCBFBDBEC2BD9FA5A2
909693BABEB9BABBB7B8B7B5B5B4B2B2B2AFB3B3AFC0B0AEAC6D70A11E22B71114B90C10
B40E11A1161AAA596659486C2334674A5182896A8B954758951C28A30F18AC0A11AE0A0C
AB0508AD080DAA060CAA070CA6050AA60409A60409A6030AA7040BA8040BA7030AA8060D
9E090C881E276E4F6E1026507CA1C11D4164385473AEA9B97137465E1637270C42121253
2813454D34583A4763A8C8DCAEC9D6B2C9D7B5CCDCADC6DE6E8DB0143464011F511F466D
5D859C88A7B28FA6AB7D8F926D7D7D5D6D6950625B394D4C253A3B61685F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004FB91CA29074899497B0C5D187A0AD54737E5E7D86
65818893A9AFACBDC6B4C3D0B9C9D7B9C9D898A6B677818C7780867B8386808689868A8D
88888A8F8F8F908F8D918F8C9992909A908E9E94918F867F8C847A938A819D908A9A8B85
9B8A819E8C7FA39081A49283A1917FA2907BA6937CA7937AAA957DAA937BAD947DAB9680
AB9681A7927BA28D73A49075A49276A8987CAC9B81A39073A79275A59174A6957CA99980
A69982AB9F8BB0A493ACA192ABA293AAA392A49E8D9C988A7C7D747D8179787E77626C66
848D88BAC0B8BCBEB5C1C1BAC5C3BBC5C2B9C1C1BBB0B2AF8E9293919899929D99949D98
B2B5B2BAB9B6BBBAB6BBBAB6B7B8B3B4B3B1B3B3AEBFB1ADAE6C71A21D23B81114B90E0F
AD1112B4474C87596B5C4E6F8769888F465D94212FA3121AAD0D13AD070EAF080DAD0709
AB0508AA0409AB050BA8030AA6060AA1060A9F0C0CA10C0FA4070DA60309A70309A20309
91080D9343543A345C1A3B667698AF7490A2849FAFC2CEDC927A8B4E2247200F47190F4C
46123C60233F3C344F9CB9D1A9C8DAAEC8E093B2D53F618F07285F011F550A27514F7089
59798668828B63767C5E6F71606F6D5464604D605C1F3439294147606E67209B1300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0027D90BA68D7093999DB4C8D86F8A9961828C5E7B81
96ADB3B6C6D1B3C1CFAFBECCABBBC98796A46B7681737A82787C807A80837F848787898D
858689888A898D8E8B92908C948F8C98908E97918B979289918D829892869B9287998B84
9A89819E8C82A39084A59284A59081A48E7CA58F79A7927AA6937BA9957DA8937BA9947C
A6947CA39278A39173AA9679AC9B7FA5957BA8987EA59376A69174A89276A59278AA9982
A89982A89C84A59A84A59B87A99F8CA69D88A39C89807F727B7D768D91898F958E737E7C
566663A3AFA8B7BBB3BFC0BBC5C5C0BEBEB6C3C4BDC0C1BCC0C2C0B8BAB8B9BCB8BEC1BC
BBBBB8BAB9B7B8B8B6B9B9B7B8B8B6B6B6B5B8B9B4BEB3B1B780829C2127B61217B80D0F
AA1111D5686AB66C75A14E5E9523319F111CA70A11B20B0FB1070BAF050BAB0509AC070B
AA050AA9040BA8070EA2080D970C0E8C1816A5423CBE504E980D12A3030BA8040B9F060B
8A1721825473102254537EAA9FC5DA9ABACA7DA0B2AECCDDB2B6C6614E6D1F164B170E49
43123C5213304535547F9BBF8CAFD44F709E10306703235C092C5D2A4B70728EA469828D
849BA1778B90697C7D6476755B716D4E6464344A52061A2D172C3D606F7025A21C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A58666939597B2C4D46B849667839088A2A9
B0C2CAB8C7D4B3C3D3A1AFBF7A808F706C786E677075737A7D7D837E8084818689858889
8888898987888E8D8A92908C928F8A938F88948F88959188969087978E84998F859A8A81
9B897F9B897FA08D82A18D80A18B7CA48979A58C79A6917BAA967EA8947BA7967BA69579
A493769F8D6FA49070A38E6EA39071A18F73A28F74A69074A79070A89270AB9676A89679
A5967CA4987DA59B7FA99D84A89C84A89D86A69F8B6B6A5F6D746E7E88827A8480627170
4D605C9BA8A0B9BDB5BFBFB8C3C2BCBFBEB9C0C0BBC0C1BBC0C0BBC2C1BDC0C0BBC1C2BD
BBBBB8B9B9B5BABBB6B8BAB5B6B9B4B7B9B6B7B8B3B8B4B0CAA5A4963339B0181DB80F11
B41012B31D21A81B22A8141CAC0E15AC070EAF090CB3090CB4090EB0070CAC070AAB060B
A6050AA0050C960B138D1A2292434A8B585DA7717396353B980B12A6050CA3070C900E14
99506238305F0627605E8FBE5585A97DA9C5234E689BBFD5BFD1E09393A92F2D5511144B
1D12472512412122541630690C2C68001D5A022157254770779AB891B1C99AB5C789A1AD
A5BCC48DA2A9889BA17A929567838B304C5C061F3701122F01142D3C4C5629AA2700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A2825D939493B0C0CE8096A578919CAAC1C8
B1C6CEB4C5D4A5B4C67072826D55635F303963383D8370747C7B7F7E83867F8585838786
8789898C8C8A8F8F8C92918C8F8F88939188918E86918D85968F86978D84988C839A8B82
9B897F9D897E9C897E9E8C7FA28B7CA18878A78D7DA7917FA28D78A7907AA59077A58F73
A69071A49070A28F6EA38E6AA8936EA18E6BA3906FA79373A79170AA9370A89371A69475
A6977BA79A7FA5987FA99C82A79D83A49C83A49E8A75756A525C57586A665566644D5C5B
616F69A9B1A7B9BDB2C0C1B6C4C3B9C5C2BBC5C4BEC5C6C0C0C0BBC5C4C0BFBFBCC0C0BE
BFBEBCBEBDBABABBB6B9BAB5B5B7B2B5B6B1B4B7B0B3B2ADC3AFACB670729F1C20B71213
B90E10B80C11B50D11B40C11B2080CB3090DB2080BB2070DB3090EB1080DAC080CA4090C
960B0F8D1E248D445075516845364F6A4D60873D4990141DA0090FA1070C921013974755
5A49710C25602147796991B2274C6B5B7F9A638396A9C5D4BFD2DEBCC4D1736D8828214D
18134914114D0B124F041A5505265B21426E6685A6A1BFD769879F82A4BD46677E7A96A7
6C87946A818F677F8F3C576D14314F031A3F011238010E330111331A2C3E4C4D4400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A38256A5A49FA9B8C397A9B596ABB5AEC4CD
B0C6D2A5B6C4717584674C5A67232D6A0D13671619865E607F797C7D82847D8485818788
888B8B8D8D8C908F8D91908C918F8A928E87918D87938F87968E86938980998B83998881
9A877F9C89809B887D9D8A7D9E8A7A9E8A78A38D7AA58F7CA7917DA68F79A28B73A38A6F
A68D72A58F71A18E6DA08F6EA39170A28D6DA28E70A39070A4906FA89272A99675A8977B
A69780A99D86A59A84A39A82A29A83A29A84A49D88989684666C625B666066716B68716A
8A9085A1A497B3B4AAC0C0BAC2C1BAC4C0BCC6C3BFC4C3BFC1BFBDC4C0BFBFBEBCBDBCB8
BDBCB8BDBCB8BCBCB7BABBB6B7B9B4B7B8B2B3B4ADB4B4AFBEB0ADC08386A02529B51315
B90E0FB7090EB70C0FB50B0CB3090BB5080EB3080EB2070DB10A0DAA0A0D9D0E12911F24
8F475372566E36365A2F33596C57727D3647860F199A070E9E0A0D901116934652625173
0F26600E346A688BA8859EAC9CB5C2ABC5D588A3B1BED4DFC0D1DBC7D2DCAFACBC694D68
4A1A3F42113D341542262B557797B5A3C2D6AFC8D8ADC6D649657A67859B486577708796
5E7481657A8E213959041A4501144301104102113B010E360110350A1A35494C4F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009B7848AEABA59CACB9BCCEDDB1C2D1B0C3D2
A8BCC978818E614D575C1D266B0C1474080E6F0E12824B4E84787A7E81847E8285848689
8687888B8B8B8A8A898E8E8B918F8B918D88918C868B877F928A83988D89978984988680
9B857EA0877E9E887E9F897DA38C7D9F8877A18A78A68F7CAB937EA38C759D876E9F896D
A38B6FA79075A89479A28F73A39173A38F73A190729E8F6EA1916FA4936FA39372A79A7F
A19580A89E8AA59C88A39885A69D88A19A83A19C86A19E8A9697879395889193869A9B8E
A3A194A3A295AFB0A7BCBDB7C1BFBBC2BFBCC5C5C1C0C0BFBFBEBEC1BFBFBEBDBABCBCB6
B9BAB5BCBDB8B8B8B5B9B9B7B7B9B4B4B7B0B4B7B0B5B6B1BCAEACA46367A11E24B50F13
B6090BB7090DB40709B6090CB70A0FB3070DB40B13AC0B0FA31113951F25954955755773
383D631D2C5948477078526E7C2737890F1A95071094090E8C1B21904F6051476B102B61
0D356B587A9DB9D2E3ACBFCDA3B9CB6384A0698EABB3CEDFBFD2DDC1CFDAC6CCD8A493A1
6B34466C142A640E26512D4A7D8EA4AECAD9B1C7D5AEC4D19CB5C58EA7BC92ABC198B0C1
7C94A2829BB1041A44021347000E42010F41010D39010D35011034031430444A5200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009C7640A9A39992A2ADC0D3E2AFC1D2ABBBCB
848D9A6A626D59323857121570202587363A6310167E454988787B7D7E807C80817F8283
848788888B8C8D8F8D8E8E8A92908C918C87938C868F89828C857D978D89968885988582
9E85819D847EA0877FA0887DA38B7C9E88779F8B77A28D79A5907AA390779D8C6FA79479
A69277A28D73A18D71A18C70A18C6FA08E70A798799D8F70A19171A29271A39375A3967E
A69C89A5A08C9F9A86A19985A59C87A09A849F9A86A19C8A9D9A899E9B8C9F9D90A19F92
A2A093A2A195AEAFA6B6B7B1C1C1BBC2C1BDC2C3BFC1C2C0C2C1BFC0BFBDBCBBB9C2C1BD
BDBDB8B8BAB6B6B8B5BDBFBCB7B9B4B2B7B1B2B7B1B1B4B0BBB1AEAE73769B1C22B30F13
B70B0DB6080AB6080AB70A0FB2090FAD0B10A00F13921B209446537F5E7A39406E143068
2C41716C5B7F7E3C54841725930E1892070F8C0D1284252E81546B3638630B2760194073
8CAECF94A9BC9BB0C27E96AD8AA0B8324F701A3F60ACCBDFBCD0DDBECEDCC3D1DBC4C4CF
997C896D25336F0F2161263C5C5F74ACC8DAB0C8D7ABC1D29FBBD2335175203D6A48678A
7494A95E7991081E47011244001044010F40010F39010E32031633051A333B465010CD0C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053C12BACA5958E9EA5BED0DFB3C2D39198A8
6C5E695D3C416D4446562B2C734E5186585F59181F6F383C8673747C7C7F7A7E7E7C8080
828889878B8B8B8D8B93928F91908C928F8C928E8A928A84948B85968C87968985998883
97847E9D88809F8981A38D83A08B7CA08E7BA08E7AA18C77A9937DA08C749B896EA28E71
A18C6F9F8A6DA18B6DA18B6B9F8B6BA08E6FA49576A19273A49476A29275A39379A4977F
A59E889E9A83A09B84A19A84A29A86A09A88A19B88A09B889D9A879E9D8A9F9C8DA29E91
A29F93A6A69BACADA4B2B3ACBFBFBAC0BFBDC1C0BDC0C0BBC3C2BEC1BFBEBAB8B5BCBBB7
C0BFBDBDBDBBB6B8B4B4B6B3B1B6B1AFB5B1AEB3AFB4B8B4B7AFADB68284991F26B10F14
B70C0FB80B0EB50B0EAE0A10A00B13931A22994752835F7A3E4270132E6E0D33732D4D7F
7C759272283C8C101D960912930A1186131B843B48654C6A1D2B5D072863193F6F6283A1
92A8B896A4AE8696A46C80918FA1B0899DAF91ADC0B4D0DFBED2E0C2D3E0BFD0D9C4CEDB
BFBDC8906D79671E2C601C314A4055A0BCD0ACC7D792A9BF617C9B0D2958011B56031F4F
44647E536F830E2346011241010F4302113E0115360F283D324E592D47532D3D4624A220
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004FBD24B0A5919099A1BFCEDEA6B0C1786D7A
6332395813146E3A396B52536A5C61775A62581D26672C31846C6E7677797A80807B8081
8083858789888C8E8A8E8F8A90908D92918F95918E938B88968C88968C87988E86998D84
95877E97857E9D8A83A28E859E8B7E9D8A7A9E8A75A18974A78D78A188709E876BA08B6D
9E8B6BA08D6EA08C6D9D89689D8A699F8D6CA09272A29478A99A80A7977DA29279A69983
A29A849F9883A19984A099839F9984A09A879F99889F9A889D9A889C9C8A9E9C8CA19F92
9C9C90A1A298ABACA4BBBDB4B8BAB3C0C0BBC2C1BDC2C1BCC3C2BDC1C1BCBEBEBBBCBDBB
BABDBCBABDBDBABEBEB4B8B8B5B9B9AEB2B2AFB5B3B3B6B4B6AFAEC2969B92232BB11318
B60C10B30C11AD1317991A2096414D89627946486E1730680C326E234A7E5E7EA08B99AA
9D8089771B24910F18890E158327317D4E643C375E10275E0A2E6630547C6E8C9E869B9F
91A0A2A5B0B7919FA7B8CCD7B8CFDC94ADBD85A6B99BBDD1BAD3E2BFD3E1BDCFDCBDCDDB
C4CEDAB9B1BD845E6C5920324A344A839AAFA9C3D394ABBD7991AC122C5B01185601154B
4765856F8BA018315001154000133E0C2343284452425C5D4B635E4B606229393E2AAA28
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004DB71DB7A38F91969EBFC8DA837F8F6A434B
61131664080A6424266A4F51675D62755D6460273063262C83676A747477747A7D797C7E
8484868989888C8C8A8E8F8A8F908D91918F928F8C96928E948E89948E879890879C9188
9D8D859D8A839F8B83A28E85A28E81A38E7C9D8872A18A73A187719A81689E86699E8768
A08A6A9E8A689F8B699E8C69A08D6AA59170A391719F8F72A6977DA7987FA2937EA39783
AAA08DA29988A59D8B9B95829D9784A099879E99869D99869C9A889B9B899C9D8D9C9D8F
9D9E909D9F93AAACA1B8BAB2BCBEB7BCBDB8BDBDB9C0BFBCC1C0BCBDBEBCBBBEBDB9BDBD
B7BEBCB5BCBCB6BCBCB5BBBBB4BBBBB1B8B7AFB6B2AFB3B0B1AEACC5A1A4912D33AD171D
AD1115A01D219B3E47936475554E6B3442683049752C4C765A7A968399AB91A0A79A9DA0
A58D906C262B7E232C8244555442641D2A5C07245C1338674E6F8C7B939D8E9FA08E9B9B
9CA7A9C7D4DCB0C2CC92ADBE5B819A7DA1BB355D777DA4BBB7D3E2BCD2DFBFD3E1BFD1DF
BDCDDAC2CCD9B1ADB8725A684737495E6F82A6C2D1ACC3D48098B3203D68001A53031852
1D355D718FA61F3C510B263F25415745606B4E66694C615C52635D4E61602334373A7A35
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0025D90BB9A2867C8082A4A9B468535D591C22
6D171A71181A5E161A663C4168545B775F67642E36601F26866467726E727175797A7C7E
8080818989898C8B8A8D8D8B91908F928F8E94908E928F8B928E89968E89958C859D9188
9D8C859C8A839E8C83A08E839E8C7F9F8D7B9B8872A08B73A28B739D856A9D85689E8567
A28A6B9F8969A08D6D9E8B6B9F8B6A9F8A6BA39071A09171A4967AA89C86A69A879F9380
A29987A9A192AFA7999C95859C9481A098849F98859C99849B9A879C9C8CA0A1949C9C91
9C9D909FA193A6A89CBDBEB5BFBFB9BFBEBBC1C0BFBEBEBCC1C1BFBBBEBCB9BEBDBABFC0
B8BFBFB3BCBCB6C0BEB1BAB7B2BDB9B2BCB8B0BAB5ADB4B2B3B2B2C8ABAE913D429A2226
9F393F9A6575615772373C5E605B7C7A627C917E919295A094A0A697A1A498A1A1979B9B
9A9594866D6E856F7B2E30550C255A0E2F63315377667F907F91938594919FACAAA7B2B3
8E999E97A3ADA0ADB88699A8345067688399748D9E9EB7C8BCD3E0BDCFDCBED0DCBED0DC
BED0DCBDCEDABFCDD8A5AAB5676A7A43576BA2BFD18DA8BA25425D29476F011C4E01174E
072148506F7F435F654660674F696D5168695069664D645D4E625C495C5D213238494A47
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B0926D74716D7572785B3C41551B1C
7B3C3C742D315A0C116126296A4A4F74555D682F375A1B1F8260637270716F7576757779
7D7D7F8887898B89888E8A88928D8B948E8D908A878E8885918785918482998B869F8F8A
9E8C859F8C85A28E879E8A809F8B7FA390809F8D789E8C769E89729D84699D8365A1886A
A0876AA48E719D8B6D9F8F6E9B88689E8B6FAA9A7F9F9175A092799E927DA79F8A9E9681
A29A86A39C8CB2ACA1A29C8E9A92819D96839F99859E9B869A9986A1A395A7A89FA19F98
A1A096A1A196ACADA2C0C1BAC1BFBBC1C0BDC0BFBFBDBEBDBDBFBEBCBFBEBDC1BFBFC3C2
BDC1C0BAC0BEB8C1BDB8C1BDB6BFBBB7C0BEB3BCBBB2BAB9B6B7B7C2B3B5936769A06A6E
7F66773C3F615A5A7C906C868A3B4C84212B995659A6989B959EA197A1A1999F9F979E9D
949897969594838A9320355528486D5D76917B8C94818B898A938D89928C8B9190939799
959296948F96968F95A0949CA297A0B2A7B1988E98B8B1BDC4C5D1C2CCD8C2D0DAC0D0DC
BDCFDCBACEDCBACEDBBACAD5A0AFBB51697B84A5B76985937992A0637C932E476B04204C
234563617F88637B7A596E6E5C7070546968516A664A645D4C635D43585C1D3039565B5B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A67D537B6D656C5F655634395F3334
794F50652E3152090B702F2F6B3A4077414A661E24601E217F62627172746F777A737679
7A797D8480838E8A8A8C8A878C8A858B85818E84829086848F818091817F92807D9C8984
9F8A859D898298857C9C877E9C867EA49185A29181A3907D99836D9C83679A80619C8264
9E86699F8A6D9B8A6B9D8F6D9C8D6BA09174A79A809C8F76A2967DA19780A19B859E9884
A39C8BA8A294B2ACA1A59F929C9584A099879B97829D9B869A99869D9C90A8A79DA8A49A
A9A69BACACA1B1B6ADBAC1BBBBC0BDBEC2C1BEBFBFBDBFBCBFC1BEC2C5C2BEC2C1B9BDBE
B9BCBDB9BEBEB5BEBDB5BEBDB3BCBBB7BDBDB5BABBB6BABBB3B5B6B6B4B4B6ADACB9A9AF
7C6A7F8F6B89984D65931F2EA012199F11189D424C69586A6B7F8C92A1A2979D9C9BA09D
949A969297958A949378868C7C8A93838C92888C8B8A88858E8A85928481957B7D9B747A
94606796555E9045508F39458C323C8A2F3C862F3C8B3E4C965D6BA2828FB6ACB8C3C8D4
BFCFD8BBCFD9BBCFDAB7CAD5B6C9D299B1BE82A0AF86A2B0AAC4CF8BA2AEA9BED1516D83
7F9BAD637B82677B7C586C6B596F6C566B684F67614A645E4C63602F434D1F34405D6766
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074912F7E67597262634E30336A4949
725352501D1F530E0E7A3839641F25671019670B11712E317E61636D6A6F6E747A71777A
7C7B80827D818882838886848785828983818A817F8B807F8C7C7C8E7A7A917E7C92807B
9A878099877E9C897F9E8A819E8A83A18D839D897B998471978069A0886EA0876A9A8265
9C896C9B896D9D8B6E9D8D6F9E8F719B8E73A2977FA399809F957DA9A08C9F9785A49E8D
ABA496ACA69AABA79CA9A5999A96849B98839996829B98859796849C9C8EA2A297A2A097
A8A99FA5AAA3959E978B96918994938E9B9BB0B9B9B7BEBBBEC2BCBCBFB9BCBEBBBABCBE
BBBDBEBABDBCB8BEBCB8BEBDB6BCBCB6BABAB4B7B7B7B9B8B5B6B6B6B5B6BAB2B3C09EA6
A85F6F962536A2131FAB0C14B00A12A50B149734424C3B584D69818CA2A6969F9C9CA39F
9AA09C9197938B94908B92918D8F8F8D87889885859776778E585B893B4183222C83141F
890F178F0B15950B16980A13980A119506109207128F0714870B1A8017267F303F976B79
B8ADB9C0CAD5B7CBD7B2CBD6B1C7D2B1C7D5A3BECF4F7085799BAE5C7C8A6C8794637986
5E737B5C6F725A6D6C596D6B586F685169634E67614E66673A505B091E3024404C5E6D6D
219E1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004AB2187F654B6E5F595239375E403E
70585563413E4C19177E42455E11176306096A151682474A6A4A50736B706B74766C7576
7D7E82868285857F818782808A8381877F7E877E7C8A7F7D8679758979768C7A778E7D77
95847C96837C99867F99867F9D8981A08D819C887897816C99836B9C866E9F886F9E8A6F
9E8F739B8F739A8D72A090769D8D759C8E78A0957FA69E8A9F9785B1A89AA9A193A7A294
ABA69AB1AAA1ACA69DA6A4989796869998859A9887A09F8E9B9A8DA0A094B0AEA4A9A79E
A9ABA38990899CA59DB3BAB2B5BCB89FAAA8818E8CB8C2BEBCC1BBB9BBB6B8BBB9B8BCBB
B8BBBAB7BBB9B6BABAB5B9BAB7BBBBB3B7B6B4BAB6B4B7B4B4B6B3B6B4B5BEA5AA8F3F4A
A01C29AD121AB00B10B1090EAF070DA709129123336145653A537490A8B295A2A098A09D
969B9993969393918E978A8C9B7E81935C6285353A801B21870E168F0B1592061096040C
9B060C9E060E9F040D9E02099E04089B010698010899030D94020D8F04108907157B0F1F
7B3345A68B9DBCC3D0B7CCD6B4C9D4B6C8D68197A82F4A5F446274637F8A627A83768A91
5F7376677B7B5B6F6E586A6A576D69516A674D6666384F5A0C1F3701102D0B213852656A
25A52100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004DB4158163416C5C525A423C553531
6A5250624F4C5A403D714344550B0F6210128242437946495E353A7C6C6F6E71726E7776
787A7C848284817C7D8981808C8280887F7C887E7B8178748074718575738774738C7975
92817A92817A99857F98847E9A867D9A877A9885759A88719B886F97836AA08C739C8A70
A293799D91779F9178A4957EA1927BA2957FA39782A69F8CA39E8BA9A494A4A193A5A396
A9A398B3ACA2AEAA9FAFAEA19D9F909E9F90A09F92AFAFA29D9F93A4A69BA9AA9FAAABA1
B0B2AB818983B1BAB3B6B9B4BFC1BFB5BCBB7A8483B1BAB8B8BDB9B8BBB9B9BDBCB8BEBB
BAC0BCB7BEB9B7BCB9BDC0BFBEC1BFB7BBBAAFB6B3B0B6B3B2B7B2B1AFB0BD9CA08C2932
AC131DB70D13B4090FAF080DAB060BA909138D1423754C6D2B426487A3B098A4A59CA1A1
9A98989E8E90A17A7F934F5789262F89101A8F0C1491070F94040C98010D98010A9A0109
9B02079D02089D03089E030B9F020A9E02089A020997020A94010A92010B91020C8E0410
830917721D2E9E7D8BC4C7D1B9C9D3BBCBD87E909BA6BAC6788D97A7BEC681989EA3B8C0
6A80867E93955C6E6E5A6B6A586C6A536B6B37515A081D36010F30000C31011230314454
387B3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0083592F735A4A664B43532E29
6D4A495D4443644E4E6A46474E12135F20218A5A5D612D305923277D6365717171747877
77797A7B7C7E7D7B7C817C7A857E7B88807D847B788078748077727E736D8575708C7A76
8F7E7897867F97857F95837B97847A99867B9886799B8A789E8A7697816B9C89719C8C73
9F90789F9079A1927CA29680A59883A1957FA59984A59E8AA6A08DABA596AEAA9CA5A196
AEA99FB2ACA4A9A69BAFADA1A9A69CA5A398B1ADA3B0AEA4A9ABA0A1A69CB0B5ACC2C7C0
C7CDCBB5BEBCBBC3C1AEB4B2B1B6B4ABB4B37F8988B4BCBAB7BCBBB7BBBABABFBDB5BCBA
B6BFBDB5BFBDB3BCBBB3BAB8B6BCB9B6BABBB4B9B9AFB5B3AFB5B1B5B3B6C7A9AD8C2C34
AB131BB60912B50812AF0710AB050FA80913870E1A7B506D1C31557D99A9979FA1A99C9E
A48084934B5489202B900F1A93071098051095020C95030B9401099A030B9A030A9A0107
9A01079D020B9D020A9D00099D02089B010597010692010893020991000993010B94020C
8C020C8108136F1D2AA98A95C0C5CFB5C8D5859EAB92ACB88DA6B17D99A286A0A670888F
627A7E5F73755D706F5B6B6A576A6B4A626B0E243C011034010C32010B3202123610253D
464D4C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7210754B34735047522824
7644434C1B1B6848486851525F3E3E4D292A7E5B5F5F2B31551A1F826264757171767878
79797D79797D7878787F7D7B827C7C857D7B7F76747E75727D756F7B716A837570847571
8D7B77927F79937F7899857C96827A96837C99867C9885779F8B7B9E8A749A88719A8A73
9F8E769F8E779F907DA09482A29684A79887AB9F8DA69E8DA6A090A8A395ABA79AAAA69B
AFA99FABA69BA9A79BACA9A0AFADA6A5A59DB1AFA8ACACA2ABB0A6B5BDB4CAD4CFC9D2D1
C9D3D4CEDADACDD8D9B8C3C49CA7A7838E8D9AA4A1AEB6B3B6BBB9B5B9B8B6BBBBB2B9BB
B3BDBEB2BCBDB2BCBBB1BBB8B5BDBAB6BABCB1B5B6ADB3B1AEB4B2B5B4B6C7AFB3913B43
A6121BB3090FB20910B00911A909109E0D168119257B5975182C4F7E8B9FA28B929F5D65
91272F9A131C9B08129C050C9B03099A020B97010A930008930108970108980107980108
99010A9F030D9D02089F040A9D02089E03099C040998030B93020991010891010A92020B
8D000988020B7B07126D2330BAA5B1A5B4C229475C4266784869764A676F6A8387687C82
5E76795A6F705B6E6E5A6A6A586A6E2D4354021435000C35010C33010C32001036061B3B
414D5400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00419E08713B237F574E5F3231
77393C4D0C0D68383A65494D6551536455576F5C615F313754171D805A5E776E70727174
7475777676787777767A7A78827E7E7D78787871707B73717D74717D736F80736F82726D
8874718F7875947D779C857E94807896847C9D8A809A877B988778A08E7DA08F7C9C8C76
9F8E7AA4927FA39383A39686A59989A99C8CAA9E8EA69C8DA8A192A8A194ADA79BACA79B
A9A39AA9A59CA8A59DA7A69EAAA8A2A5A49EAFB0A8ADB2A9A9B3AAC9D4CEB6C0BDAFB7B6
AAB4B3B8C4C3CDD9DABDC8CC8E9A9B9EA6A5ADB4B0B0B7B3B4B8B7B6B7B9B3B6B7B1B9B8
B1BBBBB5BEBFB5BCBEB4BBBCB4BDBCB3B9B9B2B8B8AEB4B4B1B7B6B4B3B5C5B1B59D4F58
A41722B20B13AD0A0FA70E149611178E2C358A576A453F5F494C6C8B677C8D3441981521
A50C15A80610A3030B9E01089D02089B020B9701089601079501079903089B0309970107
9A02099D020A9E0207A004099D00079D010898010698020796020892000891020B8E010A
8D020989010982020B72081380475099949D6E84904A6A7792B0B87B949A92AAAE809498
839A9C5D7675576C6A59696953656D10233D011037000B36000C33010D32000E33021738
3A47570CCB0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00449E0571321880544C683935
611B1A580C0A773939511E22643F4368565B6B5C6263363C5313177F545975686B6F6E70
7272727474747675737575737A78787D78797E79767874707B73707A706E7E706E82706D
86726E8B746F947D779681799581789A887E99877E9E8C829B897C9D8A7CA493839E8D7C
A0907FA59585A59386A59689A5978AA5988BA89C8EA89C8DA9A08FAAA495A9A497A7A398
AEAAA0A9A59CA7A79EABABA3AFADA6AEABA4AEAEA4ADB0A6B5BDB6C4CEC9A7AEABAEB2AD
A8AEA9A9B4B0C8D7D6CDD9DBB4BFC0ABB3B1B2B6B4B5BAB9B6BAB8B3B5B4B4B8B7B4BBB9
AFB8B6B1BAB9B3BBBCB1B9BBB0B6B5B4B8B7B3B7B6B0B4B3B2B7B3B5B5B5C2B0B4A65F67
9F1822AA0E149E121590252D995C6A68566E3F3E5C6E5B79874A61871B2B9A0C17A60711
AC090EA9040AA8040BA4020B9D020A9B010999020998020B960109950108970109960107
9A01099E020AA1020B9F020C9D020C99010A95020993030890030A8E01088C01098A0109
89020A8600078301077C030C6B121A846267B1BAC095ACB789A2AB9AB0BA738C907E969A
657E805E76755A6E6D586A6B465665031334010E37010D37010D33001030061833041B36
2C3D4E1D9C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D407794023754B436E3C39
580F0C5B0E0D7D3538560D115416196D4F5168575B6A3D43521114794D4F76686B717073
6F70727272717473717474727C7A78807B797D7A75797871766F6C7A6F6E7E6E6C836F6D
856C6988706A907A7395817A97847D97847C98867B9A887C9F8C7EA39183A18F81A29182
A29283A39484A09283A19485A09485A29688A59989AA9E8FAA9F93A69E92A9A399A5A198
A8A49BAEAAA2A7A79DACACA2AFAFA7A9A9A0AEAEA5AEB0AAB5BBB6C5CECBAAAFADB0B3AF
AFB5B0AFB9B5CAD7D7C8D5D7B1BABCB0B8B6B3B9B7B1B7B5B6BABAB5B8B9B5B9BAB2B9B8
B0B9B8B2BCBBB2BBBBB0B9B9B4BABAB7BBBAB2B5B4AEB3B2ADB4B2B4B7B8BCB1B3AB757B
8C1F259220259D535F7D647F363D643A42697C607D802E439214249F0A16A4040EA9060D
A9060BA9060BA7050BA3040C9F03099B02099801069B020A980108960107960107950108
98030A98020B99050E94060E8C060F870A11810C127A0A0F77080E7D070E81060E83030A
85030886020883000982030C73070F74353F8A808A72869259727E637A8260787B688283
637D7E5C75735B706E596C6F314357031239000C38000D350317361C37493D59642C4654
1D333F1C9F1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774021774C456A3837
5C1D1B60212279353A55070B5D1D1F6A484B6B4E54662F34561013794F4F6F636568686A
6A6B6D6B6A6B6C6969706C6D7976777E7C7B7E7D787A787379736F79706D7C6E6B806D6A
816A6888706C8F797496817C947D7996827999857AA28F82A29181A79686A59485A49384
9F9183A39587A497879E9280A29685A69A8AA59C8CA79E90A59C90A69D93AAA199A8A098
B2ACA4ADAAA1ACA99FAEADA1B1B1A7ABABA2AFB0A9AFB1ABAFB4B0C8CFCDBCC2C1B4B9B5
B7BBB8C4CCCCCCD7DCBBC6CBA7AFB0B2B7B6AFB4B3B4BAB8B2B8B7B6BBBDB4B8BBB5BABB
B3BCBBAEB8B5B0BAB7B0B9B8B1BAB7B3BABAAFB6B4ACB4B3ABB5B4ACB4B4B3B2B2AB8F91
8550529E788545496E1F3568545886835473842136950D1DA20814A6070FA5040BA5040A
A7060BA9050CA40309A3040C9F030A9C020A9D040A9B010A9901089402079203098E060B
85090D83121A86222C8836448346557B4E606B4A5C694D5F6E4E6077485873313F701521
7C091284040D85020B83010B7C050D6A15206146517C8B965B727C778B93738B8C768E8F
6C84865C74735A706D586C70263A5002113B000E380314342945554460634B6261445B5F
1C323A25A92B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723A15794E45663937
61322E693E3D6B343751080B69262A76434A6B313A590E135D1B1B735252665F625F6162
6365666868696665666C6A6D7473767877777E7B787D78757A746F79716B7A6E687E6D68
816D6889746F907C7598847D99857E96827A9B877CA18F80A19081A59284A59283A49484
9E8E80A190829E90809E9381A19887A19989A69C8FA59C91A6A094A79E94AAA199AFA79E
B1ACA3AFACA3B3B0A6B0B0A5AFAFA5ADAFA4B3B5ACB3B7AFA6ABA6B0B7B4C3CDCCCAD3D3
CED4D6CBD2D5BCC6C9B0B8BAADB3B2B7BBB9B6BAB8B5BABAB0B8BAABB5B7ADB7B9AFB7B7
AEB8B4ACB7B3AFB9B7ADB6B5ADB6B5ADB6B5ADB8B4AAB5B1AAB6B2ABB5B4ABB2B1B0ADAD
B3ACAF797E9323376167628E884B698C192A9F0C18A40711A5040BA9050CA9050CA7030A
A8040BA6030BA3020AA1030CA0030D9B020A98030998020A92060E870B1182182085323D
7C475572546C5A4E6F363A631F2B5A1122540F24521126541427511C2A50333855685469
6D2D3F770E1C84051084010C7E030A6D0B15552E3A9AA4AF9EB5BE798E9599B1B5698184
6E86885D73725C7270596F721E364B01123C011537203E4F405F614A64605065604C6363
1F363C40484700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00713910775043663C3A
5E3431745752643D3B541214681A1F73242A640E135D0B0D6A34346A56575E5C5E5A5C5E
6061636767676A67676B686A7371747573757976758079768178767B706E7B6F6C7B6C67
7F6D6783706A907C7596827B98847D99857C9D897EA08D7FA18F80A08E7FA1917FA1927F
9C8C7A9E8E7E9B8D7C9F95839E97869E9788A29A8BA59C8EA79E91A89E93AEA59DACA69E
AFACA3AFAFA6AFAFA6AEAFA6ACADA4ABADA4AEB1AAAFB4ABA8ADA6A7ADA8A6AEABABB3B4
B3BABDAEB4B7ACB5B5AFB6B4B2B8B4B8BDBAB5B9B8B2B8BB8F999C89979A7E8B8C9AA6A5
ACB8B4AEB8B5AFB9B6ACB5B4AEB7B6B0B9B8AFB7B6A9B2B1A6B2AEA8B3AFAFB6B4AEB0B2
ADACB1A49FAD8D72898F3E57961425A30914A9080EA9060DA8050AAA070CA8050AA60308
A30207A5050AA2020AA1030A9C030A93020B8D070F84101A832D397A4559644C6B3B3B65
1B2B5E0E245C0A225C12286020356530436A6272908D9CB598A7BE9CAAC191A3B8758497
766B7D763A48740B1681030E7F0109720510602A395D5D6D889EAA627980677F81647D7D
5D77755F787559706D5872731F3A4C011538102A434562694A65614F68614F65614D6165
1E353F44505600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00773F13794E42704445
582A2C765857684B4B5D212360060B68070B5F0C0C682E2C6C50515D56585B5D5C5B5D5C
5E5E5E6865666B66676C6768716C6F706C6F7772737D74748077747F72718173717E6D6A
816E6888736C90797395817995837997857B96847A9B897D9F8E80A08F809D8E7C9D8F7C
A39583A09181998C7C9C907F9A9180A19A88A29A8BA59B8FA9A094AAA198ADA59EAAA6A0
ABABA3B0AFA9B3B0ABAFAFA7AAACA4A4A79FADB1AAAEB2ABA8ADA7A5ABA7A6ACA9AFB5B5
AAAFB1ACB2B1AFB4B3A7ACAAACB2B0AEB4B3B9BEBFAFB6B8869092AAB6B7A3AFAE84908F
AEB9B7AEB8B7AFB9B9ABB5B6ACB5B6ADB4B6ADB2B5A9AFB1A6B0ADA8B2B1ACB5B2B0B1B3
B7ABB1B48993903642A01522AC0A14AF070FAA040BAB060DAA070CAA050BA80308A50207
A4030AA4050EA2050E9D060C91090F81121B813442734C68433D671A285D0A235F0C2865
1833683C4D7764688882738B8362768557698753638A56658C5D6B8F6A7890828E9BA3AD
B6C0C8A08B947229347C091581020C78040F6C2635392E406A80895D7579667C7B68807D
5D76725F7572597270557073223D4C0118333550614F676A54686451686347605E3F575F
17314026394604C50700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783B0C78483A794C4D
5224267553536A4C4C642D2E5806075D0A0B652D2D6A4F505E5457545457555758595A5C
5B5A5D6362646867666C686670696C716B6F766E6F7B74707F7771847A7683757282716E
86726D907874917B7594807898847C97837C9B877D9A8A7D9A8C7C9B8E7D9C8F7C9D917E
9F94829D9181998E7C9C917F9E9382A2998AA69A8FA4988FA7A095A7A198ABA69FABA8A1
ACABA1AFACA5B1AFA7AFAFA5A8AA9FA7A9A0B0B2A9AFB1A9A6ABA6A4ABA8ABB2B0ADB2B0
ABAFADA7ABA8AFB3B1AEB4B1ADB6B2B1B6B6B6B7B9B9BCBD8B949594A0A08290908F9D9D
A9B7B5ABB7B5ACB7B7ADB7B8ADB7B9AEB6B8ADB6B6B2B8B8ABB2B1A7ADAFA9ADACB9AEB0
B9899096323DA1141DAF0D14B20A10B0080FAA050DA9040BAD080FAD060EA9050CA6030B
A5050F9F070F93080F85121A863947734E6938355F12245E0725640F2F682F4B77606E8D
7F758B855B6C7F36457D1B2983101E860B1B880C17880C19810B1778141F622931888289
B5C6CDBBBDC7855967720F1F80040F7A040F6A1D2D2F2236758E989BB5B76D8383889E9C
5F75725F75735A716F59707337515E0119304863724C63665467665265654F646B1E3547
031A39071C38068B1200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008846107847357C514E
4F201F774A49663C3B6C38394F13125B282764494B5E54565351564E505354565858595B
5C5B5E626164656566696769706B6D756C6E776F6E78726E7D7870867C77877876857370
86726F91797690787495807996837D95827B97857B9486789A8C7C9E8E7EA19181A49685
A194839B8E7D988B799E917FA39685A39687A4988BA69B90AAA298A9A39AADA9A0ADACA3
ABA9A0B0AFA5B3B4AAAEAFA6A8A8A0AEAFA7ABABA5AAAAA4ACADA9ACB0ACADB2AEABB1AD
AAAFABAAADAAAFB4B2A8B0ADAEB5B3B1B6B4B6B9B8B2B6B6B1B8B89CA6A69BA7A7A5B1B1
A9B5B5A9B5B5AAB5B5A9B3B4A7B3B3A8B2B3A8B3B3AAB4B5ACB3B5AAADB0B4AAAEB4838A
99313AA5131CAF0B12B30B10B1080DAD060EAA040EA9030DAA050CAB040CA50209A2050A
99080D8C11178A343E8057703F3D6812235F0622600B2C63294A72667A93807B89885D6A
7E2B3686111C8E081294061196030F97020D98030C97040F8D08137D1D2A7654658C9CB1
A3C5D7B9CBDA967F916714287C04127B04106E1F2E2E2033506C787E9C9F677F80677F7C
6178765D73715C7071596D6F48616A021C2F405D694965675066694B616922384D031638
01143E04193D024C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00627209774732825A56
55201F7B37375D1516682F2F6742435843465A50555250554D4C52515155525456535655
5C5C5D6261646362676766696F6A6C726C6D746E6D78736F7E787382787688797A847373
857070937A788F7773917D7892807B95848093857C94877A998B7C9C8B7DA49284A09282
9F9382A196839D927E9F9581A09984A59E8BABA190A89E91ACA598A7A397ACAAA0AAA7A1
ADAAA4B1B0A8B0B1AAA8AAA4A4A69FA1A29CA7A5A0A8A5A1A5A4A1A8AAA7ACAEABABAFA9
AAAFA9AAAFAAAFB4B3ABB3B1AAB4B0B1B8B7B3B7B8AFB3B4B1B8B8AAB3B3A5AFB0A6AFB1
ABB5B4A8B4B2A9B4B2A7B1B1AAB5B5AAB4B4A9B3B4A9B2B4A7ABAFB3A7ADBB8B93972E3C
A91521B30D15B2080FB20910AD060DAB040DAD0711A7010CAB060DAA060DA4070D940C11
86222A86506553496F1729620726651031683A5980617991737B8A88717D823F49861723
9409149B050F9C040B9A010A9A010A9B010B9A020A93050D7E131F7545601D26530B3464
5787A9B6CEE296859666192B7C061377030E6F2434291E373B596959787C627C7A667B79
6578776175745D7170576D6C566F72102939314D5E4D6976334C5D10254101123700103A
01113C04173E06152A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A1077A4B33825A56
5A1F1E610D0C600A0C602627624A4C564D515752565250544F4C51524E53555356555557
57585A5D5D616060646766686D6968756F6F76706F7A75717F7773817675857677867274
85726F8E77738D7470917B7693827B92837D94877F95887E9C8E819E8E809E8D7EA09182
A29585A39786A49786A19683A19A86A39E8AABA593ACA596ACA598A7A398A9A79CADA9A2
AFAAA4AFACA4B2B3AAA6A79FA1A49B999B929D9E959B9B95999B97A3A5A2B0B1ADA8ABA5
ABADA9ADAFADB3B6B6AFB6B6ADB6B5ABB4B4B2B7BAB5B8BAB5BABBAFB6B9ACB3B7ABB4B6
A9B5B4A6B3B1ADB6B8ACB2B6AFB6BAACB4B7ABB3B6A9ACB0B0A5ABB78992993541A5131F
B10C14B10910B50A11B0070FAC040CA80209AD080FAA050CA8070CA10B0F8E13188E3F4D
6A4E6D26336808296A0B316D345782647F9570808C808188886771792A3787101B970712
9D030B9D02099C01079B01079A010998020996020B830B148346582A2B53072D6043759F
9FC8E1B9CBDD927C8D6616267B061276030E6E2B3D1F1C3A5272885D7B8288A0A1657A79
6275745F73735F7374596E6F546C6E324C5A0E274118335204173E000F3C010E3A010D39
010F3A02163E04162C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DAE12825336805A56
602729570A07651F1D6A41435E4D50585056534E534F4C4F4B484B545053514E50555457
545558585A5E5B5D616462666C6869706C6C7471707B76737F787581767682737383706E
8974718C7672917B778E7A75907F7791837993847B96867B9A897F9E8C7FA18F81A39484
A29585A79A8AA69988A69A89A59D8AA7A08DABA393ADA499ABA398A8A399A8A59CADA9A2
AEA9A4B0ACA7AFAEA79A9B949A9D959193899294898D90868C8F8892958FA8AAA4A7A9A3
AAAEAAA7ACA9B2B8B4ADB5B2AFB7B5B1B6B8B3B5B9B5B7BAB3B7B9B4B9BCAFB4B9AAB3B5
ADB9B9A8B2B3A9B2B4AAB2B5A9B1B4AAB3B5ABB3B4B0ACAFB99299983B44A61822AF0C14
B00A0FB30A0FB4090FB0060EB1080EAF070CAD090CA8070C9A0B118D232D8D576D4B4671
112B67072C6B234B7D5D7D9B7B919E7F8E9284848986666E75243084091492060E980209
9B01079A03059902049C03089A020A9500098C070E862E3E4C395C07265A3568949DC9E4
B6D0E0B6BCCB8664726A101C7D060E6D040D6B36491519397B99B069838B6E8385647978
6277765F74725E72705A6F6D566C6C38505D01163501123E010F3F020E3E010E39010D37
010F3702163A0D203600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050AF0F82522E795851
623939511C196D433F644E4D5D51545A5358504E5349474B49484B4F4D4F575556535253
56575A56575B5B5B5F5F5E626666676D6C6B7773727972727D747280747383757386736F
89756F8B7671917E79917D7994817A93817995847B96857C9A897C9E8C7E9F8F809F9181
A09383A49787A49787A49887A69C8AA79E8DAFA696AEA499ADA49CAAA29AA8A39BABA6A1
A9A49FAFAAA5AEABA4999A928C8D858C8E838E91848D8F828B8E838E9086A0A199A5A6A1
A3A7A5A3AAA8AAB3B0AEB8B4A5AFADAFB6B6B0B5B7AFB3B5B3B7B8B3B8B9AEB5B9ADB8BA
ABB5B6A8B0B2ACB2B5AFB4B8B1B5B8AEB2B5B0AEB0BD9CA29D4751A01720AD0C13B10A11
B00910B00910B0070CB1060DB50A0FB2090EA80B0F961017903847755274242F660B2D6E
0F387441688E7594A881969E87959885898C90777E772C37810B168F030C920109970208
9701059A03089B02079A000895020A91030D7C0C17824F6B1421511947778DBDDAAFCFE1
BDCDDBA49CAA743948790B1781050E6A0C1858354E0916384B687B617A80647A78617A76
6079745E777359716D5C6F6D596D6C354857011337010D3F010D41010D40010D3B010E37
0110320A233C31475208C90800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B3107C4820795A51
6952505E49456857536158565F57595954564E494C4440444342454B4A4C555254535155
52515659595E5B5D615C5E616262636C69697873737B72737E7576807575827473877672
8A78728C79748F7C788F7C77907D77917E7795827B9A887F9B8A7D9D8D7E9F8F80A29585
A29585A69989A79A8AA69A89A39A88A59E8CACA595ACA499AFA69DA9A298A9A39CA9A59E
AAA7A1A9A6A3A8A7A29A9A938A8C81878A7D8A8D7F8B8C808B8C838D8D8595968FA5A8A3
A4ABA7A7B0AEA1ACA8AEB8B6A4ADAEADB2B5AEB2B5AFB3B6B4B8BBABB1B3A8AFB2AAB3B5
A6B0B2A5AEB0ABB1B4B0B3B8AFB2B5B3B0B5BDA4A9A659629E1B26AD0D17AF0910B30A11
B10710B20910AE060DAF050CB50C11AA0C0F971C22934D615D4E77152A68062C6C244D82
6184A37995A281999D8093958490938D8388753D467A0C188D030F94030D95040B97020A
95010899030997040992040C8C050D8108138231444B3A65092A616595BBB0D7E8B9D0DE
B6BCCB8E6D7F6C15257F061279050D7225343525430D2346557284718889657978627773
6178726076735B716E5A6F6A566C69435864021334030F3E000E3F010D3F010E3C001037
071F3933505F50676A15971600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B80491E775A4F
665B5A61595665605C5F5B5B5854555B55584F494C47424644424549484A55525657565B
5051554F5457565A5D5A5F606364656967687471727872747B71747E7374847777887976
8879748778728D7C768F7E77917F789380799481799A887E9C8B7F9D8D809B8D7F9D8F80
A29383A39484A29585A69A8AA59D8BAAA393ADA79AA9A498AEA89EAAA59CA8A39CA9A59E
A9A69FA7A6A0A7A8A29FA29A8A8D82898C7F888C7E898D7F8B8E828D8F848E9389989F96
A0A6A1A5AEACA3ACABABB6B6A8B1B3ABAFB4ADB1B6AFB4B8B2B7BBB1B6B9AAAEB1AAAFB2
A3ABADA4ADAFA7AEB1A9AEB2B0B1B6BAAAB0AB707996212CAA0F18B10910B20910B30811
B40911B0070EAD070BAD080EA80E1598232E935B753F3F710C2C6E0C35733B638C7191A5
7F979F84989C7E9392809291878E908C6D736E182286061192040E93010B91030A8E020A
8C050D85080F7E0F167B1B247D2C36733646745879122158255282A1CDE7B4D1DFB8C6D4
9F8F9F7630427E0C1980030E6D0811713D5412173A4261805F818B869DA0697D7E627673
6378726178725B74705A706E586E6E4E646F041634010E3B01103F00103E001239102A43
33525D4664665B6F6E17991800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008852227B6152
655D5A605C59625F5E605F615A575A5853554E474945404245414547464B504E54514F56
5254584F5455555A5A5C5E5E6162626968697370717C74757E75757E7473827574897978
8B79768B79748E7C75917E788F7C7696827C98867E99897E99897C9A8C7F998C7E9C8F7E
9C8F7EA295839F917FA09383A19989A59F90A9A396A4A195A9A69CAAA69FA5A39BA8A59D
A8A59CA9A9A0A8A9A29C9D968E90858A8C80878A7C888C7D898D7E888E808B9184929990
9AA39DA5AEACA7B1B2A3ADAEA4ADAFACB2B6ADB1B6B1B5B9B3B6BAB1B6BAA6ABAFA7ACB0
A1A9ACA7B0B2AAB1B4AAACB1B5ADB3BF919B922C38A8131DB00C12AF090FAE060DB2070F
B40911B0060EAD080FA10E16972C398A5A7C2B336E072A7118437F577D9F7E9BA7849B9E
8A9C9D8A9999899897859393939092743F487C0F1A8D040E8F020A8F030B87060C790A12
7D27337C445768496355496C4043692E39671A3066072C656993BAB6D2E6BAC7D5A092A4
814759790F1E8606107B060E7126343D2C4C061A4354749065838B62797B667A7B647676
6679766177725C75715A706F5A6F71566A730A1B3601113901143C071F3E274357435F68
4864664964615A6E6C1DA12000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00637C197D6252
655C5A5F5B586663626161615B5959524D4C4C464645404044424349474A525054525055
514F545353575556575C5C5C626161696768726D6E7972727C73727F7473837676837373
8471708E7A768F7B7594807995827B93817A96857E96887E97897E998B7D9B907E9B907C
978C789A8E7C9A8D7C9A8F7E9B9582A39D8BA59F90A4A092A5A397A2A298A7A59DAAA7A0
AAA9A0ABABA3ABAAA5ABAAA5989892888B7F888C7E878C7C898C7E8A8D808C8F858A9087
959D97A1AAA8A8B1B0AAB3B2AAB2B2ACB1B4AFB4B7B2B8BBB1B7BBABB2B8A7AFB3A7B0B2
A6AFB2A7AFB3ABAFB4B2ACB1C1A3AA98424DA31823B00C13B40C10B20A11AD060EB30A11
B20A0FAD0A109E0E169634437C587E212F6E09307628538B6E92AF87A1AA8C9FA18F9F9E
92A19E8C9B9A849493838F8E998D8F6D2831860B1791020D8D020985050D781A23744459
493F6519245B0C21610621640E316B2C4F814566956080A8ACC4E1B5BACC998395804354
76101E84061280060D711620623F590F1A44103056577687678184627A785E7472607573
6579776176745B726F5C716F596D6D566B7111263803173219364A3F5F6A4C696C4F6969
4E67654A64625C7170393F3C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0041A915806253
6B5E5E615B59625F5C6565635F5C5D554F514E4548484242474444474647515053575557
5150525353555555575C5B5C615F606A6766716C6B726C6B766D6D7D7274827477837575
82716F8F7C7A8F7C768F7C7593807A94827E92817B93867C96887C968878988C7B958978
938876938777938676988E7C96907C9A94809E97869E998AA09D919F9E93A4A49BA9A7A0
A7A59EABAAA4ABA9A5AAA6A3A5A29E92938B8E9085878A7D8B8F838C8F848E92888F958D
98A09A9CA6A2A5B1AEA3AEADA9B3B1ACB4B3AEB4B4ADB6B5A6B0B1A4AEB1A3AEB0A4AEAF
A4ADB0A9B1B5B0AEB2C2A9AFAA68729B202BAC0F17B20A10B70C10B30A11B10A11B0080D
AD0C1099101599424F6D557C172F6E0A34793361917598B088A1A88C9EA091A1A192A0A1
8E9E9D8D9D9C8396947E8D899186856D252B880A1494030E8D040D7C121C77475D1F2050
06215D1C3F7A2546840226625B82ADB4D2EDBDCFE6B8BED6A498AE8F61767A293B7F0E1C
85050F82060F73141D73455D1E214A0A26555C809D64828C99B1B4687C7D5E73745A7370
6177756377775F73715C716F546D6A546C6C314C513250574664684C6B6B4F6D694F6A66
4E68654966654761633D4A4A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048AF1B856858
6E606068616067635F6968645F5D5B524A4C4B4044493E424C4346474143504B4D575554
514F4F504E515553565857595C5A5A6661606F6968716C6B756D6D7B7170807474867979
8F7E7F927F7F917D7A907E7791817990817A93817B928079907F7491827595877A938678
958878928573948573968976928773958B779A92809993849794889C9990A1A097A8A59E
A9A7A1A6A5A1A8A7A4A9A6A5ACA8A5A29F9B9A999496989193968E999D969AA098959B95
9BA29E9CA7A2A2B1ADA3B2B2AAB7B6B0B9B9ABB0B4A7B0B2A4AFB0A3AEAFA0ACACA3AEAE
A0A9ABA7AAAEB3A0A8B8828C932C37AE1820B50E15B3090EB3090EAE080CAE080FAA0A0F
9A121795425363517B133072093679426C9A83A2B790A2AB91A1A48D9DA08F9FA28E9E9E
94A4A48B9A9B82929182908F97908E743339870C1594040E87040A872E3A3F274A071B52
0E31668EAFD2AEC7E54F68888FA2BFACAFC4A08DA29161777E2D42831627880A1588060F
7F060D75182276485D2A2853041C4F28496E9FBFCE7D959C788E91697C805E72725C7471
6177756379775E74715A726E556E6A576D6B5269684F68664D68664D6866506D694D6A67
4A686A33515C0E2A3A35474F0ACA0900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049B31C856B59
6F6462625B5A696561686660645F5E52494A483E404D42444E41444E42445246495A5154
534F50504D4E5553555958595D5B596762616F6769736D6C78716F7B707182757787787B
8F7D7F8F7B7C927D7B93817B93827C917F7B927F79907D758B7A6E9080728C7E6E8E8172
8D80708C7F6C91856F928771928771918671968A78968E7F918A7E9894899D9991A8A59F
A9A7A2A5A5A0A6A7A3A8A8A5ACABA9ACABA7A5A6A1A3A7A2969C969A9E999B9C979C9E9A
A5A9A7A5ADAAA5B0ADA1AEADA5B1B1AAB4B3A9B2B4A1AAACA1ABACA3AEAE95A29F9EAAA9
9FA7AAAFA9AFB788929336439F1923B00F15B20C13AF0A11AA060CA9080EA3090E940F15
96425363507C1330720A397F4A74A286A2B695A2AC9BA2A8999EA2959C9F95A0A1909D9E
8D9C9E8999998595948491928A8C8D8254597A10198F060F88050C83243155304E30355D
6A7A97A5A9BEADA6B98D7A8D8963778340548021378710248E08178D040E8A050D7B0A13
762632724D6B252858051D551638605A7A8D748B927284886A7E8065787A657876627672
6076725D75735C757257716D546F6A546D6A546A675168654F68634F6A6653716F49676C
2A4756051E3901173531455615971700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB71D80644A
6F635F665D5D6B67646A68656A6565574E51514548513E41492F324D3438534347564D52
5853574E4C4F5452555755565C5A586863626E6768776E6E7A706F7D71728576798B7B7D
8B79798E7A7A8F7C79907D79937F7C917B778F78748B746D8E796F8D7A6D857666867969
8D806E91846E91856E998D779588749488749188748D87748F8C7B918D819693899A9891
A3A39AA7A89FAAABA4A8A9A3AAABA6AEAEABABADABA2A7A49BA29D9AA09CA0A4A0A1A6A2
999F9CA4ADAAA0A9A7A3ACADA8B2B2AAB4B3A7B1B0A5B0B0A4AEAFA6B0B19FAAAA9EA9AA
9DA1A4B6A0A69649549A1E2AA81018B10C12AC080FAB0A12A80A11A20A0F9410168A3947
614E75102A6B0935784A75A18BA1B69A9EA7A69FA5AC9BA3A98E96AA8E96AB969C9F9799
9597988A94948896968693938A91939A828770222C830A1589040D840916882B3F834258
864D5E8542537F2E407A1A2E7E0D208808199107169506119208108309107A1A237D4357
54446915215904215C1739675D7C93788F9775888B7F8F926E8082667A79617572637673
6176736278765B737159726E546F69526B65536C66526A654E68654A67693D5B66153148
02193D00113A01153A294055169B1D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B81B7C5435
79665E645C5A6A66636D69686A6465594D51574246522D324312164B2024584045554C52
57555A4E4D525353555554555E5B5C68636570686B786D707A6B6E8373758B7B7C907D7D
8C7A788876748572708D7978927C798F77738D736E8B70698D736C8A73678A7668918170
91846E978974978974988974978975978B79938B78918C799A95858F8C7D8B897C929286
9D9F92A4A69AA7A8A1A6A7A1A9AAA5ABACA9AAABABA7AAA8A1A6A2A0A5A19EA4A1A0A6A4
A3A9A8A0A6A6A0A6A7A1A9ABA9B1B3A9B4B4A5B2B0A3B1AE9FADAAA7B4B1A6B1B0A6B0B0
AAA8A9A67C828C232DA4131CAF0F14B10B10AD090CAD0C11A60A0F980F129039446B5579
132E6B0D37774C71998D9AACA18E989F707C954F5B8B2E3D8B21318C20328C2C3B934A54
9B70769F90948D949686959594A0A1A9A7AB876067721E277F0A13890511880612830715
820915890C178A07128B05118B030F8B050E87080E810D137B1F277D4252634B68252959
081C58041E5E173A6C7EA2BF7D98A5A2B5BC798C9091A4A875888D697D7D697D7B627474
63777564787661777459726E566F6A536E69506B6850696A456068264156071E3E01133D
000F3D02103D01123B1E364F2A323400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058B91880512C
7B645A645C5B6C68686D6769675E5F5B484B5633374F191B460C0D471A1D5A4047564952
5754595455584F51535354565D5C5C66616370676A766B6E7C6F718377768E807F917F7E
8F7C798F7C788874718F7A778F79768D75708B736B886E678B6F678970658B7769907F6F
8D7E6B8F806C9C8D779F8E77A0907B998F7C96907D94907E918E7F908D808F8D808C8D7F
96968A9F9E95A4A49DAAABA6AAAAA6ABAAA8A8A8A6A6A7A5AAACAAA7A9A8A4A9A7A5ABAA
A4ACAEA0A8ABA0A8ACA1ABAEA6B0B2ABB6B5A2AEACA9B6B39BAAA79EACA9A2ACACA5AAAC
BEACAF9951589E1A22AC0C14B20C11B10A0FB20C10AD090FA00E13912E387D628119336F
103779586D9A9A8BA09257648A2A378D1421920D18980C189C0D199A0E19960B1793101C
8317249959629D8E928A9598839496828D918483868B6F7374383C74191F7A0C157E0813
7F0611850814840912810912790D18771D267A36407C50635B4C6B282D5D0D1C550B1C57
203163556289535F7B9BA6B78A939CA4ADB37C8B8F6E81856A7F81667B7C667B7C627676
6479776377755D7371596F6D56706C546E6D4E6C6E375461102A4401153B01103C031141
000E3F010D3D00113B1328452C373E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059B71587542C
80665D6A63636B696A6F696A6E5C5F5D393C551F23571C1D4A1B1B4C2F30524144554A4F
58545758575A51505552515659565968636473696E786D707C72718479788C7F7D907D7D
907C7B8F7B788F7A798F7A798D76748D757189716B886D66866B62876F628B7667877463
8C7A668F7F689A89739B897391816B958B769D97849592829290839192848F908395968B
93948B9C9B96A6A5A0AAAAA6ACAEACACACABABAAAAABACACADB0B1A8ADAFA5ACACA1AAAA
A2AAACA2AAAC9EA8AAA2ACAEA5AFB1AAB4B3A8B4B1ADB9B69CA8A59DA8A89EA7A9B2AFB3
BB949A922E36AC141BB60E14B40A10B4090FB40B10A90B1198252F966A8922336D1C3D83
5D62989263848A293D9513219D0E189908119609108E0B14840F1884161F89101B940D19
910B187E1622986C748A90957B9395819698A5B3B48C9194837F837561696844526B384C
6E354A713449733C4F71465A694E6753496A2F345D152153111F54252F624D4872654B6E
744A64763F5377384B76394877455084616985777A767C7C7484836C7E7D657877647776
657A766478765D73725A6E71546C714A6772254157051C4000123E010D40010D40020E42
010E41000F3E00133910284032434600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00936139
856B6371696B6E696A7164666C4B4E571C2058171A5524234D2F2D4C3D3C504544554B4C
584F535D555A58535757545759575A686367736B6E756B6C7C7371857C7A897D7D8C7A7A
907A7A8F7A79927B7C90777A8C7274876E6C866E69846C65836B60897262846E5C867360
8E7C678E7E6696886D8D7D648B7A60978A7399907D9A968894948891938691948995978E
99999192928B959691999D9BA4A9A7ACAEACA8A9A8ABACADA6AAACA5ACAEA7AFB1AEB4B7
ABB0B3A1A6A99DA5A7A1AAACA3ADAEA3AEACA3AFABA9B5B1A2AEAAA2AEABA5ADAEB8AEB2
B0747E9B1C28B20F17B50A10B80F15B20A0FAF0C139A141F995772393B711F397B5A5189
853E6392182FA10D1CA20A14990A108B1119872933874A5A76566D6B556D8B5C6F811F2D
8D0A15840C158244525B61716787937A959ABED1D49EADB178888F6C7B863B4B601F2C52
1A295A1B275A1A2A591222560A1D540A1E5710225934396866507575405C742238780F23
7E081B8207168206168006157A0814720F196D2229815A5C8D85847D86876A7A7C657777
677A78617574596E70566C753F586B162E4F011341010F43010C41020E41010D3F010E3F
02103F00133C0A233E334F5C43525500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0096663B
88716771696B6E6566765B5E612E315C1B1C551C1E5733344E3B3B4B40404A3F41554A4E
5A4F5660555D5D535A5E585C605A5F6C636873696C766B6D7F75768A80818A7E808B7C7C
8F7D7B8F7C788E7A768E78778A71727F67667E6964806A6282695D886E5D8C735F8D7863
8877608C7D6595886E94856998896DA0937A97907B99968792928593958A8D90868B8D86
8F8F898B8B868B8C86878B869BA09DA6ACABA9ADADACADAFA9ADAEABB3B2ADB6B7ABB3B5
A5ACAFA5ACAFA2AAACA3AEAFA3AFAEA7B2B0A8B2B0B0BAB8ACB6B4A9B3B2A7ACADC1ABB1
9A4854A51723B40C14B80D13B40B10B00C11A01019953E554A3B692B3D75796C9A853453
9B1528A20917A108149410197F212E76445D564D7427376B0F2A6310295B5148687D3143
890C17890B1482394E303254587B9574909A83969D7C8C9476899167808AA3BDCC5D7799
032558305887668CAF6D8CAF6A7EA4595C7F705673703049761529800A1B8705138D040F
8F020D8E010A8B010A8B010B87020A82010A7C060F6E12197D4A4E7D72746D7778687879
62757564797C5A727D2F4860091F49011448020F48010B45010C42010D3F010E3C01103D
001339122F4936576149646846565618971400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A17646
827164726A6C6D5B5C653E3D6029285F28285833354B373A493D3F4C42434B4044574A51
5C4F5660545B5E545B635961655A626F626974676C796D7085797B8C80818B7E7E8B7B7C
907F7E8E7C798E7B778C767388706F806A687C665E7C66597D6658876F618A73638A7864
8675618B7D699488739A8D78998B749C8F7A99917E9996859291858E8F8391938894968A
8F90868A8A8289887F8989818C8D879EA29DA9ACA8A9ACABACB0B0959D9CA6AEB1ADB5B8
AAB2B5A7AFB2A3ADAFA3ADADA4AEADADB7B8AAB3B5AAB2B4A3ACAE9EA7A8AFAFB3BD9AA2
8E2A37AB111EB40912B80D14B30B11AC101792263679587B3743738777A28835509D1322
AA0D189E0C178D1B2987485F574C78182E6A092A6E1038752F54826173938C7085791E2C
8F0B168A0B1681395128285235567772919E768F93A6B9BE94A9B52D4A5CAACADAACC8DC
3E5F7E678BA8B4CEE0A8AFC08C768A79384E7814278508178C04108D020F8D010D8E020B
90010B8E010A8B00088A020987010885020A83020A7D060F690E1782565C767574687779
61767C5067771D375502174501124801104901114A031046010D41020E3F00103D02193E
1A3B5140626A4868674A646447595916961400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A67744
8671627E6D6E67464663322E653430643F3D523B3B473B3C44393B4A3D414F404654474D
5A4E525E54595C535A60565E62595E6C6267766C707B70747F7478867A7E8C7D808F7C7E
8E7B7C8E7B7C8D7A79887472826C6B7D65637D645E7F665A7D6558846E62867164877566
8878668E7E6E9084719185719386739D917FA19787948E80908F83999B8E98988D97968C
96938A8E8B838A89808B8B818788818E90899B9D97A4A6A1A9ADABA9B0AFACB5B5ADB8B7
ACB6B7ADB5B7ABB3B5ACB5B7A8B1B3A9B1B4ACB4B7A9B2B4A5AFB1A6B0B2AEADB1AE828B
8E1F2BAC101AB50B14B40A13B20D159B121C9E5B71474066877499893650A01526A90C15
9C101791304171486E2E38720E347B0C3979335D8C6989A68091A39A88947E3944860E1C
920912830D188048641B2252476A8D8FAEBD546F78B1C9D0C0D5DF718A9983A0AF9DB8C7
768E9F6877888B8291835564751E2E8009188A030F92020E91010A8F000A91010B90000A
8E01098A00088A01098901088501078301087F00057F010974040C6D242A82707366767C
465F73122C5002174901114A010E4A01104C01114C010F47010E4002103F01153B1D3E52
3F676A496B684663614D666550626217991700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA23
8E6E5D8464655A29286E3A3575514D604948503D3E493A3C493A3E493A414D3F4653464D
574C535C535B5D545C62575F635A6067606377707272696C83797D83777B897C808D7D80
8B7A7D8C787A8D78788974728167667F625F7E615C7F635C80685D846D61836F61867365
88756893827396867591826D9C8D7B9C8F7F9E9384938C7F91908497978D9594889A988C
9C9B909091889091898C8D858A8B848689828F938DA2A5A0ACB0ABADB4B2AAB3B1ADB7B6
A9B5B4ADB8B9ADB6B8ABB3B6A7AFB1A9AFB2A9AFB4A8B1B4A2ACAF96A0A7A6A4ABA4717B
911926AD0F18B00911B40E15AB1018A0333D865A6E876684913C56A21727AF101A9E111D
8D35486A537B1D367409377D22528A6389A9809BAB8A98A09B8B918A4853871320950713
9107117D192A65446D0B20595A7EA6B5D3E47E97A17D959E90A7B0748B99536E857A96AB
9EADBD7D6D7C793C4B7A121F8506128A020B93030C93020A91020891010A91010A90010A
8F020B8C010A88010886000983010982010683010782010A7B040C630D156B505C42546E
09244F00174D00134D01114D010E48010F4901124B00124701114202143F0F2A443F6569
4A6E6B4B6A654863604B6762556A671CA11D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B91F
9166507E53535C2727764A476D55535A4B494C3C3B44353547383C4B3D4450434A52464C
584D545B515960565E635A61675D626A6063786F717F757982797C837A7C857A7B8A7C7E
87787B8E7C7E8C78788A73727F6462785D597C615C7F645E846960866F64867062897466
8B786A907D6F9B8A7A9685729C8C7B9B8E7D9B908197908295938697988B96978B9C9A91
9C9B929799908F92898D918892968E8B8E88898F89969C98A5ACA9A7B0ADACB5B3ACB5B6
AAB4B6ABB5B7ACB5B8ADB5B8A9B0B3AAAFB3A9B1B4A6AFB1A3ACAF939AA0B1A9B0945761
941620AF0E15B40C12B30F15A21517BD656AB67D89953F4FA11826AD0E16A2141D9C4258
6854811531750B3B7F3664967396AF8BA0A88F979CA28E968A475387142397081696040E
880E1985435E28275E06276540688D7895A57A9199748B9799AEB9B2C6D7223D5C314A6B
7B738A6F31427B0E1C88040D8A02088F020A93020B93010B90000991010B8E010A8A010A
87020984030984040C84030D84020B84000986010983010A7A020C61081A472A480A1746
01154E01145201135201125001124A0013441129521D375F01123F01153A2D4E5D4A6C6A
51706A526D6A4C65624F6864576B6922A72500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057B81C
9763467B4B455D2F2D765856695A5B574A49493B384737354838384B3C3F4F4044504147
5749515A4F565C5359605A5E655E616A60637C717481757883777C84797C83777987797A
87797A8877788B76768970707F6463755A56765D587B625C816960856F62887063877061
8C7668907D709987789D8E7C9E91809D90809B90829A938795938793938A95958E9B9A94
9B9B9593958D8B91878F968B8F948B8D918A858B858F9792A2ABA7A5AEACA9B2B4A8B0B4
ADB5BBACB6B8AAB4B5ACB6B7ACB6B7A9B2B5AAB3B6A7B3B4A3B0B1A5AFB2BAB0B69D5B66
9D1824B20F17B20C11AD1014A22325E68E92AB4F57A11B26AD1116A31419A2475765507C
1130740B3C7E4F7BA5819FB391A0A99B979EA4848C883C4A88122095061397050F8B0A15
88384C4E3E690A2462143A6D61869E89A2AABACDD65A76876D8B9DBFD6E67F8FA5675F76
692F42750C1984030D8A020A8D010790010990010992010A9001098F030C89030E7F0610
740B1270131A711B2372162175081283041085010B7E01097206134A09261A0F3D05134D
001252011355001254001650061F492847614A667D1A325100153E051A3B3F616D4B6C6A
53706B516C6947626249646552696B3E494700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0D
995D386E3C3171504B776765645A5B5448474C3C394A38374736364E3E3F5245464E4243
574B4D5A4E535F545960565B665C626D61687D6F7780717982757E84777D85767A87797A
8B7B7B8B787A89747686706E8168647A5E597C615A7B625A806A5E846D60886F63907869
8772638B786A8F7E6F968878998D7CA094849D93869692849394879C9C9398989095968E
9798919599928B948A98A3999BA39A8B908A8C928C8E97939CA6A3A3ABACA9B1B3A9B2B5
AAB4B6ACB6B8A9B4B4AAB4B4AAB4B6A4AFB1A6B1B3A6B2B3A6B4B5A5B0B1B6ADB2A3616C
9D1822B10B12B50E13AD1216B9353AD15F679F1A24AE1119A711199D39496E547C142F73
0D3E7F4E7AA38DA8B989929B9B8D959B6975862837921020970712950711890E1887384D
594470102764133A6F8BAECD6A889777939EBFD7E0A7C0CE657F8F9AABBA958A9A703645
750D1A82020C8700088900088E020A9001098D00088C020989040B7F08107717237C3B4A
724F63594A64453F5D4D3F59734052710C1B7E030E77020F5A072224083707104F001357
001354011553011A4F18385D395C6E4D6E783F5C6E04193B0720470A254040646D4E6D6C
53706C4664663A5761142F401F3B4944545900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
92572D744A3C745F5D736B6B635C5D534745503E3A49353240282A4E3A3B524445504647
5247495B4F5261545A60535A675A616E5F667E707781747B85787F83787D84777A897A7B
8B7A7B8B787A8B78798874737C6561755B55775C537A61557F685B886E638970638D7666
8B78698D7C6D8F7E6F96877A96897D988E8299918496938493938598988D97988E9A9C92
9396908C938D9CA7A3C5D2D0C9D3D2B6BCBB8D93908C948F99A29EAAB3B1A7B0B0AAB4B5
A9B6B7A7B6B6A8B5B6ABB5B6ACB6B7A9B3B5AAB5B7A9B4B5A9B4B5A4B0B1B5B2B4A56D72
9D1E24B71217B80E15B00D13C9303AB41F28B3121BB0151D9D2A39875E821D33730E3B82
47719F8CA0B39C969D9D7981893E498B1A26960D199B071693091481121E87465B514370
0E2568082F704D769DB6D5E796B0BB6F89957E99A1829DA5788F998B8C987F505E781220
8A07128B000A8801088800068D01099102088B04097B060C79222A7B49595C4867292D59
102054061B5208205210224B51415B691B2D78061564051B31072F0E0F4C021359011359
0216530721512A4B6752727C5573784D6A741A365001183B27436308233B4465704F6D6E
4F6C6B39556208203C00143803193441545E08C80800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8E572676544474635F726868675D5E574846533A374A2728441D224F313857414855474D
564A4F594D545D51596556606958627060687A6D747E727882777D82777C827478897A7D
8C7A7E8A757A8B76788872727E6664755A56775B527A5E5480655B896E65907A6D8A796A
8D7D6D9384749285759B8E7E978B7D968D8196918395938396968796978B95978D91968F
7B837D7D87839CA9A89DACAEC6D1D6C6CED3888F908A918D99A39EA5B0ADA4AEADA6B0AF
A6B2B1A4B0B0A8B3B4ABB5B7ABB5B7A7B1B3AAB5B7A5B2B3A3B1B39AA8A9B3B5B6B28488
952127B51218BA0D15BB0E18BA101ABB1019B81118A91F269852693836681D3875546696
968FA7A177859547548F202E96111E9B0D15980A13890C178126367D54733336690D2A6F
0732723D66907394A88098A27B939B768C9678949BB6CFD57C89958A748271202D870815
8E030C91020C8F020A8C01088F020A8F0209850C10873D4754405B1D2858091F5906225B
11316037577A728CA5717D8E7C65716313206E0819450424170B4104115901135D011756
102C58405D755371785975775D797D385366021A3D122B4C3C58720218343A586C4B6975
3853660B224300113C020F3C0112332F435312961700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
915C277E5D49634C48715F5F6A5D5E594546522B2C440C1049121750292D563C42524048
574751594D565F535D65586168596073636A7B6D757D6F7882747C83757B827276867678
8D7A7C8B73768A7174897070806763765957735753795E577D625B866D65927B70928072
8F817197877999897A998B7B968A7B9A91829790839390829A988A999A8F999D95858D87
737E7A9FA9A8CAD7D8A6B4B9B7C3CBBCC6CC848A8F7E84828C9591A2ABAAA3ABADA5ADAF
ABB4B4A7B1B0A7B3B4A7B1B3A7B2B4A8B4B6A4B2B3A3B1B29EACAE95A2A6AFB5B7C1A2A5
8D2C31AD141CBB1019B70A16B50912BA0F18B31118B4373FB172857457797F597C934F69
922E41981C2B9F131FA00C199D0C18920F19821E2B824960584C73172C6606296D16407B
4C74997795A68298A082939BB6C7D093A8B7446173BCD1E2A8A7B67842507F0F1B8E050E
91020B92010B91010A90010A90020B8F030A800911783449281F470A2056193C694C6F8D
6D8D9E738B957A838C88747C6D2F396D091565091F2C052F0B105003135F01145A143162
4B6B815773785672715A76774D6A760C254500183C2F4C63445E710115380B2148183356
051B42011141010D3E010C3B010F361C2F46189E2200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D662E855E495B39367259596D5A5B583D3F4512134C090B5012144E2326543D3E524348
55484F574B525D515A62555E6759607263697B6C747F6E7782717983727A807074857678
887678857273897273886F6F8166647B5F5C735652795C587E645E876F688470658E7C6F
9383749787789787789B8C7C9486789E9286958E81959283959486949688989D927A827A
78837F8A9695C2CFD1A8B6BCB2BFC5A9B3B98A9194848A88949A97A4A9AAA5AAADA7ACAF
AFB4B7A6AEB0AAB4B6ABB5B7A7B2B4A4B1B2A2B0B0A6B4B4A7B3B4A7B1B3ABB4B6BBACAE
974B50A11720B50F1AB90F1AB60D15B70F16AE0C13AF242FAA3F5089263E8C1C319B1828
A51420A80F1AA50A159F0D188B101D7E2A3A8A637F454474102A69052E711640756085A4
7694A295ACB192A6AC80919DC5D4E0A5BACB29455B93A4B79586946E2230890C1690020B
91010A93010B92020B8F030C8D010A8A020A86050F791B2C63405B35415E6784987B98A3
93ADB2859297887C8379454E6E0E1B7406155606221B0638050F5201125D0117532F4E6E
5B78805E76775D767459757C2A465D00183D0A26434563724A6572061939001340001242
000E40020E42000C3D000D3B010F3710233C1DA52A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A16A2F885C465C34317356566F595B593536480B0B570F0F4E0D0E4A2020553E3F514246
55484D584A5161535D6556606A5A6275626A78656D7D69717F6C747F6F777E6E72827475
847575847374877273876E6D816664785C577659547A5E598066618670698A766D907D71
928273918172908272928575978A7B988E819A938696928598978A999A8D9A9C927D837C
727C798994939EA9AC8592998D9A9F828C8F888E91898E8EA0A6A5A3A9AAA2A8ACA7ACB0
ABB0B3A8B1B3ABB6B7A9B4B5A8B3B5A7B2B3A4AFB0A8B3B4A8B2B4A9B3B5A7B2B4B1AFB1
AD7D818F2129A9111CB10D1AB30C14B50D13B00A11A80D17A0111EA31221A7111DAA1018
A80F15A2101896131E8A25358D4F66705A7E2E3A6E0E2D6C0B32712A52825F84A17F9CAB
829BA1BACDD2B0C4CB6D7F8CA5B6C2B5C8D5758B9C7D87988C6D7C6F131F89080F8F030A
8C01098B040B83060C800B137B081080050D87040D7C081575303F9F939FA0B0B88DA2A7
ABB6BC8B7E867D4A557116227B071373041549092A11084003105501165A0421524A6A7F
5C77795D75755A74774866760C2647011A4024455B4C6B73506C740D213D011341011043
020F43000C41010E3E010E39011036091D38323F4500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A902587553D60332E765653715655522221520A0A590E0E4E1212532D2C584241554647
594A4E5A4A4F6151596756606E5963775C6577555E704E5677606878686F7E6F73827374
8374748372728772738B72718469677D5F5A7C5E577F625D836B6686706A8B776F907D72
8F7F719082728C806F928674948A7A928B7D9A95889693869594879694899E9C958A8B86
6B706C737A7A6972757981848F98988289878B908D969997A7ACACA8B0AFA6AEAEA5ABAD
A7AEB1A8B1B2A8B4B4A8B4B4A9B4B5A9B2B5AAB2B6A6ADB1A6AFB29AA5A7A5B3B4A9B2B3
B6A8AAAE6D74921521B11521B40B14B80D14B40E13AE0E15AC111AA50E17A0111895141C
8E242C8F3E4F8754706858812D3A6F0D2F6C0A33702A53845D82A17794A5AAC1C9A1B6BC
7A9197A0B3BCB1C4CE889AA680939C8C9FA6A6B8C08083907C4C5C7B0F1D8A040B8A0309
83070C7B1B2480415171475D704359702937760C15830611730B148C545DC7B8C09C939E
8E6F7D74303F760F1C82051280030D6D081B360932090D4A011357001B54294C6C5C7B83
6078765F75794D6876153151011C44102F4D446771516F6F557073243B4E02163D011142
000D41020F41010F3D011036031939031B3339474E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
55B71B814C2F6A3D367B5B5872524F531F1B510D09541615582C2D513736524040534546
584A4E5D4D5464535B6B586071525B6B3A4465242F7036407D5B6274626878696E77676B
79686A8571738973748C7373856A687F625E7E605C7E615E81686489716A8C766C8D7A6F
9180729181728A7A6A928574928A79918A7C99948897948894918696948C99989195958F
92958F878B87949A969396948A8C8880827D858883979C99A2A7A6AAB0AFA8AEADA1A8A8
A9B1B2AAB3B4AAB4B4A8B4B4A8B3B4A8B0B4A7AEB3A8AFB2A5AEB197A3A5A6B4B6A4B2B3
ACAFB1BA9298942733AE1622B80F17B51014A71B1F9E303A933A479247577F435888607D
6E5D824346771D336D0C326E123E75345C8A5E83A389A8B99BB4BB889BA2A0B1B5A4B6BC
859B9F85999F8EA1A6A5B8C178919E9DB8C4B5CFD96B707F723C4E820F1F8B030C86050B
7E1C257348602326510A22531229505049606E3542730A147F0611750F1DA45B6A7E3949
7318297E081885040F80040D7108126A263C261541051351001752193D62537886627D80
60787D516A7D173252011A4508284B3E6173516F7357716F57706F4E6671061D3C00113F
021044020F4200123C06203C314F611931423A4B500BCB0A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59BA1C814D2D784D477452526949454B221B4D1D1758322C553E3B4E3D3D4E3F4153464A
584B525F4F5866525B6D51597448506A212C670C166D1F277F5459705B61716168726166
7664677D696D81696E856B6F896E6D8468657E615E7A605C82696488706A8B736A8B766A
8F7D6F907E718977699385768F8577928A7E98918696928896938B96958D96978F9D9F98
979C939AA097979B959395908C8E8882847E8D908C969D9BA0A9A9A2A9ABA5ACADA1AAAA
A7B0B1A9B2B2A9B2B2A7B1B1A6B0B3A9B2B6A8B3B5A5B0B1A6B2B3A5B0B2A5B2B4A8B6B8
ADB1B4B58B9292202BAE131CB40C12AA1217B352628363874F55823E507D253F6E17366E
10346D1940773157884E759B7195AE84A1AE869EA59CB1B5A4B7BB92A1A690A2A58B9DA1
93A8AB849B9EA3B6BBC3D7E33A576D55788EADCAD69198A6703F4E7F101C8D060F85050F
8831413D25470E23563E5F907E9DC19DAAC096788575232D7E050E84030F8109167E0614
83061284050F78070F6B141C6835463F2F500A13460215501333604A70865F8089627C88
446078122D54011A4808244A3E5E7255747A59737458726F57706E596F73374E6004193B
00133D01163F102B4936576447666A2C454E374B5016991600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2DDD0D7E472187554D62333474504C52342B53372F55403952433F4B40404D404353454B
5A4C54624E5867444F703C4767232B6F17206E0911650F157D4B506D555B726065726265
7B696C7A666A7C656A775D61876D6F8469687F63617C615E80656289706B8A736D88746A
8F7D738F7E718D7D6E91837595897E968C82978F869892899A978F99978F98999092948B
959A92989D97979C978C918B898C8684877F979D96949D99919B9B8C9697959E9F818B8D
97A1A2A1AAACA7AFB0A8B2B2A9B3B4A7B1B3A6B2B3A2B1B19CA9AA9AA6A7A5B0B2798689
95949AB8828B991C25B10F17B60C13A91420A75A78272F69134284406EA05177A06184AB
7697B681A0B78BA6B48BA4AD89A0A58CA0A38B9FA08EA1A48DA0A393A5A88A9D9FA4B9BC
C2D9DF6A848E839DA6AFC7D3728C9F607C91768D98959DA5825E687716208C081188030F
781120783E5A513E608F88A795849F87677B8449577C1C2881060E87020B88020A85040B
7B070D6C1019662C3B5038501F214606154801164F00164F1F3F6A4B6D8A4E6C852D496B
072353011B4F07254F395A6F5B777C5D76775B737356706D587270546B6B5A72773E5764
1C37482A4A5744646B4B696B4D6969334C522E444821A62300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008345177E403164292677504C5C443E55423B56453F5243404F404050414357494B
5E4F53694C5457232C6A21286C171E731A1E690F1461171C6F4349664D55705D626E5E60
7665667B67697C666A7A626582696C806769806666836766886B6A896D6B876F6A88746C
8A786F8A7A6E8C7F708F837496897D968B81978E859A948B99958D98968E999990999B92
979B95949A95969B98878C888589828C91898A938B7F8982808A867B86827B85847E888A
919A9E97A1A39FA9ABA6B1B2A6B1B3A6B1B3A2AEAFA2B1B1A3B3B3A3B1B2A6B1B398A2A5
AAA1A8A766709F1A24B60F18BA0E15AB101CAC536E393C7130609782ABC88DA6B492A6B0
96A9B093A7AC90A3A791A1A693A4A78FA1A48CA0A18DA2A39BAFAEBFD1D595A9AF94ABB0
B1C9D177929C7C99A07F999E93ACB77792A966829AC1D4E29B8F976E2A34810D1689050F
820410780B1B74192D711C33731A3075112577091880071182030A850208830409790E13
7E374467476026274A0918470218480C28522C4B720A244F011B480A245406205001194D
011C500E2D5641637957767C5E7778667B7C5E73735A727158716F57706E5A7374536D6F
4A686753706F59757254706C4F696930494F26404437443900FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4C16702E1764261D7F58535F4D475648425748434F3F3D513E405440425C4749
5F4648653F435F272C66212361191B6825286D34376B424565494F624B556551596B585B
7563647663647762647960647C63667F6568866C6E8369698A6E6E846A67846C668B756D
8B796F8B7B708F8375948777978A7B968D8097908598938C99958D999790969590989B95
919791949D979198948389837C817B828780777F7876817A77827A7A847F7B8280828A8D
869193929EA096A2A39DAAABA5B1B3A7B2B3A4B0B1A4B3B3A4B3B4A2B1B3A2AEB1A8AEB3
A999A0954B54A61721BA0E16BC0E14B20E189A283E705480274B7B7FA6BE96AEB49BAEB1
9AABAD97A8A997A7AB96A3A990A1A69AADB0A6BABB8FA4A694A8AAB4C7CC86999F889CA2
879CA298B0B68CA9B27B9BA5B8D7E636577A092F5C7EA1BCA2B1BA8A6F766F232C7D0E19
82060F8404108003108004127E04117E04127E06107C060E7B040B7F02097B060C863844
49324F0F194803184B1029562948665677886A8793455D70162E4C041C45061E48132C52
2E4B68506F8058787C5F7C7C617B7A657D7F6277795F74765A7273597072587072526C6B
49666256716E536D69526F6B4C6968223D442441463C4D4400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0099591E642307652A1F7E5753624E4B56484353443F513D3D543A3E5E3D435E393E
5E3639693C406533365B28296D404069424767494E654E555C4A525F4C56634F58665258
705C5F7461637661647C62677D62667E636685696C866A6A8A6E6E896F6C87706A917C75
907E758F81779084779487789A8D7D9991839792879A968E96948C9A98929E9E99969A94
898E898F97917C867E727D746D776F6E766F727C7676817C77817D747F7B757F7D7E8889
828E9086959592A1A195A4A4A5B1B2A4AFB1A7B2B3A5B0B195A2A4A2B0B2A4B0B3A6ADB1
B29FA7904048A9161EB90C12B90A10B50B129E101F9750722C35636E92B293AEB79EAFB3
9EADAF98A9AA97A6A996A4A997A6AC9EAFB3A4B7BB899BA292A5A98FA2A597A9AB92A2A9
90A4AAC2D9E36182983159739CBED557779510345B3D657E9BB7BDB4B8BC91777F763B46
6B1D286A0E1C6C0B17680914680D176816206A26307C3A44812D3776050E77070F7E3C4C
25183B0E194725335877869E778591636D73676D70676E715E6D724F636F50687557717C
5471765673735A78755B79765C7A75627C7B6077786074765E77775B73755A7174546E6D
4C6A6753706C4E6965526E6A4F6C6D122D352E4B50485A5000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007483155E21046C3730774E4F624A475A4B455845415A3D3E54282C5B252C612C33
65343B6C4045613A3F5E3D41654A4F654D56665059655159615159594951624F56634E54
6853586E585D755F63785F627D64657E6567866A6B8A6C6E8668698A6F6C856F6A8F7C75
8B7A7291817B91847B93867995897C9991839A948795928798958D9898919999938B8D86
777C747C817A737B736D796F727D74737E7678817A777E7B79817E78837F727F7A768381
7D88888592928D9C9C93A2A298A5A6A6B0B4A5AEB0A6AFB1A2ACAEA3B1B2A5B3B4ACB4B7
B4A2A8924149A9161FB80D15B80A10B70A0FB00F189A283E76567E3B537C95B1C599AAB0
9EADAE9AAAAD99A9ACADBCC19CAAAF93A2A694A4A790A1A790A4A790A3A7C2D5DBAEC2CE
88A1ADB4CEDC7B98AE3A5A767190A3819CAA8BACC0527A8DA8CAD2C2D4D9C0C6CFA69EAB
6D5E6E564359583F595A415D5743604D41613938583D3550723F517109147A060D8A3543
74455B62405967415364384761313C5D2B335E2E3362363A6A4B4E6C6062656B6B5D7170
58737058736F57746F5C77745B7773637D7B647D7C62797A607B79607A7C546D72476465
4665624868634E6C6753716E476169041E2D39575E4A5E560DCE0A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0049A80C5B2206703D36683A3B684844604B455D444161363758191D5F181E682930
643138542D346A4D555B464E5B4953624D5965505B64525A5F4E575A4952614D545F4A50
624C52664F546F565B745A5D775E5F8169688A71708D7072876B6C856E6B826F698B7A72
8D7B74927F7B93847B928579998E7F9890829D978A9C988D9A978C918F8882837B797D74
767E74737971737C73727D74727C7478817A767D767C837D78817D78827E77837D7A8683
7782827D89898998988D9D9D9AAAABA4B0B4A2ACB0A4AEB19AA4A79BA6AAA2AFB1A9B1B4
C3AFB68C3B45A4141DB80F16B90B13B90C11B70D14A211209E506D3F3B657893B297ACB9
9BACAE9DACAF98A7AA99A7AD9CAAAE97A6A890A2A2BACCD0ACC1C6899FA6B5CCD399B1BD
6E8797879EAB97ADB99BB4C66C8AA09BBACE82A7BE235168ADD3DFBDD5DDC1D4DEC0D1DE
B2C5D46D8399334A69172F550B234D091F4D0F224D413A5B64283C78081581030B7F0B16
740F1E6C09196D09166D07136C071269050E65050B63040C5F0A1258171E6743456C6666
5D6C6A576F6D5B74726078765F79755D7774607A79627C7C5D7A785B7779344E56224146
40605F44625E49686449676C1B354700163018334347605D1DA01900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DAD0F6025076B342B67322E6E4642694A455F3332591A1A5D10135F13185F2327
60363A6043495B474F5A49525F4D58624E59645058604E555A49525747515C4953604B53
5F4A50614B506951556F5559785E608166678A6E6E8D70708A6E6F87717084726C8B7A72
8C7B73917F7895837A9A8B7F988E7E99928495918599978B969387817D747E7D757D8079
727871727870727A74737D78717C77737F7A79847E76807A77817D77827F75807E768282
7682837B88887C8B8B85969696A5A79AA8AB9CA7ABA2ACAF9FABAE9DAAAEAAB5B9ACB3B7
BCAAB191444EA2141EB30C13B80D12BD1015BA0C13AE0B15961B2E88587B3E4D7290ABC2
99AEB59BAAAF98A7AA99A9ADA6B7B99BADB093A7A9BBD0D49AB1B689A0A58AA2A795AAB1
9EB6C089A1AEB0C8D588A5C0183D693F6A91618FAB5E899DB8D9E3C0D7E0BFD4DFBAD0DC
BBD1DCBAD1DEB2CADE9DB0CB757E9A625C78664D666E3449710D1C82051086010987030C
83020F7E010D7B010A7600087301087201076F01057002086E020868030C5B090E623135
6E6365616F705B71705E75765D767357726E5873715D77765B78765A7678344E56153039
426364466362415E651D364B01153301103101132D384F5523A82400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0054B4156B300C592012652F286F433F6C3F3D5C1C1B6111116614165C171B6C3E44
60454B5E495058474E57484F5D4B54614C535F49505A454D59444F5946515A49535D4953
604C51634F52634D4F6C545774595D84686C8A6E708F737488706E836F6D8875728D7B73
8B7A6E91807694847B988A82998D8397908498948899978A828074807B71827D787F7E78
757973797E796E7674566462566664516260586A686A7A79758281758081747F80758182
7782837A85867B898978888889989A99A8AA9AA9AB9CA9AB9DAAAC9BA9AD9BA8AFA0A9AF
B6A9B0954F589E1720AE0910B50A0FB6080CB80910B40910A60F1A96334B644D725E7699
92ADBE98A8B19BAAB09AAAB0B2C5CB9CB3BA8EA5A98DA6A992A9AD95A9AE8CA4A7B3C9D0
A6C4D46388A383A5BF7193B2052D5B14426C6790A7B3D3DFBDD4DFC1D7DFC1D5E0C0D3E0
B8C9D6A6ACBE8E869B785C726B384B661D2D6A0D1B79081782030F87010B87010789020C
85020C80010A7C010A7601087401087301097001056E00066F00076C000867020859090E
63383C6B6A6B5B6F6E57707058737055726E54716D55726F577471577472455D640B2330
3F6068324F580E243B011034000D32010F3101112D1A303A327C3500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002DDC0C71380A4D190463342C7F53505B222063171660110E651F1F5B282A64444A
59464E58474F58464E57474F5C4B525F4B526048516046525E45505B45505B46515E4A54
5D4A4F624F52634E506C555870585C80666A8A71748C757487726F87736F8B79758E7C74
8C7A7092837990827992857D90877D958E839A948A8D887E7F7C727F7E747D7C757B7C75
798179626E6959686660736F687A766677765267674D6264677979748281748280758283
7681837985877784857685857F8F9092A3A596A6A98F9DA197A5AA95A4AA96A6AB98A4A9
ADA6AB9B5F67991822B10D15B90C13B90A10B90B12B80C12AF0A119C10209A506C48466A
7A98B1B2CAD59FAFB593A4AB8B9FA6889FA590A7A98CA2A5B8CED2BED4DDA2BEC89CB8C4
7EA1B60C3656567B987292A77095AE5B89A38BB3C1BED8E1BFD2DDC1D4E1BECBDBACADC0
9482977C4F666923386D12257209177D051381020D83020D83010B89040D85020987010A
83000881010A7C010A7501087401097300097100067001077001076E00076B0206650307
530F136E5C5C5B6C6B54706E56747156737154726D54726D55736F53706C4C666D041D31
1C364F041934000E31010A31020B31010C2F010F2C0B1D2A414D4300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007E410F521E07683A317A49465917146C1E1A5B14106A37346345465B484E
55464D54454C56454D58464F58464F5D4A545B44505D434F5F46515F49535B46515E4A53
5F4B51614C52664F536F56596B5256785F638770728F76758D74728A73708C7974907F79
93817A96857D92847A91847A91887E958D84968D86857D7674736C6A6F676E756D797F79
6F797550625F677A776E7F7A707E786D7D795C7070475E625369696B7E7A6E7D7A727F7D
707E7E717F807280817989887B8B8A83949581929489999D8C9BA098A9AC92A3A796A5A9
A6A8ACAC7F868F1A24B0121CB90C16B90912B70B10B6090DB1080DAD0D1793172A8E5A77
515B7999B5C49DB2B890A2A78BA0A3B1C5C7BBCFD29CB1B6ACC3CA9AB6C45E7F907F9EAA
7C99A67795A982A3BA7E9DAFA9CFE42C5B768EB8CBBCD5E1BDCEDAACAFC1968399855168
7826397A11217B05137D040F7C000981010A83020980010981000983010985020A850108
8401088402097E01087801077401087401087301067201067101067001076C0105690105
59060A5C393D556064526E6E547370526F6C52706B52706B4F706C4E6C6F3D5867041838
000E34010D34010C3300093101092F010B2E010E2C0314243C484300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0081420D5A240B663329793D3B651D1A6E2922652F2C6B4949634E5356464F
54444D55454E55424C59454F5C485258454F563F4B58404A59424C5E47545B46525C4950
604D525F4B51634D546F565B73595C795F63846A6E8C73748E7372896E6E8F78778F7C78
907F7893817A96867E8F83788E857B91897F877F777A776F656762656E6A5B6561777E7C
5661625063646677786D7A7A6F7C796A79765F7372475D604F6566677B796F7D7B768080
747E807481827483837383827E8E8D829392778A8A91A2A392A2A499A9AC8C9DA094A3A7
9BA5A7BB9EA48B2732A71521B60C18B70811B60B10B6090DB60A0FB40A13A80F1B972A3F
835F795E6E8391ACB697ACB18B9FA3B9CCD1BBD0D7A7BDC58BA2AA8DA8B088A5B0849EA8
87A1ACB3CEE35B7EA4406A9477A5C534617EB2D1E7B0BCCE988DA0865C707A2A3E841526
8A0A168A050E87020A8102087E01097E00087F02087D01067F010784020A840109840107
83010582010780030979030A7303097003096F03076E01066E01056E00066A0105670004
5C050B512532343A45506C6E53716D54706B536F6A516F6D4C6C7329465B071E3F000E39
010A36010A34010A3100082F000A2D000E2E00122A0012223846460ECE0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008649105F2A0E571E156B27236A241F6C36306E4D4B6D585C56474C53454A
55454E50404953414B57454E5A4A515D4B5259444B574149533C4758404D57414C5C4950
5F4C51614D5365505770595F765E61795F63886E728D75748A72708D7473907A788E7C77
90817C93847E94857E92867F8C837A8A8177807B6F78786F5F6660626D69646E6A7A817E
4B56574F62646173756775786573765D6F70586C6E44585B556A686D7F7B75837F778381
6F7C7D6E7C7E738283738383748485778888788B8A8194948A9B9D8C9C9F8B9C9F94A4A6
9AA6A9B9ACB29A515B981A26AE0F1BB40912B80C12B70A0FB50B0EB3090FB00A13A61220
9A3C506A536DA8BED4B7D2DF96AAB299AAB28FA4AB899DA78AA0A896ADB4BDD9E59BBAD1
7D9EB984A4C8062B64042F694973989AB4C9A6A4B88C667E7D344C7B12268909198F0411
8E020C8C02098800088200087F01097E00097D02097D000681000887010A870209830309
7E040976070E6F0B14660F195E161F5D19235D161E600B1468050B6A0107690104660005
5C040C542737161C2E4D696F506D6A516D694F6B6A3F5C6916314C02163E010F3F010B3B
010936020934010A2F020C2F00102B0B263726454E0E252E2C3D3B21A11A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0064790B642E0E54190B6120176F38317855536C585964555755474A504447
53434953404856414B54424B56464E56454C5A474E59454D553F4857404B57404A5A464D
5E4B51604C526650556B5659776365786164866E718A71728B73728E76748D7672917F79
8A7C778F837F908580908580908680837C727E7C6E7B7E706C736A68706A737973777C78
495655485D5E596C6F5B6D7256696E53686D485E6241575A6073716F7E7872817C6F7E7C
69787B707F836A797D7887887A88887B8A8A84959581939480919393A1A595A4A795A4A6
9FADAFADAEB2AF818A83222DA31621B30B15B80B12B80B11B50A0FB30A10B20911AE0B16
9D142492445C685E7A778DA28FA4AE92A5AA9AADB3BFD3DCB1CAD694AFBCA3C5D91C4369
244D756F91B048668B4F689178829D90798B8644597D182E880B1E8B021191030F93030E
8F020B8D010A8A020C8400088100098001087F010880010883010889020A830209770C12
72222B733F4F684861544260453C5A3F3956463952674151590D16670308690204680205
58070E512D4209142C4B66714F6D6B4D6A68425F66061F3A021541000C4000093D010839
010736010835010C3001142C18353F305454375A5728424224373125A71F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0041A2056228064F1304602C2173534C705F5D685C5B615455574A4B524144
593D44512C364A283159424A57454D55444D5B48515A454D553F4858414B543F485B484F
5E4B50624D526954576C58597461627763647F676A876F708A73738D7775907B77917F7B
8D7F7B8B7E7B8E817E8F837E897E777E766C7E7B6D7D7E7176796E72766E7679717B8079
5E6A68435657475C60455D61425C60415C5F3E585A516768697A7973807D727F7E697879
6B7B7E7283876F7F838391938390927987898897988898988191928E9C9F99AAAC94A6A7
A0B0B1A7AEB2B7A0A99C5A66901C27AD0D17B50A10B50A11B30A11B40A11B40A12AD070F
A70A15911122944F64928695BDC8CFA3B4B79CB0B5B8D2DE6C8EA17B9CAF80A0B252728A
68859F839BABABB7C9A499AE89586C8025378B10208F041391020E8D000A8E010991020B
8E010B90020D8A010B88010A8402098101097D0209810209830106820208720811804454
513E5E1E25540A1E53051E54031E4E061F49102241544357510E1A630208670102640206
55162036273E081B374966734F6D6B4E696749626A021635021040010D42020B3E010839
010936000B31071E3623454E365A573D5F573E5D56354F4C1A2E2735792B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004AAA0C5D1F0051190962392E735D557269636B615E6358575D4D4E584045
5329304409115522295C3D4353404857454F5A464F564048513B4458424C55414959464C
604C536752586B575D705C5F7460637C656881696C8970738972718C75758E7879907D7C
9384818E807B8F847E9086808379727D746A80786E7B796D76776C7B7D747C7E767D817A
757D794F5E5E3E515440595A415E5D496362536A686275726D7B7A6E7A7773837F6D7D7B
6676776B7C7D6F7F82818F918290908392928B9A998695948796968B9C9C889B9C8C9FA0
9BADAEA2AEB1ADA8AFC09DA793414DA1161FB20C14B30A11B30A12B60B13B30A10AF0910
AE0B13A30814941826A45E69D7C4CBC9D2D58DA0A598B0BB5C7B8B7E9CAB819AA4BCD0D9
C3D1DBA6A4B28B6D7E833B4E8415278F061596041096010D94010C90010A8E010991040E
8E000B90010C8D030C89040D7E060C75080F891E257D07107E030B75050F76344646385F
06195402205E1536682F4F7544607C55677D605E6F5227375A071166010765030458090F
5432420F14330C26434767744F6C6C526B6A5068700C203B010F3C020E40010C3E000938
000F341730473559603A605D3A5E563E5F563F5E55354F4C172D28444B3800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052B2135A1C00511A0B6A40345E443C71635E6E63606658585F494B532C31
571A2251060D4E0F135F383F533E4755444D58454E58424B533C4457414958444A59454A
624D536A565B6D5B607563687761657B636783696D876D71876D6F8B7273897173907D7C
91837E90847C8E857D8D857D877F757E776D7F7A707C796F7A7B70797B717D80787E827B
7D837E737C79616E6D60716D5E726D61746F6878736C79746F7B766E7C778F9E98B6C3C1
B3C0C18F9D9E7B888A7D898B8695959EAFAE97A8A69BABA997A8A793A4A593A5A89BAEB0
8EA1A39CACAFA3ACAFADA6ACB0868D8D242BA90F19B10A10B80E15B40A12B10810AF0810
AA050BAB0712A50B18961B29AA6571BBA8B0949DA28EA1A7B7CFD8B4D0DF98B2C2A6B2C1
AC9FAF925F737F2336890D1E94071597030F98020D9A030D98040E92010A8C01098D010C
8B01098B040C810A107312177D303496495184242E77040F77060F6D1D2B593F610C1B53
04235F2D507D4D708864808C6B798073646D5C2A355A081367030B6802075B0709613039
27223B03153B23425D496973506C6C536B6C546C7313274002113A010F3C00113C0A1C42
0118333A5A6542666340625B4161593D5D543E5B55334D4C162B2A49554800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0056B6145E22015F29195B2A1F5B36307B6563736161684F4F653B3E561A1F
550C125304074E0C10633B4155404954434E5A485257434B543E445941485E474E584349
604C516F5C5E7461637865687B646A7C636782686C84686D856A6D8A6F71886D6F897372
8C7B778F847C8F887F8C877E807B717C796D7B7A6F79796F76776D787B707F827782847D
82837E7D807D7A7F7D777F7C707A75758078727C75757D79707C78899895C8D7D6C9D6D7
CAD5DAC6D2D87C8B8F7887897D8E8E8A9C9C9CACAE83949587999986969B81929884969C
8EA1A5899C9F9BA9ABA5ADAFAFA5A9A3646A9A1D27AE0F16B60D13B20911B0070FB10A11
AF090FAE070FAC0710A40B17931B28A05E68C0B1B69CA8AEADC3D246657F60728E927E95
89445A88182F940C1D95031095010C99030F95010A95010A95020D93020D8A010888040D
7F081072131E7A3C49724D5B906872752E3972081478050E6A111B69405B15194A031C55
4A6A9488A4BD718694727781755D6465252F6307116B020A6C010666010572262A5D3947
1315320D23424363734C6C6F506B6A516A69546C731E3348011434061E3C2544573E5C6D
09203238576044676246665F43625B405E57415E5A284245142F2E4556480FCE0900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00642A03602B1A521D125F332D7F6362765858632F30641E2057090E
590E124F0A0D521E1F5C3C3F53404852404B5A46505A454E57434B58424859434A5B464E
6551576F5C5F7362637966687E696D785F6282666A83686B84686B886D6F82676A856E6F
8976748E837D90877F9188818177707D766D7B797078786F72736B76786D797A6F838279
82817B80827D787D7A7C8381767D7B7C868077827B76817C6E7E79A0B3B1C5D8D9C8D8DE
C9D7DFC9D7E085959D788B8E8295957E9090899A9B8396968B9C9E808F94849499798D91
889C9F8FA0A49AA8AC9AA6AAA4ABAEBBA4A9893B439E181FAA0A11B10A11B0090FAF070D
B0080EB0090EB10910AE0911A50D168F1824A25F68B09EA77D879561687E81637D812D44
8F11249806179A031098020C97020D99030E95020C94020C92020C8D030C81071071131F
753B50624A6A332E5251406075384E740D1B7A060F6A0A15734258231F4D0418540F315E
92B2CAACBDCE88819272495964162470081475050C7200067201066F0308670A125E1B29
4F2F424E4F5D536A6E4F6B6A526E6A506968536B6E334B551E3B473C5D6548696C4D6A6E
152A382E4D594568684A696444635C415E5A405D5B122D30163332435A4B21A31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006E340A622D17511C105E3029835C5B723D40611619610F105A0E11
5114174F2223533335574244523F46513D465B464E58434C58444D543F485C474F5D4951
6351576F5F6472626579676A7D6A6D755F637C6466806669896F71866C6E806668826C6A
8977748678728E827C9286818275718276717C777177766F74756D74756C7A7B717C7D74
81837C7E847D78817C78827F767F7D78837E75817B75837C6F7F7997ABA8C4D8DAC5D8DE
C4D6DFB8CAD375888F7185888295957486858FA1A1839696889B9D8191978193977A8E91
7A8E919BADB199AAAEA0AEB49FABAF9EA1A5AD8E938529319C0F18AE0C13B10B0FB0080D
B30B11AE070DAE070FB10A12AD0911A30C178F1926A86571B8939D96606E842235920C1C
9C05109E040D9E040D9C030D96000A97020C94020C92040D890810750D19722D415E4467
2D316714245F4D4978683153750D228106136F071173384D352C570516531431677E9DBD
7683937E6A7D692F456B0F217604117C020B7601067501077402077202086D010766030C
56081253282D656061546764536D6A516A685068684D68684665634867634967644D696B
1D36431D3B4944676948676245655C43615C3E5B5A082225223F3F40574A23A71C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0083481359240A4E1B0E6C3D378250516824276915157125255C2525
5831334F33354D373C513E4654414B56414B58424D56424B543F495A454F59444E5E4953
604F566B5B617361677B696E7A686D7A676B7763647C656784696D866A6D836867856E69
86726D8A7B748F837D9187827C726E7D74707A757274746F75776F787A72787B72737A71
757E7677817978827C76807C757E7A757D7A737E79727F797B8A867B8B8AA5B7BCB4C7D0
A9BCC47B8F9674888C708485839596788A8B889A9B819496809498778B9081959A84989D
788D918A9EA299ABAF98AAAE8E9DA29EAAAF9A9A9C9B6F738820289E0B13AB0A10B00A11
B30C14B00811AD0710AD070FAD0910A20910921219AF4A55A547538A17269209179C0511
9E040B9C010A9D040D9A020D9B040F95020E8C050F7D0D177E32426C4766302D5D0C1E5F
0D2267433F7A6B3459760D2582061477071279324646325C0A1756031A59485C8789869E
6F4659691A2D72081B79030F7D010B7E020A7A010877000A7300077301086F0106690005
66040856060A5D36375F62605067644E67644D66634D67644A68634A6964466560496767
27424D152F3C44666747676046665C43635C41605C133130314F4D43594D36782A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063750B592405562315713B367231307321236715136A2C2A633B3C
56373A48292E543A41513E4751414C56444F56414D58434E56414B5A454E5B46505B4650
5E49526B575E705F6579676D7C686F79656B7B65687E63678B686D8D63677C5250896962
88716B8776708F847D9088807A746C7D76707A767073746C74766C767A70737A726E786F
707B7378827C78817C77817C747C77777E7977817D75848079888675848478898B788A8E
7A8C907083866C7E817385897B8C8E7B8B8E7B8D8F7F9296748B8D758D8E6E84887B9094
73878C7A8E928EA2A49DB0B08FA2A395A5A9879495AEA6A8925C628A1A25A00D16A9040E
B50B14B30913AD070FAD080FA80B129C1418C54E54AB343E97101D9C08149C030EA0050E
9C020B9C020C99030B9A040F9606108409167821316A3B5840376511205D031F63152C6D
565386672E527A0D248805147B0813752A3D5239620E1454081A5C363E72705B7B65283D
6F0F1E7905137D020D7E000A7F01097E01097F020A7B010A7400077301076F01066B0105
6901046303055011126558575367644E67654E6865506A664C67624B6662476561466363
35505614303845676645645D47665E44625C45615C3B58513B595141574B4A4C3A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0041A208551E02622C1D61211A72222074201E6C25236F3C3B623A3A
512728481B205B383E543E4554434C54434D56424D54404A57424B5E4952604A535F4952
6049516753597260667B676E7F69707E676C796065805961854C537B3237752F2F8F615C
8C7570897C77887F788D867D7C766D7B776D7B786F78786F797A7173796E6C766D6E7670
767D797A827E767F7B76807C737E79747E7977827B81908B7C89897987877B8B8A829391
7E8E8E71838474878976888B7685897A888B88979A788B8E7E92937F9494768C8D7B8E90
7A8E90768A8D7E949596AAAA899E9E90A3A48DA0A18E9B9BA3989A995B638D1721AD131C
B40C15B50B13AD090FA90C13A0191EC74F53A72B369B0D1AA70A16A5030E9F010A9F040C
9A000A99020B97060D8F0A15811B2A81455F4C3B6417245F06256719387842568C746991
7235508010248F06168206127625385B40680D14540B165B3B366B683F6265152B770818
8106117E020B80030C7E010A7F000A7E010B7E01097C020B7501077202086E00066B0105
69010466020552070C482F364A5B5E4C68674C67644C69654F6B664D676345625D456260
4662633E5D5D44656247655F46625D48635E49635B4660563B554C42584E48504000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0049A90E591F0663271B560D0674241E6D25217F4945704141582223
5115164E14174E2328573F4454434C55424D53404B53414857464A5F4B51614A52624952
60464F6852586F5B617D676E7F686D7C676A7D656881575E712C32882D317E29298C5552
8A716D857875897F798E847F7E766F79756C7A7A7174746D78797272786F6D786D6A726C
767C787A807C77807B76807B75817C76837B7A857D848F8B7883847986877E8E8D839392
7A898A7788886D81827487886C7C7F848F948793988494978E9FA08E9F9F7C8E8F748689
798C8F788C8F6F868892A8AA96ABACBDD0D296AAAC899C9E97A1A2B3A4A688444B951823
AB0E16B40D14A80A0EA1191FCD575EA92D37A00F1CA70813AD0A12AB060FA4030C9F020B
9C040D95050E860E1883344A6E5076282F670724630B316F5A7FB299ADD67561827B314A
840D1F9006138807147E263967486E141B5A131D5F4B3A6F6025466F0D217C031382010C
86020B81000982030B81030B7D010C7800087A01097D010B7A02087501087101056E0006
69000265010355050C3F212E2F3D4A4866684866634867624968634B686346656144635E
49666249676147655F47645E47635D48625C476158435D5435504A39524A43524300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB0116227065516094F080269251E804C457A4F4C683434571214
570F12541A1D502A2C553E4255434C57434E55414C54414958464A5E4B4F5D474F624650
60414C674A536F525B785B627E65697864677A656885626882434A761B207C24238F5652
8A6D6A847370847875877C79847B7579746C74726A73736B73746E70766E6A746B69716A
6E746F757B76767D78757E7A7E888475817B75807B8B97947A88877686867586867C8C8C
7E8F8E7083826C81806A7E7F72848684929789979C8B9C9F97A6A99AABAC7385897D8F93
7285887F9395798E918CA1A49DB2B4ACBFC49DB0B499ABAE97A7A7B7BFC1A69197994D58
9B1A23AD1319A6181AD3575FAF323DA3121EA80712AC070FB00A11AC050FA5020D9D030C
920911831A2779415C443D6C0F2968052D6D325E9191B5D9AFBEDB8F74927A29448D1023
9205108A09147C22356B4970171F5B1E28675D4977631D3B760A1B83041082000A840108
8601078601098401088002087D040D75040B73010876030B75040A75040B730108710107
6C010366020453060D3F21341A293B45656A4767644A69644968644A666548656246655F
47665F4A686146645D47655E45645C46635B466058435E563B5A5526453E435748209F16
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057B615692B034F10024F10076B332C83544E7C4A485418175E1919
5D2020572C2E593E41523F4556434D503D47513D4856424B5D484E614B5260464F623A47
5E2B386E3A4668343E602F37805C617B60667C63698162678752577728297426218A5750
866B66857570817671847B76827A7477716976726B7A776E75756E70746E6C726D6F756F
707570737975747976757A79838A8978817E76817E788683758583758685768686788585
7C8A8A788A89647877667B7C728689879A9D8D9FA2859A9C94A7AA93A4A97F929775898D
6C8183B2C6CA92A6AB7D929695A9AD8D9FA69AACB1A1B2B6A7B9BCCDDEE2C5CDD2BFA8AF
954A5297242AC74B50B8353DA7131FAB0913AE0810B20A11B20A11AF0912A80A11930A10
91323C6A4260272F66062A6D1A48816F99C0B0D1EAA8B1C68A697F812B428F0F20960711
88070E7D2334725076191F5D1F27676B507C691C3677061583020B85020A810007850108
8401068501088403087F030975040A68060D5F0A12611A2367262E6A1C2568070F6F0208
6D01046303065211192F1D330D213644666E4667664968634A69654C68654C666349655F
47665E47666047676144635E46646044615D46635C415F573F5E5714332E354C4122A51C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006D2D07501003541A10713A33783936753130642220612B27
5E3735573D3E544043503D4453404A53404A523F49533E495C46505D464E624049622836
560B176416216B1F295C1A218B585F6E424A6C444B815E657B51556E383685504B87625D
856B6882726D81756F847B75867D77776F6A79726D7C787174756D6F736D6E736E727772
6E756E727973757B77737875777D7A7C8582737F7C73817E738280788886728080839091
7987887484846D7F7E677B7B728688889B9D809396889CA08DA0A592A4A97F9298778B91
758A8E6E82896F838A7F949999ACB0A3B4BBC9DBE0CBDCE2ABBDC4B2C5CCB5C8CCA4ACB0
B99FA7AD636DB03742AF1824B40F1AAE050EB30B11AF080DAE090EA8080F9B0E12AB3D41
A062732B2B57082F6D3A699D9BC3E1BED5E9AAA9BE885E787E2338910D1D9A0813910B13
7E2230704D711C24601A27696A5080701D3980081785010C84010983000983010984010A
83010A80020A79050A6C0A0F641B24693C4A584056453B5A36314F6A4D60580D196E050D
6C010659040754293513122B0C263D40646C43646245645F4867614B67644D66634A655F
496860486860476962456560476562486662405E584262563D5C512E4C452C483B25AA21
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0077350C511203581F156729226C1F1C7226236B312D643E3B
5B4341534141503D41523F464F3C44533F48523E47563E4A5B404D63414D63323E601823
6B161F630C14651419530F1378454864353A5B2E34816165806466876868846765846866
8A716F88767182756E857B75897F797C726E7A716B7E7871797A72727770737A736E7470
6B726E747C76757B76757A7671787476807B707C7874807D79848473807F6E7C7C728281
7688867183817789886B7C7D697B7D7D90918598997A8C908FA1A690A2A78093987C9096
7F949971878C8EA2A7B0C2C799ACB1889BA2BFD4DBC1D5DCA9BBC2A3B5BCB4C6CACDD9DF
C2AEBAA35263A41827AF0A16B30811B60B13B40A10B0090BA90C0CA01718C64F51A1323B
81344A48426B4975A2A7D2EDBBD3E3A8A1B58C5972821E39910B1C9E0A15910A14842738
6E4B701B25631025686056886A1F3F83091B8A030E88010A83000982000981010881030C
7C060F6D0A1267202A6A4456493F5C1E264D091C4B07194D1F26536244605709196E030E
6903075F181D40283707122C1B394C3D616442645F4766604B68634C67664A68654A6863
49686248696148696247676146655E44645B4363594161543C5C5123443C315146317A2C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0084421155190661271C55110A6B1E186A28237148425C4540
53433F5044424E3F414E3C43503E46533F485840495E3B475F323E69354260202A5A0912
6C161E5E0E145E1B1F643334704D4E6C4F50634949725C5D7C6969806D6D806C6B836D6B
8B7572897671837770877E77887E7A857C777B726B78736977776E71756D6E746E6F7572
767C78767D78767D77767B76747A76747D79717B77737E7B727D7B6E7C7A6E7E7C6A7C7A
687A78697C7B7184847080826C7B7F80909382939595A5AA7C8E9385989C84979B7A8E91
72898B789193B0C5CBC3D8DFB5C9D08A9EA67B90989DB1B8BDCFD59FB0B7AFBEC6CAC7D3
AC77889D2639B3101FB80A15B70912B40911B30C12AA0C0F9F1819CF595BA52C3196101C
82192D674E7254779CB4D1EA9F96AB844A6282183092081B980713910C1682293C6A4D74
18276706236B4247816933567C0C218B02108C020C89010A8602098101097A030A6C060D
691F286F465B493E61141F4F061C52041E53152C5A3E436B5C405F5B162B6906136F010A
650105641A214E2C38191C2D37515943636146655F46635E4B6964486663476763496762
4766604968624C6C6649686348676046655C4564584161543C5C5128484216342C435241
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008E4F145C24095A201159180D70312876463D6E50485B4742
5443405043425245464D3E434E3D45553C485F37425D212D59121D67242D68232A61181D
6B292F6029305D323765494B6B585B6756586655577767677A69697F6D6D7E6B6C826E6F
8773718A787284777089807A8B827E89827B7F7A6F74706576746C767871767C75777D77
787C7A767A77767B76777C77777D7A798381767F7D707A776A77746979766B7B7A70807E
728381768888788A8B6E7E817584887B8A8E88989C7C8E9483949B7B8D92809395ABBEC0
B0C4C87F969C718A927E969F89A0A695A8AF9CB0B5C1D2D7CBDDE1C7D5DCA9ADB7BD9AAA
983549AC1426BC0E1ABC0B15B80A13B30A13A70D13A82327C852589F222AA3111BA00A14
881120764A68333D618C80A07E3C57851429950919970714860B1687384C574068112566
052E732E4B846E567C72132E8A05168D010D8C020B8A020984010879030C6A0E186D3648
4D3D5B172150051B55041E561D35624F5B7D6B62795A2E415E0F1E6C051172010C6F0108
69000660040A510B11502F34565A5948625C45635C44615C4867614766614A6964496862
47665E4B68634B69644A68634967624A666149655E4463583D5C523957511F3C32435343
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF003E9F02652D08541D095B231569392D7651486A4C455C433F
564342554344503F41503E43543B445429355314205E0F185A0D1264232869303559252A
6C4449603F4760444B6950586551585D4A526A595F79696C7C686B7D686B816D70856D71
8A74748A76748A7A76887D7A8A807D857F798480767C796F78766F767871777A73767B75
787B7A757878767A77787D7B747A79717A7A707B7B6F7B796B79777180806F7D7D788783
6D7C796A7D7D697C7E6B7E806D80827F92958B9EA1869A9F7E9196788A8F83969AA2B5BA
A3B6BD7D92987F949A8CA1A7B1C4C9C0D2D6A1B4B8ACBDC2C4D4DBBBC3CCB7A3AF934556
A0192AB00B18BA0B14BD0E15B80E16A80E15AD2D31CA545CA2232EA6101CAA0812A50812
870914A25C707C516B7D2F498A122796091696091186111C7E3B534D42710F2A6C0C3A7B
608CBC818AA860253C840C209003128E010D8C020B86020978050B6B18246A42572E2A51
081A50031D55153061526284766D826C4253621B2B67081671040C7401097200076F0108
6E01066D02076202054B07085C444151625846635B44625C4767604867604B6962496862
4867604B68634E69654D676549676548656347645F45635C415F543D5A522947403E5143
20A01500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047A808632E0556250E54251567372E5A29236638325C3A35
5842405544444F3C3D51363D4A2028531720591016560C1061242765383C6C484D69484D
64474E644A53654A546A515A59424C503B465F4F5775666A7B696D7C686B80696D876D72
8C74778F7B798B7B7A8C807F8C83808A847F827E798B8881797A7273756E72766F737871
757B77747977727975757E79757D7B717A7A717E7D707D7C6C79797682836E7B7A72817C
6F817C637776667A7C65797C6E8284798D8E839899819699A8BDC09AAEB38A9DA285999E
7C8F959FB2B7879AA083959CC0D2D9C6D8DEACBFC4A2B3B99FACB3B1ACB6A36C79951D2D
AE101CBA1019BA0D15B70E13A60E11AE2D31CD575DA4212DA60F1BB20D16AC070FA50710
8F0812B955637F1B2D8F0F1F980915940C15841A25844B6739366B0C2B720D3A7B6B98C4
ACC7E28672876F182A8A061792030F90020C8D040C7E061071222F6445601A1E4B041752
0A2158394B7267647D6F4B5E6B2130700B1A74031176020C7602097501087202086E0006
6C00066C01056601045704064F242451565143605942635C4567604968604C6A62496762
4968624C69664D68654D66644764614A676348676145635B425F533E5A530D2A252F433C
22A31B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004FAF0E5D260150210E602F2361231E52100B6E38325B3833
55413E534443523F40502F354E1E254F141A56181D5D282A66404465484F685057675156
634B52695059674F5966515959454F4C39445F4E5777676C7B6A6D7D6A6D836C6F876F72
8C77798A797A8A7E7E908785908A8786837E84827E8A898482827B787A7273766F70746E
757B76727A766E7A76717E7A768280707D7B6976726A7673737E7C727C7C707C7C71827E
718582677C7A627677677A7E75878B83969885999A8095967C9295788D917F94997D9598
A0B7BBC5D9DEB7C9D08FA1AA8EA1AA9FB2B99DAEB39EADB2A3AAB0A0838E852837A51320
B40E15B80C13B20D12A11012B0363AC9555DA31C29A70C1AB10B15B40A12AC070EA40510
920811BC4B578C1220960A178C0C168328397A5174292E6907276F19448382ABD2B8D6EC
AEB8C97F5A6E7C152690061492020C91030D83071179253562416113184A06164F1B295A
5C577B6542596422326E0D1D7A06137E030E7C010B7700097702097401087101076D0005
6A00056901046301025802064C19202B293145616040635F4666624665614B6A65496864
4967644967634A686449656148656049686246656044635C425F56415B5616302E324A42
23A81F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0055B5125F28005A28155F271F560E0B560A07723B355F413C
54423F4F4040533E40512C335B2A325B293062373D59383E5F454E614B54634F56665357
6853596B555E6B545E69535B5B47514735405C4C5576676D7C6B6E7E696C836C6F877174
8D7A7B88797A8477798A817F827D7A888581817F7B88888493948E85877F72746C73746F
7276736C77755D6E6F4F64665B6F71687A7968767276817B6F79746B7473627070687B7A
667B7A647A7865797A6A7E8461787F7F969B7A90918296967B8F908BA0A2B3C7C98DA3A8
92AAAFAFC4CC9AABB48798A17F9298A3B6BCC9DADEBFCACF968D94874856901624AB0E19
B71116B30F16A0161B9C3E44C87D868A1C2BA40E1EAB0612B20912B10710AC0610A70912
920A0FBF4C57881320821221793146644E7A192A6A062B712B548C98BFE2B8D7E9C1D5E3
ABB2C1815A6C7F172794071591010B88040D7A1A26744D671818451A1F52443964633E5D
641F346F0C1E7A05137D010E7E000B7D010A7901087501087301057301077101066E0106
6D01066901036401025802064F1E271413223652593F6160456561486663456560466662
47666346656049686249666147645F47665F47656045645E4362593F5B52345249284135
337B2C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDC0B692F02612C1752140B580C08560A066B362E60413A
594340523F3D52393B4D23284A161E5B2F385E42475741485E4A52614E55604D52675558
6653586B555F6E55616B545E68525B523F4963555D73656B7D6C6F826D6F876F71877172
8A76788676778376768077747E7976888481817E7B8D8C8890908C878A8477797172746E
7076745D6A6D3C5357365056385257576D6F6A7A77717C766C76726D7A766D7D7C637777
667B7B6D8181677A815B74814562707892987B918F839696849799A3B6BCC4D7DF9AADB6
80959E7B8F989CABB3AFBDC599AAB0A4B7BCCADBE0C3C6CF946F7D821E2E9D0E1BAB0C16
AF0F169F131E9742547358749476907C1B2FA40D1BAC0611AE070EB20811AB060FA50710
920E13B14E5776293A8253723935680D286C083274507AAAACD0EBBBD7E8BDD5E0C2D5E0
ADB6C4866877791B2B8E08168E030E7D040C95485550314E503D61663B5B651B346F0A1E
7B051481030F84020C82010C7F020B7C01097601057100047102047102066E02066D0206
6E01066B01046701035703074F26300A0D1F2F4D5740636145645F48676244655F476962
4666604866614967614A686048665D4C676047645E46645D4565583F5E4E3D5D4D375443
44503B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00763B095E250F511007550E085D1F166F453A62463B
583E375238345639383E1518542A30573A4157444A57484B5544495F4E555B4A51604F53
69555B6B545F6B52606B505E6E5460705B6470606775666C7A6A6E7D6A6D826B6E80686B
857074806F718477768B817E867F7C8883818C89868B8A878E8F8A8B8D8781857E72746F
7277764C5B5E385056324F55355055546A6C68777777807E6D76736D7A7968797A677A7B
65787965797D6079832A4B5C4D6D7C7E969C98ABACBACCCF8EA0A584969C8A9CA580919B
7B8C958B9DA4C9D9E0C9D6DFC5D5DD96A7AFA9B7C0AB9FAB8C4658961523A50B15AF0F18
9D131C9B455B64517F1B306B6E6692792036A20E1CA80610AA050CAE0710AA0710A30A12
8C151EA062746152761D2C6507286E1D49857CA6CEB2D4ECBBD6E4BED5E1BDD3DEC1D4DF
BBC7D28C7D896F2836830A198F081483061096364283364B6D1B30730A1C7E051382020D
83010C83010B83010981010B7C010A7801077302056C01056703066208086C1818660A0D
6902066B010565020552060C4A2B39070F252F4F5B40646342625D47666146645F476760
45655E4B686349675F48685D49695E48655E4A666046645D446457405F513D5D4D375545
43533E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0082460E571B0452110754170D6F40366A4B415E473A
543B324F3831573D3A422929543D4050414754474E564A4E54464A5C4B525D4C53614F58
6A555F6D56617057637055626E555F715D6466565D5F515773666A79696D80696E7F656A
80676C837072867A7981777486807C8984838B88868E8E8A8E8F8A8D8D898788837F817B
7278745A6768334B4E314F52415C5D6074736C7A796F79786D77776C7979677778697A7C
6D7F826378813A5A6A284C5D6F8D98768D91899DA1A6BABF788C917F939886999EBACAD0
B5C4CC8E9FA7B0C2CBBDCED7B4C6CE8FA0A8A4ABB3A584918C2737A10D1AAA0E169F141E
8C33485D4877122B7313327A796C9880253A9D0C19A3050FA6050EA80811A4070F970811
8828385E466A112C64072F6D456FA19FC4E5B7D7EABBD5E3BCD4E0BCD3E0BCD1DEC0D3E1
C2D1DCA7A7B17F5662700F1D85041089040E83050F84061583041186020E86010B86000A
83010A83000883010980020D7B010B7301086B04085D060C591A2060363A82565A5D131A
6603086B010661030456151E35223704142D33556044656543615C46625D43615A4A6863
4B68634D68634A666048675F44655B46655F46645F42605B43625A426057405C513D574B
4254410ECE0900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF008E4E135416004F10035F251A65362E603E355F463C
58413855423D5444424D3F404E414451434A54454D55474F58494F5D4C505F4E5468545D
6D535D6B4D58745863715A636E5A616B5A605D505652464D73676C7C6D71826B70785E63
6E55597E696C8677777F757288817D8883808C8A868686818989868F8E8C91918E898B86
787C756D76715667645367666C7F7E6976746F7C796D7978727C7E68757764737765777B
667B814B687A10365062849799B4BA748A8D778D91768D9289A0A381959A8CA0A6C6D9E0
C6D9E1899BA682949F93A5AFB5C9D0BAC9CFACABB2A87480931A28AA0E199A10188D3748
675078192C6C23377C605890905C7C891C2EA10E1AA50914A30610A40812A007108F0A15
8539512A275A0F397374A2CBB2D4EBBCD4E4BFD7E1BFD4E0BCD3DFBBD2DDBFD3DFC0D2E0
C1D2E0B2B9C6977E8C7C293784061389010C87010989010B88010B860009870008870109
84010982000981010A7D020C74030B64070D5E1A235933423C30452F293C603E4C590A16
6802076B03075A060A582D3B14112D0B223B40616A47646645626049636047625E4D6764
4E68644B64604B66614A676248665E44625D43625C42615B44625C45605C425A533E574B
4357421FA11500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006C7A0F55170055190A5B1F13581C1466332C57322A
5C413C55433F4C413F493E3F4D3F4454434C56454E5746505B49525F4C5265505570525A
73475056262F79545C725B606F5D626E5E6465575D52454D6D61667C6D717E676C755B5F
6A515476616483747689807E87817E827E7A87848083847D8586818E8D8B999A988C8F8D
828682727773767E7A7D8683747E797B82807A8483737E7F707C7E67757760717364767B
5D76841B3F5C1943605F818E6F8A8C768D8F788F927C9295C2D6DAB6C8CF7B8F988FA6AE
8EA4AB8497A07789958C9EAAC6DAE2CAD8DEB6ADB69954619F1A28A9131E972B357E576E
333762605C8D7A4F79742341A33A4D981724A30D17A60B16A60C179C050F9A0812870F1C
7A42601621582B5889ADD7EEBAD5E0C2D6DFC0D4DCC2D5DDBED2DDBFD2DEBED2DDBED1DC
C3D4E09CA0AE7855677417288706148A020D86010986010A850109860107830006830107
82010880030B78050C69070F621A23663D4D4436501B2040202444533C56541224670510
6B02066105085B202A37263F0411321C3B5240656A47656445625F49656347635F4D6965
4965614966614A68624866614A686047655D46645D44625D46635E47615D445D553C584B
3C543F22A71A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A2095418005923125A1B105C140C65251E4E211A
61433D53413E4D403F4E40415242475A484F56444C5B4852634B56684B5369434B713F47
69262F6A262D815258765B616F5D626F5F656C5C6262535966575C7B696E735B60705459
674D507460627F7072817776837D7A817C7A807C787E7C767A7A758383807C7C7C6A6E70
686E6E6A716E777F7999A09EB1BAB9B2BCBB98A2A3727F81707F806D7E7D6D8180637880
3E5B76072C534A708B6A888F6E868593A7A77D91947D9295AFC3C8A1B1B9788A93798C93
B3C6CCC7D9DFA8BAC3798D97A5BBC3B6C6CCBBB0B98B404DA11925A20F1AB84C5AA3667D
8D58748A37518E192C92101EBF424E9A131F9F0914A007149C05119B0712940A147E1829
64456A0A255D527FA7B6DAEABDD5DCC0D4DCC0D4DCC1D5DCBFD2DBC0D2DDBED1DCBFD2DC
C1D3DBA3A7B379526176132487051386010B8401098401098401098500088201097E0209
7A040D6F0912691E296B3F51483B571A21470D1944302F5452344D550E216805116C0208
6004075A1C22452F430B103503193B3357684166674767634A68644A6965466560486862
47666149686249696348686148676048675F43625A47655E43615A44625B405F533A5A4A
3D5843337A2700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BAA10581F015C281650130859160D6A3128633C33
5D423C543F3C51404055434756454B5A474D5C464F624650663E49622D37672B347C3840
76242C7B2C33845057785C6374636A7263686D5F636B5E626E60666E5D62735D62694F53
6F55597762657D6E6E7B716F7E757379716F7F797578746E76766F7F807A8485827E8181
7C8482616C67A9B4B1C7D2D4C1CDD3B9C7CCC5D3D7A7B4B86C7B7E697A7A687C7F5A7585
103257133A605C7D906B83877C9191C5DADA9FB1B5778A90768A9097A9AFA9B9BF82939A
B3C5CDC6DAE3A8BDC68EA4AE839CA394A8AEBAB3BB9655619A1B27AA121EA41A279C2332
9519289E18249C151D931C23C7546097111F9E09169D0814990511980712870914833950
37305F072B6385B0D1B8D7E3BFD5DDBFD4DEBDD3DBBED4DBBED3DBC0D3DCBFD2DABED0DA
BDD0D8A7B0BD7D61706D142484051488030F84020B84010A86020A83010B7E040D710811
6918276C3E515142611D234E0818481C26534C3F62582840600D1D6B040F6D030A5E0509
5920274A35490C143502163C1E3E5545686F4768654967624B6A6448676345666045655F
47686249686347676248686247666048676141615A44615B46645C426157405F513F5C4D
3D5544434C3500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0054B415602704511D0A4E160A5D291E6941375E4239
5C453E55423C53424157444958464C5C454B623F47602F39672D3768252E76343B813D42
711F26792A32854F57795D65715E677162687063676D60657063686E5E627A666B7D676B
70595E776366807170796E6C786E6C746B69736C6873726A77796E8A8C82878983888C88
868D89939F9AC6D1D3B8C1CB7C889174818A819095C6D4D87F8B906F7C8060737E294564
0327533055758EA9B47A8E92788D91859B9E72868A71848A778B90BFD3D7C8D9DFA6B8C1
798E9A7A919B88A0A89AB1B990A7ADB5C7CEC0C5CCAE8D94852A349B1720A5171FA01822
90141E8B252F964B55BB7B859D435191101F96071293050F91040D940B147C11207D5274
14235C1A4377A7D0E8BAD4DFC1D5DDBED5DEBBD3DCBED6DFBED4DEBED3DDBDD3DABCD2DA
BDD0D9AEBBC875647466182A81091785010E83020D83010C7F030C7406106A16216C394C
523F611F2654061C4F041E502B39634E395755142868091672040E6D040C5C09105A2935
40334C0B133A01173F1939543F646C4A6A684A68634C68644A6964476761466862466661
4667614B69644B69644A686348676244645F41615B46645E45635C436158446156405C4F
3F584747533D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059B8156C30064911024E1C0E67403262453A5C443B
5D473F56443D5745455A474B5E464C643D445E222A5F151E732B3465222A74353C7F4247
6C292F6C2F3480575D765E666F5F677060696B5E626E62656D606574666A79696C7B686B
7D686B7E6A6C7B6B6C796C6C736967716865726D677A7971777A72848880848983878C88
89938FB4BFBEC8D2D8858E987A838A798386667476B9C7CC818D9564727D465C73082551
0B2F5A51738BA1B9C184969C74888D7B9193A6BBBDB3C5C97B8E9599AEB5ADC1CA8399A2
748A948499A2C4D9DFC5D9DFB5C9D29AB1BDACC3CFA4AAB1B39498915056934853955568
855B776C5F833F42668A728F7722388C0C1A8F071088030C8C060D8A0C187D2F46463C6C
0728655984AEB5D9EAC0D6E0C3D6DEC2D6E0BED5DEBED3DEBCD2DDBBD1DCBED3DCBDD3DB
BAD1D8BACAD57368775E1C2D7708167E020D7A040D7408116C1823713C50554160232955
091D54031E552E4F7A7C9BBA70778E4F21356208156F050D67080E5C17205C38492E2849
071643011B451B3D5A4165714767684B68654966614A66624A6963496A644A6A644A6965
4968654A676446656046666043655F45666141645E40625B42635B4361584260553D5C4F
3E5A4943523A0FCF0800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00733408491503572D1B654634644C3D5E473B
5E48415C45425B434461424764384065273161111B620D15752A306423296B31387C4A50
754C5279585D77606577676D6E5F6770606972646970646870646872676B786A6E806E72
7965687B6668826F707C6F6E726965746D6878736D7D7A767D7E7A8488838A8F8A878E8D
7B8788B3C0C4C4D0D7727E84737D7E6F7A76697875BBC9CC67777F566A7C1A375C082F61
1F466B54758361787D687A807183876C8185BDD3D7C3D7DD8B9EA583979F7F929AA5B9BF
9AAEB48A9EA5C3D6DEC6D8E2AAC1CC7494A83E657CAECBD8C0CBD0A9A6B270749238487F
1839780E39783A52867E597C7E172C8E0A15900A128A050C8C09117B142360365C132460
0F3B719AC3DFBAD7E3C1D6E0C2D6DEC2D5DFC0D4DDC0D4DEBCD3DABDD3DABFD3DCBDD3DC
BBD2DABFCEDA7F77855E25366B0B176C071161111E683448584362282C5B081D5604225A
2D4E7D5070937E9EB593AFBC777E8B552D3A570C1559121B653847493A56161E47041747
05224E204760456D764A6A6C4F6B6A526C684B69634B68634B69644B69644968624C6A66
4A696549676347676245686245686245676142645D3F615A42635B426359426256415F54
425E4E47564121A11400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF007B400E4D1F075D3B25624732614B385C4639
5F46406044435E3A3D67373D5E1F276D20276A151C641118753538703F42744A5176555D
735B62715E6371616676696E72636A72626873636874636870626574666A7A6B6F826C71
85686D8764687C5B5D806C69746B64756F6878746F7F7D7A8888848C8E898A8D8A6B7474
727F81A3B2B6C5D5D9839495707F7D6D7A7795A3A2A0B1B5586C793A53700321540D3366
3D658058757E6E8488AFC2C6BECFD5758991788D9683979F8799A07E8F9696A9AFC5DADF
C4D7DF8B9FA78DA1AA93A7B0A1B6BF93B0BF65899DB8D6E8C4DAE7ADC4DA3B5D8F053282
1247945E8ABD9995B682374D8D10219108139911188F0911850F1B854259302B5C072966
5886AEB3D7E9BED6E2C1D5DFC1D5DEC1D5DDC2D6DEBED5DDBCD3DABFD6DDBED3DDBBD0DB
BED3DEC1D0DD85859354303F551A255E2E3E493552222652071A53021F5A0C3063355A80
7EA2B8698998627E8A829CA487959B564A53563B4652415622274D051A49011B4B0E2D54
3B5F74456C724B716F4B6A684D6A674C69644B69634D69644F6B674C69654968624F6D69
4C6A664B6A65496A6345676145665F46655E45655D46655F43645D3F6158436259425D55
445F5346594923A51A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00824811582F0F5C3E275F4731604B385E4639
66473F693F3F572023652229671B2372232969191D5C171A6B3C3E68494D735A62715A63
6E5C6471616A74656A76656B7D6B726F5D64725E6576626874616877636982676D845C63
8249516E2F357946497F6462786D677F7A747F7D7981807C8586808C8E888D928D898F8D
8E98998B989BB7C7CCB9CCCFA0B1B2ABBBBCA4B3B7687983556D81142E5A011957153663
5C7C8C657F83667E82A5BABFA9BBC2687B82667A808FA3A8C4D6DAB4C4CB7C919AA3BDC5
A1B7BF8B9FA772878FA6BDC3C7DCE1C6D9E2ACC6D891B4D283A9CB94B7D8254C7F03317D
1B4D8D96ACCD9564798D1B2B9F111E970A14940A148A101C7A293D553E660C245D1E4979
A3CBE3BAD6E0C2D6DEC1D4DFC1D5DFC3D6DFC0D3DCC0D4DDBCD2DABED3DCBDD3DDBCD0DC
BCD0DBC2D3E08F99A665616C685F6A343755071A4C011D58072C5F264E72466F8851788A
6C909B98B8C256747F9EBCC4A1B9BF67757D7D8997142844021C480A29542B4D6B4C6F80
5272785070704D6C6A4F6D6C4F6D6C4A68674A68654F69674F69664D6A664C6B654F6C6A
4F6C694C6B664C6B6547676147676148676246645F46645F43625C426058426058445F57
405D52475F5023A91F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008B54145B320D5A3D255B46325E4A385F4337
643A33652829681D2164151A61141B662024652B2C6A3F41684C5065515769575F6E5D66
6E5E686E5F6874646A77656B78656D78646D746067785F677D5C65785157824E54773239
80292F822E307D41418468647A6E697E77747E7B7781817D8688828B8E88898F8A8D928F
8F96958F989B889298919BA397A2A9818D936A787E5E6F7B3C5271031B540018582C4D73
98B6C29BB2B75F777D5A73786B808584989B6D82859CB2B6C5D9E0B9CBD5748994748F96
A4BCC2BFD3D9A0B6BC9AB1B8BED4DBC0D3DF97B1CB224C7F0F457F8BB8DE8CB0D042638F
738DB2A892AB8A2D419E13209D0B14970A128A0C16751E2F75577915245E0B2F6884ABCC
BAD8E4C2D7DEC3D6DCC2D5DDC2D5DDC2D4DDC3D6DEC2D3DCC2D4DCC1D4DBBED2DBBED2DD
BCD1DCBFD0DDA1B2BD99A7AFBECED74257740E2B5B1A40742D5B82608CA180A7B820475C
7196A8ACCBD77D9DA875949F9FBBC37D959C637B85314D6036546B4C6C7F688892617F84
5673754E6C6B4B6A68516F704D6B6B4B68694A68684C68674A66634A68634F6E684F6D6C
5370715572704A686547666348676146635F46625E43605C46635F446159436056466156
405C50486053434B3800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF006B830F5F390D5C3E255E4432644939633D32
581C176E212069191A661C1F5C20226B3D406C4B50654F5462515665545C6959636C5D67
6A5C6671626B77666D7B666E7D666E7C636D7A586381535E73363F752A32802F347D2427
862727781F1E8747478264627B6E6B8177767F7B797F817C868A848F948E8A908A8F9590
8F95918C9292898E9073787B70767A6B7478626E74596B7F182F5C011D5D05265E416381
69858F6A808563787D5D747698AEB0C3D8DAB0C4C96D848C91A6AE92A5AD8C9EA6758B91
BBD2D8C5DAE1B3C8D195AEBB91AEBEA3BDCBB0CBDF3C608A2A5C8E9CC8E9BDD9ECA6B5C7
B9AEBF964F629C1B2CA50F1B9D0C13910F187A1E2D6744631C2A5F082B666088B1B8D8EA
C0D8DFC3D6DCC0D4DAC2D7DDC2D7DEC6D8DFC4D5DDC4D6DFC2D4DCC0D3DABFD2DBBED3DE
BCD1DCBCD1DBBCD1DABED1D8BCD0D8AAC0D07F9DBA133762012754527A999BC1D52F546B
42687B84A5B2809DA85D798468838B839CA1647F847A949CA1BDC5658188849FA385A0A2
5773734E6C6B4E6E6B4F6D6C52706F4E6B6A4C6A674A68654A68634C6C6751706D4C6B6A
4D6C6C4C6B6A49686549676449676446645F45635D44625D45625D49645E466158476157
445F54485F5449524200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049AF0D653E0E5E40246144326842365E261D
5E130C6815116015105E24226A4346684F556352595F52595E515761535C655862695C67
6C606A6D5F6877626B80616B87626D8658646C2E3C8134416C151E7A1F2472181B893333
7E2C2A6A1F1E672F2F7B5D5C7B6E6B79726F767470797C768689838D918B8E948D8F9790
8F98918F9791888F8A797F7A707774737D7D65737D394D6D031C56092B6D264E7C4E7183
5C767A6F838396A8A8677A7D889CA2BBD0D69BAFB67488908B9FA5C3D5DAC7D8DE98ABB4
8CA3ACA1B6BF94A9B47B96A731576C88AEBFC3DBE8B6D0E685ADD075A2CB87AAC9B0B2C5
A87383942133A81320A50D1796111B781B2C775474202E62052C6548729CB3D8EBBCD8E2
C0D7DEC2D8DDC1D8DCC3D8DFC2D8DEC2D6DDC2D5DDC1D3DDC1D3DCBFD3DCBBD3DABAD1DB
BBD2DBBDD1DABDD1D9BDD1DABAD0D7B7CDD7ABC5D55B779605274F244B6D739AB07699A9
4F727F50727D8AA8B07E9AA279959BAAC7CC98B3B9728B93A3BCC37B939A637B81647D81
5B7477536D6F51706D506F6D506F6E4E6B694D6B664C6B664A6A664C6D6A4B6C6A496B68
496C694C6C6A4C6C694A686647656347656244625D47666148676149645E466159476157
476157475D524C574800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B41269400D5B3E205F402D5E2E21540E05
64130A63160E682D26603B36634A4C63535A61555D5A4F565F535A62535C6758626F606A
70606A735C6779545F6C37436C2D387E333F832B387A1E29791F24731F2068201F8D524F
82514F774A497A56547B64627C716E77736F7A7A747E817A8789838D908B8C918C8B928B
909991909991919A93828883757C796D7777637280192F59021A5D001F5E2F54775E7C86
667C7DA5B6B7C8D9DC8899A06A7D85768A919EB3B7A4B8BD93A5ADC0D1DAC1D2DB91A5B0
7E95A08A9FA7BED2DBBED5E293B1C1A6C5D3BFD5E2B1C9DE4066910A3C7A436494B59FB9
943345A81425AD0F1C9D131F8326396443671E2D62072E69416D97AED2E8BEDAE3C0D9E0
BFD7DEC1D8E0C2D9DEC3D7DEC2D6DDC2D6DEC1D5DFC1D3DEC2D4DEBFD4DDBAD3DABAD3DD
BBD4DBBFD3DBBFD3DBBCD2DCB9D1DAB8D1DAA7C3CD7795A95F809A4269844A728696B7C5
789AA8436777A7C8D5A1BECB6B899594B1BB96B1BC627D87667F8663777E5E73795D747A
64797E5D7577567371506E6E4F6F6E52706E506E6A4B69664A6A664C6B694C6C6A476965
4A6A654D6C6A4B6A674665644B696647646147646045625E48676147655F47635A49645B
466257455E524A594A209F1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0055B914693E095F4020633F2B5C2317590C03
66170D6121186D453C634D485F4E5062565B61575F5D525B60535C64545E6A5761755C66
7B586480535E6025317E3D457A3339701D24923D44691B217C393E743F407F5756866967
826A6A735E5F715E5D7F706E7E74717C79757F817B898D85878A838E908C8A8E898E948E
979F979099918D9491858B897379776B75794B5C74021A4F00175C06265A52748B93ACB1
70828676888E93A5AD68798067797F798D92C4D9DDC4D9DF9FB2BC8699A483969E95AAB1
7D929991A8AFC5DAE1C4D7E1BACFDC99B4C880A1BEABCDEA51769E1E43759D9FC6965068
A41E2EAE1321A218269239516447721B2C6A052D6A45709CAED1E9C0DAE7C3D7E0C4D8E0
C2D7E0C2D7E0C1D7DDC4D8E0C2D8DFC0D5DFC0D5E0C2D6DFC2D5DEBED3DCBAD4DBB7D2DB
B9D5DBB9D3DBBAD3DDB8D2DCB4D1DBB5D0DAB0CCD759778A88A8C2224266214569A0C4DA
799DAF254A607091A692AEC064808F55728069868F6581875A767999B1B373898C6A8287
9EB5B962797E5A7675547170506F6D516E6C4F6E6A4A6866496865496865496966466661
4969634E6D6A4D6B6B4A686848686447656046635F48656043615C47666046655E47625C
456259445F554B5C4E25A61E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00704209613B1B582A17602215570D04
6621186F3B316C4A43644E4A5D4B4C5F51555D52595C515A62545E64525E6E5461693E4A
612330752A386F242F8042478B55575C1F238E515679484D8562667C6468817072817375
78696C79676A7968698477768076747C79757F807A878B838689828D8F8A9195908C928D
929B938F99918F9995888F8E747C7C6A768122385D021D5C001A5D12325E628292B9D0D5
74868C61747A6A7E83B4C7C9A9BBBF6B7F859EB5BCA4BBC5859BA5778C93A8BCC1C6D8DD
BDCED491A5ADA6BDC4ADC2CBA9C0CF4C6D8E1646728DB6D7B6D1E8A3A5C0A9738C982236
A91A289C2231A45D78615284162F740A35785582AFB4D7EDC1D9E6C4D8E3C6D8E2C7D9E3
C3D7DFC4D8E1C4D8DFC5D8E1C3D6E0C1D5DFC3D7E1C0D5DEC0D5DDBED4DDBED7DEBAD4DC
B7D2DAB7D4DBB6D3DDB5D1DCB6D4DDB7D1DBB6D0E036536E88A9CB173662022654507895
84A9B95577884E6D7E65818E7A95A0597680A1BDC3A4BFC4647F84A1BDC09DB7BA657E84
70878D637B7F5D7877587572516E6C53706C52716D4D6C68486764476764466863486863
4668624A69664967684A69684969654A69634A67614A666247645F47655F48676046625E
46625A486359495E4E367B2A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007C490B5D300C59230E602011601F15
743931632E266C403953312F634C4E6252556054595C4F57634F5B634856714C59612D39
813F4B64162280353F6F3A40815C6075515683616680666B7C6B707A6D727F747982767B
796A6E7B686B7A686A7D71707D74727A767182827D898A84888A858E908C9395928A8F8A
8F98908D98928895918590907A858A57677E061F53001E64103572254C6E5C7B86677E81
6D80856C7F827C9195C5D9DDBCD0D66B818768818886A0A6B3C8CE9EB0B7A2B4BBC4D5DD
B3C5CD9BB1BC8CA6B1AEC8D3C4DBE892ADC6507797ABC9E0C7C8D7B4859A8F2A40971F33
9A3E53956A91414983103179164281729CC6B9D9EEC3DBE4C3D9E1C5D8E2C6D9E0C4D7DF
C5D9E0C6D9E1C6D9E0C6D8E2C7D8E2C5D6E0C4D6DEC2D5DFBED4DCBED6DCBFD7DDBED7DD
BBD5DCB9D4DBBAD6DEB8D3DEB6D3DBB7D0D9B9D3E33E5E7B3D64865378982F5473456982
6586948BA9B55172808DACB8AECAD4849FA98CA8B2ABC3CE70899369858D6C878E667D84
6981866A8284617B7D5A777459767457737153706E506F6C4B6A66476764496B66486864
4969644B6A664A69684969684969654B6A654B68624C686447645F4A686048665E45625B
46655A476457455C4E49503D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008750105E2D08622E175A23127D4438
692D246122186F372E562E2B654C4E665457665358684F58603B48693B47703C475E2E38
82535C531F26774449724D51795F657F686D7D676E7B686F76686F7A6E747F747A85797F
87777C7F6D707564667D6E7080777576726F82817F8988878C8C8B8A8C8A8D908D929692
9198938F9B948C9A958491917B8A942E4267031B5D021E6B0F3671476E88628084708585
BACDCFB5C8CA6A8085869EA47B939867808360787CA9C0C5C6D8E0BCCDD597A8B09FB2B9
A4B7BFA8BEC95E7986ADC8D6C3DBE5C4D8E3A8BCC8ACB4C0B59AA8833E4F944051B77F98
696092203E880B3E8632629999C1E2BDDCECC3DBE3C7DAE0C3D7DEC5D8E2C5D9E1C5D8DF
C4D8DFC6DCE3C5DAE2C6D8E2C6D8E1C6D9E3C6D8E1C3D6DFC0D6DEC1D7DEBED4DCBED5DE
BCD5DDBAD4DDBAD3DEB8D3DFB7D4DCBAD4DDBDD4E27492A9466D885B859B84A9C13B5F7B
7B9DB2ADCBDB36586C6185989EBDCB86A3AE5D7A8569858F6A828B5D7880819CA38BA2A8
6D858AA1B9BF6E878B5D797A597675597475546F70516E6D4D6B6A4C6B694A6969496868
4A69674968644767644969684A69664B6A654A68634967634A686347635E4A675F46645A
446458426055465F5249534300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009254185C250764311C6935246A3023
632014601A0F6931266C4B43614E4D6750526A464C5F2C355F212C733038601F265D2930
79555B65494D6D5254755E6176646978676E7B687079687171636B796D737E74797F737A
87777E8473777C6C6F7C6D6F796E6E817A7A817E807E7E808687858C908B8B908C929894
939A97939D98939F9C8A97987486980E2656031A650018660C2C606A8A9C7F97998FA3A3
BDD2D5AFC3C96A808660797EA0B7BABFD4D591A3A88DA0A7B1C4CCA0B2B998AAB298ABB1
C5D8DFC8DBE3AFC4D09EB5C2ACC5D1AFC4CDAEBEC6B4B8C08C7981AF8B95C7B4C86A79A9
103C8D084299548EC7AED9F2C0DEE9C4DDE4C6DAE2C9DAE3C8DAE2C7D9E2C5D7E0C5D8E0
C3DAE0C1DBE3C4DCE4C6DBE3C5D9E0C4D8E1C1D7E1C2D9E2C0D6E0C3D5E0C3D7E1BED4DE
BBD4DEBDD5E1BCD3DFB9D2DEB8D3DEB9D1DBBDD3DF94ADC31B40615E89A7577E9F012552
3A60829ABCD17798AA5174845F808C77949E6A878F88A5ACA9C3C978929A8BA6AEAEC4CE
768F977992996E898D5F7B7E597776587574567172506C6E516D6F4D6A6C4966684C696A
4E6D6A4D6C68496A654969664968644B6B644868624B6A654F6A674D686249675D47655C
48675D44615A4760554A5A4A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003E9D04571B02622C186F3928622113
71251C62170F642C246B4C4668514F633F42652C33702B3362171F671F2766272D5C2F36
6C515768565A66555A6D5B6273636A75666C7B6B7177676E6E6166776D737E747A7C7178
81747A7D6C727C6B6E7E6F707C6F6F817877807B7C8382838788868E918C8D938D898F8C
8C9391939C99919A998B979E51658205215D021B6A001A631F3F6BABC8D7A1B5BA8A9CA1
8A9EA47C9096889CA15D7579B7CED2C3D7DCA9BBC18EA0A88EA2A8BBCDD3BDCED59EAFB9
BDCED7C1D3DBB1C7D692B0C5668CA498BACAABC0C8B5C3C9BCC5CCC8D4E57E9DC20F448B
0440A30747A27FB8E9B9DEECC2DCE2C3DAE0C7DBE4C9DAE3C7D9E0C8D9E1C6D9E0C5D8E0
C1D8DEC3DCE4C3DAE2C4DBE2C6DCE2C4D9E4C0D6E1C3DBE4BFD6DFC1D6E1C2D8E1BFD6DE
BDD5DEBFD4DFBED3DFBBD3DEBAD3DFBCD2DDBED3E0A5BCD60B2D591B46716F9ABC14385E
446A885A7E8F86A5B06F8E9973929BAFCCD599B7C085A2ACAEC8D28CA6AF69848D7A949D
69848A637F836581836580815B7777557272567373526C70526E71516C6D4D68674B6867
4C6A674C6A674667624766644968624A6A634B6B644D6C664F6D694A676246655E47655E
47645C47615B4962574A5D4C1EA01600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0047A70C5B210168311B5C200F6F271B
64170E6320176839316D4D49674244682F35641D246D252A66242A5B262D714B53684F56
65555C675A5F64545D6D5A6474626B77676E7A6A717B6B7177696F7F757C7D727A7D7179
83757B806F737C6A6E7B6B6D796C6C8076757F7A787F7E7B8889868F938E8E948E8E9591
969D9A979E9A959D9E92A0AF28406D04236B001E6D00206033557B84A0B07F959C75888E
768A90B4C6CBC7D8DE8CA1A871899292AAB08FA3A7889AA091A5AAC8DAE0C9D9E2A9B7C3
ACBBC5ACBDC5B7CEDC5B7D942B58739DC1D4B8CFD7BED4E0A2C3DD699BC75B97CB4283C5
04469F03489F629CCFBBE0F0C4DEE4C4DCE2C6DBE4CBDDE4C8DAE1C7D9E0C7D9E0C6D8E1
C6D9E0C8DCE4C9DDE5C6DBE2C6DAE1C5DAE3C4D9E3C4D9E2C2D9E0C2D9E3C1D8E0C3DAE1
C1D8DFC3D6DFC2D6E1BFD5E0BDD5DEBED4DDBED3DEB5CEE21E42661E4C75527F9A7CA1B6
7CA0B66B8FA1B1D1DF93B2C3698B9CA6C5D49CB9C667839276929D6E899265808769858A
749093617D7E839D9F708A8C647E825F7B7E577575526E70526F70506D6C4F6E694E6B66
4D6B684C6A674868634B6A664A69644D6A654E6C664D6B654D6C674A696547666146635E
46615A476159435E53485D4C20A31800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004BAC0D5F2604612713601C0F71251A
5F1B10703C32734C456D44446A3236661E256E21277433376B3D426F515A68565F655961
62585F6559616B5A646F5D6675636C7969707868707A6A727F6F76806F767F6B73836E74
70585B8C7276826B6E7E6B6C7B6D6C817776827B7985817E8585828B8E8C888D8B8D9290
929795999F9C959EA37688A30B28640221740F3384163E7A476A8A58748072888D8A9CA2
6B7E85A2B7BEBFD4DC8DA2AB7289938AA3A8C4D9DDBFD3D9889EA6A4B8BFADBEC697A7B1
9FB1BBB9CBD4C7DCE4BCD6E1A2C0CEB2D1DEB9D5E1B6D6EE467AB00B59A62A79BB91CDF5
467AB14984BE98CCF3BDE1EFC6E0E6C9DFE4CBDEE4CCDDE4CADAE1C8DAE2C6D9E0C4D8E1
C8DCE3C9DDE4C9DDE4C9DBE2CCDFE6C8DCE3C6DBE3C6DCE4C4DBE1C2D9E2C2D9E1C2D9E1
C0D7DEC2D7E1C0D6E2BFD7E1BDD6DFBED4DEBED4DFBAD3E47FA5C24778A05888A9A7CFEA
406A8D39668AA1C8E17293AB57788E6C8A9C77929F6A86937590999EB6BD77929786A5A9
ADC9CE748D907E999E728E936380845F7D7F5C7B7B5471714E6C6B4C6C694D6F6A4E6C69
4C69664A69654B6B674C6B664A6B654B6A654E6C664F6C674D6C6749696546656043615B
405F58436058436056465B4C25A71D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0055B512682D03541606671F15611D11
70382C71423A70403C6227276722246723255C21246B41446A4E5466555E635660685D67
695F686B5E676D5E6871606872616978676F7B6871826B7485656F845863693D46946F76
67464A8462657C5B5D715857847471847C7988827F87838081817E868886868A898D9291
909896939A9B8F99A44A5F8704206A001F780124770F366F597B93627C83AEC2C7C7D9DF
869AA369828D6E8A919BB3B994ABB0829CA2C2DBE3B7D0D87F99A092AAAFAFC4C7C0D4D8
A3B9C0B1C5CDC9DAE1CCDFE5C4E0EB8DBCD782BBDFACDFFC4F89C01764AE468CC1BCE5FD
D2F2FFA3D5EF80B8DABFE5F3CCE3E9CFE1E7CCDDE5D1E1E8CDDDE4CADCE4C4DAE0C2DAE0
C6DEE3C7DCE3CBDEE4CADDE4C9DCE4C8DCE4C6DDE4C5DBE4C6DCE2C6DBE3C4DAE1C3DAE1
C1D8E0C0D6E1C0D6E3BED5E1BDD6E1BED6E1BDD4E0BCD4E96A8EB60A397B1A4C888EBEE7
15436C1E4D756C95AF7191A56D8A9B7B95A3A7C0CB92ADB78FA8B1B6CAD298B3BA7A98A0
9EBBC27893996A858B668287617D815F7D7F5E7D7C58777553736E52726E4F706C50706D
506E6B4B69684B6A674C6C674E6C674A68644D6C674B6A654C69664B6A6548676242625C
3F60593F5F57416055455C4D474D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0A7336065A190756130A753B32
78483F612F266C30296F2D2863221F71403E6E4E4F6C585C64565D6659616A5E676D626C
6A5F6971656F70626C70616A7661697D606B835D69814F5A7A37447C293770212D7E494F
805C607A55587B575A8167697C6C6B807876817E7A8484818282818A8B8A878A89858C8C
8B9494939B9E8E9BAE1F376A022071011E790122702549797A98AA627981879DA5A1B7C0
647A87637D897B989FC2DCE0C4DAE279929D738F9A7E99A094ACB1A7BDC1C0D4D6C9DCE0
C9D9DFCAD9DFC9D8E0D0E3EEC0E1F44383B22B7AB291C9E8B9E0F9A8D1EBC9F1FDDAF9FF
D2F5FF7BB5D775B6DAC7ECFBD4E6EED4E4EBD1E2E9D2E3EAD0E1E8CFDFE7C6DAE1C4DAE0
C9E1E5CBDEE5CDE0E6CBDEE5C7DBE2C5DBE4C7DDE5C7DBE4C7DCE4C9DDE4C7DBE3C6DBE3
C2D9E1C2D7E3C2D6E3C2D5E2C0D6E2BFD7E3BDD4E1BED6EB6082B00535810A4188659AC5
6F9AB7638BA57C9FB2ADCAD8A3BBC988A0ADB4CED8A9C3CE7F98A59EB6C18BA5AE738F97
789299768E936E898D7F9BA0698387647F82637F815D7C7B57777454747153756F52736F
4D6D694D6C684C6B674F6D68506E694D6A664B6A644C6B664E6C684D6B674D6B66486762
46666045645C47655A435D4E48534000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783A085417015D2317744139
69332B62231B6D2F256A342C673B366B4D4D69585C65596163575F61555D665B636A5F69
6C616A6E606972616B765F677A525D7738467626348D354083212F811221730D168B484E
7F585C7352548C7073897476786A6A7F767376726E7574728486858C8F8F8A8E9082898A
8B96968D9BA07287A107246102217700207A00226E5478A3BBD7E87D959C5C767E607A82
A3BAC38DA5AF748D97B5CFD7A6C0C96E899490AAB2B7CED4C9DDE2C1D2D6D0DFE1D3DFE2
DDE9EDE9FAFFBBD2E1C6E0F0C7E4F595C0E1A4D4F1D9F7FFF1FEFFF4FFFFCADEE6ABC7D4
B6D8E7B3DDF2B2DBF1D7EFFADFECF4DCE8EFDAEAEFD7E8EED3E4EAD2E2E9CDDFE6CBDEE5
D0E2E9CFE0E8CCDFE6C9DDE5CADEE5CBDEE8C8DCE5C7DBE5C5DBE5C4D8E2C7DAE7C5DAE5
C1D7E1C5D9E4C5D7E3C3D6E2BFD5E0BFD7E3BED5E2BFD6E690B0CE3C679C4B7EB574A4C8
A9D0E88BB3CF81A8C1B5D2E29FB7C8809BAC96B2C08FA9B77A94A0829DA68DA8AE7A9298
9FB7BCA3BBC1748F95A1BCC47B969C6D868B6B8588708C8D6381815C7A7A597775567570
55757054726F52726E506F6B4F6E684D69654F6C674D6C674C6B684C69664E69664D6865
48656047645B47655844605247574600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C3D0E531903643122723C2E
5A190F611B1061291D7A554B71585465535561555A5F555C5F565C60555C61565F655961
6C5B63745B667D5B656F3F4A75313D701420780D199328338518247E0A147B1119914A50
724C4F7C61628A7575837473796E6C827A767D78747473707B7C7D86898A8D9192899191
8B96968E9FA7435F8104256B00237B072E87002670547AA584A2B2748C92647D8287A0A5
C4DAE1BBD0D98096A28099A290A9B0A9C1C7ACC1C8C3D8DDCCDDE1D4E1E2EFF6F6F2F7F9
E3EAEFCEDFEAADC5D3D6EDF5E4F3F9EFFCFFF4FFFFF5FFFFF0FCFDF4FEFFEFFAFEF1FFFF
EFFDFFF3FFFFECF9FCDFEBF3DFEAF1DEEBF2D7E5EAD4E5ECD4E7EBD4E6E9D2E3E8CFE1E8
D0E1E9D0E2EACADDE4CADEE6CADDE4CBDCE5CADDE6C7DBE6C3D9E4C4D7E4C5D8E5C1D7E4
C1D8E4C3D9E5C4D7E2C3D6E4BFD5E0C0D5E1BED4E0BBD2DEABC7DB9AC0E74F80B673A3CE
9CC6E82150785080A49CBDD498B3C692ABBD94AEBC9DB5C28BA4ADA3BEC6B2CBD188A0A8
A4BEC6A9C2CA7D959E7E969E778F946F888B748D8E7C9596748E90647E7F607B7C5F7B78
587674567474567676537271506F6B4D6B664E6C674A69644D6A674E6A66516B694D6864
4D686149655C486659456255465A491E9E1400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008246145621086331205B2114
5E1A0C6225155F3527735D53695A5862555860545A60555B5D53585C52595D515964545D
70565F724954672D387C374281313C7918218A2028962F3687252C76171D8D3E43835054
836769816E6F8474758174737F7573837A797F7B797B7A787B7C7C868A8A8A8F8E8C9493
8D96988B9BAC1D396B02237601248217419C012B715D85A97F9BA6ABBFC29AAEB47C919B
ADC3D09EB4C194AAB69BB2BBBBD0D6CCDEE4CDDDE2DEECEFE3ECEFF2F8FAF9FCFDFBFDFE
E6EBEEDBE4EAF2FCFEF8FEFFFBFFFFFAFFFFF3FFFFC9E8F1B7DCEAD2E9F1F2FBFDF8FCFD
FAFFFFF9FEFFE9F0F7DCE7F0DDE7F0D6E4EBD6E4EAD6E5EBD5E6EAD5E3E7D3E2E7D0E0E7
CFE0E8CDE0E8C9DEE5C9DDE5CCDFE7CADBE3CADCE5C6D9E5C3D7E4C4D9E5C3D8E4C2D8E5
C0D7E4C2D8E5C4D7E2C2D5E3C1D4E1C1D4E1C0D3E0BDD3DFB4CDE55278A806387E255A95
81B1D4527E9F648EAC85A5B8A9C1CF95ABBA9FB7C4BBD0DD9BB5BF9AB7C1ACC7D18AA2AC
87A1A9899FA9899EA78CA0A7869A9F8A9FA2849B9B81989A7A92966C8587678283637C7D
5C79775A787959777854747451716D4F6F685070694E6D68536F6A526D694F6B684E6B64
4E6A604B695E48665A476457475E4B22A41A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0060730D5D270B572412581C10
5F24156C3F2F69504371625B6A5E5F63555B60535A64565D62555B5A4D555C4E5669535B
5E3B4377434D661D2875232D82303772192077171E7521268E4B4E864E5190646884676B
7E6B707F747783787B84797A83797B837D7E7E7C7C808180808382858A88848D8A889190
909A9E798AA10B266202257E012489002685083579678DAE8AA0AAC6D4DABECED699ACB8
95ABB7AABFCABFD1DCB9CBD3C6D6DBD3DEE3E6EEF1F3F9FBF8FCFEDEE4E8DDE4E9FBFDFE
FBFCFDF6F9F9FAFFFFFAFFFFF5FFFFE7F5FCD7EDF6A5CDDCA8D4E3DEF6FBF8FFFFFBFEFF
E9F0F3D4E1E6DCE8F0DFEBF4DBE5EEDAE6EFD6E5EAD8E6EBD6E4EBD7E5EBD4E3EAD0E1E9
CDDFE8CADDE7C8DDE7C9DDE7C7DAE4C7DAE4C7D9E5C5D8E6C4D8E6C1D7E3C0D7E3C2D8E5
BFD6E2C2D6E2C3D6E2C1D3E1C1D4E2C0D2E0BED1DFBFD3E1ADC5DC4A6E9708356C295A89
6A96B0A4C8DB91B4C88DB0C0B4D2DFA8C4D585A1B0ABC4D096B2BD7797A27E9BA67D97A2
7F98A196ACB58DA1A99AACB4B3C5CB9BAEB292A6A9889DA07A9296728B8F6B8787617C7D
5E79795B78785C79795574724F6E6952706B51706851706B51706A516F6A506F6A4F6C66
4F6A604C675D4B675D49655A445C4B32772800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A309612806521B08582111
693C2C6D514364544B6D615C685D5D61565862555B66555C664F5762484F5438406B4C55
5F3B43804C546E222D721D257C30356A24296F2D338C565B8E626993656D97626C7D4D59
8666717E7277837B7D847A7B847979827B7A838181818381828686818987858F8F8D9697
909B9F8296AB0E2C65022782002891002C8E23549488ABC896A7B2A9B4BDA4B0BAAEBEC5
B2C3CAC9D9E0D0DDE6D2DEE4EBF5F7F0F6F9E9F0F4ECF2F6F7FDFFDDE3E8D8DFE4F9FCFE
FEFFFFFCFEFFEEF7FBDFEFF9B3CDDAC1D8E5DEEFF8E6FAFEEAFDFFF5FFFFF8FFFFF7FEFF
ECFBFEE4FBFFE0F6FFE1F0FADBE9F3D9E5EED7E6EED2E3EBD0E1EBCBDEE7CBDFE8C9DDE7
C9DCE9C5DAE6C7DCE7C7DDE8C1D8E1C0D7E2C3DAE6C0D7E4BFD6E3BFD7E2C0D8E2BED5E2
BCD4E0C2D6E1C2D5E0C2D3DFC0D2E0BED1E0BACFDDB9CFDDB3CCDD63849D8AB3D17BA6C8
628BA5A9D0E7517C9C5985A595BACF6D8FA27090A088A5AF7E9BA46F8E98A6C3CC9BB6C0
819CA6AFC8D298AFB8859AA49EB1BA879AA085999C8BA0A47D9297748D91698586658182
627D7E5E7A7C5D797A56737153706C58726E58726E55716D54726E52706B57736F526D69
536A65536B654F68614C685D455E4F414B3700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EAD106326014B1200522111
6A473869534867574F6D615C6C625F635758665357694B5263343D6228325E2A337B535B
603A4186545C5F1C23712A307E454A7D4F5686575F87535D8A4C577326328D303F761E2C
7F4750877276877D7F8A8081857A7A847D7B84837F888987858A89898F908F9798939C9D
94A0A293A5B6234376032C86012E9A0133973366A7AED0EAB7C5CFC3C9D0C9D0D8D1DBE2
D5DFE5DDE5EBD9E2E9E0E9EFF2F8FBF2F8FBD5DEE5D3DEE5EDF4F6F3F7F9F3F7F9F9FDFE
FDFFFFF8FBFDDAE3EAD9E8F3D2E6F0EEFDFFF6FFFFF6FFFFE5FDFFC0EBFCB4DEF4D7F3FE
BFD9E3B6D5E1C1DFECCFE3F0D1E2EDD1E1E9CEE0E8CCDFE8C6DDE6C6DDE8C4DBE6C5DBE7
C5D9E7C5D9E7C4DAE5C5DBE6C2DAE2BED7E2BDD8E2BDD7E1BED6E1BED5E2BED5DFBDD4E0
BBD2DFC0D3DFC2D4DFBFD0DCBDCFDCBED1DFBAD0DDB5CFDBB5D1DE7192A585ABCA194070
2049786F9CBE1241662C5B7D5881957596A57D9EA98FACB5ACC9D07E9CA6A6C2CDA8C3D0
73909D96B2BE839FA9849EA887A0A78A9FA6879DA1869A9F798E9472888D688285678284
617D7E5D797B5B78795976755976735971705B75725D777457757152706C55716E57716E
546B685369665369634E685E47635441513C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056B6166227004D1903582F1E
6A4F3F69564967594F6F645E6E62606E5B5D69474C622932661921650D1761172081515B
623C457D555C60343981565C8259617E4D577A364275232E8931398C2932861520831721
80383F8E7275887D808C82848980828781818B8C89888D8A8990908C9394969B9D999EA1
9AA0A49EABB94C699605328A0237A6023CA3275CA0AFCDE9C9D2DADCE0E5DBE1E9CFD9E1
D4DEE6E1E8EEE2E9F0DCE4EDDEE6EDE7EFF4E3EAEFD9E1E5F2F8F8FDFFFEF8FCFDDBE2E6
E0E6EBF9FDFFEDF1F4EEF2F7F7FEFFF4FFFFE6FAFFD1EEFF8ABEE33C8FCB549FCFC5EFFE
DBF6FFC4E9F8B7DBF3C9E1F1CBDEE9CCDEE7CCDFE8C7DCE4C2DCE3C4DCE6C1DAE3C2D8E3
C3D9E5C7DBE7C5DBE6BED6E0C0D8E1C0D8E3BCD5DFBDD6E1BDD6E0C1D6E3BFD4DFC0D4E0
BED2DEC0D3E1BED1DEBED2DEBCD0DDBACFDBBBD2DCB9D0DCB6D0DE7594AB3E668C022861
042A624170916590A46E95A8668A97ADCCD790B0BA7C9BA7ACCAD484A1AE75919F84A1AD
6B8895698591718F9875929B85A0A7869FA57F969C7B9197758A916D8489647E82627D80
6380805977775473755775765674725A74745A76765C767458757053706C57746F5A7471
516C67506963546C63516A5F4B6658465A4700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0C6C330554270C573822
66503D68564766594E6F625C6F5D5B76585955202464141B7B1C21700F145C10167A4C53
6F50586D50577B5D647D5E657B5058803E487D222D811A238B272F963039871920871F25
7932388F72788980848D888B8B888A87858788888B90949691989B959C9EA1A5A7A7A7AB
A9A9ADAFB2BC7D92B70938890345B00850B53672B3D0EDFFD7E1E9D7DDE4D2DBE4D2DBE5
DCE6EFD4DFE6E6EFF5D4DCE6D2DAE4E2EBF0FAFFFFFAFEFFF3F7FAF5FBFDF4FBFDD1DBE2
D9E2EAF7FCFFF8FDFFF4FCFFE5F2FDA5C4E65A8EC08FC1E99CD0F65EA0D38AC7EDBFE8FF
BEE1FC5889B384B5DBBEDCEDCADFE8C5D9E2C8DBE5C7DBE2C3DBE1C3DAE3C2DAE2C3D9E3
C3D9E3C4D9E3C0D7E1BFD8E1BDD6DFC0D6E3BFD5E0BDD4E0BED4DFC0D3E1BFD2E0BFD2DE
BED2DDBED3DFBAD0DCBCD2E0BAD1DEBAD1DBBAD2DAB8CFDAB6CFDC92B1C3456B8644698E
51789C48738CA5CADA9DBFD1638A9EA0C4D68DADBD5778886B8B9766828D607D87809DA6
7B96A0708D96A7C6CD7C99A290AEB78AA7B06E8990678085647E83637F83617E815B797B
5E7B7C5575745574745371725371725773765A76775D77765D77745E7974607E77647F7A
526D694B6661526C63516C634C695B475B4C1B9D13
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006F38075A3111583C22
644F3C66554767584E6F5D576E535077494A631D1F660B0F761719691314622324764E53
7B5A637F576177485382515B83475182323C7E1A25841C24862930852F377E292E7C3034
86525991767D91848B97929797979A919194949497989A9E9A9CA1A2A5A7ADADAFB1AFB2
B9B4B7C1BCC3AFBDD7214F92084FB41160C22F70B1B9DDF5CEDBE2D9E1E6D7E0E7D9E2EA
D7E1E9CDDBE0DFEDF3DFE8F0D7E0E8E0E9F0E5ECF3E8F0F7CFDAE3D5E2EBE2F0F6CCDBE2
DEEBF5D3E0EFBFD1E5C2D8EEC7DEF8759EC9326FA591C3EABBE0F3BDE4FC75A8D74682BD
81BBEC417DAE7AAED2C0DDECC9DDE3C7D9E1C7D9E1C8DAE2C6DAE1C5D9E2C5DAE3C4D8E2
C2D9E2C2D8E2BFD7E2C0D7E3BFD6E1BFD4E1BFD4E0C1D7E3BED5E0C0D5E2BED1DFBFD2DF
BED2DDBED5E1BCD3DFBDD2DFBBD1DEBAD1DEB6D1DAB6D0DAB8D0DCAFCAD66183939BBFD5
7FA6C6416C908EB4CF496E8C174162567E9660829258768669879296B3BC708E979DBBC4
A5C2CA708D97A0BDC67E99A364818A638289618085688488658184688587688587668385
5A767753727050706D516F6F5572735370705472725976745E7975637E796A878267817E
5A74714D6662516B664E69624D695C4D615120A319
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C470D5E3811573C20
634E3A66544769524B714F4B7A4A486422226C191A650B0C6B1A1C66272773424573454F
7C43506B222D84344073242F85343F8D364174161F7D242980393D955D6289575B996C72
9B70799268708A6C72A4969AA09EA29E9EA39E9FA39D9EA1A2A2A6ACABAFB5B5B6BCBABB
C9C7CAD1CED4CBD4E84A71A90647A5024EB24184C5B8DBF3D7E2EAE3EAEDE5ECF1E3EBF1
D5DFE7CBDAE3CBDCE4D4E3EAD0DFE5CAD7E0CAD8E4C0D0DDC5DAE6BCD3E0B3CAD5B7CFD8
C2D9E5BFD8EE6485A77596B9BCD8F2BAD7EFA0CAE990BDE3A6D1F2A2D0F31A599C0D5BB2
377FBF99CDEEABD0E5C4DBE6CADCE3C9DBE3C8DAE3C8DAE2C7DAE1C6D9E3C8DCE4C5D9E3
C3D9E4C5DAE5C4D9E5C3D9E5C1D8E4BFD5E3C0D7E4C0D7E5BED6E3BFD6E5BFD5E4BED3E2
BAD3E0BBD5E4BCD4E3BAD2E2BAD3E2B5D1E1B6D1E1B4D1E0B7D2E3B5D2E386ABC180ABCD
133E7604306E4977A24E7896355D775E85979EBEC88AA6B27B99A4A8C5D18DAEB97C9FA9
97B9C06F8C9769858E6D868D6581866B888B5C7A7D6480846683856784856B8888688486
5F7B7C5472704F6F6B4D6B6B516E6E506E6E4F6E6C516F6C5775705D797566837F677F7F
647E7C60767459726D526C64516C5F52675724A91E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00885311613D13553B1E
644F3A644C406D47415C221F742E2D6C1D1E6E1C1D601818743C3E73434867333A6A2934
6C192672101C87242E872C366B19228640477235397B42468F5E659668718F5F6A8E5B66
8D4C59702A33AB787CB39CA0ADA6ACA5A4A9A6A6AAA4A4A8AAABB0B7B8BDC2C4C6CBCDD0
C0C4C9C1C3CABEC5D37B97C10E489D044FB53172B9BEE0FADBE4EBDBE0E6D8E0E7D3DBE4
CFDAE4C6D6E1BED0D8BED0D7B7CBD3C7DAE6C6D9E7AEC4D399B2C08CA6B2ADC7D29EBAC7
B3D0DDBFDBED9AB9D492B2CDA4C0D6B0C7D79FC3E329649F256BA88AC6F24781B62B6DAC
74B2DEB6E5FDC1E0EFC6DCE6CADDE6CBDDE8C6DAE5C9DDE7C9DFE7C9DEE8C7DEE8C5DEEA
C0DDEAC0DBECBEDCECBBDDEEB7DCF0B2D8F0B3DAF5B2DAF8AFD9F7AED8F8AFDAFBA9D4F7
A6D4F8A5D4F9A1D0F6A4D1FAA1CEF69FCBF59BCAF398C6F196C4F197C5F45589BE4C85C5
0E4092023185427BB687BAE198C5E378A4BFA2CAE2A5C7DF6F93AB93B6CD6D94A75E8695
7397A270919A6E8D959AB6BD728E9493AFB4829DA2617C81648184607D80698687698588
637E815673734D6C6A506D6C4F6D6C4E6C6B506F6D52706E57757054716D55726F668180
6984838EA6A56C827F58716B536F6351685A25AB22
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00905D17624113533B1E
5D4A345A4132572A215B1812742621661B196D2E2E713E416C3C4261282F5A11186F1C25
791C2575101A81242D80353C71343C8F61688661668E646C89515E8139487D3140A35B68
8F3E4AAA555F96565BC2A4A6AFA7ABA8A9ADA8ACAEAFB5B8BAC1C5BCC2C7B6BBC0B4B5BD
AEAFB7D3D1D7CAC7D0B3BEDC24509A064AB01655A3A7CAEBC5D3DCCBD5DDC9D6E0CDDAE5
C0CED9B2C3CDC4D6DEC1D3DCA7BBC8AFC5D4A7BECE88A2B086A1AEB1C9D4C4DAE5A6C0CB
98B4C0AAC4D2A7C2D1A0BCCDAAC9DCBAD8EC9CC2E4205E9C2B75B39CCFECCEF2FFB7E7FE
88CCEC7FC0E3B6E2F8C8E1EEC9E1ECC8E1F0C4E2F4BFE3F5BFE8F9BAE5FBAFE1FBA5DEFC
9BDBFF8DD0FE83CDFC75C4F968BBF55EB1F452A5ED4E9DEB4190E23C89DD347FD52E79CE
2971C72A72C92369C21E62BC1D5EB71C5AB41856B01954AF1750AD164CAB0D45A40F48AB
0A3FA702339A0B419B1F55A2295EA71F51973362A33A64A32F5A953D689F436FA1507EAA
81ACD18DB6D56D94B09FC3DD7FA2B76E90A06E8B995F7B865C797F5A787A627F81678387
6781855A767753716E4F6C694B69654B6A674C6B68516F6B5875715775705E7C79668381
718E8D849D9E8096955F7775536E6752675D29AD26
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A808633F12563C21
5B422F573A2B54281B53130A6620175B1F197648466B3D41592128621A205D09106E171D
7622297521296B252C8D5D64835C658C616B8F5A668844527F27398A2033851B2BBB6872
9749538E3842853D43C19EA1AEA7ABAFB3B7B5BEC0BDC7CAB7BFC4BCC1C8BCBEC5BDBBC1
BDB6BCC0B5B8C6B6BAB8B4C83D5896063D9C11499AA2C8EDC0D5E2B3C5CEAABDC8B5C7D1
B2C3CDA8B9C4C5D7E2C4D7E29BB0BD8AA1B093ABB6B3CAD390A8B39BB3C0C2D8E3B6CBD4
AEC3CBADC3CCBDD8E4BDDDEF6D95AD97BBD0D0EAFBB3D5EBB6DDF1E3FEFFD0E9F4AAD3E2
7CBBD798D6EBC0EDFAC6EDFBC0F0FDA9E4FD8AD4F77BD2FB6ACBFA61C7FC44AFEE329FE8
2795E72090EC1A8BEE138AEF0B80ED0A7BEF0670E80D6CE60D60DA125AD21356CC1654C8
174EC01748BB1B47BA1B43B61A3DAD1B39A81B39A61733A0142E9A122993112890102890
122C95122E970E2A920E2C910F319209298B072684072782082C84062A8105297E052D7F
0B3483153E8811397F2C539529528C33598B4569914C708F56788E5678865B7C85618089
607E835E7B7D5675724F6E6A4D6D684D6B684D6C694E6C6851706B52716D607E7D688684
7B9896809999849B9E637B7B516B6651655D454B3A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047AD0C6841115B3C21
4A29164A26155227194D15095B21156D3A32623132591E24601C226F20265F090F67151C
6D2B306E3A4078515781646A846069763542791D2D8A2633972C3A9B22328E15239B3F48
BF7A82964D5685444AB7989BB4B0B4B6BDC4B9C3C8B7C0C6B2B8BDB4B6BCB3B2B8B3AFB4
B7AEB2B3A8A9AA9E9FA4A2B052689A08358A0C3D8B90B6DCAAC3D2A7BDC8A4BBC4BBD1D7
C5D8DFA0B3BEADC0CCA9BCC7899FA8859CA4B5CAD0C7DAE2B5CAD595ABB9B5C9D5BCD0D9
C2D6DDD4E6EBCADEE7C6E1F0ABCCDDD8F3F9F0FFFFEAFEFFDDFEFFC5F4FFA0DDF4BAFAFF
ADF4FFA5EFFF95E5FE70CEF854BFF14CC2FA32B5F523AEF411A1EF0C9EF50696F3048CF2
0787F50174EF016FED057DFA0375F5016AF00562E62152CE4441B05C399E64379463318B
692E856E2C82722B80742C7D7228777226726B236D671F68611A605E185A591555581658
53175B4E175E4C156048145F44165E3E155F3A165F371B652D19642415642319691E1A6E
1B1F77131D7710237B0B237C06227905227304226A0626670F30691D3D6D2E4F78436689
5478915F8090597C83517275517171516F6E4F6D6B4E6D684C6C67506E6C5271705B7B78
8EACAB9AB4B4859EA15B7577506A6750645C444A37
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB4106B3F0C552C12
4E23134019084F29175123126C34255C1D166522226C2428661C217023295A0F1467262C
80545A73555C735F677A676F8C67706A1F2B8216238F1E28A3363E8511198E1D24832F34
B07C8182585DA78186B6A3A7B0ADB3B0B1BAAAAEB4AAAEB2ABADB0AEADB2AFAEB3B0ADB3
ACA9AE9F9EA08E8F9089919B6179A1062E780A357B789BBF8AA1AEA2B4BDA6B9C0C1D5DC
C4D9E0A4B9C4A4B8C3AEC2CCC0D5DCB9CED4B7CAD3CADCE8BDD0DDBFD3DECCE2EDBDDEEF
B3DEF4C7F2FDCFF9FEC7F3FFC4F5FFC9FCFFB3EEFE89D6FB6BCAF449B7F032A8E837AFEC
26A1E21E9FE31CA3EC0D99E90B9CEF099FF1079FF108A3F6019BF4009AF6029AF90092F4
0391FA0283F30281F40586FA047FFA087AF8266EE96D51B7AF3980C62A5FC62250C92450
C71F47C81E47C81D44C3183EC31B3DBE1A39AE0E2DAE1330AA132FA5112DA3122E990D28
910A278C0828910C2F8E0C2E860A2C810D2F770D30701237660F37620C38650F3E600F40
5910465413504B15533C14562D11552411571E135B13135D0B145F07175F051C62042062
08266318386B2E517943678650758852737E51727552716E53726D577471537270537373
75959798B3B689A2A659727648636251645C3C7F31
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B915723F0D532007
5524134D231157311D61311E6523165A09065B0809782C2F632023703436622F34805259
764853663E4A7A5E6879646D8A686F6C2D3781212C80141CA03D427D24288B4144956466
A68F91A49699A59B9EA8A0A5ACA6ABAFA9AFAAA6AAADADAFABACAFA7A8ACA5A6ACA4A7AC
989CA192979A8C91958491986E87A50628690A31717091B19EB3BDCCDBE0B8C8CEB4C7CF
B3C7D2A7BCC7B1C5CFBBCFDAC3DCE6C8E1ECCBE5F2CCEAF9BFE6FCB8E7FFB5EEFF74C3F6
53B4F541A6E550B5EF3CA3E2339EE039ABEC259EE81399EB0C96EF0693EF0492ED0792E9
0F93E71897DD27A4E226A0DD29A9E528AFEB23B3F31FB5F81BB7FE15B4FF0EACFF11AAFF
0DA2FF0E9BFF0D96FF0B8AFB087AF20E78F43666DB873D94C92552D61B32D2172BCF162A
C30C20C50E23C40F20BF0B1CBC0D1CBC101EAD0713A50413A30816A106149C051390010F
8A010F8C01109608198F031287051281121B923C459F5B638A424F7115287E0A1F860519
87051B84061F8006237906266C0829630A2E580A324909363A0839350F46260D4B1D0F53
15155C0B1861041A610524640E32652649733F627E50728158787D597878547271567575
7494948DA9AC819A9F5E787C46615E55685E2AAD25
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00733A08571C06
5B2313592A196333235D1F1262120B6B13105E0A09712B2C5924266F4548724C50703B46
671E2C66202D8E606A6C4D558263698E6067803842711D2387414497666AA484889C8B8F
9A93979C989C9E999DA49DA1ACA3A8ACA6AAABA8ACA8A6ACA3A4A9A0A1A6999CA29AA0A6
949CA08F989A8894968393997E95AD0C2E660A336E7295B49EB4BEC5D4DCBFCDD7B4C5D2
B5CADABFD9EABEDBF2B8D9F6AED9FC95CDF97ABDF161ACEF3B90E0308CE3238AE41186EB
078BF3068EF60B94F80891F5028CF00695F70193F20195F10596EB119EE92CAEED54C5F3
7DDCFAA0EFFFA4F7FF97F7FF75E8FF5BDBFF3DC5FD2CB9FC1BACFB0F9EFB038AF30586F6
057FF30172EE056EED0460E20351D4064ECE324EC1772B7DB51740C11225BB0C1CB7091A
B3091AAD0516AF0818AD0817A205129F08149707139104148F031294051492061383010D
7C030E7A010D7B020D7C020E70050FB1696EDFB7BBBEA3ACCFB2BCB383906A1321820715
88040E86010D86010E84020E81020E7D02107802107603147105186C051E6508275B0C33
4D0C3B3B0C42280E4B1A15570F1B60081F6305225F1334663257785176885A7C83628082
728F8F88A4A76E888C5672734966605B6E6322A41C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723209591804
612514662F2153140A6A1C16630B076D1312590C0B703A386A424371484C643038702732
70111D680B158A4D54815C64856B748D737B6E484E8D6166937276948187988D95968E97
9991999B9399A1979CA2979DA79DA39F9AA09B9AA09A9A9F939498929599959B9F959CA1
8C9498909C9D819293819497849BAE1D40721947828DB6DEA2C0D8B2C9DEB8D0E8BAD7F5
AED5FD81B4EB5C98DC4385D82C77D7146CD8096AE00971EC0671EF0270EF0273F30278F6
0182FA0087F8028DF70190F50194F6059CF910ADFE1BB5FF33CAFF45D2FF54D5FF66D5FD
68C8F66CC3F550ACEB349EE71C92E9128CEF077DEA0879EA0772E20868DD085CD60D59D6
0F51CB1247C21942BB233EB42230A2282C9A3E25877E1F66A81134B0091CAE0819AB0617
A504139F0110A106149D0B16860A118523288F3A43893645741727780A1B7C0A16721018
78282F681C255B0C1664121C5D0E1A905261976E7C502F42776070D4BFCC7742506E0D1B
74040C77040D78030B79010B78000A7C020C7B03097901087A010A7C020B7C030D790210
77031772061F650A29570F35400E402E14501A17580B1A5D07225F0E30603C6080628595
7393988CABAE6480824F6A684B665F5E6D620ECE0A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0079350F581706
6C2D1F641F165D0C0869100D6209056C201D66302F6C4946674645562328631B24863039
700C15720C14772D359671798B78838B7C8787777F87757B8C7D848D838A9089908F8892
928B94988F96998F96978D94958E95949097908F959191968F8F958E92988D9599969DA3
929A9F93A0A287989B8D9FA693AAC13D61990C3E8B5F95DD568AC95A8BCD669BE0417DCB
2C6BC70F51BD0950C70651D00457DC0262E90064EC0067EF006BF20171F40378F7047FFA
078AFD0A92FF0D97FF0F9CFF0B9CFF0C99FE0694F80791F3098EEF0D8AEE0C85ED0D7FEB
0E7CE8157BEA1471E3156ADD1B64D9235DD42E55CC374FC23B42AD443AA04C359A553598
603793632D846A287B7627777A236E7B1F697E1759971545AA0D28B0091BAD0617AD0817
A80716A406149E07138F121ABE7072DEB6B9DCC2CBDDC3CFCDABB888505E5A1722BA898E
D7BDC0CAB2BAA48B91C8ABB1865D6A4F1D2E9A7684AD95A28E8390C2BCC78A6E7C561E29
793A3E6E2D315C1317610E1465091066040B6C040B700208710006750106770106790108
7A010B7B010C7A020D79031273051C670A2A530F35360D3E1F12490F1652051E571E4472
749EBA8FB5C465848856717049615A57605300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C391162210E
7531255E0C07660B096C141163181276403B6F4F4A6A53506C4F4F5F292C5F0D138D3238
73151C71171E6D2C348B6B74887B84847982847982837780857982887C858D838C8C858E
8E87908C858C8E858E8D848C8F868F8E878F918D9492919792939895999E959CA2979FA4
98A1A895A2AB92A6B781A0BD6B93C73060B001339A0539A50D44AF0541AF0850C20650CB
033FC20134BB0138C2013CC8004CD7076DF40473F8077BFC097EFD0B80FF097EFC0B83FE
067DFA0379F50274F10173EF0272EF046AEA076BE70865E11264DF175AD4245AD23257CD
4457C8514FBF634DB97049AE74409F803E998334898E3284952D769F2F729824679B2567
98216197236091225E8A205C8A24628425637B215F892059A3183FB81029B60818B90B18
B80C18B30916A60B189C2431F9B5C0E1B7C8996B858A6178CCB9C6CEBFC85B424CCEBDC6
C6BAC78A7286B29AAACCC5CE948893786471CDC0C9AC9FAFA79AABC3BECC9086948B7882
C5B4B8BAA9ADB59EA1B49398603239A36B75661F2963030E6A01066D01066F0003720106
7502087401097701097C010A7F010B7F031078051668051D5A0C2C44123F24134D0F2163
1138755885B07EA4B9617F8351666046493800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C6C0B6E3118
651E11610A05630C086A211A74393172443E6D4944735451634544703C3C621012711C1E
813D3E794748825F657E6C727D737A7F757E7D727A8377817E727B80737E857A84847D86
877F89887E87897F8890858D93878F938A919994999191969A9DA299A0A599A5AD99A9B6
98ACC2829DC2577EB51E529D0F4CAB0945B1012FA50126A00024A0002CAB0345C50650D4
0037C3002EBC053ECE064AD80459E7096EF90372F90473F80470F30167EC0462E9035ADF
0558DB0B58D90E51D0104AC61C4AC12C47BB3D48B7544AB56644AA743D9C863E9794398E
9F3485AB327FAD2D79B02F79AF377A9C3272953676923C7E8C3F828A478C7D4A926B4590
624A965246944B4D9C454EA23B4AA43649A83147A74D48A4883378BE1D43CE1727CD141E
CA121CC4101BBA111EB01C2EB33C52A039537E203C6A263EBEA6B2D5CED6776874CFC1CD
BBA5B6632A46662B45D1BBC89A939E968E9BCBC0CE634059552740BFAAB99B92A09B919F
B7ADB653435292828FBEB3BD584752CAB2BE7445555D08176701076700036800016B0206
6A070A6D10166E08107A030D7C010A7F030B7A010B7B030F7C07167609236311373F154B
1C1D621132754C75A47394A9556A6824A72000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003A9B026C2E0F
560D025C090260170D743B307A433C7339326028227F554E55342D784D495D221F6B3331
89676779686A786B71786D757B72797970787B70797B6E777D717B776B767A707A7A727A
7D767E857B848B808791848A9B8F959D959AA09DA29CA1A89BA5B394A6BE7C98BC567CAE
315C9E1747990B42A40540AD0441B6043EB8012CA600219D0024A4012CAE0749CC0D5FE6
0855E10349D80348D7024BD90657E5045BE9045AE50757DE084ECF0C45C31841BB1F35A8
2D319D4234995432906130887936898834808F30799D3079A62C73AA2F72B13D7CB24686
A546899C4C938D51998A65AE786BB16571B75175BB497DC24282C82E76C6257CD1218ADF
1B90E71993EC118EEA118BEF1288F20F80F2137BF1256CDF7451ADC32F61E4283AE1212A
D91A25D11823CF1D27C71D2CB01B2BA02C3AB1646ECEA7B0D5C5CFD6C1CE765565D3BAC9
C7A5B775243F732037D8B5C2A699A7A194A5CBBACA632E475D192FC5A1ADA993A276556B
CFB3C289748381727FC2B9C4544452C5B1C07B51625F091A6B01096900046B0205690308
67181ACA90926F232D720815760A1072070D72020B79020C81030E870513810516750C29
5A18482F206211286A466891556B7525A72300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049AA0C6C2D09
5710015C140572362571392D642018772B23651F18824E4672524979605A7B625D796361
7A6E71736D73736D74706970726B71786F77736770766872746771756A747970797B727A
817980897F8890858E9589919D939EA39FAE9EA8BE849ABD5477A82F589B134496073B9A
0438A00338A40334A4012FA40034AE0136B40638B6002CAD0430B50336BB0546CD0758E1
065AE60751DE0748D40946D00440C80D42C51C3DB82B31A1422E93522A84612577712470
7C22668722639126659329669C326F973A7891488A855199795AA36F66B0646FB7607CC2
577EC15884C06698CD6FACDD75C5EE64C8F157CDFA48CEFC44D2FF34C4FF25B8FF15ADFF
0DA9FF0CA4FD0B9DFF0892FE0787FD047BF70675F30F61DC5348ADA92862D31D34CE1120
CA101EC30E1AC2121DB41520AD3940E8A9ADE3C6CCDBC3D2C79DB493506C79354BE1BBCA
C199AB79223A802839E2B9C4A48D9DA08A9DD1BFCC6B42535D2939CBADB8A789995D283F
7E4F60A98E9BBDB2BCBEB5C1584553C8B3C17C5162650C1D71020A7000036D0105670408
5A151AC9A4A87038436A10209A4951A25A6168101A6E0610750610840A1589070F8A0512
850E24691B4831205F12296138536C22A72700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B1136A2A06
5C1B08672916793E2D67231763100791392F65160B6C322779595078696379706D777071
7772786D666F6C666D6C666B70696F72697174697174667070626B6F636D776D7580767E
837C848A858F8F8C999293A8868FB1687BAC375798164292083B99073EA60438A70336A7
0032A20132A2022D9E0530A60738B10437B4063BBB0333B90331B80430B90332B90C44C9
0945CA053DC2012BAE0123A1011F9520208A5E2B847A1E69891A5B8E1B578A1B54892660
80326F6F3A7D684E975A539F4F5AA74268B7387AC8348CD8339AE435ABED33B2F14ECBFB
72E3FF90F2FF9BF4FF98F1FF7EE5FF55C9F931B0F226ADF61EABFA109AF3078CF20180F0
0381F4037FF50074EF0067E90161E8005DE20058DB074BC9393AA18D1F5FBE122EC30E1F
BF0B17BC0915BB0D18A0131EE1979EE5C9D1C09FB197597487304F861D3B95374CF9BCCD
CB8CA07E1932963447F0B7C4A5758A8C5971DEBFCDBEA6B3B6A0ABD1BEC8987585976274
C599A75F4451A3939FB7A6B466505ECDBAC67F576665102175030D770106710104670307
58161BC6A4AB6A39485E10228F525CB98B9454162385414A914F57721824850E17940E16
960B1787112E5A275D192362183156327A3800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDB0C632200
5B210976402B6929186C190F75140D781B11813727814E3E76594E746661776E70777177
78717A756C766760676963686861676E666E72697074656F75646E73656F766C74807A84
818291848EA56D7FA4405A911B3E870C368F04319704329F0131A40130A50130A50233A8
0236AA0539AD0334A7012CA00535AC073AB30839B5072DAA0B239E101B8F19137F23157A
342F950A1A85011A8600167E0415761D106764256E782464783073693C84513E8C3D4698
2B50AA1E60BF1D80DC2096ED1A9AEF26B2FB1AB4FC23BDFE30C5FF30C0FE29B7FB24A9F3
2DA6EF2696E32699E6259BED128BEA0982EE047EF10279EE0279F00170EE006AEB0066E9
005FE10267EA005EE40056DD0053DA0157DC0357DB0347C6303EAB84256DBD1437C70F1F
CA101AC60B15C10F19A91D26F0ADB6E1CAD48D6879955469DA91A3D3788D96253CC35066
AF39509F142DA51E34CB5A70A2354F8F203BBB6379D492A7B88096CF95AB964B6283364A
D59FADCCABB6CFAEBC916679855D6ECBB6C0B39AA48B4D5B6F09167A030C7701066B0407
632528C3A9AF6C4D58521C2983545FB58F9B4D1F2CB7919CB398A19C6B776F1F28801922
9317228E142D6326561F256708204D343E3E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00672B02
6B391C76462F6C2A1A6C120A7A150D6D1408925443916D5C755F55665955776E6F726B6F
766F77736B765C555E665F686B616B6B626B71676F70646C776A74756D77787685717892
566A912C4A8310388207348D033194022F9A012C9A012B9C012CA00331A70333A80233A9
0237AE063EB40836AB032696112E9B182E9A2929902D157336095B46084D5F0E496D124B
601B5C1F0D5F041877001B81021D85142B913444A72E44A6224DB21860C81474DB198BED
1995F80D8FF814A3FF13A7FC0D9EFB12A3FE0B9EFB0792F6048BF20182EF027DF0027CF2
0275EF0271EE0273ED0175EE016EED0068EA006AEB006AEB006CEB006BEA006AE7016AEA
0066E70067E9016AEC0267E80162E30162E60160E40558DB2E52C5803685C31E44D41321
D8141CD5131BD2151DC01A26E17787F5C1D0E5C2CFE8BECBFBC1D1CE6D85AC1C34BA1327
BA1123B80C1EB50B1DB40E24B30D26B00E26A61026A61B349F1A35991731961028911024
8C1F32A0455A953B507C1B31964054B87D8CC798A5B06F7F6D09197C010C7C01066F060A
804749C2B2B7C0B1B984646D8B6D75A68691532A37C8ABB8685461997B8BA8828CD19CA6
7C223184193461275920276A051D4F18612800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A3F0A
6C3D1A6E40277439256917087A21117A31209266558E7569817269685F5878706F71686C
756C746F666F4B424B575059675E686E646E726872726C7573727F6870874B5C821E3871
072B76042D86032F91022E94002893002896012A99042E9E012FA00131A30433A60633A7
0934A80F30A11B289121136C3C17644E11586B1A5970134A6E0E3E660D3B5D0C3F54114B
522D75252B870626950129A2022DAB023CBC0B56D60B63E20E71EE0B7CF50C87FC0A89F8
067FF1037AF1067DF2057DF20072ED0070EC0073F00069EA0067E90066EB036EEF0069EA
016CED006CED0172F10174F00376F10277F0037EF40281F20387F40389F40A90F80489F5
0287F5068DFA0084F50180F5017FF6037FF70177F30470EF2267DD7749A3CA2957E61E2E
E91E24E31C20E01B20DB1C28D02A3DD5556DE07A91DB7792C6506DBC2744C6182CCB1421
C70F1AC10B18BF0B17BF0B19BF0C1BBD0D1AB70C19B70D1BB50B1BAF0A19A30412A00613
9D091897091A9407198F03148C081A861024871B30861A2C7F071583010A8102076E080C
AD797DAB929C8D6778764A59AD91979A818A5C3C49CFB9C5B4A5B0766271B09FAAB1929F
A66173811F3B6223542526670820510D921C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00647609
6D350E703D2086503678381F74331B996A55917565826F667B6F6976706B6861616D6568
6F676D71686F5850565A54596D69706E67746E697B666A8343537718306606246B012479
012887042C91002A91012A94012A95012A96012A98022B9A032D9B072D980E2A931E288D
31207D401567571458620D426C103B6B113E5E1448501550380A4E290D5B1A116A141D7F
13349E0C3BB30130B10538BF0942CB0341CB0855E00760E80563E80261E50265E70160E1
0159DA015ADC005ADD005BE0005DE2005FE30265E80169EC0067E9006DEC0073F00175ED
027BEE0484F10687F20A89EE0E8EEE1492EB1B9AEA21A5F020ADF417A8F01DB0F11DB1F8
12ADF90FAEFE09A9FE0BA7FF07A0FF0B9EFF0A94FF0B8AFF1D79F47866CDC83671EC243A
EF232AEA2127E31B24DF1923DA1927D41B32CA1B35C91B38C81633C50F28C50E1FC60F1C
C30C17BC0A15B90812BD0B15B90A12B80C14B30811B80C15B60B15B00A14A3030E9C020C
9B030E97010B98050E92010B90020E8D010F8B030F88020E86010C88030C81040A6E1217
CAA0A38866736121396A243ACFA7B3C4AFBB816D78BEAFBA82767FC4B9C5C5BAC6957784
AA647690243E731F473422590E1C460C8E1700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048A809
6F3004692B0D7F4A2C8051348A634A8C715E8674667C6E646D605A746A67504747665D5F
696366716A706A6469615F66696B7764698248527B192D6305216403217302237E022484
02268A02278E01268F02289302269303279105268F0B238B1621822A1C7444196660195B
73154D7A1142761341691A47542256311A5E212478162B8A081F88051E8E032397032FA6
0B46C00E4ECA0035B70639BE053ABF0136BD0441CA024BD20045C90047CA0149CD004ED0
0152D20056D5005BDC0061E30065E60571F1006FEC017AF20382F5078BF60890F21192EB
25A2EA3DACE858BAF16DC5F383D7F895E5FE9DEFFF8FEDFF77EAFF58DAFF56E2FF3DD0FF
20BCFF11B0FF08A8FE07A1FD0498FF038FFD0280F90278F9096BED4A5ACC9B2D77D21B3B
DE1927DA1422D40E1DD4111ED1121FCC1020C50C1CC70D20C60C20BC0719BE0A1BBE0C1C
BA0916B70814B30812B30914B10811AF0811B00711B10712AF0812AA07129C020C97010B
97020D95040D8B01078900088801088701078602078200068301098201097D050C772227
D2ABB0BBA2AB9E6D7F6F233A954E63C792A6916C7ED2BAC7B0A0ABB8A6B6C4B5C3D0B4C0
AA677897253D841A354E1D40251E3909C70A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052AF0E
7129026D250A874E338E664C8B6F5883715F7B6D618173696E5E5773635F4E3E3E625455
6B61646F666D79758064677A4C58781C2F63081E64031D6E021D7604217F042181021F80
02208302228A03258E04248D051F850E1B7B1E166B37125E5615566F15497B1540791542
6D1A4C591E58402065231F6D122680092D930633A5083AB2032FA8052CA6062EA8032FA8
0437B10944C00032B20029AB0126A60026A50132B30346C80146C70049CA0657D8045EDE
0262E10167E5016EEB0478F4017EF50288F8018EF70699F413A4F233BAF652CDF97AE3FE
9DF5FFB5FEFFC3FFFFC6FEFFBEF9FFABEFFF8BDFFA69CAF648BEF52AAFF216A2F00D9AF4
0390F5028BF90286FA007FF8027DFA0275F8016BF10468F20560E72558D0683B95A92156
C01534C3112BBE0C24BE1126BA1126B60F27B20F25B10D26B00E25AD0E24A90C23A70A22
A60A1EA60A1EA50A1DA3081CA20719A30819A50818A50515A30615A1061696010D95030D
9905108D01098300068101058000067F01077C00047B00067B01067B0107750209711019
98535FB48392C78EA07A2236790A2182162E7F2239C78196D19CB0966C80C5ABBBB597A5
B26F8095223984122757142811C80D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BB613
772B00742A0D763D258C695188705B81705F7F71657C6D6479686177655E685552615151
6F62676B63716465802E3C69081D5A01176300176D021A77011A7A011B7D031A7B001271
021572051D7D081C7D12187122105E4211535C0E426E0D3878133B711A42602355452465
27217114257F09288B0630990536A6053AB0063EB90A43BF0536B000249E011E9A001B96
00219D053CB90237B90026AA0024A60026A80031B5044ACD045ADC0363E4046CEC087BF7
027EF50486F9048FFA0799FB07A1FE0EADFF15B5FF24C5FF3BD4FF51DBFF66E1FF6AD8FA
6FD4F961C4F452B6EE3FA5E4329EE52095E61593EE0B8FF2068EF4078FF90385F7027CF5
0176F30274F3006BEC016BF0026CEF0164E9025DE1035CE10156D90B51D02843AE583083
7824638220597D1F577822587425596E1F576D20586A1C556D20586A1F56641B53641A52
671B5068194C691949701D496F194474184279163D7B11377C0F31811030840E2B870D26
860A1F7B061675031173020D76020D74020A7001066F01056F02066E01056E01066F020B
750819730F2378172A7E0D1D8704129106178F071B8E11288F1E37873147E7B4C5E3B0C1
99405591172F76102729881300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7D36036D2A0884543783664D826B587C695A7A6B5E7D6F657C6C637263596F615A6F6365
6D6674484D6C16245503185C02196803196E021671011774011A78021B79051A76010C63
070B5F151060240B50400B455C0C3B6B0C336C123B601A4A481F592E21681723770A2786
05299206309E0432A20535A60837AB032FA6012CA70233AE0330AA001E99001894011A98
0127A80842C40341C7012FBA012CB6053BC40442CC0452DA076DF10679F90483FA0792FD
099AFE0B9FFF0DA4FF0EA8FF05A2FE09A7FE089FF90BA0F7099BF20C9AF30B98F20B94F1
0D94F40A90F3088BF50585F60480F50581F7027BF60177F50278F50274F30170F00067E9
0063E60161E3015EE2015EE3015EE0025CDD0155D40355D2014FCD0249C9094BC21741AF
2539A02A35982B399B2235962136961F35951A31931B2F931B2E911E30941A2D90192C8F
1C2E8E1B27871C268222298223267B2727782D277430206E3320693A20674423674A2361
54285E522352501D46491033500D2C540A2155061657030F5B030A5C03096002076A0106
77020E78021075010E7D010A8A020A94051094030F9907159908198E0E21AA4157A9455A
9D223793132C6D193A264F2800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C49107A411989644379634878645075635278685A7A695F7A685D6C5A506E625E676470
353C5C08194D01155902196702176B02176D01136A01156D02197104186E0A1364180C53
2D0A464C0E3F5A0930620A2F5F103A4B12463318591D1E6F0E2580082C8F042C96022D9D
032FA20330A4022EA201299C001C8F00188A00198C022DA20331AB0022A0001D9F0329AF
002DB60648D00450DA003FCE013ACA084DDC034CDB0760EB0979FD047FFD0587FF0991FF
068DFC0184F70285F90080F60183F80287FB0184F80283FA017EF6017DF70182FC017EF9
0179F6027BF80178F70277F70072F10371F2016CEC0268EC0267EA0466E90162E5015CE0
015CDC0058D70155D50257D90156D40256D30050CC014CC7024CC80249C70147C20346BF
0645BC053FB8043DB5043DB4023BB0053FB2043DB3043CB30238AF0437AF0333AA0435AA
0435A90231A70431A5042FA2042F9E042F9C06319A062D95062B93072B9109298F0C298B
0D288210287C14257517216E1F2167271F5E2B194C2B0E362E082634061C3F0516550515
6D071973031573010F7B01098D080F93060F91030B96040E9E08129A06129A0A19990D1B
9F14228F19326027521E184311901900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
3D9E02764016866440756042705F4670624C6C5C4B746253705D4F6B5E55605E64252E4C
05164A02175C02176601166902156A03166A011366041466081360120B4F2C09434B0B39
5C0A2F620C2F58113A40124A24115913186B081E7C05278D042E9704339E0331A1022FA3
012EA4002BA200299E01249700168700198A0020920536AD033EBA053ABD002FB70132BE
0136C5054EDA0E6AF3045BE8074FE10448DB044ADC0961EE066FF6006FF40374F90070F4
026FF4006CF2026FF6046FF7016DF20170F4006EF00270F2036CF2016BEF016FF1006AEE
0066EB0067EE046FF1016BEC036AE90264E40160E10262E2015CDB015BDB0159D90255D6
0155D20155CE0152CF0253D10053CC0151CA0151C90350C80350C4014BC20148BE0247BD
0244B70140B4023FB20341B20341B0023FAD0441B10441B10340B0033DAD033CAA043CAA
053CAB0338A70337A60335A30233A102329F02329E01309C012E9A022F9B022E9A012C95
01299201299102289004289003278C06278709227C081B680814550B1048110B3C260F3D
3F123F4F0E355A082471071B8408158B04108D010B980510A70E14A2080EA0070D9F0B12
9209177D1C3E4429620C1A4F155A2600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B00D7B4612805E33735F3D6B5B406A5C43695A426C59446B5B4E5854571B253D041643
01165302175F021463031467011162031261040D57110C4D23063E4108325A0B2D5D0B2F
500E39340D44190E520E186B051C7B03238802278E022A94022A96002A97012B9B002CA0
012CA4022FA70230A8022EA700289D002A9E0134AC0343BF034BCC0850D40342CC043FCC
0542D1034DD80B67EE0C66EF0146D50039CB013BCC0245D4045AE60160E90262EB0263EA
0162EA0160E80162E9005EE60162E80365EA0162E70061E5005FE30160E20160DF015EDF
015CDE0362E20363E40160E0025FDE015CD8015BD7025DD8015DD6035DD6025AD20156CB
0155C70253C50252C50655C60756C50855C10551B90851B6084EAD094FAA0D4FA70B4BA0
0F4DA00D4998104894124A95164D951A4E96164A92164B9216499015468E13468C15498E
14458C13448A1041870F3F880E3E870A3884093885063384043285073689043387043085
042F86032D88022B8B012A8E022C9001298D03268A02238203217B031E73041A6C061969
0F18671A175F2B18514316465C1237710E2B7F071C940A19A50F16A60C109F060A9D0912
8E0C22671E4F2E2C7409215E1D223400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C5510825F2D6E59366D5D4169593F6D5B436E5B4B534B4A13192D03143A02174B
02165502165A000F5802115D040D560907471C043936052C4C0726540B2A490D33310D41
150B500A1666031B7302217F012589052C94032C97012996012696022999012A9B012BA0
002CA40233AD0138B3023CBA0541BC0440BB0649C6034DCD0455D70757DB0347CF033CC7
063CC9003BC60351D70653DB0038C50233C30132C30037C5034ED80258E00057DD015ADE
015BDF0058DC035CE00059DD015BDE015DDE025ADC025DDD015CDD015AD80159D40059D4
0058D30159D2005AD2025AD2045BD1055CCF065CCB075CC60C63C90D5FC10E5AB5125BAF
155BA9195BA51F5CA4225A9F265F9D2B629C30659B37699B3A6A963F709743749541708E
4873924C7491507791567E94597F955B7F96587C93587A905A7B9052738A5074894A6F82
51748C5B7F955A7D935E829A5579915378904A6F8A466A893C608231587A355D8032587F
2E547D274C7A22487C143B750C3675063074022A7302297502277802257A022479012279
021E79041F780821720D1E6A1D1C61321A564F18476F1434870E1F990C16A1090FA20B15
8D102A622B651B297507235F0C922000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00788E13896026745A356B573B6A59406F5E4C5E5350181A2B031234011343031851
031759021457020E52070D4E1509402E07324507254F09224209272C0B38150D4A0A1560
031971011E7D03258503288A03298E01289101289700279900289E022DA2012FA30132A8
0237AF0139B40442BE0245C3054ACA0247C7044BCB024DD00250D4054ED30039BF002DB4
032CB3002DB50544CA094ED40036BD0133BC053EC7003CC3044ED30457DB0257DC0258DA
0257D90155D60156D50155D40155D40258D70257D50157D40357D40358D0045ACD065AC9
085BC30959BA0E5AB8135AB1175DA91E5EA62562A12E68A1366FA24276A54D79A2517C9B
578199597F9565869B6786986885936C8894728E9878949C728F95719192719191789597
7D979C7A9399829C9E89A2A38AA5A590A8AB90A7A990A7AA92ABAD8EA5A893ABAA8EA5A5
94ABAD9EB5B59CB3B595ACAFA0B8B896B1AE92ADAB8DA6A88AA4A7809BA07C989D79939B
658289607E85607F8A5879884B6F823B6279335A76274E6F19406813396A093065022965
02266C0226710225740425770425780925771824712F2161531D4D781535950F21A91724
8D1736522B68142B770420580A8F1B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CDD099566217A582C6C53366C5942655A5121232F04103101113E011449011552
0416590410520C0A451D04333F0A2D500A254607232E082D150A3C070F52031565021A74
03238402258901248901258A01268D002892012A9A022DA10130A70134AB0238AF023BB2
0440BA0341BC0344C10145C5054ACA0445C60342C40146C80248CB0343C80235BA0026AA
0126A90128AC043ABE0A4ED10141C50343C6084FD0024ACB0550D1004ED00251D20051D0
0254D20153CF0254CF0253CD0556CD0456C80758C40855BB0953B0145BAF1C5DA92863A7
3069A03F73A14E7CA25580A06088A06386996586946886906D89916F899271898F738B8D
768C8E799192849A9D83989A869B9D879C9E8BA1A1889FA089A09F8AA29F92AAA694A9A8
97ACAC9AADAF99AFAFA0B7B5A5BAB8AFC2C1AEC1C0AEC0C0AFC4C2B3C8C6BBCCCBB6C6C5
B4C5C5BCCBCBB7C7C8B4C5C5AEC1C0ACBFBEA7BDBD99B1B195ACAE8BA4A77D969B819B9F
738F8F6D8A8A6A85876681855A787C5474774C6D6F45676C3F6067385A66325764284D61
1D445E173C600F335E03285D01276702287304297B092A7F1D2E7D3D296B671E4E8D193C
832049462D6F0E2C790B255A0D8F1A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0028DB0A7F571F6447266D5A4837333506122802123902144401144B00134F
05114E0E093D29082D4408214C08213A08291B06330A0B45021157011868001A75012183
02278B02288E02288E01248D012791022D990130A00233A50437AD053DB4023BB30139B3
023CB6003BB60140BD0140C00341BF023BB90031AE0238B5023AB9023BBB0335B70126A8
0124A70226AB0130B3094BCC0349C9034CCB024EC9014BC6024DC8034FC9024FC60451C3
0650BF0852B80B54B11055AC1A5AAA225EA22E69A03D72A04C799F5E85A562849E6D8A9C
728D98789297708A8C748D90779091748C8C768F8D79939081999879908F839A98899D9B
8FA3A18DA1A092A5A59BABAC96A5A59FAFAFA3B4B4B0BFBFB1C0C0BDCDCCB8C9C7BCCACA
BECECEC1D2D5C2D5D5C7D9DACADBDCCBDADBCADADECCDBE0C8DADDC3D5DAC4D5DAC3D3D9
B8C8CEB8C8CFBAC9D0B3C1C7A8B7BDA2B3B997ACB08DA5A8849DA27E979E7891996E8A90
6B898B658284607C7F5E7980577578516F704E6C6C48676744636142615F3C5C5A3A5C5A
3457563456592F52592A4D5C1C405911355B052D60022A6D052E7F1032882A2E7E502466
5E2D6C302F7B0C2D79122855108F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006A88185A3C13584B3D10151F02132F02153C021544011546071346
150B37330A2844071B430A20270429110A3E040D4F02145E011869011E7502227F012587
02278E01268E012890002891022D9803319F0131A30235A90336AC0135AB0136AC0137AD
0037AE0139B1013AB4013AB6023CB70137B10130A70030A60134AC0138B50436B60027A7
00219F0123A40029AC0440BE034AC5034DC4034DC0044EBA0950B50B4FAB1452A41F559D
2F619F3F6EA04E7AA15A83A261859F6686976B8B92708D92738B8F758A8D728688788C8E
758B8A7B918E8096938398977F949382979591A7A392A9A698ACAA98A9A9A6B6B5B0BABA
B9C4C5BAC7C8BDCCCBD1DCDBD9E0E1DCE3E6DDE5E7DFE5E9DBE2E8D5DFE5D4DEE4CCD4DB
C5CFD5BDC8CFB0BCC4A9B3BBA2ACB5A0A7B097A0A99399A48D929B868B937B808781878D
767E85767E86757A83757A826E747A6E767B6874766674756372766170755F6F735E7276
587172556D6C536A6C51676C51686C4C666848656549676542615D3D5E5A3C5D593B5B56
3958533656503856523755523353512D4F53264A551C405909305D0530720C35831C3789
2033861232850C307319244200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB4116C4D20352D2308132102153402153C02144006123C170C30
390B2549091A3403161A05270B0C4203105501146301196C02207502237C012482012688
02288C02278F022993012994022C98022F9D012FA2012EA40130A6012FA40031A50134A7
0439AD0338AE0135AB0136AD0137AF0239AE0238AD0338AB033BAF033BB50337B4022CA6
01249D02249D0028A0083FB00A49B00C4BA518539E2359973768994D799E5E819E69849A
79909F72899370888D6E84877186887086847089847288867C93908498978194938B9F9D
8A9E9C91A4A29DAFADA1B1B1B4C2C0BCC9C8CBD8D6D4DFE0DAE6E8E1EBEFE4EEF2E5EAF0
DFE4ECD4DBE5C6CED7BCBEC7B9B8BFA09BA296909691888F8780877D777D787276776F71
796F6F786E6B776E6A756C66776E68786E69796E6A7A706A7E71697E6F687E6F667F7168
7B6F65786D637A6D64786B60786B5E786A5D7268596F65556D65546D6558696156656355
5E6153595C4E5B5D53575B54555C56505C554B5C534C6057475D56435D573E5B543A5850
3D59513C59513B565038545039574F39585233544F3352502C4C54183B530A325D063475
0A3D8E0738871130650F911D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADD0B765526221D17061529011534021437030F33130727350A20
4509192F0315120321050B3E031358021767011A6F01207901237C02248003278703288A
002388062B93022894012691012892012996012A9A02299D01289A022C9D012FA00134A3
0135A60034A80135A90237AA0238AD033AAE023AAF0036AA0139AE023AB1043AAF0432A0
03298B0629811438842751913965984F779B61839B6A87956A858C778F93708688708487
74888B6F8687718786768B897A8F8D839894879D97889C969BAFA99FB0AEAAB9B8BDC9C9
CBD7D7D9E4E6DFEAEDE3EDF2DFE6ECDADDE4CCCDD6B9B8C3A7A7B295939F87858C837E82
7D777B7A74787972757A71717C716D7F6F6C806F6786736985736781706283715F836F5D
836C5A806B537B6A4F7D6C507D6D527D6D557668507B6D547D6D55806E577D6D557B6B54
7C6D567C6F57796A527B6C5376684C76654A76654A74634878674B7B694F7C6B52796C51
776B4F75684E7467507066506F67506D664F6B664D64644D5E634E565E4C505D4B485949
445847465A4D41574C3D544C39534B36534A3958503B5A5137554D2C4B47214249113852
0733610A3366172B490AC80B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007B55241F1A1307192C0116320411300E06212E07193F0917
2A04150F041F040B37031453041B68021E7402217C032582032583012383042687012284
03268B03279001269101258E01258E012691012693022695012697012898022C9B0333A1
0233A10132A20134A30135A60338AB023AAC023BAC033BA8053CA3063B98124291244C8B
3E5F8E547092607A91667E8B6981876E8588708688768A8A718684768B8A768C8B778E8C
7F9695809797899E9C98ACA99EAFACB4C4C1C9D8D4D7E2E0DCE6E7DBE6E9D4DEE2C4C8D0
B3B5BCA3A1AA8F8C94837F867D777B7A72757B70747C6F747E72737D716F7E7169817367
7D71627D74647E7462756C57796E5676695472654C73674B73674D72684C72684B74694E
6A5D42695D416960436A62446B6546676144635D406B654B6D674D6A634A6D68506F6B56
6A67536A675269655066624D6A674F6B674E66624966624A6761496C664D6A664C69654A
6762476A62486C644A666146696547686040665C39675D3B6860406661426160415F6145
5D61475A5D49535B484B59484557484153493B53493855483B5A4C314F4327483D214441
1E4248102F3B115B2000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF005F811A21180A0918230415290C0B222504163C0815260412
0D051E030B3100104602195E021E6E001F78012282012385012083022182011F7F022284
03268C03279100228B01238A01238901248A01248C01238E022491012793012B98022E9E
00309F0132A001349F0237A10339A0053B9A073B9017478E2C568D466B925C7C966E8796
748A916D81836D80816B7D7D748786758A88819696809595839594899B998E9FA097AAA9
ADC1C1C0D3D7D0E1E5D4E2E4D5DEE2C5CCD2ADB0B69A9BA087848A77757A737071726C6B
746B68786B67786A647D6F668073667B70607B705F7F71627E7261756C58706851746D57
6D6A526B6A536A684F6E6A506C694E68644C6A654A6A65496C684C6C674B6A6749686447
615D3E656043686445605D3E62604165614465624563614665624864604669674F666550
646651696A5565675267675665665466675266675163624E61634B5E604863664E61644E
62654F62634E5F604A5E61495F62475B593C5753325955315753305752315653305C5836
5D58375D583A5A583D575B43545C455057464C5A493F54433A5343344E402B493A27483B
244639254336139C1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047B21436230811191B070F1B1C0915380A152904110F061D
030C2D01113F011653031D69021F7501207D002183012285012083011F80011D7D021F81
01208602208B011E8A01208B01218900208701238802248B00238C022691012A96022D99
013299023596053A900C3F891B4886355E8D50739664829A6C869272878E75888B7B8D8E
7A8E8C758987758A8A7A8F8F7F9393879A9990A2A1A5B6B5B5C3C4C8D4D8C7D3D9BFCAD1
ADB8BE919BA17E848A74757B7471756E6969736C68716960766B5F766A5C776A57766952
7A6D5573674F6F654C70684D716C507570557A755B77705A746D576A664D67644A727056
6E6D546A6A4E69674B68644868654966654865644869654A6361446A65496B6649696547
646142666344666445646243626243605E41606042605F425E5D40615D43615F465F5E48
62614C6768536767556967576465526A6B5567674F63644E65685070745E696E59616552
6366525D604C5C5F4A5A5F485D6249605F485A5A3E59583B59583A595837575433575231
5753315651325250345153394D513852543F51563F4D58434555433E5241354E3D2D4A3A
26483525473430462F0CCD0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005A390D1F1A10130D12280810310914130516060E29
01113700154B051D64021D70011E7701217E01218101218402238503208200197B01187A
011A7F001A82001984011F8A03238D01218901228701238801268B022C8F032D8E043189
0B38821A467F305984537693678395708992788D92798C917D8F937B8D8E7E8F8F839694
8195928398948CA19F9BAFAFB4C6C8C4D3D6C7D2D5B5BEC29AA0A581858D6E70756A6769
6966626969606F6B60726A5E706456695C47665B3F675D3D6860406D64466B6044695E42
6B614471684D6F694E6B684C6868497171517976587670566A664C6F6E516E6E4F6E6D51
6E6A4F6863466763436661426966466867496766496561456764446B66496B6649696548
6965476663446665456463445F5F40646345646245615E415C593C645F465E5C435D5C41
5B5B4062604864624D69685461634D63664E62654C686B5361654D6265515E614F606453
696C5A5E62525D614E5A5F4B595E4A5B5F495D60495A5C445A5E425A5D3E575839565739
595A3D57593F5559414C543E464D374B513B494F37494F3848523D4554403D533D354E3A
2D4A382646322B46311DA31700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005F80153A250923100B2C0E121D0913090D1E031431
011540021D5B03206E011E74001E7702217C012180022284022183011C7F00197B00177A
031A7E021B80011D83012188002088012388012385032684042A80062E78123B75315682
56779363808F708A92788D90768A8A7A8F8F80939482939587999A8396948DA09C9CAEA9
B1C2BFBECECDBCCBCDAFBCC08F979E777C816A6D6D6666626A675F6B655A6E66576A604B
666046625F426663456A6447675F44685F41665E3D6A63406E69486C67496A6347655C41
665F436C664C6B694D6E6B506C6C4D6C6C4C6F70506C6A4E6C6C506B6D4E6A6C4C6D6C51
6C664D6B644768624167613E64603F666345605F40656143656343676244696447656145
666245676244656342626143656445656346666248615C42635F43615C445C5C405D5D3F
5C5C3D605F4163624665654B63654B61644960634A61644B62674E686A566B6D5B656756
646755636755646856676D5A5A614D5B604A5B5F48595D44555C41575D4153593C555B3F
565B40575C42535B434D59444451404A5645404D3B323C2938432D424F3641523840523B
3A513B324B362E483335422B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DC0B5C360935160526100F110F19051428001636
021B4E02216701217302227A03247E02227E032381011F81011D80021F84011C7F011B7C
001C7E021F82011F820020840021840226830226760A2D6E244675496987648290708890
7387898196937E93907C908F809591899D998FA09F95A4A4A6B6B6BCCBCAC0CDCDAEB8BA
909799787E80696B6B6867656A65616D685E6F6959706A53736A4F70664B6E664A696246
6C674B6F6D506F6D516D6A4F716C51746D526F6A4E6D684B6F6C516F6C536D6A516D6750
6A654D6E6A51706D536E6A506E6D4F6C6D4E6B6E516A6B526C6E526A6B4F636546666347
69634868614468614067603C65603D615D3D5E5B3C605C3F615F3F615C3C635E40645D40
656043656142666344636242626241615D40605F43605F436160445F5E425E5E3F5F5E40
60604160604063634461604563644961604962624C5F614A60624A656550656753636451
61655060654F5E634C5D644C596149586048585E465B5F495A5F49565D46565D44555B42
545A3F565A42535B42505E494856474353472C40322639292C3C2838462F425038434F37
4350383C4E38344B363447311B9D1100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0045AB0E4B220223110B0E162101152D001840
03205C02226C01207301227B022580022381011E7E011C7D021E82021E84021E82031D80
011D8000208101227F03257B0428721539733A5A815E7A90748B977F95977E93927D9190
8899968A9E998A9F9B8B9E9C98A9A8ADBCBBBBC8C9AEB9BF98A0A7787D82696A6C646362
67656174716A7772687972657A73647B75657A75647874617B7662797460797662777560
76756072735D75755F74725E73715C76715B75715B72705A74755E70705C747160757462
7475617576626F6F5B6E6F587071576E70556C6F566F705B6C6C5567674D636446656346
666144666143666140655F3C655E3A63603D605C3E625D405F5C3E605C3D605A3B615A3D
645E41635F42615F405E5E3C5B5D3860603C5F603E5D60415C5F406060445F5E40605F40
5E5D3F5F5F416060435F5F465E5F485F604B65675164675060634D62614C5D5F465C6046
6368505C634C5D654C5C644B59624959624A5A614A595E485B5F4B5A5C4A555844555944
54574251563F4E573F55655047584933453923392C273E2D32473340503D45533F4D5843
49533B454F373D4E3734452F1EA21500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074451429170B0D1824011837001B4C
03216201226D022273012279032580012482022180001E7E032184032186011C80011C7E
001E7C03247904286E183C6E456683708B997E93978293948B9C9C8CA19E8BA09D90A4A1
91A3A19DADABA6B7B8A9B8B9A3AFB1899192717276605F6262605F66635C6A675B716D5D
726F607C7B7081817794938AABA8A0A5A19C9E9C999C9B9693918B93928A8B8D83818479
8084778185767E80717D7D6E7B7B697A786478776273755F70745D6C6D5B6F6D606D6D60
6C715F6E73646C72616C72606E74607476627175626F73617075626B705C686B5465664F
63644C626349636448615F425F5E3D5D5B3E615F42605D405E5C3E5E5C3E5F5D3F605D40
625F415F5F415C5F405D6041585C3C5A5D395D603D585B3C585B3F5C5C415E5E415E5C3F
5E5B3F5D5C415D5D435D5E485B5E485A5E4A5C604C6165516165505D60485B5F44585D3F
595F445961495B644B626752646A555D624D5B604A585E475A5D48575945585B47545845
4E523D4D533E4D59455061503E50412C40322A3F313349373E533E4959474E5E4D4D5D4C
505D474D563E464F373C49303C442400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003BA40B321D0B111C2A031B41021E56
022165022471012375012379032681042887032887022586012486032586012081032178
06276C1F3D6F4D6988718B98819697869592909D9996A2A19AA8A791A1A19CAEACA1B3B0
AFBEBE99A4A87F878A696F6D5E605A5F5D53665E51675D4E746E5D868674999A8BAEAFA3
BEBEB8CFD0D0D0D1D6E1E1E8F4F0F9EBE4EFD6D0DCCDC9D7BEBCC6B8B6BEACACB09EA09F
989C9693958C9091879494889294858F8E808E8E7E8C8F7C8B8E7A898B7B868578828375
7F81727A7D6E7178676C75646A74636C71616971606A72626A75646671636A74656A7465
697363657160606B5A5B64506067515B624D5E654F60654E5F654B5D624A5B614A596049
586047576149556148545D47515B4350593D565C41585B43585C46575C46565C455B5F48
595C46575A46575C495A604E585F4D57604F5761515760515B63515C644F60664F60654E
5B624A5E66505D654F5B64505B634E5C624D5E624C5A60495D634D585E49535C454F5642
4B523C5058465B685946564B2D42352C4335344A3A3E5241495C494E5F4E5163544D6254
5668565E68544E533B434B3140462200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA1B3C2407131B26041B43031E59
012168052A7C01247A00237A002581032C8D022A8E00258601248401237E01216E15336B
4560806D82908090948D9C9C93A19F9BA6A49AA5A497A2A3A5B1B3A3ADB0A1ACAD798586
676F6D5F605C615E5469635168624B6E644D786D537F765D85816A7777647374657D7C73
86848189898A949298B2B0B9C5BECCC8C0CFB3ADBBA29EAA9A97A296949B908D90888784
88898187887F87887D8384778083717E8172797B6C777A6A7579687375677175676F7365
7377697175676D7465737C6C7782727782736C78696974666A796B6C7C71697B7066776C
64756A6172695B6E66566A5E55685955665957665855655659685957665852625456675A
5264575263565467595463574F5F505261515362515260515260524F5E514C5C4E4E5E50
4C5D4E4A574D4E5A5157645D57665C5B6A615A6B625B6A605F6D5F5D6858626959686C5D
6C71616F7665687461636E5D636D5B646A596369575D64505B634E565F4B4F59444E5642
4D55415B665748594E33463D2F473A3049393D5643465D4B4F625053645554655950645A
5C7064606F5E535B44474D3134761D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005D3E121E1E1E051B3B031F56
00226909368B002A86012682022A8A043195022C900126830325770D2D6B3450765D7485
74858B818F90919E9D96A3A28E9D9D91A0A199A8AA8F9D9E7F8A8A646B69595D57585B50
6463526C67516E664D6E64496F664A6B61456960426961436E684B706B4E736D54726A55
6A64526B66566B6557706A61726C6877716E746D68736D68716D646F6C616E6B5E6C6A5C
6B6B5B6C6C5B6A6A586E705B6A6E556B6E586B6D59696C596B6F5D6D72626A72646B7669
6D7A6C6F7C6E727E7274817473827673857B75877D6F81795F776E59726B577269566F69
536B664C646147625E45615B3F5C54415C55415A53405751445B54425951405752435A57
4058553E55523E57523E58533A554E3B554D3C554C3D544C3E544E3F544D44575042574D
40564A3F534C3E52503B515038514F405854425A53455A504A5B4D4F5C4E565F52595F52
5D62525D63545C65545E69596671616A74646870605A645358625055604C4D57444C5644
5661514E5D52364A40374C413E56463F5742405743506555596B5D5A695D56675957695F
5D70665F6E6158614C4A4F3424A41300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7F182C22110A1B32021E51
002168093B9403389901309103349602349605328A04297021406E4C637B6B7E847A8988
84918D828E8C8F9B98909C9A909D9D8390916E797959625C585B4E62604C6A664E726F55
6F6E526E6B4F6F6A50706A5170674D6D65496E65467268486B63406B633F685F3F6C6245
6D63456D634572674B766951716550796D597C6F5C7A6E5B79705A776F59757058716E58
726E58746F586E6A516C6B506A6B506C6E566B6E586A6E5B656D5C656E6166736864736A
5F736A61766D5D726D59716C56706D4E696549636043605D32544F2546421E423C1C3B37
1C3A3717363316373413322F11312E11312E14322D14302C13302C12302B142F2D15312F
132E2E102D2C0F2D2B10302F1033301D3E3B213E3B28423D31453E3A48413E4D433A493C
3A4D3E35493E28413B1D3A381C3A3925443F334F473F574A485B4A4F5C4D55605361695B
606958616959616B5A667160636F5E687262656F5F5B645456615054614E4B5A47576658
4A5A4F384C42394F4341574A485F4E5166544F62515B6B605E6C625B685E5B6B5F58695D
5C6C625E6A5E5B624C53533313D10900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0027DB0D5237121C222B031D48
01266B053A94033EA4023CA2063C9F03358C0B32722D4B6C5568756E797D778180808C87
838E8A808B8A828E8C76827E626B645B60555D5D4E68634E73694E796E51746C506D684D
69684C6D6C4F6D6A4F6C674E70694F716A4D736B4E746C4E716A4A6F68456F66436F6241
7365417769447B6C497E6C4C7E6F4F80715184735685745985775C86785E83795D80785C
837B61847B627F785F79775F7B7C6471745F6F735F7179686C786B6470685869624D605F
3C53522E4948213E3E1938380F302E102F2C17373124443E2F504A3D5B564D6B65607B75
5C7572506B67486460405C564560583B554E3C554D3A514C394F4A344C44334B42324942
2F483F2C453E2C463F27423C24413C223E391F3A35253E38293E35314137364539374738
3243332B3F3020392E17322C0C28241230292D493F3E54464B5D4C566354677265636E60
5965565A65565D6556595F4D5D644F5D63525C62515B6151545F4D4E5F4F4C615344574E
3C524841594C4860524E645753675A5B6D606170655F6C635C6A60606F655E6F6459695D
5D6C5F616C5B5E6348417F2300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0068891F3D31220D1E3D
052D6E09449E0343AC023EA40637910F34723148654F5D62646A697377747A808077807E
757E7C6E76745E675F565C4F5B5C486B664C71684A6D64436D634373684C70674F67634B
6E6B526C694D6865496E6A4F6F6B4E716B4C6D6748716A4C72674A7569497C6F4E7B6C4A
7A6B4677694278694578684775664472644073654377674A75664A83755A7A6E54796F55
7269517169546A6753686A56696C5A6A6E616972646875676979705264612A413F122D2C
0725230A2A251A3A33314F49536E6672897F8FA49CA5B8B2BBCBC7CDDBD8C3D2CEB5C2BE
A3AEAC8A95947A89836A796E6E7A6C646D5F646E615D655960665B62665A5D6457586050
5965525864555B675A5762585160554F5E524F5E534D5E504D5D4F515C4F4D584C505B4E
535D4E4B5948425443415243364A3C2B4337253E2F2D41324C5D4D6673645D695C5C685C
5965575A65565D63515D604B60634D5C604D5C614F595E4F5560544E5F56445852455A54
4A605750675C586E625F726764756A67756B66736A62716861726760716660726759695D
606E605E66525F603F2DA91400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0E6A4C2226272F
0625590B459A0546AA053D94103670364962545D5F575A53696A6472736D737572676B67
5D61595758495C5A43676346726A4A776B4B7265476B62426E67496F684B6A6348706A51
6E69506762496B66496F6B4D6C684A6D6949706946716543716442786B4B77694B756646
74654273653F72654073654271634070633F6F603D6D5E3D7061416D5F4174664C756A50
7269526D68556265535E655561675A626B625B6B64475A562C4441112A290C2A2524433D
4261596C897F99B3A6BACEC6D2E1DDECF4F2F6F9FDEBECF3DADAE3CBC7CDB0AAA99F968F
8F8378857769796E5C736A53766C51776B507A6C51796B4F77684D806B537C6A4F79694C
7C6F508072597D705B796E5C776D5B746B59726A55706951776E547D7055786C52796D54
73684F71694F6562485C5C43595F48535E4B485746394838384938536050606B5C5F685A
5C65535D655061654F61634E6164505D6152576052545F554D5D544A5D574E625C536662
5C6E6761736B6779716A7A7061716768766E66756D67777164756E63746C637369616F63
636E5E65664E655C3430A70C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B318503C28
17284615468C094091133A7332445B4E54545B5E5461635667695E686A605D5F545B5B4B
5D5A426862426C653F7066426F654375694B7267496961436A65486D694B686346726C4F
6F684C6661446E6A4C706C4D6D694A6D67467065416E613B6D613B6A63406761426F6546
7064416E623D6E613C74664271623E70623B71643D72653F7265406C5F3D7265476F6449
6B644B66644E666857646A5B626A5F4D5D582239360A26220A292522403B58756B86A099
9EB5B1ACBFBCB0BFBEA6B1B2A4A8AC9F9BA09A919691868A8F82828D7B778D7B6F8D7A66
8D785E887255816B4A7C68457C68427E6842806B437F6A41826C42876B448568408E7145
91764A90744D89724F897254856E52866F538672538B7452957E59937B58927D5E917D60
8875598272537E6F51756A4D6D674A67634A63654E5B63504E5B4A4954455E6455636656
61644F61654E6367516266545B62565C675E56655E526460536863586F685A6F6862746F
6C7B77707E7C70817B6F807764756D6C7C766D7C766B7B7668777168756F65736B636D63
6669586B63446D582546B71500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00855E2D
342F3226426F183968314256494D4A535449585C4C6063515E604F595B49595943625E42
6D64436C5F3A6B5E376E66416A62426C634473694A6D674966624469684A6E6C4F6B674B
6F6A4D6A6547676243746F4F6E694A6F67476E633F6E613A6C623B6A65406A65456D674A
6C66486E674971694A7065446D623E6D643E6A60387168407269437169486E6949696446
6A654A686750626554535B4F36443C0B221E0C2B242B4B424E6C647B948E8EA19D919E99
89908E7B7E7C70716C716E67716C6579736B837F748D897B9D96849C93818A82706D6450
6A644A7A745A7C765D736F55635E435E593E5B573A5E5A3867603976663F79653C7A6439
76613578643B7868437B6A4A7866477666476E63446C61436A6145665D4765604D656351
60604D5E5D4966634D6C69507570536A6346686449666852696F5E5A6051626556626350
6568526067525C66545F6B615C6C665E726F5D73716A7D7C697D7B6E847E687B7571817E
78878575848471827F70837C71857D71838072837F6E7D786E7B766A756F67706864685A
686148705B2D68902000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE10
583D1F404147323A3F46463D5251405959465D5E495B5F455A5D415C5C3E5C5A3A615C39
63593267592F675B3069613A68623D6C634074684872694B6C67486763476A674E706D54
6D684C6C66476E68466D68466F694A6E65457367447266417367416E6440736A47726949
73694B736A4C72694C6C64466862446A66456A643F6B623B7069446D6846686442666141
6D684B65654E444C3B2C392E50615A4159533452484F6B5F697C73757E78747871737368
7571647C75677F77657D746065634E797D6A989E8FB1B7ABB8BCAE9D9D8F8A8879777767
7174657A8075687068505D5545554A3B4E413548373B4B35434B2F615F40756C4A776946
73633E726441736849736C516C6A516567505C624E555D4B545F4F525C4F535E51556256
5663555C685A555C4C5A5D477B7961726D54706C536D6A5671715F686C5B656956626856
5F69575E6C5E68786D6B7D787185827389877087847D908E7F93917D928E778C877D8F8D
7C8C8A7B8B89768A85768C86758B857487867182816E7E7B6C7A74656E6764695C67644A
6F5C30678F2000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
5C7F1A473419473E2750492F5A553B5F5C445E5B415C5C3D5E603D5D5D3A4D4E2B534F2A
615529635424635627645A2C635A2D645A2E6B5D356E603A706440736A4A6F6A4F6B674E
676449635D3D665E3C6A63406C65426E65436F6543716745756946726643746844776944
7568437668457567477264456D62436B60416F63416D613C6C613C615833655C37766D4A
70694B6060473D473668746ABBC8C3606E6C57685F5362565F685B6C6B5B74705C74715C
73725D77756073725D71705C6D715B7077637D81728183768385788687798182746D7265
5B675E4758553C4F4F2C44441C39351938311A3A2C2F483648563F67684C766E507D6F4F
746948736C4F7C7A636F7462636D5F5A6A5D55675A56675C57675C5D6B615F6E615F6F62
59695B505C4B5A604B706D5775705A75705C74715E7471606F7061656A5B656F5D667366
72847A7A8E897D908D8092918092927F90917C8F8F869897869998859A98819794859796
8192918496938195927D9390778D87748785768585707C7B68736E60665A6360456C5D2F
66912200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59780D5337115544255A4F3062593C635C3E635D3F5A57395455385257384A4F2F504F29
6158296657256959276859286759286357246B5B2B6D5C2F6F5F3572643D716844706A4A
6F6A4C6965456965426C67436D67466F68476C67466A65436B62416F63406D603C6D5F36
6E5F3471623874643C7968427D6C467B694276633B76653B73663973663878693F7D6E4A
746A49636144444834898F82979C9660625C65685A6066567177667573607A7661767561
707361727968656E606672666B78696570626C7467687064646F6558655E43524D334641
1F3633142D2C08252402201E0929231C3B32415C51596B5D646C5776715672664973684B
6F6C527A7E6C7982756C7B7063776E647970657B70697A7069786E68756B627064506053
4A5A4B5F68546D705974725C75735E7776647475666F74676D766B79857B8B988E859591
8C9F9D99ABAB9AAAAA95A4A492A1A38897998696968B9A9A8494938093928B9F9D90A0A1
8A9B9B8999988294947E9290788985788984717F7B6E77736B6D63686247756132997734
29DE0C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6A40045A40155D4C2A6657376A5C3D6B5F41565436333A1F303E26414F374D563C515536
57542C5D54246456266B5B2C66572766572565552669592C6B5A2F6D5D326D603670663E
746B457069466E6A466E69486E694B706A4E746E53777154716B4C6A62416A5F3B6D5E38
69593167592E6C5E326E60346C5D336F5E346E5C306E5E2E6B5E2D6A5F2E6F623572633D
72664365603E5B573B6F69527C766167604B6C69517479656C7262777663797462787563
6E736541504828403C1E3C371C3A341B353018302A162F28112C270E2825223938384C4A
3D514F3E5353425B595169635D7368576A5D5D6B5D676F5F71725F746F557771567B7A63
7A816F7B877B7C8A8272857C687E755F776E50685F4D6258526158536159536056556253
5F6858747765787A65797C697A7F6E8085778A93879CA79E9FADA5A6B3AFABB7B5A5B1B3
A3AFB1ACB8B9ABB6B8A2AEB0A2B0B19BA9A99AAAAA9AA8A99EABAB99A7A795A4A494A3A6
909F9F8A9A9A8798988291917E8C8877847E6C756C6F70616B5F427F643077992600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB40F
613D04604B1C6758306B5B396D5E3F564F33343A22223420203724293F2D455543515B47
595D415654305D552C5F552961562A5F562863592E675B326A5C346C5E37695D35695F36
6E633C7067416D6641706B49736D4F726C51746E55706B517670567973567B75577C7357
786D4F7167466A623D6C653F6E633D70633E6E61396E61376C61356C65396D663F6C6441
726A4A6F69476F65416F5F3B71603A6C613C726F516E725C767A67807E6B7E7A657E7D6A
4C5548283E38203D3A1738341638331B3B3723423D36554C506D6592ABA8DAEBEBF1FAFB
F0F6FBC8D0D798A1A4848D84767C6E6C715E74766171715D6767556D715E7077656B7869
697A6C6D7D7473807A707F796F817B6E847D667D7760746D627069646F676A7466757C69
787E697A7F6D898F7E9EA699AEB7ACBFC8C2BFC9C4BFC9C4BEC8C5BBC5C5C2CDD0BAC4C7
B6BFC2B4BDC1B0BABCADB7BAADB8BAA7B4B5ACB9BBA9B5B7ABB6B7A6B4B49CAAAA97A5A6
8F9C9D8B9A9C8B999A818C8D7B838073786E6C6955766440916F362ADF0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0044AD07
6443096955246C5C316D5D395E563740432B2F3D2A273E2B223B2A233B2C2D4334415244
535F4D555D45595B3B5E5C3965633F6865426561406862436A644469624168613F67603D
6C63406B63416C66456E6A49706A4D746D53756E54746E53746E516F6A4C746D50736D51
746D52736B50736A4F787154777254777052726B4A726C48726C48746F4D747151757156
7B765C797357776A4971603B7460356E5F326F6946706E557B7A64807C667F7A647E7D69
636A585A68595564565A695C5767595A685C5F6B5E6B76687D877A929992A4A3A4B0A9AF
A59EA4948E92827E797E7968817C617972557B785B62644E4B55444B5848505F52607066
819288C7D2CFE3E9EBDEE5E7BCC4C899A4A67E8985777F767C827680867A888E7E999F8C
B6BCA9CBD2C4D7DFD7D6DDDAD6DDDCD4DBDCD0D7D9C8CFD0C4CDCCC4CBCEC1C8CBC2C9CD
BEC6C8C3CBCDC5CED0C0C9CBBBC5C7B0BABDB0B9BEACB5BBAEBABBA5B2B39CACAB95A3A5
909D9E899799869293787D78716F60726448856B3C779A2D2BDF0E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042AA04
705011705B29705F31675C374A4B313947343247352F46342B43312A42312B42342F4437
3A4D3E4D5C4957624B5B60485D614761644964654B64644B65654B67674B6A684C6A684B
6C684B6D684C6F6A4E716C50736D53746D55716B52726C51736D4F726B4A6D6544716647
74674A746749726649746C4F726C4F726D50716E4F737250757252737050757154726E54
756E57756C547A6D507A6B4979683E7261356D6037706645756C507A72587F765F807962
7F7A608A8468948B6C988A6B94866798896C9C8C70A291749B896C99846C967F6C917B6D
8E7D6E8A7D6C8B806B83765A7F704E7C6D4A8880636B6D5757614E5B67555F68556E705F
807F709E9890ADA5A39D98998D8A8B898784908E87A7A49AC4C5BBD5D8CFEAEFE4F5FAF0
F4F8F1EDF2EEE7EBECE3E7E9DDE1E4D6DBDFD1D6DACCD1D4CFD5D5CED2D4D7DADCDEE3E4
D8DFE0D8E0E2D5DEE0C7D1D4BFC9CCB7C0C5AEB8BCA9B3B7A9B4B6A3B0B29AA9A995A2A6
8A9798818B89787B717067507E683E9D793E2BE01000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0045AD06
775614755F2B6E6032565331444E383E52413B5341354C3B344B3A364D3C324839324738
3246343A4B384754425862505C6551606651616550626551626551666A5466674F6A6950
6D6A506D68506D68516D68516E695275715C736F5A74715A736F54736E506D6849726B4D
756C50786E51766E50746F50716D4F7975587775587A795C79785B7E7C607B785E7A7860
7C79617B735C7E745B82755A8679598074517F724F7C714F78704D766F5079715581765A
7C72518174508978508A754C87734987714A85704A826C44826C448269427D66417C6847
7D7152827A5E7D785B7D7354776A45766842756B496E694D6B6D5374775D8280639A8F72
A6987CA59782AFA496BFB8AED4CFC7ECEAE3F8F6F0FFFEFAFFFFFCFFFFFCFBFDF8F7F8F6
F7F9F8EFF0F2EDEFF1E6E8EBE5E9EDE6EBEFE1E7EAE0E6E9E1E7EBE6EBEFDFE4E8E4E9EC
D8E0E2D5DCDFCED5DBC0C9D0BEC8CDB5C0C3ACB8B9A9B4B6A3B0B1A1ADAF9AA3A5899190
7E827A756F5B7C694494743D54C01F00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CB40B
7D5B17725F2962593053573D4654433C53423C56443D554642574A4055473D52453A503F
384D3940523D41513D43503E4E5847575D4C5B5F4F5C61515D6353616555656855666852
6F70596C6B556B6C556E6F586C6E5771715B71705B74735E75745D75725A78755D73725B
78755D79745D74735971715675745C79766078765E78785F76765F7878637C7D687E7F6A
7E7F6B7979647B78627D78617D7961827E6588846A89856B88876B8A896F89876B898569
8C88698C8968908C6B938F6D9793719994749992739990719C94749E95769C96779A967A
9F9E849FA088A3A58DA1A2879F9E81A19F829F9E839B9B819C9D85A4A48DB5B39CCFCAB4
EAE3D0F8F3E5FEFBF3FFFFF8FFFEFAFEFDFBFEFEFDFEFFFFFEFEFEFEFEFCFEFEFCFCFCFC
FCFDFDFBFCFEF5F6F9F2F2F8E9ECF3E2E8F0D9E0E5D2DCE1D0DBE2D1DBE3D3DBE4D1D9E0
CCD4DACAD3D7C5CED3B8C2C8B7C2C6B2BDBFA8B6B6A4AFB0A1ADAD9AA09E898880796E5B
7E6A4498773E52BE1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA11
845F1B725E295D58324F57404A5A4B4056483C5647415B4D475F52465D50455C4F445D4B
4059434458444657444856444F5947525845565947545A47525C48535C4A58604E5B6352
696F5E7278647178646D77636B746070736071716073736071735F70725E6D715D6C705C
7374617878667E806C7F826D797C677777637475607778627374607274647B7F6F7E8270
7D826E7478637679647B7E687F816C8689758D917C8F927F8D907D868A78868A738C8F78
8F957D949B82939A83979D8897A18B9BA18DA0A391A3A593A4A793A8AB98ABAF9CB5BAA9
B9BEAFB9BEB2BAC0B3BCC2B4C2C7BAD1D4C9D9DED1E4E9DDF1F5EBF9FBF3FEFFF8FEFEFA
FEFEFAFEFEFDFEFEFCFDFDFCFEFEFDFDFDFDFEFEFEFDFEFDFDFEFEFEFEFFFDFEFEFCFDFE
F6F7FAEEEFF5E2E5EBDDE0E7D1D7DFD0D7E0D1DAE1CCD6DFCCD9E1C8D4DDCDD6E0C7D0D8
C6CFD3BFCACEBBC7CAB7C3C6B4BFC3ACB7B9A4B0B09EA7A38C8C817F735C856C45729831
2ADF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C621B775F2A5A542F49523B4D5F4F495E52425B4E3F594D465F534C65594E655A506858
516955526654516051546051555F4D59604B595F48565E47525C464F5947505B4B535F51
596557606C5D636E61697569707D706E786B6D73656D71646F75656E7767717B6A737D6B
71796872796A747B6C757B6B747867757866787C687B806D8388787E83767D84767C8472
7E87747D87737E86737F8775868E7C89907F8A92819196889196898F95878D9482939C89
97A39097A49195A38F9DA9989CA998A4AC9EA9AFA4B2B5ABC3C7BDD4D7CFDEE1D8E5E7E0
EAEDE6ECEFECF2F5F2F8FBF6FCFDFAFEFFFBFDFEFCFDFEFDFEFFFDFEFEFDFDFEFDFEFEFE
FDFDFCFDFDFEFEFEFDFEFEFEFEFEFFFEFEFEFCFDFFFBFDFEF5F8FAECF1F5E4EAEDE2E7EA
DBE0E6D6DBE2D1D7DED4D9E1D3DAE1D2DBE2D2DCE2CCD6DDC7D3DAC5D0D8C9D3DAC4CDD2
C0CCCEBAC5C8B7C5C6B4C0C2B2BCBDA1A3A188867A7B6F578A7146789D342BE01000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6E8D147A5E235F552D454C33495A484961514B6658466053475F544C625951675D586F63
5D73666275685F6E63616E63636F6165705E626B57606A555D6753576150556250546252
536052525F5354605755625956675C5B6B61606D6265706768756A6473676A786C6D7A6D
6F7C707581767582777886787784747C88787E8A7A7C887A7A867B839086849186889488
8392848493848998898B9A8A8C9B8A899786909C8C959E91939C8F99A2949EA798A4AD9F
A7B2A3B0BBAEBBC6B9CCD6CBD7DFD4E4E8E1F1F4EEF8FAF5FDFEFBFDFEFDFEFFFCFDFEFD
FEFEFDFEFEFEFEFFFEFEFDFDFEFEFDFDFDFDFDFDFCFDFDFDFDFEFEFDFDFEFDFEFEFEFEFE
FEFFFEFEFEFFFCFDFEF8F8FBF6F7FBEDEEF3E2E6EBD7DEE4D6DFE4D2DDE3D2DCE1D2DCE0
D1DADFD5DEE4D5DFE4D1DBE1D0D9DFD0DAE0CBD7DCCAD5D9C8D3D6C5D0D5C4CFD3C4CED0
C0CACDBEC6C7B2B8B79D9F998A8373857353957A497BA1332BE00F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DC0987621E6C5B2A4B4D2C4E5C47495E4F486251526B5D51685C52675D556B62536B61
576D6262766C68797168786E6C7B706E7A6C6C7867697564667260626F5E5E6E5C5D6D5C
616E5F5E6B5C5C685C5A695E5D6E635F6F655E6C635F6D6461726A5D6E655B6D6365786F
697C756A7B77697B766A7D7670847A73887D768980778A8281938D80918E84959080928C
83978F889C938FA49998AB9F9EB1A2AEBFB0B7C5B7C4CFC4D3DCD2E2E8E0EFF4ECF4F7F1
F8FDF6FCFFF9FCFFFBFDFEFCFEFFFDFEFEFDFEFDFDFEFEFDFEFEFCFEFDFDFDFDFCFDFEFD
FDFDFDFDFEFDFEFEFEFEFDFDFEFEFEFEFEFEFDFEFFFDFEFEFDFFFEFCFEFEFBFBFDF5F7F9
EEF1F5E9EDF0E0E4E8DDE0E7DDE2E9DADFE5D5DCE1CFD8DDD0DBDFD3DFE4D4E0E4D5DFE2
D2DCE0CED8DECAD6DCCBD7DCCAD5D9C4CFD2C7D3D6C0CDCFC3CFD2C4CFD1C0CACCC0C4C7
ADABA8988F858B786192785279A03C57C32400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007492187D601F5E55284950364D5D4D485E50506759536A5D586D63576D655A7169
5C72695F756B60746A67796E6E7E73748075738172717F6F707D6D707E6E6C7C6C6F7E6F
6C7A6C6C7B6C6C796D6E7B706E7E756C7D7472817973827A798981788B83748982788D88
859895869896849695879A988AA19D8BA39F97ADAA96AAA69DB1AF9FB1B2ACBEBFA7BBBA
AFC3C1BACDC9CADED8CDE1DAD3E5DCE1EEE7E7F2EBF2FAF4FBFFFCFDFFFDFEFEFDFEFEFE
FDFEFCFDFEFDFEFEFDFEFEFEFEFEFEFEFEFEFEFDFDFEFEFEFDFDFCFEFDFEFEFEFEFEFEFE
FEFEFEFEFEFEFDFEFEFEFFFFFDFEFFF9FBFCF3F8FAEEF3F5E9EFF0E4EAEDE0E4E8DDE2E6
DEE4E8DAE1E5DAE2E6D8DDE2D9DFE5DEE4EAD4DBE0D6DFE1D4DEE1CFDADECDD7DACED6DA
CDD6DACCD5D9C8D4D8C5D2D3C8D3D5C4CFD0C8D1D3C4CCCFC2C8C9B6B6B4999086917E6A
977A59A7835357C2292DE11100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006D8F15745B205954304E5843475A4C4C6355536A5D5B70655E736A5D726A
60746C60736C64776D65776C68796E68786E6F7E75707E7472807573807478867A77867A
73827874837978877D76867E77898171847D7F928B84938D7F8E898697928DA19F91A3A2
8B9E9D95A7A695A6A592A6A4A1B6B5A6B9BAA7B9BAAABBBBBAC9CAACBDBFB2C5C7B7CACC
C5D7D8C2D2D2D4E4E4D8E7E7DDEBEBE7F0F1EAF0F0F5F9F9FDFFFEFEFFFFFEFEFEFDFDFC
FDFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFDFDFDFEFEFEFDFEFEFDFEFFFDFDFEFEFEFF
FBFBFCF8F9FAF2F6F7EDF0F2E7EDEEE2E7E9DCE4E6DEE5E8DBE4E5DFE9EADCE5E7D7E0E2
E2EAECE2EAEEE1E9EDE3E8EDE4E8EDDCE1E8D2D9DFCDD6D9CED8DACDD7DACBD5D7CBD4D8
C6D0D2C6CFD2C9D3D5C8D2D4C9D1D2CACCCAB8B4ADA1968A94816C9A7E5CA7805156C027
2EE11200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006C8D167259225C583648553D4A5F4E53685B5A6E635F726961736A
66776F66766F6979736F80776C7E756C7F786E807972827A73827972807872827874857B
73867D74867F7A8B847B8D867F938D819590879B978699968DA09C8FA3A095A6A598A9AA
9AADAF9DB1B1A4B8B6A4B8B6B3C4C4B2C1C3B5C5C8B4C3C7C3D2D4C2D4D4C3D5D6C7D8D9
CDDCDED2E0E0D2DFDFDBE6E7E2EBECEBF0F2F3F7F6FCFDFEFFFEFFFFFEFEFEFFFEFDFEFD
FDFFFDFEFEFEFDFEFFFDFDFEFBFDFEF9FAFBF9FBFCF6F8F9F2F6F5EFF2F4ECEFF1EAEEF0
E7EBEDE9EEF0E6EBEBE9EFF0E3ECEBE1E9EAE0E8E9E3E8EBE4EDEDE2ECECDFEAEADFE9EA
DCE3E6D5DCE2D5DEE3D7DEE3D5D9DED5D9E0CCD4D9C9D2D7C9D3D6CCD4D8C9D2D4C9CFD3
CED4D7CED1D3C6C5C4AFABA39A8F7D9882659F80587DA13F5AC42A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CB61381632A655B3354583D515E4C596A5D61726866776E
68797066766E6B7B746C7E746C81766B807873857E76868077857F7887827B8C85798C83
7D908981928E80928E829691899D9A889C9A8CA09F91A5A38DA29F95A9A699ABA99FB1B2
9CAEB0A9BBBBB0C1C2AEBEBFB8C6C7B9C6C7C0CDD1C4D3D7C8D9DAD0DFDED3E0E0E4EEEE
EAF1F2EDF4F5F1F7F7F3F9F8F9FDFCFCFFFEFAFDFDFAFCFDF9FBFBF8FAFBF4F7F8F3F6F7
EEF1F1F0F3F3EEF2F3EBEEF0EAEFF1E7ECEDEBF0F0ECF2F2E8EFEFE6EDEFE8EEF0EDF2F3
EDF3F3EEF4F7EBF2F2EBF2F4E4EEEDE5EEEDE4EDECE0E5E8DBE3E5DAE4E6D7E3E3D6DFE1
D6DEE0D0D9DDCFD9DBD1D9DBD3D8DCCFD4DACDD3D8D3D9DDD2D8DBD2D5D8C6C6C6B1ACA5
A194879B86719D8061A8855983A73E2DE21400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DE0D698D1F78612E68623D5D644B5E6A59637367
6B7C71667970687A716F81766D81766E837974837D7A85807E8A847A89837A8C8780938E
8596928A9A968C9E9B8DA19E95A8A696A9A897A9A99AADAEA1B3B4ADBEBDABBDBBADC0BF
BBCCCCC2D1D2C3D1D3C1D0D2C2D1D1CBDADBD7E5E7DBE9EAE5F1F1F0F9F9F7FDFCFBFFFE
FCFEFDFCFDFDF6F9F9F3F6F6F4F7F7F4F5F7EDF1F2F0F4F6E9F0EFEEF4F5EDF2F3ECF0F2
EBEFF0EFF3F4F2F9F8EEF5F5E9F1F0EAF1F1EFF7F5EEF6F6ECF5F3E9F1F2E9F2F1ECF3F4
EBF0F2E7EFF1E3ECEDDFE8E9E0EAEBDEE8E8DAE4E3DAE2E2D5DDDED5DFE0D3DFDFD2DADC
D0D9DAD0D9DBD4DDDCD4D9D9DBDCDFD7D5DAC8C5C5B6ADA6A9998A9C87709C8362A7865B
80A23E59C32900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0027DC0B658E207A65336D6340696951
666F5D6573656C7B7072817573827873857B7988827A867F7C88827987807D8C887D8E8C
869693859692869996889C9B8FA2A18FA1A295A7A898A9ACA0B2B4A9BABBB5C4C4AFBEBE
C0D0CFC4D3D2C5D3D6C7D5D8CCDDDED0E0E1DBEAECDCE9EAE7F2F3F2F8FBF3F8F8F6FBFA
F4F9F9F2F7F7F2F7F8F4F9F9F3F7F8F6F8FAF6FAFBF6FAFBF0F7F6F1F7F7F1F7F7F1F6F7
F4F9F9EBF0F1F1F7F9EEF6F5E9F2F1E8F1F0E8F1F0E6EFEEE6F0EDE8F1F0E4EDECE5EDEF
E4EAEDE1EAEBD9E5E6DCE6E7DAE3E4DAE3E3D7E1DFD7E0DED8E1DFD6DDDCD6DEDCDCE1E0
D8D9D9CFD0CBC7C2B9B8AC9CAB9785A28771A18364AB875B5AC7305BC42800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADF0E47B618866931
7561366B63416D6D536B715D707A6B7380747484797988807B89827F8B867A888480908D
8395928295928499968398978EA3A28FA2A490A2A393A4A696A8A9A0B2B3A8B9B9B0BFC0
B6C6C5B7C6C6C1CED0C3D1D4C8D7D9CEDEDFD0E0E2D5E4E6DCE9EADFEAEBE0E9EAE2EDED
E7F2F2E6EFEFEDF4F4ECF2F2EDF1F2ECF0F1EDF2F4E9EEEFE9EFEDE7EFEEEAF2F1E8EDEF
EBF0F2E8EDF0E9F0F1E6ECECE5EDEBE6EFEEE3EDECE3ECEBE3ECEBE2EBEBE0E9E8E4EAED
DDE4E6D6E0E0D6E0E0DCE1E2E5E6E8E6E7E7E2E4E1DDDFDBD2CFC9BFB8AEB6AB9AAD9B87
A48C73A68A68AB8B5E57C6315CC72E5EC52900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28DE0D47B5188E6E347F6A3C746843726D4F71735A777D6A7981747E847D7F877F808C86
82908C80918F839794809593879B9A90A4A48D9E9F96A8A89CAEAE9FB2B2A6BABAA9BCBB
B2C2C1B7C7C7B9C8CABFCED0C6D5D6C9D9D9C8DADACFE0E1D5E4E4DAE7E7DCE7E6DDE8E8
E2EDEDE1ECECE5EFEEEAF1F1E6ECEDE8EDEEEAF1F0E7EFEEE7F0EEE4EEEDE5EEEDE6EBEE
E7EBEEE5EAEDE2E9E9E8EDEDE3E8E6E4E9EAE4EAEAE6EBEAE5E9E8EAEDEDEBEDEDEEEDEE
E5E5E4E3E3DFD6D2CBCFC2B9C3B0A5B7A092AD967EA88E6EA98B647DA44757C5305BC62D
2EE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BF204ABA1E6B962D8A713F836F467F6C4B7F70537F775E
807B6983847681877C848D8585908B8C96948A96948B999890A2A099ABAA9CB0AFA4B7B7
A8B9B8B3C2C2B2C2C4B7C7C9BFCED0C5D5D6C8D8DACBDDDED0DFDED7E1E1DEE7E6DEE8E7
E2ECECDFE8E8E1EAEAE4EDEDE3ECECE7ECEDE6EDECE8F0F0E9F0EFE9F1F0E7EDEDEAEBEE
EDECF0EEEDF2ECEDEEECEAE9EAE6E4E9E3E0E1D8D4D5C8C2CDBEB3C6B3A4BBA694B49B85
B09578AE906FB18E6759C6385CC7355EC6312FE31700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C32453C0224CBA22
47B7239A77478E724687714B85725483725783775F837D6683826E898A798C8E80989A90
9EA49AA0A69EA6ACA5ABB2ACB8BDBBBBC0BFC1C7C6C0C6C3CCD0CCD3D4CED5D6D1D2D4D1
D6D7D4D7D4D2D8D5D2DBD8D5D5D2CED4CFCBCFCAC4CCC6BFC7C0B5C0B7ACBFB3A7BEACA0
BDA898B69F8FB09A84AE957AAF9272B2926EB2906A87AB505AC7375ECA365EC83130E418
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059C32657C32851C0274CBE264ABE2845B92543B826
6F9C3C9B80529A7F529B81579C815B9E84619F84639E8361A18662A38863A68C66A88D69
A98B69AC8D69AE9069AD8E66AB8B62B08F6581A94C81AA4A54C63556C6335AC9365CC834
5FC9335EC83030E41700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0108209 0.97619 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 181.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000]B000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooolP003o000@00[f0`0W
f``09]/<05F^6P1bTR<0Li8T07NC901eTbH0VG8g09]d>`2JMCd0LiP`07JJ<P1hVc<0IJd^03g?7080
:MlC00D0:=hA01oV3000o`002_L401C^1`0Q003o00T0oooo8000o`00100Xb3`0D91h052@N01hF;@;
0:0Pl0D0D91h00<00?l002S8?01@T7P08@00o`3=0?ooo`002P3ooolL003o000P02KJ2`25OBT0UV/`
09I_<`2GLCP0Uflj09I^>P2HL3`0Wg920:Ef@P2`NDP0]G]>0;InD`2gQ5`0^X=K0;^5GP2cQe`0/XYP
0;:9H@2aR5h0[hMN0:f6G02YPU@0YWe<0:9kBP2MNT@0WWY207JK<@1=_1h0C;XL04^h6`1>^A`L003o
00T0oooo7000o`000`1@T7P0X23`0:0Pl00M0:0Pl1`00?l0c@3oool000X0oooo5@00o`00;00Dk@H0
9]X;02KJ2`0/d@h0II/R06nB9`1`Ubd0VGI209afA`2ONDd0XWY?0:1aB`2LI4@0UUHl09M==P2VAc80
]SlY0;Xf8P2k;ah0^R/N0<mBA`2b:a`0[b@E0:0_702JAS<0OBXK08D_8@2<=BP0T3d/0952;@2BB340
ZFeD0:1/C@2RM5@0Wg=?0:UlE02SOe80Wga<09]gA@2KM3d0QhDd07>F:`13`AP07N@:5`00o`090?oo
oaD00?l000@0:<Pl052@N01@T7P0D91h1`2P8?000`2h>;@0d51h0=1@N0030=1@N0L0oh0000D0j6Pl
0?n0003oP000oh000>QX?0050=1@N0030;Ph]02P8?00X23`00D0X23`0P1@T7PG003o0<d0oooo000:
0?oooa<00?l00380;M4<05ZR6P2?J340SV/d099_>P2IMTH0VgA:09IW@`2;F3L0Pd<Y088^6`1k7@h0
O1D9084=1`2420L0R@P908d72P2?1@P0W@L80;<>2`385100eA@A0=@E403C50h0dA@=0=4F3`2m4`l0
Y@d<09hK702I8R<0R`P:090:2P2:20X0XSTk08d[:P2XCD`0M14<08TV7`1g81@0Qd<`0<FMR@2kXXX0
Zi5b0:66G`2PPE80VWHo07^><01^TRD0E:dJ00[f0a<00?l02@3ooolC003o0003052@N01hF;@0X23`
00@0X23`0`3@D7PM0?n000<0d51h1P2P8?000`1hF;@0:<Pl003o000B003o0<d0oooo000:0?oooa00
0?l003L02OH304Nd4`1jNB@0RVTb095]?`2CID@0Qe4e07/m9P1_8140JPh506`70P1`1P<0N0<308@4
102:1@<0S`D409L51P2I1@L0WPD70:462P2L1PP0U`H909L72`2O20/0]`l?0=8G4`3N61@0hQ/C0>0H
4@3O6Q80fQL?0<HF402]8Al0UQPF0:XO7`2M2P`0V`H909L81`2D6a80cGYZ08DW7`2K;Rd0VB`/09Y>
B@3@^K<0c<>k0=77^`2l[Y/0]9n50:bCL02QQEd0WGe<09A`=@1PUQX08mP701400?l02@3oool@003o
000302S8?01hF;@0X23`0080X23`00<0^3Rd0=1@N03XJ3`07`3oP0000`3@D7P0oh000?n000050?n0
00030=1@N02h>;@0X23`00@0X23`00<0D91h003o0000o`003`00o`3=0?ooo`002P3oool?003o000i
01;/1028Hb80RfXi09=]A@2JK4`0OCXW06`A201b2@D0M@H307T4101l0P<0O08407/11@250PL0S`@6
09<4102H1PL0X0H80:X9302X1PP0[@P:0:T82`2U20`0WPH;09l:302S30`0/`l=0=0H5@3T71H0hB@L
0>8l<`3N6a40hQTA0=l`;02_7A`0VP@50:@82`2X2@T0X`L709TA3037JEd0Q1/D07h31@1k20H0[UA;
0:MhK`3?_kT0_k^d0<_6`P3:`kd0dlRm0<2dYP2iZ9D0X8Y[09IiB@2>JBl0=/L>01000?l02@3oool?
003o0005052@N02P8?00X23`0:0Pl03@D7P0;`3oP0040:0Pl003052@N000o`000?l000h00?l0c@3o
ool000X0oooo3@00o`00?@0[cPP0E9hF085a;02<Hcd0OdD`07@V6P1_4PX0M`L608@6202710D0QP@4
08L40`2?1@L0S@<708/21`2A0`H0W0D709l51P2S1`P0Z@L90:/72P2]20T0/@T90;8:2`2X1`/0Y`T<
0:`<3`2/40l0Z0l;0;8>2`376A80gdi50>9FD@3Q8QH0iQ`C0><M5P3F7AP0_A<B0:L=3@2N2@X0XPT9
09`81`2L3Ph0U@X708T3101i0P<0NPh<078G4`2eQ840f<c:0<k=b`2n^KH0_[N`0;JaZ@35`K/0b/>l
0;j`X@2_Vh00Vh5H05jX:@09mP@03P00o`090?ooo`d00?l000D0D91h0:0Pl02P8?00^3Rd0>QX?00c
0?n000050=1@N02P8?00X23`07QH]00Xb3`03P00o`3=0?ooo`002P3oool;003o0011032o0P1dHa<0
Q5l_07e<;01a;a`0JA4807<7201l10T0OP<608430`290`@0S0@208d50`2B10@0V@D609/51P2I1@H0
W@H60:H82@2Z2@X0ZPL90:/7202^2@T0/`X;0;<;2P2a2`X0[@/:0:/<2`2[3Ph0ZQ0>0:hB3P2_5100
YaXD0>>TW02jM6/0WB@L08lL501i5a00JA@?05lC3@1D4Ph0E@l=06P?3P1j3a00V1dN09X;302K1`P0
S0@308<20P231@D0PaTI0<bCTP3?`;d0a/G00=C?b@2l][40cL[70<_:b031_k`0cL_80<c8`P2k[Y/0
TXeK05NT:P0Bk@P03000o`090?ooo`/00?l000@0N5Rd0:0Pl02h>;@0d51h>@3oP000103@D7P0X23`
0:0Pl00Xb3`<003o0<d0oooo000:0?ooo`T00?l004@0:<X2071[4022FRP0K3dP05lD2@1Z20H0L0H6
07@51@1h0`D0O`<708<31P270`@0SP@609051P2C1@H0U`@609X41P2P1@L0XPL90:871P2Z2@P0[0X9
0:d:2`2]2PT0[`/:0;8:2P2e30`0]0h<0:l=2`2^40`0Za0=0:PE4@2P7AP0RQhI06XM601@<Rh0J5U>
08MaIP2RShD0^JRM0<BdZ@31]JX0^:fQ0:2BQ`1gIEd0DSXd03XE4`1L3Pd0S0l>09P;2@2H20L0XQ<?
09hU8P36MWH0^Y>@0=G<a`3<aL00^kB]0<>n^03:b/H0b/[:0<c=cP3<c]00c<k=0<S6`P2f[:00X8e_
03g07@/00?l02@3oool9003o0004052@N02P8?00^3Rd0=1@N340oh0000<0d51h0>QX?03oP0002@3o
P0000`3@D7P0^3Rd07QH]00;003o0<d0oooo000:0?ooo`P00?l004H04NX107eG5@1oF2l0G2LB05@7
0P1W10D0L0D707431P1`0P<0N08607l3202410L0R@@508/2102@0PL0U0<709L41P2G1@D0W@D60:<5
1`2X1`T0[@P:0:/72@2Z2P`0[0/90:h:2P2d30`0]0`:0;0<2@2^40h0Z@l=0:<C4@2:81X0BQD<04@Z
802BOWD0g<[00>KFbP3Zg=@0k^CP0>kWi03Zin@0i^CR0>WUh@3/i^00j=_D0>;AaP35]Z/0?BdV04D:
2@1n4@l0UP/<09H7202M<S<0oL_>0:j5Q`3@^;@0elk80<>n^@3Gdlh0c/W30;jk^038b<L0al[<0<kB
e@3;c<l0_Kjn0<O4_@2STGL0<lHG2P00o`090?ooo`P00?l000<0D91h0:0Pl02P8?00=03oP0000`3@
D7P0oh000?n000050?n000030=1@N03oP000oh000080oh0000<0X23`052@N000o`002@00o`3=0?oo
o`002P3oool7003o001901;Z0@1cLQ80NSHE05hA1P1A1@40E08106L3101_10L0L@@707421P1g0PH0
N`8408<41`291@D0SPD509841@2F1PL0U`D609L51@2R20L0Z0P80:L81`2Z2`T0XPP809h6202S2`T0
Z@T;0:h:302_3@X0Z`h90:8A3P2<5A80JQPD06M2=`2ZUXP0fL^m0>OLd@3Zi>00k>OV0>OTi03Xi^H0
i^OU0>KViP3Ui>L0j>KX0>OUi`3Uhn40iN7M0>COf03?a;d0JUIA03/<2P1h4Q80TPX<0:Hf>@2G>3h0
PBDV0;=nNP3A`[d0/ZNP0<6h/@38`k`0cLg:0=CCd`3>c]00cM3C0<o@d`38b<d0`lG60;Ve[P2KV7<0
Ej<^02Jf1@08003o00T0oooo1`00o`000`0Xb3`0X23`0>QX?00P0?n000030=1@N03oP000oh0001X0
oh0000T0j6Pl0?n0003oP000X23`0>QX?03oP000^3Rd0:0Pl01hF;@02000o`3=0?ooo`002P3oool6
003o001;01?Z0`1XM0h0R1X709T91@2N2@P0UPP908P51@261PD0OPD407H20`1f0PH0O@@808441`27
1@T0Q`@608h51P2E1PD0V0H609X7202O1PL0YPP90:@72@2P1PP0Y0T809T31P2I1`T0W0L90:<9302T
2Pd0X@d;09<F401L7140LE=50;>RU03Re//0jN3K0>SUh03Wi>40inKU0>SVi@3Vi>@0inKV0>KVi03W
i^L0iNKX0>OWj@3VinP0hnCS0>;ShP3PhN40gn3O0=cGd@2^X9H0GSPb07L?402B5QX0S0L;09@:2P2O
BDX0flS80;fd[@3Eb/80b<2j0;fh]03GemH0e=OH0<oAd@3Ad]D0bL_?0<W=d034aLL0YZ:N0:FGR029
KDl09[H500L00?l02@3oool6003o0003052@N02@L7P0oh0003P0oh0000<0j6Pl0?n0003oP0001P3o
P0001`3@D7P0j6Pl0=1@N03XJ3`0d51h0:0Pl01hF;@01`00o`3=0?ooo`002P3oool5003o001=02CC
1P26>Q40OQ0309P51@2Y20P0[@T90:h<2P2f6a@0^1P@0;P>2P2a30/0W@T808`51P230PH0P`@608L4
1@2:1@H0S`@409H61`2M1`H0X@D60:87202O1PL0W`L909`6202J10H0W0D809`92`2I2``0TQ4@06lB
3@1^ASX0a;NX0>CLd@3WiN00iNGS0>?Th@3Rh]l0i>?Q0>CShP3UiN80iN;T0>KSi`3Vi>H0inCW0>?R
i03Ti>D0i>GT0>?RhP3RhN80h^;T0>CSh`3Shn<0i>3M0;Z_Y`1C61H0P`T<08h21@2Z3Q00TPX>07L/
;@2oWI80b[V^0;nbY`2m^:l0c/k90=7CdP3;c<h0dM7C0=?De`3?d=D0alO<0;bk_`2b/:L0UHel08IX
B@0CfP801P00o`090?ooo`D00?l000<0D91h0=1@N03oP000703oP0020>QX?280oh0000@0j6Pl0?n0
003oP000d51h0P2P8?00103oP000j6Pl0;Ph]01@T7P6003o0<d0oooo000:0?ooo`D00?l004d0LE88
074:00260P40X@D70:/92P2_2`/0_24K0;@I3`327AD0_Ph90<4<2@343@`0^0h;0:P92@2C0`@0Q0<4
08P51P280@80TPD40:07202R1`D0X@L60:47202O1`T0W0<50:872P2S2PX0U`X908D@3@1H30T0Id<c
0=30/@3UgmX0hN3M0>;Sh03Rh^40h^7P0>?Rh03RhMl0hn;Q0>?Qh03Qh=l0hMoR0>?QhP3ThN<0h=oQ
0>3PhP3Ph><0h>3Q0>7Qh@3PhN40i>;S0>CRi03Og^40g][H07IFD01j5Q@0T1TH08`61`2;1@P0OaLF
09]QF`3Kc<L0c/>l0<:f[@2h/:H0_kbe0<[;b`3Be]L0e=KJ0=;De`3AdM@0_[o10::SWP2LVY40SGIV
01_>2006003o00T0oooo1@00o`000`3@D7P0oh000?n0000L0?n000030=1@N03oP000oh0002H0oh00
00D0d51h0?n0003oP000oh00052@N006003o00P0oooo8`00o`005P1Ae3L0RkEM08njI02F`Fd0Y<>2
0<B]U`2eVh80Yk>00;j[UP39^JX0ZYjD08^1NP1SI600Th]n09NbQP2@_H40T<Ij08;4J01MdDX0C]<k
02cU800El0hP003o00P0oooo8`00o`001@1@T7P0X23`0:0Pl02P8?00^3Rd0080X23`00L0^3Rd0=1@
N03@D7P0d51h0>QX?03oP000j6Pl00@0d51h0`1@T7P00`0Xb3`00?l0003o000N003o00/0oooo000:
0?ooo`@00?l000d0<[D3078B0@1i0`40TP<30:@72`2N1@H0Z`d=0;DI4`2i8AD0_Q/B0;d=2@3230T0
a0`:0080a@d;0400_`d;0:L81`2>0`@0R0@308d5102J1@P0X0L609h71@2R2@X0Y0T:0:D92`2S2PX0
W@T:08L>301I71<0PVEB0<VfX`3Pfm80gM_J0=oNg03RhMl0hN?P0>7Rh03Rh^00i>?P0>?Qh03Tgmh0
hmcJ0>?Jf@3Odm40fLO70=_6a`3Ia<@0g/c=0>?If@3Tgml0hN3P0=oOh03Pg^40f]_M0=WIf@2k[:L0
J24L0:i9A`222@X0Q0D7098Y:`28@dL0`Z:T0<:d[`2n]:X0e<_10<2m]@32_k/0alO70=7CeP3Ae=P0
cLgA0<K9bP2l`;l0V9ZC09n@QP1<IAH07m071@00o`090?ooo`@00?l000<0N5Rd0?n0003oP0006`3o
P0000`3@D7P0^3Rd0?n0000<0?n00080d51h0P3XJ3`>0?n000030>QX?03oP000oh0000H0oh0000<0
d51h0?n0003oP0000P3oP0000`3@D7P0D91h003o0004003o00P0oooo6`00o`008P0;n0L0;^@J057B
;`21^Dd0YZMW0<6QO`38/ID0`k2H0<RiY030/j00f<o20<Rk[`3;`kL0`;FX0<o6_037_kP0]kF`0;Ba
ZP2/ZjX0/kBd08:EXP2BYK80<DmW06f;V`2ncM80b/k?0<g=c@3=c<`0cLc80<O1^`2n]:/0N=5]05_A
BP0[i1lL003o00P0oooo6`00o`000`0Xb3`0D91h052@N0070:0Pl0040?n0003XJ3`0oh000=1@N0@0
oh000P3XJ3`40:0Pl0030=1@N03oP000oh0000<0oh0000@0d51h0:R8?01XZ3`0D91h7000o`0;0?oo
o`002P3oool3003o001A01?W0@1a9P40L`8108010P2K10L0Y`H90:T92@2_4Q00]A`F0;HI4P2k5a00
^P`90;l<2@332`P0aPd:0<T>2`393PX0b`l<0<4>2`2c2`X0X0H509H41@2L20P0X0L90:06202R20L0
W@P908d61`2440h0HbTO0;JST@3MdlH0h=cD0=cJe@3Jf]H0gMgK0>;Qh03QhN00hN3Q0>?Qh03Vgm`0
g<W60<6DT@2`L6d0XE1=09<a<@2>7B40U1/N09HL702F8R@0UcXh0:1LF02oUY<0h=?B0>3Ng`3Kfmd0
emOI0=_Fe@25CDH0NP/:08P61`2:1`P0P`H:07L42023;Bh0b[2Y0<W2^P33^k40]ZnT0<C3`03=c/h0
c<c@0<oAe@3Ae=L0b/g@0;Jj_@2`/k80V9B<06Dn<@2VNV<0;Z`<00@00?l02@3oool3003o000302S8
?03XJ3`0oh0001/0oh0000<0d51h0?n0003oP0009`3oP0001@3XJ3`0oh000>QX?02P8?00j6Pl0080
oh0000<0d51h091`N000o`000`00o`080?oooaP00?l002T0;nDL05k<>@21^e00_Yaj0<>SPP37ZHT0
b:b;0<V_T03?]Yh0c;FM0=:lZ@36/j00_[>U0;R`YP3:`k/0c/Nn0<[9`038a;d0b<Bn0=;Bc033`k`0
_[jh096HVP2KY:X0SJ6_08jX^P1mWk@0JXZN0<CBeP39dM@0bm?E0<S@dP3;dM@0b=3B0<O<d034b/X0
bLO30;n`Z@2CWg<0Dk4f017/2@0H003o00P0oooo6000o`02052@N0P0X23`00<0^3Rd0:0Pl03XJ3`0
2@3oP0000`2P8?00d51h0:0Pl0030:0Pl0030>QX?03oP000oh0000<0oh0000L0d51h0>QX?03oP000
oh000>QX?02XR3`0:<Pl01P00?l02`3oool000X0oooo0`00o`00D@15U040P0L107X10P1j0000V@<6
0:P51P2]2@P0/A@A0:dC3P2k81X0]a8>0;T:203030P0a0`:0<T<2`383PT0b0h60<`>303<3@/0c`h=
0<LA3`2N10<0VPH709l6202R20P0X`X908h51`214Q40EaH>0;>OSP3Le/`0fmWD0=_KeP3LfmH0g]_H
0=[Je`3Mg]`0h=oO0>KOg@3Wdm40a9NB08lk=`2F7Qh0WA@F09lB4`2P3`l0X@/=0:@;3@2U30/0Y0`;
09X;2P2C3`l0PQ<C0;QgL`3Uf=H0f][K0=WJfP3HemL0Y7ad074?20281`@0TQ4A08H<3`1l10L0T2<S
09UUH039`Kd0d<_80<S2^`3Ad<h0`L;10=;Bd`3@dM@0blkA0<S<cP3BeML0YJFW0:FTWP1YBT80V7A[
07=i?`04003o00T0oooo0`00o`000`20`000oh000?n0000J0?n000030=1@N03oP000oh0002X0oh00
00<0d51h0?n0002P8?000`3oP0000`3@D7P00?l0003o0002003o00P0oooo5@00o`00;P0ggR40L/17
0:^QK@2nY880`:J60<F/SP3;/IH0cKFN0=6kYP3<^Z<0dKjX0=K1[03FaJh0e<6Z0=BmZP2o/jH0clVo
0;NcZ`3=b;l0fMSA0<_8`P3BcLP0b<Bm0<o;aP3;b<80b/o=0:Rb]`1ILX`0NYB`06j<YP2R_<d0[<C>
0<WDe`39d]D0am3B0<[AeP35cM80aLkE0<C=d`34c<l0a<[=0<;5aP2o_;T0YiN904j`<P08m@@F003o
00P0oooo5@00o`000`1@T7P0N5Rd0:0Pl00<0:0Pl0030=1@N03oP000oh0000L0oh0000<0j6Pl0:0P
l02P8?000`2P8?00102h>;@0oh000?n0003XJ3`20;Ph]080X23`0P3XJ3`01@3@D7P0j6Pl0>QX?02@
L7P0:<Pl01H00?l02`3oool000X0oooo0P00o`00D`0Dj@40O3X108T40@280P<0S08209/2102W1@L0
Z@L70:H81`2c6AL0[a4>0;8:1`2j2`T0_P/80<8;2@3730/0a`/:0<T=2`3;3Pd0c0d;0<l>2`3@40`0
a@h;0;H:2P2Z1`L0XPL609P71`1j2P/0FQTC09UnKP3IdlT0g=gJ0=_Jf03Jf]H0fm_G0=oKf@3Mg=X0
h]oL0=k6a02eMgH0XD500:4T8`2T5AD0Ya4@0:L?3`2V3a40Y`d>0:H:3@2T20/0Y@X90:481`2M2@T0
VP/;09492`2C6aT0cYVF0>7If03JfMX0f]WI0<>UWP1d6Q00Q0L508L41P2210P0OPH709Xa<@2=C4T0
e/C00;fe[@2bZYh0_[^d0<g<c03?c]80blc@0<c>d@36b/d0a<W=0;Rn_P2LWYT0M5mG06mCC@2TT8<0
2^H200<00?l02@3oool2003o0003052@N03XJ3`0oh0001X0oh000P3XJ3`Y0?n000030=1@N03XJ3`0
j6Pl00<0d51h103oP000100Xb3`00?l0003o0000o`080?oooa800?l00380>=hQ07nhC02OYfH0^:5m
0;ZTP`2nZ8D0`:b<0<RcU`3=^J<0b[ZX0;fbY@2gZi`0f<Jc0=c8]@3Lb[H0g/be0=k9/P3JbK<0cl2/
0<o5^`3;a;X0`l6i0;6_Y`3Bd<P0d<_60<[6`P3=aKh0d<_40<C3_P2m`/<0^L;:06f6V`1ROYP0EGVE
07NGZ`39fM`0bmKH0<OAe@39dmL0bmCH0<WAf037cmH0`L[?0<7<c`33c=40`LS<0;k3a`2k][D0OhmR
01SR3QD00?l0203ooolB003o0003052@N02P8?00X23`00H0X23`00<0^3Rd0>QX?03@D7P01`2P8?0:
0?n000030=1@N02h>;@0X23`00<0X23`0P3oP0020>QX?0040?n0002h>;@0X23`0:0Pl080^3Rd0P2P
8?000`3@D7P0j6Pl02S8?00E003o00/0oooo000:0?ooo`800?l005<0F7d109<C1P2:0`80S@8509/5
1`2R10P0Y@@70:H51P2W10H0Z@D90:/6202e2PT0^PX:0;`;2`2n2`X0``/:0<L=2@3;3Pd0b`d<0<h?
2`3?3`X0dQ0=0=<B3P3E4@h0da@A0;X=2`2830X0IblT0;JQS@3Kd/T0g=[H0=gJf03LfMP0g=[I0=oK
f`3PemD0ckNd0;AhM`2V<300[QPF0;<F4`2h5A@0/a8A0:dA3P2Y4@h0Y@h=0:L=3@2U2P/0YP/;0:T;
302S2@P0W@T909P8202C1`P0S@L908h`;@3E]:d0f]KD0=OFeP3E_k`0UC/c08l;1`261P@0TAlL098X
:01g20/0MA8D09][HP31/ZL0_[F[0;nj/P2o_;P0clk=0<S:bP3=cm<0a<S;0<O<cP2g_;d0WjBQ089d
K01;<B`0_kJe02bP4@03003o00T0oooo0P00o`000`2P8?00oh000?n0000I0?n000030=1@N03oP000
oh0002P0oh0000P0j6Pl0?n0003oP000j6Pl0=1@N03oP000d51h0>QX?080oh0000<0j6Pl08300000
o`000P00o`080?oooa000?l003D08N/D08FaDP2fWGP0_J610;bSQ@2hXhP0`:Z<0<VbT`3<^9h0d[nV
0=6mY`3Ebkd0gM[F0<^n/@3Ja[00g<Ze0=[=_`3Ndl@0glff0=k<]P3Hb[H0e/Ne0=C8^@3@al00[JbV
0<k<a038`[/0f=K=0<k=a03=b/<0`l6i0:na[P2]/;00T:6]0:c0b`1WQYl0JXbT09jkb@3;eMP0b]GF
0<WDeP39d]L0aloG0<?<dP30b<h0_/O<0<?<d@35cM@0_/O?0;c4b@2c^;l0E61?01SD4@0D003o00P0
oooo4000o`000`1@T7P0X23`0:0Pl0080:0Pl0030>QX?03oP000d51h0080X23`00<0d51h0?n0002P
8?000P2P8?000`3@D7P0oh000?n000070?n00080j6Pl00<0^3Rd0:0Pl02P8?000P2P8?030?n00003
0=1@N02P8?00X23`00L0X23`00<0j6Pl052@N000o`004`00o`0;0?ooo`002P3oool0E@00o`004^L1
08HM002A3PP0PP4109041`2I10H0V@4409l41`2Q1@H0Y0@80:H42P2Z1`P0/`T90;P;2P2l2`X0_`/;
0<<=2@3330T0a`d;0<T=303=3``0d10:0=8A2`3A4@/0e14=0=LD3@365a80NRXR0<BaY@3MeM00f=KE
0=_HeP3OfmT0gMWG0=kHe`3E`<00YfMR08XS7@2Q5aD0/Q@C0;HC502b4Q80/1<B0:XD4@2P5Q<0U1@B
08dF4`2;4a40S`lA09`<3P2T2`/0XPT90:092@2I1PH0T@<508h31@2220H0XEU>0=[8`03Ee]L0f<S7
0:E@A`2a8QL0XbHJ09/g<@2H?ch0M@L:07P92`1m=C00dkNb0<2c[P2dZ:40^;J^0<c=bP3:bl`0al[=
0<W=d@39bll0/[Rj0::XY`2?Qh@0@B@P09N<RP1EQcH00`00o`090?ooo`03003o000Xb3`0oh0004P0
oh0000H0j6Pl0;Ph]03@D7P0X23`0;Ph]03XJ3`30?n000040=1@N000o`000?l0003o00P0oooo3@00
o`00<`0FlPh0ElTg092YF`2cVW<0]imk0;VQQ02lXhX0`ZZB0<J`V@3:]I/0b[FJ0<nlX`3A_JL0dkjX
0=O9]`3KdLH0e/B`0=K2[@2n]:@0bLW60=[JeP3Kc[h0gl^g0=_9]03Ga[00eLNh0<o2]03Jd/X0cLJn
0<k;`P38`kT0dlo70<W3_@3Ie]<0`l6m0:R/Z@2CWJD0JH2D06Z4W@2F//H0R:Ff0<SHf`3<e]P0c=KJ
0<gEf`3;dmX0aloD0;k6b`2i`lH0^<;50<39c`020;k8c`040;k8d@27UJ80O82002cF8A<00?l0203o
ool=003o000302S8?01@T7P0X23`00/0X23`00D0^3Rd0?n0002h>;@0X23`0=1@N0020?n000050>QX
?02P8?00X23`0:0Pl03@D7P02P3oP0050:0Pl0050>QX?03oP000oh000=1@N02h>;@00P2P8?000`2h
>;@0X23`0;Ph]0040:0Pl0030=1@N01XZ3`00?l001800?l02`3oool000X0oooo05D00?l002nb0P1a
4`80N0P407X10P2:0P@0S`0309@10P2J0`D0W`@809l31@2S1@L0Y`H60;892P2g2PX0_@/:0;h<2P31
30T0a0d:0<H=2`362`/0bPd;0<h@2`3A40/0dQ4;0=HC3`3@5A00U18=0;>AQP3Qf=L0g=SK0=[GfP3M
fMX0fmSF0=cHeP3LalH0UT]:09/H5`2V4@d0Za8=0:lB3`2Z3a00ZA@D0:8L6@217Q/0Da8>03X<1`0Z
2@<0:@T603L82P1O4A80R10A09X92@2L20H0UP@309810@2A0P80R@@2080P5P3A/JL0emOH0=c=b`2]
Fe40_blS0:@A2P2G7AT0O0T707d51P275a@0P3D`0;^JV03Ec<h0b<?40;Ra[@35`l40al_<0<G;cP33
b/h0`/K;0<;5b@2BUi@0Vi>A04HV8P28Mg@0KGm=00<00?l02@3oool00`00o`00D91h0?n0001:0?n0
00030=1@N02P8?00X23`00<0oh000P3@D7P3003o00P0oooo2`00o`00?00Fl@d0B/l]0:>LJ@2bV7L0
/iai0;:MO02lY8P0_ZRA0<J`VP38/id0b;:I0<RbU`39/YT0c;JM0<bjW`3A_Z@0dknW0=K1Y`3G_j80
b[NQ0<>iZP38`kX0dLVm0=k=^03Nb[<0flR`0=O4[03EaK80dl>d0<k1/`39_[40e]?80<k9``3?blD0
b/S20<S0^`35`;`0c/k;0;Vj]`2:VjH0OIJW031@KP1VQIh0/<WF0<[Ef@3=eM`0c]KM0<gEg@38d]P0
am7E0<39cP2na/T0^<350;K0a02i`lX0^<C?08NDYP19Gg40JGe/01WT4A800?l0203oool;003o0003
02S8?01hF;@0X23`0140X23`00@0d51h0?n0003oP000^3Rd0`2P8?00102h>;@0j6Pl0>QX?03XJ3`8
0?n000@0X23`00@0^3Rd0=1@N02P8?00^3Rd0P2P8?000`3@D7P0X23`0:0Pl0050:0Pl0030;Ph]03@
D7P0:<Pl01800?l02`3oool000X0oooo05D00?l003JF0P132080O3`k06`41@260PH0S`8409410`2I
0`H0X0@90:44202T1PL0Z0H80:l82P2e2@/0_0/;0<0<2`3330/0``X;0<H=2`383PX0c0l:0<l@2`3A
40`0dQ8<0<hE4@2[5Q<0TDi70=c?b`3Ke]P0fmSJ0=WGf@3Lf]/0h=KF0<BUY02HBdT0VADD0:P?402Z
3`h0Y`h=0:HD4P2B61D0KaHD05<K5@1M@cT0OF]O09F4M`2PTH<0Vheo07IUF@1<=Rh0C0l=098?3`2M
2PT0V@@509D20`2A0P40R`8107/<1P37V8h0f]KF0=[;b@2/FDl0]b<H0;lY7P2T81P0P`h:09/[:`27
5Q<0Ob0M0:1YJ@3B`<@0_[bm0;Zh]03;c</0`l[:0<37b034blh0`<K90;jo``2Z[Jd0V9FC04hh<`21
LW00OfmM00<00?l02@3oool00`00o`00P<000?n0000Z0?n000030>QX?03oP000oh000080j6Pl503o
P0030=1@N080oh000P3XJ3`20=1@N0060:0Pl03@D7P0oh000?n0003@D7P0oh000`00o`080?ooo`X0
0?l003d0:N8I09bGH`2[U700/IUh0;BLO02fWh80^Z>;0<F^UP34[iP0`ZjE0<F]U035[980aK2G0<Ze
W03=]Y/0cKVO0<nkXP3B_JD0e;nV0=RoX`3J_jD0a[>N0<ZhY03LbK<0gLZd0=[7/@3JaJd0e/:Z0=:n
Y`3Ga;40c;f^0<g4^032^:/0d<c20<6l]03Dd<`0a;jh0<>n^@2i/jl0[Zn[0:^`^02HZ;<0QI^/07jJ
/P1PPYd0aMGL0<cDfP3?f=l0cMKO0<cEg039dMT0`l_C0<S@f036c]P0`<[A0;g9d02i`l/0Z;2j06an
SP1iRY40Q9]b01800?l0203oool:003o000302S8?02P8?00X23`0180X23`00<0^3Rd0:0Pl02P8?00
1P2P8?000`3@D7P0oh000?n000070?n000H0X23`00<0d51h0;Ph]02h>;@02P2P8?000`2h>;@0j6Pl
003o000A003o00/0oooo000:0?ooo`1E003o001:IPH0JeM@07IZK@130`@0Q@D809021`2C0@H0W`@8
09d31`2M10L0X@D70:H62@2^20T0]@/90;X<2P2n2`X0`P`;0<@;2P3530T0b@h:0<d@2`3@3P/0dQ4<
0=0B3P2T5A00Od<h0=O7_`3OgM`0emKF0=[Gf03Kf=P0gM3?0:=YI@2<8Ah0Wa@A0:X?3`2W3Q00Xa0>
09<D4P1V5a40IdHi09Z7N03:^jh0hMG<0>;Gd@3TgMP0i>3K0>GNf@3Pell0fL_20:nAR01o61@0W@T:
09/72P2E1@P0S@8308T20P1l1`80_XMh0=OCc`39/Z/0W3LX0;DB2P317A@0]B0I08X4102:4QH0Ta`J
08LK5`26<Bl0Nd920<Zk^034`;`0^[Vf0;Zl^`34blh0a/oA0;o8bP30bL/0W:JW09RLVP1ICDP0RX:1
08MjK@03003o00T0oooo00@00?l00=1@N03oP000d51h=`3oP0000`3XJ3`0oh000?n0000>0?n00007
0>QX?03oP000oh000?n0002P8?00j6Pl0?n000020=1@N0<00?l0203oool9003o000o05^m>P2HTf<0
Z9=d0;2KOP2eX8H0_j>;0<^PR@2iLEh0aY9h0;jXS02mYh`0`jV=0<F/T@36/9T0ak:J0<NcV@2^XXl0
UY620::MSP3=_JH0el2W0=[1YP3H`jL0fLF/0=_7[`3LbK40f/R`0=W3Z`3H_jP0e;bU0=6jY@3?^jT0
dLBf0<Vn/`3<`[D0bL:f0<6j/03@blD0b<Bn0<6n^P2l^kH0Y:FT061aO`2;WZl0M92Y07jK/02db]D0
cMGI0<oGg@3;eM`0cMOP0<SBfP37d=D0a/oF0;c5cP2f_lL0`/gD0;c6cP2f_L@0Kgb;0724S`2GW9h0
=LdY01400?l0203oool9003o000307QH]02P8?00X23`00@0X23`00<0d51h0;Ph]02P8?001P2P8?00
0`2h>;@0d51h0=1@N00=0:0Pl0030=1@N03oP000j6Pl00H0oh0000<0d51h0:0Pl02P8?000`2P8?02
0=1@N0040;Ph]02P8?00X23`0;Ph]0P0X23`00<0^3Rd06RX?000o`004000o`0;0?ooo`002P3oool0
;P00o`00GH<W08^8Q@1TJ6/06@41064620220`L0SP860983202C0PP0V08709d4202T1`T0[PP;0;@;
2`2i2`/0_@/90;l;2P333@X0a`d:0<T=2P3<3P`0d0l>0=4A3`2k5A40RD@m0=O7`03Rgmd0g=cM0=WG
f03IeMD0fL2l0;iNE02W5a80WP/80:4;302Q3@h0UA8D07HG5@1S<b`0[I^>0=gCb03Qg=@0h^3M0>;Q
h03QhN020>3PgP0U0>3Pg`3Ngml0fmgL0>7He@2NEdl0V@/:09/61`2I1PP0T`H708d51P223PD0_hQf
0=?=a`30WiP0T20C0;0910322`/0_PX=0:h9302?0`D0P`D8084N7`3SYjX0R5=D0<F^ZP2i/Zd0`[nk
0<S9b@32b/`0`/[=0<G=d02laLL0Yk:b08jHV01mNWP0NgAe08UoM@03003o00T0oooo00@00?l00;Ph
]03oP000d51h=`3oP0000`3@D7P0oh000?n000080?n000030=1@N03oP000oh0000<0oh0000L0j6Pl
0:0Pl03oP000j6Pl0;Ph]03@D7P0oh000080d51h0`00o`080?ooo`L00?l004404o0<08NHF02OSW00
YiMl0:jNQP2cXh/0^Z:=0<26M02X>2H0]2<C0;eSA`32XhH0`jR>0<>YS035ZXd0bJjC0<F]U@2DRgX0
SH]k0:6JRP1mOWD0R8Mj0=BoYP3G`:H0f/:V0=W4Y`3Kajh0g<R_0=[7[`3Ha:/0el2X0=FnYP3A^j@0
ck^W0<NfX03@`[<0akb`0=??a@36`k`0b<Fk0;be[P3@c<D0`;nk0;Vi]`2_/k@0MXB@04]VP01POi/0
NIJY0<WEfP3?emh0c=GL0<cFg@39e=`0am3I0<G?e`35cMH0/KVo0<7>e031c=@0_lcE065cP`1<IG80
S9^S07^SK`0A003o00P0oooo1`00o`000`0Xb3`0X23`0:0Pl0040:0Pl0040=1@N03oP000oh000=1@
N0H0X23`0P3XJ3`00`3@D7P0oh000>QX?00=0:0Pl0030;Ph]03XJ3`0oh0000D0oh0000<0j6Pl0=1@
N02h>;@00`2P8?000`3oP000^3Rd0;Ph]0090:0Pl0040;Ph]02P8?00X23`0:0Pl1400?l02`3oool0
00X0oooo05D00?l00::3GP1eNh00GFM[00d10@0a0P80F@8208431P210@80R`8609<10`2J0PL0XP@9
0:`62P2b2@`0^0/<0;`<2`3130/0`P/90<L<2P3:30X0cA0>0<h?3P3=4@l0Ta<@0<6UWP3Rg]`0hN3R
0=oOh@3Pg]h0g<K20;YSFP317A@0aa@@0;D@302P2`X0TA8A05XA3@1YCD80b[b^0>;Le@3Ng]X0g]kL
0>3Pg`3PhN00hn?S0>3Ph03Ph=l0gmoO0=_Ng@3Mgmh0gmcL0;1oMP2E3``0V@<609`62@2J1`T0U0L8
08PB2034Sgh0elo90:Z7OP1d1`40Y`H60;`82@302Pd0^@h@0:4=3`240`L0SQ/O07LD7@1d9b`0el31
0<c8a@35a;l0^;Rg0<36bP36d=80][k10<G?d@2U/K<0UJ6R07QhM01]IfD0Rh5g00<00?l02@3oool0
1000o`00X23`0?n0003@D7Pg0?n000030=1@N03oP000oh0000X0oh0000<0d51h0?n0003oP0000P3@
D7P00`3oP000X23`0?n000020:0Pl0030?n0003@D7P0d51h00<00?l0203oool6003o001302;M5@1g
Vdl0W8ma0:>FO`2XVhD0[Yj60;6PQ@2iUg`0XThf0:i09@2oJD/0b9Mj0<2TR@30YXP0`JN70<BWQ`35
Z8T0/in706i_HP2OWHL0Y9j=08f;P@1XKf@0cKfS0=JnY@3J`JL0f/>V0=[5[03Kajl0fLJ^0=S4Z`3F
`ZT0e;nY0=6jX`3<]j80c;RU0<JeX`34]:@0^JfP0=7=a@33`;T0a;nj0;^bZ`2j]:d0_;Ve0;Vf]02@
RY80^JN/0;2GUP2XTiD0a[bo0<k?dP3;e=T0bM?J0<WBfP38d=T0a/kG0<33_P31`jh0`<[=0<7=e`2o
c=P0U::`06=ePP26UYl0[:b/01SS4@0@003o00P0oooo1P00o`000`1@T7P0X23`0:0Pl0050:0Pl080
oh0000<0d51h0:0Pl02P8?00102P8?00102h>;@0oh000:0Pl02h>;@20?n000d0X23`00<0^3Rd0:0P
l03oP0001`3oP0000`2P8?00d51h0=1@N0040=1@N0040;Ph]02P8?00X23`0:0Pl080d51h00<0^3Rd
0:0Pl02P8?000`2P8?000`3@D7P0D91h003o000?003o00/0oooo000:0?ooo`1E003o002dW800RIRM
051MGP0@0`80:P<502/10@1I10D0Q0<608d2202@0@L0U@870:432@2[1`/0[``>0;8?3P2j30`0`Pd<
0<@<2`373@/0b`h<0<`@3P3=40h0`Q@A09=6?`3NeM40h>3Q0>;Ri@3Qgn40i<W80<=YHP2o91`0bQ8?
0<`C3`395A00[1HB06<F3`2>MFD0eLVj0>;Me03Rh=d0gMkK0=oPg@3OhMh0g]oN0>7Rh`3Qh^40h>7Q
0=oOgP3Mg]l0gMkN0=cIe`2WM6/0V0l;0:<92P2Q1PL0W@H709@61P2;70h0bYn;0=_Fd@2KLFX0M0T5
09@4102h2PX0`0X:0;X<3@2i5aT0T`<608P62@281`/0N`T<07`m?032];80`l:o0<W9b@35a/X0b<oB
0<G=d02nal/0^lK:08nLW`2AUiL0JVAU08n4O003003o00T0oooo00@00?l00=1@N02P8?00j6Pl8P3o
P0000`3@D7P0oh000?n0000B0?n000030:0Pl03oP000oh0000h0oh0000T0d51h0>QX?03@D7P0X23`
0;Ph]02P8?00d51h0>QX?03@D7P00`00o`080?ooo`D00?l004@0:M<K08IfFP2:OfD0Vi1h0:>HP02X
W8<0Zi]m0:nMO`2eWWl0_i]m0;V>K`2nWgl0^j230;bPPP2oXGl0_j600;nQOP31XWd0YI1d05eRF@1h
OG00N7ed06=^JP1gNfl0c[nT0=?0Y03G`JH0f/>W0=c6[03Jajd0f/F/0=W5[@3G`JX0eKnZ0<nlY03<
^:00bKFM0<FaW03:_:T0^jbK0;fbX`32^[00c/[30<Jm^03:[j/0/gA_0:Y7@`2V9RH0[1LI0:dC5@2Z
4aL0YQ`S0:Y0AP2fPXH0c/G90<WBf03:e=/0aLoE0<G8_02_YfT0bLVc0;o9dP2gaLl0VjNg051RL01]
OXL0UinQ04Ro>a000?l0203oool5003o0003052@N02P8?00X23`00l0X23`00<0^3Rd0?n0003oP000
0P3oP0000`3XJ3`0X23`0:0Pl00<0:0Pl0030;Ph]02P8?00^3Rd00`0oh0000<0d51h0>QX?02h>;@0
0P2P8?000`3XJ3`0X23`0=1@N0030:0Pl0040;Ph]02P8?00^3Rd083001000?l02`3oool000X0oooo
05D00?l00;BTR01KKG80DEiO01L41@0_10L07`8301`10@1N10H0Q@8408X1102?0@L0WPD;0:<73@2N
3Q80XQ0B0;@>3P2l3@d0```;0<H=2`393P`0bPl<0<PB3@2K7QD0c;6X0>;Og`3Ng^00g]kN0=o5``33
De00bA`E0=8E403D5A00d1P@0;TJ4`1h71<0Yi1n0=gEb`3Pg]X0h>3L0=oPf`3Ngml0h=gO0>7Pg`3O
fmP0h=7A0>?Bd`3RgMX0h>7O0=oOg`3Ngml0g=CA0914?02N3@T0Y0P90:H72@2P1PL0T`P709Th:@3<
[9/0f]7A08YBC@202PL0RP<30:T92@2k2PX0^`X<0;L72`2/2PX0S0@5098>4P2520X0Uchh0<J/ZP39
aL@0^[^i0;o4a03?f=X0bm?G0<G>e02la/`0Tj6R08J>S`1MFed0ThV100<00?l02@3oool00`00o`00
d51h0?n0000J0?n000030>QX?03oP000oh0000@0oh0000<0d51h0?n0003oP0001P3oP0000`3XJ3`0
oh000?n0000;0?n000030=1@N03oP000oh000100oh0000L0d51h0:0Pl02P8?00X23`0=1@N03oP000
j6Pl00<00?l0203oool4003o001502KA6P1`MDl0QWeY08R1K02HTG`0XiZ30:NLQ02ZVh40[Yf30;6O
PP2dXH80^jB60;NNOP2dW7P0]9eg0;ZNN`2lW7L0`9ig0;jMK`2hVg00IEm@05ANE`1OIEh0K6aO0;JW
T03B_J40dknU0=BnYP3H`ZP0fLBZ0=_6[P3IaZl0f<F^0=O2ZP3C_jT0c[fT0<bhX039]Id0`k2H0<Jb
W`3C`k80`k:S0<Zi[P2mUh`0]5eG0:dS7`2b3`l0/`P;0;@82@2f20T0]`L90;H62@2c1PT0/@L:0:P;
4P2Q<ST0`j>W0<W@f036dML0a<k@0<2oZP2/YGD0`LNm0;W3b`2b`<`0C5e^07B5S@2@VId0Ik1K0100
0?l0203oool4003o000406RX?03XJ3`0oh000>QX?100X23`00D0j6Pl0?n0003oP000oh000;Ph]00?
0:0Pl080d51h00<0j6Pl0?n0003oP0002`3oP0001`2h>;@0X23`0:0Pl03oP000^3Rd0:0Pl03@D7P0
1@2P8?000`3@D7P00?l0003o000>003o00/0oooo000:0?ooo`1F003o002:Rel0BUeL059OG`0I0P<0
:08301P20P050@00804106H41@1m0@@0QP850982202P1P`0[AXO0:/H6`2e8R@0YQDE0;H=3P343@d0
aPh90<HA2P2c6a<0X65H0>;Lf`3Ogn40f][L0=S7``2gD4H0`aLA0</B303=4Ph0caD@0:`I4P1c:1d0
/YR;0>3Id`3LfmX0g=gK0=gNf`3Ng]/0g]OE0=S0_`2oS8T0Ydm;09ha;@2E>380]9B:0=kNg03Mg=h0
h=[I0;VBS`295AH0X0T;0:L:2`2T20P0W@L708`;1`2eJ5D0bkNY0=C8aP1n<B/0RPL608l41P2C0P<0
/PT90;P9202g2@X0]@T;09D31@262`h0UbTZ08DK6P2:C4P0_Jn/0<[<c@39cm40a/oB0<_DfP3;eM`0
^L?909fY[P2<UIP0FU]N0926P006l`42003o00T0oooo00<00?l00=1@N03oP000803oP0000`3XJ3`0
oh000?n0000E0?n000030=1@N03oP000oh0000h0oh0000<0d51h0?n0003@D7P0102P8?000`3oP000
d51h02S8?002003o00P0oooo0`00o`00AP07m@D0E8ln08nCQ@2f]k80S8Yh09VDO`2RVhL0Y9^40:VK
P@2/WH40/:260;6NP@2dW7h0/iUh0;BJM02dVg<0]i]a0;ZJK02nVg00_YUZ0;nNK02eV6`0XXeX0;>K
NP33YH@0bZn:0=6kW@3C_Z@0e;nU0=O0Z03I`jX0e/:/0<2cX@2o/j40cl6[0=;0Y`3@_:<0c;RO0<Ve
W@37/YX0b:nK0<BZUP38Xi40_FUM0;<U8@2g3Ph0^@/;0;L82`2e1`X0]PT:0;H:2@2g2PX0]PP;0;45
202`1PL0[`H80:X7302I6b40^iJK0<O>d`2maKh0_[bC0:nUB`2k^800`<O70;[4cP1JJGP0Jgn909NU
Z`1iXfh@003o00P0oooo0`00o`001@0Xb3`0d51h0?n0003oP000d51h01/0X23`00<0^3Rd0=1@N02P
8?001`2P8?000`2h>;@0j6Pl0?n0000=0?n00080^3Rd00D0j6Pl0;Ph]02P8?00X23`0>QX?0040:0P
l0030;Ph]000o`000?l000h00?l02`3oool000X0oooo04800?l005^B?@14EU<0G6QW01d4100R0P<0
3@4000400@0@0@40@`4207051`1l0@@0R`870:062`2[2@h0X@L<0:L?4`2J20X0[``=0<0<30353P/0
`1@=08dQ5@36ZZ@0gM_N0=oOhP3Ke=<0_81i0;HK5@333P`0a@`90<L?30315a@0NRLN0;ZRT`3Oelh0
g=cK0=_Kf`3NgN00gmgL0>CGe@2dPGh0Sc8_0:8Q7P2^5a@0X1hJ060I3P2_Vhh0g=_H0=cFe@3B]K40
UChg09/=302R2@`0XPP80:061`2I1PP0TQP>0<>7L03?`[L0bKVe07TK5`2@20T0T@D708d1102R1PL2
0;H72@0B0;@81P2U2@T0O@D50;=GF`2;3A00OadN0=Nj^P3=blh0]kbn0<gEf@3<eMd0bM?L0<WBfP2A
WZ80TYfP04a?D@2>QWd05L`30P00o`090?ooo`03003o003@D7P0oh0003L0oh0000<0X23`0=1@N03o
P0003@3oP000102P8?00d51h0=1@N03oP0050:0Pl0030?n0003@D7P0D91h00800?l0203oool2003o
001701GQ3@1QJdP0TiJ=0:bk_030b<X0S8f109ZHQ@2OVhT0XYb40:NMQ@2XVGX0[I]m0:nKO02`VGT0
[IIa0;BJM`2cUW80^9M/0;REH`2kUV80`9]Y0<:PL031Wg40`j1d0<BUO038Ygl0bZb60<bbTP3A_9l0
dKnT0=NoZ@3B_j`0Ui:30:bUU@2SVXl0R8Mm0<c0ZP3?_jD0cKZQ0<bdWP3:/I`0d:2A0<UhKP2j?cP0
^a8A0;l;3P2m2@/0^`P<0;T72P2d1PP0/`L90;@62P2e20/0/0L90:l83@2_1`/0[PH80:X5202W1PT0
UA/O0<J][P34c<@0]Zmh0:NG6P2WVaP0]kI[0;c3[`1ZNh@0E6ik08fNY@2@RXH04000o`080?ooo`80
0?l000H0:<Pl0>QX?03oP000d51h0>QX?03oP00I0:0Pl0050;Ph]03XJ3`0d51h0?n0003XJ3`01@2P
8?000`2h>;@0oh000?n0000@0?n00080j6Pl102P8?001@2h>;@0d51h0:0Pl02P8?00d51h01000?l0
2`3oool000X0oooo05H00?l00563:`1LJVL0DeiM01d4100F0@401@400040000C0@80<04204h10P1_
0`@0Q08509l52P2[20`0U@P;09XZ;0292P/0/0l>0<<?30333@X0/b0E099FAP3Le<h0gN3S0>?Nh03A
Y:40/CH^0<0A3`353`h0a@h<0<@?3@2E5A00[X^00>3Hc`3Mg=P0fmcL0=cKg03Pg=/0dkfj0:ALFP2M
92<0YQLF0:dF4`2M6QH0J2HK0:27N@3Jd<T0g]WI0<>XX@2A@c/0UaHB0:4:2`2S2@`0X@L909/61`2@
1@H0U2PL0;b?NP3Cb/40^9fI07dB3P2=10H0R`8408`31`2E0PD0/0P<0;L82P2e1`T0/0P909/62027
20`0R`L;08DF6031UI<0`;Zk0<?5b@2oaLT0aloG0<S@fP2ob]@0Y[Fl08:BU@1KGV40QgQ_01G;0P80
0?l02@3oool00`00o`00d51h0?n0000g0?n000030:0Pl03oP000oh0000h0oh0000<0^3Rd0=1@N02P
8?001@2P8?000`3oP000j6Pl052@N002003o00P0oooo0P00o`00B01=R3P0R8Z20:fh_P1UNh40am3D
08jBRP2DUHH0WIV709nGQ02VV8D0YYMk0:ZINP2WU7<0[IUh0:jJM02`VGD0/iMd0;BDI`2gU640^YEO
0;jKI`33XW@0a:5f0<:PMP35YWd0b:V20<f_S@3=/I40ckVK0=>nY@3F`JT0]:BF08V7P@2e/:<0[ZVN
06edKP2k]J@0dKnW0=2mYP3@]Z80e9N90<0j=0326A<0aA4>0<<<2`2n2PX0^PX:0;X92P2f20T0[P/<
0:@D5P2M:Rl0SSE007diB01i>TX0QcQ409HW;@2O2a00Z0H90:85302I@4@0b<W:0<C:a`2]XE00ZYP8
0:jO2P2`Xbl0THi>06QfL@26U9L0Ui>B01KO30l00?l0203oool2003o00030=1@N03XJ3`0X23`0080
d51h0P3oP0000`3@D7P0X23`0:0Pl00E0:0Pl0030>QX?03oP000j6Pl0080oh0000D0d51h0:0Pl02P
8?00X23`0=1@N00;0?n000@0d51h103oP0030>QX?0@0X23`00D0^3Rd0?n0002h>;@0j6Pl052@N00?
003o00/0oooo000:0?ooo`1F003o001MSC80JWId06Y`L`0M1PL03P4100D20@010@404`8302P10@0_
0@40A`4207X21@2K10X0Y`H<09l<3P2YADH0YQ`K0;`<3@3330X0`a0;0:U1=03E_kH0gmoP0=oOhP3A
YJ@0/3@^0;dE40323Pl0bA8@0<LA302a5@l0UU]<0=O@aP3If]L0fm_K0=cKf@3FdL/0VXf2080h;`2Q
61D0ZQHF0:@I6`1o6QH0ICX]0;j`XP3Pf]80hM_H0<NSW`2A;BL0U`h=09l;3P2Q2Pd0WPP:09l82@2K
20T0T@T609m4<`2jWX`0e/o:09Y]I`222PP0S`@708h21@2:0PD0R08309820`2_2@/0/`P:0;@91`2]
2PL0T@<308D71`1l3@h0PSXk0<F_[P2k^k`0`LG90<_@e039d=H0`lcD09j]/P2FYZX0FEeN07e[G00G
c082003o00T0oooo00@00?l00=1@N03oP000d51h5@3oP0000`3@D7P0oh000?n000040?n000030>QX
?03oP000oh0000X0oh0000<0j6Pl0?n0003oP0002P3oP0000`2P8?00oh000?n0000>0?n000050=1@
N02h>;@0d51h0?n0002h>;@00`2P8?000`3XJ3`0oh00052@N002003o00P0oooo04X00?l0023>5`1h
OG40[;Nj0;K3bP2lbM00bm;G09NKUP2DTX@0W9F709nEQ02QTh00XiIo0:FEN`2WUGT0[IIg0:^EKP2[
Ufh0/YQd0;:BJP2bTel0]iEP0;fJJ031XG<0aZ=k0<BUOP35Ygl0b:R10<^_SP3</i@0d[ZO0=:lX`3E
`:P0_J^M06m`K`1jPGd0KgYd06IbJ@35_JX0e<6^0=Ro[@3FSH80`BPW0<XB4@383P`0bPl=0<T>3P30
2``0^@/;0;4A4P2T;c@0Md1B04DmFP0i@fH0BE5`061XP@1/Ni@0BfB606IcS@2:Gfh0V1lX0:872`2E
3100]I>F0<;=d02d/7l0NF`G09F;3P2^X0L0WY0B05ML@@1jRHl0X:2P027J5`l00?l0203oool00`00
o`00J:Pl0?n000030:0Pl0050=1@N03oP000oh000?n0003@D7P05P2P8?000`3@D7P0oh000?n00002
0?n000<0X23`00<0j6Pl0?n0003oP0001P3oP0000`3XJ3`0d51h0;Ph]0060:0Pl0060;Ph]03oP000
oh000?n0003XJ3`0d51h1@2P8?00103XJ3`0^3Rd0=1@N01@T7P?003o00/0oooo000:0?ooo`1F003o
001XVD40O8Z@06ajP`0F1PL03P4100L10@010@404P4102`10P0_0080=P4106`3202H1@X0Z0P=0:X:
3P2W4Q@0^10?0<4<2`353P`0_A<=0;McIP3Pf]@0fmkN0=W@dP2[CDP0]a<A0;lB3`324Q00aa0?0<DC
3P2F7A@0e;Z]0=_Ie@3GemH0gMcM0=_Kf@3Of]<0akZ]07Ln<@2U7a/0U20M05hF4P1D=BX0cKnb0>?N
f03OfmT0d[Fe09<a;@2R4Pl0Y0`>0:<:3P2O20`0W`T909X41P2M1`T0T`T60:ULBP3<]j/0eLk;0898
@0231@D0RP4408d21`2:0P@0R08308L00@2P1PP0[@H70:l61P2_1`P0VP<308861@245QL0KaDF0:R3
P@3:c<d0_<330<S;d@3;d]P0^lK>0;[6c@24TiP0Jfma07m]G`0Hc082003o00T0oooo00@00?l00=1@
N02P8?00d51h:`3oP0000`3@D7P0oh000?n000070?n000030=1@N03oP000oh000140oh0000<0d51h
0:0Pl02P8?000`2P8?000`3@D7P0oh00052@N002003o00P0oooo04X00?l005F4A`2T[k00]L?<0;k>
e`2gbM00a]?H09fSX02?Sh<0Ui>70:2GRP2QTh80Xi=m0:>DNP2TTGL0Zi5e0:bDLP2]UFh0[99Z0:nA
H@2cU640]YIU0;fMJ`35YW/0aZN30<JXQ`36ZhX0bjj?0<^bU@3;]YT0ckZO0=6kXP3E`ZX0el>^0:^O
T@2CTHH0WIb>0;^bX@3DaK<0ekn`0=J=Q036:BH0d1<D0<lA4P3=3`l0cA0@0</=402k4A40ZCHi06m7
G`0a?640CE]g08nFWP2]/;80Z:fb09>MZ@1kSZ80>eMf09Zha`37dMX0^i^R09HQ9`2M20`0Q3Lo0;c2
bP2b[gH0Q78D06]Q3P24P0h0X9@:092:<@26T7`0V9jK03_4;0l00?l0203oool00`00o`00d51h0;Ph
]0030:0Pl080j6Pl0`3oP0000`3@D7P0X23`0:0Pl00D0:0Pl0<0d51h00<0^3Rd0=1@N03@D7P0203o
P0001P3XJ3`0^3Rd0:0Pl02P8?00^3Rd0=1@N0H0X23`00D0^3Rd0?n0003oP000j6Pl0;Ph]0060:0P
l0030;Ph]03oP000J:Pl00l00?l02`3oool000X0oooo05H00?l006bNBP27UYl0MhJA00`3100<0@40
1`4200410@0G0P80<`8303<10P0e0@40DP4408h63P2T1P/0[@T=0:l9302i2`d0_@`=0<<<3@2g8QX0
fkBX0=gNf`3Lg]l0c:VX0:HS702R4Q00N@d;084=302m5180]b0G0:1HBP3Ldl`0f=WF0=[GeP3Ncll0
gLS40>7He03RfmH0`:JM06XW7`1R>2/0Th1a0<o4^03Tg]T0hmKD0;ZHUP2E@Ch0WQHB0:H>302V30h0
X`T=0:4:2P2Q20P0X0H909d72P2B2`L0^GaY0=W>a@3?aL40Mb/T08@40P290P@0R`<608X210290P@0
Q@8208h20`2W1PL0]aDD0:h72@2Y2`T0RA@C0:]DEP1]71d0XWA`0;Fd/`30a/T0a<_@0<?;e039dmh0
/l7909j]]01ZL7@0PgAZ01O<10800?l02@3oool01000o`00d51h0:0Pl03@D7PA0?n000030>QX?03o
P000oh000240oh0000<0j6Pl0?n0003oP0003@3oP0000`3XJ3`0oh000?n000030=1@N0@0X23`00<0
d51h0?n0001@T7P00P00o`080?ooo`1:00o]2`2HWYT0]<;90;K5cP2P];d0UZbc0;72b02U[:h0SXn5
09NDR@2LUXT0WYB50:2DP@2RUWl0YIMo0:JDN@2]UGD0[I=_0:bAJ@2_Sf80]9AS0;NEI@2mW6d0`Z=j
0<>YQ`35Zhl0b:jB0<^dU`3<]I/0cKVN0=2lX03A_J<0eL6Y0=O3[P3Jak00fLRf0=O8^03GakD0el>d
0=VGS@34:R@0ca@A0=0B4@3=4100cA0?0<P@3`2k:Rh0Q4aR03=2JP1HKHX0W:2R0<c6`@35]kH0_::S
0;6BT`2eVID0Yj2R07b=X01VQJ00_M3J0<cBf02]Nh80T`dC08XJ802MVJ40/jml0:VD5@2AO`X0GEL;
07Eb3@2NTPX0W9@S09^HJ`1D^d8?003o00P0oooo00<0:<Pl0>QX?02P8?00102P8?000`3@D7P0oh00
0?n000020?n000030;Ph]02P8?00X23`01@0X23`00<0d51h0>QX?02h>;@02@3oP0001P2h>;@0X23`
0:0Pl03@D7P0oh000>QX?080d51h00<0j6Pl0;Ph]02P8?000P2P8?001P2h>;@0d51h0?n0003oP000
d51h0;Ph]0H0X23`00<0^3Rd091`N000o`003P00o`0;0?ooo`002P3oool0EP00o`00L:=?09BVZ`1`
PhX01`<400T10@040@400P0001T20P0e0@80=`8103X20P160P<0M`H:09h93@2Y20`0[@P:0;H:2`2n
3Pd0`@l;0<15>P3Nc<D0g^?R0>3Lg@2^FeP0Ma0=04/M601TDDD0PDm40:@Q5035JED0b;2R0=WHeP3K
b<L0aHB00;i7@P2e=Bl0`Y6:0>;LeP3Of=<0YYV:0=K>_`3ThM/0h^;P0<C8aP1iH5d0GBHS05LF4`1M
4a00LQ0@090B4`2L30`0X@P80:47202P1PT0W0H909HI4P38Wi00fmC@0<2]Z@1j5a<0RP<408L10P27
0P<0Q`8408H11@260@<0Q@8209h6202]1PP0/0D70:X;3@2Z>Ch0OQ<D08hT8`1h:bT0a[Vi0;c1``30
bld0`LcB0<C@f@2iam80U:B]071lPP1mN7805L`50P00o`090?ooo`04003o003@D7P0X23`0=1@N1L0
oh000P3XJ3`00`3oP000d51h0>QX?0090?n000030>QX?03oP000oh0001`0oh0000L0j6Pl0?n0003o
P000oh000;Ph]03@D7P0oh0000@0X23`00<0d51h0?n0001@T7P00P00o`080?ooo`1:04?@>@2ja/d0
/lCA09Z_^`1hTid0QIfS0;g;dP2^]KX0S8j709ZHS02LUXT0WYJ60::HQP2RV8@0X9=m0::CN@2ZU7L0
[95^0:nAJ02`T6<0]9=U0;NEJP2mWGD0a:J30<:XS034[900ak6D0<VcV@3;]YX0b[NK0=2lX@3D_ZH0
e[nY0=O2[03JaZl0elNb0=K6/@3Ga;00gZnR0<Di<P3D6180daH?0<hA3`355180^R4P0:]7DP1BCWP0
@EQn096BV02cYY/0^YJ<0;9WHP2]=C@0ZQPL0:@>4@2S4aD0XS4c0:MmP@1[NY00_LoJ0<WBf@3;`/P0
SRTb08h>5@21M800_<K40:jVI@2VU@l0X94;06YQ1`2CRP`0VHl80:NJ901hZ40?003o00P0oooo00<0
D91h0;Ph]02P8?001@2P8?040?n000030;Ph]02P8?00X23`01L0X23`00<0j6Pl0?n0003oP000103o
P000103XJ3`0X23`0:0Pl03@D7P80?n000050;Ph]02P8?00X23`0:0Pl02h>;@00P3oP0020=1@N0P0
X23`3`00o`0;0?ooo`002P3oool0EP00o`00KJ9<08ZMX@1YN80020<400<10@0100400@4101T20@0k
0P80?`8203l20`180@@0HP8608@5302O1`d0[0L;0;<:2P2l2`/0_a0>0<MVG03Rf=L0h>3S0=Fj^@2@
:200PeE80<:eZ03Bc<<0g<Rn0:AJA@3<VhP0fm780=WFdP2HJF80T2LQ08DJ501H50d0ITm20<o6^`3R
gmX0g]cF0=oMf`3;c/d0PXZ404QBB@1[I5X0R7a_08]oLP1kL6@0E4Hl03<A3P1R3Pl0V@`=0:492P2R
1`H0WPP70:0e9@3</Z40f=;A0:^<R0213P/0S0@508X310250@80Q@4308@11@240P<0P`4208l3102[
20P0[PL80:`61`2V2@d0Ta8C094L6`1n8R00`:RX0;2d]P37cm<0`lkE0<C>e`2kaM00T:2X07B1QP1d
L6X05/d70P00o`090?ooo`04003o002h>;@0X23`0=1@N1<0oh0000<0j6Pl0?n0003XJ3`00P3oP000
0`3XJ3`0oh000:0Pl00@0?n00080j6Pl203oP0000`3@D7P0oh000?n0000@0?n000030=1@N02P8?00
d51h00@0X23`00<0d51h0?n0001@T7P00P00o`080?ooo`0L04k=B@2e`/d0XKG406V4T018IV`0W;6g
0;k>e@2e_l<0S8j809JERP2IU8T0Vi650:2EQ02SUX<0XY=o0:6AN@2XTgH0ZY1^0:f?I02aT6P0/YA[
0;BFJ`2lWgT0_j1o0<JXS037[9<0a:fC0<^eW080c;NO02`0ckbS0=:nY@3E`:T0e/6[0=O3Z`3IaZl0
f<Ra0>34/@3;H5L0caXE0=DH403D5A00`Q`F0:EAG@1UEGT0<TUh07J9W`2cZYl0`9f>0;MNE`2^8200
]@`>0;X82`2f1PT0/0D60;461`2`1`T0X1HK06e?I@23WK40am7J0<c@f@2LG6D0SP`D075DHP2dam00
`/S00:^RA`2[W0L0XY<50962301[I`H0VY8<07RX4@l00?l0203oool01@20`000X23`0:0Pl02P8?00
j6Pl0080X23`00<0^3Rd0?n0003oP0000`3oP00I0:0Pl0D0oh0000<0j6Pl0:0Pl02P8?000P2h>;@0
0`3XJ3`0oh000?n000070?n000090;Ph]02P8?00X23`0:0Pl03@D7P0oh000=1@N02P8?00d51h00L0
X23`3`00o`0;0?ooo`002P3oool0@000o`00KZ9<08^NX`1AGVD02@840080000000000P0002830`0k
0P<0?@4103l10@1=0PH0H@8:06d01P2D1``0[0P<0;@82P2l2PX0_a4>0<UeK03Ug]h0h^7R0;fDT@2=
<240ckBW0=GAc03Ce]@0f<_60:EZF@3C/J80gMOC0=3;aP0j;B<07P`302PJ3`1nM6D0bKn_0=gGc03N
g]T0g=cH09^QU`1HGU40Wj6C0<k7^@3Kcl@0h=G=0=kEcP3Md//0bkjb0:bNT`1:91l0Ra0D0:8;3@2S
2PL0WPX80:Q??@3<_K00eM3?0:=iMP2830`0S`<709052@270@@208810`0D084100240P@0R@430:<6
2@2Z10H0[0H60:h92`2D1`P0QPh>07DF5`3;[k<0`lG80;g6b@2iaLT0aM;I0;K6cP2S];/0MH>7071]
J00FcPP2003o00T0oooo00@00?l00=1@N02P8?00d51h5@3oP0000`3@D7P0oh000?n000020?n00003
0:0Pl03oP000oh0000@0oh0000<0d51h0?n0003oP000403oP0020=1@N180oh0000@0X23`0=1@N02P
8?00d51h102P8?00103oP000D91h003o0000o`080?ooo`1:08fCK`2a`/d0NI:P03mMIP1CL7L0Q9bT
09^a]P2mbL`0RHn;09FES02IUX/0ViF709fFQ@2QTh<0Xi=o0:BDO02WU7L0Yi5^0:V@J02`T6L0/IA]
0;RKMP2iWG`0_J630<FZS037[I<0a:fD0<VcV`3<]Yh0ckNO0=2lY03@_jL0e<:/0=K3[@3HaJh0fLRa
0=[7]@3LVY00abLP0=HI4P3D5`l0abHP09MLK@0bC7L0FG>C09jQY`33/:<0aiB70;@m=`2g40l0^`X;
0;P72P2j1P/0]`L:0;452@2b1PX0/PD80:/72P2BA5@0Df^:0<7Cg@37dm/0ZH>;08`>5`1U@E40/lSC
0<;?e02l_9@0/J<`0:NF1@2MSPH0HU`806AS202GQ@h?003o00P0oooo00P0d51h0:0Pl02P8?00d51h
0>QX?02h>;@0X23`0=1@N0@0oh0000<0d51h0?n0002P8?005@2P8?000`2h>;@0oh000?n000030?n0
00060;Ph]02P8?00X23`0;Ph]03XJ3`0d51h2P3oP000203@D7P0X23`0:0Pl02P8?00d51h0?n0003X
J3`0X23`0P2h>;@60:0Pl0l00?l02`3oool000X0oooo05H00?l006FF@@1MK6l0DEeP00@20P020@40
000000<0000Q0P<0=08303410@0e0@40BP8505h3201U0`P0P0@90:/9302g2@X0_P/;0;`A303<P7D0
hn7Q0>;Si@29O7@0RVUM0>3He03Mg=d0fmWI0=B[ZP2dFdh0fkFX0=gIe@3Hdm40YY^A09jDQP2i[Il0
d/[10=cJd`3LgMH0gMgJ0<g7_P2]ZIH0e]C40=kLdP3NfmH0g]cJ0=oMg03Lf]X0gM_L0=gIf@3Id</0
ZiJ?07TH5P2L2`/0W@P709P=2@2eL5d0d/[20=OAd02DH5`0S@`<0984202A0`H0S@<608D110260PH0
P`4408H21@250PL0V@H90:`7202_1PL0[@H80:882`2;1`X0P@hA08M3A@2j];@0b<oC0;k8c@31cMD0
^<O@09NX[`1lRXl0LFiY01O>2@800?l02@3oool01000o`00d51h0?n0003@D7PO0?n00080j6Pl103o
P0020=1@N0d0oh0000<0d51h0?n0003oP0004P3oP0000`2P8?00d51h0:0Pl0030:0Pl0030=1@N03o
P000D91h00800?l0203oool0B`2MSgX0UjVi04MVM01;JW<0HGj409nc^`22VJ00a<oE08^AT02BThd0
VYJ?09VCQ`2LUXD0WY>00:2BN`2SUG`0YIEj0:NBL@2^TW00/9A]0;6EK`2hWG/0^J620;jWR`33ZXh0
aJjD0<J]T`37[iD0b;:J0<fgW@3@^Z<0d[jW0=?2Z@3E`jd0e/Fa0=O6[P3Q_Zd0adi50=@L5@3C5Q<0
aRLR08mPN00eE880WJB/0<2dYP35[il0c9240;P/:@2k30d0_0T<0;X9302d2@X0[10A0:HW;@2H<3L0
XaLM0:l62P2]1PX0R39303mMP`2/a]@0am?K0;6CWP2:41X0GSM90;78eP2mbmH0`/oA0;RdP`2XVQd0
XY<409b@201lL0T0SX4@027I100>003o00P0oooo00D0d51h0:0Pl03@D7P0d51h0>QX?0020:0Pl003
0;Ph]03XJ3`0oh000080oh0000<0j6Pl0:0Pl02P8?005@2P8?000`2h>;@0oh000?n000020?n00006
0;Ph]02P8?00^3Rd0=1@N02h>;@0j6Pl2`3oP0000`3@D7P0X23`0:0Pl0020:0Pl0050?n0003XJ3`0
X23`0:0Pl02h>;@01P2P8?000`1@T7P00?l0003o000<003o00/0oooo000:0?ooo`05003o001BPbP0
LH1l05EVIP010P800P010@40>`030@406P8102`10P0a0@40=`8203l10@1:0@<0E00207021`2N2@`0
^@/<0;l<2P2n4@h0bGE^0=ODe03EemT0];B^0;Zg/P3De]H0fM?D0<jYYP2`>cH0]R8J0<aeJ`3O`[l0
gMKF0=gFe`3PemL0h=?A0<o0`02c[Z@0e]790=oMfP3Lem80iN?N0>GWh`3Qh^00g=cK0=gMg@3MgM`0
g=[J0=gJg03Kf]`0e]KE0=[Ed@2QHe`0U0h<09X72@2G5@l0`I1m0=SBc@3Gd</0Rdi508`81`2F1PT0
T`8708l21P270P<0Q@830080QP830180P`<708T2102V2@X0[0H70:h62@2Y2P`0T@T<09`Y:@228b<0
`jn`0;Ro`@2c_/80_/_B0;W8d`2__lL0O8jC07=aKP0Hc`X2003o00T0oooo00@00?l00=1@N03oP000
d51h5`3oP0000`3XJ3`0oh000?n000060?n000030=1@N03XJ3`0oh000140oh0000<0d51h0?n0003o
P0004P3oP0020=1@N0@0X23`00<0^3Rd0?n0001@T7P00P00o`080?ooo`1;09Z8L@2>XJh0?UiX04][
KP1^RY00SJB]09N]]033dMH0RY:A09:DSP2KUXl0VY6809bFQP2LU880WI9n0::FO@2RTgT0Yi=f0:jD
M`2bVGT0/YUf0;NPO02mYXL0^JB:0<F_U032[940ajjC0<ZbU`3<]Yh0c;FL0<niY03@_ZP0d/2W0=?0
[03E`jl0f<B/0>6/V`33:1h0f1X@0<`I502bG6L0:DQi09:Q/@32]:D0a;6N0<nVUP2f>CD0a14B0;d9
302j2@`0/``=0:0Q8`2AEVL0@C]P024UC@2<>dT0[0H=0:H92P1e>dd0@FF?06Z;YP35e=/0/9BO08P?
6@1M=4P0/<OG0;S6c`32d=L0^[f`0:bTGP2OTaT0WHd30:BE2@2AP0X0@K8700h00?l0203oool01@3@
D7P0X23`0?n0003oP000d51h00<0X23`00D0d51h0?n0003oP000oh000=1@N00G0:0Pl0050=1@N03o
P000oh000?n0003@D7P00P2P8?000`3@D7P0X23`0=1@N0060?n000040=1@N02P8?00X23`0=1@N080
oh0000<0d51h0:0Pl02P8?000P2P8?000`3oP000d51h0:0Pl0020:0Pl0030=1@N02P8?00X23`00@0
X23`3P00o`0;0?ooo`002P3oool0EP00o`00D7lQ04]KE@17EeL0004100810@010@000P0101T30@0R
0P40;08203d20`100@40CP4405d11@1d10T0R`D90;8=3P2n2`/0`Pd;0;hg=03N^;P0gMSI0=[He`3C
c</0bZNX0;IRH@2a:2H0_Q0>0<DA402n5aD0_chk0<ijN03;OGd0aVa[0;Q?CP1i=2l0_:jQ0>7LeP3N
gM/0hN7Q0>GVi`3Ui^P0h^;T0=cMg@3LgMh0g]gM0=_Kf`3JfM/0fMWJ0=WHfP3HemP0^I>=094B4@2M
30h0WR/O0<Z[W03Ie=@0f/c;08M2>`2@2@P0UPH909021P2>0PD0QP4308H30`230P80Q08308D31@24
0@@0U0@50:L71P2/1`/0[0P<0:P;3`2H20d0TA/H0:5kN02b][P0^lK90;_8c`2ncMH0UJJ_08FEVP1c
KVX06]4;0P00o`090?ooo`03003o003@D7P0oh0001H0oh0000<0j6Pl0?n0003oP0001@3oP0000`3X
J3`0d51h0?n0000D0?n000030=1@N03oP000oh0001<0oh0000<0X23`0=1@N02P8?000P2P8?000`2h
>;@0oh00052@N002003o00P0oooo04/0XhY[08ZIY01?Jg80IH:607fIX01mVJ40NiJM0;_<d@2@VYP0
TiB>09FCRP2GTH@0VIB409^DQ02NUX<0XiV60:6FOP2WUWd0[iUl0;2HM`2dWGd0^j:30;^VQ`2lZHd0
a:jC0<J_U@37/9@0ak:G0<VdW03:]9d0c[RQ0<nkY@3@_JH0d/6Z0=G3[03I`jd0eHEi0<lP6`3G71@0
`Cdk05EGO@1ZQjH0`[V`0<VdY@3C[J40`FQO0;dG5@363`l0_@X=0;H@3`2Q?dD0DdEV02m2K@1ZN9@0
UhZH0:0e>P2]20/0X20U04LjF@1aSJ/0OIZb0<CDgP2_SIX0R@hG05TdBP2X`]80^/[B0;o>eP32cM<0
^l:j0:VXMP2ES1`0XY<909F62P0cb@P03P00o`080?ooo`060=1@N02P8?00d51h0=1@N02h>;@0X23`
0P2h>;@00`3@D7P0oh000?n000020?n000030>QX?02P8?00X23`01@0X23`00@0d51h0?n0003oP000
j6Pl0P2P8?00103oP000^3Rd0?n0003XJ3`40?n000060>QX?02P8?00X23`0:0Pl02h>;@0j6Pl0P3o
P0040:0Pl0030;Ph]03oP000d51h00<0X23`0`2h>;@40:0Pl0h00?l02`3oool000X0oooo05H00?l0
05:0801YMG00B5MG00010P020@400@4000800@0H0P406@0001l0000g0`D0@04105L11P1^1@X0N0<7
08@52@2U2@/0_0`;0<4<2`2o4Ph0`e5@0>BZZ`3AYJ@0]gIc0:D/:@2c4a80_@h;0<8>2`3640d0aQ0<
0<LD403561H0`ALH0<<K6@2M6QH0REmA0=gEcP3Nf]X0h^7P0>?Si@3Vi^P0iNGW0>CTiP3NgMd0gM_J
0=oJf03Nf]T0fmWI0=_Ge`3Jf=L0fMKG0;VFTP2A5140U`X80:A2<@3;^:/0e=?D0=_=b@28?CL0T0L9
09432@2=0`P0RP8408T30`280P<0Q`4208@00P240@<0Q04508P00P2T1`T0[@P90:l93@2^2Ph0V`P;
08L?3P2RL700cL_=0:Rc]@2mbm80]/K@0;S8dP1mSI<0MWAa02Jh3P800?l02@3oool00`00o`00d51h
0?n0000C0?n000030:0Pl03@D7P0oh0001l0oh0000<0d51h0?n0003oP0004P3oP0000`3@D7P0oh00
0:0Pl0040:0Pl0040?n0001@T7P00?l0003o00P0oooo01l0P:iH096MX`1TOX@0M8jE06:0R027XjX0
R:6Y0:fm`P2HXZ<0SY6;096@RP2BSh<0UI:309ZDQ02LUhD0X9V60:FIQ02[VH40/IYn0;:MOP2dWh@0
^j:70;VUQ`2mZ8/0aJjE0<B/T@34[i80a[2F0<NbVP3:]id0b[ZO0080c[bT02X0dL2[0=G3[@3K`:X0
bEA:0=DL5@3::2<0Q65l05=aU`33^kH0cKZ[0<n]WP2lJ640]R0N0<L@40323Q00^@d@0;DD5@2?AE80
Kg620:fWY@2iTXh0Yd0o0:L<3@2O7b<0GD5N03=BOP1INYH0DGF=0;W?gP2UOhT0Q`lE05LjCP2[aM<0
^/OB0;_;e@2kb]<0/[k70;>n``25Th00WJ1L09B;5`1iR@l>003o00P0oooo00D0X23`0;Ph]02h>;@0
X23`0;Ph]0030:0Pl0030=1@N03oP000oh0000<0oh005P2P8?030?n000030;Ph]02P8?00j6Pl0080
d51h1P3oP000103XJ3`0^3Rd0>QX?03XJ3`30?n000030;Ph]02P8?00X23`0080X23`00<0d51h0?n0
003XJ3`01@2P8?020;Ph]0<0X23`3P00o`0;0?ooo`002P3oool0@`00o`00DX8Q059QF`19F5L00@81
00<20@0100000`4101`10P0_0P<0=@4204421@1C0`D0J0@806l:3@1d1`/0PPH:09T71`2g3P/0`@d:
0<H?30345Q80^AhL0;0Q7P2^5Q<0^@l>0<8?3@333P/0a@l<0<D@3@343``0aQ4>0<LA3P2o5A80WAHE
06l^9P39^K00g][I0=gLg@3Ti>@0i>GW0>GUi`3WhnH0j]kO0=fh]`33Ph80/6UY0:e_K`3C_;P0fMSF
0=KEeP3IeML0[85m094B3P2G3P/0Z5=20<k2]`3Bdm<0e/[708Y3>`2B20T0U0@908/21P2:0PL0R@84
08P21@270@@00P260PD04@250PH0PP8309/8202]20T0[PP<0:l:3`2/6Q`0P`/<095ADP38`l@0]l;3
0;g:d`30cmX0Xk>l08JFW@1cKfl0=:4C00800?l02@3oool00`00o`00X23`0?n0000Y0?n00080j6Pl
0P3@D7P40?n000030>QX?03oP000oh000080d51h503oP0000`3XJ3`0d51h0=1@N0040:0Pl0040?n0
0020`0000?l0003o00P0oooo04`0JKDl09FQX@1hSYT0JhRB07fHWP1kUYl0Rj>[0<3>e02JXZ<0Q8N2
08^:P@2BTX@0UI>509bFQ`2PVHX0X9Z80:NLR@2[VhH0/If40;>OQ@2gX8H0^:690;ZTR02lYh/0`:^B
0<6/TP32[980ajjH0<JbVP38]ih0bkVQ0<jkY03A_ZH0e<2Y0=K4[@3Q^jT0`S@[0=<N5@2iF640CUR2
0;V8TP3:Mfl0eJJI0<^:P02[9240aQDE0;lH5`2O@Td0PdIF0:P/;`2[5aH0`GEX0;=XG@2W8b00YPl<
09H_=@18>U`0>5Al08ZJZP2IZ[P0UK720:S0d02KKGL0R0hF05A0E@2ab=L0_LWD0;g;e`2lcML0//3:
0:jnbP1OLWd0OHUi09:DCP2KSAl08]/53@00o`080?ooo`0307QH]03@D7P0X23`0080^3Rd0`2P8?00
0`3XJ3`0oh000?n000040?n001D0X23`0P3oP000103@D7P0X23`0;Ph]03oP0020>QX?0<0oh0000D0
j6Pl0=1@N03oP000oh000>QX?0030?n000030>QX?02h>;@0X23`00@0X23`00<0d51h0?n0002h>;@0
1P2P8?001@2h>;@0j6Pl0:0Pl02P8?00D91h00d00?l02`3oool000X0oooo05H00?l004Qf5@0lBT<0
B5EG00810@030P40000000D1000R0P80?@8404X2101E0PD0IPD807L=4@2W=3L0PA@G07`42@2@10H0
Z@P90<0=2`373PT0bA0=0<<<2P2j2PP0]`X:0;X;2P2k30X0^`T80<4=2P323@d0`Ph?0<<@3`324Q80
RAD>06m1=P2n[J@0g=SG0=_Kg03Ng]h0i>?U0>_TiP3]alP0hi>F0=QNGP36:RD0_a`I0:PB4@2O6AL0
Yg9Y0=SGe03Ce]H0elk>0957@P2I40h0Ta0;0:YWEP3Ab/@0d<oB0=S=cP2:Bd@0SPP80984202<0PH0
R`<908T21P280@@0Q`8508L21P280`D0PP8508841`2@10H0[PT=0:d8302`2Ph0[0d>08T;302FFe@0
/jfX09jXZ@2ea</0_<gF0:jobP21TIT0N7Ef03JS5`800?l02@3oool01000o`00d51h0?n0003@D7PU
0?n000030>QX?03@D7P0j6Pl00/0oh0000<0d51h0?n0003XJ3`05@3oP0000`3@D7P0X23`0:0Pl002
0:0Pl0040?n00020`0000?l0003o00P0oooo04`0Dl</09RQWP2<XZd0J8J?06V6S`1cSYD0PIfU0:>f
_02RZ:/0OX1k08V9P@2ASX80ViN909bHRP2RVh`0Yin@0:fRU02cXYH0]Z>?0;NQRP2jXX/0^:::0;RT
RP2lYhd0`ZjE0<:^UP34[ID0ajjI0<NbW038]9l0c;NQ0<jjX`3A_jX0dKn[0=G3[`3P/Z40`BPP0<TU
802UK7h0/EU[0<LN8@386aP0^eeL0;Q_L02d7ah0aA<C0;/nA011@6H0P82@0<>1O@2/5140]10A0:h@
402T8b@0MSa?02H_F@1FMI00[[k6096PZ@1lTJ00@F1k09R``@2BF6<0RPlG05A9GP2ecM/0_LcI0<3<
f@2oc=P0^LOC0:c0c01eT:D0KXNC09fWV@2HTUP0>M4L3@00o`080?ooo`03052@N03@D7P0X23`00<0
^3Rd0P2P8?000`3@D7P0oh000?n000030?n00080d51h00<0j6Pl0?n0002P8?004@2P8?020?n00003
0:0Pl02h>;@0oh000080oh0000H0j6Pl0?n0003oP000j6Pl0:0Pl02h>;@50?n000040=1@N02P8?00
X23`0;Ph]0@0X23`00<0d51h0?n0002h>;@0202P8?000`3@D7P0X23`052@N00=003o00/0oooo000:
0?ooo`1F003o0011KP`0E65H04eIF`040P801@8200<1000@0@40<08404L21@1;0@D0CP4405P31P22
2@/0W0P:08/92P1f1@L0SPD809T31P2c2PX0`Pd90<H?2`363``0`@h;0;T92@2i2`X0^0X80;`;2`31
3@/0`Ph=0<4>3@314100W1@B08MOD`3<a;T0g=SF0=[Jf`3LgMd0h]kM0>W=c@3JOh<0dSLf0=LO7@3L
7Q/0da/E0<dJ5P2h5a@0QAXE09N0M03Gf=D0dmCD0;JGU@2<71X0V@h;08`A2P2aNFX0eM3<0=3@dP3F
dM40SV9L08H;2P2@0PD0SP<508/31`2;0PH0Q@4308<10`220@D0Q@8508P31`280`P0R`870:P8302a
20/0/`/>0;0<3@2=30`0YGUa09BDR`2:UI40^<G;0;C4c02hall0QYJM06m[K00hYAT2003o00T0oooo
00@00?l00=1@N03oP000d51h8`3oP0000`3XJ3`0d51h0?n0000V0?n000@0X23`00@0oh0008300000
o`000?l0203oool0@`17aQh0UiZC082GXP1eTYh0EWQm06>0P`2=YJ`0QIVQ0:Nb]@1iOGT0QHEn08f<
PP2MV8h0YIjD0:^TV02_YYX0/jNJ0;FWV@2aXHl0/in;0;JQRP2hY8X0^ZJ=0;ZVS02mZ980`:VC0<>[
U035[iP0ak6J0<RdW@3<^J@0ckbV0<noZ@3A`:d0eLB^0>2iY@2n<BL0cR`Y0=MeO@3592D0dQLF0<0S
801jE6/0SGR:0:Po?P2h6aX0_A/O0;I2B02f@3d0/24M0;H>3P2d30`0UCHh03ddD@0jAVh0OgR40:BD
SP35`L00^L3309j`^P1jUZ/0PYV]08]7D02;4aX0EDmW0;K>f`2lbmH00P2nc]P01`2kcMX0[l;?07:;
W01gTYl0UjBW09RLUP1AZT<03@00o`080?ooo`04052@N02P8?00X23`0:0Pl080d51h00<0X23`0;Ph
]02P8?001@3oP000103@D7P0j6Pl0?n0003oP00B0:0Pl080oh0000@0d51h0?n0003oP000oh000P2h
>;@30?n000030=1@N03oP000oh0000<0oh0000<0^3Rd0:0Pl02h>;@00P3oP0040:0Pl0030=1@N03o
P000^3Rd00P0X23`00<0^3Rd0=1@N02XR3`03@00o`0;0?ooo`002P3oool0EP00o`00A7<C05aYH`19
EeP00`4100L10@0:00007`4303l31P170@@0AP<404810`1:0P@0QPX@09D:3@1d1@L0J`<408/41P2B
0PD0Y0D60;`<2@302`T0a0d;0<8>2`2i2PP0^P`;0;/920333@h0``d<0<8=302o2`X0]Q4@07HW8039
_[D0f=SF0=[Jf`3JfM/0hm[J0=nd/`3;Fe/0eRLU0=hO6P3E5@l0daHB0=0G50366AH0WAXG068^8`38
`[P0e]KD0<Zl_02@BDP0UQ0>09P<2P243`D0]XIg0=GBd03@dM<0dmCC08igL`1h3Q00T@@808l31@2:
0P@0Q@4208810`1n00<0OP4408<21P290`T0R`@:08T31`2Q1``0[PP;0;8:302d3@d0W@/>08i6@P2S
Th`0TYRE0:Rg^P2nc=D0/;g608nPYP1fMWL0>ZPN0P00o`090?ooo`04003o003@D7P0oh000=1@N4`0
oh0000H0d51h0:0Pl02P8?00X23`0=1@N020`002003o00P0oooo04`09]/=09NBQ@2G[;H0FWN005mm
P`1KNGh0FgEm07Z=T@2`^K`0MWUg0861NP2<RGl0V9B:0:BOV02]Yj00[:>I0;2UUP2]Xi40/ZFA0;6P
S02cWhL0^JB;0;ZUS02oYhl0`J^D0<6ZU@33Zi@0a:jH0<J_V03:]9d0bKRP0<^jX@3>_Z@0d/6Y0=;0
Y`3H`jl0dW]_0<PZ8@3<9b@0b2<M0<93@@28Hg`0=eR40;2c/`3@/Z@0`h9e0;M4?P2b=3@0Z3/n09M3
B`2b>S/0Z`h>09Q;E`24@UD0ZC]30:4N8@2Q7R<0X3]10:AgN023S9H0Rj2b08JFZP27=C/0RaDM05UJ
L@2jd=`0^/[E0;S<e`2hbmL0^/cI0;S9eP1hSZ<0DFj307jCW@2?W:00NG=]3@00o`080?ooo`04052@
N03@D7P0X23`0:0Pl0<0d51h0P2h>;@70?n000030;Ph]02P8?00X23`0140X23`00L0j6Pl0?n0003o
P000oh000>QX?02h>;@0X23`00<0d51h0`3oP0001P3@D7P0j6Pl0?n0003oP000d51h0>QX?0<0oh00
00@0d51h0;Ph]02P8?00X23`0P3oP0000`2h>;@0X23`0:0Pl0080:0Pl0030=1@N000o`000?l000/0
0?l02`3oool000X0oooo05H00?l004=c4P1FIV00B5EG00@10@0@0@406P4102T10P130PD0A`8503/1
0P0o0@80?P8505X62`1S1@P0C`4307052@2=1@L0T`@609d4102i30/0`0/:0<<=2`3130T0_PX90<0=
302o30`0_@`=0;d;302n30`0_A0>09DD402SPWL0fMGB0=[If`3Kf]d0g]?E0<b6QP34?3X0dB4L0=PI
503F6A40dAL@0=0F4`376QP0SATC060^902]XI@0f]OC0<Jn_@24DU00RATI09T<3@2L3@l0RQL?0;bB
Q@3Cd]40d=7C0=7Bd@2/Y:40EPh=08`72P2;0PD0R@8508H20`220P<0O@43080110240P@0Q@<508T4
1`2910D0U`D90:d8302c2@/0]0`<0:T=3`1m3Q40HbDU09^ASP2]^[h0`LoG0;k<e`2:W:<0IVU[03ZY
80800?l02@3oool01000o`00d51h0?n0003@D7PP0?n000030>QX?03oP000oh0000P0oh0000<0j6Pl
0?n0003oP0007P3oP0040:0Pl0040?n00020`0000?l0003o00P0oooo04d07^@909nCQ@2:WZX0I7n8
05aiOP1iTiP0P9RM0:^k_`2g`<H0NGan08:1N`2;R7l0VI>:0:6MU@2ZYYh0Z:FI0:fUUP2`Y9H0]ZJE
0;>QSP2eX8T0^JB=0;bWS`2lYXl0`:RA0<6YTP31Zi<0`ZfF0<FaV`37]Yh0bkVR0<bjX`3?_ZL0d/6Z
0=K4[P3Fa;@0g<Jd0=fZW02`MWD0PVb0055WRP1SP9h0/;>g0<Fj[`35^JX0aKJW0;FSVP1oNXH0G6Aj
06EUN`2R?T@0/`/=0;8B5P2`2Pl0/`H<0;862`2_10X0ZPD:09h>4`2XL7P0I7J805QQM0259bl0SAHQ
05UMM@2jdM/0^L[E0;[<f@2kcMP0_<gI0;W;f02I/LL0Oib`096V/02KZk40QHB400[V100<003o00P0
oooo00D0D91h0;Ph]02P8?00X23`0>QX?0040:0Pl0030>QX?03oP000oh0000@0oh000P3XJ3`A0:0P
l0@0j6Pl00D0^3Rd0:0Pl02P8?00d51h0?n000020=1@N0050>QX?02h>;@0X23`0:0Pl03XJ3`0203o
P0000`3@D7P0^3Rd0:0Pl0020?n000/0X23`00<0d51h02S8?000o`002`00o`0;0?ooo`002P3oool0
EP00o`00@W<F06UjM`17De@04P8202H20`0W0@40<00204D21@1>0PH0CP4405@21P110`H0CB//081C
D`1E2``0P0H:09052@2F10L0W@D60:h8202n2`X0``/<0<8<2`2o2`X0^PX70;H82@2i2P`0_0X=0;h>
402b8A`0Rd]20=O@b`3KgMd0gMgN0=OFeP25Jf/0OAlN0;PM6`3F6aL0eQPB0=<G4P3D6AH0a1/I07PG
4`1oIeh0c<Bm0=oLfP3;cL/0B4a7028?2P1;2PX0S@h@09X>402<7aL0`IZ>0=?Bd@3?d=80dM7E0<W9
b016;R`0K`/<08P51P280`<0R0<408<10@200@40O`4307l110220@D0Q0<708P42@2>0PD0[@/<0;89
2P2c2Pd0[``>090B4P1R5140Wh^:0;O3bP30d=T0//?;09FU[01NHV@0>j`Q0P00o`090?ooo`04003o
003@D7P0oh000=1@N200oh0000<0j6Pl0?n0003oP0004`3oP0000`3@D7P0oh000?n0000B0?n00003
0>QX?02P8?00X23`0080X23`00@0oh0008300000o`000?l0203oool06@00o`00WHYc08fOZ`1YQXl0
KhZ?069nP`1NO7l0RZ:W0;G4b@1nPh@0P85k08b;P02KUX/0Y9fE0:JQV@2XY9X0ZjFH0;2UUP2fYIH0
]j6?0;NOR@2iXX`0_:F>0;ZTS@2nYi000P30Zi<0<P32[iP0a[:M0<RfX03:^J<0cKbY0=2nZ`3A_jX0
e<:_0=W7]`3EakX0e/Rl0<c2^`2j^;T0`knm0<[0]P39_Jl0a[Z/0<6gZ@33^J/0`;JX0;^aXP2gZI/0
^X5i0:TH5`2f2@/0/`P90;D72P2f1P/0]0L90;46202`1@L0[0D909DG7`2FSj40Y:>^08PN9@2>5b80
G6Am0;W?f`2lcMP0^lcH0;g>f`2kc=X0^/_H08RO]01dTZD0Q9RR092OYP22Q8P05kl<3000o`080?oo
o`0:003o003@D7P0X23`0:0Pl02h>;@0d51h0?n0002h>;@0X23`0>QX?0L0oh0000<0^3Rd0=1@N02P
8?003`2P8?030?n000030>QX?03@D7P0d51h00D0oh000P2h>;@00`3XJ3`0oh000?n000090?n00080
X23`0P3oP00;0:0Pl0030=1@N01@T7P00?l000/00?l02`3oool000X0oooo05H00?l004Uo9`1JKFl0
Ce=G02T4100e0`@0:P4102l10`130P<0C@4505021P1D0@@0G@/?07=4A@26D4l0O1/K08H51P2A1@P0
V0@709`51P2T1@L0^``<0<8<30313@/0^`/70;P:202j2`/0_0/;0;l<3@2d5a80_fUK0<2YWP3KfMT0
gMkP0=;FeP1YLVh0GUiG07]UG02?=2l0bR0K0=/K5`3?71X0ZQXI06PI5@2AOgD0fMC<0=kNfP3JfMP0
alS20;:aYP2PVhl0IeM?06/A4P2H3A00SR0I0<BOU03CdM80c]3C0<oBeP3?d]@0TI:<02P91`1R2@X0
PP@608D20P210@80P04207h10`200PH0R0L808D31P2610P0Q0450:@:2`2a2P/0/PX>0;4>3`2/<S00
Q3Tg09anOP2a_<80_/cE0<;?f@2CXjd0HV=T03NW70800?l02@3oool01000o`00d51h0?n0003@D7Pe
0?n000030>QX?03@D7P0oh0001<0oh0000<0d51h0:0Pl02P8?000P2P8?00103@D7P0P<00003o0000
o`080?ooo`1=003o002XSVd0UZNb08BOZP1TP8T0DG1e06N6R01_RXh0[;c008J;SP20P7`0S8b509jK
T`2QWIH0YZ6M0:ZTW@2/YIX0[jJH0;FUU@2cXHh0]::=0;JRS02iY8`0^jN>0;^VS`2oZY@0_Z^E0<2]
U`36/I`0b[FQ0<fiY`3?_:`0d;jZ0=70Z`3D`k00eLFd0=K9^P3Cb;P0d<Rh0<o4^@3:`[@0bL6b0<Nm
/P33^jh0^kNY0;bgZP2i/JD0^:bO0;b8P@2Z9BL0]@/=0;@92P2c20X0]@T;0:`9302U4aD0XQ`P0:D<
4P2[10P0V@H=05LkFP1_LhP0R1HM08lD7P1PIW`0^/oL0;?5c`2kcMP0^/cH0;_<e`2gbML0W:o505A`
QP1gSIL0RY^O08^DU`0UWQX03000o`080?ooo`06003o003@D7P0X23`0:0Pl02h>;@0oh000P3@D7P0
0`2h>;@0d51h0?n000060?n000030>QX?02P8?00X23`00/0X23`00D0d51h0:0Pl02P8?00X23`0=1@
N0020?n000030>QX?03oP000j6Pl00<0oh0000@0d51h0?n0003oP000j6Pl303oP0020:0Pl080oh00
2`2P8?000`2h>;@0P<00003o000;003o00/0oooo000:0?ooo`1F003o001=PRh0P96E061OH`0`10@0
<@4302D00@0b0PD0B0@504T20`1;0@@0D@450602201[2Q40LPX?07/420281@L0TPD709T31`2M1@P0
W`@70;L<3@333@d0`P`<0;`;2@2h2`T0^`d>0;T;2P2g2P/0]2/S0<NAP@3EbL80f=SJ0=CAc`1VJF80
O89h0=;=aP3Od/d0hZbU0<4b;03?71/0S1LG03`<1P2;OG00fmKA0=oPg`3Qhn80h>3P0=cLf`3Dem80
e=C>0<o5_P26@Sd0T`h?08lO6034WiD0dM7B0<gAe03>dmD0d=CF0<[:b00m>CD0704006@72P210@<0
O`4207l00@1o0P<0PP@60847201j0@@0O`<:07`31P2G1PT0[0P90;4;302a2`d0W0d?07d?402EGel0
ZK6c0;g:d`2]^lL0XK6k05eOH@0gYad2003o00T0oooo00@00?l00=1@N02P8?00d51hB`3oP0000`3@
D7P0X23`0:0Pl0020:0Pl0040=1@N020`0000?l0003o00P0oooo04d00?l008FcG@2DY:h0RjBb05Ib
O00_Be00GgQl06=oQ02X^;`0SiBF07amN@2<RhD0V9V?09fMT`2UX9L0[:BL0:nVW02^XiP0/jFI0;BP
T@2fXXd0]j6>0;NSS02iYHh0_JR@0;bXTP2m[9D0_jjI0<>dWP39_JX0bkZ/0<jnZ`3>_jX0cl6/0=;4
/P3Aa[H0d/Vh0=;8^P3?a[T0cLBj0<W2]@37`;<0b;jh0<>j/P2o]jh0^kBZ0;Z`Y02nShX0Z2HW0;P=
3`2h2Pd0/PP:0:T?3P2N:c40LSeB04E0H`12BVT0Qe9N0:4:402E20d0ED1K07f2V0274aX0SP`G06EQ
N02hcm`0^l[F0;S:e`2fb=H0^<[G0;C6e@2S]/`0Mi2V08jS[P2HZ[00V:>X03mc;P0<003o00P0oooo
00X00?l00:0Pl02P8?00X23`0=1@N03oP000d51h0;Ph]02P8?00d51h2@3oP0000`3@D7P0X23`0:0P
l0070:0Pl0030;Ph]03XJ3`0X23`00<0X23`00<0j6Pl0?n0003oP0000P3oP0020>QX?0/0oh0000D0
j6Pl0=1@N02P8?00X23`0>QX?0020?n00080X23`0P3oP00<0:0Pl0030=1@N000o`000?l000X00?l0
2`3oool000X0oooo05H00?l0066JBP2=X:P0JfQ`03X51P0f0P80:P4103<20`140`H0?P4303l10`18
0@@0G`8807442P1g0`X0P0<908T52P2A10L0V0@809`31`2O1PL0[`T:0;h<302o2``0^@X;0;@82@2f
2@/0]@T90;H:2`2d?380^YB60=SAc`3Fe=D0UXF008=_I03>b<00fm_K0=oMg@3UbLT0[DE307`F4`1M
@3T0Yj:I0=KDc@3OhN40g>3R0=_Ph03MhN80fmgO0=GHf03AeMD0eMCD0:f2OP2<5140RQXC0;jGS`3B
d=<0cm;E0<kAe03?d]D0cm7D09nMV@0j8Ql0H@T908420`220@<0OP4307d10`2:4180PaDD07821@1Y
0P@0QB0Q090:302^3@h0/@/;0;8<3@2U4100SQHG08@m?P2h^;/0]Ko80<;>e`2JZ[<0KG1d03b/8`80
0?l02@3oool01000o`00d51h0:0Pl03@D7Pd0?n000050=1@N03oP000oh000?n0003XJ3`04`3oP000
1P2h>;@0X23`0:0Pl02P8?00d51h083000800?l0203oool0C@00o`00PJM809ZU[@1kUj<0>EMP05A/
L@1UOhH0NiFJ09BVZP2GWj80O7ij08F5OP2FV8d0XJ2F0:JSV`2/YYh0/ZJP0;6UW02bY9T0/j>C0;>Q
S@2cX8T0]j::0;^TS02kYhl0_JZB0;n/UP2iZiP0/[2T0<_?cP3=bL40c;bZ0<boZ03<`:`0c/6a0<c3
/P3@aKH0d<Fg0<c3]P39`KT0bKnh0<W0^035_KD0_[R_0;bh[@2l]JX0`Z>K0:Xb=02h3Q40^@/>0;4=
3`2P;C40JdQP02/lI`12F7L0NXRC09jOWP2WM7@0WP`@09HP900d=U<0TY2P08HA6@2>1Pl0IU5T0;O@
g02kbm@0^/cE0;[<f02gbML0[L3=09BZ_P1<KX@0NiJQ086DW022SiT0@e`j00`00?l0203oool01000
o`00X23`0;Ph]02P8?030=1@N0030:0Pl02h>;@0d51h00T0oh0000<0d51h0:0Pl02P8?001P2P8?02
0>QX?0060?n0002P8?00X23`0:0Pl03XJ3`0X23`3`3oP0001`3XJ3`0^3Rd0:0Pl02P8?00^3Rd0=1@
N03XJ3`00P3oP0020:0Pl080oh0000<0d51h0:0Pl02P8?002@2P8?000`3XJ3`00?l0003o000:003o
00/0oooo000:0?ooo`0^003o002:NUh0ZKc806]YLP0l1@H0?@<302T10P0S0@80=P8303<20P0c0@40
@04305/11P1b0`P0O0<908422P230`P0R@@609D41`2H0`D0W`L80:L61`2h30`0^0/<09d51P2F1@H0
[PP;0;87202b20P0/D0c0;fPTP3Gdm80c<[:06]YG03?a[d0emCD0=KGf03<cLd0RGel04PW8`1nLVT0
b/[30=WIf03Ifm/0f]kO0=[Kg@80fMgN02H0f][L0=SIf`3EfM/0dmSH0;^TXP2761D0RQH@0;^?Q`3C
dmH0cM;D0<oCe@3?dmH0cM;D0<g?c`35]k80Te59084610250P@0Q04507l11@1n0PD0N@8407@10P1T
0P<0QQ<H09H;402P2P/0/Ph=0;<=302W61L0gG]n06lW:P2h[[80]<770;c9dP2V]L00IVab042c;@80
0?l02@3oool01000o`00d51h0:0Pl03@D7PR0?n000030=1@N03oP000oh0002D0oh0000<0d51h0?n0
002P8?000`2P8?00103@D7P0P<00003o0000o`080?ooo`1=003o001FaC40UijS072:V012GfL0>e=J
05UcM`1PO840S::Y09nZ[@1nPh00S8n809NISP2PWYP0Z::L0:fUWP2^Y9h0/:FK0:fQUP2aXI40]:6?
0;FQRP2fXXT0^ZF=0;^XS`2mZY40_JbF0:>JR`34aKd0^Kfj0<S1]03:_:T0cKj[0<boZ`3>`[40c/>b
0<o4]`3=a;P0c<Fi0<[2^03;aK`0a/2f0<:l/`2n^;40_KN_0;jaZ@2dH5h0^1<E0;X=402]5aL0TDE?
03LlIP0nFWh0Qi>H09fMT`2RX940[IR?09`c=@2Q2@d0NSU:01`lI@1kOHP0PQ8G09H53P1Y=TH0[lWH
0;[;e`2jb]L0^l[J0;[9e`2dam<0Y;W906>0TP1nV:00QYVO07j>V@0h>SX03000o`080?ooo`04003o
001@T7P0d51h0:0Pl080j6Pl0P3@D7P20;Ph]0T0oh0000<0d51h0:0Pl02P8?001@2P8?00103XJ3`0
oh000?n0003XJ3`30:0Pl0030;Ph]03@D7P0oh0000d0oh0000H0j6Pl0:0Pl02P8?00d51h0?n0003X
J3`30?n000030=1@N02P8?00^3Rd0080oh0000<0d51h0:0Pl02P8?002@2P8?000`3oP0000?l0003o
000:003o00/0oooo000:0?ooo`1F003o002?OfD0MhfJ06EVK00i1@@0>`<202410@0J0@40=P8302h1
0P0`0000A`4405/10`1a0PD0NP0508842P250`P0R`@708h20`2C0`D0V@@609l41P2^2@/0/`X:0:D9
2`2B0`@0Z@L80;48202a1`H0[RdU0<BERP3IdLl0d<k=0;:^Y03Ed/d0eMKE0=7Dd`1hQX4052<H07Qi
K@3@c/D0f=_J0=OLf`3Fg=/0emgL0=OIfP3FfmX0em_K0=[Jf`3HfM`0e=SK0=;Ge`2aTI00Ra<C090D
4P2cOgL0dmCE0<gAe03@eMH0cM;D0<gBd`3;c<d0[IRH08@k=`241PP0R08608L110230PD0O`8507X2
101g0@<0I`4207d5202Q2@h0S`430:X=3P2b30`0[0dA09X@5`1d4aL0a;Fj0;6l``36dmd0UJJc07Ak
P`10/R`2003o00T0oooo00@00?l00=1@N02P8?00d51h>P3oP0000`2P8?00oh000?n0000?0?n000@0
X23`00@0d51h08300000o`000?l0203oool0CP00o`00E/4X0:2RXP1^Q9<0CVYd04IPI@1FLWT0NYFJ
08VNXP2X]KX0QH^<09:CT02IVY@0XZ6I0:FSV`2YXid0[JBM0:nSVP2bXID0/9n?0;:OSP2dWXX0/j28
0;JUSP2hYi80^ZVB0<6^V02_X900YYnB0;J_W`3<_JX0c;f[0<fm[P3;_:X0cL6_0<c0/`3<`kP0cL>j
0<k3^`3;`[T0bL6i0<Jo]@34_K@0_;Za0;fi/@39[jX0ZRT]0;d?4P2a71X0aVUT08m6D`27Gfh0Wi^E
0:>RUP2QX9<0ZinC0:AIE`2P3@l0V2/c02l`F`1aT:P0XjR_080H7P2H0`X0OAl/09n/^`2kbmP0]lSE
0;S9e`2hb=H0]<OD09ba`P1_Rih0NI:L09>X[@2@XZX0?4A600[V10/00?l0203oool01`00o`00D91h
0=1@N02h>;@0d51h0>QX?03@D7P00`2P8?090?n000030=1@N02h>;@0X23`00D0X23`00P0^3Rd0>QX
?02h>;@0X23`0;Ph]03@D7P0X23`0;Ph]0X0oh0000<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0d51h
0>QX?0050?n000040>QX?02P8?00X23`0:0Pl0<0oh002`2P8?000`3oP000:<Pl003o000:003o00/0
oooo000:0?ooo`06003o001hIdT0QIbT06e[LP0h1@D0<@820P0M0@40CP0h0P@0=`4204030`1=0P@0
GP<407421P1l0PP0PP<708D31`2;0`D0T@D609<41`2K1@P0V@<60:<5202^2@T0[PL70:X51P2^1`L0
/PL80;D82P2^40h0]e5;0=>]ZP3Hd]80f=;@0=K>cP3=^[/0NgAb041<@@2FVHd0cLg60=[KfP3Ff]/0
emcL0=WKg03JgMd0f]_L0=SIf`3GfMX0fMWL0=OGg03BemT0d]3A099DD`2D4140U18@0:=TG@3Bd=00
cm?F0<kCeP3?d]D0d=7B0:Z=SP1n:bX0Q0`=08P320230@@0Q08307l10`1l0@80NP4407T10`1W0P<0
NP@60:072`2@1@L0V`/=0;8=3P2_2`h0XP`?08/V9`2bYZP0]L780;k=e`2Y^/P0JgEk05R0<`800?l0
2@3oool01000o`00d51h0:0Pl03@D7PO0?n000030=1@N03oP000oh0000d0oh0000<0j6Pl0?n0003o
P0001`3oP0000`3@D7P0oh000?n0000@0?n000040;Ph]02P8?00X23`0:0Pl080d51h0P00o`080?oo
o`1>003o000Zga<0UIF?092W]@10G6D0@eaR04MQI@1dSi<0MXjC0;O2b025RXh0T92>09ZHU@2QWiX0
Yj:L0:VRVP2]Y9`0[Z:J0:nQT`2bXI80/Z2=0;BPR`2dX8P0]jJ>0;^WTP2mZYL0`K6N0<FcX035/j<0
bKZX0<^iY`3=_Z`0bkna0<Rl[03:`Zh0b/:b0<_4]`39`KL0c<>k0<[2^@38`KX0a;jg0<:m]@2n^[00
_kRa0<FUXP2Z7b<0]a8A0<UDCP2V7b00[Pd@09/K7P2<OGh0Wj:K0:bLU02WG5/0Xa0D0:D:3@2M@4/0
IT]T0:VVZ`2CU9`0Q2H^09T22@2;1a40V7N40;k=e`2hbMD0^L_H0;K9e02fb=D0YK_<04iZOP1]QXl0
K86507F8SP0kB4l06L8=2`00o`080?ooo`04003o001@T7P0^3Rd0:0Pl0<0j6Pl00@0d51h0;Ph]02P
8?00^3Rd203oP0000`3XJ3`0X23`0:0Pl00:0:0Pl0040>QX?03@D7P0X23`0=1@N0T0oh0000<0j6Pl
0?n0003oP000103oP0000`3XJ3`0oh000?n000030?n000040>QX?02h>;@0X23`0:0Pl0<0oh0000<0
^3Rd0:0Pl02P8?001P2P8?00103@D7P0^3Rd0?n0001@T7P;003o00/0oooo000:0?ooo`0L003o001o
KU40WK:o06aYL`0d1@L09@4101`10@0S0@40=@8403020P0d0040BP8405h21@1c0`L0OP<708D52@26
10T0RP@608l31P2E10P0V@<609@21@2G0PD0Y@D80:l6202`1PL0/PD70;852080]@L;00/0/`/>0;0W
9`2iFE/0]UmR0:M:C01^:RP0He990<6o]`3Hf=D0f=[K0=WKg@020=SJg00[0=gHg03La//0`Y6F09e_
L`25NG/0dM?D0=OGf`3AeML0Whj>084M7`2J3A00VPh?09Y1?03AalD0cM;C0<kCe@3?e=D0bLG607`c
<P2;2P/0RPD708@210220@<0P04107h10`1l0P80N`4307L10`1W0P<0MP@60:<:3P2F2`l0QPH90:l<
4@2`30l0YP/>08PE602RRH`0/;k50<3@f`2U]Kl0Lgf105R3=@02003o00T0oooo00@00?l00=1@N02P
8?00d51h703oP0000`3XJ3`0d51h0?n000090?n000@0d51h303oP0000`3XJ3`0oh000?n0000A0?n0
00040;Ph]02P8?00X23`0:0Pl080d51h0P00o`080?ooo`1>003o000Xf``0TXYj086FX01PNh@0?5AJ
055_M`1eTIL0OYBI0<C>eP29S940SXf=09JFTP2NViL0YIjL0:ZQWP2^YI`0[Z:I0:bOT`2^WXl0/Ij<
0;>PR@2hX8T0^:B<0;fXU02mZYP0_J^L0<:aX036/j<0b[NV0<ZjZ03<_jh0bkna0<Nn[P35_Jh0al2a
0<K2]@3:`KL0b<2g0<W3^P35`KP0`knf0<2m]02n_;<0_KJ^0<N`[@2X=CP0]A4B0<0/;02c3Q40ZA4B
098mC@0^>V40XY6E0:96A@2W3a40Z`H90:X42@2U1@T0WPT@09Pc=P2WT940RCTn09P32`2I10`0QR4Z
0<:f`02ibM@0]lWD0;G8e02fb]L0Xk_?04aYQP0kEG<0;TMR03Q@I`0aB540:Z@K2`00o`080?ooo`03
003o001@T7P0d51h0080^3Rd00<0j6Pl0;Ph]02h>;@00`2P8?030?n000030=1@N03XJ3`0oh0000<0
oh001P2P8?000`2h>;@0X23`0:0Pl0020:0Pl0040;Ph]03oP000j6Pl0=1@N0X0oh0000<0j6Pl0?n0
003oP0000`3oP0000`3XJ3`0X23`0=1@N0070?n000030=1@N03oP000oh000080oh002P2P8?000`3o
P000P<00003o000:003o00/0oooo000:0?ooo`0N003o0021KeH0WK2m06eXL`0_1@H07`4101/10@0R
0@40:P4201l10@0Z0@40AP8305h21@1b0PP0N`8608<420271@P0SP<709<41`2C0`D0TP<709021P2D
0PP0WP<70:`62@2`1`P0/0H80;862@2d1`T0]@X<0P2h30d0=P2h3a<0X1DE05lA3P1`Fe40bLRn0=OH
f@3If]`0em[J0=[Lg03Me=H0e;:f0<=hOP2Y>T00Jb0N05Hj=P2[Z:80e=WI0<g=d02e][D0E4m:064A
4@2H3Q00W0`@098N7`38/Jd0cmCE0=3Ce@3Ce=L0^Jb]07PE5@2<0`H0R`<608L20`260@40Q@830841
0`1n0@<0O04307L10P1Y0`<0E04207/73@1e1P/0L`D70:X=402`2`h0ZPX?098;3`2<EeT0Z[>j0<KC
gP2V]Kl0LWZ005V3=`800?l02@3oool01000o`00d51h0:0Pl03@D7PU0?n000030>QX?03@D7P0d51h
00D0oh0000<0j6Pl0=1@N03oP000703oP000103XJ3`0X23`0:0Pl02P8?020=1@N0800?l0203oool0
CP00o`005>h50:>GP02FZK@0A61Z05EaNP0dEU/0LH^>07V@UP33d=P0SI>H092AT@2IVIH0WI^G0::O
VP2VX9d0ZjFN0:ZOUP2ZWI40[Ib>0;:PS@2`WhX0]J290;VSS@2hYi@0^j^H0;j[V@31[Y`0a[>T0<Vg
YP37^:P0bK^^0<Zo/03:`K<0a;ba0<Jn]034`KD0a/:g0<O0]P38`KL0a/2h0<:o]P30`;X0`L2j0;ji
]02m][00_92?0:Tm?@2V9BP0X3<k07]:H@0n@fh0MTi[0:8U:P2[2P`0[PP90:T51`2W0PL0Y`<80:X4
2P2O1`d0PdaG08eHH@2C1Pd0V0<:08l43@29=d<0^[[30;C7d`2ebMX0Oi^j024mLP015Dl00A13004>
>`013SH06Ri303R5;0/00?l0203oool02@00o`00:<Pl0=1@N02P8?00d51h0;Ph]03oP000d51h0;Ph
]0020:0Pl0P0oh0000<0j6Pl0:0Pl02P8?00202P8?000`3@D7P0oh000?n0000@0?n000040>QX?02h
>;@0X23`0;Ph]0P0oh0000<0j6Pl0=1@N03oP0000P3oP0000`3XJ3`0X23`0:0Pl0070:0Pl0030>QX
?03@D7P00?l000X00?l02`3oool000X0oooo04400?l008MhH`2hbML0KfMb03041P0T0@807@000281
0@0Z0@409`4103420P130@@0E`4507431`1m1@P0PPD808P52@2?10H0T08508l2102?10H0T0<70983
202C0PH0X`@70:l62P2a1`X0/`L:0;@72P2e2@/0^@h>0;X>3`2b4A@0H0h=06]KCP32_[D0e]OE0=GH
f@3FfMX0eM[K0=WBdP32Q8L0ZcHk0:HV:`1G4100GU=:0;fn/`3Ff=<0eMWJ0=?De@3Cd<l0`;Zf07Dk
=`2E3a80VPX?098@4@2gRhP0c];B0=3De`3BeMP0]Z>U07PA4@2<0`D0SPD508P10P0208D10@0C08D2
101n0P<0N`4207P10P1b0`@0A@410546201@10P0G`<70:8=4`2[2`d0Z@X?09L:4@2=CU<0a<SA0<;>
f`2`_LX0N82605F3>002003o00T0oooo00@00?l00=1@N02P8?00d51h9@3oP0000`3@D7P0oh000?n0
000T0?n000040=1@N02P8?00X23`0:0Pl080d51h0P00o`080?ooo`800?l002<0ZiAb08fNZ01TOXX0
=eQM05AcN01IMGd0S:6X0;g;dP2EWJ00SiBD09JGU02JW9L0WYnI0::NVP2XX9P0YYfB0:ZKS`2]VX`0
/9b;0:fKQ`2bWXH0]J6:0;RVT@2lZ9<0_JZE0;j[V@30[ih0a;FT0<:gY@34^ZX0a[j_0<S0/`32^k40
`[ba0<Bn/P020<No]P0W0<G1^033`KP0`/6i0;no^02n_[L0`;ff0;jj/P2l/jh0]J^W07akR01;FgX0
DeEm08i0E@2X4aT0/@T=0:h72`2/1``0Z0@90:L52P2W10T0Z0<709`52@1U=4X0N6Qh08T<502F0PP0
U04;08T54029HV`0Zl?G051/V@047Ud00QMK004BD@013T<00@dn004<=@024Rh0?E`f00/00?l0203o
ool2003o000:0;Ph]02P8?00X23`0?n0003@D7P0^3Rd0:0Pl02h>;@0X23`0>QX?0P0oh002`2P8?00
0`3@D7P0j6Pl0?n0000=0?n000050>QX?02P8?00X23`0:0Pl03@D7P02@3oP0000`3XJ3`0^3Rd0?n0
00030?n000030=1@N02P8?00X23`00H0X23`00<0d51h0>QX?000o`002P00o`0;0?ooo`002P3oool0
EP00o`00QWMQ0:2b`01YI6d0;0<402H10@0O00008`4103020`0_0P80=08104D1101H0@H0K08507T2
1P1o0`L0Q@<808h41`2?0@H0S`@608h31`2<0`H0SP@608h21@2O1@L0[PP<0;062P2a1@L0]0L90;P<
3@2j3Pd0^0h@08hB501aDTT0`[fc0=KDd`3Ef=X0eMWK0=SJf`3Gb<T0_71d0:4];P1i6A/0BAPG07=/
H`37a[h0emWF0=WKfP3Ff=T0emSJ0=KHfP3FeMH0[HN608dC5`2H2@h0V0d?09]ED03AdL`0cMCE0<oD
e@2fYZL0MA4B08T31P2:0`@0R08308H10P240@40P08107`10P1j0@80N04207P71`1I51@0W6m_06Hf
=`1B0`D0V``?0:X;3P2V1``0VP/A09YNHP2g_LH0a=7O0;6ob`1kPXX0EX@i0P00o`090?ooo`04003o
003@D7P0X23`0=1@N2<0oh000P3XJ3`P0?n000030=1@N03oP000oh0000@0oh0000@0j6Pl0:0Pl02P
8?00X23`0P3@D7P2003o00P0oooo0P00o`00C@27/eh0UJB/04UWL`1BL7D0>e=G08FMX`2R]/00^LO?
09jW[@2;TI80UYNF09^IUP2OWIX0XIjI0:BMU02SVHh0YYJ<0:RERP2/VHL0[Ib70;6NQP2cXXX0]ZF=
0;NWS`2jZI@0_:^F0;bZU02n/9d0_;:O0<>gX`31^ZT0aKn`0<No]030_:l0`[fb0<Jo]P36`;/0`l:i
0<;0]`30`KH0_l6h0;fo]`2i^[<0^[Nb0;Vf/P2a/ZX0[ZfY0;2AUP2P<CX0/@hD0;D93`2c1`h0[@X=
0:4>502E9bl0RC@n09XJ802U1@T0UA@J03lbE`21S:<0Pb@[09L32`2D0@/0RP<;058WA@0VAGl00AUN
004EF@026EX032=E02@hE`0^@E`02Q/i00`Q=P0c=cP02ND300X00?l0203oool2003o00030:0Pl02h
>;@0d51h0080j6Pl102P8?000`3@D7P0oh000?n000060?n000030;Ph]02P8?00X23`00X0X23`00<0
d51h0?n0003oP000303oP0000`3XJ3`0^3Rd0>QX?0050?n00080j6Pl0`3oP0020:0Pl0@0oh0000<0
d51h0:0Pl02P8?001@2P8?00102h>;@0oh000?n0000Xb3`:003o00/0oooo000:0?ooo`13003o002?
Pfl0_m3P069LIP0`0`D0;P8302D20P0P0@40;P8203820`0c0@40A`8405l31P1]10L0MP<907`22@22
0`T0SP<909442@2@1@L0R`8508X31P2=0`L0T@4609`41`2P1`T0[`P<0;86202c2@X0]@`<0;H>3P2T
4a<0LChk0<S3_P3Ee]H0eMOH0=SHg03Gbld0_hnB0:I:C01g71h0A2@O06QTG@2^[jH0eMKB0=WKg03F
f]/0em[L0=GIf@3Cf=X0d]WJ0=7Hf@2jZJT0QQLI09T:3`2I2Ph0R1`J0<F]ZP3>d]<0cm;E0<:b]01g
61P0RP@708X31P270P80Q@4208810P0207d10`0A07X10`1e0@80L@81084_:`1Z=SL0L34d06l62`2K
20h0WPH<0:483P2M2a40UD]@0<C3c@32cmX0^<SB07V3RP1HQC`00P00o`090?ooo`04003o002h>;@0
X23`0=1@N240oh0000<0j6Pl0=1@N03XJ3`0:03oP0001P3XJ3`0X23`0:0Pl02P8?00^3Rd0=1@N080
0?l0203oool2003o001=07:Z?`2EWZ40EG1k03aHG01WPXP0N96M06f6T02eaLd0Yjnf08^@T@2=T8l0
UiJ@09fKU@2OWIT0X9V@0::FS@2UU8`0Z9N<0:bIRP2_VhT0/in:0;6NR02aX8P0/j:<0;FTS`2gYY40
]JF>0;JWTP2aXHh0]ZVF0;J]W@2o^Z/0a;fc0;jj[`30_K40`[nd0<C1^`33`kd0`L2i0<32^`2m`;T0
_Kni0;Vk]02j^K<0^;Na0;Bc[02iVYH0YRhc0;<<4`2e2Ph0/`T>0:@C5`2>>TP0E41W02TgIP1@@F80
U1hX0:842P2O=Cl0B4QY07JG[`25EEh0TPL>09<12@2410l0?Aa5008EF`0165T04RmR05YkX01PPY`0
Pif[04EMM00O=DT0CV=U02lh?@0Ab`P02P00o`080?ooo`800?l000@0X23`0=1@N02h>;@0j6Pl0P2P
8?00102h>;@0X23`0:0Pl03@D7P80?n000030>QX?02P8?00X23`00X0X23`00<0d51h0?n0003oP000
4P3oP000103@D7P0^3Rd0:0Pl02P8?020?n000040>QX?02P8?00X23`0=1@N0<0oh00202P8?00103X
J3`0oh000?n0001@T7P:003o00/0oooo000:0?ooo`06003o002KSg`0`m;O05Q?EP0X0P<0;P830P0R
0@40CP0[0@80;P4103l20`1?0PD0GP8506T31P1_0@D0O0<808D31P2?10P0S08508T210290PD0S@<7
08h11`2B0`H0W@D809l41`2/1PX0/0H90;D;3P2f3Pl0ZQ8A07DP702k/Z`0e=KF0=OGf@3IemX0dkk1
09iGF`1e92L0AAXH06MTG@2m_kL0e]K@0=WLf@3JgN00em_L0=OKg@3Ef]`0e=WH0=GHf`3EfM/0e=SJ
0:J0P`2@4aD0VPT>09/:3P2E2``0W5ID0=76a@3?d]80bL3107TV9@290`<0RP8308L10`230@80P`83
08421@1l0@<0N@8207L20P1d0@40M0L9088P8@1n5aH0PP@809/83@2I1@`0V@@<09h9401m51X0^Zjg
0;o<f@2^_l/0PX^D05F4?P800?l02@3oool01000o`00X23`0:0Pl03@D7PP0?n000030=1@N03XJ3`0
oh0000d0oh0000<0d51h0?n0003oP0001@3oP0000`3@D7P0oh000?n0000B0?n000<0X23`00@0^3Rd
0=1@N000o`000?l0203oool2003o001=056o:P2SZJ/0GGN205mkPP1FM7X0NI>M092W/035d]/0[KJm
07Z0PP1kOW/0U96=09bFT@2RViH0X9N?0:2ER`2PTHL0YiJ;0:ZHR02ZVH@0[9Z30:bLP`2_WHD0/Z29
0;6OQP2]W8<0[Ib10:^JP@2/WHD0[9n80:jUT@2_YiL0^k>W0<2k/030_K@0^;Rb0:b_[@31`l40_;jj
0;6f/P2l_kP0_Kjk0;^m^`2i^KP0][Jb0;^]ZP2U@4@0]@hC0;L;3P2]2a00WC0k05U6JP0Q?700EV66
08]MKP2C6B@0Y0D=0:L42P2Q1Ph0T2df0:NT[`25PY<0PQDM09822`1V2B<04A9C00<KGP14I8l0WKO<
09Z_`@1mUZH0>UA_00PS@P0mF6<0DVAN03e8B`0Bc`d02P00o`080?ooo`800?l000H0D91h0=1@N03@
D7P0d51h0>QX?02h>;@30:0Pl0T0oh0000<0d51h0:0Pl02P8?002`2P8?040?n000030>QX?03oP000
oh0000<0oh0000@0d51h0>QX?03oP000j6Pl103oP0001@3XJ3`0^3Rd0:0Pl02P8?00d51h00@0oh00
00<0j6Pl0:0Pl02h>;@00P3oP0000`3XJ3`0X23`0:0Pl0060:0Pl0040>QX?03oP000oh00052@N0X0
0?l02`3oool000X0oooo05H00?l009nBP02/[[/0=a`R02@10@0X0P807`4002D10@0[0P40<@4104L3
1@1?0@<0F`4406T1101e0`H0O08708@21`2;1@X0RP<708L210280`@0R`<408h31P2C10P0V`@70:/5
2@2`1`T0/0L:0;@:3@2c3a40W2@Q08=KE03Ge=80e=OF0=KHf03Eb<`0TEQM04XH5`0U61@0PXEn0<_>
a`3Kg=X0f]gL0=OMg03HgMd0fM[M0=SJg03GfM`0eMWI0=CHf@3FfM/0c/_>08Q0AP2H3a<0W@/?09`<
3P2H2@X0RAlO0;:=S@3Bd]40dLk>07Lk>P221@L0RP8308X31@2100D0O@0307h1101k0@<0NP4307T1
0`1f0@<0M@4207821@1^0@@0O@8609L72P2F0`X0UP<<09T73`244AL0a:ng0<7;e`30cMX0Q8bF05R8
@P800?l02@3oool00`00o`00X23`0:0Pl00P0?n000030=1@N03oP000oh0000d0oh0000<0d51h0?n0
003oP0006`3oP0040:0Pl0030=1@N000o`000?l000P0oooo0P00o`00>01C_bP0W9nO08JLZP1AKWL0
Ggb5076<U@2S];h0aM3K0;Nna`1cMg`0QXR809FBT02MUY<0W9N@09RDS02MTh/0XI260:BAQ02WUHD0
ZIR40:ZHQ02ZVH00ZiZ00:^GO@2_W840[9ao0:^JO@2[Vh40ZY^10:bLP`2[XH`0ZZ6?0:nXU`2d[Z80
_kbc09bOVP2MXj00]KRh0:2SX02`]:l0UYjL0;Rm^@2l_;P0^;Rd0;Jc[`2dO7l0[ADK0;L<4@2]3a@0
ST1A030lKP13Eh@0SFYj09H_=P2Q3180YP<:0P2T0`T04`2V10T0T`H>071HK@1YOi@0QTeD08D84P0e
3Sd011YO05Z0Z@2`bMX0/lKE07ZCZP1?LIL02BE>03IDJ01TOH40EVIO03i;BP0P_Q/02P00o`080?oo
o`800?l000D0D91h0=1@N02P8?00d51h0;Ph]0040:0Pl0030>QX?03oP000oh0000L0oh003P2P8?04
0?n00080j6Pl1P3oP0001@3@D7P0oh000?n0003oP000j6Pl0080X23`00<0^3Rd0?n0003oP0001@3o
P0020:0Pl0030>QX?03oP000^3Rd00P0X23`00@0j6Pl0?n0003oP000J:Pl2P00o`0;0?ooo`002P3o
ool0:@00o`00XXQf05loA`0g1`X09@4202<20@0N0@409@4102h20P0j0P80B@8305D21@1S0`L0J`<7
07<2201k0PT0OP4808<320240PH0Q@<408L10`2=0`H0SP460942202J10L0Z`L:0:l72@2^20T0]0/=
0:TI5P2^IU`0]ZRR0=GEe`3DemP0al;308EVJ@0n8200HV1G0:Z]Y03>clX0f]cI0080fMcM02/0f=gN
0=[Mg`3AeMP0]L330:F_[`3Ef=T0eMSK0=;Be02[S8l0QQXM09/=4@2O2a40W0/@09P9302;30h0S3/k
0<B_[P3Be=H0LeIH06l=40271@L0R08408410P1l0080O@4407/10`1i0@80N04307D10P1e0@<0LP45
07410`1m0PH0U`D909P5302D10/0U`L>08@@5@2`V9d0`L_E0;C1c`27SiT0GHY700800?l02@3oool0
0`00o`00^3Rd0?n0000O0?n000030=1@N03XJ3`0oh0000P0oh0000<0j6Pl0=1@N03oP0000`3oP000
0`3@D7P0oh000?n000070?n000030>QX?03oP000oh000140oh0000D0d51h0:0Pl02P8?00X23`0=1@
N002003o00P0oooo0P00o`00C@0XgQ80UYF@08BLZ01LNX<0HWn709bb^`30d=/0_/[E096KXP1jOX80
SHf<09:@SP2ITi80VI>@08b7P02MTHP0WXb40:6?P@2VU8@0YiAo0:BBN`2XTg`0ZIIl0:^HOP2[VGh0
YY=h0:RDMP2ZV7h0ZIb40:RNR02]XY40ZYj>0:^SU@2PWI00/;2W0;Ff[@2^/jX0_[nj0:FWY@2m`;`0
VJ2M0;Rl]`2i^;D0]KBa0;Zb[`2XC500^0lD0:l@502BAUP0=T5a06aHN`2J=d@0X`lE0:T6302Y1@/0
Y@@90:H42P2V0`X0Z0D;09<>5@18?Eh0Ih^Y07]lT01/7C807Q1902PSE@1aSjT0/LWG0;C9f`1YQZT0
2baJ05IiS`25WJ<0KX2105EUG`0eAdL0;Zl/00X00?l0203oool2003o0003052@N02h>;@0X23`00H0
X23`00<0j6Pl0?n0003oP0001P3oP0000`3XJ3`0X23`0:0Pl00;0:0Pl0030=1@N03oP000oh0000<0
oh0000<0j6Pl0?n0003oP0001`3oP000102h>;@0X23`0;Ph]03XJ3`80?n000<0X23`00<0j6Pl0:0P
l02P8?001`2P8?00103XJ3`0oh000?n00020`00:003o00/0oooo000:0?ooo`0W003o001`CbP0E@h>
03L20P0O0@407P4101d20@0W0@80=08203/20P180@<0F08306021@1P0@@0I`4606h21P1d0PH0O@86
08441`240`L0R0<508l3202C0`P0TP8809X31`2Z20/0/@L;0;48302_2@/0Z3H^0;NGS@3Cd<d0d]KH
0:>][`0^>CP0>chg09^MUP3?d<h0em[K0080f=_L02d0f=cL0=[Lg@3LemT0`j^a05mFF@1<FeP0]Kfh
0=OJf`3=a/L0VFe^08PU9P2G3A00V`T=09h:402I20d0U@P:09482`2:30l0TTU:0<o7b@2IU9<0>PP6
07L720260P<0O`4307`00P1n0P<0P08407/20`1c0@80M@4207D20`1c0@<0M04307d21@2E10/0U@@<
09442`2C2@d0V2P[0:b<TP32b]@0^lSG08J?V01NS4X00P00o`090?ooo`03003o003@D7P0oh0001h0
oh0000<0j6Pl0?n0003oP0001`3oP0000`3XJ3`0d51h0>QX?0030?n000030>QX?03@D7P0oh0000L0
oh000P3XJ3`D0?n000050=1@N02P8?00X23`0:0Pl03@D7P00P00o`080?ooo`800?l004d07^@:09VC
QP2G[[`0GGb509:X[`2a`<d0ZKW707b6TP1jP8@0Q8R;08Z:R`2AT8`0Ui6>09ZBSP2ARh40VI2709^;
P`2QSX80Y9:20:F@O02XU7/0ZiAl0:ZEO`2TTGL0Z9Ei0:VIOP2VTWD0Yi=h0:VIPP2[WhX0ZZ2?0:JO
S025QGX0QHZ206ahM02e^k80`l>m0<;2^P2`/[00YZ^Y0;2d/02j^KL0^[Zg0;Ng]02k];00ZD]@0;P@
4`2i=CL0SeU/09<iC@2U4a/0[`P>0:d72`2[1@X0Z0H=09/<3P2Y:bX0XPL=0:D52P2=;Sh0;TA`08VZ
_P2M]lL0OFR201`ABP1?5cX0J72=08f/b`0jFXX03c1Q04eZP`1`RI40IWUm061bL019GEd06Rlk04:7
@P0:003o00P0oooo0P00o`000`1@T7P0X23`0:0Pl0050:0Pl0030>QX?02h>;@0j6Pl00L0oh0000<0
j6Pl0;Ph]02P8?002@2P8?000`3@D7P0X23`0?n000050?n00080j6Pl203oP0000`2P8?00d51h0?n0
00080?n000030>QX?02P8?00X23`00<0X23`00<0^3Rd0:0Pl02P8?00102P8?040?n000030=1@N000
o`000?l000P00?l02`3oool000X0oooo05H00?l005TZ1`1?10@0=@4201d10P0N0@80700102X10P0a
0P80>@4204P2101<0@D0E`4606021P1U0@L0J@870702101k0@D0P@4608D31P280`@0R`450903202>
0PP0Q`<70:D82`2_20T0/PX;0:l;2`2V@CP0^Z>L0=KEe03=d=40J7=]08>:P02n`KP0e]KD0=KHf@3G
f]`0em[M0=SLg@3Fc<h0bZ:V0:=RJ01C9bT0P7eg0<S=b03HfmX0dlK90:aIG02T7R00W10A09d<4@2O
2`l0X0P=09h93P2I20h0TP@:08h52P243@d0XW5a0<K2`P1:>cX0D`P:08431@240PH0PP4408021021
0PH0O@8507810P1e0P@0MP8507@11P1e0@L0N@4709@53@2G10`0T`@:098630293aD0YGUn0;>ja@2k
bMD0QXjG06B2CP800?l02@3oool00`00o`00j6Pl0?n0000V0?n000030>QX?03@D7P0j6Pl00@0oh00
0P3XJ3`O0?n000050=1@N02P8?00X23`0:0Pl03@D7P00P00o`080?ooo`<00?l004`0W8el09BX^025
WZP0]<G@09^W]`1^GFT0Lf5W07ioP`22QhP0RXZ9096@S02AShT0Ti2809F@Q`2HSX@0VhZ109f:P02Q
S7h0YH]j0:NBO02WTgX0YY9e0:>@L02UT6h0XY1a0:NBLP2ZU780YiIj0:JJO`2YWH@0YYj806Q/I01Z
Mg<0F6QU0:je[032`[T0`l6l0<;2_@32`[h0_knl0;^k]`2i^[D0][Rd0;Jf/@2gOWl0/1HI0;LB5@2_
4QT0/0X@0;893@2c2@h0ZPP<09/=4`2:;c`0M4QF09DnA@2P20l0V1`S04hlI@0lI9<0EGnM07>FZP2d
_lh0=cAN01`CB00B85T03BeS04a[TP1mW[P0NIFW08>JY01hSIP0CFQg00lV@`014S40<ea02P00o`08
0?ooo`<00?l000<0^3Rd0:0Pl02P8?000P2P8?00102h>;@0oh000>QX?03XJ3`:0?n000`0X23`3@3o
P0000`3XJ3`0oh000?n000060?n000030>QX?03@D7P0oh000080oh003`2P8?020=1@N0030>QX?000
o`000?l000P00?l02`3oool000X0oooo05H00?l005/F10190P@0<@4102400@0R0P80804102P10P0[
0@40>@8204410P110040D@4605d21`1S0@P0I`4406h11@1k0PL0P04508L21`290`<0R@4208l21@2?
0`P0PP860:4:302_2`T0/0P:0;092`2V<2X0^IF@0=KDe039c/h0/kF_0=;DcP3Cem@0e=OH0=KHfP3F
f]d0e]WL0=K8c@2cJg80TS8h04dC4P1bK6H0dM;>0=SIf03Jd=<0]Ve_0;<L7@2e4Q@0XP`@09d<402O
2@h0X@P>0:093P2J1Ph0U`L=09@82`2<1@L0QR4U0<fc]02HUI<0=Pd>07T62`230PD0Q08308@21@22
0`L0O@4507`21P1j0@D0MP4507P11`1i0@P0N`4609842`2E0`/0T08809052P291``0U5eO0<K;dP2i
aM40R92J07MLE0800?l02@3oool00`00o`00oh000?n0000U0?n00080d51h1@3oP0020=1@N0`0oh00
00<0d51h0?n0003oP0004@3oP0001@3@D7P0X23`0:0Pl02P8?00oh0000800?l0203oool3003o000W
0:FCN@2W]l@0Z[k:09j__01VBeL0K18I07Pd=`20OX00PHF708Z;R`2?SX`0THn;09:>R02BS8@0Uh^5
09Z7P02NR7l0X8]m0:6;N@2XTGd0Xhad0:>;L02VTG<0XY1b0:>?L@2RTFl0YYAc0:JHO`2WWHL0Y9^5
0:>LQP2>SWh0NX1g08b@Q@2ZZj00`<2j0<G2_P31`Kl0`Knm0080_;bg02<0^[Zg0;Ni/`2e][00^96B
0:/J7P2h2`h0]PX<0;D93P2b2Q00YA8E08hd@01F@V00BT5U07`a@`2C2Q80Tb8Y05I3I@0Q@gD0UJo2
09B^`@2I]LL0`];L0:6FZ01I7C`0A1m209:]``2_amH0Mi:V07VBY01aR9T04bY?008DA@0243h00@lf
02La@P0:003o00P0oooo0`00o`001@3@D7P0X23`0:0Pl02P8?00j6Pl00<0oh0000<0j6Pl0?n0003o
P0001`3oP0000`3XJ3`0X23`0:0Pl00:0:0Pl0030=1@N03oP000oh000140oh0000L0j6Pl0;Ph]02P
8?00j6Pl0?n0003XJ3`0^3Rd00H0X23`00<0d51h0;Ph]02P8?00202P8?000`3oP0000?l0003o0008
003o00/0oooo000:0?ooo`1F003o001=5P<0@P<303410@0R0@407P4101l10@0V0P809`4104020`1<
0P<0C`<40582101H0@@0G`4606P11@1_0P<0NP8407h110250PD0Q`4308d21@2C0PP0U@<909P52P2S
20/0[0T;0;0:2`2`2@X0Y1PD0:]^I`30^kP0d=GE0=;Ee@3Df=H0eMWI0=GIf`3GemT0f]?F0<fZ[`2c
DUT0RQlP04PG501cJV80bL_30=_Jf@3JaLT0`WMk0;HR9@2o4Q@0]Q0C0:D=402N3100W`X?0:493@2O
20`0WPP>09L7302D20`0TPH;08h:3`2KDUD0e<3105lm?P1]1@P0PP<7084210230`@0Q0D707/1101i
0@D0M`4307H2101f0@D0N00407d11@2F1P`0U0<908d32@2<0`X0R0D;08I8C02_/KL0_l[E08ZBW@1c
FE42003o00T0oooo00<00?l00?n0003oP000903oP0000`3@D7P0j6Pl0?n000040?n00080d51h3@3o
P0000`3XJ3`0d51h0?n0000A0?n000050>QX?02P8?00X23`0:0Pl03oP0000P00o`080?ooo`<00?l0
04d0TZ1W0:Ria@2X]/L0KV=]05d]<01m?d@0JbX_089jO01mP840QXZ;08n?S@2BT8`0Thj90969PP2G
RhL0VXJ209n7P02RRgh0X8ai0:F@NP2OSG<0YI1d0:6<L02QS6h0Xi=d0:6BL`2STgD0YIZ40:6LQ`2S
VhH0X9^709nKR@2OWHd0XZ2C0:VYW`2j^kD0`/6n0<;2_`2n_K/0_kjk0;Vj]`2i^kP0/kNb0;:f/@2f
UYH0YQLL0;L;3@2e2Ph0Y@lE09@d@01IAF/08Sec069?L0296b/0T0dE07l_?@0g>6@0:4]i09:Y_@23
UjT0MXbR08>R^02odMl0`lgH09IcP01V72l0OHVM0:Nod01@KHl073QW05]hS`0;8DL00A54008A?00B
9cl09cY700gL2`09003o00P0oooo0`00o`00102h>;@0X23`0:0Pl03@D7P>0?n000030;Ph]02P8?00
X23`00/0X23`00<0j6Pl0?n0003oP0003P3oP0001`3XJ3`0^3Rd0:0Pl02h>;@0j6Pl0?n0003XJ3`0
202P8?000`2h>;@0oh000:0Pl0070:0Pl0030=1@N03oP000D91h00T00?l02`3oool000X0oooo0280
0?l004`J0`0j0P80;P4201h10@0P0P807@4102D10P0_0@80B0450542101<0P<0C@4205L10`1Q0@<0
JP4606l21@1h0@<0O@0208@10P2;0P@0T@@709L6202E0`T0VP@90:<82@2]2`/0[@T:0:l:2P2R61@0
_H5i0<Jm^@3De]L0e=SI0P3HfM`08`3Hd]H0aYNN0;ECF02f:2/0_2l/0:agL02i]jh0e=GB0=cAd`37
RXl0/cTo0<0L8@3451H0^A<E0:/D5`2B4AD0PQ0C07X=4P1k3A40PPhA08`>4P2A2`h0TPX<09D8302I
20d0RP/B08lk@02/MgL0KPX<08031P1n0@<0P@8607h1101l0PH0N@430080MP4200d0N@4407`11`1o
0@L0U@@<09H4302>0PX0R`8908P52P1n>3/0]K2e0;_6d@27SiT0M5eE00800?l02@3oool00`00o`00
j6Pl0?n0000Q0?n000030>QX?02h>;@0d51h00D0oh0000<0j6Pl0=1@N03oP000403oP0000`3XJ3`0
oh000?n0000@0?n00080X23`00@0^3Rd0?n00000o`000?l0203oool3003o001=086_F@2X/[h0PgR6
060I701Z@440L5eS064V;@1mL780NGj008F7Q`2=SXX0T92=09>ASP2ESXX0Uhj709Z=Q02LRX80XHj3
09n;N02SRWD0WXI[09n:J`2PS6/0WhaZ0::AL02UUWX0YIIm0:JKQP2RVXL0WYR40:2JQ`2NVXP0WIf<
09jNT@2UYid0^[bd0;no^`32`Kd0_[nl0;Zn_02h_Kd0]KZj0;>h^02`][<0_:JW0:4O9@2^4QH0WC@m
06]=I`0_A740@fB<08JEY@2:E5/0Qb4/05diEP0J;f00@F:308BIWP2W/kP0XkO308ZX_01eVZl0_=?Q
0;k@gP30am<0PF9`05eNLP2T_Lh0BfF9008HDP1AKHX073MA00dTAP0bC5/0Bf5N03Y<CP0IbAP02@00
o`080?ooo`<00?l00P2P8?000`2h>;@0oh000?n0000=0?n000030=1@N02P8?00X23`00`0X23`203o
P0020=1@N0060?n0002h>;@0oh000?n0003XJ3`0^3Rd0`2P8?000`3@D7P0oh000;Ph]00:0:0Pl080
^3Rd1@2P8?001@2h>;@0j6Pl0?n0003oP000D91h00T00?l02`3oool000X0oooo01H00?l004/G0`0d
0@80:04101/20@0N0@407P0002H10@0k0@@0A@4404X110170P<0B`4305P10@1N0080I@8306d10`1m
0PD0P`4508H20`2<0@H0T0470P2G1@P00`2I1@P0Y@T:0:d:2`020:h:2`0Z0:0G5@2mQ7h0c<C40=GF
fP3Ef=/0f=SL0=[?d`2lQ8X0[RX^0;dG5`335AH0`4U60=74_@3Kg=T0g=GF0<N4S02h9B`0`1HJ0;hG
6@2X6AX0O1HI04l;3@0]10L060@501841@0C0`807@<303<41`1K3Q80NPhB090:402J20h0UPT?08d;
4P2B<cD0PAXJ08441`1o0@@0P@8507P10P1g0@80MP420P1d00803@1i0@H0O08807`11`2D1@/0UP89
08l11`2>0PP0R0<907TX;02/XJH0_lWE07j7T@1`GeP00P00o`090?ooo`03003o003oP000oh000200
oh000P3@D7P70?n000030=1@N03oP000oh0002<0oh000`2P8?000`3oP0000?l0003o00080?ooo`<0
0?l004d0I<=008>4Q`1M<SL0M2LY060Q9P1`EE`0HRH]07]YK01dN7X0Q8B508f;RP2BShd0Thj=096<
R02FRhH0WXj709n<Q@2OS840Whej0:2;M02MQFT0XHQZ0:6<K@2NS6/0Xi1c0:6CM`2UVXH0XIR40:bU
UP2MUXH0WiR509bJQP2RXiH0WinD0:FVVP30`;T0`L2n0;no_P2l`;h0_<710;O0_P2e_[X0]Kjk0;6i
]`2m/[@0V4a@07eAH`1QEgD0NTML09V1RP2FX:@0V9nN09><S01FF6h0:4E_06EkRP26Ti00VJ:R09BH
WP2GVjD0O8FE09VQ[`30cMX0`=3L0;g?g02ga=00IgN708NU]P1;IX003RME03MEK@1CKG00DfY]059Z
J01=I5d0<dI;02RY:@09003o00P0oooo0`00o`000`1hF;@0j6Pl0?n0000?0?n000030=1@N02P8?00
X23`00L0X23`0P3XJ3`20:0Pl0030>QX?03oP000oh0000@0oh0000<0j6Pl0?n0003oP0000P3oP000
2@2P8?00oh000;Ph]02P8?00d51h0;Ph]02P8?00^3Rd0?n000020:0Pl0030;Ph]03XJ3`0d51h00d0
X23`1@3oP0000`20`0000?l0003o0007003o00/0oooo000:0?ooo`1F003o001?60<0<P8202D20@0L
0@407@420281000b0P<0@08404@20P160@80B04204l10P1H0@80G@8406@11@1`0@H0O`4708@11`28
0`@0R`8709<22`2F1@X0V@L:09/62@2V2@/0[PX<0;4:302b2`h0XaXI0;j7Q03=a/H0eMOJ0=OBe`3@
]K`0]fec0;8W:@325aP0bAHF0<LE5@2nBTT0elC30=c1a033Mgd0]RT^0:lI7@2<51H0H0lA02l:2`0[
8Qh0>chi04UAC01PIf<0Jg1/06U/IP1BETl0?40j01dH500P1PH0D`/?08/=4@2@1`X0T@H:08X93P2?
51P0P`<608831P1o0@D0M`4207D10P1a0P40LP8307<10`1d0@@0M@4607X11P2D1P/0V@@:08l22@2<
0`P0P`8907@P9@2eYjT0[[S008VAV`1[GU`2003o00T0oooo00<00?l00?n0003oP000703oP0001@3X
J3`0oh000>QX?02P8?00d51h00D0oh0000<0j6Pl0=1@N03@D7P09P3oP0030:0Pl0030?n00000o`00
0?l000P0oooo0`00o`00C@17`b40MVIR05`h>`1Y?3d0I20Q06`[<`1X7R80MfQ[075gNP1oOH40RhN7
08Z8Q02;Q840SX60095oO@2JQh80VhQo09f9P@2RSX40VhIa09j5J@2LQFP0WH]]09f>KP2RUGX0XIEl
0:>KQP2TWXd0[JNK0:6LS@2LV8@0ViV60:6QU@2WYI/0YZ^R0:>[Y`2_][D0_L6m0;k1_P2j_Kh0^Kjm
0;Nn_@2f_;`0][Zj0;Ff]P2kZZh0TeM/09hS<P2U3QH0Nd=D07J;UP2JX9d0UIZG08N@T@27S8l0THB3
08iYJ@2>BU40TC@m09@U<02A7BL0SAl/0911C`2TQ980_LK@0;O<f02]`/h0Oib]08>P[P1cRi`0J7j7
065dM01IKV/0DVUT04QPH@0O=T<0>9dk00T00?l0203oool3003o0003052@N03oP000oh000100oh00
00<0^3Rd0:0Pl02P8?001@2P8?000`2h>;@0oh000>QX?0020:0Pl0@0oh0000@0d51h0?n0003oP000
X23`0P3oP0002@3XJ3`0^3Rd0:0Pl02P8?00^3Rd0>QX?03oP000d51h0:0Pl0020?n000030>QX?03@
D7P0oh0000H0oh0000<0d51h0;Ph]02P8?001@2P8?000`2h>;@0oh000?n000030?n000030:R8?000
o`000?l000L00?l02`3oool000X0oooo05H00?l004dF0`0b0@807`4101T20@0N0@408`4103<20P15
0@@0@`4204810P170@80D@4305P10`1Q0P80J04307@210200PH0QPL:08D31P2<0@H0T`8:09L42`2L
1PX0X0L<0:P93@2`2P`0/PX=0;@<3P2T71`0`Xj:0<o8b03A`/L0VVQ`06PP:@2H7Al0`AHE0<DD5@38
5AD0aa@E0<Q2@`39L7<0[C<i09hM8@1Q3a00<1@C040n>01VK6H0W:6O0;c0^`37b/D0c=3;0<oBd03?
e=80dMGB0<_?bP33bL80/KB_07]oN@0l>SL0>@T:07l;402=1`X0S@@808P31`200@<0O`4407h31@1g
0@80M04207820@1a0P80LP4307820P1b0@@0N@460986302F10/0S@4808X320210@H0LQXN0:FAU02U
[;<0PX^D06QOG`800?l02@3oool00`00o`00oh000?n0000L0?n000030>QX?03@D7P0d51h00L0oh00
00<0d51h0?n0003oP0009P3oP0020:0Pl0040;Ph]03oP0000?l0003o00P0oooo0`00o`00C@0Vf@`0
Mf5>05Pm>@1XCd`0ISPh05l=4@1j>S`0KUIK06eeM@20Oh80QX2008^3P@28Ogd0QGYf08UgM@2AOgT0
UhAm09^7O`2LRG/0VXI^09f8K`2OSW<0WI1e0:6BN@2QU7l0Y9f:0:ZTU@2XY9L0/:ZP0:>RU02MW8`0
XZ:D0:RXW@2/[:@0UYnG0;Rm^02DWYd0^;nk0;Vl^P2i_[/0]kbj0;Vm_@2h_;/0/[Re0;Be/`2VJg80
[1@M0;4:3`2[2100OC=:061iS`2IXZ40VIJF09QjO@2@A4/0RQTP09484@2G10`0W@@;09h42`2N0`P0
V@<;09<33@2921D0QSU:0;Je`@2hb]H0MX^K07:<U`20UId0K86305a_KP1IK6X0BVAU01@W?P045380
>G=600T00?l0203oool3003o0003052@N03XJ3`0oh000100oh0000<0^3Rd0:0Pl02P8?00102P8?00
1P3XJ3`0oh000?n0003oP000d51h0>QX?0P0oh0000@0j6Pl0=1@N03oP000oh000P3@D7P30?n00004
0=1@N02P8?00d51h0=1@N0/0oh0000<0j6Pl0:0Pl02P8?000`2P8?001@3@D7P0oh000?n0003oP000
j6Pl0080d51h2@00o`0;0?ooo`002P3oool0EP00o`00CQD203D30P0P0@40604101d10P0V0P40<`42
04/21@150@80A04204L10`1>0@<0H08506T21@1/0@@0LP8507@210293a<0NP<408/21`2D0`X0V@D;
09d62`2Q20/0Y`T<0;0=3`2b30h0/``?0:HJ703ASXl0]hjB06/h?@119bP0OFe/0;I/J`2n61T0aQ@F
0<DB5@344aD0^aTM08LH6`1<30l0>28P06mbK@2e^[D0a/g80=3Fd`3Gf]`0emWL0=GIg03Df=/0cm?G
0=7Ff@3@e]P0d]OG0=7Fe`3Ae=L0cm;D0;c0`01QHUh0@P/<07h:3P271PP0P`870801101m0@80NP43
07@00@1d0@80LP8306P20`1`0P@0L`4307@01@1j0PH0T0D;09D22`2>0@X0QP8808421`1f6Al0[I:F
092EW025SI@0JV=Q0P00o`090?ooo`03003o003oP000oh0001/0oh0000<0d51h0;Ph]03oP000<@3o
P0020:0Pl0040;Ph]03oP0000?l0003o00P0oooo1000o`00C01cGC00H3df06@l>`1XC4`0EbLX0794
B01/@D@0M7Ee07UjO@1nO7/0Q7el08ElN@1oMg80PGA^08]kMP2EPg`0UhAk09V6O02MRWT0VhQa09f=
M@2PT7/0XiJ30:JJQP2VWhh0[:NI0:bWW02/Z9h0[J^Q0:^YX@2/[Z<0];bc0<O?c@33cL`0[KJe09:L
V`2d^kT0]kbk0;Fm_@2d_K`0/[^h0;Jl^`2a][D0/[Fd0:]`MP2_3QH0/PTA0:L94`20=DT0C65k0:69
SP2I@TT0U0lI09P53P2E0P/0U`8:09T22@2L0P/0WP8:09d2202H0`T0TP8909<230290`d0P3E10;Fj
aP1QOXh0J8B?07::T01OMGP0G6m_05Y[K00R>4d00@dd004?=00X=dH9003o00P0oooo1000o`000`3@
D7P0oh000?n0000?0?n000030>QX?02P8?00X23`00@0X23`00<0j6Pl0?n0003oP0001P3oP0001`3X
J3`0oh000?n0003oP000d51h0>QX?03oP000103@D7P30?n000030=1@N02P8?00^3Rd00d0oh0000D0
j6Pl0:0Pl02P8?00^3Rd0:0Pl0030?n000040>QX?02P8?00X23`0>QX?0T00?l02`3oool000X0oooo
05H00?l0050C0P0h0@40904101`10P0K0040904003T10`1;0PD0@P4204H10P1;0P<0B@4205H10P1Y
0PH0K08407421P1S0P80I0D606H10P2;0PL0U@8809/5302J1@T0U`H90:882`2`3100/P`?0;D<4@2_
5AP0b5MK06hT:@0a8Al0Z:RS0=cGe@2jOgh0_1/L0<<C5P334QH0^aTK07L@500V30/0G5]I0:^^Z@3A
e<l0f]_J0=SLg@3Ef]d0e=WL0=GJg@3Ef=/0e=SL0<oEf03Ae=P0d]KI0=?HfP3Ce]X0c]CG0<kCeP3;
dM@0_l?004<_;P1S3a40O`H:07l22@1l0@@0N00207L00P1e0@80M`8507<31@1K0P80H@8407821@1b
0@H0N04708h32@2@0@T0SP4=08L12@220@P0K0P:095_K`2:Si<0KgQl06iWI0800?l02@3oool00`00
o`00oh000?n0001@0?n000030:0Pl03@D7P0oh0000800?l0203oool4003o001=05Y[4`1bAT00H1/L
06Hg>@1VCe80IdQ>06Xf>`1dKW00M7Ef07QgMP1nNg/0O7Mf07]dL@1nLVl0QG9_095jM@2GPWX0VXQn
09^9O@2QSgl0Whik0:FDQ02UUhT0Z9b=0:ROS`2ZYIL0ZjJL0:VVW@2[ZZ<0[JbT0:je[02ka<00[;>`
0;k:b@2c_l40Zk6_0;Bi]`2e]kL0/[Zi0;Bl_@2c^[`0/kZi0;6f]P2d][D0/hB;0:PC6`2Q51X0RSa:
061<J01iAUh0VQLS0:T8402T0`/0W08:09P22@2G0PP0V08809`22P2P0`X0W04:09L3202B0PT0SP8:
08X22@1m10d0PeAL082EX02=YZh0PIRL06V1PP1IKF`0DfAZ00HE>0013CD00Q4b01/^A@0;fPX02000
o`080?ooo`@00?l000<0d51h0?n0003oP000403oP0001@3XJ3`0d51h0>QX?03oP000d51h0080j6Pl
203oP000202h>;@0j6Pl0?n0003@D7P0oh000;Ph]02P8?00j6Pl0`3@D7P20?n000030=1@N02P8?00
^3Rd00l0oh0000L0j6Pl0:0Pl02P8?00X23`0>QX?03oP000j6Pl0080X23`00<0^3Rd0>QX?01@T7P0
2000o`0;0?ooo`002P3oool02@00o`00DQ<203h20@0V0@407`8101l20P0S0P40<04204L31@0203h1
0P0Y04X20`1?0P<0F@8506H1101Y0@80L084070?3`27;Rh0M`H808d21`2D0`P0U@<709L52@2C10P0
X@X=0:l=4@2`2`l0/``B0;0C5`2W=C<0L4@o0:JVX@3FemL0f]SI0;J1OP2h6AX0_QDI0:@F6P1T3Q00
A3<`096ET03;cL/0f=[H0=kQh03LgMl0fMgO0=KKgP3Df]d0eM_N0=CIf`3Ff]`00P3Be]T0803DemX0
e=SK0=7Gf03@emL0cmGE0<gBe@3<dM80TXn>048?3`1i2@`0P0<807d11@1k0@@0N@4407X2101h0@<0
M@4306h31@1Q0@<0M08607@01`1i0@H0T0@:09D1202@0PX0R@<808<11`1]2@`0WWam0864Q`1]M7P0
L6QV0P00o`090?ooo`03003o003oP000oh000500oh0000<0d51h0>QX?03oP0000P00o`080?ooo`@0
0?l004d0AYDC0753?P1L5aH0JB0T06<c=@1YADX0Ic0b071YK01^KVl0LFm_07]hN01oO7T0NGE`07a_
K@23KF/0S7E`09J1N`2HQG/0X8j00:BCQ02RTX<0XiF60:6DQ02UVXX0ZIjA0:RPUP2ZYI`0[:VP0:n_
Y@2][J@0/KF_0;g4`P2c]k<0`lg>0;O2a02a^;H0];Vh0;Jj^`2c^kX0/K^i0;2i^@2d^kX0[kFd0:jf
]@2bVYd0TD99061>KP1BBg80QS1509l<602V1@d0Z@H<0:D42`2N0`X0V`<909L2202C0`T0S`P@08lI
8`25:CH0M2`g07LZ=@1j51l0P`D<08@22`1d5Ql0MgJ106AkQ01]QHL0HW]k05]`KP13EV800Q0i00`P
?P0jEEd0:d9<017B4`08003o00P0oooo1000o`000`2XR3`0oh000?n0000C0?n000030=1@N03XJ3`0
oh0000T0oh0000H0^3Rd0?n0003XJ3`0X23`0>QX?03oP0020=1@N0070?n0003@D7P0^3Rd0>QX?02h
>;@0X23`0>QX?00:0?n000030>QX?03@D7P0j6Pl00@0oh0000<0^3Rd0:0Pl03oP0000P3oP0000`3@
D7P0X23`0;Ph]0020?n00003052@N000o`000?l000H00?l02`3oool000X0oooo05H00?l005@A0P0n
0P809`4101l10@0N0P80704102L10@0h0P80=08203H10P1=0`D0DP4205d21P1R0@<0J0830741101l
1`T0P`/<08L31`2@0PL0T`<809@3202H10X0V`L;09H72P2L20/0[0`@0;<<402V6Ad0ahj:0<K1_P3G
f]/0f=[N0=WIfP2fPX00ZAhM06DA400i8A/0MGE`0<C9aP3Hg=`0gn7Q0=kQi03Kh><0fmoQ0=SLgP3F
fmd0eMWM0=CIg03Ef]d0eMWL0=3Ff03Af=X0eMOL0=;GfP3>e]P0d=KI0<oEe`3;d]@0bm3C0<[<c@2;
Lfh0LA8C08431`1n00D0OP4507`1101g0@D0N04407L11@1d0PH0L`4707/22@1i0@L0N04408h32@2D
0PP0S`<908P220270PP0KP@908]NH`22OX<0HfEZ079YJ0800?l02@3oool00`00o`00oh000?n0001@
0?n000030=1@N03XJ3`0j6Pl00800?l0203oool4003o001=03VM2P1_ACl0J3ll05hS9@1_:S00HQLL
06Xn?`1PGf00IFIW06YXJP1dLWD0NWMg07mhM@1kL6`0OfeX08]gL@2HQ7d0VXIl0:6?P@2STH80X920
09n?O`2PUXD0XYZ;0:JNTP2ZXIP0[jZQ0;2_YP2_[jH0[k6X0:baZP2a^;D0_/G70;W1``2`]kD0]k^i
0:Za/`2HY:H0ZKBa0:ji]P2]][D0[kRg0:bf/`2Y];40[[:b0:2NZ01ZDg@0U24c0:H94@2Y1P`0Z0@:
0:H42P2R0`/0V`<<09473`268Bd0JSE<04HkG`0[=F@08C9P04AFN`1IJHT0JFf407DhB0201A00N0D?
06aGI021Uj00M8b>069kNP1KLFl0?5EP00DJ?00lFEl0CfIQ03I<D@0QYRP02000o`080?ooo`@00?l0
00<0P<000?n0003oP000403oP0020>QX?0030?n0002P8?00oh0000P0oh0000L0d51h0;Ph]03XJ3`0
oh000:0Pl02h>;@0d51h00<0oh0000<0j6Pl0?n0002h>;@00P2P8?000`3XJ3`0oh000?n000050?n0
00030>QX?03@D7P0^3Rd00D0X23`00H0j6Pl0?n0003oP000d51h0:0Pl03XJ3`30?n000050:0Pl03o
P000oh000?n00020`0002000o`0;0?ooo`002P3oool0@@00o`00E0`104D20P0a0@80904101`10P0K
0@409`4203L10P0e0P80;P4104<20`1K0`P0H08606D20`1/0P@0L`8407X2101o0@@0R04608h21P2C
0`P0UP@:09T52P2K1PT0WPT:09d72@2^3@l0]@dA0:@K6`2oS8T0cLW80=KHg03If]h0f=KJ099hNP11
6AL0MWE^0<?9`P3DemD0fMgO0=[Nh@3RhnL0g^7T0=[Ph@3Lgn00f=cN0=OMgP3DfM`0eMOK0=;?d`3>
aL/0`;6g0;VRZP2hW:L0^Z:Z0<Fl`@3AdmH0d=GG0<[Be03;dM@0b]3B0<:j^`1f;S40P0@90080OP46
00<0N`4506h20`1a0PD00P1h0PH03P1j0@H0NP4707`2201k0PD0T0@;09<22@2>0PT0Q`4808<3201_
10P0R5MK08>1Q01AEEX0KFIU0P00o`090?ooo`03003o003oP000oh0001l0oh000P3@D7P=0?n00008
0>QX?03@D7P0d51h0=1@N02h>;@0X23`0;Ph]03@D7P50?n000030:0Pl03oP000oh000180oh0000<0
d51h0?n0003@D7P00P00o`080?ooo`@00?l004d0?9h807M:A01V?cl0ICXk06082P1V;Rh0GeAF05UK
F`1RH680JfQW075[KP1dKW00OWIc089eL`22L6`0SgQb09J3NP2HQG`0W8an09j?OP2OTh00W8mo09bB
P02SVX/0YifB0:^TW02/ZJ80/JnX0:b]Y02[[JD0ZjnY0:N]Z`2]/[40[K:`0:bb/02d^;T0WjJX09VV
YP2KZ:H0[[Rg0:bf]`2^][P0[[Bf0:Va/02`/K40[gb50:4K9P2`2A40ZPD<0:`73P2X10X0Y0D>09H:
4@23:CL0D3MJ01d_I@0Z@G80EeAf07U;H@25=DH0RC4n08HjA`26MGh0/[Bm07XW=01m10l0D2Df07J>
U@1aR8H0GgIc05YbL012G6@083Y>055WI`1?IFD07SI800iZ9P08003o00P0oooo1000o`000`1@T7P0
oh000?n0000@0?n000030>QX?02P8?00oh000080j6Pl203oP000203@D7P0j6Pl0?n0002h>;@0X23`
0;Ph]03XJ3`0d51h0`2P8?030;Ph]0L0oh0000<0j6Pl0;Ph]02P8?000P2P8?040=1@N0030;Ph]02P
8?00j6Pl0080oh0000<0^3Rd0?n0003oP0000P3oP0001@3@D7P0oh000?n0003XJ3`0^3Rd00P00?l0
2`3oool000X0oooo05P00?l005D:0@190P80>@4102/10@0O0@406`4102P10@0j0P80<04201l1000[
0@80B`4505l10`1V0@40KP8307010@1f0@80O@8308D10P2<0PD0T0@709L52`2H0`P0W@D:0:472P2Y
2@`0/0/=0;<<3`2T7Q`0aYB>0<k;b@3Hem`0d/G;08UeO00V9BD0NH9j0<_?c03Lgn00f]kQ0=cPhP3O
hND0h>?W0=gRi03LhN40fmoP0=SJg`3Mfmh0e/C<0;^=V@2KG6H0Qca407dX<`1i8Rd0NQTU088K9`22
<SX0]9JJ0=7@e03;dMD0bM7C0<_@dP3?blh0P4A808052`220@P0P@0507h10`1j0P@0N08507T11@1g
0@D0NP8607/11`1o10X0P08809<32`2C0@L0SP<908H11P200@D0K@<708AADP1hMWL0EEMK06MPG`0O
S@P00?l02@3oool00`00o`00oh000?n0000N0?n000030=1@N02P8?00oh0000`0oh000P2P8?070?n0
00030=1@N03oP000oh0001T0oh0000<0d51h0:0Pl000o`00203oool4003o001=03^^1`1lCd<0IS4`
06H_;`1K<C40G51C051@E01EEeP0GemQ06IVJ01`Jfd0MFi^07]fL@26NWP0QW9a095iMP2DPG/0UHAm
09N:N`2PT840XIB409fAOP2QUX<0YYb<0:VQU@2[Yid0[:ZR0;:bZ@2YZZ<0ZJVS0:VYY02/[j`0Zk2[
0:fa[`2[];40/kRg0;6g]`2R[:d0Z;>c0:Ze]02X/[<0ZKBd0:Zc]@2][K40[gZ20:LJ902b2Q40[PH>
0:X43`2[1Pd0X0L=08dS;@1N@6006RiV02]9M@1SKH<0Q4aH08dC7P2F1@l0V@8=09L43@2082l0Be=d
09^jc`1oCEl0N`DA04hQ<`1IMh00IWil065fM@1MLG40E6]^024lC017H6T083A<008C>`049C402000
o`080?ooo`@00?l000<0D91h0?n0003oP0004@3oP000103XJ3`0d51h0:0Pl03@D7P;0?n000050>QX
?02P8?00X23`0;Ph]03@D7P0102P8?000`2h>;@0oh000?n000040?n000030>QX?02h>;@0X23`0080
X23`00<0d51h0?n0003oP0000P3oP000103XJ3`0X23`0:0Pl03@D7P20?n000030;Ph]03oP000oh00
0080oh0000D0j6Pl0=1@N02h>;@0X23`0;Ph]008003o00/0oooo000:0?ooo`1H01K]1P1N6@h0BP<2
04420P0_0P80804101X10@0W0@40?P8403T82P1I8bP0=@D603h21@1P0P@0J@4306l2101b0@<0M`43
07l110260@<0S08509<42@2E0`P0V@D909d72@2S20`0[@X?0;8;402e3A40XahN0<:CT03?bLT0bK6g
075;DP0a92<0MGag0<_Ac`3Oh^@0f]kQ0=_Ph`3Qh^H0g]oS0=cPh`3NhN@0hn?V0>3Af03BZ[@0`GR1
0:Q1B`268BP0IQDI04X?4`0a3A<0;@P;05d?4@284aH0TA0D08XU:P2WO800b<O:0<[Be03;d]@0c]3B
08=@D`201``0P`<708811@200PH0P@480802201l0@D0NP4607X1101o0PP0P@D;07l32@2B1``0U0<8
09432P2:0PP0O`4406`31@1nBT/0Q7n104Y<CP1QEeH07hd7003o00T0oooo00<0:<Pl0?n0003oP000
703oP0000`3XJ3`0^3Rd0>QX?00;0?n000040=1@N02P8?00d51h0>QX?0T0oh0000<0d51h0>QX?03o
P000603oP0000`3XJ3`0X23`003o00080?ooo`@00?l004d09=@7081EAP1M61L0I2DU05a>D@1CCe@0
D4eA05ACE@1IFUd0HV9U06eYJ@1dL6l0OGMc08=fMP26LW40SWQd095nN02CQG`0VHYo09n>P02RU8@0
YIV80:BJQ`2XXY00[JFH0:VUV`2^ZZ<0/JnX09nQV@2GV8l0U9J?0:BVX@2Z[:L0[k>`0:jg]@2a][P0
]KVj0;2f^P2[][L0ZKBd0:^b]P2/];L0[;2c0:moQ`2U72H0/P/A0;<9402^1P`0Z`P=09`@5`1n?540
:cMZ02E9O01UOY80Og^307l`?02C2180W0<809`21`2I0PX0Ra4K044eF@17MIh0//SK07Y2D@1g1@l0
A2Ho06F3TP1`QXH0HGEd05mcLP1HKVh07cM<00PKA0013c`00@hi00HI=`08003o00P0oooo1000o`00
0`1@T7P0oh000?n0000B0?n000040;Ph]02P8?00X23`0>QX?0P0oh000P3XJ3`30:0Pl080^3Rd0`2P
8?000`2h>;@0oh000?n000040?n000060=1@N02P8?00X23`0:0Pl02h>;@0j6Pl1@3oP0030:0Pl005
0=1@N03oP000d51h0:0Pl03XJ3`00`3oP0001@3@D7P0X23`0:0Pl02P8?00d51h00P00?l02`3oool0
00X0oooo05P0:]T:06X_7P111080?`<202d10P0Q0P80704102X10P0j0`<0;04204D310110`@0;042
05/21P1U0@@0I`4206h10@1h0@<0OP8208D10P2;0P@0T@<809P52@2F10P0W@H90:@8302]2@h0/`/?
0;L<3`2Y6ad0fiFF0;n1Q`1_:bl0IeUH0<C7a03NhN40gn?U0=cRi03Jgn80fmoR0=oPi03KgN00g]cP
0>7<d`3>QY40^Se:0:HS;01k51X0>`X=02dU8@14BD<0GFIP07f6P@2CThd0ZY><0:Y]J`2@6A`0S`/@
07`Q8`2_Vi/0c=?E0<[Ce03>cm40O4=708872P261@H0Q@@808<420200PP0OP8807X11P1i0PD0NP86
07h21P1i1@T0K@84098>4P2G10/0UP<:08`21`210@L0J`<707Y6A`1mMWP0DU1D05Q7A@0QS0H00?l0
2@3oool00`1@T7P0oh000?n0000K0?n000030:0Pl02h>;@0oh0000X0oh0000<0d51h0;Ph]03XJ3`0
:03oP0000`2P8?000?l00?ooo`070?ooo`@00?l004h0:MP807aC?01O?CX0Ie1>05aDE`1;B4`0BTU;
05ECE@1FEU/0GEeQ06ATI@1cKfl0O7Ad089eM029MW40SW]f095nN@2DPWX0VXUn09n>O`2QU8@0YYV9
0:FJR@2ZXY80[ZFK0:ZSV`2ZYZ00[:VT09>DR`2;SX40S8j209FFS@2UZ:@0YZn/0:Zc/P2_];H0/[Jh
0:fd]P2[]KH0Z[6c0;2d^02a/kH0]I:H0:<R;02`2a80/@T@0;073@2b2a00Vb8[05i1I`0G=W40BfnB
07jFW`28SI00OS]508d5402F0`X0V08809P32@2=1@h0Lc9;02M:N@2ZcN40ZZFd07HH9P1f3aX0:BE4
05egP`1TNWL0H7Qc05YaKP1JKV`07c9:008>@0013Sh00a@g0319EP08f0P7003o00P0oooo1000o`00
0`1@T7P0d51h0?n0000C0?n00080X23`2P3oP0000`3XJ3`0X23`0:0Pl0050:0Pl0030;Ph]03oP000
oh0000<0oh0000<0j6Pl0;Ph]02P8?000`2P8?000`3XJ3`0oh000?n000030?n000040=1@N02P8?00
X23`0:0Pl080oh0000<0X23`0;Ph]03oP0000`3oP0001P3@D7P0X23`0:0Pl02h>;@0oh00052@N0L0
0?l02`3oool000X0oooo05P0:MT805hU400l0040?P<302h10P0U0@40904102l20P0i0`<08`4103h4
1P0e0`@08`4205H21@1M0@80H04306X10P1d0@80N@4208010P270P@0S`<809@2202E0`P0V0H:0:88
2`2_2Pl0^0d@0;l@4P305QP0`c8c07PK701fIf<0eM[H0>7UiP3Tj>T0gnCV0=[OhP3Kgn80g=oR0=kL
h@3@/;L0_fig0;dg@02o7R@0Na0C03P@4P1ED4d0W:>O0<C=b@3>e]@0e=SH0=?Gf035`<D0U6M_08XR
:@2C1`h0T0P=07dJ6P2DOgd0cMGE0<gDeP2k/kH0MB/^08H62P2510P0P`460883201n0PP0N0<807T5
2`1i0`L0P0<908@32@1m2@d0M0L70:<B5@2K2@l0VPD;09022@220@L0KP@807]4AP24OGl0AD9105A2
?00QSPH00?l02@3oool00`1@T7P0oh000?n0000U0?n000040>QX?02h>;@0d51h0>QX?0T0oh0000<0
^3Rd0=1@N03oP0000`3oP000103XJ3`0oh000?n0002P8?0D0?n000050>QX?03oP000oh000:0Pl000
o`00203oool4003o000/00cg0`1oEST0I5aI069OGP1JEEP0BdE804M5B01DDUL0D5AG05UMGP1RHf@0
Kfe^07acM@21MGD0RWUf08akM@2@OWP0UX=l09^:OP2KSH00WY200::DP`2SVHT0ZZ>E0:ZUVP2YYId0
ZJJN0:RYX@2EV8h0RHao08Z>O`2<THD0VJ6I0:F_[P2W/K80[K6f0;:f^P2]/[D0YZb_0:R`/P2Z[K80
^:N^09ld?`2_31<20;88400P0:X:402I;Sh0@Cib0299P01/Rih0QYZM08BEU027LgP0P0dG09433028
1Pd0PahZ06h_@`1H>5@0:SIX07ZR``2b_</0Q4IF08074P1S9SX0;49T06^7S@1VNGT0HgUc05aeL@1J
L700;D1C004A?00<8T<0=51L059ZJ@0=cPh7003o00P0oooo1000o`000`0Xb3`0d51h0?n0000B0?n0
00030=1@N03XJ3`0j6Pl00T0oh0000<0d51h0:0Pl02P8?001P2P8?000`3XJ3`0oh000?n000020?n0
00030>QX?02P8?00X23`0080X23`00<0oh000=1@N03oP0000P3oP0000`3XJ3`0d51h0=1@N0030:0P
l0050=1@N03oP000d51h0:0Pl02h>;@0103oP0001P3@D7P0X23`0:0Pl03XJ3`0oh00052@N0L00?l0
2`3oool000X0oooo01L0;=/;054D10110@00@P8302h10P0W0@408`0002l10P0h0`<06`4102L41P0M
0@80:08305/41P1F0040G04206X10`1d0@<0N04207h10`250@@0S`4809H42`0209L52P0o0:08302[
2@h0]`d?0;/=3`2l51H0R1DE05<f<`3;d/l0gnOW0>;Wi`3Tj>X0gN;T0=SNh@3Jg^80h]oS0=>W[`2`
=Sl0_aTO0<LG6`254Q@0?bhZ0:6WX@3?e=<0f]oO0=CKgP3Cf]`0e=SK0=7CeP2EJG00Q1TP09<9402C
0``0SPT>068B4`1hL6d0b]?B0<_Be02LR8T0M1PK08H42P220`P0P04708022@1m0@T0I@4305`00@1h
1@X0Q08808L42P1l10P0J`<409P@4`2710H0TPD;094220220@D0L@@807m5A@20MgP0CD]804Xj=00Q
S`H00?l000T0oooo00<0D91h0?n0003oP0009@3oP0000`2P8?00oh000?n0000:0?n000030=1@N03o
P000oh0001h0oh0000<0X23`003o003oool01`3oool5003o001=06Uk=@1TG5/0I69Q05UEE@1:A4@0
AdE705ABE@1BDUD0FEUJ069PH@1^JVX0N71`085dMP23Lg80Sgag09>0N@2DPgd0UXQm09V<O02GS7T0
Uh]j09VAOP2QVXT0XYnA0:BSV@2ZYj00Zj^U0:FSWP2<Sh@0RHeo08b@Q@2BVI80XjfZ0:Vb/@2^];D0
[[Jg0:N`]02V[k40Zk2d0;Z[/02XG6D0[A0H0;D;4@2a2A00ZP`B08lgBP0`>gD0=f2A08>MZ@2@X:40
SijM08>BT021FE`0S@LB08L8401Q<T/08S5V00l/J`1CMZ80Qifo0:FN]@25@500P@TD07HN:P0W:500
BVZ207>:S01NM7<0HgQf05ecL01JKfh0>e=J02I1C`1:J6/0CfUW04iWI`0NXR801`00o`080?ooo`D0
0?l000<0d51h0?n0003oP000403oP000103@D7P0oh000=1@N02h>;@90?n000040>QX?03@D7P0^3Rd
0;Ph]0@0X23`00<0d51h0?n0003oP0000P3oP0000`3XJ3`0X23`0:0Pl0020:0Pl080oh0000@0j6Pl
0?n0003oP000^3Rd1@2P8?000`3XJ3`0oh000>QX?0020:0Pl0030>QX?03oP000oh0000L0oh0000<0
P<00003o0000o`001@00o`0;0?ooo`002P3oool0F00Yf0X0BP/104010@100P80<08202H10@0T0@40
;04103H20P0H0P801`410104100g0P@0FP4305D0001I0@40J`8207H10`1j0@<0O`4208L10`2>0`P0
TP@;09D52`2@1@X0UPL<0:H:3P2b2`l0^0lB08<@4P1>;2/0[k6^0=kRh`3QiNP0hNGW0>?Uj03Qh^H0
gn3T0=o@eP3HVJ80_cHm0<<F6`2o4QD0VA@F05`l>@2i`;T0e]gI0=[Og`3Hg^00e=_M0=?If`3CemX0
]YjS08TR:02E2`l0T`H<09862`1a30l0=QPG09nSX@3<dM80^k:e07<i?01l3140P@8;07d12@1n0PP0
P@<80882201o10X0KP<807841P2810X0R0<808H62P1/20X0I0X=06d41`2=1@/0T@<808H11`1f10P0
PTI808j7R019AdH0BCDb026=1@00o`090?ooo`03052@N03oP000oh0002<0oh000P3@D7P<0?n00003
0=1@N03oP000oh0000H0oh0000<0d51h0?n0003oP0004`3oP0001@3XJ3`0oh000?n0002P8?000?l0
00P0oooo1@00o`00C@1WSS/0JV1O06UVH@1JE5@0Bd1304a2A@1ECU00DDm@05MFF01MFeX0JfEU07E^
K@1nLg@0Rgam099mO@2BPGX0TX1k091nM02APW@0THAe0964L@2CR7<0UXah09J@P`2MVY40ZJJQ0:NV
X`2[ZJH0Y:>N09VMUP2KWYP0WJ:N0:>^ZP2U/[80[;Be0:B][`2OZj/0XJZ/0;2OYP2VG6P0Y1`T0;<<
4P2^20d0Y0/A08XjC`0U>gP0AfjK096R[P2CWj80TInP08jMWP24Ti80QVU/08X:4`275b40<bYB06^1
Y02>U:d0TWjD08i8GP2752@0QPPA07PU=00c;UP09dI[086IX@1/P8<0HGEc065gM@1MMG80Eg5/05E/
JP1?J6H0D6aY04=QI@0B;D808W`b00L00?l0203oool5003o00030=1@N03oP000oh000140oh0000<0
j6Pl0=1@N02h>;@0103oP0000`3XJ3`0oh000?n000030?n00080^3Rd00D0X23`0;Ph]02P8?00X23`
0=1@N0040?n000030>QX?02P8?00X23`00@0X23`00@0j6Pl0?n0003oP000oh00102P8?00103@D7P0
oh000?n0003XJ3`30:0Pl0030>QX?03oP000oh0000H0oh0000<0j6Pl0=1@N000o`001P00o`0;0?oo
o`002P3oool0F00Ve0P0A@L103d10@0j0P<0:@4202<10P0[0P40<P4203T10P0R0P80?34a05Tm@@1?
0`L0EP4205D10@1N0P<0K04207L2101l0@<0O`8208H20P2:0PH0R@4608h2202?0`T0U@H<0:@93P2[
2`l0R14D06]BD036bLT0fMgN0=cPh`3NhnH0gN?T0>3Ui03Mf=d0ahfH0;i1BP3<8RL0eALJ0<HD602K
61T0LTQ50<_>c03Jgml0fMoO0=SNg`3Gg=l0e=WL0=GIg03<aLP0SCHk09`<4@2A1PT0RPD:06l:3`0j
9280U9VE0<W=c@39b<d0QUAK07T=4P2010X0OP8907d22P1m0@X0O`8808822@230`P0P08907h31`25
10P0QP8908H32@2A92L0P3dn06D52@2D1Pd0T08708D11`1j10X0QdU;08ElO@1CC4h0@2dZ01n;1000
o`090?ooo`03052@N03oP000oh000240oh0000<0j6Pl0;Ph]03oP000303oP0000`3@D7P0oh000?n0
00060?n000030;Ph]03XJ3`0oh0001@0oh0000D0j6Pl0?n0003oP000X23`003o00080?ooo`D00?l0
04d0J8X^06eQGP1/J6H0HEYK05<m@@199RT0ETQ<05=AE@1EE5H0GE]J06aVI`1iKVl0Q7Ih08ekN`2;
N7H0TGej08mhL`2=M6d0RWMY08j0KP2DQg40V8Yf09B:M`2BSW`0THj109^KT@2XZJ00ZJZT0:b]Z`2R
Yj<0WZBP0:2UX`2QZJP0YZn`0:Rc/P2S/:h0YK2_0:>YZP2PHV/0WaTS0:l>502]2Q00XP`A08LfA`0U
>740C6jH09Z@W@2MKWP0VeQT09]YLP2GRhh0RIFE09VGVP1l:c@0QPLB08HO<026:CP0Q1HU08P85P2<
2A80Q1dW060eC`0N:5l0;Dil07fFX`20TYH0KH2206AgMP1SN7D0GWEc05MaK01CKFL0CVMX02e9F@06
6d000A<l029A?P07003o00P0oooo1@00o`000`3@D7P0oh000?n0000@0?n000040>QX?02P8?00X23`
0=1@N0D0oh0000H0j6Pl0?n0003oP000j6Pl0=1@N02P8?020=1@N0030;Ph]02P8?00d51h00@0oh00
00@0j6Pl0:0Pl02P8?00X23`103@D7P0103XJ3`0X23`0?n0003oP0020>QX?0@0oh0000<0^3Rd0:0P
l02P8?000P2P8?000`3XJ3`0oh000?n000040?n000040=1@N02P8?00X23`0;Ph]0L00?l02`3oool0
00X0oooo04808m4504@5000l0@80<@4102H00@0Q0@00:@4103<10@0l0@40>`@603`G7P154aX0E085
05@20`1@0@80F`<306P2101e0@D0NP4307h00P240@80Q`4408/11@2>0@H0U@@;09P21`2S2@`0V0dA
04LH6@2i_K`0f=[L0=KJg@3HgN00g>7T0=_OhP3Ogn<0aI6L0;HV<@3A6R00f1TJ0=HF5`2c5aT0G1HG
0;be]03JgN00fMcP0=OKgP3Gg=l0em_M0=KIg@3Ff=d0/H^C09@A6@2L1Pd0S`L;07H=400V20L0OXJ0
0=7De03=d=<0ZiVM07LJ80261`h0P`<:07l1201n0@T207l22P0D088120200@P0O`88080220240`T0
R0<908T32P2<2a00[Sm109P@5@2O1P`0T04608D11@1l1@X0OCa009F;SP1DCe00=B<O01j:0P00o`09
0?ooo`03052@N03oP000oh000240oh0000<0X23`0?n0003oP000303oP0000`3@D7P0oh000?n00006
0?n000030=1@N03oP000oh0001@0oh0000D0X23`0?n0003oP000X23`003o00080?ooo`D00?l004d0
KhHR07=SGP1]JFX0I4mB05DR9@197Ah0ETI<05MEF@1BDUD0FeUK06eUJ01jKg00RGak095mO02>NWL0
SgUg08adKP29KVH0RWAV08ekJ@2EQW00Vh]d09VAO@2DT840T92209>DR02RXI/0ZjbX0:^ZZ@2[[:`0
Yj^[0:>[[02PZJ`0Y:j`0:Rc/P2T/Jh0WjZZ0;FWZ`2N;3<0/@dD0;<;402_2a00V3=103I2N01FFh`0
TdQI09@E8@2D31D0T10K098?6P2;9C00ThR=086CUP2ASY40NDeB07<T<P1i7Rl0NbHd06/aA01?=eD0
;c9P03<cI01HB6T0Meib08]jPP1jP8<0K82006EiN01UNGL0GG=b05Q_K`15HFX04b]9004@?P023d40
0A0l024c@`07003o00P0oooo1@00o`000`2P8?00oh000?n0000A0?n000030;Ph]02P8?00X23`00D0
oh000P3@D7P0102h>;@0X23`0:0Pl02P8?020?n000030;Ph]02P8?00oh0000<0oh0000@0j6Pl0:0P
l02P8?00j6Pl1@3oP0000`2h>;@0X23`0=1@N0030?n000030>QX?03@D7P0^3Rd00<0X23`0`3@D7P5
0?n000030=1@N02h>;@0X23`0080X23`00<0j6Pl003o0000o`001@00o`0;0?ooo`002P3oool0F00R
d0D0A`H103/10@0_0@80:P8202D10@0[0@40>04204020P160P@0B0P;04L31@1F0@@0D`8404T20`1J
61T0HADF06H2101g0P@0O@8308<20P260@80R@4308`1102B0PL0W0L:09d>3`1R30d0NW9^0=OIfP3I
fmh0f=[M0=OLg`3IgN00fMCI0<NHX@2i<C/0baHK0=PH703J6AX0dQTI09L/:`2YTY40fM[J0=_Mg`3H
g=h0e]WM0=SDfP3=]Kd0/H><0:IUL02N=3d0X``E090;4P1P2Pd0;@d=06=XI@33b/T0dM?F0;je_@1n
?4<0Q0TA08P32P260`/0O`8907l12@1n0@P0OP8808422@220@P0O`8808021`220`P0Q@@:08T22@2I
2@h0YPdA0:T<3`2R1`/0U0<808P21P1k1@P0Rda>08=gN`1NEUP0:ALB01f80P00o`090?ooo`03052@
N03oP000oh0001l0oh0000<0d51h0;Ph]03XJ3`02P3oP0001@3XJ3`0d51h0=1@N03@D7P0j6Pl00L0
oh0000<0X23`0>QX?03oP0005@3oP0001@3XJ3`0oh000?n0002P8?000?l000P0oooo1@00o`00CP1;
/Qd0O6aX075TI@1Q;Bl0Eb<T04dj>@1AAdP0G59I05]EFP1MFEd0KfM[07Y`L@29OWl0SWak091kN@2=
MGH0PfaX08=[HP29LEl0RgQS09:3JP2BPVL0VY1j09NER02AThP0TY><092@R`2HWIX0ZJb/0:Z][P2Y
/[80Zk6d0::YZ`2S[Jh0Y[6^0:Ze/P2V[jl0/HJ>0:XD7P2g3180]0`B0:0L:01B@g40GT]m09DN=@2N
31P0Qb4]06<nG011@6H0MceB08T<5P1TAEX0K8ZG09NY[P1aQ8`0Ef^601/dI@10FH@0=TId04TiH01e
;4H0P@lP08P54P271100OPLA07LU;021LW@0JWUi06AhN01JL7L0=4]S00LIB@013D<00Pho004A?@0E
;dX0@UML00KU1@H00?l0203oool5003o0003052@N03oP000oh000140oh000`2P8?050?n000030;Ph
]02P8?00^3Rd00<0X23`0P3oP0000`3@D7P0^3Rd0?n000020?n0000=0>QX?02P8?00X23`0>QX?03o
P000j6Pl0=1@N02P8?00d51h0?n0002h>;@0X23`0;Ph]0060:0Pl0030=1@N03oP000oh0000H0oh00
00<0d51h0:0Pl02P8?000`2P8?000`2h>;@0oh0002S8?006003o00/0oooo000:0?ooo`1H02;@1@1;
1P80?P8202h10@0V0@409`4102h10P0h0P80@@8204010P120@80B082050310160P80JQ`P07/P:01k
4aT0FP8406<31@1i0P<0P`4308<10@260@80R`450982202C2A00H@X=05i<B035b/L0f=WK0=OHg03F
f=/0eMWL0<Za^02XEUl0[B8Y0<8E5P3?5AD0e1DG0=HF6036;Bd0cZNV0=SGf03Kg^40f]kQ0=O?e031
VZ@0[eAQ0:TP:`2O3QD0W@dE09H>5@1Y2Pl0:`h?03m3?`28TX`0bLk=0<c=d@2`Vj<0P3Q208@94@27
1@X0Q`@908P42@220@H0PP8608031`1n0PL0P0890803201k0@D0OP<708421`230`X0Q`4709`83@2/
2Pl0[@X@0:863@2F0PP0R04607T42021@d@0T8>505aAE00M2`L06hL2003o00T0oooo00<0D91h0?n0
003oP0007P3oP0000`2h>;@0d51h0?n000050?n000070>QX?03oP000oh000?n0003@D7P0X23`0=1@
N0090?n000030>QX?02P8?00j6Pl01L0oh0000D0j6Pl0?n0003oP000X23`003o00080?ooo`D00?l0
04h0D[/S07i_J01WAD@0Hc8`04lh>P19?T00DTE:05eBE`1PEUh0I5YP079VJ`1nLgH0Rgj008imO@2>
O7X0R79`07iWHP1nIUT0Qg5S08QgI@2@PVl0UXUe09fBP02DTH@0UIJ:09FDRP2;RX80RX^309bOVP2Y
[:X0Y:f]0:bf]`2Y/K@0Yk6a0:^d]P2W/;80ZJf`0:9JI02a3QP0]P`D0:`?5`1lAf<0M5Z009`K;02N
5b80KCUK02<jMP0^DhH0JgVD08<fA@2<2aH0DS=G0620V029X:L0OIFS09jkc01QO9@0ViFV07lfB027
2AL0S`8=08l1302>0@X0R`8908D22@200`X0M2<[079eN013Ffh042M?008BB@014D/00Pm4008A?P0O
?e<0AVMW04aRHP0<c0/6003o00P0oooo1@00o`000`1@T7P0oh000?n0000A0?n000040>QX?03@D7P0
^3Rd0>QX?0D0oh0000<0d51h0;Ph]02h>;@01@2P8?002@3@D7P0oh000?n0003oP000^3Rd0:0Pl03X
J3`0oh000;Ph]0030:0Pl0030>QX?03oP000X23`00H0X23`00<0d51h0?n0003oP0001`3oP0000`2h
>;@0X23`0:0Pl0030:0Pl0040;Ph]03oP000oh00052@N0H00?l02`3oool000X0oooo01H08<l304X6
0@100@80<`4202`10@0^0@40;P4203D10P100@80@@8203d00@140P80@`8205L2101_0PH0NP8908@3
201X10L0B`0107831@200@80Q0420P270@<0;02=1@L0G`/>05E5@@2k_;T0e=CH0=CFf@3Fem`0fMKK
0<FQZ02V;cP0]1DL0;TA5`2l41<0`a0A0<hC5@3@51H0cE]M0=C;c03LgMh0g=oQ0=32bP2WD5/0ZA`V
0:lC702N4AP0K`/A04L82`0V2P/0@D=209FQX031b//0dmWK0<G4b`2=GfH0Ob0X08<=502720l0Q@<:
08P32@280`P0Q0<708421`1o0@P0O0870P1o0PT04P1m0PL0OP8808<320240PP0RP<809l93@2Z2100
Z`T?0:H63@2K10/0R04707T42@29BD`0TH:304m3@`0K1`D06HD1003o00T0oooo00<0D91h0?n0003o
P000703oP0000`3XJ3`0d51h0?n000060?n000060>QX?03@D7P0oh000?n0002h>;@0j6Pl2P3oP000
0`3@D7P0j6Pl0?n0000H0?n000050>QX?03oP000oh000:0Pl000o`00203oool5003o001>02[M4@29
HeX0IcDc06M?C@1;>c/0BC]00554B`1JD5L0HEMO06ELH@1aJ6/0OWAh08EjO@2;Ngh0SGUj08E]J`1m
HE`0PFMN08E_H`29MVP0UXAe09R9MP2MTH40U92309NGR`2LVY00TYB;08j@R02;ShP0XjRS0:^c/@2/
][H0[KNh0:Zb]@2Z/;@0YJja0:6RZ@2H?TT0/0dE0;@?5@2[<3H0UV1c0:4O;`2S7R`0GTA_01Y4PP1Q
QJ<0SiJP08i<E`2C2QH0Qad]02P]H`1bU;00Ni:L09BZ]`19Hgh0PW2207hH9@2;0``0T`<<09412P2?
0@X0RP8:08H32`240PT0Q04906l74P10>UH00aY@004CD0014D`01AQ;00PLBP0@:DL0BVa[04eXI@1B
JVH04=8A1P00o`080?ooo`D00?l000<0D91h0?n0003oP000703oP0000`3@D7P0X23`0:0Pl0030:0P
l0050>QX?03oP000oh000?n0002h>;@00P3XJ3`01`2h>;@0X23`0:0Pl02P8?00j6Pl0?n0003XJ3`0
1@2P8?000`2h>;@0oh000?n000080?n000030;Ph]02P8?00X23`00<0X23`00D0^3Rd0?n0003oP000
oh00052@N006003o00/0oooo000:0?ooo`1H023=0`1:1040?P4103@10@0_0@40;`8102`20P0a0@40
?@4103h10@0l0040?P8203l10P1T0`H0LP4507`11P230PL0J0<70440001_10P0P04208D10@270P<0
S0<508D8301;9bD0Zj^W0=;Ce@3Ce=T0eMKI0=SGg03C_L<0X3Hn0;@C602i41D0^@lF0;X>4`313a80
bA0E0<dE603@Kg00f=CF0=gNhP3Ig]l0RGQm06lM901]4AH0DPT=02T10P0<1`L06b@Q06eiMP2`^KL0
d]SK0=;IgP2obm<0HV=^03dB600l1`T0?@D805@93P1e20l0QPD<08T32P230PP0O`8807l22@1n0PL0
O`8508022@1l0PT0P0<90842201o0@P0RP@:0:0:302X20l0ZPT>0:P83P2K0`X0R@4707T4201e=CL0
PG=e04/m?P0I10<0:DT2003o00T0oooo00<0D91h0?n0003oP000703oP0000`3@D7P0oh000?n00006
0?n000050=1@N03oP000oh000?n0003@D7P02P3oP0000`2P8?00d51h0?n0000L0?n000030:0Pl000
o`00oooo00L0oooo1@00o`00800Qi@/0Qe8m06m@C@1ODU80BSXh04/j>`1@@dD0FDeB05mFF`1VGF80
MFU^089eN`24N7`0R7Yk08YgN024JfX0NEiI07iVG@27Kf80RgAV095oL@2KSG`0WY:309JDQ`2HV8l0
VIVB092ES@2EWI<0Ri2:09NPW02W/;00Zk>g0P2[]KL0;02X/[@0Y[>d0:n`/`2O>dH0/`dD0:dA5@35
DUL0YbH_0:DL9@1SAg407TV607ZFZ`2IS9D0TCi<09<:5P2=5R<0D3US031BP`1cTJ00WkO308^S/`1k
K7l0MQ<Q08P22P2?0PT0S`8:08X5301o5b<0K2hm05h/?`1g5R@0O`8=04l89@0:4T`00AAD004FDP0F
<eX0@5ib00XQA@0T@UH0D6m/04MSI@0dCUL08JLX1P00o`080?ooo`D00?l000<0D91h0>QX?03oP000
1`3oP0000`3XJ3`0d51h0?n0000A0?n000030;Ph]02P8?00X23`00@0X23`0`3oP000103XJ3`0oh00
0?n0002h>;@30:0Pl0040>QX?03oP000j6Pl0;Ph]0@0X23`00<0^3Rd0?n0003oP000103oP0020=1@
N080oh0000<0j6Pl0:0Pl02P8?00102P8?001@2h>;@0oh000?n0003oP000P<0000H00?l02`3oool0
00X0oooo04807ld304X50P0j0@40;04103020P0X0@40904103020P0m0P80>`4003`10@0g0P80@@84
06P21@1a0@H0M`4607T2201E0P@0?00006l41`230@@0R08308X2102=10H0H@/;089kM@3=dM00c]?E
0=?Ff03Fe=P0c[Rm0:YDFP2`5AT0^14D0;TA4`2j41@0_0lC0<4@503641D0bQ@H0<MUIP3GdmD0g>3R
0=WNg`1LI6L08AdO02<Q8@0a=380D5QE08>?S@2[][@0`l[;0=?Ig02mb]80QiVS03Y>EP0E8bH09bd_
02lf=`0Y;bh06ADD02T41P1S2A00P@D<08<22@200`P207l2200D084220210`L0M`8407/11`240PT0
P04908L12@2O2@d0Z@T>0:T73P2X20d0VP<708`21`1g10T0SeEH081aLP0m;c005@<303T<0`00o`09
0?ooo`03052@N03oP000oh0001/0oh0000<0d51h0>QX?03oP0001`3oP0001@3@D7P0j6Pl0?n0003o
P000d51h00H0oh0000D0j6Pl0?n0002h>;@0X23`0>QX?00K0?n000050>QX?03oP000oh000?n00000
o`00203oool6003o001=08=C=@1dIV@0GE=B04he<`19;C00E4E905M<D01QE5`0J5UR07IXK`22MW`0
PgMk08]jO@2;MgX0Pfe[07ILE@1mI5P0Rg9V08ajJP2APG80V8]m09R@P`2FU8D0UiR=08nCS02AViL0
_LW:0:F[[02BViH0Yk6_0:Rc/`2W];@0[;Jg0:Vd]P2W/k@0Z[2a0:==DP2h41L0]PhF0;dL9P2b5Qh0
OTAS02M4P023QZ00V5iY098N:@2E2aL0QBHg04HkJ@0G?7L0OYjd07jGX@2<Yjh0PhJB07`S<@2=0`d0
R`8808l22P255A`0FSE>02H^G@0H<F00?e=e06LeA`1T1Q`05`e6008DFP0G<5d0?ei`05QeN`0YA5X0
7SQH028oD`19IVh04b]8008D=`0SOSD01P00o`080?ooo`H00?l000<0d51h0?n0003oP0001`3oP000
0`3@D7P0oh000?n0000<0?n000050>QX?03@D7P0j6Pl0?n0003@D7P01P2P8?000`3XJ3`0oh000?n0
00020?n000040;Ph]02P8?00X23`0=1@N080oh0000<0j6Pl0:0Pl02P8?00102P8?050?n000060=1@
N02P8?00X23`0:0Pl03@D7P0oh000`2P8?00103@D7P0j6Pl0:0Pl02P8?020=1@N080^3Rd00<0d51h
003o0000o`001000o`0;0?ooo`002P3oool0F00Nc080B0D203D10@0]0@80;`820241000U0P<0<P42
03d20P0j0@40?04203420P0o0`D0L@<907T22P1g0`X0HP<804L10`1D0P<0N08408810`270PD0SP@9
08H7301C:RH0_l6m0<kBe03?dmL0d=CG0<^`]P2I?d<0[ATL0;8A4`2L4aL0PQ4D07hC5P2J51P0_Q<J
0<8>4`3441D0]SDk0=S1aP3Jg^00fn3P0<39b02b_;P0ZKJ_0:bg/@34cL`0d]WL0=7Ig038d=P0Sj2X
03eEG00bB4/0IgUf09NTX02U/:l0ZKFd0:Ja/@2BWIH0ATY50283101/2100PP8:08@42@2310P0P047
088120230`P0M04207`42@240PT0P`8908`3202O2@`0YPT=0:L8402S10`0V`<:08l2201d10T0PDe?
07ARIP0d92H04`4103d<1@00o`090?ooo`03052@N03oP000oh0001X0oh0000<0d51h0?n0003oP000
2@3oP0000`3@D7P0oh000?n000070?n00080^3Rd00<0j6Pl0?n0003oP0007`3oP0000`00o`00oooo
0?ooo`060?ooo`H00?l004d0R5dh06YFE01RDE80Ba`N04dN8P1D?TD0F4YD069FG`1XFF00MfQ`081b
NP23M7T0RWQj08]bM@25K6X0MEQE07]PF@2<M6/0TH5b09R8NP2HRg/0VI6309NDQP2IW980O8J10;G0
`02__<80X:R^08F=RP2SZj`0Z;6b0:Nb/P2W/[@0Y[>e0:6_/02R[:l0YfM[0;@B6`2g2QH0^0`E0;@T
;02CIGl0REAc09DU=P2P41`0V0hI088dAP0h?6d03SEd06:5X022UYh0YKS4082IZ`2@MH<0Q`XE0982
2`2A0@X0T0<;07`O;@0I84l0<eIk072<VP21O8@0KA`W04T79`074UP02b=N055_O@1FLW40E71g00HO
@@0jEFX01Q]000lWC0013d000@hi01YW=006003o00P0oooo1P00o`000`3@D7P0oh000?n000070?n0
00030:0Pl03oP000oh0000`0oh0000@0d51h0:0Pl02P8?00oh001`2P8?000`3@D7P0oh000?n00002
0?n00080X23`0`3oP0000`3@D7P0X23`0:0Pl0040:0Pl0030=1@N03oP000oh0000<0oh00102P8?00
1`3oP000d51h0:0Pl02P8?00d51h0?n0003@D7P01`2P8?06003o00/0oooo000:0?ooo`1H01g;0P12
1040;@0102X10@0[0P808`4102H10@0j0P80@08203T00@0n0@80<@8402T1101>0`P0E@8:04`22@11
0PH0G@@907l62`2410P0Q08708T21`2;0`P0I@d?0928Q@3=dM80d=;F0=3CeP37][X0WS]10:LF6@2B
4QH0C0T=02TI6@0h>3L0?C`n02hK70254AH0_0hD0<4>4`2l4aL0^TeG0=>V[P3Kc=80gM_N0=cKg`3J
f]d0f=?G0<G5c@2>WjX0EFYe04MMH`1[Ngh0[;Nh0<38b@3=eM@0d=OG0=3Ff@3?eMT0cmOH0<kGe@30
alD0PG]i068H70210`/0Q`<:08H220250`L0Q08708D31`220PL0P04908022@240PL0UPL<0:89302T
1`h0Y@T@0:873@2K0`X0S`8807451`2DIFD0JUIJ024B500D0P40?PX3003o00T0oooo00<0D91h0?n0
003oP0006@3oP0000`3@D7P0oh000?n0000:0?n000040>QX?02P8?00d51h0>QX?0@0d51h00<0X23`
0=1@N03XJ3`00`3@D7P70?n000030=1@N03oP000oh0001H0oh0000<00?l00?ooo`3oool01P3oool6
003o001=09=S?01XB4H0I4Y;04d>3P1>6AX0E45305M:D01RE5h0JEYQ07MVKP20KWH0P71f08EfM`27
Lg@0QF]Y07QKE`1mHEd0Qg9Y0960LP2DQGD0UhUj09ZAQ02GU8H0V9^?07V2O02MZJX0W:V_092HW02A
UYD0Y:V/0:Z_/`2Y/kD0ZKBf0:Fa/P2X];@0ZK>e0:b9S@2T5R00]@hJ0;H>5@2^4Q/0WR8d09lF902V
4AX0VQ@Q088iC`13A7@04cMd05IjVP2BZk80S9nY0;73d@1/Oi80P4]H08d73`2?0P/0RPH>08D53@21
31P0Je5V08BLY`2DWJ<0O4UB07D85P0c23400a9H020lI@1MMgX0G7Ef03IBIP0<:4L0BfQc00HH?P01
44<00@e0004?>@0KBCT01P00o`080?ooo`H00?l000<0d51h0?n0003oP0001`3oP0020=1@N0d0oh00
00@0j6Pl0:0Pl02P8?00j6Pl1`2P8?000`3@D7P0oh000?n000060?n000030=1@N02P8?00X23`00D0
X23`00<0d51h0?n0003oP0000`3oP0001P2h>;@0X23`0:0Pl03XJ3`0oh000;Ph]080X23`00D0j6Pl
0?n0002P8?00X23`0=1@N0040:0Pl0030>QX?000o`000?l000@00?l02`3oool000X0oooo01<0<[T7
03H30@0S0@009@8201l10@0V0@40:P4103T10@100@40@04004D10@0e0P@0604302T31P0`2@/0<@H9
04D3201m1Q00R@890080S0@904<0SP<608<;2`1E9R@0_/700<_@d`3>d]D0dLoD095DFP2G61h0LPlE
02T3100k?c`0XJfX0;2l^02a^kL0Z:b[07lb<`2d4aD0_P`C0;h=4@2j4aX0ZalZ0;==F@38Phd0bhbJ
0<9jR`2QFF/0BRhn00dP:01BIfT0UJ>P0<kCe03EfM`0dmKJ0=7Gf@3@emT0cmKH0=3Ff@3@eML0c=?E
0<oDe`3@dM80OT]>07X52`210`L0Q`<808T320250`L0PP8607h11P210`X0O04808811`2I20h0X0H<
0:<7302T2@h0X@L<09T42`2:0@P0K`P:09IYJP1C?Cl03P@401@10@0n2P@00?l000T0oooo00<0D91h
0?n0003oP000603oP0020=1@N0L0oh0000<0d51h0?n0003oP0001@3oP0040:0Pl2L0oh0000<00?l0
0?ooo`3oool01P3oool6003o001>07Ik:`1_BD@0Hc/h05D?3P1C:BT0EDA405];D01VEEd0L5IO0714
CP1eD5P0NFU_07i^L026Lg@0RFm]07iPF`21IV80RWA/091nLP2>P700ThQg09J@P`2FU8L0VIN?08R:
Q@1nQH@0RXn>08F9Q@2NXj40Z:n_0:J][`2Y/k@0ZKBe0:Va]@2W[k80X:b^0:b_/@2TCeP0/1HR0;L>
5@2Z6R40WRTd090b@`1d@Ud0ATEd0251M`17KID0OYZY0:Bh_P2:WZD0W:jg08VOZ@2BWj/0NbXj08X4
2`1l8Rh0B3EE054hD@1g5B00OAhX0:9hQ@1m<400P0PC07<?7P0K44@01b5H04m_OP1LM7/0<TeT00PT
BP0iFVT0EG1`01lfC`0144800Q1000lV@`0T>4D00o831@00o`080?ooo`H00?l000<0d51h0?n0003o
P0005`3oP0000`3XJ3`0oh000=1@N0080:0Pl0030>QX?03oP000oh000080oh000P3@D7P90:0Pl080
oh0000<0j6Pl0;Ph]02h>;@00P3oP000102h>;@0j6Pl0?n0003oP0020:0Pl0070;Ph]03XJ3`0X23`
0:0Pl02h>;@0oh000;Ph]0030:0Pl0030?n0000Xb3`00?l000@00?l02`3oool000X0oooo05P0B:L>
03<40@0L00006P8200l10@0S0P40:`0103X20P140@40BP4104d10P1:0`P07P8406QEE`2/Vj00ID96
07DG70281@h0S0<:08`4202A1PT0TPX=06hF501dI5h0bm;A0<_Ad`3BdmL0]IZP07lR9@1?2`d0;A`L
06I/J`2mal80e]WI0=_Mg`3JgMl0emcK0;^@S@2U7Qd0_PhC0<0?4`323a@0`a4G0;lE702i6B40]AXT
0:HL:01M41P0=Blb08>AT02g`/40cmKE0=;Hf`3Bf=`0d=KI0<kGf03?e=L0d=GH0=;Ff@3?e]T0c=GG
0<kFf@3?eMP0TGIh07L83`1o0PH0R0@:08/52`220`L0P08907d22@1n0`P0O0<808@31`2I1`d0W@L<
0:072`2T2Pd0WPD909H32P270@L0L0`?0:9jO01B?T002@4101T20@112P@00?l02@3oool00`1@T7P0
oh000?n0000:0?n000030>QX?02P8?00oh0000/0oh0000<0^3Rd0?n0003oP0008@3oP0000`3@D7P0
oh000?n0000E0?n00003003o003oool0oooo00H0oooo1P00o`00CP1RRah0MTY705ll=P1D<R/0DD0n
0553A`1MCUH0JdUC06hf?P1/51d0M3@j075MH`1fIFP0OVQ/08=YJ`22IV@0OVAP08YbK02=NFh0SWa_
09:6N@2FSX<0V9B;09RGS`2GVi<0V9jG08j@R`2;ShP0Uj2N09ZSY02HXZ<0Yk2`0:Rb/`2X/kD0Xk2`
0:>^/02IXJ@0Ye=L0;0A6P2`41P0PE1c03QFR@0lG8X0B6^E06J6X@23WZX0SjBX09JXZ`2CYZT0TJV^
0:JmaP1IMX/0TjB_07Xa?@2:1Q00KRY104aCO02>SJL0Pd5=08<53P241Q00O0TB06LP;P0d9dT011I>
039DM`1@KH4063=L00@PC00gEFX0FWAg05QaK`1@Ifh062m:020lD`16I6T0<TU>00k@3`D00?l0203o
ool6003o00030;Ph]03oP000oh0001T0oh0000<0d51h0:0Pl02P8?001P2P8?000`3@D7P0oh000?n0
00090:0Pl0040;Ph]02P8?00X23`0:0Pl080oh0000@0d51h0:0Pl02P8?00j6Pl0`3oP0000`3XJ3`0
^3Rd0:0Pl0040:0Pl0040;Ph]03oP000oh000>QX?080d51h0P3oP0000`1@T7P00?l0003o0003003o
00/0oooo000:0?ooo`1104NV3P0c1040704101P20P0@0@408P8102`10P0h0P40@08204P10P1B0080
FP<705PS9`1D>D40J3e8074Q:`1m1@d0R08;08T32@2<1@X0U0L;08TJ6@1?;2H0][Rd0<W@dP3>d=<0
/YZO07<_=00g3@d0IVQW0:je/`3=dm@0f=?G0<BJX`2^JWH0X86:0=KJg@3B_l00V2d^0;lD5`313Q80
aA0F0<<>50374QH0`A<F08T@4P0k30`0FEYF0;K0_@3@fMP0dMWI0=CIf`3BfM/0d=KJ0=7Gf@3=e]H0
c]GH0<kCeP3=e=H0cMOH0<kFf@3>e]P0d=OI09IiO@1k2a400`200PT0501n0PX0O08907/2201i0PL0
O@<808X32@2H1@/0V`H;09d7302Q20/0W@D;09D42`260@P0NADI0:9jO@0a7b@0104101`10P152@<0
0?l02@3oool00`1@T7P0oh000?n0000G0?n000040=1@N03oP000oh000>QX?080oh000`3@D7P00`2h
>;@0oh000=1@N00I0?n000030=1@N03oP000oh000100oh0000<0d51h0?n0003oP0000P3oP0000`00
o`00oooo0?ooo`060?ooo`H00?l004h0A:@<06h`8`1]CdX0EdI00550@01FADL0HdU=068S:@1W61d0
KB4U06Pj?`1XDUX0LV1R07YUI`1mI6L0PVQZ08I[JP27KFT0RgM^08enL@2ER7T0Uhj309VES@2IUi00
UiZD09BKUP23R8<0Q8^407b6O`1kQH80QY2C09RSY@2T/;40YK6b0:Bc/`2T/K<0YJ>X0:4i@`2h3aL0
]@lH07a3J01GP:H0UJZc09NY[@2DY:T0U:FY09BXZP2Y_;l0SZ>X09:Z/P21WZH0Oiba06b:Y@2>Mgl0
OQ4K08074`1j3b40NPdO07d84P210`X0P1@L050cC`0A8Dd0941R03YELP0:8d`0225>02A1I01=KW/0
GWUk06=iNP1KLg<0FG5b04mZJ@1FLFl0DFe[02M2B00MY205003o00P0oooo1P00o`000`1@T7P0oh00
0?n0000K0?n000030;Ph]02P8?00X23`00@0X23`00@0j6Pl0?n0003oP000^3Rd1P2P8?000`2h>;@0
X23`0:0Pl0030:0Pl0030=1@N03oP000oh0000D0oh0000<0^3Rd0:0Pl02P8?00102P8?000`3@D7P0
oh000?n000060?n0000308300000o`000?l000<00?l02`3oool000X0oooo05P0AZ@=03430@0Q0040
=Q8B01T10@0J0@40900103D20P0i0@40AP4205@21@1I0@<0F@@905`94P1S1@`0L@<907l22@270PX0
R0<:08/42`2?1`/0LBTU09jHU03=d]<0c=;E0;6OXP1T:bl0>QPG07j2P03<cm00eM;H0<BU[`2YA500
[1/T08PF6P1eEUH0fM_M0<^UZP2U9BT0`A@F0<8@50384AH0bQ<F0<<B5P284180DCdk0:2VX`3:dm00
eM_M0=CIg03BfM/0dmWK0=;Ig03@e]/0aLK;0;:X[`2LP8`0Ugf90;6^]@3;dmL0d]KJ0=;GfP3<bm00
OdUA08863P210`P0O@4807h22@200PT0N@8807@11`1d0@P0M08607h4202@0`T0V@D909`52P2O1`d0
V`<<09432P250@L0MQXM09QhNP0K41<00P4101/20@1320800?l02@3oool00`1@T7P0oh000?n0000F
0?n000030=1@N03oP000oh000080oh0000<0d51h0;Ph]03XJ3`0103oP0000`3@D7P0oh000?n0000=
0?n00080d51h0P2h>;@20=1@N0050>QX?03oP000oh000=1@N03XJ3`04P3oP0000`3@D7P0oh000?n0
00020?n00003003o003oool0oooo00H0oooo1P00o`00CP14]`d0IBXG06m@C@1GB480ECLj05lb>@1W
>Sl0H3Dh06U5B01WBe80HTmG061=EP1YE5T0M5mR07aRIP22IfX0R6]/08Q`J`2?O7D0TH=i09J9N`2I
TXD0V9F<09^JU029SHH0OhN0071kLP1cOGH0N85m07F0O@1mRHT0RiZJ09ZWZ02V/;<0XJb]0:Bb/`2^
ZJh0WB`d0;T=502h2a40X2Hj05=MQ02H[kP0W:b^09f//02JZJh0UJJ[096TY`2W^L00Y;c6059dS01j
VJh0Bg2:0:o4bP2LQY00ISA3068U>@1N:Sl0F3A707LO:`1o82/0@bi>05Y=I@1VE5d0I51D065OI@1K
KW<0Eg=b05UfLP1LNGD0Hgak061hN01KLgH0C6UW04i/I`1?K6`083a402RR;0D00?l0203oool6003o
0003052@N03oP000oh0001/0oh0000<0j6Pl0=1@N02P8?00102P8?030?n000030>QX?02P8?00X23`
00X0X23`0P2h>;@40=1@N080oh0000H0X23`0=1@N03XJ3`0oh000>QX?03@D7P:0?n000030:R8?000
o`000?l000<00?l02`3oool000X0oooo05P0@Z<<0303000S0P<0E34b01d20P0G0@408@8103410@0h
0040A`4304`00P1?0080D`0205h01@1V0@D0KP4707P12@220P/0Q04808X42P272@`0NE5<0<S<b`3=
e=D0d=7B07ICE`0Z20/0I6AO0<[>cP3Dc=80/H>=09h`>@2h5A/0Ta<F03h>3`2_[:/0gMcO0;YdO02h
6B00`a4E0<DA5P374QH0bA<H0:/B5P146QX0/;Rf0=CMfP3Eg=`0e=_M0=;If`3Df]`0d][L0<oAf02L
PY80PDYF07HS;`1l5240KAXV050mA02i`L@0dMOJ0=;Ef@2TTYX0LAhX08@52`210PP0O@8807d21`1o
0`T0M`8707411P1c0@L0N0<707`21@2>10X0U@@909`52`2L10/0V0D;08`120240@L0PRd]08Q]K@0=
1@L00@0001T1000n1P400?l02@3oool00`1@T7P0oh000?n0000J0?n000030=1@N02P8?00oh0000D0
oh0000<0d51h0?n0003oP000303oP0000`3@D7P0X23`0?n000040?n000040=1@N03oP000oh000:0P
l1P0oh0000<00?l00?ooo`3oool01P3oool6003o001>02KE1`1V;a`0JSll0694@01L7b40HQhT05hf
?01OBE40GD]F06A?FP1PCUL0G4YC065;DP1XDED0ME]N08I/K02;Kg00QG5]08akL`2CPW/0V8]n09VC
QP2JUh/0QH=k07QmM@1cNW<0Lgef07N1NP1iPWd0Mh9o07R3P`20SXh0TJ6R09n[[`2PZjh0XJfa0;J`
]@2I:S@0]PhE0;X=4`2a3QP0Od1O07R>Z02K[;40VJR/09f^/02W^[`0UZfb09bc^P27X:d0VkC505Qk
V`1JQ9`0^MKP0;oCgP2V^lX0IgfJ03]8K01:>5H0M14P08@53P1i1aD0L`D?06l4301Z0`T0I0XA06@i
?01QK6`0Fg=a05mhM@1KMW<0GWYh04QSJ00_CU40AF=S024jC@076cD0<7hl1@00o`080?ooo`H00?l0
00<0D91h0?n0003oP000703oP0000`3XJ3`0^3Rd0:0Pl0030:0Pl0@0oh0000<0^3Rd0:0Pl02P8?00
0P2P8?000`2h>;@0X23`0:0Pl0090:0Pl0030;Ph]03oP000oh0000h0oh000P3XJ3`00`3@D7P00?l0
003o0003003o00/0oooo000:0?ooo`1604:S300f2PL0CC0a05U3A@0C0@405P4201h00@0`0P80>`41
04H2101;0@<0C@4305H11@1S0@H0JP4507822@1j0@X0O@8707l2202610T0R1`M08ekM`3:dm<0cMGF
0;F`/@0l9BH0G5]I0;Jk^@3@cM00ZF]g09dP;02a4aT0W14F050O802KV9L0e=KG0=[7c@2_>3l0aA@H
0<H@503:4QL0b14E0;hE6P1_4A@0TXj<0=GIf@3IgMl0f=kN0=KKgP3Cf]d0dMCI0;n^]P2BEV40QAlZ
08TA6P2831@0N``C03d<4015BDX0_<O70<oEf02f[[D0LcU307/=5P200P/0PP<;07l22@1k0PH0N@47
07811@80L@460100N@4608H21P2<0`P0T0<809D32P2I10X0U0<:08`22@260PP0Q3@e07QLG`080P@0
0P4101h20@0o1@400?l02@3oool00`1@T7P0oh000?n0000E0?n000040>QX?03oP000oh000?n00080
d51h1P3oP0000`3@D7P0oh000?n0000;0?n000030=1@N02h>;@0d51h00H0oh0000<0j6Pl0?n0002h
>;@06@3oP0000`00o`00oooo0?ooo`060?ooo`H00?l004h08N@9064Y2`1^?cT0HRHT06@F5P1R<CD0
G4M?05Q8C`1MBe<0H4]B05e6D01KAe80Gd]B06=?D@1_Ee/0QVa_08]cLP28M740SG]b09:3N@2ERH00
V9:708Z7O020OGD0NWeg06UcK`1MKV/0FF]Z06EfMP1ePH40MX:307Z6Q`1nSXh0UjNY09RVZ@2IYjd0
YjR]09Xh@@2`2a<0^0X@0;P;4@2R62H0JEMi09J^_P2JZ[40VJje08jUZ02X_/<0X;W106F9X@1`TZd0
>VB709VlbP30eMl0^lSG09bBY@1hAU/0LATY07X74`260`d0Q`8:08<12P1i0@T0M04907011`1_0@P0
I0@906A4AP1KKVd0Eg9`05EcK`1FLfl0CfY/01/fA`0A9ch00@dc004?;`0WASL5003o00P0oooo1P00
o`000`1@T7P0j6Pl0?n0000M0?n000030>QX?02P8?00X23`0080X23`103oP0000`3XJ3`0X23`0:0P
l0030:0Pl0030;Ph]02P8?00X23`00H0X23`00<0d51h0?n0003oP0003P3oP0020>QX?0030:0Pl03@
D7P0j6Pl00D00?l02`3oool000X0oooo05P0?Z0;048H4@19:R/0:@lC01D10P0H0P80704102`10P0l
0P80@`4204/10P1A0@<0GP8606D11@1Z0PL0JP@:07442`1n0`L0P08708D42`2<>c`0/Jn/0<gCe@3<
dmH0EeIF06U/I`36c</0d<_@09eMIP2P5Q/0ZQ0F08dA5@106AT0WjFS0=;JfP3Ke]X0]61Z0<0G7038
4180bQ4D0<dB5P356A/0Na4A08QbL03@fML0emgO0=KLgP3HgMl0e=cM0:2[]01NCUd0ORHd09L@5`2H
3Q80S@dA06h=4P0Z2PX0CU]F0;6o_03@emT0`Ko407Pm@`1n2a<0P`@:07h3201m0@T0O`8:07d2201j
0PP0L@8506h10`1`0@@0N@4408<110230@<0RP8609832@2G10/0T`4909022P250`T0Ue=F03/T:006
0@80104102H10P1110800?l02@3oool00`1@T7P0oh000?n0000E0?n000030>QX?03oP000oh000080
j6Pl1P3oP0020>QX?0`0oh0000<0^3Rd0=1@N03oP000203oP0000`2h>;@0j6Pl0?n0000B0?n00003
0>QX?03oP000oh0000<0oh0000<00?l00?ooo`3oool01P3oool7003o001>06/b301a?CL0IQlK06Ha
;`1NBDh0EDE=05Q5CP1JAe40FTE@05a3CP1MAe<0Gd]B06==D`1_EUX0P6IZ08ieM02<MG<0TGmi09F4
O02@QW/0THV107MdK@1WKVP0KWId05a^K@1_OGX0IGMe04aSI@1/OG/0Lgmo07>1PP1jRXT0P96B08jO
X@2DYJP0VjJY0:5HH02/51l0^0/E0;L:3`2c2a80VB/o07=hS`2FZk80X;Fh0:o4bP2H/KX0NiRU08bX
^01WRjT0H8bX0:_7f@2RVZ/0QdEJ088B802010h0O`4908022@220PT0Q@8908@2201l0PT0L`890742
1`1`0@L0JP4505TK8P15CED0Dg1_05=`K01@Kfh0;dYL008@=`0133<00@X_004?;@0N;C@01?<31000
o`080?ooo`L00?l000<0d51h0?n0003oP0007@3oP0001@3@D7P0X23`0:0Pl02P8?00d51h00@0oh00
00<0j6Pl0:0Pl02P8?000P2h>;@70:0Pl0030=1@N03oP000oh0000l0oh0000L0^3Rd0:0Pl02P8?00
X23`0=1@N03oP000:<Pl00@00?l02`3oool000X0oooo05P0@:@904LO400Q10<05`4201D10@0L0P80
7`4202/10P0k0@40AP4205820P1H0P80G`4606L21P1U0PH0B`0404l2101m10P0P`@70844202=De00
`lC30<kCe02laLL0<T<m0;O0^@3Ae=D0[HR?09HI7P2N41<0NA4E02`61P23RXH0cmSH0=KGg037VZ<0
/R4X0<@C5P3441@0b0lE0<X@5@2V7al0GcXh0=7Cd@3FgMd0emkO0=OLg@3Ig=l0d]_K09FTYP0W8b/0
GQ8I09L?4`294QH0FP`@01d4100nCTL0/knj0<cFeP38c]<0QV5Y080A602610/0P`<;07h2201n0@P0
P08908432P1l0P/0L04506`00P1b0@@0O04508811@2100@0QP8508l11P2E0PT0U08908l12@240`T0
QDA902@>50060@<01`4102`10@0o0P000?l02@3oool00`1@T7P0oh000?n0000D0?n000050=1@N03o
P000oh000?n0003@D7P01`3oP0000`2P8?00oh000?n0000;0?n000030:0Pl03oP000oh0000L0oh00
0P3@D7PJ0?n00003003o003oool0oooo00H0oooo1`00o`00CP1/A`h0GR0G070j=@1[EEH0E4I:05=2
B`1F@d`0F4Q@05Y7CP1F@DX0F45<05e:D01TCeD0LeeP081WJ`2<Lg80SgMe08moN@2BQGl0T8Io08=n
LP1`M6/0JG9]069[J@1EJ6X0H71d05AYK01?I6@0LH5l071nOP1_OX40MhJ707b=S@23UIH0T:2S09VW
Z@2/Ri<0SQhZ0:l?6@2h3140]0/@0:h=5`2=>U00T9nd09FX[`2M/KT0V[:l08JW_P1VRJX0:D]k07^9
X`2>FW00PaDY08l54P2>0P/0QP4908012@1o0PP0Q@890845301g6bD0IBXl050Y?@1K9cH0I@H=06P2
1@1G62D041P]04i[KP1<JFT0635=004??`012CP00PXc00LJ<P0WAdd08SLg01;B3`@00?l0203oool7
003o00030=1@N03oP000oh0001h0oh0000@0^3Rd0:0Pl02P8?00^3Rd1@3oP0000`2h>;@0X23`0:0P
l0060:0Pl0030;Ph]03XJ3`0oh0000L0oh000P3@D7P00`3XJ3`0oh000?n000020?n000030>QX?03o
P000X23`00<0X23`00@0j6Pl0?n0003oP000D91h1000o`0;0?ooo`002P3oool0F013Z@d0>aH901d1
0@0F0@805`4101X10@0J0@00:P8203`20P160@40E08305/11@1Q0@H0J04506P21P1W10X0HP<60844
2P2910X0Q0X=09=XI@3:c/l0bm;E08JDUP1hQX80cm?A0;JMY02<<cX0R10E04d92`0/6a/0MG]h0<K?
c03Fd=H0_i2J0:/f?@2n4aP0_@lA0;h?4@343Q80`A@F08Pk?02a[jh0em_L0=OLgP3Ff]`0e=7E0=C?
eP3Gf]h0d=_J0::]ZP15;c00GA<G02l82@0O71X0Df5J0:bi/`3?e]L0`<?808]_N@1c5b00Q@D<08P4
2`220`T0O`8807l22@1o0@P0P0<:07`12P1a0@H0J@4107010`1l0@@0PP8707X110210PD0S08709D3
2P2D0`X0TP8908<42@2@FEd040<600<10@0:0@00=P<303l30@0=dP490?ooo`03052@N03oP000oh00
01@0oh0000@0j6Pl0?n0003XJ3`0X23`1P3oP0000`3XJ3`0X23`0>QX?00:0?n00080d51h00<0j6Pl
0?n0003oP0001`3oP0020=1@N1/0oh0000<0D91h0?ooo`3oool01P3oool7003o000W05=U1P1I9AP0
LUiI06IKFP1HAdT0DBL_05Hc>P1E@d/0FDI?05I0B@1G@D/0GDY@06QCF01aGV00OFIY08UbLP2>N7L0
TH1m08j1O@2;PGX0OgQ]07UjKP1hNg<0Lg]f04IIF`13G5l0Af5Q06=eM01bOgd0JWYk06n0P`23T980
Q9>D08JFU@2?X:40UjVZ0:bY[`2^O8L0WB4[0080]0/B02D0/@TA0:<<602HDf80`<G:09ne_@1aTJ80
Q9n_09JV]P2HOY40R2Lh0987502A0P`0T08;08l2302;0``0OPD<084;4P1o0`/0K2i301hXF@0E<F80
:D5T04HkD01N1`l0HP@703`Q=@0:8Cd0C6Y`04mXJ`055S/00Pe0004;=`0E;D@0=5QG03mOE`0W?cX0
7k4I00@00?l0203oool7003o00030=1@N03oP000oh0001/0oh0000@0j6Pl0;Ph]03XJ3`0d51h0`2P
8?000`3@D7P0oh000?n000030?n000030=1@N02h>;@0X23`00<0X23`00<0^3Rd0>QX?03oP0001`3o
P0001@3XJ3`0X23`0:0Pl02P8?00^3Rd0080oh0000@0j6Pl0:0Pl03@D7P0oh000`2P8?001@3@D7P0
oh000?n0003oP000J:Pl00@00?l02`3oool000X0oooo05P0@ZX?02T60@0K0@405P4101`20P0F0@80
504002/20P0m0P80BP4205P10`1M0PD0H`4606`2201_00P0M`4:07d32P240`T0RP@;084;3P2PPGl0
cM;C0<SAd`1ePh40a<_;0:VNX`1U:c80CPlB028=3P1GH5`0Z;Jb0<kEe@3Ca</0ZeMT0:XJ8@2k4Q@0
^`lB0;`?4@2m3Q00`A0@0;L];@34[J`0f=cL0=SLgP3FdMH0/7N109`jA02L<T00X6=b0<g<dP3Efm`0
WjFX02hg>01^OGP0YKF]0<OBc`3=cm@0WX:;07`e?P1i4AP0N@<807h320241@T0PP<808032P1n0PP0
O@4707h2201k0PX0M08606h10`1d0P<0OP8407l11P1k0P@0O`4508T21`2C0`X0U@<:09<22@212@`0
L4A500T00@020@403`4103L20`0m0P004L812@3oool00`1@T7P0oh000?n0000F0?n000030=1@N03o
P000oh0000@0oh0000<0^3Rd0>QX?03oP0001P3oP0001`3XJ3`0oh000?n0003XJ3`0^3Rd0?n0003X
J3`00P3@D7P00`3oP000j6Pl0?n000030?n000030=1@N02h>;@0oh0001`0oh0000<0D91h0?ooo`3o
ool01P3oool7003o001>05QZ2`1N;1h0JU5<06aKF`1L<cL0E0`B05PT:@1D?dP0EdI?05I0B01JA4/0
GDU>06mLH01hI6P0P6IZ08I/K`2:L780SWai0926O@29PWT0OGU_07YiK`1lOWD0P8=m07=kN01ZMg<0
K7Yd075lM`2DXil0`<c=09BQY01oSHh0UjRX08nQX02<WJ00Sj:U09VXZP2YZZh0Y6ec0:TB6P2e31<0
/@TA0:d73`2S3QX0Yf9]0:2V[02H//80S9FZ09AGJ`2=4240U`@@09P2302E0`d0R`8;08894@1i:S<0
QdA<07X>601^7R`082AE045QS01UO8/0KUQP068?6@1Y0PP0HbH]01<L>`0cDfP0CVa^05=/K`0>83h0
325301D/AP0nH6<0@f=L041NE`0R>c/0:9lW1000o`080?ooo`L00?l000<0d51h0?n0003oP0006`3o
P000102h>;@0oh000;Ph]02h>;@40:0Pl0030=1@N03oP000oh0000<0oh0000D0d51h0:0Pl02P8?00
X23`0;Ph]0070?n000030>QX?03oP000j6Pl00<0X23`00/0j6Pl0?n0003oP000oh000=1@N02P8?00
j6Pl0?n0002h>;@0X23`0=1@N0040?n000030:R8?000o`000?l000800?l02`3oool000X0oooo04P0
>ih;02X30@0K0@405P4201L20@0C0@404P4102H20P120P<0C04205D10P1K0@@0IP4806`1201b0@X0
O@<;08@33@260`/0Q@<908<<4@2XRHX0b]3B0;>l_P2[];@0`/[=02lg>P0M7Q`0?dM408NCT036cLh0
e]CH0<RZ/`2R>dH0/18G0;L?4@2f3@l0]`dA0;/=4P2o3a80_Q0B0;mGF03@b//0f]_M0=WJgP2<L7P0
PAdW07hA5`1R3A40<PdE05]TK@39e=P0dM[K0;W4`@3?f=P0cM?F0;BY/026Ce`0MAHP07L>5@1d2Q40
L`T?07P32@1o10T0O`<807`11`1k0PL0OP4708022@1n0`/0M@4707@1101l0PD207h2100>08411022
0@@0Q`8609022P2C0PX0T088084H6`1H=ST01`4100<20P0H0@80?@8203d2000A`P490?ooo`0306RX
?03oP000oh000140oh0000<0d51h0?n0002P8?000P3XJ3`50?n000030=1@N02h>;@0j6Pl00L0oh00
0P3XJ3`20?n000030=1@N03oP000oh000080oh0000<0d51h0?n0003oP0000P3oP0000`3@D7P0^3Rd
0>QX?00N0?n00003052@N03oool0oooo00H0oooo1`00o`00CP0eU`@0FRDE0719A@1[=cT0GQ8D058D
5`1G=3H0Dd1705M3C01IA4d0FD=;061=E01aH6<0O6U[07]RIP25JV`0Q6Y/08MbL@2=PW/0RWmi07ig
L01fMVh0N7U_0861NP1lPG`0N85n07R4O@1cPG/0/LC40<OHg`2O/;P0O8n@08>EU@27VIX0PY:G07jB
U@2HZ:`0WJZ_0:RWZ`2G@dX0ZP`D0;493P2a2@l0/0TA0:4?6@2SGfX0S7V808L`A@2I21H0V`@>09P2
3@2D0`d0R0LA074S=P16=f40Cc]P07PG:01b5240=2UD02Y6MP2=V:/0M49E07895P1e0PP0LP<806H;
501B;3P0G6EX05=/J@1BJVX0>EEJ04IUIP0cCEH0=UIM04MVH011GU/05C4b039o<`@00?l0203oool7
003o00030830003oP000oh0001X0oh0000<0d51h0:0Pl03XJ3`00P3@D7P50:0Pl0030>QX?03oP000
oh0000<0oh0000<0d51h0:0Pl03XJ3`01@3oP0000`3XJ3`0X23`0:0Pl0020>QX?0<0X23`00<0j6Pl
0?n0003oP0003@3oP0000`3@D7P00?l0003o0002003o00/0oooo000:0?ooo`1H03JI1`0W0P006@00
01H10@0H0@405@4100`0000P0040@@8304d10P1F0@80FP4406D11`1Z0@H0L`8907/22P200@X0Q@8:
08H42P242a80YGn20<W?d@2j`l@0a<_=09^TY`1HIV80Q92:0:nh]03?e=D0c<780:elQ`2K<3`0/14G
0;L?3`2f3A00]@h@0;@;3P2h3Q40]Pd?0;P>4@2oGf<0dM3C0=OKgP3>dmH0<cLj01D72P0?1@H04ADF
055RH@2DYJD0_l_;0=CMgP3Cg=l0];k607I`NP1D;c/0@@`F02L11P0K00806`4202T2101C1P`0L0@;
07/22@1h0PH0MP4507X11`1m0@P0O08907P1201k0@L0O`8607d10`1o0PD0PP8608@11P280@L0S048
0902202<0PL0ScDf044/;@0300400P0101/10@120`<0?P4001710@T0oooo00<0P<000?n0003oP000
4@3oP0001@3@D7P0oh000?n0003oP000d51h00@0oh000P2P8?090?n00080d51h1`3oP000102P8?00
oh000?n0003oP0020:0Pl200oh0000<0D91h0?ooo`3oool01P3oool7003o000I03Z_201F8Pd0MCll
06/L7@1W;Bd0DS4e054l@`1C@D`0Ed==05I2C01JADl0GTYC06mMH`1kJ6h0NVEY08=WJP25HV<0QfmY
08aoN026OWL0O7Ia07EfKP1gNg80LW]c07R2O00207IoN`0c07N6PP24U9H0U:N]07>6R`1iRhd0OY2A
07fBU@1gSI00NhnD08^OXP2K[Jl0UJBX09^AU02A:C40ZPXB0;<;4`2]2100Y@dC0:dh@@2I7R/0V`HB
09d32`2K10d0T`HA07/L;01?=E/05RIS04@iK`1i5Bh0Na0N04P]EP0C8f00JUYh070N;P1j1140OP8:
07/22P1d0@P0K@4606<41`1G92D0FV9P04iWI@1=JF@0BFMR03]GG00]C540AfIN04ARG00_CDP0@Edo
00@00?l0203oool7003o0003052@N03oP000oh0001T0oh0000<0j6Pl0:0Pl03@D7P00P2h>;@00`2P
8?00^3Rd0:0Pl0030:0Pl0030;Ph]03oP000oh0000T0oh0000X0j6Pl0;Ph]02P8?00X23`0>QX?03o
P000^3Rd0:0Pl02h>;@0j6Pl403oP0000`3XJ3`00?l0003o0002003o00/0oooo000:0?ooo`0303>F
1P0Z1@<06@410080604101`05@8201010P0Q0@80@@8304h20P1H0@@0GP4506D11@1[0@L0L@4807X3
2P200PX0Q@<:08/62`292A00V5iT0<S:cP38d=80c=;D0:Zd/`2i`l00bm;B0<g>dP2kWJL0WDI@09hJ
8`2]4AL0/`dA0P2c3A00=@2b3@l0]0h@0;8=4@2g41<0^Q4E0;Q<DP3?b<`0eMcN0=;KfP27UiD0Jg]i
07^:R02M[J/0^lS70<gHf03Bg=d0dmcN0::^]00[?DH03AHJ018C5@0P92H0;cTi03E1?`0b?S/08RTY
01@82P0k1@T0JPD;07T1201i0PP0NP8907T21`1l0PT0O@8907l2201n0@@0O@4407d00`1n0@@0Q@47
08P1202;0PP0S@8708T4202<?Ch0;1dN00<10P060@40:P<504@310100@404/8100T0oooo00<0P<00
0?n0003oP0004@3oP0001@3@D7P0j6Pl0?n0003oP000j6Pl0080oh000P3@D7P00`3XJ3`0oh000?n0
00080?n000030>QX?03@D7P0oh0000D0oh0000H0j6Pl0?n0003oP000oh000=1@N03XJ3`Q0?n00003
052@N03oool0oooo00H0oooo1`00o`00CP0Sd`H0GBD@06PM601d;BX0IcLg04hK7P1F=c`0E4=<05E2
C@1F@dX0H4YC0659D@1]FEl0OVQ_07aUJ@1nBU80ORh`08eWH`28OGP0QWif07]hK`1hN700L7Q^075i
M01iPG`0MH1l07N3N`1oRhT0NhZ:082@S`1cQHH0LhF708BAU@22UIL0P9BD07V<S`1gS8l0U:VZ09b`
/02?XJ80XXnB09HR:`2c3AD0Z0lD0;Pk@P2S5200Z@PB0:43302I0`d0S1DR06LhFP0N;VH0AF>J06YE
N`225RX0QPlN05@cFP0N8F00GBY>07L96@220``0P@<<07d12`1m0PX0MP8806l11P1X0P@0E0H<044j
@`1:IfH0BfUU04UVH@17I640AFAP04MTGP18He`0?eU@049CA`@00?l0203oool7003o0003052@N03o
P000oh0001`0oh0000X0d51h0:0Pl02P8?00j6Pl0:0Pl02h>;@0X23`0;Ph]02P8?00^3Rd203oP000
0`3XJ3`0^3Rd0:0Pl0020:0Pl0050>QX?03oP000^3Rd0:0Pl02h>;@04`3oP004003o00/0oooo000:
0?ooo`1H032F100i5Pl0504101@10P0G0P803`4100h10@0R0@40@P4205010`1G00<0GP8306@1101]
0@H0LP8807P22@1o0`/0Q08:08T42@2:1P/0Qb`_0;6ZZ`36cLl0c=7E0<[8c@30[[L0ZX2909U9E02E
5R00X``A0:d;402`2a00/P`@0;4<4@2a3A40/`h?0;8>4@2c3A<0]PdD0;T>5@2_6B80a8NC0=W@f03G
g>40emgP0=CLg03DgM`0d]cO0<?@eP2EZ;00VZja0=3Lg@2DY:@0Ffe]07R9Q`2HZ:D0[;Zi0;O3``2k
al@0^lK40:Zi]@1iQhH0;Rla04@82`1g0`T0M`4607D1201f0@P0N`4608@21`250PH0P@8508<2101n
0@@0O@45084220270@P0R@8608X120220`T0TU1C01H62@010040304103X31@1=0P@0@`8001;20@T0
oooo00<0P<000?n0003oP0004P3oP0001`3@D7P0oh000>QX?03@D7P0^3Rd0=1@N03XJ3`03@3oP000
0`2h>;@0d51h0>QX?0040?n000040=1@N02h>;@0X23`0?n00080j6Pl0`3oP0000`3XJ3`0oh000?n0
000K0?n00003052@N03oool0oooo00H0oooo1`00o`00C`0Zf@X0G1h605dL5@1oCdX0GAhO05PN801E
>Sh0ET==05A0B`1HAD/0H4U@064kA`1/@dd0MU=I07]SJ024Eed0N2@T08]RG@24MW80QGag07McJ`1f
MFh0KWA]06idK`1eNgL0Nh>107N1O@1mRhT0MXJ607b;R`1^PX40KH6308VIW@2?XJ@0R9ZN07B8R`2@
Y:L0QIZM09^_/`2M[k<0/L320;6EW@2M9bl0_ca20:TI902]2A40/0TA0:073`259SH0>cIW02Q>QP27
Y/L0Tg:<08`D9P293QX0GCMO030`JP1X8d00P@D@08@12@260@P0PP<907@5301[2a80Ka<J06l32P1Y
0PD0D``C02HR=`16IfT0BVUU04]WI018IUl0B6MP04ITGP16HU/0@5iG02e7?P0Ad@d00`00o`080?oo
o`L00?l000<0D91h0?n0003oP000703oP0001@3XJ3`0X23`0:0Pl02P8?00d51h00@0X23`0P2h>;@6
0?n0000:0>QX?02P8?00X23`0:0Pl02h>;@0j6Pl0?n0002h>;@0X23`0=1@N1@0oh0000@0D91h003o
0000o`000?l02`3oool000X0oooo0480<i`403PK4@0B0@403`4101410P0<0@003`4102L20P130P<0
D@4505P0101L0@80IP4506`11P1c0PP0N0<:084430250P`0RP@<08X63@29>c`0[[2^0<SBdP2QUY`0
SCI209XL8`2O4AD0YP`B0:P8402Z2A00[`/?0;0;402a2a40/P/A0;D>4@2e3A00]`h@0;P>4P2i3A80
^a0C0;PA5P2Y62@0Z45A0;AbPP2oT9l0[H^G08R1R`1?GfX093Y304MNH@2`_l00emgO0<W@dP3Af]X0
d][J0=?Kg@3AfM/0dMSK0<oHfP3?emX0cmGH0<_DeP2f`Kl0H41007062`1d0PH207<11@0D07h31`29
0`P0R08508<21@250PP0PP4607h11P1o0@L0Q@0608X120290PP0N@X<07Q>D@0<0`@0104201810@11
0P@0B@420441000B`P490?ooo`03052@N03oP000oh0001@0oh0000<0d51h0>QX?03oP000403oP002
0=1@N0040:0Pl02h>;@0d51h0=1@N080j6Pl00<0d51h0?n0003oP0006`3oP0000`3XJ3`0oh000?n0
00040?n00003052@N03oool0oooo00H0oooo2000o`00CP1R8@L0HBPO07</:P1V<2`0FChn058oA01A
?TL0Dd1905U1C@1R?dT0HATT06HF7P1]<SL0Ic]1081NHP20EU@0QfYW08AeK`27OGL0NW9/07YhL@1a
MW00KgE`07AkMP1dNWL0MX5m07F2P01cPH40NXV807>4P`1/Oh00PiJH08RKW`29Vj00NXnD07R<TP2H
Zk00V:Z`0<GIg`2[_L@0]lG:0;>1S@2]7BT0/`XD0;8:3`2X3Q40[3@h06I1H01=N:L0[l?I091PN@2@
4R80TA4M05hhG@0Z<Vl0LRI508H43`240@T0P`8:07`53P1^7BL0CRm602`/D`19>eT0H`PD06@83@1:
:CH04B4i045TI@18If40C6MU04YXH@18JF80AfIQ04ASG010Ge<0;4]101K950<00?l0203oool8003o
01l0oh0000<0^3Rd0:0Pl02P8?00102P8?00103@D7P0X23`0;Ph]02h>;@50?n000<0X23`00H0^3Rd
0?n0003oP000^3Rd0:0Pl02h>;@40?n000040>QX?03@D7P0X23`0:0Pl0d0oh0000@0D91h003o0000
o`000?l02`3oool000X0oooo03D0=il702D90@0>00402`0100l20@0=0@403P0002L10@110@80CP82
05P10P1L0@<0H`4606/11@1`0@L0MP8:07h32`200@P0R0H<08<62P2:DU<0^/710<O@dP2:Oh40R1DI
0:H:3P2W2`d0Z0T=0:d94@2[1`h0/PdC0;0:4@2a3140/0X@0;0:3`2d3A00^@hA0;`=4P2m41<0^a0B
0;<?4`2_3A@0Z`hG0:@B7@2?7BX0Aa0L014:4`0H9bX0R9NG0<??c@3Cfmd0em_N0=OLgP020=GLg@80
dm_M0140dm[M0=3Jg03>emX0c]KI0<[CeP39dmD0TXJ606D83@1e0`P0LP4607<01`230`T0R@8708D2
1@200@H0NP@708<3200207h11@0<08L21P290@L0Q`8707LC5P1aEUH01`<400@10@0J0P<0AP<304X2
0P120P404/812@3oool00`1@T7P0oh000?n0000B0?n000030=1@N03oP000oh0001P0oh0000<0d51h
0?n0003oP0007@3oP0000`3@D7P0oh000?n000040?n00003052@N03oool0oooo00H0oooo2000o`00
CP1a=0h0FadB06l`:01VBD<0DTA104m0A01??TH0F3e705dX=01V:340IATP05lR9`1ZBD/0J55B07QV
IP20KFd0QW5`08MgL@29P7/0PW]c07MdJP1cN740MG]g07IlN01gO7P0MWml071kN@1]O7X0KGmm07>5
Q@1`P8<0PY:E08FFV`21U9P0TZNZ08NNY02Q]kl0V:bc09ja^02lcM<0^;Bo0:@jC@2i3AT0]PXC0:/C
5`2f>Sh0X1HO07XaBP1bPZ80RTaT094=7`2>5R<0ESMP01DaL`1S>F40R0HF08/22`210PX0L1@N04la
C00J9UL07S=Q04I0H01Q6bl0K`<=06D83P1@72D0?Si504ITG`18IF00BFMS04QWH@1;JV@0BVQR04QV
G@10Ge@09T@m02:Y8@<00?l0203oool8003o00030=1@N03oP000oh0001/0oh0000D0j6Pl0:0Pl02P
8?00X23`0;Ph]0030:0Pl080^3Rd00<0X23`0>QX?03oP000103oP0000`3@D7P0X23`0;Ph]0020?n0
00030;Ph]02P8?00^3Rd00@0oh0000D0^3Rd0:0Pl02P8?00^3Rd0>QX?00=0?n0000408300000o`00
0?l0003o00/0oooo000:0?ooo`1H02nF100N0P40400001T51@0D0P803P4100l10@0V0@80@@8204/1
0P1A0@40FP4406<11@1/0PH0L@4707P22`1m0`X0P@@<08<42P202Ph0T6MV0<?<c@38dm<0U9RI06D@
502V3A80Y`/>0:T:3P2/2A00[PP@0;4:4@2`2Q00/@/>0;@=4@2f3a@0^0lD0;`=4`2m3A@0_@hC0;/A
5P2`3Q<0[0lC0:8D5`1l3a@0=PT<03Lg>P1`OWd0[[^j0<oHf03GgMh0eM_N0=GJg@3Efmd0eMgO0=GK
gP3Ffmh0eMgO0=?Lg@3Cfmd0dM_L0<oIfP3<e=P0bM;E0:FPX`1Q3180M0<807@2201h0PH0R0<908T2
1`260@D0Q@8706`2101f0`P0P04608411@260PH0QP4708831`21:2T0BB`]00<10P040@40708304X3
1@150@80?P4001710@T0oooo00<0P<000?n0003oP000E03oP0000`1@T7P0oooo0?ooo`060?ooo`P0
0?l004h0E6T605LS4@1X>c80HT4k05I4@`1A?400Cbhf05DI8`1L51T0J3Dj06DoA01SATl0IDiF05i<
E01jJF`0OfY]08UaM02<NWP0Rh5n08J1NP1oOGD0MGQa07IkMP1eNWL0MWej075lN`1^NgX0LWmo07:2
OP1XNg`0Jgn108:FV02<X:@0R9^P09:UZ`29WJ<0R9^R0;k@eP2W^Kh0];c40:5MJ`2^4Qh0^PdE0:dF
702j?dH0Z1@O0:P84@2M<Cl0PR]009<=6P2982l0ACQY02E>RP25U;@0N1@X09033`2810d0Kb8`02hY
DP0D:E`0D55`070gB01]2QP0M@8:0741201]0PH0I08505@M7@1;GeP0AFEN04]YH@19J680CFUU04]W
I019IV80A65H02e:@`0/MR`3003o00P0oooo2000o`000`3@D7P0oh000?n0000L0?n000030;Ph]02P
8?00X23`00<0X23`00@0d51h0:0Pl02P8?00d51h1P3oP0020=1@N0030?n0003XJ3`0X23`0080X23`
0`3oP0001@3XJ3`0X23`0:0Pl02P8?00j6Pl00l0oh0000@0d51h003o0000o`000?l02`3oool000X0
oooo05P0;Y@102D50@0[3`h0DcXj00h10@090@403@4002T20@130P80C08305810P1K0@@0I@4506`2
201/0@H0M@@908062`231@`0Q@D<07/:402KOgd0b];D0<SCd`2b_kh0?QXM09/@5@2W20d0Y`P>0:`:
3`2`2Pl0/0X>0;8;402e2Ph0^0d@0;H<4@2g3A80_@lD0;h>503041H0]PdC09l?501/3a<0<`P:03@^
;P26Ti40a]7B0=KNh03FgMl0e=gN0=CMg`3Efmh0em_N0=?IgP3Cfmh0e]cP0=CIgP3Cem`0c=3E0<_C
f@3@fMh0dM[L0<oHfP3<dmH0UXN;06L:401e0PL0M04607`11P270PL0R@8808X22@2<10T0Q@@808@4
202<0`X0R@4808T11P270PP0O0H908Q1@@13:2/0104100L10P0Q0@80C`@404L20P0k0@403l412@3o
ool00`20`000oh000?n0000Z0?n000030>QX?03oP000oh0000L0oh0000D0j6Pl0=1@N03@D7P0d51h
0>QX?0030?n000030=1@N03oP000oh0001D0oh0000<0D91h0?ooo`3oool01P3oool8003o001>05Q]
2@1K:1X0F1<?06Ll=P1C@T40DSLj05DT;01I92T0GcXo06E=E@1WDEL0JU=L065<E@1D@T`0NVU^085[
KP2:MGL0R7Yk08^4PP25Pgl0RXZ507UkM01cMg80JgMe06EeM@1[NGH0LGah06agM`1]P7d0IGYi06Yn
P`21UYP0OiBE08jSYP2?Yj/0//G<08^MYP2DYjh0/L3509V1RP2J62H0]PlF0:@M8@2cBU80Y`lM0;<:
4`2Y1a00Z2/d08/A7P1l;D@0<CI^03UPV@2]c><0UhRI08P?7P2@0`d0NbDe02XUD@0b;U/0IC5:07<>
7@1m0`h0N@4:07D2201`0@L0J`4506@10P1C3aD0;ca404=TH@18If<0B6MT04UWH`19IV40B6IQ04AS
F`0cCTP0;6`a0`00o`080?ooo`P00?l000<0d51h0?n0003oP0006`3oP0020;Ph]0040=1@N02h>;@0
X23`0;Ph]080X23`0P2h>;@30?n000030>QX?03oP000oh0000<0oh0000<0j6Pl0:0Pl02P8?000P2P
8?020?n000040>QX?02P8?00X23`0=1@N140oh0000@0d51h003o0000o`000?l02`3oool000X0oooo
04D0<IL303`F401O?cl0HDmA00X10@090@403P4002T20@140P<0C@4405H21@1L0PH0I@4606`22@1W
0PL0L0@908073@241@/0QPD:07T=4`2QRH`0c=;D0<O@d`37d]<0Ce1A06L>4P2R3140[0X@0:d93`2_
2Pd0/PX=0;D;3P2h2`l0^`dA0;T<402j3A00_0lA0<0?5@2h41H0TA0E03`92`15AT<0SIZE0<;<bP3H
g^00emkP0=KMg`3EgMl0e]kP0=GMg`3FgMl0e=[M0<o>e@30[KX0[8VG09MTM@27@U@0MS];04HhA@29
Uih0cm[L0=3If`2k^[l0KSPo07L52`1h0PL0OP<:08D32@2:0`P00P290PP04@2:0`T0SP@709042@2A
0@X0T`<:09H52`2C20h0O1DG09MUJ00C10D00@4100T10P0Z0P<0C`8204D10@0g00003/0100T0oooo
00<0J:Pl0?n0003oP0004@3oP0001@3@D7P0oh000?n0003oP000j6Pl01/0oh0000<0^3Rd0:0Pl02P
8?00103@D7P01@2h>;@0oh000?n0003@D7P0j6Pl00l0oh0000<0j6Pl0?n0003oP0001@3oP0000`1@
T7P0oooo0?ooo`060?ooo`P00?l004h0@i8605TN3P1I4@/0Id4h05Ho>`1=:bd0Cb0W05Xl@`1IAT`0
GdeD06ICF01/EF00Je=N06IDG@1hJFh0Pfe_08I`L`24MGD0Q7ai08R4P@2>SXX0PhIo079fLP18Fel0
=U5F061cL`1aNWL0K7]j06IjNP1WO840AVAc08>IW02DYjT0W[2g08JHXP2K[;@0_<[B0:Jh_`2i_/L0
SS]:0:L>602R7b/0HdM]07i6HP2W2QL0[PL?0:P84@2L=D00GSmR01/dLP1RR[H0^MGW0<3Eh02OVJH0
OaHU08P64020>Td0IRQ307H;7@210`l0P`8<07`22P1b0PD0J`@606`:3@1/0PH0IP84054G800L;Sh0
@VAP04MVH@17If00BVMQ04UXG`1:IUl0AVEK03mNC`0nE443003o00P0oooo2000o`000`1hF;@0oh00
0?n0000J0?n000040=1@N02P8?00^3Rd0=1@N0D0X23`00H0^3Rd0=1@N03oP000j6Pl0;Ph]03@D7P3
0?n000030>QX?02h>;@0X23`00@0X23`0P3oP0000`3XJ3`0d51h0?n0000C0?n000<00?l02`3oool0
00X0oooo05P0:Hl104h/9@1UAdT08`lC00T10@080@40404102P10@150P80C@4205@0101J0@L0IP47
06l1201d0P/0M`<<08<73`251P/0Q@L;07H;4@2SRXh0b];E0<OAd`38e=D0QI:?02l72@2B51X0ZP/A
0:l:4P2c3A<0]0X?0;H93P2i30l0^P/@0;X;3`2l3Q40_@dB0;8B6@234aX0;`@5059KFP2nb/T0fMoO
0=_Nh@3Hg^40f=kP0=KKgP3Fg=l0eMcN0=CLgP3Gf=d0aK:k09QMK0289SH0SaPT08hA701f41X0;`L<
01dS9P2DY:<0cm_K0<C8cP1jFF80LA8I07/3201l0PP0PP<808H21`2;0`T0R08808P1202>10X0SPD:
09@63@2E0`/0U@<:09l73`2J3Q<0Y4e?07E9C@0@0@<01`8100T0000]0P80F@@404P20P0j0@407h@2
2@3oool00`20`000oh000?n0000A0?n000030=1@N03oP000oh0001`0oh000P2P8?080?n000030=1@
N03oP000oh0001L0oh0000<0P<000?ooo`3oool01P3oool8003o001?04BU2@1D5@@0HRdS0696>`1D
?SH0Cc/j054o@P1CA4`0ETU>05i=D`1YDed0KeEP071HHP1XF5h0IUYO07i[K`1jH6D0Q7=d08AlN02;
Qh@0Rh^708f>RP1mP7/0EFAS04eUI@1ZN7L0KgYj06QfN01YNgl0?Ua^06F5TP1kTI@0R9fR08FIWP2o
dMP0TjB^0:Rj``2]_lH0Z9BN09/H9@2L6bD0FciY02/kO`25@el0XPXF0:H74@2K2180ISAD02M>Q02E
]mH0_=KT0;cDh02odn00^<7=0853D@271100QP@>08H23@270@X0Q04:0842301b0`/0H1HO04X[=`1V
;CH0J@<805h51`0n7S008C]=04ETHP17Heh0CFQT04aVHP18Iel0AFAN04=RF`13GUH0@EM700cL2002
003o00P0oooo2000o`000`1@T7P0oh000?n0000I0?n000030>QX?02P8?00X23`00P0X23`0P3oP000
0`2h>;@0X23`0=1@N0030?n000030;Ph]02P8?00X23`00@0X23`00<0j6Pl0?n0003oP0005@3oP000
0`1@T7P00?l0003o000;0?ooo`002P3oool0F00iS0@0Dc0X02hF5`0;0@801@8200D10P0<0@00:082
04D20P1?0@80D`4305H1101T0@H0K@8707<22P1f0`/0O`H?07d32P2010/0M0L?09n4R03;d]D0b=;D
0<SCe@2haL<0;BXZ04/;3@2G41@0[PXA0;0:3`2b2@`0]`X>0;T<3P2l3A80^``@0;/>4P2X4QP0EP/?
02dL701ZLW40`/g=0=SOhP3Ig^40f]kQ0=WNh@3Jgn80emkP0=SNh@3HgN00bl;709IQJ`2E<3`0V1<N
09P=4`2@3aD0J`dC02X<3P12CDT0SijL0<OAdP34dMD0Hf]c048H8@1c2Q40N`8708@52@270`P0S0D9
08/4202<0`X0S@<;08h42`230@D0RP8809D32P2H10/0WPPA09HL803CUIP0KdM;01d31P0A0P807083
04810P1M0P<0B04203T1000OP`490?ooo`030:R8?03oP000oh000140oh0000<0d51h0?n0003oP000
6P3oP0000`2h>;@0d51h0>QX?0080?n000030>QX?03@D7P0oh0000l0oh0000<0X23`0?n0003oP000
1P3oP0000`20`000oooo0?ooo`060?ooo`P00?l004L0;<L605HK1`1K6a40GB/T05Y2?P1=@400D456
05M6CP1LBE<0IT]B0710B@1_?D@0LUaR06aMH`1RE5X0NfI[06iDE`1kJV`0QGik08=oN`21P7/0RXZ8
07QmO01cNWH0SiRE092IV@1bOh00JGYj05U`OP0RB6L0JXN<082EU`2K/;<0TjF]09>W[`2K[KH0PiJQ
0;_=e02VOHP0XaHR09e>G`1[BFd0Q2M20:DZ>02R2QH0W`PC08d?6`10=600NJ?20;oEgP31eMd0`=;M
0;oBg@2a_<P0McE508P440250@X0QP490882201k1@d0KQ/V04/]A00X:4X0AbU306@8501R2Ph0D2Pg
01<H>@0eF6<0B6IS04UVHP0204YXH`0604UXH@17IEd0AV=M04APF00lF4H05/PA0P00o`080?ooo`P0
0?l000<0D91h0?n0003oP0005P3oP000203XJ3`0oh000?n0002h>;@0X23`0=1@N02P8?00^3Rd0P2P
8?00202h>;@0X23`0;Ph]03@D7P0oh000=1@N02P8?00d51h103oP0070:0Pl0030=1@N03oP000oh00
00@0oh0000<0d51h0:0Pl02h>;@00`3oP0000`2h>;@0d51h0?n000080?n00003052@N000o`000?l0
00/0oooo000:0?ooo`0Z055n300d4``060<201L:2P040@40208100/1000U0@80AP8304d10@1B0080
F@4506@1201]0PT0L@4:07L32`1l10`0O@@:08032`1h1`d0T6U]0<cAe039d]@0b]?F0<_De@2;UI<0
4a4@058:3P2V3140/@X>0;<:3@2f2`h0^0/>0;X=4@2e3a<0TA8E03`@4@1_MWD0^LG50=;Kg03Ign80
f=kQ0P3Ign80;03Fg^00d][M0<7:cP3Cfmd0e]?H09]EG`2K5Qh0X@dA09@?501M2`l0:PL902LY9P1^
PG/0^/O40<oIfP3;eMT0UjJ^059SI@0S92H0A@P=07X32P250`P0R`@908h5202;0`P0RP8808h21`2>
0`T0Q04608d31`2H10T0V@H;09/<4@2]EeT0VG9g058_=00i3A00808302d20`1M10H0J@8404/10P0j
00007h<12@3oool00`3@D7P0oh000?n0000A0?n000030=1@N03XJ3`0oh0001H0oh0000<0j6Pl0=1@
N03oP0000P3XJ3`90?n000030>QX?02P8?00j6Pl00l0oh0000<0j6Pl0?n0003oP0001`3oP0000`20
`000oooo0?ooo`060?ooo`P00?l004l0:=L:05XS2P1E6a00IS`c05U3?@1D@dD0EdI<05e5C01T>D<0
JRdf07X_=@20?TD0MUmW075RI`1^HFH0Lf1U079IGP1kJV/0Ng5_07QaKP1gMVh0QXN108:8QP2IYJ80
/;_109f[/@2GY:P0J7Yn02I5I@1<KXL0Mhb?09N/[P1fRHl0//C909FX/@2L/k/0U:^d09R]/`2`Uj00
VQ`W0:8L9`2D6bL0X3i70:<_?02I21<0UPLA084Z?P0L<FH0Z<_O0<3EgP2me=d0_mCM0;kBfP2d`lh0
LSe=08D54`240P`0P0@=078G8`1B;d`07bQD02P]EP1I8SP0J`LB064?5P0l9ch01aHj01lmE@19JFP0
BfUT04MWHP17If40BVUT04UXHP14I5h0AVAM04=QEP0oFTX08jPM00800?l0203oool8003o0003052@
N03oP000oh0001D0oh000P2h>;@0103@D7P0j6Pl0:0Pl02P8?020;Ph]0030:0Pl03@D7P0X23`00<0
X23`00D0^3Rd0?n0003oP000oh000>QX?0030?n000030=1@N02P8?00X23`00D0X23`00<0d51h0?n0
003oP0000P3oP000103@D7P0X23`0:0Pl03XJ3`20?n000030=1@N02P8?00^3Rd00X0oh0000<0P<00
003o0000o`002`3oool000X0oooo03/0FW<=03PE3P0H0@404`8200L000050@002P4002T20`140040
D08205@00@1I0PD0H@8806X11P1_0PX0L@8;07H32P1n10X0PP@<07l63P2;EET0a/W<0<cAeP3;e=L0
cMCG0<;;bP1SKV/06PH808`?502^2@h0[PP<0;893@2g30l0[A0D08<>5P0^1`L0MH1k0=;Kg03Ih><0
e]kP0=SOh@3Ggn80emkQ0=KOhP38e]X0XK6e0<G?d@3FgN00]i^S09<J902P2a40TA8E04L82`0C4A80
CUmL08JIU036e=40c]SI0<cFf0020<cGfP0K0<;?cP2;UiD0AR@W07`73P270PP0Q`4608P21P2:0`T0
Q`8508`31P2?10P0T0@:09<42P2D1@X0U@H<098>4P2lOh40RfQ^06I;C`0I0PH0:0/<03D31@1M10@0
K08305820`0o0@407X8100T0oooo00<0d51h0?n0003oP0004@3oP0020=1@N0030:0Pl03oP000oh00
01@0oh0000@0X23`0?n0003oP000X23`703oP0000`3@D7P0oh000?n000070?n000030830003oool0
oooo00H0oooo2000o`00C`0GkPH0GB<505dd901PB3`0G4M005a5A`1Q?dH0HbH_06/N9P1[:c80N457
07Q@E@1cHFT0L65X06mSI`1fJF`0OFU]07i[K01gK6X0M6iY07]kM@26RXD0QHf<0;g9c@1jPhT0KW]j
09NUZ`17G7<03c=N06Z7T`1eQh`0TjR[09nb^02BYjh0SZ>[0:Jj`P36fN40W;C108nX]P2/UY`0MEMd
04I;N`1QF7h0Q1@U08d73`2831L0CS9L04=[V@2men@0`mKO0;oEgP2ldm`0_]?L0;c?f@1/BEP0L`PC
06hE8P1H<Dd08R]J02<oK`1_SZX0He5S064;5@1M9C<0:BI800`WCP0`EFP0BFU/04eYI@1;J6@0BVYT
04]ZIP19If<0AFMQ04AVH011He/0@f9H041MC`0_QRH00P00o`080?ooo`P00?l000<0:<Pl0>QX?03o
P000503oP0020;Ph]0060?n0002P8?00X23`0:0Pl02h>;@0X23`0P2h>;@20:0Pl0040;Ph]03@D7P0
X23`0:0Pl080^3Rd0P2P8?030?n000P0X23`00@0d51h0?n0003oP000^3Rd0`2P8?00103@D7P0oh00
0>QX?02h>;@20:0Pl0030>QX?03oP000oh0000P0oh0000<0d51h003o0000o`002`3oool000X0oooo
05P0DVd=04h[900H0@004P4100X20@060@002@0002L20P1;0`@0E08205H10@1I0@@0H@4406P11P1U
0PH0F0<805h4201j10`0P@@<08453@27>3h0^;Fj0<_CeP3;e=L0cM?G0<kFeP2f_kl0?T9304l;3P2V
3a<0[`X?0;8<3`2[3a@0IP`A02lE6@1_MWL0bmGE0=[PhP3Hgn40emkP0=OOh@3Ign80e=OL0:Nb^`1O
MWh0]<C60=KNh03?a//0Tci:09HC6P1d3A40>@T:038g=025UI80//2k0<WEd`3>fMT0cMKI0<gGf@3=
e]P0cMKI0<_Ee`39dM<0RgMk07T;4`270`T0Q@8608H21`2;0`T0R`@808`51`2>0`P0T`@:0902202>
0PP0T0D908/O8@2YP880X86602hK800F1@/090D903P10`1Q10@0J`<305410@0o0@408H<22@3oool0
0`3@D7P0oh000?n0000B0?n000030=1@N03oP000oh0000/0oh0000<0d51h0?n0003oP000103oP000
1`3@D7P0^3Rd0;Ph]03@D7P0oh000;Ph]03XJ3`03P3oP0000`3XJ3`0oh000?n0000;0?n00080d51h
203oP0000`20`000oooo0?ooo`060?ooo`T00?l004h0JCH>05m2;01OBCT0I4E1064]<P1S7BD0KAdS
06PW:P1`Be40LeYR079RJ01gIfh0LV5W07ASJ01jIf`0Q5mU07]>D@1kJVH0NgMa08B3O`2<Sh/0OHN7
0:^j_P2CY:D0UJ>T06j1S@0E;eh0;e=f06EnP`2_`/P0Kh>;09R[/@2AY:/0]<[A08JJXP2M/[X0/LOA
09Ngc02S`=T06TB404UcZ`2@DfX0U@dJ098>5`1g;TH06C5W09_0e`31e^00`]KO0<3Eg@2ne=`0_M;M
0<3BgP1dK7X0E3Q901dUDP0>;F00=Uen07^M[01fTid0NXB;04m<GP0=8Td08T5S04U/M01<Kfd0CVaZ
04]YI@1?JVL0C6YU04m/J@1<JfD0AVMQ04MVG`15I5h0@V5I04=NE@0ePSD2003o00P0oooo2@00o`00
0`3@D7P0oh000?n0000B0?n000040>QX?02h>;@0d51h0;Ph]0<0X23`00H0d51h0:0Pl02P8?00^3Rd
0:0Pl02h>;@20:0Pl0030;Ph]02P8?00X23`0080X23`00@0^3Rd0?n0003oP000d51h202P8?000`3@
D7P0j6Pl0:0Pl0040:0Pl080^3Rd0P2P8?000`3XJ3`0oh000?n0000:0?n000030=1@N000o`000?l0
00/0oooo000:0?ooo`1H05Ud3`117aP06`0101<20P090@40208100L10@0U0P80BP8405810P1D0@<0
G08406@11@1X0@T0H04505L31`160PD0L0@;07l42P2210P0Qa@I0:V>TP3;dmH0bm?E0<cCeP3=e=L0
c]GH0:Ve/`0T7A`0M`lD0:L;4@2N3aD0D@T>055AD02b_[`0d]WK0=WOh@3Hg^00fMkP0=SOh@3Hf=d0
]9>P06m<F`0g>Cl0X[6a0=OLg`3;_/H0V4mJ088F7P0j30`0<2l]06emN@2c`/40cmWJ0=3IfP3Af=X0
c]OI0<gHf@3;eMH0cMKH0<[Ce`3<eML0bM;E0;Rb]@1f61l0R`D:08L31`260PH0RP<808T41P2:0PD0
T`@:09D42P2?0@T0SP8808l83@2dL6l0TWYm0:JFV@0K2Pl060<602`21P1@10P0J`@606X30`1@0@80
@@4002:40PT0oooo00<0d51h0?n0003oP0004P3oP0000`2h>;@0oh000?n0000@0?n000080>QX?02P
8?00d51h0?n0003XJ3`0oh000=1@N03XJ3`<0?n000040>QX?03oP000oh000>QX?0d0oh0000<0j6Pl
0:0Pl03oP0001`3oP0000`20`000oooo0?ooo`060?ooo`T00?l004h0K54@05a2;01QACL0I2PU06LJ
7P1O6Ql0JCDh06M;C`1WEUh0KEeW07=SJ`1jIVh0NF1Y07]AF`1l?dD0ObX^080f=P1oJVL0P7Ug08>5
P02<TH/0SiFB08bCUP23Ri40KWZ004=GLP037UX0G7^B07:9SP1_QXT0VZja09R^]02CYZl0TjZa0;K;
dP2H/;X0[LGA06Z:[@1IRKH0SJW509^8X02K6b/0V@dE07PS=P0/=FL0JXnd0<3Hh032e]`0`mKN0<CF
gP32e=`0_m?M0;gAg02^_lP0VZjm02m@N`0hHX@0Fh6F07VL[01dTYd0PYbS05egPP1SP8h0MI:G05=`
L01=K6X0D6i^04aZJ@1;J6D0CVeX04m]K@1>K6T0BFMT04ITG`15HUh0AV9J04EPE@17F4T2003o00P0
oooo2@00o`000`2h>;@0oh000?n0000C0?n000030;Ph]03@D7P0d51h00<0X23`0`3@D7P30:0Pl003
0;Ph]02P8?00X23`00@0X23`0P3oP0001@3XJ3`0X23`0:0Pl02h>;@0d51h0100X23`3P3oP002003o
00/0oooo000:0?ooo`12059^3@0L0P40604201820P090@402@8100T1000V0@<0B08405D21P1I0@@0
G08406411@1Y0@P0L04;07422P1^0PT0N0<:07h2202710P0U@X@0993B`2eZk40bm;F0<_Df03<eML0
c=?G0<_De01dOG/0Da0C08DE6P1530h0HVQV0<[De03Gg]l0emcO0=SNh@3Ig^40fM_Q0<Ve`@2IDF80
FQ/T04Hn?`2R[Z`0emgN0<>X/@26=T80KAHO03@M7@1iQh<0//6o0<_Ge`3Af]`0d=WK0=;Ig03@e]T0
c]KI0<kGf@3<e]P0bmGH0<[DeP3:dmL0a]3C0;J_]@1h5b40RP@:0P2:10T0502>1P/0T0H;09<52`2F
10/0T@8909<32`2B0`/0Qa`L0<ZY[02@O800I5EI02lJ7`0Q10X0=P<705@21@1b0PD0KP8304h10P10
00408H<12@3oool00`3@D7P0oh000?n0000B0?n000030>QX?02P8?00j6Pl00h0oh0000<0d51h0;Ph
]03@D7P0103oP0000`3@D7P0oh000?n0000=0?n000030=1@N03oP000d51h00`0oh0000<0^3Rd0=1@
N03oP000203oP0000`20`000oooo0?ooo`060?ooo`T00?l001D0FWT?05m1:@1N:Al0I1D>068Y901W
AdT0I5=J05iBF@1TEUl0KEmZ07AMI`1hBUD0OCY607TR:`1b7R00QT4o074l>`1lJFH0N7Ea08:4OP2=
TX`00P2?Ui00>@1iOg/0JWMm01H]G`0H>g00G7R109f_/01iS980Vjnf08jQZ033e=`0SJ:/0:2e_P2M
]/D0OIn`0;_Ci01BOJX0S9Rg09hgB02V4Ad0ORHj030hJ@1?N:00_=WT0<7Hg`33fMh0`]ON0<;DgP31
e=d0^m?K0;gCf`2nd]/0^M3I08VU^@0cEgL0LiNY05MjQ`2E/[d0RJJ^086KY01jTYT0HGQn05adM`1D
LVl0D6m^051^JP1;JVH0C6aZ04U[I`1=K6T0BFMU04MTH@17IV40B6AM04QSF019Fdh02>L6003o0008
0?ooo`T00?l000<0X23`0?n0003oP000203oP0000`3XJ3`0oh000?n0000:0?n000030=1@N02P8?00
X23`0080d51h00@0^3Rd0:0Pl02P8?00d51h1`2P8?000`3XJ3`0oh000>QX?0030:0Pl0030;Ph]03@
D7P0^3Rd00h0X23`00<0j6Pl0?n0003oP000303oP0000`0Xb3`00?l00?ooo`0:0?ooo`002P3oool0
F01;I@h05`4001@00@0F10@01`0000H100080@00:@8304P10`1D0@@0G0050642201P0@@0I`460702
2`1f0P`0NP8<07d12P1n0@P0R0<909d93P2<5Ah0[H:90<O9c038d]@0bmCF0<cBe@3?eML0^;fl05HW
:@0^1@H0B4Y70<C>c03Eg=h0emcP0=GLgP3Hg^00f]CM0;F=W02E>4L0MAPQ04<j=P2O[j`0dmcM0=?8
d02BA540IaLO02TB502<VIP0b]CF0=?LgP3Afm/0cm_K0<oJf`3@fM/0d=SL0<kFfP3>e]/0c=OL0<WE
eP39dmD0bM?G0<K?e02QS9D0O@hJ08/42P2?1@/0RP8908/32P2=0`T0U0H<09432P2<0`P0S@<808/6
2P2KC4d0VXF;0;2PYP1NDUP0;ALJ02L5300l0`P0H@D907/41@1^0P80C`4304@10@0QPP490?ooo`03
0=1@N03oP000oh0001<0oh0000<0X23`0=1@N03oP0000`3oP0000`3@D7P0oh000?n000060?n00003
0=1@N02P8?00oh0000@0oh000P3@D7P20?n000030=1@N03oP000oh0000/0oh0000<0X23`0=1@N03o
P0002`3oP0000`3@D7P0X23`0?n000080?n000030830003oool0oooo00H0oooo2@00o`00<01<SPX0
GcXP05/H3@1W9A`0JD]505i=CP1PEEX0Ge=L06QEH01_AU40LS8n0852A`1k<cT0ND1507aKG021K6d0
MV=T085eL`1nOGP0R8^408jAS02AV980SiRB07j4P`1AH7<00A]J03=DMP2<XJH0MXR>08^MXP2BYjd0
XkW208^NYP2V^Kl0Y;[10;W=eP2C[L40M9^m07><[`2MHG`0YQ`Z08m1G@0X=W80EGjY0;gGi`36fN80
`mSQ0<CHh080`]KP01h0`=GN0;_Eg@2he=/0^=?M0;KBg01nVZ`0Dg>F04EZS01NPY@0KXbM06>0S025
XJP0OYVM07R@U@1eS940G7Mf05AaK`1BL6`0BfUV04QYI@18J6<0C6YY04YYI`19IV40AfEP04MVH017
HU`0B5mC01O84P00o`080?ooo`T00?l000<0N5Rd0?n0003oP0005@3oP000102h>;@0X23`0:0Pl02P
8?040;Ph]0030:0Pl02h>;@0^3Rd00@0X23`00<0^3Rd0?n0002h>;@01@2P8?000`2h>;@0X23`0:0P
l00<0:0Pl0030;Ph]02P8?00d51h00d0oh0000<0D91h003o003oool02P3oool000X0oooo05P0?e`;
01h10@0^30d0ARDW00d20@070@002P0002`2101:0P<0DP4405/11`1R0PP0H`4706P11`1`0`X0M`<:
07L22@1j0PT0O`8808d32P2O20l0V@/C098f?P2kYZ/0bmCG0<WEe@3:eMH0cMGG0;2l_`0W;bl0B5=A
0:nm^P3Bf]X0eM_N0=CLgP3GgN00dlC=0:aRL02L9340QQPO040U9@2M[:L0dMgK0=SFfP2RJG@0GQXQ
03`];`29Ti@0b]CE0=CLgP3Cfmd0dM_L0=3Kg03?fM/0dMSM0<_>eP2aYK40UX6B075dPP2P[[80c=GG
0<_Ef@2o_/P0P4MA08H840290`X0RP4908`22P2;0`X0R`<808l42@2?0`P0S0<708P5201l3`l0^8^<
085`M`2/XjT0:R@/06]OH`0S1PX0?`@806P420210`D0K`8305010@160@408X812@3oool00`3@D7P0
oh000?n0000D0?n000030;Ph]03oP000oh000080oh0000<0d51h0?n0003oP0001@3oP0000`2h>;@0
d51h0?n000040?n000060>QX?03@D7P0oh000?n0003@D7P0j6Pl1@3oP0020=1@N080X23`0P3@D7P2
0?n000030:0Pl03XJ3`0oh0000X0oh000P3@D7P00`2P8?00oh000=1@N0070?n000030830003oool0
oooo00H0oooo2@00o`00AP11YPL0GR`?06HZ7@1Y;RD0HSHa06A<CP1TE5P0HTYE06a3D01a?4L0K2`d
07MAEP1mHFH0O6U_07eaM`22MGT0NfU[07icLP1mNgL0RXZ708jASP2?UY00S9VC082=T00T>FH02BY]
04]^P020UIL0PYNJ0:6g_01WOh@0Zl370:Fg_P2_`LT0S:B`0:k8e@2hcmh0U:g00:f:V`2M@UP0Ke:0
02A7Q`1hWlH0`]_V0<CHh@36fN00a][Q0<KIhP37f>80a=OP0<3Fg@2oe]h0^mGM0;WDg`2hdm`0RZJk
04edT@1=LXd0QZJf05ioS`2F/kh0P9^V06R3R`1hTIP0NI6E06R1Q01KMgH0EW9a04m]J`1:JVP204YY
IP0804YYI`1;JF@0BVMS04UWG`16I5X0AV1C02FY8000o`080?ooo`T00?l000<0D91h0?n0003oP000
303oP0000`3XJ3`0oh000?n000050?n000080=1@N02P8?00X23`0;Ph]03XJ3`0d51h0;Ph]03@D7P7
0:0Pl0030;Ph]03XJ3`0X23`0080X23`00@0^3Rd0:0Pl02P8?00^3Rd0`2P8?000`2h>;@0d51h0:0P
l00;0:0Pl0030;Ph]03@D7P0oh0000/0oh0000<0P<00003o003oool02P3oool000X0oooo05P0?5T:
048K7P1R=C/0FcDj01410@090@403P4102P20`150P<0D04305`21@1P0PD0I@4906X12@1`10T0L`89
07H12@1h0PP0P@4909@53P2J1P`0WPL>09P=5@2MEEd0alS;0<[EeP38eMD0//?702a3B@1PMG40`<k;
0<oIfP3Bf=/0e=cN0=SHg@32XJd0VS=10:4G7`1`3a80@RPX0::`[03Eg]h0e<cC0:=XM@1L6B00I6=S
0;S5a@3Ag=`0e=kO0=?LgP3DgMd0dM_L0=7Gf`31/kd0WW6108XoD@1W6RP0<10H02de=`2EY:<0bmGF
0:Nf_P13A500FQ8I08T52`2<0`/0S0<=08/22`2;10T0R@8808/21`2>0`P0S@<908@9302DD4h0b[Ji
071HG02ITIL0<adW03@L8P0J10L0=P8306h52@250`L0KP4204l10P130@4088412@3oool00`3@D7P0
oh000?n0000D0?n000060>QX?03@D7P0oh000?n0003@D7P0j6Pl1@3oP0000`3@D7P0^3Rd0>QX?005
0?n000050=1@N02h>;@0oh000?n0003@D7P01@3oP000103XJ3`0^3Rd0=1@N03@D7P30?n000040>QX
?03oP000^3Rd0=1@N0`0oh0000<0^3Rd0?n0002h>;@02@3oP0000`20`000oooo0?ooo`060?ooo`T0
0?l00500=;`705lX401Y<240IQhD06Xn=@1UD4h0Id5506DT;@1X9Rd0J41606UBEP1cHFH0NFU_07AU
K@1kLGL0PGAk07m^LP1lKg00PG]l08B4Q02=TXd0SiJB09>MVP1gQi@01b1Q00/XIP2>Z;80VJb`08RL
XP26WJ40[l?709NZ/@2]_/D0[/380;_?f@2H/l@0UkC40;6oaP2`Z;80L8B`00U2V`2?`>@0`mgT0<SK
h`38f^80a]SP0<;KhP35fn<0aM[R0<;IhP31e^40`MOP0;gEg`2ldml0^]?N0:k4e`0XD7D0=ej305f1
V`1`T9h0OYfW08FRZP2G/KX0Qj6Z06n:T01ZQHP0GW]l05McL`1BKG00CFU[04e[J@1;JVH0BFQT04][
I01>K6L0BVMP04QVG@17HET0;IH[003o00P0oooo2@00o`000`1@T7P0oh000?n0000<0?n000030>QX
?03oP000oh0000D0oh00102P8?00102h>;@0X23`0>QX?03@D7P;0:0Pl0050>QX?02P8?00X23`0:0P
l03@D7P00P2h>;@?0:0Pl0030;Ph]03@D7P0oh0000/0oh0000<0Z8Pl003o003oool02P3oool000X0
oooo05P0@E`:06]2A@1>8b/0<a@I00`20@070@003@4102`20`1:0PD0C`4405L10`1M0PD0HP8806T1
201_0PL0L@<907<22@1i0@L0R0<909@42`2J1@/0W`L<0:493`2D61h0/9BG0<SDeP2eaL/0?59H05e`
L034d<d0c]OH0<oIfP3Bf]d0`jng09aBH@2J7RX0W1@L04d=4@1<BDT0X:f/0=GLg030YZl0U41>06dK
8P1[IVH0a]?C0=GOh03EgMl0e=gO0=;Ig03EfMl0bl3:09mYN0279300Na@N04d:4@0V7Ad0HG9_0:Bc
/@39dm<0`lk@08^MXP1KJFd0?b8T08493P2>10/0R`<<08X3302:0`P0S0<:08X12@2;0PT0R@<908T^
;P3E^k`0SX240962Q026PhT091DN01d7300X2`h0A`@807@420220PD0L@8204h10P170@808h412@3o
ool00`3@D7P0oh000?n0000E0?n000040=1@N03oP000d51h0>QX?0D0oh0000<0^3Rd0=1@N03oP000
0`3oP000103XJ3`0oh000;Ph]03@D7P70?n000030=1@N02h>;@0^3Rd00L0oh0000<0j6Pl0:0Pl03@
D7P02`3oP0040=1@N0T0oh0000<0P<000?ooo`3oool01P3oool9003o001@02GE1`1Q:0d0Ib8E06HT
6P1^AT40JCXm06PS:P1];c@0JDM?06IFG@1WFF40LV1Y07UYL01kK7<0Og5h07e/L@23KW80O6a]085i
N025Q840S96=096GU@2GWih0CfB900HVM@0TB7P0M8fG07V;TP2gbm40P9JO09bc]`2I[K<0^L_B0:>c
_@2icML0S:Zk08R[_@2je>80Ehfo05NHd00VHj`0WL_Y0<KOi03;gN@0bM[Q0<KIh@38g><0bMcT0<SL
i035fn<0`m[R0<?Jh@32f>00`=KR0;kEg`2kdn40@F^@07BN^@1HP9`0U[S<07FEY`1jUZ<0OYVR07>?
U@1nVI`0PI^O06^6RP1MNW`0DVm`04i^J`1>JfP0BfYV04][IP1=JfH0CVaW04UXH`14HE/0A61G03F1
=000o`080?ooo`T00?l000<0D91h0?n0003oP0002`3oP0000`3@D7P0j6Pl0?n000050?n000030=1@
N02P8?00X23`00<0X23`00D0^3Rd0:0Pl02h>;@0X23`0;Ph]0090:0Pl0050?n0003XJ3`0d51h0:0P
l03@D7P00P3XJ3`00`2P8?00^3Rd0;Ph]00<0:0Pl0030;Ph]02P8?00j6Pl00/0oh0000<0d51h003o
003oool02P3oool000X0oooo01h0BfL>05lj>`0X1`X0600200T10@080@403P0002d10P190P<0C043
05@10@1G0@<0F@0506L11`1]0@L0K`<807D32@1i0@H0SPD:09X62`2M1P`0W@L=09l52`2P3A40UdiD
0;W0aP16FF<0:D140;K4a03<eML20<kFf@0h0<Via02==4<0X1@N0:0B601I30l0EEAD0:Vf]P3Bfmd0
d<C<094hB02>7RP0Ec4a0;o;b@3DgMl0e]kP0=GLgP3Cfmh0e=GJ0;ZQ/P2@AUT0RaPU05`?500N0@@0
6b0P07R;Q`2kb/D0b=?C0<[Ee@38eMD0amCE0<OCe02<O7h0N`hD08l52`2;0`X0RP<908T1202<0PP0
SP8:08/22@221@P0YFe[0<W1``1ZF5`0XIZJ06eZK`0K2a00:``B05/h>`1=10P0M`<708@11P1d0P@0
D00104@0000/H`490?ooo`030=1@N03oP000oh0001D0oh0000<0d51h0:0Pl03oP0001@3oP0000`2P
8?00oh000?n000030?n000040:0Pl03oP000d51h0=1@N0L0oh0000<0d51h0:0Pl03@D7P02`3oP000
0`3@D7P0oh000?n000080?n000040:0Pl03@D7P0d51h0=1@N0T0oh0000<0d51h0?ooo`3oool01P3o
ool9003o001@027T1`1S9@H0IB<I06lm<`1/<Bh0IB8R06Te=P1ZD5D0IeUR06]PJP1_HF/0Lf5Y07eT
K@21EV40McQ407mGG01nFeh0OFQW08AmN`24Ph40R8Z908bCTP2AVj<073Id004QM`12IHX0OiJL09FY
/`1^RI80[/K;08fV/02C[;<0Zl340;kAeP34e=`0c^7Z09G1f`1k^=h0LZSE0:[Gk`2agO40Wm3Y0=7T
j`3AhNP0c]oV0<CJh@39gn@0c=oU0<SLi037g>D0b=cT0<KKhP32f>80`MKS0;oGhP2meNH0=f2I04Ij
[`12KY00PZBh08FO[@2V`</0VK2k08FPZ021W:80K8N<06b8S01ROX00F7Qe059cK`1@L6`0C6]X04m]
J01<JVH0CF]W04aZI@14I5h0@f=I04IGA@00o`080?ooo`T00?l000<0D91h0>QX?03oP0002P3oP000
0`3XJ3`0oh000?n000060?n000D0X23`00<0^3Rd0:0Pl02h>;@00P2P8?00102h>;@0j6Pl0=1@N03@
D7P30:0Pl080d51h00@0X23`0?n0003XJ3`0j6Pl0`3oP0020;Ph]080d51h3P2P8?000`2h>;@0oh00
0?n0000:0?n00003003o003oool0oooo00T0oooo000:0?ooo`1H05Mc5P1281l07P4101`30P0<0@80
1P4100/1000/0P<0A@4304H10P1?0@80E`<505l2201Y0@L0JP4606`11@1c0PT0OP<709D73@2N1Pd0
V`D=09d73@2M1``0W`T>08dM9@1/GfH07C4d08RIVP37dm@0bmGG0<gHg030]/40Ud9A09lD7@2L41P0
I``B04<i>`2`^[X0e=_M0=?<dP2RE680UadX058E602GUiH0e]kO0=GMh03Fg^00eMcN0=;=e02TKWh0
Qb`k07DE8P0o2@l09R4R04mOH02<WId0`<c90<[Ee@38dmD0a]?E0<OBe@37dm@0am;D0;fj_@1a6b80
RPH:08L21`2;10P0RP8908d42P2?1@P0SPL<07`A4`31YjT0]k2f05m9CP2a/K40TI>F02hS9P0N1`d0
;0`B04`41`1g0`P0QP<907@2101@0@40@`4103A40PT0oooo00<0d51h0?n0003oP0005P3oP0000`3@
D7P0oh000=1@N0030?n000030;Ph]03XJ3`0oh0000D0oh000P3@D7P20?n000030>QX?03oP000oh00
0080oh0000<0d51h0;Ph]03oP000103oP0000`3XJ3`0oh000?n000050?n000030=1@N03oP000oh00
00L0oh0000<0d51h0:0Pl03oP0000P3@D7P90?n000030=1@N03oool0oooo00H0oooo2P00o`00;P1W
:PL0JSDY068S6P1]>Bl0K4Y506MDEP1REel0HeMO06YMIP1eGVP0MTUC07HP;@2:9S80O0lJ08A>D`22
IfP0P71`07igL`1kNgT0Rhj?08VBTP1eR9/012A`008VN01jVkT0KHJ<09B//`2?Yk40VkFm09F^]P34
f=h0e^?T0>;[kP38gNP0c^Oc0<cUm03Jlo`0loko0=KXkP3CkOH0eNcg0=k[lP3Hj>d0e>GZ0<oQi`3@
h^T20<_NiP0O0<SLiP34fN@0aMWV0<?Ii034en<0`=KQ0;kEhP25Z<`0HI;107fWaP29[/L0Tjbn09J`
_P2;YJl0TJZ`0:Bma01iTYX0QIjU06n8R`1aSHh0Gg]k05UgL`1EM780DG1/04i[I`1=JfL0CfYW04aX
H`18IU/0AUe>00SW1@080?ooo`X00?l000<0d51h0?n0003oP000403oP0000`3@D7P0oh000:0Pl004
0:0Pl0050;Ph]02P8?00X23`0:0Pl03XJ3`00P3oP000202h>;@0d51h0=1@N03XJ3`0oh000>QX?03@
D7P0j6Pl1@3oP0000`3XJ3`0d51h0:0Pl00A0:0Pl080d51h2P3oP0000`0Xb3`0oooo0?ooo`090?oo
o`002P3oool0>P1=JA008@8101h20P0D0@803`8200@10@050@009`<304X82`180`H0CP4505l:401T
0`P0J04506T1101X00@0LP8:08T52`2G1Pd0V0@;09L5302G10/0UP@:09P73@1a3AD0?cPh09n^Z`37
dM80b=;D0<C@eP1oTI/0Cce809@H7`294AL0@@P=04i8B`2d`L80e][M0<^b_@2QBUT0YaXP08e5A`2H
VIH0d=[K0=WOh@3Eg=h0fMgQ0<fja@2ABEX0IADP03L;3P0W8200GVe/0:Vh]`33c]40c]OI0<kEf03<
e=T30<WBeP0K0<SBe037d]@0aLO<070T:`271@/0Q@8708L31`2;1@X0TP/809HA30231@H0U5AD0<:m
`P1JAdh0N6=V09BJW@18AD/0810G02063@0R0PL0DP@:07L320250`L0N@<305@10@120@00=4@300T0
oooo00<0d51h0?n0003oP0006P3oP0000`3@D7P0X23`0>QX?0030?n000050>QX?03@D7P0j6Pl0:0P
l03XJ3`01`3oP0000`2h>;@0d51h0?n000030?n000060>QX?03oP000oh000?n0003XJ3`0d51h0P3X
J3`20?n000030=1@N03oP000oh0000H0oh0000H0j6Pl0:0Pl03oP000j6Pl0:0Pl03XJ3`90?n00003
0=1@N03oool0oooo00H0oooo2P00o`00B01V@@h0G2DF06<Y6P1[DTH0JUaL069EFP1QEE/0G51H06M?
E`1^=T40ORli07`K8P29<3H0Qd9708=SI`22M7H0PWMg085lO01nOgh0Qhb;08fFU`1;HXL00RB000Tb
P`1dU:X0/lC:09J[]`2W_<P0]/W@0=GRi`3/m?H0j^ob0?KinP3`moT0nOoo0?Gmo`3>jO40a>C_0?Sm
oP3]m?H0hN_c0=[VkP3Gi^/0e^GZ0=;Rj@3=h>P0bMkV0<[Li@38f^H0a=SU0<;Hi@31en@0`mKR0<7D
hP2odn00P9k101M9PP1iY<00PZJk0:O1d02S^lT0TJjh08fW/P2:XZX0Rj2X09R[/P2?Y:H0P9NJ06b7
R01PNg/0FgQi05=bK`80DG1Z00D0DFiZ04m[H`1;J5d0Af5B01G74@080?ooo`X00?l000<0d51h0?n0
003oP0004@3oP0000`3@D7P0X23`0:0Pl0050:0Pl0030;Ph]03oP000oh0000D0oh0000<0j6Pl0=1@
N03oP0001P3oP0000`3@D7P0^3Rd0;Ph]00D0:0Pl0030>QX?03oP000oh0000L0oh0000<0D91h0?oo
o`3oool02@3oool000X0oooo01@0=UH702020@0M0P80404100l20P040@40200002/210180P@0DP43
05D10`1N0PL0H`8706D11P1X0PD0J04506l11P2<10/0T`<:09H52`80T`@:02L0U0@:08@:400g6Q/0
YK6_0<_Ee@3;eMH0_/g@055YLP0lDeT0W9nP06<Z;P0h8B<0JgMg0;_7b03Fe]`0/G^909`U<P2_51X0
ZBX/0<B`/@3CgM`0fMoQ0=WOhP3Df=`0[iRT06lgA`0b3aL0@4E606j0O`2W^KH0am?B0=3GfP3?e]X0
d=OK0<kGf@39e=L0bM?F0<[De@38d]D00P36d]<06@2`Zk00M1@P08X430260PP0QP<;08T71`2I6A00
P`<507LA4P2oZjX0VYBJ03/P9`2SVil0XZ^_04m0A@0R1`d0;0XA02L4201A0PH0O@@;08H2201n0P@0
FP4104H10@0fA0802@3oool00`3@D7P0oh000?n0000F0?n000030>QX?03oP000oh000080j6Pl00D0
oh000>QX?03oP000oh000=1@N0020>QX?0050;Ph]03oP000oh000?n0002h>;@00`3oP0001P3XJ3`0
X23`0>QX?03oP000j6Pl0=1@N0`0oh0000<0d51h0?n0003oP0001P3oP0000`3XJ3`0^3Rd0?n00002
0:0Pl0X0oh0000<0d51h0?ooo`3oool01P3oool:003o001?05IX2@1B70/0JdXl06YLE@1ZH5h0HeII
06M9D@1N=Ch0JTI=07Dh@01h<3H0N3i508]FGP2;B5<0OdMB08AgN`26O7`0Q7mn08F7QP28T900TIbN
059[T002:hd05TNI0:6jc@2g`<P0`/oF0=CPi`3Tk_80j>od0>Wam@3Wk?00o?ko0>oen@3Lk?H0c^?/
0>cjoP3RnOl0goCm0=;Yl@3EjoH0e^G^0=7Rj`3:gnT0b=gW0<KKj036g>L0`MSR0<3Hi02oe^80_mKQ
0;oDh032e=l0_m7O0;W@g@2?[L00JI6e06N@/@0kJ8T0M9V[08:P[026Y:d0Y<3;08nZ]@2>Yk40S:>/
08RLX@22Ui`0KXR;06B0P@1MNW/0EgAb05YcL01HM740E75^05E]JP1BJV@0BVEH026W7@080?ooo`X0
0?l000<0d51h0?n0003oP0002`3oP0000`3XJ3`0oh000?n000020?n000030>QX?02P8?00X23`00@0
X23`0P3@D7P60?n00080d51h00<0oh000>QX?03XJ3`00P3@D7P20>QX?1T0X23`00<0d51h0?n0003o
P0001`3oP0000`20`000oooo0?ooo`090?ooo`002P3oool0?00`D@@0804101l20@0H0@803@0000D1
0@080000;@8304D10P1?0P<0D`0205d11`1@0@D0E08606@11@1W0@D0L04608/3202?0PH0T`D908l2
202@0`P0SPD:05X83@1PIF@0am;B0<SBd`39eMP0LXZA04aWJ`2da<<0am7B03Ln@@25UIH0`]3A0=SK
gP2hTIh0WQdZ0;PF702i4aP0/dA90<[4a`3Ih^80en3Q0=OPi02NZK80;bLa01LC5P1HJfT0[;bl0<SE
eP3@g=`0d][L0=;Hf`3Aem/0d=SK0<kHfP39e]P0a]CH0<GBe`80b=?E01X0am3D08e^N@1m2aD0R`@=
08/32P250`L0VAhC08D:1@1n1@X0R4900<73`P1`H6H0KU9F0:FXZ@25T980<RX]01d83P0S1@`0<`D;
06462P1j0@D0Q@8607l10`1R0040CP4103I40PT0oooo00<0d51h0?n0003oP0005@3oP000103@D7P0
oh000?n0003oP0020=1@N0<0oh0000@0d51h0?n0003oP000X23`103oP0001@3@D7P0oh000?n0003o
P000X23`00<0oh0000<0d51h0?n0003oP0001`3oP0001@3@D7P0oh000?n0003oP000d51h00P0oh00
0P3@D7P20?n000030:0Pl03oP000oh0000P0oh0000<0d51h0?ooo`3oool01P3oool:003o001?05Ek
2P1E:Q@0JE=306]NEP1_H5h0JDM:06XM901U4AT0M4]C079>E@1oF5l0OSU408<V;`2<8R/0PBP`08ai
O@2<QHL0RHN708fCT`2GW9h0XJBX08JG/@05>Y/06UN[0<SLj`3IgnH0eMkW0>3Xk`3Hh>X0j_7e0>od
mP3hoOh0f^;X0?Kjo@3amo/0g^gi0:S>jP1`/=h0VM3_0:kCjP2ae>/0b]kW0<WMi@34g>@0`m[S0<GJ
i@31f><0`=OR0;kEh@30eN40`=?P0;oCg`2md]h0^m7M0;[Af`2M^/X0<eV103QRQ`26[;h0QZVi07fM
ZP21WjX0Mi>O072<V02<Zk<0PYnW082JX@1_Qh`0IX24061mOP1FMGH0EG=c05YeMP1LMg@0FgMb05Ud
K`1AJV<0CfYN02^E:P080?ooo`X00?l000<0^3Rd0?n0003oP0003@3oP0020>QX?0030=1@N02P8?00
X23`00<0X23`00D0^3Rd0>QX?03@D7P0oh000=1@N0060?n000050>QX?02h>;@0X23`0:0Pl02h>;@0
0P2P8?000`2h>;@0d51h0:0Pl00G0:0Pl0030>QX?03oP000oh0000L0oh0000<0Z8Pl0?ooo`3oool0
2@3oool000X0oooo05P0<4l202820@0L0@405@4200`10@060@40204002/20`160P<0D04305L10`1M
0PL0D08704d1101Q0@H0J@4607D1202>0`T0T08609432@2@0@X0T`H=07l?50107al0Z[Je0<OAd`38
e=@0[/72055/KP2a`/40cmWI0<[Ee`2?XJ<0a=7A0=SLh03?[KL0Z30l0<0E6`344QL0a1@H0<5AE@3A
c<l0fn;S0=_Sh`3:em`0=4eE04QNH02@Xj40`M;A0=;Mg@3Dgn00eMoP0=;Kg@3@f]/0dMWL0=3Gg03;
d]P0V:Nb05I^NP1nTi`0bMKH0<[Ce`2_YZl0Nblk08D73@2910/0R`<:08`=202I8180P@D6070:302^
R8H0_/74050b>02COgh0Xj^[0:>_/@1CD5@06@T?02/A600c10X0F`<507T11@210PD0OP8406L10P1B
0@40>4<22@3oool00`3@D7P0oh000?n0000H0?n000030=1@N03oP000oh000080oh0000D0X23`0>QX
?03oP000^3Rd0>QX?0030?n000040>QX?03@D7P0oh000?n00080j6Pl00<0d51h0?n0003oP0001`3o
P000203@D7P0^3Rd0=1@N02P8?00oh000>QX?02P8?00j6Pl203oP0001P2h>;@0oh000?n0003XJ3`0
X23`0>QX?0T0oh0000<0d51h0?ooo`3oool01P3oool:003o001?03^P1@1J>AT0IE9106aFC`1dCd`0
JbTZ06`B5@1Z:2X0NDeF07XnB@20?DL0PBHa088Y;`29@dT0SUQN091dN`2MV9`0VIVM09fNXP2/[Jl0
_;Zl0<?7eP0OEZH08FVk0<KNk@3Ni^/0f^C[0=7Pi`3GhnX0en7Z0<oMj03:g>H0bMcU0:k4f`2L]m@0
[L_Y07f_e`2af_H0>GRi06FQdP2[c^<0bMcS0<SJhP37f^80a][T0<CIi032f>@0`=KS0<7Gh`2oe^<0
_m?R0;gDh@2ldn40^];P0;KAgP2ed=l0PJJn03IPS`1LQJD0@6V207RGY@29Y[40QZJ`08NV[P25XJX0
KXV@06>1QP1VPXH0JHJ7069oP01BLFh0DFm_059`K`1HMG80I85l06=mN`1FKf/0D6]Q03V5>0080?oo
o`X00?l000<0D91h0?n0003oP0002`3oP0000`3XJ3`0d51h0:0Pl0070:0Pl0070=1@N03oP000oh00
0=1@N03oP000d51h0;Ph]0020=1@N0P0X23`00<0d51h0:0Pl03@D7P05P2P8?000`2h>;@0j6Pl0?n0
00090?n000030=1@N03oool0oooo00T0oooo000:0?ooo`1H02m=0P0R0P40704101H10P0>0@801081
00L10@0W0`80A@4204l2101F0@<0GP4606<21`1P0PH0I`4606/11P1m0PP0T`<:09<22@2G10/0V@D<
08X<3`102@X0PHF30<OBd`39dM@0ZJfc09JUZ02jb/T0c]WH0=7Jf`3?f]`0_l[<0>?Bf@3CR9P0bCM4
0>4Q903Z9R<0kbdZ0>d_:P3VHV00ln[[0>S]kP3YkNh0h>KW0=7Jf`3Pj^/0hNWZ0>?Yj@3Rj>P0gnKV
0>3Vi`3LhN<0emgP0=SGgP35[;T0KTmR02Pb?@1]QHX0^LS:0<cEf@2aWZ/0OB/k08/;5@2<10X0RPD9
08X<1@2V;aX0P`L507H92`2GH5d0a/310:2HW01T@d@0[JZY09ZZZ@2Q/;407b4V01@:3P0J1``0;0<7
06<42P1j0@L0O`8607H10`1S0@80D`4103Q20PT0oooo00<0d51h0?n0003oP000503oP0000`3XJ3`0
oh000>QX?0020:0Pl0080>QX?03oP000oh000?n0003XJ3`0d51h0:0Pl03XJ3`80?n00080j6Pl203o
P0001@3@D7P0X23`0=1@N03oP000d51h0080j6Pl00<0X23`0?n0003oP0001`3oP0001P3XJ3`0^3Rd
0?n0003oP000j6Pl0:0Pl0X0oh0000<0d51h0?ooo`3oool01P3oool:003o001?04J/2P1K?AT0H4Xh
05l[9@1d:RL0K24Q06dd=`1V;3<0L1lZ07`J9@1i;3@0Q4iD08UFGP29CET0U51M09MDF`2eY:P0YjR/
0:jb]P2k_l<0_;k40<O8dP1HO;H05EVa0<;Ik03Bfn<0c=SR0;o@f@2hbm@0^LkL09J__@2/aM00Y<3<
0:_7fP2I]ld0[/_N06:B`@1NW/l0O[;H08g9j`32h>l0b]o[0<GOkP33ho40^=oc0:_Im@2Mdo@0S<Wc
08:nlP1g/n`0Kj[V06RSh@1RW=`0GiGF05Z?d@1GR]00<6Ne00LiU`0mLkH0EhNh06jF`P1LPj/0F8:R
07fS^@1^TJ<0Rj^j07fJY01POH<0HWn106N2QP1DLW40CfaZ04i/JP1ELfl0F7Eb06Z6Q@20UiH0F79[
03f:@0080?ooo`X00?l000<0D91h0=1@N03oP0002`3oP0000`3XJ3`0oh000:0Pl0030:0Pl0060;Ph
]02P8?00X23`0:0Pl02h>;@0d51h302P8?000`2h>;@0X23`0:0Pl0020:0Pl0030;Ph]02P8?00X23`
01D0X23`00<0d51h0?n0003@D7P01P3oP0000`3@D7P0oh000=1@N00;0?ooo`002P3oool0F014?PP0
808101d20@0I0P803P8100@2000400009P8204810`1>0@@0D`4305`11P1O0@D0H`8606d2201c0`T0
Q`@;09D42@2I10X0W`L;0:893`1f4Q<0EDM60;c5a@39e=@0aK[106a0C02cZ:d0d]_L0=;Lg@3Egn00
en7R0>?Ri03QSiX0gCQ10?Hb=03n>SD0oD8h0?m<@@3nDd@0mWA[0?oXjP3mo_d0o_on0?knoP3jnod0
k_;d0?;dmP3`lo<0jnk_0>W]kP3Vjn/0h^KW0?7Mj03IUJT0SSiA02hG8@2?Xj@0`mGG0=3Hg@3=a]00
UD5D09X<6P2K1@l0U0<;08h91@2d@240UAd:08@41`1l:BP0cknn0;k4b@1jIFX0QFa/09:JV`2N/;40
Z;Fg02HP9@1KBT`06PD:038;3`1D0@H0K`4407/11@1c0@80H@410540000j@P490?ooo`030=1@N03o
P000oh0001@0oh0000D0d51h0?n0003@D7P0oh000:0Pl0050?n000030:0Pl03oP000oh000140oh00
00<0d51h0:0Pl03@D7P0103oP0000`2P8?00d51h0?n000080?n000030:0Pl03@D7P0d51h00<0X23`
2P3oP0000`3@D7P0oooo0?ooo`060?ooo`X00?l004l08]D5060n6P1B<b80DQhB064Q5P1X=C40H2L/
06@C6P1_7bD0LSDl08IPI`23A540RS0o08lM;@2[Ff@0S49:0;NTY`2e_L40^<350;Rj`@2i];T0^Jf_
07^6ZP0;?Y<0YlKP0:Zob@2jcMD0[l7<0:Fia02F[KL0/<K@0:[0c@2ic]H0`mSQ0<;Ol02Ra=D0f?3i
0<odo02eiO<0V]k`0:?Tn`23e_X0El?g03^em`0PWNl058S^00f1lP07Mo403fCQ031>_`0mAJd0@SbQ
04PiW017<Y00@Bb703XSNP0e7g@0<R=j02`PN@0W8WL0821c01PRM00C8gH052ao014^O@0J>hH08D9o
02i@O010HGd0EWN:05alP@1@L6l0Cfe[04m^J@1EM780M9:@08VRY01HLW00BeQ;00P0oooo2P00o`00
0`1@T7P0d51h0?n0000;0?n000030=1@N03oP000X23`0100X23`00L0^3Rd0:0Pl02h>;@0d51h0>QX
?03@D7P0^3Rd01h0X23`00<0d51h0?n0003oP0000P3oP000103XJ3`0X23`0?n0003oP00;0?ooo`00
2P3oool0F01I:a00808101`10@0F0@802P4100@200090@00:P<204820P1>0@80E`4305`11@1Q0PL0
J`<907812@1g0@X0S`D>09T42P2O1PX0Y0P=0:8=4@1_;bl0Y:RX0<_DeP3Ae=H0/79k08PZ=P3;/KH0
f=gP0=WPh`3Ih^D0hnKZ0?>i`P3/AU40ncDj0?hg=`3n@C`0o4Q10?]=A03lEDL0m79X0?gTi03oooh0
o_kn0?[knP3inO/0loCg0?;cmP3^l?<0ko7d0>c]l03`k?00l/OG0<e`Q`24:c`0E38i0:Zc]@3@gN80
eMgR0=_BgP2iJg`0/1TS0;8;4@2^2Q00X@P:0:d`502X;A<0T@T508L:302YNGP0aLK;0<;3c01G<SX0
ZibK08REU`2@XZ@0QY2C01`D600I2Ph05@85034>401>0P@0K@8307L10`1a0P<0F`4205410@0k@`89
0?ooo`030=1@N03oP000oh0001H0oh0000<0d51h0?n0002h>;@0103oP0000`2h>;@0j6Pl0?n0000A
0?n000050;Ph]02P8?00d51h0?n0003XJ3`00P3oP0020;Ph]0@0oh0000D0j6Pl0?n0003oP000oh00
0>QX?0020:0Pl0030?n0003XJ3`0d51h0080^3Rd2P3oP0000`3@D7P0oooo0?ooo`060?ooo`X00?l0
04l0:M/:068c3@1=8A00ER`I06T/7P1N5180K2<W06LV:P1hADd0LUEN08=WK`1g8Bd0UBXa08LU:`2L
J6/0WH>70:nVZ`2][;80[:ja0:^[/02VYj`0TiJH07R9W`08;g@0Q:2g0;?5b`2lcmP0ZKg80;cAfP31
f>80aMo_0;oSl`2>cO@0R];d08;;l@1oco<0GKoc03:[l@0MWn/06i_S01jQi@0JYN`05J_e00fXnP09
XO/029Gk00R:n`09NoH0E5W40<DYF@3<7Ch0aQHe0<@D<02o5Bd0[0`Q0:D=8P2K2Ql0S@HL09898P24
3280Qbi4074M>P1c32h0KP`e06H>>`1D3Cl0@0m502T>B`0J55D041]N01H_JP0ZCGH0@VAj05AdM`1F
M7<0IHF508bVZP1BK6d0@gi400P0oooo2P00o`000`1@T7P0d51h0?n0000;0?n000030>QX?02h>;@0
X23`00@0X23`00D0^3Rd0:0Pl02P8?00X23`0;Ph]0070:0Pl0<0d51h3@2P8?000`2h>;@0d51h0=1@
N0020=1@N0040>QX?03oP000oh000?n000L0d51h00<0^3Rd0:0Pl02P8?00102P8?001`2h>;@0j6Pl
0?n0003XJ3`0X23`0?n0003@D7P02`3oool000X0oooo05P0ERXA01d10@0K0@405P8200H10@020@40
200002/20P180@80D04205P1101P0PL0IP4607422P1h0``0P@8=09/63`2S1Pd0Z0L?0:`93P2S5QT0
XGn00<kDeP3AemP0d[Zo07LY<@0^1``0][Rj0=GLg`3Ig^80f=kR0>[PiP3ICeT0o2d_0?d^;P3m=300
oChi0?m<B03nCdT0oU9;0?UmM@3ol_40o_kn0?gnoP3moOh0nOWk0?Kgn@3bm?H0kNoa0?O]mP3ldn40
l8fM0<e4E@1^=d40W9ZL0=CNh03Hh>@0h=_T0=J/_P2kDVL0aAXV0<LB5`313QD0^PhA0<0b4P2j<A80
YP/90:093P2H?S`0clO60<G:d@2VTi`0FRT]0;Bc]P2>WZ<0Z[Rl0:6Z[@0D3a<03`<701D31@0a0`D0
G0<607D31P1h0@@0K@4205L10@1?0@40?4812@3oool00`3@D7P0oh000?n0000B0?n000040>QX?03o
P000oh000=1@N080oh0000<0d51h0?n0003oP0000P3oP0000`3XJ3`0oh000?n0000>0?n0000;0>QX
?03@D7P0^3Rd0=1@N03XJ3`0oh000>QX?03oP000d51h0:0Pl02h>;@0103oP0020>QX?0<0oh0000@0
j6Pl0:0Pl02h>;@0oh00102P8?0:0?n000030=1@N03oool0oooo00H0oooo2`00o`00CP1V:0L0GbTI
060Q5P1S3`T0I0l>06Xc=01^@dL0KRDa07Xg@01nGVH0PeEM08I=D@2JOh@0VY2F09jGW02WWJ<0YJ6V
09jNY02HW:40U9^P08^GV@22UZ<053Yb092`bP2lcml0]LoX09O1j@1f[>T0C9WY02^8j`0FOn/01h?d
00F>n005TOD019Gf00bSn00T]?D0ClSg07gFn@1`co@0@;Wf01jMm00?RNh027;V00YSg00BE=005Cnh
05X`R`2d4Bh0/`TJ0:T55@2W2AL0T`lH090O;0242a/0P@TD07HC701^2A@0Q3@o0:5nRP2dUJ80MA/Y
07l43@1o0Pd0OP8=07`33P1g0a00L`DH06H89P1?2cH0<AA;01HLF`0F<VL0?V5k06^:T01jUYT0CfYW
03^D>`P0oooo2`00o`000`3XJ3`0oh000?n000060?n00080j6Pl00<0oh000;Ph]02P8?006@2P8?00
0`3@D7P0X23`0:0Pl0060:0Pl0030=1@N03oP000oh0000L0oh0000<0j6Pl0;Ph]02P8?001`3oP002
0=1@N0@0X23`00@0d51h0;Ph]03oP000d51h2`3oool000X0oooo05P0CbD=01d10@0L0@005P8200`2
0@070@402@0003<30`1D0@@0F08505h1101U0@H0L@<908@;4P2>41H0V0/A0:d:3`2c20h0]@X=0;`=
402e:bh0g<340=GFf03Fe]P0SX>303ll?P2JY:D0cMOK0=;Kg`3Ggn40emgP0>?6c@3=<3L0jB0S0>dR
8P3^92<0kbLV0?<];@3d;c40lbla0>U7C03jfml0kNoa0>W]k`3Xjnl0i^[]0>CVjP3^hnX0ijfl0=aJ
L@3Q>4T0fDA:0=JXZ03AeMT0f^;V0=KKh@3Ga=80_fEg0;LS<P355b40b18G0<4A502g40l0_C0A0<4l
4`2a3P/0[PT>0:0Q8`3B/k<0algA0<W1bP1^>T@0ZXB50;c5aP2AY:H0Xk>f08jHW00C2`l050D801D3
1@0W0P<0F@`?06h21P1f0@@0K08205d20P1?0@40>4812@3oool00`3@D7P0oh000?n0000B0?n00007
0;Ph]03oP000oh000?n0003XJ3`0oh000>QX?0030?n000030=1@N03oP000oh0000L0oh0000<0j6Pl
0?n0003oP0000`3oP000103@D7P0^3Rd0;Ph]03@D7P20?n000050>QX?03oP000j6Pl0:0Pl02h>;@0
1@3oP0000`3XJ3`0d51h0?n000030?n000030;Ph]02P8?00j6Pl0080j6Pl0P2P8?000`2h>;@0oh00
0?n000080?n000030=1@N03oool0oooo00H0oooo2`00o`00CP1/:Pd0JB<I06L?301S4@`0KSPe06]=
B`1N7B<0OR4Y078P9`2>M7h0QgZ308MiP@2=Ph/0ShRA09>:TP2BRY40THfD09:AU`2BV9d0UYjT096P
Z023X;/07dfL039W_`0dK/P07Uk800M4`@03CM<016[a00Ecm`06N_X028?l00R6n@08R?L028Gf00Qn
k@0@M^@076kN02iXe`10GLX0CE2j05i3Y`1]=hh0MBf107dZMP1o9F`0PB=W08LLEP2^42/0/`TH0:h9
5P2L4Qh0gZF]0;REYP2lWJT0T6Qa0;fW/P2kYZl0NEYX0;6KZ02_Y[@0Of=_09YaM@29FE`0McPn07LU
;@1/0PT0LP4607L22@1i0P/0NP<A06d98P1633D081M>02e?PP1cVJh0EFi/02RZ8`P0oooo2`00o`09
0?n00080X23`00<0^3Rd0:0Pl02P8?008P2P8?00203XJ3`0oh000?n0003oP000^3Rd0:0Pl02h>;@0
d51h0P2P8?00102h>;@0X23`0:0Pl02h>;@20=1@N080j6Pl1@3oP0000`3@D7P0^3Rd0:0Pl0020:0P
l0030?n00020`000oooo00X0oooo000:0?ooo`1H04TR3@0L0@408`8101T20@0=0@40208000h10@0e
0P<0E`4405`10`1U0@D0KP8807/53@2@4QP0T0dB09d:402`2@d0^0X>0;/;3`313Q<0^34f0=g5b@3C
eMX0bm7D059NG@2V][H0bMCE0<;<dP3?fM/0d]cM0=;Hf`35V:00^Q/R0</C5`3;4QD0bQ8E0<XD6@3@
4aP0eAHH0=TI6`3A9B`0j;_20>7Uj@3Qi>P0gn?V0>CSj03YcMT0bW>50<DY>@3>6B<0bQLK0<=<D@3<
bLh0d]_N0=KKh034]Kh0WDEH0:dC902d31H0]0`D0;494P2/2``0XQ/10<QI7`2M40@0Y`L<09d>4P2g
KVh0c<_@0<[:d@2;IW<0HB@X0;:WZ02ga<T0YkFm0:Rg_02HXjH0ASDj02P<400M0PD0<@@705@52P1^
0PL0LP4306X10@1L0@40CP4103E100T0oooo5@3oP0001`3@D7P0oh000?n0003oP000d51h0?n0002P
8?000`3oP0000`3@D7P0oh000?n000070?n000030=1@N03oP000oh000080oh000P2P8?040?n00005
0=1@N03oP000oh000:0Pl03@D7P01P3oP0001@2P8?00oh000?n0003oP000d51h00<0X23`00<0oh00
0:0Pl02P8?000`2P8?0:0?n000030=1@N03oool0oooo00H0oooo2`00o`00CP1LFPh0Ga0706TP601g
?SL0KC`f06]9A@1Z;bh0NSdn07]OHP1lL7L0O79k07mcO01nLWd0PGZ208UoQ`2DR8l0ViFJ09VMY@2A
XK@0Khba03mY[P0>B:/013R^004TX@03>[/01doH00=0c`05D^001VK`00IRiP0;E=D05DO002a4]@0i
?JL0DcnR070mV02;=h/0X3n:0:<nR02MAHl0Re:F075JW@1RH:L0C6Je03]]`00]K/H09FO<02iNa`2P
=7<0f1h[0<lE80316RP0ZC1309YEIP3@_lX0Y8nL09MVO@2QKh80WYBR09MjSP2>HgH0UX>C09V6U02:
NXL0Rgj:0:1oSP1T1A40J@4406X:3@26<cX0N0H?07P4301m1100N@TQ04/FB00X?7X0FGF601?C4@P0
oooo2`00o`000`3@D7P0oh000?n000070?n002L0X23`0`3oP0020=1@N0<0X23`00T0^3Rd0:0Pl02P
8?00^3Rd0:0Pl02h>;@0X23`0=1@N02h>;@00`3oP0002@3XJ3`0oh000?n0003oP000j6Pl0;Ph]02P
8?00^3Rd052@N00;0?ooo`002P3oool0F0187``07`4102D20P0J0P802`4100P10@0=0000=P<505d1
1@1W0PD0K`<807h>50253a@0Q@L=08X43@2N1a00/@T?0;H;3P2h2Pl0_0dB0:`X:P3;^;X0c]GF0;g9
bP2T/k<0`Lg?0<GBe`2__L<0c]SI0=3IfP3Be=L0XUeW0;LD6P2l41<0_a0E0;l@5P304aH0bA@F0=4H
6P3D5a`0c2<X0>Nj_`3Qi^T0hnKX0>gNh`3RUJD0c4IG0=@V<@3G6Qh0caHI0<`H6P2nB4h0d/kC0=;;
d`2nUJ80XT5@0:TC7P2X2180Y@L?0:@73@2R1P`0X1`70<aY9P2P;P/0U@H809H93P2:;2`0ckVh0<K<
dP2_VjD0FaXS09]]KP2f^[d0ZKJk09RW[P2DY:X0P8J=03LP:@0o7bH0=a@J03021@1H0PD0L0460741
0`1Y0@80G08105010@190`890?oooaD0oh0000L0d51h0?n0003@D7P0^3Rd0?n0003@D7P0X23`0080
oh000P3@D7P90?n000060=1@N03oP000oh000>QX?02P8?00d51h103oP0001@3XJ3`0d51h0;Ph]02P
8?00j6Pl00D0oh0000<0j6Pl0:0Pl03XJ3`0103oP0001@2P8?00^3Rd0?n0003oP000d51h00<0X23`
00<0^3Rd0?n0003oP0002@3oP0080?ooo`/00?l004h0GFd<05hK2P1a=2H0I1P@07DW7P1gBd80NVMR
07U]K`1`JW40L6U_07EZL`1dIW00MF]d081hO`2=QY00Ti2S07V7[00nI:D054FP00@gX@03<j8013>[
00Di]`03<KD013Ro00U?e`05@LT013>d02XcX`1M9Wh0Lb9Z07hXJP1l=7L0Mcj3079<TP1QJ;40E8;:
05:KfP1]]^00Pl_Z06c?mP0n_oP0:[Ok016Mn@08U?X01H?f00=`l007Gmd0LC>40<TD:@333AX0]A8M
0=NAU`36XK40VTm[0;YiS02QFFh0^W>209ijSP2gVZP0[8jI08eRM@2CKgd0/:>^08emRP2UQY@0K0TF
07811@1P3A80Vfmh07d_?026@dd0ObPa084>602?31T0Gae=01ldHP0Eb1P80?ooo`/00?l000<0d51h
0?n0003oP0001`3oP0000`3XJ3`0^3Rd0=1@N00I0:0Pl080^3Rd2@2P8?030?n000040;Ph]02P8?00
X23`0;Ph]080d51h00<0X23`0;Ph]02h>;@00P2h>;@00`2P8?00d51h0:0Pl0030?n000030=1@N03o
P000j6Pl00<0oh0000<0^3Rd0:0Pl01@T7P02`3oool000X0oooo05P0B1`:01l10@0N0@405P4201L2
0P0B0P404P4103T31@1V0PH0L0<707<21`2?4a`0S@`C07d32P2:1a00W0TA0:l;4`2/2@h0Z@L<0:`:
3P2M4AL0]8nF0<[Be036dm@0b<kC0:jT/01DFFH0Wjjc0<cGe`3Cf=/0cjnf0:@Y<@3951L0e1LI0=XK
7@3M7Qh0iBLU0?0]:@3`;2P0mCD_0>]=A@3lh>40m_Oi0?O/k`3VTYH0kU5<0?Q4?@3j@CH0mSHZ0?4_
903[:bD0hVY/0>g1c03<E6H0bR4^0<`F7P313QD0]@/B0:P7302U20X0W1450<IX7@2J<PL0SPT608d4
2`236al0d:j_0<O;c@36b]40MDI@06<O8`2fYJL0/;o20:bl`02gb<`0Vjb^06MSJP0f72P08Q@M07ER
J@101@X0K@@907T21P1d0@<0J04205/20@1>0@40A`<22@3ooolE0?n0000:0;Ph]03oP000oh000=1@
N02P8?00d51h0;Ph]03oP000j6Pl0:0Pl0X0oh0000@0j6Pl0?n0003oP000^3Rd1P3oP0000`3@D7P0
^3Rd0=1@N0070?n000030:0Pl03@D7P0oh000080oh0000@0d51h0?n0002h>;@0j6Pl0P3oP0020;Ph
]080X23`00@0d51h0?n0003oP000j6Pl203oP0080?ooo`/00?l004h0?XX406dh801/81<0N1D=07l_
8@20GE00LVMV07I_MP1[I6d0JF5Y071VK`1dIW00MVeh07=hSP1<I9@06T2?00DaU`02;j000S:W008e
Z`06>Jd01bjP01DcY@0N78H0=19Y04TMKP0<5gT00QUo03<ZQ01@>X`0>UB]02M^bP0HQND06Yoe01RT
n@0DZO/06ZGh01FGm@0FRN`058O/00Qik002Lnh00G7]005YjP01INL00F;V005Lh003E]T0FC^I0<LE
;`3@4AX0`1LQ0>Z/^@2lSil0gXjR0;0Z@02a6c00]bDj0:HL=P2gBEl0/59Z090Y?P2dK7`0/WF608]8
F`30VZH0QSA307/22@1`7R40[INN07UAF`1oF6@0YhZF09ARKP2I?4L0MQm501@SG00CZ1X80?ooo`/0
0?l000<0Z8Pl0?n0003oP000103oP0020=1@N080oh0000<0j6Pl0=1@N02P8?008`2P8?000`3@D7P0
oh000?n000030:0Pl0<0j6Pl0`3@D7P01P3XJ3`0^3Rd0:0Pl02h>;@0X23`0>QX?080oh0000<0^3Rd
0?n0003@D7P00P2h>;@0103XJ3`0d51h0:0Pl01XZ3`;0?ooo`002P3oool0F0156`T08P4102@20P0O
0@408@8201/10P0G0@80<@8406821@1_0PH0L04807@;3`269BT0KP@<07l5302B1`l0X0/D09`7402N
1P`0X0H;0:<8402O:CD0/Vam0;=nS@2YEfL0N2<`04`l@`33cLl0d=[L0=oAe`2gEV00e2<W0>lV8P3j
;RP0n2`X0?de;`3n@3P0od]10?iCB03nFTX0o7Q/0?oFgP3ke^<0n/kL0?V]]03kPWL0oViO0?eQD@3j
ETH0n71S0?IaK03_GF@0l4UD0?T`<`3i9bX0lbDV0>HN7P3G5a/0bQ8D0;/E3@3<HAD0]4T>09h=1P2P
1P`0S`X=0:Q`K`3<c<`0a<k@0;bb^01E51h0SfUY0;o3``2d`/H0VJ^^09>WZ@2=X:80M6mg02D8500P
2QL0?BXe07He?01f0`T0P@8707X20`1X0@80GP8305010P1710890?oooaD0oh0000@0j6Pl0=1@N02h
>;@0d51h0P3oP000103XJ3`0oh000=1@N03@D7P:0?n000@0d51h1P3oP0020>QX?0L0oh000P2h>;@3
0?n000040>QX?03oP000oh000:0Pl080oh0000<0j6Pl0:0Pl02P8?000P2P8?001@3@D7P0oh000?n0
003oP000j6Pl00L0oh00203oool;003o001>03R]1@1^?1`0McLQ07LZ5P2>GT`0Pg9Y071YI@1aJFh0
HEQP069KH`1_J7@0I6Ml03E8M`0:;7X00bf?008[U001:YP00bjM00L_WP0H;9L0<B5m04/BE01Q54h0
FQ1:048>D00d97P03bnP00De]P07Bm002VKX00Mcl005LNX00f_X00=/j@00J>P00F_/001Yj`02L>h0
0WK_00Enl@0:Q>l04I3`012Jl`0CWoH02icj00JFnP06T?/01h;h04aTd@3I:D`0jR0V0>0K903E;D40
e4YT0<@W@`384b<0`PdH0;d;5P2l31L0]``G0;<;602Q1100VPHC09H6502@1180RP`M08D95`240`X0
UDeA08UPL@2GJWP0SgN20;6Q[02/WZX0YWB407XRAP0L8EH01lP=203oool;003o0003052@N03oP000
oh0000L0oh0000<0^3Rd0:0Pl02P8?00902P8?00103@D7P0oh000?n0003XJ3`20;Ph]0d0oh0000@0
j6Pl0;Ph]03@D7P0^3Rd1@2P8?000`1@T7P0oooo0?ooo`090?ooo`002P3oool0F01460P08`4102H1
0@0X0@40:@8302810P0J0@809`0105X31@1/0`D0JP4506LD5`1b=CX0I`@<07H11@2>1@`0TPD@08P5
302H1P/0XPL<0:P93`2a31D0[a8O0:lF802l51`0La0E0:>NX03?f=X0e=cN0>:ma@33=Sh0jBHV0?DU
903k:RH0oBXV0?/]:@3j<b`0mSPb0?M2>`3hAcl0kdi:0>=[M03PMX00hGR10>MXJP3_GU80l4m20?A<
@03`JF00lJJW0>bUZP3cQh/0lS<g0?//:`3i9bT0lR8Q0>HK6`3M6AX0e1/H0<Xl303SQQh0]1l70;H<
3`2c2a80U1PH0<ni]`35cm00a/k@09n2R@1Q6R40Sg]n0:6]/@2V]K/0[[g30;;3b@2HYZh0<2@_040Q
9P0e4a`0;0HA064:501o0PH0P`0507d2101^0P80H@4304`10P140`490?oooaX0oh0000@0X23`0?n0
003oP000d51h2`3oP0000`3@D7P0X23`0:0Pl0050?n000030=1@N02P8?00d51h00L0oh0000<0d51h
0:0Pl03oP0001P3oP0000`3@D7P0oh000?n000050:0Pl0`0oh00203oool;003o001>02OF1P1^:`P0
QE@h08]YD@25LF80MfQP069ED`1WGV00LF]b05mSM00d@W802B9[00@RO@028hD00RJ>00@USP0>8880
;1]a05LHF@1_64h0HaU@03dQH`0I:8@02bfK00DWW@06=k001Snm00<a]002=;P00TS;009<c`02F=T0
0F;Q009]k003N?800hGc01BKm@0j]OH0KM7e09CPn@2QjOh0R>;l057=nP0^_?T03Z;k00FDo003Qo`0
0g?f021Pg02P:FP0caD[0<T?8P344B@0_0hR0;P<8@2d2al0/0XJ0:`9602Z21D0Z`LE0:P7502H0Pd0
U@@=08L11`250@L0PP4707l11`1l0`X0UDaD0;J9V01n:3d0UdiS0<NN[`2fWJd0^HVH08dM=@0gAR`0
0o43203oool;003o0003052@N03XJ3`0oh0000D0oh0000<0j6Pl0;Ph]02P8?006`2P8?020=1@N003
0;Ph]02P8?00X23`00L0X23`00<0j6Pl0?n0003oP0003`3oP000103XJ3`0X23`0>QX?03@D7P30:0P
l0030?n0003@D7P0:<Pl00/0oooo000:0?ooo`1H04HH2@0X0@40;P4103020P0Z0@40908101l10P0V
0P80D0<706L31P1T0@D0K18H07HU;@1]0`X0O@8:09l@6@2Q3QD0UPL<0:D:3`2/2Q00]@`D0;lA4`36
4a<0c1DC0=8O7@1`8bD0b/_=0=?Ig03Gem`0c7f90=8W:`3[9200mR@R0?/X9@3m;BX0oC8^0?hk<`3n
@ST0oDa30?iEB`3lIUh0nXJ90?ZV[`3l]l@0o9fR0?enL`3mJUX0nV5E0?VSW`3_^;d0jJV_0?>T[@3Y
@DL0nRd^0?HV:P3b92<0j1lO0=TL5@36;PH0gWdF0<5:2`2l40l0^`XD0;H?502eFeX0d/o@0<OCd`3<
cm00OdQ@08eAE02]ZJX0[;^m0:2_/`26V9h0SJ2V096OY@0]7bP0@1`S03T@6@1E4A/0M@D>08L22@25
0@H0O@430781101V0P<0D`4204D30PT0oooo703oP0000`3XJ3`0d51h0?n0000:0?n000040=1@N02P
8?00X23`0;Ph]0<0oh0000@0j6Pl0:0Pl02P8?00X23`1P3oP0000`3@D7P0X23`0;Ph]0060?n000<0
j6Pl00<0d51h0;Ph]02h>;@00`2P8?0<0?n000P0oooo2`00o`00=@0Gk@D0MRh708=I?`25KUX0OViP
07a/I01aH5T0JemU04a?K@0?8f800QQ/008JN0036gX00a1Z018FJ`0d45@0GQ1106@GAP168Eh07bIl
00X/T`07=JD013F^00Dg/P017YX00B2M00Dn`001:[000cJl00EIgP05Lo401h[j00VGo@0;XOd02JKo
01B_o00Y^_T0>[[h03Z_mP0XVo005hg^00V5l`05PoH00WOb009/k001INT00V?V00=If`04D=00:D2Y
05<]OP1A;7P0BBag0080A2Qe01L0?bAb048SK@168VH0C21O05DLEP1K64d0IaU706XG>P1S42`0H@TO
06@54P1T0`T0IP8707843`1g2a/0Q0DA09<65@2D42@0ZTiQ0;5FJP225C005;H?003o00080?ooo`/0
0?l000<0:<Pl0>QX?03oP000103oP0000`3XJ3`0X23`0:0Pl00c0:0Pl0<0d51h00<0j6Pl0?n0003o
P0001P3oP0001@3@D7P0^3Rd0>QX?01@T7P00?l000/0oooo000:0?ooo`1H04`I2P0^0@40=@8203@2
0P0Z0@80;08302@10P0M0P80=@8505000P1I0@80I04507412@1n10`0T``F0:lG7P2`3Q<0/0X?0;@:
402g2Q80_`dD0<PA4`3>5180dA@C0;lL7P1dCE40eM_N0=?Hg03C`<H0/SHm0<XK7P3G6A`0hadN0>`M
703`81l0lb4Q0?DV9@3^8b<0lRTY0?4Y9`3b;Bh0kRdg0>X_?P3X;d80ib`l0>HW<03Y:2`0gbT/0>1n
Q@3HX:`0b8^G0>>JY@2f92d0baPL0<`D703<4AL0aa<B0<@h2`3QSAH0b6`A0;DG302l3a@0^0lD0:PY
:03K`;h0c=;E0<W@d`2iWZL0LQTP0:J9S02FXJT0]L?:0;c8c@2__l<0Z;Vn09:SZ00Y6200Ba<L02d5
3P102Q00LPH>08X22P2?0`X0S0D807T20`1]0P80F`<204P30PT0oooo6@3oP000103XJ3`0oh000>QX
?02h>;@>0?n000030=1@N03XJ3`0oh000080oh0000@0d51h0:0Pl02P8?00X23`1@3oP0000`3@D7P0
X23`0;Ph]0050?n000050>QX?03oP000^3Rd0?n0003@D7P00P2P8?00103@D7P0X23`0:0Pl02P8?0<
0?n000P0oooo3000o`00C@1_Fa40P6=407ARB`1cHe40MVEH06YNFP0b>ET011MK008GJP025FX011IZ
01<@FP0l2d40F0df04X@A00W66803BN500D`VP02;j800RfR004PT`006hd013F^008Z[@02<;/025CN
00=9f@05Bm`026_d00=kn`05P?T00WWg009hm`02N_L00W[e009em001MoH00G7b00=cl`03KN`00VKW
00=Rh`02G=d00ESE009Ee002EM000U3:00=<aP02B;l014>h00@o]004?k0013nb00@k[`04>JX013NY
00@cY@03<Il0136K00D]U`07;9<022V900/WP`0@9Gd06B5/01/BA`0T2Rh0BP`[06@780201Q80S`@>
09d84@2N2180V`hJ06`RB@0DAcD00?l000P0oooo3000o`000`2P8?00d51h0?n000030?n003/0X23`
00@0^3Rd0=1@N03@D7P0j6Pl1@3oP0000`2h>;@0X23`003o000;0?ooo`002P3oool0F01B7`/0=0<2
03<10P0i0P<0<@4202/3100J0@80304102T20`1A0P<0G04106/2101i0`X0P`D=09<8402[3140[`P=
0;483@2d2@l0^0TA0;d;4P313Q80``lB0;h@4`1]2`l0R8R;0<[Ff@3>cmD0Ve9M0:4B602Y3A<0/`dB
0<0>4@3F5QP0eA4D0=`E6P3J51H0hATJ0>DK703V6a/0iQlM0>@Q8@3V92@0ib@W0>DS:03W92L0kBLY
0>HT9P3E>D40i8>B0>66U`3:Ef@0^1LL0;PA502b2a00^0hB0:hM1`3BQQ@0c8TH09DO102J0`T0V@@9
098@4P2cNWP0bm3B0<K?e03=bLl0Od=<08Q1@`35a<@0ZKFj0;O2a`2a_l@0UjN^09BU[@2FXjX0<QTP
03X94@0/1@l0@@XC06h73P1i0@<0O`4408D21P1o0P@0LP4205`10@1=0`490?oooaT0oh0000@0j6Pl
0?n0003@D7P0j6Pl4`3oP000103XJ3`0X23`0:0Pl03XJ3`40?n000040>QX?02P8?00X23`0>QX?0<0
oh0000P0j6Pl0?n0003@D7P0X23`0>QX?03oP000d51h0:0Pl080^3Rd0`2P8?0<0?n000P0oooo3000
o`00C@1VNa00NUlh06]K@01ZFd<0K5Y903XmBP035T/00QIQ008CI@0445`06PU604h:<01G3C@09`i;
00XJL`039H/00RZE004[V@01;:800S2X004[XP01;jD00dO600I9d005@Ll01e[S00MFhP01>/`00e3M
009QjP02HnX00F7Y001NiP02I>T00F;V005Ph`01Gml00UoP009RhP02G]/00UcH009MeP02F<l00UC6
00ADaP08E/<01e6h00U?[00<CJ@03T^L0159U@0HCYH05T^B01I8S`0DB8d054F;0110R00<>hH023J5
00HdQ`04<XH012j7008[R`02:hl00RR<00<RO`0477002aUX02<HF01@53l0N0/T09d=602S2@d0UP/J
04/UHP0C8TT00?l000P0oooo3000o`020:0Pl0@0oh00@02P8?040?n000030:0Pl03@D7P00?l000/0
oooo000:0?ooo`1H05HQ300i0P40>P@403`3100`0P<0804201400@0:0@80;@<405X20`1U0P80K043
0781101j0@H0R@460:P83@2a2@h0/0T=0:d8302^20`0/0P=0;89402^2@l0WP`C03L?4P2]^[`0bM?E
0;fS[@2D6b@0Z`lC0;0?502g3Q<0aQ4E0=<E5`3G51H0h1TH0>HP7@3]8b40lbTS0?</9P3f>2h0lT8e
0?1;A03/CT`0kTe90?54?P3gACh0mClj0?0f=@3T=cl0hcQ30>0/<P3D71d0bQLJ0<<B5@2i3``0`E@<
0=BH4@2S@@H0V``809X32`2A10X0M1@G0<fh^@34cm40aLgA0;bZ/P1L5Ah0OeEK09RW[@2^_<00`Lk@
0<3>d02mbLh0TZ6U09JUZ01]JV`07`L>02<1301@4b00L0D=07L10`1c0080MP4407P20`1g0`@0H@41
058300T0oooo6@3oP0000`3@D7P0oh000:0Pl00L0?n000030=1@N02P8?00X23`00@0oh0000H0d51h
0?n0003@D7P0X23`0?n0003@D7P20:0Pl080oh000`2P8?000`3@D7P0oh000?n000090?n000P0oooo
3000o`00C@11^@T0O5d`06aJ?P1/Fd@0CTE500LE>00365<00Q9G00T=D@0W1cH0A@PW03P<>00E4UT0
1Aeg00<VR@03:YD00BRI008/W`01<JL00cZe00A4`@04AlD00e3C00A:c`04=Kh00T3800A4c@03=/<0
0TC=009HgP02FM`00USJ005Gf@02F]X00U[I009Je`03F]001E[900UJa00@GK`06F6e02EZ]@0`JjT0
>6jO04AaWP1:M9P0EGfK05MoUP1LPi<0HhFF06f=VP1dTil0M9:N07>@W01_SIL0N9FQ07^HY@1hUj80
K8^J05inT@1HNHh0AfR2045TP`0aEgh07TIf018hL@09;G400RAa00@SM00=8Vl0:AmR05hI@@2B3al0
VQ<W03T[K`09FSd00?l000P0oooo3000o`000`1@T7P0X23`0?n000020?n000070;Ph]02P8?00X23`
0:0Pl02h>;@0j6Pl0;Ph]00T0:0Pl0030;Ph]02P8?00X23`00H0X23`0P2h>;@<0:0Pl0030;Ph]03X
J3`0j6Pl0080X23`00<00?l00?ooo`3oool02@3oool000X0oooo05P0H2/>03`50P0d0`80<P@40202
0P0H0P80508100l10@0e1@H0H@<506@10P1Y0P<0L@8507T11P290`P0YP/?0:l@502X3100Y@P:0:D7
2P2X1Pd0[0P?0:@83P1a2`l0A4520<G@dP3?`l/0VDME0:`C6@2h41<0a1DH0<lG6@3M6ad0k2<S0?@Y
9`3i<B/0o3T`0?e1>P3k@Sd0oTm60?mTF@3nQG`0o:VZ0?fka@3mZJ`0oH>00?m_J`3oJF80oeQD0?mD
E03nBT`0o4950?Pi?03_:bl0j2HV0=Dd403RUaL0d7lC0:/M1@2b2`d0Z@D=09@;3`2[KFh0dLg?0<G@
d@3<cM80PEaU05/=5P2?OX00SJ6T09f_/02M[K80Y[Nm0;K4c02R/KT0VJF]05]CG00^31@0;04904H4
301_10X0N`8607<10`1/0@<0H0<306l51`1U0@80E`D12@3oool00`3@D7P0oh000?n0000E0?n00004
0>QX?03oP000X23`0>QX?0d0oh0000@0j6Pl0=1@N02P8?00^3Rd2P3oP0000`3XJ3`0X23`0:0Pl004
0?n000030=1@N03oP000oh000080d51h00<0oh000=1@N02h>;@01@2P8?000`2h>;@0d51h0?n0000:
0?n000P0oooo3000o`00C@0;m`<0KWdN06Q=;P1NDD@031Ha008DAP0355<04P]103`8:@0k22T050a2
00<FI@038X800RN<004VSP01;9X00c:W00<j/@03?;H00T2l00=5a003?Kd00T3100<j_P019ZT00bjc
00I9b`04C</00dg;009@c@03D/X01UC200UD_@0BFKT07f>`039[Z@15M:<0EgnL06:5V01/RiH0L8bA
07J?T`1lTi@0PiVI08fQXP2AXj@0VZf^0:6d/`2W^[P0[Ko00;75a@2kcL`0_Lk@0;c?d02ocm40^<W<
0;O6b@2Y^kh0VK2b08VRYP1jU9T0K8V:06F1P`1NNWl0D71a04EUI`0jG640;E9L02=6G@0C>5l022e[
00`/NP0h:W00L2=F02@^M`0?FcP00?l000P0oooo3000o`001@0Xb3`0X23`0?n0003oP000d51h00<0
X23`0P3@D7PL0:0Pl0030;Ph]03@D7P0d51h0080d51h00@0^3Rd0:0Pl02P8?00^3Rd0P3XJ3`00`3@
D7P0j6Pl0?n000020?n000050>QX?03@D7P0d51h0=1@N02h>;@00P2P8?020?n000040=1@N03oP000
oh000?n00080d51h00<0^3Rd0:0Pl02P8?00102P8?000`00o`00oooo0?ooo`090?ooo`002P3oool0
F01:CPL0@@L202h10@0Q0@404@4101<10@0O0P<06@4102X30`1K20T0H0@508h^<`1b2@l0M08708D2
2P2R2a40Y`hC09l;402S2a00Y@H<0:P7302Z2`l0S`hC03TA4@2MYZL0e<790:Y>F`2g6b40cQXK0=HL
703Q8R40ib8R0?8T9@3j:2@0nR`U0?he;P3l=Bl0nC<]0?/e<03j>cD0nT8k0?A2@03bATh0ldaI0?53
C@3f?T<0mSDh0?Ld=`3b;300k2T/0>TW;P3Q7bT0gB4Z0=XM8P3@:Q40hWdD0>2U5034@0X0c1XD0<PB
503041@0/D920>38b@3;dm<0a]7B0<:b^P1U6280K1dT092AV@2L[kH0]/K:0;K3b02]^l40X[:i09FV
[P1WJgL0:`lL03`?6@141P`0G@D908XY;P1d0PP0LP0206@20P1E2``0KaLH06440`1H2@490?ooo`03
0=1@N03oP000oh0001D0oh0000<0j6Pl0;Ph]03@D7P0403oP0000`3@D7P0j6Pl0?n000090?n00080
X23`00D0d51h0?n0003oP000oh000>QX?0030?n000030;Ph]03oP000oh000080X23`00<0d51h0:0P
l02P8?000P2P8?000`3@D7P0oh000?n0000:0?n000P0oooo3@00o`00C00^c`/0HdDJ02XX:0025CL0
0aE201/>=@0m21d090P]00L?DP026VX00R9m008WR`02:9400R^F008`X@02<jP00C>Y008g[002>K00
0SVc008f[@02=Z`00cVe004WX`019j@01dFi00]>/P0JF:P0<fNS04acWP1LOiT0I8BE06Z6T@1`Rh`0
Ni2A07jBTP23V9H0TJBR09f^[@2a`/00^l[;0<SBe@3:dmP0aLgA0<C6bP2i^Kh0[Jje0:BUZP2MWJ00
TY>D08f<SP28QXT0Q82007mjN@1hMgD0N7Ac07=`K01/KVL0J6aV06=ZIP1IIf00EfAP05ARH@1<HEh0
B69L03mMF00kFU<0>UMA03MED@0`DU<08TAG00deJP0C=hD03S=i00Z]6000o`080?ooo`d00?l000P0
D91h0:0Pl03oP000^3Rd0:0Pl02h>;@0oh000;Ph]1L0X23`103@D7P00`3XJ3`0oh000>QX?0020?n0
00<0j6Pl0`3@D7P20>QX?0P0d51h3P3oP0001P3@D7P0X23`0:0Pl02P8?00D91h003o00/0oooo000:
0?ooo`1H04Mo2@173080;04102@10@0V0P809`4103020P0T0@406`4204<20P1/0`H0OP@;07P22@1_
0@H0QP@;0:4<4P2Z3a@0ZP`C0:P73P2[1Pd0/`/?0:h=4P1k1P/0W75d0=W?d032Hfd0aahU0<dE5`3D
61X0eAPK0=LG6@3P6AX0l1lN0?TW8@3k:R<0nRhW0?Y4@03i>c40o4@f0?Y8>03hE480mfYH0?=cJ@3d
N7<0mWE]0?]TF@3iD4@0oDe30?]7?`3i?c/0m3Dd0?0_;P3Z9RD0eS4@0>F26`3QZA<0dG4?0<4H2P31
3A00_``B0:`F6@3AXj40cm7C0<_Be03>dMH0W6Md07XA6@2PJF/0W:V`09>V[@2K[k@0TJ>X09VZ/@2J
Zk<0XK:j09NIX@1J>480=@dG03/42`1[2@l0Q`T?0843201c0@<0G`8305420`1L10@0F0D105HP0`T0
oooo00<0Z8Pl0?n0003oP000503oP0000`3@D7P0j6Pl0>QX?00K0?n000040>QX?02P8?00X23`0:0P
l0L0oh0000@0^3Rd0=1@N03oP000oh00202P8?0;0?n000030>QX?03oool0oooo00H0oooo3@00o`00
C00;m`<0NEDU01@J80025C@05@TU03T96P0E1R<011AE008MLP0297l00bJ5008UR@04:9<00BN@004X
UP02:9T00RbM008dX`01=:H00cNZ00<k[P03>ZT023fS01]2TP0dDh/0C6j?06B2TP1_R8`0MH^=07N<
S@1kTI00QibI09BWY02/_KT0_L_:0<3;c@2oaLT0]KVo0:b//@2PVZ40SXR=08=jN01mM6l0NW5X07]^
H@1kK5X0NfeI07a]EP1fID`0LfI:07=XC@1`IT`0MFYA07E[E01cJeD0LFQA075WC@1^I4X0LVI<079Y
C`1`IT/0L6I=06aUC01ZHTH0IF9605aPA`1CGDL0CE];049FBP0kED`0>UQ=02Y9A00F?E004CY300?b
0`00o`080?ooo`d00?l000L0:<Pl0:0Pl03oP000^3Rd0>QX?03oP000j6Pl01<0X23`0P3@D7P30>QX
?0@0oh0000@0j6Pl0=1@N03@D7P0oh000P3@D7P00`3XJ3`0oh000?n000030?n000040>QX?03oP000
d51h0=1@N0T0oh0000<0j6Pl0?n0003XJ3`00`3@D7P60?n000040=1@N02h>;@0:<Pl003o00/0oooo
000:0?ooo`1H03>k2@123@40;@4102T10P0_0@40A0D304d7200`0P<05@4103H20`1/0`P0O04607`2
1`1d0@L0R`H<0:H=4P2X2Q00ZPT@0:l:3P2c20h0^``B0:d83@2B51P0bYVM0<fLY02j7bX0c14G0<`A
4P3G5AL0gQPJ0>HJ7@3`81h0oBhS0?hg:P3o>bl0ncXa0?mDD03lCdH0of9D0?mcH@3oTh<0ol[50?oW
k03ok?H0on7U0?nXYP3oO7@0ofeP0?m[GP3oEdl0oTM40?m5@P3l>c40lFhM0>N/703U[Q/0dD<90=XJ
603@4aD0ca@H0;]2@`3Ld=00bm7D0<WAd`3Ab]00NbHb07P?5P2[SI<0YkO00;;2a`2mc<h0^<O70;2n
`02FYZh0NhjG061WM@0[5B@0C3Q104h[<P1R1Ph0T@H<08T31`1i0PD0F@8204l20`1A0@80D0T3041?
0PT0oooo00<0D91h0?n0003oP000503oP0000`3@D7P0X23`0?n0000K0?n000<0X23`00<0d51h0?n0
003oP0001@3oP000102P8?00oh000?n0003@D7P20:0Pl080oh000`2P8?000`3@D7P0oh000?n00009
0?n000030=1@N03oool0oooo00H0oooo3P00o`00B`1CVQL07A`D00d>7`0a1aD04PLO008A@`037F/0
0B5o004RQ0027h000R:6008RS@018XX00B>:008TSP02:ID00S2L00<fVP0;?Y@09E:D04EZTP1SOY40
MX^A0765QP1gRXX0Q9NG09RYZ@2Z^K/0[;bo0:Re^P2T[;00X::U08^8R01kM700MFaR07M[G@1fJUT0
NG1K07]bGP1eKEP0L6]C06e[DP1[J4d0JFI;06UUBP1ZITT0JVI806EQ@P1UHT<0Hf5306=QA01SH4D0
I6=<06IWDP1WIeH0IfQD06EUC`1UJ540I6QB069TC`1NH4X0GF5905aJ?@1IEcH0F5Dc05YF=01HECP0
DeLo051GA013ED<0=Dho02Q8>@0TFb`00o<2003o00080?ooo`h00?l000D0X23`0?n0003oP000oh00
0>QX?00A0:0Pl00<0=1@N03oP000oh000>QX?03oP000d51h0;Ph]03@D7P0oh000>QX?03@D7P0j6Pl
0`3oP0001@3@D7P0j6Pl0?n0003oP000j6Pl00@0oh0000@0^3Rd0=1@N02h>;@0d51h3@3oP0020=1@
N0030;Ph]03oP000oh0000@0oh0000<0j6Pl02S8?000o`002`3oool000X0oooo05P02_H305@P1P0a
0P40<@8204@5101K20L0E@L902h20P0>0@40;04306/41`200PL0P0@707@21@2>1@/0Y@P=0:/73@2Z
1P`0Z`D;0;062@2f1PX0/@X>0:@c=@3X/[P0_TQA0=HL803K6a/0gA/K0>4K6`3Z81h0lR<O0?`[903n
=BL0oSXZ0?`h;P3i=2l0oTDo0?Hi=@3lAT40ne1;0?UHEP3fJ6l0mGF30?MkS@3dL7T0n5mT0?eBEP3k
BDP0oDY50?i1?P3m>cT0ncHe0>hm7P3_W2<0hK@I0=^B6@3?:0h0faXL0=HF6@3>71l0dhF70=7Be@3;
dmD0bM7C0;nQZ@256280UdQ:0;:Z[`2KZk<0WZjf0:Bb^P2a_<00]lC60:Rg^`2`_l<0LW9j02X@6P0h
8bl0@1hY05/630291@`0P@8507P51`1G20T0C0D604P20@1C40H0?U412@3oool00`0Xb3`0j6Pl0?n0
000D0?n000030:0Pl03XJ3`0oh0000l0oh000P3@D7P00`2h>;@0d51h0>QX?0060?n000050>QX?02P
8?00X23`0:0Pl03XJ3`00`3oP0001@3XJ3`0oh000?n0003oP000^3Rd0080oh001@2P8?001P3XJ3`0
X23`0:0Pl03@D7P0oh000>QX?0T0oh0000<0d51h0?ooo`3oool01P3oool?003o001:04Do3`0S3A00
6`TG00<B=@0375h00Qie008QO`028X@00Aan008IO@016h<00R6:004SR0039hH0236302I>R@18JhT0
JhFA07V>TP20TYD0PiFD09FWY02S]K@0Y;>f09bTY`28RhX0LW1]06UTE`1YIU80KVMC06]PB@1XGcl0
K6I606UPA01/I4T0KFY>06e]C@1cL5<0K6a?06e]D01/IT/0J69106MTA@1UHTD0J6A606UTB01XI4D0
IF=406ASA@1SH4D0HUe305eM@@1OGT80IVE=069UC01SITd0I6MA06AWE@1TJ5H0HFEB05iSD01LH4X0
FEe305MK?P1GFSh0EU]204UC?`18DCd0?dTc049C>`0hCc/0;DPc01Fi4@00o`080?ooo`l00?l000@0
d51h0?n0003oP000d51h3@2P8?020;Ph]00:0:0Pl03oP000oh000?n0002h>;@0oh000=1@N03XJ3`0
oh000>QX?080oh0000H0^3Rd0:0Pl03oP000oh000>QX?02P8?030;Ph]0060?n0002P8?00X23`0=1@
N02P8?00j6Pl0`2h>;@G0?n0000306RX?000o`00oooo00X0oooo000:0?ooo`1H003o001>J0h0>PT2
03/40@1J2PL0H@X904H51P0Q0@802@4101l10P1U1@X0PP<907T31@1Z0@<0Q`870:452@2X0`P0Z`@9
0:h5302c1Pd0_P/?0;PE603ZPHT0aeAM0<HG6P3>5AL0cQDH0<hE6@3>4QP0fAHJ0>XL6P3j9Ql0oRhR
0?d^8P3h9b<0hQdL0>L];P3G7Ah0lc@b0?/h<03m?CD0oCdf0?Xk=@3n@S/0oClh0?`j<@3k;BT0o2l/
0?db:P3m;bT0o2hW0?H`7`3VKAL0fZX>0=2Q2P2mE`h0^Q@@0;l>5@2k3180ZB<T0=[2``38d]@0aM;B
0<W?dP2JGFL0Pa`R0<2OX`2/^Kl0`]7G0<gJg@2jaLP0^/K80;[4a`2[^;`0YK:e06iXK@0k5ad0<0D=
04P43@1X1P`0O0@:07@21@1S1`T0NTA703h4101I1`@0E0l102b>00T0oooo00<00?l00=1@N03oP000
4`3oP0000`2P8?00j6Pl0?n0000K0?n000040;Ph]02P8?00X23`0;Ph]0@0oh0000H0j6Pl0?n0003o
P000j6Pl0=1@N03oP0020:0Pl0050;Ph]03oP000d51h0=1@N02h>;@00P2P8?000`3@D7P0oh000?n0
00090?n000030830003oool0oooo00H0oooo3`00o`00BP0c/0T0<aL900XD90026dP00R9_00<TO@02
8X000Qj0008NP`027Gl00B62008TOP0E>7`0@5n306^5T01kSi00QIZF08RKVP2P/Jl0XJfa09RPXP23
QXH0LgA`079]I01eKf40MW1J07E^EP1aKED0LW5H075^E`1dKeL0LFeD075`F01aKUT0LFmI06m^EP1^
Ke<0KFmF06][D@1UI4L0J69506MQ?P1TGcd0H5do065M?P1SG3l0IF1206=Q@@1PH3h0H612061P@`1P
Gd00H611065QA@1QHDX0HfE>069SC@1QHdd0H6I?05iTC01KHd/0FF5905]OBP1GG4H0EEY205=I@@1>
GD/0<TDh02/o;@10CcT0Ae<l03e>>00YLb800?l0203oool?003o000307QH]03oP000oh0000/0X23`
00<0^3Rd0>QX?03oP0000P3XJ3`00`2P8?00j6Pl0=1@N0060?n000040=1@N03oP000j6Pl0=1@N0@0
oh0000D0X23`0>QX?03@D7P0d51h0?n000020:0Pl0080?n0003@D7P0oh000>QX?02P8?00^3Rd0=1@
N03XJ3`20=1@N0030>QX?03oP000oh000100oh0000<0d51h003o003oool02P3oool000X0oooo05P0
0?l0041o200o1`40CPL4060<2@1H2PP0<P4101`00@0<0@004P4104L11@1[0P@0I`8206810@1o00<0
XPD:0:X42@2`1P/0/`L:0;P:3@2k2Ph0_Q`S0<4c>`2f4aX0`0hB0;l=4P2o3QD0_PhE0<<>5@3I5QT0
k1dK0?XX8`3l;280oB/T0?X[9@3R;bd0iFAW0<PL7`3d;bl0o3@/0?`i;03l>2/0ncHZ0?Xf:`3k=bh0
oCL[0?`^9@3l<BP0o38W0?X[8P3h:A`0jC<>0?J]:P3H/Pd0eY`E0:/[0`2a20/0[@H>0:06302P@d@0
c/g?0<7>d@2ocm00c<oB07d`>P22<3H0XibR08^QZ@2/`<T0c=gT0<cJh@3;em`0e=gR0<_Hg02e`L@0
QWYn05`b>@101Pd0J`XC08PB6@222a40K@4405T31@1G5AT0H0L706P60`1H4P<0;i402@3oool00`00
o`00d51h0?n0000`0?n000050=1@N02P8?00X23`0:0Pl03@D7P01`3oP0000`3@D7P0oh000?n00003
0:0Pl080oh0000D0d51h0?n0003oP000X23`0=1@N00;0?n000030830003oool0oooo00H0oooo4000
o`00B@13B0h02AXb008OF`028g800REm00<VQ@028h@00R6400<QN00M?GP0E768086DU`2@Wil0TZBS
09f_[@2GY:H0QHj=071`K01XHe/0O7]^09BCQP2XZ:@0a/?30<6m`@2_[K00XJ6O08jARP29Rgl0RHUk
08J6M@22Pfl0OGm/07YiK01eNFT0KWES06idHP1]Lf80Jg=R06U_G01UJeL0H6E=05iQA`1PHTP0Gf15
05eOA@1LH4D0FF1405EL?P1IGD00FEa405aNA01KG4@0Fei905YOC01KHU00GV=?05eRB@1KHdX0G6E=
061WDP1MHT`0Ff1:05MLA`1@ED40DUa9045CA@0^A3D0?e=004iOCP1@HU00D5Q103m8:P00o`00203o
ool@003o0080d51h2@2P8?001`3@D7P0X23`0>QX?03oP000^3Rd0=1@N03XJ3`00`3oP0000`3XJ3`0
oh000=1@N0020=1@N0040>QX?03oP000oh000?n00080j6Pl2@3oP0000`3XJ3`0oh000?n000020?n0
0080d51h00<0j6Pl0?n0003oP0005@3oP0000`00o`00oooo0?ooo`090?ooo`002P3oool0F000o`00
=9T604D90@1D30L0D@T504@71@0Z00008@4101<10@0?0P40:`4204l21@1G0P<0I04508011@2R1@X0
[PL;0:l9302`2``0/`T<0;@9302a2`l0[`XA0;D:3`2l3A00`0hA0<8>4P3:4a@0fATH0>XU8@3_:R40
l30V0>lf;@3/?C<0iShf0=eVI03PX:D0aU9@0=A<@P3BCT<0cU=60<]CA@3<ETL0c5M80<MCA03:EdH0
ae520<Q@@`38C3h0c4Tj0=58=P3:FBl0eJ]10=2b=03@TC00^3@E0;hO702T4A80Ta8D0:mcM037c]40
`<oB0<GBe@36`LH0KAPP080oA02c^;`0W[>i0<7BfP34eMd0_loF0<[FgP3:fN<0a=KP0<??e`29MGl0
EQ0I05h73@1W10X0PPP>08L42@1/0@80EP4206892`1j2PL0J0P205HE0@0[XP490?ooo`03003o001X
Z3`0oh000240oh0000<0X23`0?n0003oP000303oP0001@3@D7P0X23`0:0Pl02P8?00d51h00<0oh00
0P3XJ3`20?n000030=1@N03oP000oh000080X23`0P2h>;@01P2P8?00d51h0;Ph]02h>;@0X23`0=1@
N0/0oh0000<0J:Pl0?ooo`3oool01P3oool@003o001903b73P0?73400R5Q00@/PP019h800bf@008V
PP0A<G@0BfAo082@U@2BX9l0V:FU09>OX021RHP0J6eV06MSE01/I4`0KfE:07MaEP1dLE/0N7AW07ej
M02GTI@0VY>I08V4QP21OW/0NWY_07YjK01iNVT0MGUT075dH`1`M6@0KWEW071iJ`1bO6h0MH=f06mn
LP1TN6h0GgE/05Y^I`1@If00Bf9G04aOE@1>HEH0BemF04UME@19GeH0AU]?04QKC`18FU00B5]?04IH
C@18FE@0BemI04mSFP1FHeD0GfEG06I/G01RKE/0HfiM06M^GP1KI540DUa8051IAP1:FTh0=Ta003aD
@@1@I5@0EVMI05U/H@1KIe@0>fhV003o00080?oooa000?l000<0T71h0=1@N02P8?001P2P8?001@3@
D7P0^3Rd0;Ph]02h>;@0d51h00@0oh0000@0^3Rd0>QX?03oP000j6Pl103@D7P]0?n000030=1@N000
o`00oooo00X0oooo000:0?ooo`1H003o000XaPL0Ca@004H:100c0P40;@4202/10@0Z0P808@810181
0@0J0@00BQhO07Lo@P1V0`T0P@4609d62`2/3100]1<B0;@A402e3Pl0^`h=0;d@3`3051@0a1/G0<HV
7P31<2P0`3de0;e9?@33GE00_fiM0;MfI@2dOW00/8Mj0:j>P@2ZThT0X9NA09VLV`2ETh`0UY6709>A
R02>SXL0S8b308^<P`27RH00QXZ008F9O`23RH40PHIl0824N@23Q7P0PX9b07inKP1jOVX0N7iS07ih
G`27LV40QfQI07iNC`1jFTh0QGYf096JW@2KZ:/0YK6e0:>GVP1j8B80WgAh0:bk`P2/`Ld0]LSD0<CF
h03<fnH0d]kX0<kKi@3<g>D0c=GP0617E@1X3aH0Q1HG08H?4P2U4AD0X0P;07h3101T0@40I@830785
0`1V3`<0GAd101_<00T0oooo00<00?l0052@N03oP0002@3oP0000`3XJ3`0oh000?n0000>0?n00003
0>QX?03oP000oh0000@0oh0000<0d51h0?n0003oP0003@3oP0030=1@N0@0oh0000L0j6Pl0=1@N03X
J3`0d51h0;Ph]03oP000j6Pl00<0X23`00<0^3Rd0:0Pl02P8?000P2h>;@00`2P8?00j6Pl0?n0000:
0?n00003052@N03oool0oooo00H0oooo4000o`00B@0RePX0:BHQ008QG005>iX013NK00HdR00ZAg00
IgMo086>RP25THl0OXZ706]bK01THe80KfQ?06i/D01^Je00KfU?071XB`1aJDP0KFE206mS@`1eJ4P0
NF]@07m`E`20Le/0OWEL07YdG01jLe/0Lg5H075cF`1^Lel0Ig5U05a/I@1;HUd0?5MD035>C00bD4`0
<E9=03YIE00hEE40;D]702U6@@0X@cd09Clj02@m>@0P>SH07CXf01dl>00T?SX0<T@k03Y9?00cASP0
7cXd01Pf<P0hDDH0Cei>061[G@1NIeP0GfQH061YE`1RJUT0F69A04mOCP19Fe00?eI904]QD`1GJU/0
GFaR05i]HP1KJel0GfMD02ZY6000o`00203oool@003o0003052@N03oP000X23`00@0X23`00@0d51h
0?n0003oP000j6Pl0P3oP0001@3@D7P0j6Pl0=1@N03oP000^3Rd0080X23`0P2h>;@60=1@N0030?n0
003XJ3`0oh0002P0oh0000<0T71h003o003oool02P3oool000X0oooo00T00?l000_g101KB`H0?`/1
02`20P0/0@80<`4202l10P0`0P400P0Q0@80C@1H;C00PTQ=06l62P230`L0Y@h@0<8R8`33:RP0_R/W
0;DZ9@2]<RT0Wd<h09YCB@2FHeT0SgY^08f:P02BU8X0UibC0:6YW`2W/jT0]L:i0;K0^@30al40_/Bo
0;Bm^02ha<40]lC30;W3`030alD0_<G40;c3a@2naLH0_lS70;_6a@2h`/40];no0:fj^P2W]KH0YKJb
09RXY02CXil0RibH08>FU01jSXT0MH^407>7P01_Pg/0JWeg06aoN@1[O7H0JGYc06IhM@1SMW00J7=Y
07=ZG@1`Lg40NhZA08NGX02HZkH0/<GA0;W?fP2gc=L0`=?M0;oBgP35d]`0S7En05/O902cQHP0N20V
0:@?4`2/3@h0U0H807d20`1_0P40J@D206@H0`1_;`808=0100T0oooo00<00?l002S8?03@D7P0903o
P0000`3XJ3`0d51h0=1@N00:0?n000030>QX?03oP000oh0000X0oh0000<0j6Pl0=1@N03@D7P01`2P
8?000`2h>;@0oh000=1@N0080?n000030=1@N01@T7P0oooo00L0oooo4@00o`00B01?NQd042I=00M5
Y008>hl0<dUV05eSH@1eN7D0K7=_061TF01SHTX0LVQ;06eTA@1_Id`0KFU@06YVBP1_Jdd0KfU9079W
A`1iJd`0N6U607EW@P1eIT@0LFA007=TA@1hJTl0MF]C06]XE01SJ5H0IVaN05e/HP0oDdl06cLd031?
B01XPg/0XKB^0<KAd03<d]@0/[Fb096@R@1eMfT0L71L06e[E`1_J5H0JfIA06a[E01ZJU/0HfIG061T
D`1UIU80I6=@065RCP1BFDD0A5=203E8>01@Gdl0GfUL05aUE01OI500H6=>05aQD@1DGe<0BeiG051T
G@1MLFL0I7E[06MeK@1TM6`0HW=Y061]H01RHTD06=@8003o00P0oooo4@00o`020;Ph]080X23`00<0
^3Rd0?n0003oP0000P3oP0001`3XJ3`0^3Rd0:0Pl03XJ3`0oh000=1@N02h>;@01`2P8?000`2h>;@0
j6Pl0?n0000:0?n000030=1@N03XJ3`0oh000080oh0000@0j6Pl0?n0003XJ3`0j6Pl0`3oP0000`3X
J3`0oh000?n0000B0?n000030=1@N01@T7P00?l000/0oooo000:0?ooo`800?l005H0C[<D04@B000h
1@<0?P@304<3100g0@40>P8202X10@0S0@40D0lC08LU:P211P/0S@P>0;0K702a:bX0XD5009=AC028
HEL0P7=X07YoMP1hPgd0MhV107N>R@1kUI80PYVG08nRX@2O[jh0[kjn0;G5a034dM80dMcP0=[RiP3Q
in`0hn[b0=gSj`3Oh^/0fMcT0=CEh03>cMT0c/oI0<k?f03;c=P0alOD0<W8e@3;bmH0b/_F0<oAe`3G
f=/0gMkO0=_Nh@3Hg^40dMWI0<WBdP2jb<H0X;6_08jPWP20U940MH^506b2O@1UOGX0H7Ye061iLP1S
NG00H7A`05icL01NLfh0GFm^069bN01cQXh0Vjji0<3FhP2[`/l0Yko=09ZR[`0l3a`0Tf=b06X@6`2T
5a`0[Q8C09`71`2;0`H0N`8206d80@1T8040PD@4003o00T0oooo0P00o`000`2P8?00oh000?n0000F
0?n00080d51h2@3oP00;0:0Pl0L0oh000P3@D7P;0?n000030=1@N02P8?00X23`00@0X23`00<0oh00
0=1@N03oP0001`3oP0000`2P8?000?l00?ooo`070?oooa400?l004P04^`604Tm=00H@Gh0<4AL05II
D01RI5H0GV1A069NA@1[HSd0KVE3079WB@1ZI4H0JfU;06mZC@1ZIDL0L6a<06mVA01^HS/0JVA206iV
A`1_ID<0LFA106mS?01bId40L6I606aUBP1VIe<0G6=E03a<A@0I=S00?U]E082ES`2DXIh0SYBA08b9
R02?R8@0UXZ008EgIP1oLEH0O6mA06mR@P1_HSh0NVQ0089Y?`24K480PVi<07m[C@1kJd`0Ofi@07a`
F01bJU40LVY?06eXC01TITl0Ef1@069UE@1RIU40H6MC05mXG@1LKFP0GW9_069hL@1^OW/0LX9o06j0
N01`P7/0K7]f06QdK@1VJ5P0KFX^01;]1P00o`080?oooa400?l000@0:<Pl0=1@N02P8?00^3Rd0`3o
P000203XJ3`0X23`0:0Pl02P8?00d51h0;Ph]03@D7P0^3Rd2P2P8?000`3XJ3`0oh000?n000050?n0
00050>QX?03@D7P0d51h0=1@N03oP0000P2h>;@00`3@D7P0^3Rd0:0Pl0040:0Pl0030;Ph]03@D7P0
d51h00<0d51h403oP0000`2P8?00:<Pl003o000;0?ooo`002P3oool3003o001E05Dc2@141`80GP`8
06091`1;0P80B08303P3100b0`H0EPL<08H@4`1f4A40MR@U07lm?01nFeD0Mg9[075jLP1cP7T0MHEo
07N9P`1gRH@0MXZ607f?S020TY40P9BB08NHU`27TiH0R96E08VAT`27SXl0OhF607^0OP1nP800M7Mi
079eMP1dLg<0LW9c079bLP1cLFd0MWA_07MbK`1fM740LW9^07QgM01mO7T0OGYg07mnNP1kNWD0OGag
07ioO028QXD0YJBT0;nl`@33a<P0/[Nj0:2QW`2OWYT0XJ6K09NPV@2CWYX0S9^I08BHUP1jT8`0K8F0
06=mM`1QNg@0GGIa05ifL@1NMG00G7=a06MlP`23Uj80TjRg06=VM@0i3AP0G1DR07`@6@2T7Al0YPl?
09h<2`2;10@0P`H407H;0P1];P80<[d3003o00090?ooo`<00?l000<0d51h0?n0003oP0005@3oP00=
0=1@N0d0oh0000D0j6Pl0=1@N03@D7P0^3Rd0>QX?0050?n000030>QX?03oP000oh0000H0oh0000@0
d51h0;Ph]02P8?00d51h2@3oP0000`3@D7P0X23`003o00080?oooa800?l004D0>:LC044l<P1ACSX0
GEa505aO@01IFCP0GUL`06EH:`1WGS@0K64k06mVA01]J4`0K6Q>06US@P1]IdD0L6I407=XA01bId@0
MFU707EYBP1]HdD0K6A206eT?P1WH3d0KfQ9059G@P1:Ed`0K7eh04aRF01[M6T0M7=U07MdH`1hM600
Kg9N09:GR@2HVX`0O7e_06A]I018FED0;TDm02m6=01EFcl0N6e<07AWAP1eLEP0I6]H05QTE01GI5L0
FVQK05MTEP1OHTh0MW9K079_FP1/KUh0IFeL06]jK`1cQ7d0N8Z807R<R`23UI@0OiBA082AT01nTHd0
N8j907B6Q@1]NWH0I6QI06]/<`0Jh`P00P00o`080?oooa800?l000H0T71h0?n0003oP000oh000>QX
?03@D7P50:0Pl0030>QX?03oP000X23`00/0X23`403oP000103XJ3`0X23`0:0Pl03XJ3`60?n00003
0>QX?03oP000oh0000d0oh0000@0^3Rd02S8?000o`000?l02`3oool000X0oooo0`00o`00D`14GPH0
C``3070B301a4@`0HPX705l9201;20L0=0L703XD4@1H=c00HEaC065[H`1VMW40Kh1l07B7P01hRXL0
NHV707N6P01gPGX0LgUc07=eKP1aLFD0KfmQ071`H01bLV40N7AV07]gI`1oNfL0O7MT07MfHP1dMV40
LgIT07IgIP1gMF40M79O07AdH`1eMVD0MWES07IhI@1kNVX0O7]Z07QkIP1hNVT0MW]/07MmKP1oPG<0
Q8Ih08F9O02@Th/0V9^H0:2TY`2ZZK00XjBZ08:7QP1gO6h0MWMV07YiI@1lNVL0P7QX081hJP1oNFd0
Qh9e092?P`2>THD0S9>908JDSP1jSXX0KXJ1069kM`1OMgH0GWEe05E[J`1CGE`0BCdi05@R9P1g4AH0
TA@F0:dj>P2N5QD0S`T608d<1`1i40<0De4200800?l02@3oool3003o00030=1@N03oP000oh0002l0
oh000P2P8?000`2h>;@0j6Pl0?n0000K0?n000030=1@N000o`000?l000P0oooo4P00o`00A00a[PD0
F48N06=G>@1RG3h0ADX^04]C=`1GE2h0IELV06UI:@1WF2L0K5``071S>`1aJTL0KFQ506iXB01`JT`0
L6U:06eR?`1]GSD0KV0e07EU?01dHST0LF8d079U=`1fJDD0FUTm07alJP1gMFP0JVeJ07=eH`1iMF80
IFaN04EGC`12ET`0@E5803M;A00eB4D0;49102Q3@00gDDL0F6UK071`F@1fKe@0N7e[07F3N@1TNW40
Fg1V05i/H`1GIEP0H6UH07EfH@1jO6X0PhUm08^GS`2HYZ80WZf]0:>`/@2KZJX0TJ2Q09:QX@2?X9l0
T:2Q08RHV01nSh`0M85k06e]G`1eL3@0<MD@0`00o`080?oooa800?l000<0D91h0>QX?03oP0000`3o
P0000`2h>;@0X23`0:0Pl00@0:0Pl0030>QX?03oP000oh0000d0oh0000<0j6Pl0;Ph]03oP0002P3o
P000103XJ3`0^3Rd0:0Pl02P8?020;Ph]0030=1@N02P8?00d51h00<0oh0000<0^3Rd052@N000o`00
0P00o`0;0?ooo`002P3oool3003o001C04J2201F4@<0KQ<;06/A2P1N30P0B`d604PV7@15@3T0C5UA
05AXG`1QLf`0J7Ye06^0N`1/P7/0J7I`06MbI`1YL5l0Kg1K07=`FP1iMF00O7IP07efH@1lN640NgYQ
07UgH@1kMV80NgEQ07YcG`1jMF40MgEP07IgH01fMUl0MgEN07IdG`1fLel0N7ER07MfHP1hNF@0M7MV
075gJ01`MfP0LWY[07YlK@20Ofl0QhId08J5L`1mOfh0O81_07UmL@1eNW00Mg]a07amM@1oOG@0PX5]
081kIP20O6H0NgUT07AbG@1`KEP0L6eF06eXD@1bKEL0OGIR07mgHP1nM5h0PWIP08AlJ`29QWP0RHYn
08:<QP1gRhL0IWil05]dL`1GJfT0E5iK05A2?01/9RH0TalU09dA3`2A2P@0VAD:07<B1@0fL@000P00
o`090?ooo`<00?l000<0Z8Pl0?n0003oP0003P3oP0000`3@D7P0oh000?n000020?n000030>QX?02P
8?00j6Pl00D0oh0000<0j6Pl0?n0003oP000503oP0030=1@N0030>QX?03oP000oh0000H0oh0000<0
d51h0?n0003oP0003P3oP0000`2XR3`00?l0003o00080?oooa800?l003L0EWT906QE:@1YFcX0?d<[
02<i9`0`ACD0D5]705UI>01QFc<0I5hf06UP?01ZH3/0Jf8l06iV@P1aK4`0M6iD07A^D`1fL5<0MfmC
075XB@1cJdX0LVQ5071W@01aJdH0M6i@07A[BP1`H3/0L60h071^D`1mO6P0OgaX04eJC@0jDDP0>E58
04UOE01mSXL0b<g?0;fm``27RX<0N7MQ075aFP1KHU00Hg1R08RGSP2Y];80SIbJ06moN01aNW40P8Qg
09fST@2e_K<0a/k:0<K>c@31b/X0`<W<0080^lC600X0]/320:fh^`2/]kT0XJn`09>QXP2:V9T0NWmj
07I/DP1[Tbd02oL41000o`080?oooa800?l00P2P8?000`2h>;@0oh000?n000020?n000030;Ph]02P
8?00X23`00D0X23`00D0oh000=1@N02P8?00X23`0=1@N0080:0Pl0030=1@N03oP000oh0000D0oh00
00D0d51h0;Ph]03XJ3`0d51h0>QX?0040?n000030=1@N03oP000oh000080j6Pl103oP000102h>;@0
d51h0=1@N03@D7P50:0Pl0040?n0003XJ3`0X23`02S8?0@00?l02`3oool000X0oooo0`00o`00D`14
Y`d0EQ@206dF2`1X4`X0Ea8:04D_7`1=Dd<0DEaC051SF`1HKVH0IGUa06EfK`1NKF40Hf]K06mdG@1d
N5l0MWQM07UdF`1jM5h0NGEM07egG`1jMEh0NWIN07]fGP1lNF40N7IN07UdH@1kMF80NWAP07YhH01g
ME`0MWEK07MfGP1fM5h0NgIR07]hI@1dM640K75O075hJP1^MfL0L7MV07MjJ`1hNf/0MWUV07UkJ@1f
MfH0LWMS071dH@1cM6L0MGEW081oK@23OF/0P7UT089iG@27Med0Q7AK08QkH@22N600LfaE07=ZDP1a
JE80MVmH07A`G@1kNFD0MWAN07UdF`1lME/0OGEN07acFP1mM5d0Pgi^08:6O@1jRXH0HgQh05E^KP1C
JF<0F5MB06HV8P2?5Q80R`P309LI3P1P40@09hX100800?l02@3oool3003o0003052@N03oP000oh00
00`0oh000P2P8?000`3@D7P0oh000?n000020?n000040=1@N03oP000d51h0=1@N0@0oh0000<0d51h
0:0Pl03oP000503oP0001@2P8?00d51h0?n0002P8?00d51h00P0oh0000<0X23`0?n0003oP0003@3o
P0000`20`0000?l0003o00080?oooa800?l00440G80<075O;P1CDcD0>Tdk0358=`0`AcL0=4Pi04YH
A01LHT`0HVE>06AUCP1XJDl0K6U>06iYC`1`Je80M6iH07=_E01`JTX0M6Y<07E[C@1cKU00MG9D07Mf
E`1iMUT0N7AK07YaE`1nL580OFi807I[A`1hL580OgIL089iF`2@PEd0SgeJ099oG@2?NEP0RG=I08Ij
H`22NEd0NVa807IaE01UJeD0NgYS09^BP02^Yj40][>_0<c:``3Vin40mOSa0?;el`3Xjnd0h>CX0=SN
h@3Ign40g^?U0=SOh@3Bf]h0`/_@0;:l`02X/kH0WZ^/08ZDTP1kN6L0MX4k03?F5006003o00P0oooo
4P00o`020:0Pl0030=1@N03oP000oh0000L0oh0000D0d51h0>QX?03XJ3`0oh000=1@N0070:0Pl003
0=1@N03XJ3`0X23`00<0X23`00<0d51h0:0Pl02P8?000`2P8?020=1@N0040;Ph]02P8?00^3Rd0>QX
?080d51h00<0j6Pl0?n0003oP0002@3oP0000`3@D7P0^3Rd0:0Pl0020:0Pl0040=1@N03XJ3`0^3Rd
052@N0H00?l02`3oool000X0oooo0`00o`005P0Cj`@0I24406`I3P1N6a00Dc4S04Y@>`1<FdX0E69F
05e]HP1OKf80HfeJ06U^F@1aLe`0NWIL07UfFP1iMed0NWUP07eiHP1mNF40NgMO081fG`20N60207Yf
G00E07IcF`1hMUd0OGQS07ehH`1iMed0OGUQ07agH01hM5h0MgEO07IdH01cMF40KgES06]bH@1YLF40
L7EW06edHP1bMfH0MgUY07EgI`1eMVH0LWIT0080KWAR02@0LGAS07AdI01iMF40NG=M07E[DP1eK500
MFmA07YaE`1jLUX0N6mD07I[C01jL5D0LFU?079[D01cKED0N7EP07YgH@1fLe/0N7AN07YcG01kM5h0
LW1D07IcEP1kL5D0OG1I07adH@1kOG80Kh1k061gM01HKVT0FUaF06DX8P256Q@0Qa`@04d<0@0UR`42
003o00T0oooo0`00o`000`0Xb3`0j6Pl0?n000080?n00080d51h00D0^3Rd0:0Pl02P8?00X23`0>QX
?0020=1@N0060>QX?03@D7P0^3Rd0:0Pl03oP000d51h0P3oP0000`2h>;@0d51h0>QX?00E0?n00004
0;Ph]02P8?00^3Rd0?n00080^3Rd00<0d51h0?n0003@D7P01`3oP0001@2h>;@0X23`0;Ph]03oP000
j6Pl00T0oh0000<0P<00003o0000o`00203ooolB003o000E06V:501YG2d0CEM303eFAP12FT`0@UQ;
03iE@P13ED40BeI405MLBP1HGdd0GF=A06M[E`1_LUd0KG9M075bGP1dM5l0Lg=M07=cGP1iN6<0N7UR
0080MgMQ02P0NGYX07j1K@1hNF@0O7]U0861JP2<S7@0RX]d08Z:L02?TG@0U9Ei09VKP02NVh80XYn6
0:JVSP2/[i`0[k>O0;FgXP2n`:d0blfl0>7Od@3hmN/0o_ki0?ono03nooh0o_kn0?gno@3gn?/0j^ca
0=_Qj@3Bfn80c]WQ0<kGg`37dMD0`<_?0;O2aP2[]kP0W:BQ08Z2L01UU3P0>ldH2000o`080?oooa80
0?l00P2P8?0A0?n00080j6Pl00<0oh000>QX?03oP0000`3oP0000`2h>;@0X23`0;Ph]0070:0Pl0H0
d51h203oP0001@3@D7P0j6Pl0;Ph]02P8?00d51h00<0X23`00@0d51h0>QX?02h>;@0D91h2000o`0;
0?ooo`002P3oool4003o000=04b31P1V<aT0FTH`04e<=@1AG4D0FFMD05aVEP1PIU@0KVmH07AaEP1e
LeX0N7IN07EbFP0207ihGP03081kH@1nNE`0OWQM0080NgIM03h0P7MP07egGP1nN5d0O7MM07aeG@1k
MEd0NgEN07UgGP1nNVP0NgES07ahI@1hMfD0MGUY06efJ@1XM6D0JGIV075kK@1fPW@0O8Uj082;OP1m
R7`0NhQj07J2L`1/MVP0IW9S06YfI`1YLfD0KG=T07AcG`1bK580MFe?079ZB`1eK500MG1G079aF`1b
KeH0L6Y807YcE`1gLEH0M6mD07eiHP1oOFL0M75H07MeGP1lMeh0NW9H07UbF01hME/0M75H07A_D`1`
Jdl0K6E806AN@P1_JE@0M7ET06]fJP1KK6T0F5aI04l/8@1B5`T0?Ph1017400800?l02@3oool4003o
0003091`N03oP000oh0000D0oh0000<0j6Pl0=1@N03@D7P00P3oP0070:0Pl0050>QX?02h>;@0X23`
0:0Pl03XJ3`00P3@D7P00`2h>;@0oh000?n0000C0?n0000G0=1@N02P8?00X23`0:0Pl03XJ3`0oh00
0=1@N02P8?00^3Rd0=1@N02h>;@0d51h0>QX?03@D7P0oh000=1@N02h>;@0d51h0;Ph]03XJ3`0d51h
0:0Pl03XJ3`02@3oP0000`1@T7P00?l0003o00080?oooa800?l002X0?k`<06]J:`19ET80B65C04EN
DP1>IE/0EVeN05U[G01LIeT0GfMC05YSCP1CGTd0EF9D05]WFP1QKf@0IW5U06]cI`1/N6T0L7a/07En
L@1gP700NX9`07j6M`21Rgh0PXem08>>O@25TH00RIF3092IRP2CVhd0VJ:A0::^W@2_^j/0_lNk0=7E
c@3Uin40l?;]0?Ggm03jnoT0o_kl0?gno@3nooh20?knoP0A0?cmoP3hnO/0k?3c0>?ZkP3KhnH0e]gS
0=?Kh@3Bfn40cMSM0<OBf036d=@0_/W;0;Fo_`2TZ:<0THI^06^I>00Yga402P00o`080?oooa800?l0
00<0D91h0:0Pl03oP000603oP0000`3@D7P0j6Pl0?n000020;Ph]0030=1@N03XJ3`0oh0000l0oh00
00L0d51h0?n0003XJ3`0^3Rd0=1@N03XJ3`0oh000080d51h00<0^3Rd052@N000o`002@00o`0;0?oo
o`002P3oool4003o000I02OK2`1OC2<0Cd/^05YN@P1SIDh0FUi805AIAP1QI580LFmG07QeF`1kNF80
OGUO07ahG01mMEX0NWAJ07]gG@1kMU/0O7IM07ehGP22NV40OGIL07afFP1kMUT0O7IK07afG00207Yf
G00Z07YgG`1jNVP0NWa[07UlJ`1eNF/0KGI/06YjL@1SMVd0EfiV05=ZH`1?JF@0BVIQ04YRH@18HUl0
BVAO04mWH`1BJFD0H7E_06]lMP1WMg80IgI]06]cI01_LE`0Lg5H07AaEP1bL5L0KVmH06i/E01eKE40
NG=E07]fG@1jNF<0OGaW07mlJ@1eM5l0N7MQ07UfG@1jMEX0NgIJ07QcG01gLe`0MG1F0P1eLEP02P1c
KUD0HEm605EH@`17CCT0EeU506m]G01JIET0EEe@03XV5@0j8@43003o00T0oooo1000o`00101@T7P0
d51h0?n0003XJ3`50?n000030:0Pl03@D7P0X23`0080X23`00@0d51h0:0Pl02h>;@0^3Rd2@2P8?00
0`3XJ3`0oh000?n0000D0?n000030=1@N02h>;@0j6Pl0080oh0000<0^3Rd0:0Pl03@D7P01@3oP003
0:0Pl080oh0000@0d51h0?n0003@D7P0j6Pl203oP000103XJ3`00?l0003o0000o`080?oooa800?l0
02@02oL307Y/801AE3D0BUm@059YG01FJf80FFmV06=gK@1[Ng00LGe_06aiJ@1WMVD0IgEV06EbI@1U
M6X0IgM^06]kL`1ZO7@0LhN107R:Q`1kT8X0PiVB08^NV@2DYZ@0UjZV0:Nk]02ca[d0`M760=GQe`3/
lN/0n?[g0?conP3nood0o_on0?knoP3no_d30?knoP0D0?gnoP3gn_`0l_Kg0>c_lP3TjNd0g>7V0=cR
j03Dg>00d]gQ0=;Lg`3?f=d0bMGI0<OBe035d=80`<S90:^WX@2QSWL0LIe504no:00Fl0T<003o00P0
oooo4P00o`000`0Xb3`0X23`0>QX?00D0?n000050=1@N03oP000oh000?n0003XJ3`06P3oP0001@3X
J3`0d51h0=1@N01hF;@0:<Pl00`00?l02`3oool000X0oooo1000o`00400da@d0ETXM06IR?@1WIdL0
DE4h05eOAP1GGDP0GFID06m`F@1bLE@0MgIJ07ahGP1mNE`0NgAI07]fG01kMUh207ihGP0o07mhGP1n
MUX0O7EI07]dE`1kMEX0NgIM07YeG01gMUl0MWQQ07QjI`1bN6D0JG1Q06A^H@1AHUT0Fg=]03aHE00T
@3d09dA004IRF`1ROg@0KHMl07bAQ`1^QW/0Eg9W02m=@P0N?3@05Bl/01T`<@0^AdL0CFAP061/H`1Z
KEh0L71N06EUD01/KeP0N7AJ07edE`1kLeD0O7EG07YdG022P6/0OGeY07=cGP1gMUh0NWAL07YcF@1h
LUP0NgAM07egHP1hLU/0LVa?07I`E@1fL5P0LVeG05iQC018ED<0:D0b02Hj;P1EEcl0JV]B05QTD@13
?RT0;Tl100<00?l02@3oool4003o0004052@N02P8?00X23`0:0Pl0D0oh001P2P8?000`3@D7P0X23`
0:0Pl0070:0Pl1`0oh0000@0d51h0:0Pl02P8?00X23`103oP000103@D7P0oh000=1@N02P8?030?n0
00030:0Pl03@D7P0oh0000H0oh0000@0d51h0?n0003oP000d51h0`00o`080?oooa<00?l001d07><6
06]V8P1?F440CfEG05eaI`1QMF`0IGM_06YlLP1]OWD0LX5g07B2N01eQG/0MhMo07Z<Q@1nTX`0QYNC
08jQWP2DYZH0Vjj]0:>f]@2]_/00]lO80;W;c@34e]L0cmkN0=[Wi`3Uk^l0m?Sh0?ooo`020?kooP0H
0?kno`3moOh0nocm0?OinP3em_P0lOCe0>cal@3Tjn`0h>OY0>7ZjP3MinP0g^GY0=cTj03KgnD0cMKJ
0<gFf@3:dmH0b]7D0<;6a@2b[:00WY]d06:a?@10d1l03?P53`00o`080?oooa<00?l000<0:<Pl0:0P
l03XJ3`03@3oP0001@3XJ3`0^3Rd0;Ph]03oP000X23`0080j6Pl5@3oP0000`3XJ3`0oh000?n00003
0?n000050>QX?03@D7P0T71h052@N00Xb3`03`00o`0;0?ooo`002P3oool4003o001A042M201YG2l0
JVLo05MJ>`13BS80CeDm05YRC@1IIE@0JG1I079bEP1gMU/0N7EK07ajG@1mN5`0O7MJ07afF`1lMEP0
NWEF07egF01nMUT0OWEI07agF@1kN5/0NGUQ075dH@1_M6<0J7=P06A_G`1AHE<0?59702m7@00[ASd0
<Tm5059XGP1QLVH0MX=i086>QP2DXIh0[KFe0;k2a@33a/X0a<W;0;:l/P2GX9@0SIJ;065cJP0dCd/0
Fg=b02`o>01EGDd0Lg1M07YcF`1mN5X0OGII07eeF@1jME/0NgUQ07elI@1dMEl0LgEM07IeG`1lMeh0
OWEJ07idF@1jM5X0OGAM07mfH01lME`0NG=I07IbE`1aL5L0KG1M05AOC`0cBS/08T0b02E0<00gB3@0
IVI906eVC01FB38088d100<00?l02@3oool4003o000407QH]02P8?00X23`0=1@N0@0oh0000@0j6Pl
0;Ph]02P8?00d51h0`2P8?000`2h>;@0X23`0:0Pl0050:0Pl0030;Ph]03oP000oh0000`0oh00103@
D7P50?n000050=1@N03oP000oh000?n0003XJ3`00`2P8?000`2h>;@0d51h0>QX?0030?n000<0X23`
00H0^3Rd0?n0003oP000j6Pl0=1@N02P8?070?n000040=1@N03oP000oh00083000<00?l0203ooolD
003o000b01?]1@1NRb<0HUln05i[F`1XN6h0J7Ya06j1MP1aPg`0NXN107Z:Q@1oTX`0QYND08bPW02A
Y:<0UjZZ0::d/P2Y^k`0^<S90;_:b`37eML0e>;T0>?^k@3bn?L0mOWi0??hm`3hn_/0mOSi0?;gm`3a
m?H0ko;c0>odm@3Zl?00kOCd0>Wal@3[l_<0k?;d0>K^l03Rk>`0g^OW0=SQh`3Egn00d]_M0=?Jf`3E
f=`0b<S90;^d[02_WhX0QZ1H05;1;`0]hQDC003o00P0oooo5000o`000`0Xb3`0X23`0=1@N00:0?n0
00050;Ph]03@D7P0oh000=1@N03oP0000P3XJ3`G0?n000050>QX?03oP000j6Pl0=1@N02h>;@00P1@
T7PC003o00/0oooo000:0?ooo`@00?l00540GXDB07AW>`1_L540Ef=<04MG@`16ED<0BUU8051NC`1R
K5/0JViG079dF`1hMUh0OWYQ07YcE`1mN5T0P7YL07mhFP1kME@0NW9B07]cE`1lNF00M7US06YdH@1K
JUT0CEmE04=FCP0bC4808d0f02e9?P0lDd@0DV9?05mXD`1[JU00LVQ<07AWB01gJTH0NV]607E/C`1n
NV/0VYV>09jOT`24OW00QGMM08ehEP2BO5h0UXih071bH`27S840IFaI05AG?P1fK4h0PGEF07mhFP1l
N600OG]U07YkI@1gMV80MGAN07IeG01mN5d0OGIO07adFP1mLUT0OWAL07YcF`1oNF<0NWEQ07UdGP1b
L5X0JfmI06A/FP1GI5L0<d]002a7?@0bC3h0=dlo03mHB@1OJUD0L6E4075K<`0P/@400`00o`090?oo
o`@00?l00`2P8?060?n000040>QX?03@D7P0j6Pl0;Ph]0L0X23`00<0^3Rd0=1@N03oP0002@3oP006
0=1@N080oh0000<0j6Pl0?n0003@D7P00P2P8?000`3@D7P0oh000>QX?0020?n000<0X23`00<0^3Rd
0?n0003oP0000P3oP000103@D7P0X23`0>QX?02h>;@30=1@N0030>QX?03oP000oh0000X0oh0000<0
X23`0;Ph]01XZ3`00`00o`080?oooaH00?l002`09=/;05JH9`1cJDH0Jg1K075lKP1eQG/0NhR107b:
Q@22Ti00QIRD08^OWP2AY:D0VJZ/0:Zk^`2faLD0`Lo@0<SGf@3Ch^@0g^_/0>[alP3]mOD0k_Ge0?3f
mP3am?H0lOGg0>gcl`3^m?@0kO;d0>ccl`3Wl>l0i^o^0>G^k@3Tk>`0gnKX0=[Ti03PiNH0g>;O0=3B
c@36`[P0_K2P0:6`NP22Ze@0E<8`02kS5QL00?l0203ooolF003o0004052@N02P8?00d51h0>QX?0H0
oh0000D0d51h0:0Pl02P8?00^3Rd0>QX?00G0?n00080d51h00@0^3Rd0:0Pl01@T7P0D91h5`00o`0;
0?ooo`002P3oool4003o001A06:96@1aJD40MWiW061aG@1CIE<0CV1>04mOD01DHUH0Gf]P06I_GP1W
L5X0KW9L07QfG`1mN5/0NWEF07ehF@1nMeT0OWUM07mjGP28Q6T0O7iW06QcH@1<HE@0=4m702=1>@0K
=b`09Chc045GB@1KJ5D0JfeA075/B@1gIcl0QFdn089^@01hJ480MVI208UhD020MUD0PX5]0:JSU`2g
]jd0Ti5n089gF02AOEP0U7eG099kF02@OEX0OVe;07EV?`1iKdh0OgAL08Z4K@26Pf/0OGaW07UjH`1e
MUh0NgMM07ihG01mN5/0OWUM07mhG`1nMed0O7EM07efG`1lMf80NgMT07McH01eLEd0JViK06E`H01B
Ge80@553039>?`0gDd@0?5I7049MC@1=IET0HW1P06EQ@01hIBl07mH400<00?l02@3oool4003o00<0
X23`2P3oP0070:0Pl0030=1@N03oP000oh0000H0oh0000<0d51h0:0Pl02P8?001P2P8?030?n00003
0=1@N02P8?00X23`00H0X23`00<0oh000:0Pl02P8?000`3oP0001P3@D7P0X23`0:0Pl02P8?00d51h
0:0Pl100oh000P2P8?00101@T7P00?l0003o0000o`080?oooaP00?l001H02_L403K94`1BYBP0IXdn
081hF@1oNVL0PHAg08:=QP24U900SIbK09BUY02O/[80Z[bk0;K5aP2ocm00b=SI0=3Qh@3Ki^D0h>_[
0>;/j`3Wknl0ing^0P3Xl>l03P3WkNh0j^c`0>W/k03WinD0hMkK0=WBc03Bakh0b[b[0:bjR@2>^6P0
HL9104[<:`0]haP03?P66`00o`080?oooaP00?l000@0:<Pl052@N01hF;@0^3Rd0P3@D7P00`3XJ3`0
oh000?n000020=1@N0030:0Pl03XJ3`0j6Pl00l0oh0000<0j6Pl0=1@N03@D7P00P3@D7P0101hF;@0
D91h052@N00Xb3`K003o00/0oooo000:0?ooo`@00?l00540I8`K079/B01fOfh0KGY^069cIP1NKf40
GfiR069^IP1`O7@0OHQm07J3LP1TKeX0IVU?06eZC01`JdL0M6e807U`D01mMed0OW]R07mkHP1iNV00
IG1I03U??@0Q>bh0>4lm059OA`1QJ4`0KFa<07a`BP2;N4T0RgDn08ea=`2>MT40GeHb05EB=01QFch0
IV9506i_E`1iNVL0PX1_07alK@1^LV00JF]H05IJB016CSX0LFU<08AcCP2:MTh0RG5008A/?P22LE<0
PGaU07]lI01kNF00OW]O081lG@1oNed0OWYL07miG01oNUd0OWUL081jH01nN5l0NWAJ07A`F@1]JeD0
IfA@069UC`1IIED0C5m>04EGAP18FTX0A5e<04UTE@1@Ied0CFIK05A/H`1QKV80Hf9307mY;@0Ni@L0
0`00o`090?ooo`@00?l00P2P8?0;0?n000@0X23`00D0^3Rd0:0Pl02P8?00X23`0>QX?0030?n00003
0>QX?03@D7P0d51h00D0X23`00<0d51h0?n0003XJ3`00`3@D7P20?n00080d51h00<0j6Pl0?n0002h
>;@01@2P8?000`3@D7P0^3Rd0=1@N0090:0Pl0030>QX?03oP000oh0000`0oh0000<0d51h0:0Pl01@
T7P00`00o`080?oooad00?l001X0;>4B02GL4P1:^R@0A;TX06jL@P1YX4T0JZAB07^UH`2OUGX0Yif7
0:nTT`2cZ9D0_K2K0;naWP33/Yh0a;>N0<6_V02X^HL0SL5c08flK@2<]f<0I<E605W9>01?cbl0;^@L
02C[4b800?l0203ooolM003o00@0D91h0P2h>;@>0=1@N0030:0Pl01hF;@0D91h00<0D91h8P00o`0;
0?ooo`002P3oool4003o001@05RR601_IT00N7i[07R3M`1hQgd0LhAk07:2N@1fQW/0NHUm082@Q`1l
SH80NHYm06]gI01XL5L0JfmA06i/C01cKe<0N7QO07YmIP1nP6/0PHA]06a[CP1WI3l0KfU407Y^BP1k
LD`0P7EA08UkEP2:N4`0SgU9099iA`2?M3h0SgM607eaC@1eL580MG9H06ieG@1NKf40M81j07j9Q01A
HE`0:40e02Y0<P0bBc/0A5]706U[CP2<Ne<0T7Q:08]dA@2@OU<0QWYJ089lHP22O640QX1Q08AoH025
OV00PgiR085lH01mN5P0OGIH07M^D@1cJTd0LFM<06YUB@1QHdL0FV1;059QC019GTd0Bf5D05AWF01K
K5/0Ff]O05U^I01GKfD0FFmY05ibJ`1LKfP0IFiN06mT?@1RVb04003o00T0oooo1000o`000`1hF;@0
X23`0?n0000:0?n00080d51h00<0X23`0;Ph]02P8?000P3@D7P20;Ph]0030=1@N02h>;@0X23`00X0
X23`00@0j6Pl0=1@N03oP000oh000P3XJ3`40?n000030;Ph]02P8?00X23`00<0X23`00<0^3Rd0:0P
l02P8?001`2P8?00102h>;@0oh000>QX?03XJ3`=0?n00080X23`1000o`3=0?ooo`002P3oool4003o
001@01kU201nIc40Q85V08B=OP23T8T0Oi6;08:ET028ViD0QIJ?07nAR`1oTXT0Nhj607J5O01gPWP0
N8Ak07N3N01eOfh0LgiY07AjI`1fNFP0NG]X07a^A@2<L3L0Tg@m07m[@`1^KUD0LGQW07IlK@1hOVX0
MG]U07YnIP24PfH0SHIU08f0G`2>P5d0UX5R0::?M@2XWXh0ZZFL0:NSX02@SH40QGYP08QfDP21M4h0
P7=908UhB`2AOU<0TH1H08n5HP2<QFX0S8E/08R2J022O680OWUL07afEP1jLU@0Mg5D07=^D01aK4d0
K6]=06]XCP1WJ580H6AB05YUDP1BIE@0DVUL05=ZG`1GKf<0GgI[06MjK`1XNG40IWQc065fLP1ON7<0
GgM_06EkL01UMFX0JfI707Ej:00DkPH4003o00T0oooo1000o`00100Xb3`0X23`0:0Pl03XJ3`A0?n0
00@0X23`00@0j6Pl0?n0003oP000j6Pl0P3@D7P00`2h>;@0X23`0:0Pl0030:0Pl0D0d51h2P2P8?00
0`2h>;@0X23`0:0Pl0040:0Pl0030;Ph]03@D7P0oh0000l0oh0000<0d51h0:0Pl00Xb3`01000o`3=
0?ooo`002P3oool5003o001>05FQ601mKDH0S96008ZITP21UY40QY^H08VMV`24V9D0PiJD08bMV025
V9@0PI>>08FBS@22TH`0Nhb307V;OP1mRg`0Oham07^3M@1jOVd0OgIE08E^?@2AM3/0SWA406aS@`1S
HT/0JVUH07]lJ`21RGX0Pi2008^HR02CWhl0Uj2?09bOR`2RX8P0TXEW09AoE@2JPeH0W8AN09^0FP2I
Oe00U7M109EkA@2QT640WiI`09VCL`2DTGD0TXie092<M@2=QW00Q7aT07ihH@1hLeP0MG5A07IbD@1d
LE@0M7AG079cF@1bMF80KW=V061/H@1GJ640GFmX05Q^I01QMV`0Igab06^0M`1XOW@0JGmg06Z0N@1W
OGL0IWig065lM01UO7<0K7md06]`GP21JS@0;>0?1@00o`090?ooo`D00?l00P2P8?000`3@D7P0oh00
0?n0000?0?n000@0X23`00<0d51h0?n0003oP0000`3oP0000`3@D7P0X23`0:0Pl00B0:0Pl0030?n0
003@D7P0X23`00@0X23`4P3oP0020:0Pl0D00?l0c@3oool000X0oooo1@00o`00C@0DkPH0JHlT08Af
E`2?Uhh0Qi^F08FKU`2;XIl0Rj2N08:HU@27ViH0RijL08RMVP2;WYd0RinN08BITP23UXh0QYJ<08>C
RP27TX`0RI>708R?OP28RVl0S8EO08mnD`28M4/0Qg5:08M`B`2;MU<0OGEM07f0KP2?UhL0[kRb0:Rc
/@1iRhD0F6UN05YOBP24M4P0TgY409IlB@2USf40]jEj0<>cRP30/Xd0ZZ:209NEM`2?TW@0TI=j09BE
PP2AUH@0R8Yg08>4L01oPVh0OXA_07n6K`21Q6l0RXUe09^CP02;QgL0PX9h07MlM01`Ng<0JgYe06Uk
M01XOWD0MHUo07>6O`1gRXD0LHJ106j6OP1^R800KhN006b5O01ZOgH0KW]^06ibG`1jJCl0>/dE00H0
0?l02@3oool5003o000302S8?02P8?00^3Rd00T0oh000P3@D7P60?n000030>QX?02P8?00X23`00@0
X23`0`3@D7P00`3XJ3`0oh000?n000030?n000/0X23`00@0^3Rd0=1@N03oP000oh000P3XJ3`20=1@
N080^3Rd4P3oP0000`2h>;@0N5Rd003o0005003o0<d0oooo000:0?ooo`L00?l000X0><TE07ijB021
PGD0SY^E092SX02?Xj40SZ:P092TXP2AYJ@0T:BR0P2@Y:@0?P2@Y:80SJ2O09JTX@2CXih0Sj2K08bL
UP2GYIh0TJ2L09RUW`2MYY`0VIj>09fKR02NV7l0Wi9c09f=J`2HRFL0THQ/08b7OP21PGT0LGIS07Ul
H@2BSV`0/:R20<c3XP3YhlX0o?W[0?Gcj03/j]l0hN3E0=CDaP38bk/0_/Fd0;Fo[`2b_;00[;^a0:Bd
Z`2S/J/0WJbW09FWX@2CXid0V:2G0:BOT`2dXiD0YiR809RCP`2>T8H0Phf707j=Q@1nShL0N8j707fE
S`1hTH`0N92=07F;R01fS8H0L8En06n0N01_OG<0JW5L06mXAP1/RBh07NH:1`00o`090?ooo`L00?l0
00<0N5Rd0;Ph]03oP0000P3oP0000`3XJ3`0oh000?n000020=1@N080X23`0P3@D7P00`3XJ3`0oh00
0?n000040?n000040>QX?03@D7P0d51h0;Ph]0<0X23`00<0^3Rd0=1@N03@D7P00P3@D7P20:0Pl080
d51h103oP0040=1@N080j6Pl0P3oP0020>QX?0<0oh0000<0j6Pl0?n0003XJ3`03@3oP000103XJ3`0
d51h0:0Pl00Xb3`7003o0<d0oooo000:0?ooo`P00?l002<05Nl805VV:028MDh0QX9^09FPV`2KZjT0
W:j/09Z^[@2K[jh0VJf[09nb/@2L[Zl0Vjf]09f^[P2IZjX0UjVV0:6c/02Q/[00W[6^09R[Z@2J[:`0
VZf]09Z/Z`2U][D0[K^h0;c4`P31bL@0`lo70=;NeP3Jhm/0gnOO0>W_i`3gnO<0oook0?kno0030?kn
oP0Q0?gmo@3no_h0o_kn0?kno@3fn?L0inc[0=KRh@38eMD0_/_<0;O4a@2[^KT0X[Bb0:Fg/@2V/J/0
YZ^U0:j]Y02][J00Z:RM0:2VX@2BXYh0RIfI08RMV024ViL0Q9^H07nGT`1oUI80MXZ606j0MP1/N6`0
K7=P07A/BP1AY2D0:=l@00T00?l02@3oool8003o000702S8?01hF;@0X23`0>QX?03oP000^3Rd0=1@
N0020;Ph]0030>QX?02P8?00X23`0080X23`00<0d51h0>QX?03oP0000`3oP0000`2P8?00^3Rd0=1@
N0030>QX?1D0oh0000<0^3Rd0=1@N03XJ3`0103oP000103@D7P0j6Pl0?n0003XJ3`90?n000040>QX
?03@D7P0N5Rd052@N0T00?l0c@3oool000X0oooo2`00o`007`1fW2l0QWQH09FHS@2PZjT0XK6`0:6c
/@2R]K@0X[Bd0:6c/`2N/[80XKJf0:2c]02Q/k80Z[Zi0:Be/`2b`l80Z;^i0:6d]02P];<0YKRg0::d
]02Y^k/0^/K80<SFe`33dm<0bmcK0<oLg@3MinT0i^k`0??gm`3moOd00`3no_h40?gmo@0L0?kmo@3n
o_h0nOWj0>7Xj@3Fh^40c][J0<KDe02jblT0^<W60;k<b@32c/X0]<:n0;K2^P2g`KX0/kZc0:Vd/@2J
ZZT0TJBQ08^PW@2;Wi/0R9^H08:HU01gS8P0IWE^06Q`G01/I4L0QFdl02WO4@/00?l02@3oool;003o
0080X23`0P3oP0000`3@D7P0oh000=1@N0050:0Pl0030=1@N03oP000oh000080oh000P3@D7P0103o
P000X23`0=1@N03@D7PN0?n000030=1@N02P8?00oh0000P0oh0000<0X23`052@N000o`002P00o`3=
0?ooo`002P3oool<003o000R02SO4P1M[3<0PY5E09N?N@2TYid0Z;>a0:Fd]02/_Kd0ZK^l0:Rm_02X
^kd0[;jo0:fo_`2U]kL0ZK^j0:^m_P2^_/00[l;00;?3``2ca/D0^lg;0;o=c@34d]80bm[G0<gLfP3H
iND0fN?T0=[TiP3Tj^`0kO3a0?;em03mo_d0o_kn0?gno@<0oOgm0P3noOd06@3no_l0n?Wi0>kem03L
inL0fNKV0=OUi@3@gMd0e=kN0<cGf032d<l0_<W70;O3`02d_kd0ZKBc09n^[02IZJH0TJBP08VLU`1l
R8@0L7Y`06Y^FP1aMd@0DJDX03[>6@0Gl@X03000o`090?ooo``00?l000L0D91h07QH]03@D7P0d51h
0>QX?03@D7P0X23`00<0d51h0P2P8?000`3oP000^3Rd0?n000020;Ph]2<0oh0000<0^3Rd0=1@N03o
P000103oP0001@3XJ3`0^3Rd07QH]01@T7P0:<Pl00`00?l0c@3oool000X0oooo3`00o`004P0Fl@X0
A<LQ06Z[A@2SSW80YI^;0:b]Y`2c_[/0/;jn0;31`P2ca/L0/L?30:Zn_@2[_kl0/<710;S<bP2kcL`0
_Lo>0<SFeP80c][J00/0dmoO0=CPh03Ki^L0fn;T0=cVi`3SkNd0jNo^0??hn03jno/0n_ck0?gmo@02
0?knoP030?gno@3no_h0o_gm0080o_kn01<0nogm0>ofmP3Yl_<0f^OX0=ORi03>fM`0c=OJ0<C?e02h
a<L0/kfo0:jd]`2QYjL0SY:<07n1M@1eMf40MGa>05VL<P15^B40<mPG01000?l02@3oool?003o0004
02S8?01@T7P0^3Rd0=1@N080j6Pl0P3oP0001P3@D7P0oh000?n0003oP000d51h0>QX?1l0oh000`3@
D7P01`2P8?00^3Rd0>QX?03oP000j6Pl0=1@N02h>;@00P1@T7P@003o0<d0oooo000:0?oooa<00?l0
01/06?8<03?H701c[TD0Nj]B08nRJ@2]XXd0[:ZL0:naZP2i_;P0`<S50<SCd03:e]@0amGE0<OFeP3<
f]/0e>3Q0=WTi@3OjNT0gNSW0>?]j`3Sj^P0iNg/0>gem03cmoL0m_Wj0?Sjn@3loOd00`3no_h04`3n
ool0o_on0?gmoP3gn?X0jo3d0>7YkP3Jh>D0b=CE0;g8b@2]][D0YZ^Y09VHT02@RGL0Sh=Z07Z:DP1L
WSH0AkPR02?K400QjQ005000o`090?oooa<00?l000D0:<Pl052@N02P8?00X23`0;Ph]0020=1@N003
0:0Pl03oP000oh0001X0oh0000<0j6Pl0?n0003oP0001P3@D7P0102h>;@0D91h052@N01@T7PD003o
0<d0oooo000:0?oooaP00?l001H0=NPJ05o;;`1C`R`0Nj=50::8I@2UTW/0/::C0;ZfZP38b<80eM[F
0=SOg03Ni><0iNOY0>K/k@3]lO<0k>ka0>c`l`3_loH0m_Wl0?_lo@3jo?d0o?ko0P3no_l03P3loOl0
mOGh0>g]k`3QhN<0d]3B0;Zi^@2XZ:@0VIB<08b2LP2<NEl0Tg]F09f0D`1@_bT0B=PR6P00o`090?oo
oaP00?l000<0D91h0:0Pl02P8?000`2P8?0G0?n000050=1@N03oP000oh000?n0003@D7P0102P8?0J
003o0<d0oooo000:0?oooa`00?l001h03OX703;W6`0^haX0=]/O05K5<P1j]D/0Qk5F08RcGP2;]fD0
V;Ic0<JYS@2i/8X0aJjE0<F`UP36/IH0`k2G0<:_U`30[9<0_ZR>0;>^QP25^6/0P;5O082^F01n[5<0
LZi704o2<01A`Rd0?]4Q02cS600Il`dN003o00T0oooo7000o`000`0Xb3`0D91h052@N002052@N0<0
X23`00<0^3Rd0=1@N03@D7P02`3@D7P30:0Pl0@0D91h00<0:<Pl003o0000o`007000o`3=0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {180.75, 0}} -> {-0.106847, -0.0454574, \
0.0105606, 0.0105606}, {{10.0625, 98.1875}, {176.438, 4.25}} -> {-17.4879, \
-6.49014, 1.7365, 1.7365}, {{107, 195.062}, {176.438, 4.25}} -> {-185.905, \
-6.57348, 1.73742, 1.73742}, {{203.875, 291.938}, {176.438, 4.25}} -> \
{-402.835, -31.6328, 1.97589, 1.97589}, {{300.75, 388.875}, {176.438, 4.25}} -> \
{-593.828, -31.5061, 1.97449, 1.97449}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1T, pdf1, 
          pdf2, {Green, Blue}];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2T, pdf1, 
          pdf2, {Green, Blue}];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1T, class1, obj2T, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44639 
%%ImageSize: 400 178.555 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0106283 0.238095 [
[ 0 0 0 0 ]
[ 1 .44639 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .44639 L
0 .44639 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0106283 0.245293 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0063C92C62C62962C62893AA3CC38F53
C39053C59055C48E55C58F57C48E55C58E56C18C53C28E5591AB3F61C52861C62961C72A
60C72961C82A60C62960C7295EC62800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC223
5AC1215BC1225AC12158BF20B58345B88146B7834AB47E46B58044B67F41B88141B68041
B27F40B47E43B37E43B57D42B67F42B47E42B17D42AF7C41B17E40B47E41B58043B38042
B38042B58243B68346B68346B68547B9894D5BC1245BC2245DC4265EC4265DC42700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDF1159C02356BD20829D31AD7E41AC7D40AC7D41AC7C43
AF7D42B37F46B38144B28146B28147B28048B5814DB3804DB17E48B68049B77F45B88148
B6824BB6814DB37E4AB6804AB7824BB8844EB37F4AB5834DB38048B58148B68248B38045
AF7C40B27F44B28045AF7D44AE7C43AF7D44AD7B41A9763AAA793AB07E40AE7C3EB07E40
B18143B28344B0834683A23658C0242CE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002EE11300FF0000FF0000FF0058BE2256BE22
54BC2156BD23829C32AF7C45AF7E43AD7D43AE8046AE8048AE8149B1824DB0834DB38251
B88452BE8757BE8958BE8A58BC8654C1885AC1855AC4885DC6865CCD885ECE875BCF875D
CE885ECA835BC88259C98259CA845BC8845CC8845DC9875FC7875DC5875BC08558BD8355
B98352B48353AF8051AD8052AE8252AD824FA97D48A67941A67940AC7D44AE7C44AA7840
A37338A37436A57538AA783DA9783CAD7B3F819C2F56BD2056BF2054BD1E809C2D56BD1D
2BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0058BF22AD7A3FAC7A40AB7941AA7941AB7D47
AA7E49AB7D4BAE7E4CB38050B4814FB98454BE8659C2875FC68761CB8861CF8960D58663
DD8965E08767E08566DF8363E17F5DE47B5CE5785BE4755BE57158E36A53E0654DE2644E
DD6149DF614ADF624AE1644DE36651E26651E26854E16B57E06C58E2725CDF755CDA775C
D47B60C27A5EBE8266BE896BBB8969BB8C67B78962B3865DAE8359AF8357AE8154AC8052
A77D4DA57C47A57942A4743CA27135A47335A16F33A27033A47335A87838A87738A97839
A978367F9A282BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0054BB1F7D9A2EA9773DAB7940AB7943AB7B48AF7E4FB48255B98458
BD835AC5855ECD8660D78766DB8665DD7D60E0765FE0705CD9624DD75741D44C38D44232
D53E2FD43829D23224CF2B1DD32B1AD42716D42716D52419D52117D71F17D51E14D72018
D82017DA2117D92014D81E14D81E14D92116D61F16D41E15D11E16CF1E17CC2015C52015
B420158D130A8118137C1D167F251A85302290402F974D3B9B5744A66651AF735BB37E61
B58464AE825EAD815BAC8055AB8051A57C49A27944A1753FA27239A27235A07130A37230
A57434A77736A8783654BC1929DD0B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DD107B9831A77743A87643A57443AC7747B27A4DBB7D53C17D58C87B5BD1795BD97459
D5664ED0543FCE4634CB392BCB3123CE281ED0241BD11E16D61F15D71B12DA1C13E01C15
E31C15E61B14EB1F15EB1E14EC2015ED2014E81C0FEB1C11EC1C12ED1B14EC1C13EE1C17
ED1D16ED1B13EE1C12EB190FEA180EF22015ED1B12EA1910E8180FE91A12E71A11E21912
CB120EA3030395040895080C950A0C8E07088B0A0A8409097C07087B0D0B77100C771912
78241A83382B924E3FA0634FAB725CB27F63AE8160AA7D59AA7F54A77D4CA27941A07339
9E6C30A16F30A16E2F9E6E2C9F712BA0712900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0029DD0F53BB1F52BB21799932A17544
A57647AD794DB1774FBB7653C47758C97052CB664BCC5943C44332C23427C6291DC92116
CE1E14D21911D71913DA1712E01914E11611E61911E6170EE91A12E91913E81810EC1B14
EB1A10EF1C11F22012F22014EC1B0FF42116F11F12F42015F31F13F41F14F62116F51F16
F21E14F21D12F62115F41F13F42013F41F13F41F13F11D12F21D12F11C11EF1C10E91C12
CC0E09AD0204A40205A30105A60408A001069D04089B03089703079002068F040A8C050A
8304087B060876070A710A0B6D0F0E721A167C2D258743369B604BA77357AA7C59A87A53
A7774CA675449F6F379A6A2F9A682C9665249E6D274FB61100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0028DC0E7B9930A97A47AA7B4DAE7B50B87955
C17656C56C51C65D48C14737BE3526BE2518C21D13C7150FCD1511D2130FDA140FDF130E
E2140FE41610E4130FE4140FE51610E71610EA1A10E9160EEA1A11EF1C15EE1C13EE1A11
F01C11F11D12F32113F42114F01E11F42116F52215F72317F72116F92217FB2419F62016
F62114F92317F72314F31D11F52111F82313F62114F62215F41F12F11C0FF11D11EB1D13
C90907B20203AE0306B00507AE0408A70105A60207A40207A002079E02079D0209990107
9601079302088F040B88030B81020A7B03097A070B71070A6A090869110D6F1F1880382A
914F3B9E634BA77451A374499E6E3F9A6A3597662A97662296661C4CB30B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DD117B9A34A87948AF7D52B67C5ABE775DBF634EBC4A38
B73024B61E15BB150FC4120FCD110FD3110DD7100DDA0F0DDC0F0EDE110DE1110DE2110E
E41410E61611E61611E51311E41511E5140FE91912EB1811EE1A12F11C14F42016F41F15
F41F14F31F14F62216F72317F42115F42116F22013F92519FB261BFD281BFE2A1CFC271B
FD291AFE2919FE2A18FB2616F92312FC2514F72012F62112F62012F62113F41F13EC1D14
C90806BD0809BB090ABC090BB8070AB00106AF0309AF050CA70106A70208A70108A20105
9F01059F04089701069101088A01088601078403088001067E01077D030C76030A730609
6C0707630A0764170E712D1D884B369C6448A06B44A16E3C9A69309565229260146B8307
47AB0300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029DC0D
50B81B53BA1F7F9931A97747B07B4FB97854BD6F50B459419C34249A1B15AF1B15BE1511
C7110DCE0E0DD30E0FD60E0FD90D0EDA0D0CDD0E0EDF100FDF100DE2120EE1120FDE0F0E
DC0D0DDD0E0DD90A09D9090BD70A0BD90A09DE0E0BE71610F01C13F41E14F72116F82117
F92217FB2519F92317F72117F92519FC281BFC2A1AFC281BFE2A1DFE2B1DFE2B19FE2D1B
FF2D1CFB2716FA2514FB2314FB2313FA2212F92214F92312F82211F82114F41E13EB1D14
C40502BE0908BF0908C30B0BBE070AB80509B40409B00308AE0308AD0309AA0206A70206
A60106A301059D02049500059001088B0008890107870105870006870109840107820207
7E01077901077604086E0506690808660F0A70221586422B9F6645A07245996B34936222
824E0E7B470542A90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DC0A7594219F7337
A67944AB7749B6784FBF7250BD5C42B43B2AB12518B0140EB3100CB90A0BC80F0FCD0D0B
D20C09D50B0BD70C0EDB0E10DD0D10DF0E0DDF0E0CE4110EE61410E3130FDA0D0CD30608
D20608D30609D30709D6080AD40708D80B0ADC0C0AE0100BEB1910F31E16FA2117FB2318
FB2517FB2415FA2515FA2619FB281AFD2B1BFD2E1BFC2C19FA2A19FF2F1EFD301BFE2C1A
FD2B1AFC2919FC2818FD2616FD2616FB2315FB2316F92112F92213F72014F31E12E51911
C20602BD0908C20B0AC30A09C1090CB70407B20408AD0207B2060BAE0307AD0308AA0209
A70106A80206A402079D01069801089301099002098B01078A00068B01078B02078B0208
86010787010889030988050A82040A78030776070A6B0805610D05702D1A915739A16C44
97653683531D6C3E047B4A074AAF0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DB0C9F7234A77D43AC8247
B4804AB46840B0462CAC2716B41A0EC0130DC30C09C50909CA0B0BCD0A0BD00D0CD10C08
D60F0AD60C0AD90D0DDE0D10DF0D0EE51211E5140FEA160FEA170FDD0D09D00402D20608
D30709D5090BD4080ADA090CD90A0ADC0D0ADE0E0BDD0D09E10F09EF1912FC241AFE271B
FD2A19F92816FC2C1AFB2E1EFA311FFB3521F93721F93522FB3522FD3321FE321FFF301E
FF2F1CFD2B1BFE2B1AFE2918FC2717FD2718FC2416FB2315FB2315F82212F52316D9130C
BB0404BC0A09C10C0BC30B0CBE090BB7070BAF0409AB0309B0070CAD0408A90207A80208
A8020AA80206A70308A20106A1030A9B01089501069101058C01058C02068E02078C0208
8801078802078B05098C04098A04088503087F02087C040A77050C70080A660A056E1F11
85442B99643C9163317D4E156F3E0260780525D70500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE0FA67B3CAB8145B0853CBC8F37
D0913CA23709AF1807BF100BC40B09C80A09CA0B0ACC0A0BD00C0DD30A0DD60D0CD60E09
D8110CDA110ED8100DDE1111E31411E81511EA1811EC170FEB180DE10E07D70A05D50806
D30706D40708D60A0ADA0C0CDB0C0ADD0D0ADB0D08DE0F09E3110AF21C13F92619F62C1E
EF3826EA3D2AE94331E84837E9503FE75544E85D4BEC6051EB4C3DF43628FD3121FD2F1B
FE301BFE2E1AFE2C1BFD2819FD2819FD2718FD2415FA2314F62513EF2A16E62C19CA160C
B60605BB0D0DC00E0DBF0C0DB80A0CAF080CA60307A20307A50408A70408AA0509A60207
A40107A60309A50207A102079C02079A0207980205910104880004850004890107870106
8201057C00037F01058202058604078202077F02087E02087F020A7F030A7B0409750609
6A09056A1A0A87482999643B8C5C2A74410C76400345A90400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0049AE049867197D9A2BAA7942AF7F3DBE8F33C39822CD9D18
DF9922AC3201B71001C10A07C10606C40707C90B09CC0909D20B0BD70C0CDB100EDC120E
DA120ECC0D0AEB2F2CD3100EDE120EE71410EA170FED190FEE1B0FF11C12E7160DD70803
DA0B08D80A06DA0C09DA0D0AD90D08DB0D07DE1109E01008EB190EF82418F4281DC41C12
EA7B6CFBAC9FFEB5A8FFC0B5FFCCC2FFD3C9FFD7CCFFD8CEFDADA3E24437F83522FF321E
FD2F18FD2C18FE2B19FE291AFE291BFE2719FC2615F72A1AD82312E45945F17F6DB53126
AC1711B5130EBF1311B80C0DAF090DA6060A9E0409980307980407A00609A40507A50205
A40206A20105A60308A00206940003930004970305940307870105820105840005850005
8101057700017700027900027A00027700037601057601057A01057C01057D01067F030A
7C050B720807660A026C210F8C533398643B834E1D6E370260740326D60300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB00A9B6A29AD7644B26F48A05127A96218D0991ACD9F08D2A306
E49D19AF3300BC1504C20B07C00607C40807CB0D09D00B08D40B0AD80E0CDA0E0DDB0F0E
D40F0EB70302C21210C00402DF1610E8180FEE1B10EF1C0FF01C0DF21D11EF1B0FE9170D
EE1C13ED1C12DC0E06DA0E08D80E06DE1108E7170CEF1D11F92518FD291CF22B20A6110F
B6766EFFEBE6FCEDE8FCEEEBFAF1EDFBF3EFFBF3EFFCF0EBFFDFDADF6258F23927FC311D
FE3019FE2D18FE2B17FE2918FE2918FD2818F82616E62D1E941206E0A193FFE0D3F6BCB2
C86A5EAF3328AE1D17AB1411A4100E9C0A0A9408088C0A098A0D0B870A0696100BA51311
A10707A20407A6060B9F02089801089201078F01058F0205870104840004860004890206
8601057F01037C01037D01047A00037701047300027200027501047A01067F0207800207
7E02087B03077703076D07065908026B2B189259398C562B7339087D420224D40300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00728E1A9E703AA56E499F4C35952614901600B85A13D79B10D0A303D3A405
DF9D17AD3500B71102C00907C00607C60A08CD0C07D10D09D50B09D90F0ED90E0CDC0F0F
D50F0EC6110FEC3C39D61814E51911EA180DEE1B0FED1A0BF01E0EF01D10EE1D10EC1E12
ED2316EE2618E22215D5190DDC2516E22719EC2C1CF32D1DF62C1DF92A1CF52E21C42721
833E3BFAE9E7F3EEECF5F1F0F1EFF0F5F3F3F3F0F0F7F2F1FFEDEBE98884EC3E31FC321F
FC2E19FF2C18FF2C18FE2A17FE2A17FC2A18F12E1CBE291A944437F4D9CEFBF0EAFEEEEA
FFE3DCF9C4BBDE8D85BB5750A1372D8E23188620157C20157422167E2F22B05A4DCC6158
96110E9B05099F040B9C020999010A9202098900058900058902058902048701038A0306
8901058701058502058301047F01047C01047901037601037600047B00067F0106810106
820308810107800209770307660103580400540C0371331A8E5631774011733901708109
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25D806996B299E7044854D30702011850E07A40F09A81103BD5313D89B0FD1A403D0A303
DB9D15AC3B01B71403BE0906C20807C90A08CD0B07D30C09D80E0CDC100DDB0F0BDF120E
DD130FDD1A16E52621E31A13E9180EEB170DEF1B10ED1B0EE81B0DE62113DC2718D32D1F
D33A2DDA4A3CDF5A4CE66C5CEC7867EE796AEB705EE86353E55444E34333E43C2CD33D33
711F1BDCC3C0F6F0EDF8F4F4F4F2F3F5F4F3F4F3F2F4F2F1FDEFEFF4B3B1E2443DF83222
FE301DFE2D19FD2B17FC2A17FB2E19EE2F1DCB301E9F3F30EAC3B8FBF1EBF4F2EFF6F3F3
F7F2F1FAF0EDFDEAE5FAD6D0E1B3A7D7A495CF9E8DCDA190D3AB9BDAB2A2E4AD9FAF5951
8209099203089802099600099400099002098C00078C01078B02078A0105870003870003
8A01078901078601048400048000047E01057F01067F0106800208810108810007840208
84020886020B82010A7500046800015E01005A02005405005A15087F44267B4116723700
6E7F0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310
9870338C633E5E2B185B130A700B07930709AF0D0BAF1102BB4A0FDB9D14CFA302D4A805
DB9F14AE3D02B61300C30B08C70907CE0C0AD00908D50C09D90E0BDD0F0CDD100CE0110E
DF130DE1160FE31810E8180FEC1A0FEB180DE7180DE21C11D42015BE291ECC584CEC9589
FBB8B0FFCBC2FFD6CDFFDFD7FFE2DAFFE3DBFFDFD6FFDDD4FFD4CAFFC1B8F5A499E2877D
8E5048B9A19CF6F0EAF7F5F2F5F3F3F3F1EFF3F1EFF3F2F0FAF0EFFED5D4DF5952F33628
FB311FFB301DF83320F03423E23727C03728BC6356F3CBC0FBEEE8F7F3F0F3F3F3F2F3F3
F3F3F3F3F2F2F5F3F2EDE7E3ECE0DAEBDBD3E9D8CDEBD7CCE9D2C6D2AFA4A2645D801A19
8B060A95040B9A020B9900099401079000069101089001078C00068901058901068C0107
8C01088A01078800078601078001057E00057F01077F0207800105810206830107850108
86020B8502098303097601046700006001015F02025C020155020050090174361B7F451A
7237016F7E0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718C16976E38
704B294317094007024D0305620102890307AB0A0AB11004B6410DDE9D16D2A602D8AB05
E1A414BA4708BD1703C90D08CE0C0ACF0B0AD10B08D60C0AD90E0ADC100CDB0D0DDC0E0F
DF130EDF130CDF1209E5160CE7170DE6170CDE1B12C22015AC342AE0938AFED3CCFEE6E1
FAEDE8F8EFEAF7F0EBF7F1EFF4F0EEF5F1F0F6F3EFF9F1F0F7EEEBFAECEAFDEBE7FFE8E2
F8E0D8EDDFD9F1ECE6F4F2EFF3F2F0F3EFEEF4F0EEF0EFEDF4EFECFEE6E4DF7E76DF4437
E73F30E03E31D34536CE5346D27064EBAFA6FFE4DCFCF1EBF6F2F0F3F3F2F1F2F1F3F4F4
F1F2F1F3F3F4EBEBECE4E1E0E6DFDCE6DAD9E8D9D5E6D1C9CAA89E91564E6F121085080C
95040A9A02099F040B9D03079903099501089802099301088D01078B02088E030A8D0108
8D01088B01078C01088900088401068001067D01067801047701037700027B01047F0107
8101098202088003077B02056C00006400006101015E01005B0202550201500600692911
81441B77370122D10100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718D178F6330593115
3B0F033805044005074802065D01057D0206A30909AD0E02B03608E49F1AD5A803D9AB04
E6AA14C3530ABE1601CC0C09CF0B0AD10A0AD00A08D70D0CD70A09DA0E0CD90C0DDC0F0F
DD120EDD110BDF130BE61710E3150DDE1812BC1A13932A20E7ADA3FADFD9F7ECE9F1EBEA
EFEDE9F2F0EEF4F0EDF4F0EEF5EFEEF6EFEEF5EFEDF6F0EEF5EFEEF6F1F1F5F1EFF4EFED
F6F0EDF8F2EFF3F0EDF3F2F0F4F4F2F2EFEEF2EFECF1EFEEF3F0EFFCF0EDF5C5BEE9978B
ED9B8EF3AEA4FDC9C1FFDDD5FFE7DFFDEEECF7F0EFF6F4F3F3F3F2F2F3F2F3F3F3F3F3F2
F1F1F0ECEDECE3E2E1E4DCDBE5DAD7E6D5D0DDC1BCC3968E88453D6F0F0B7D06078B0208
9702099A01069D02079A00049701069500079702089301098E00088C01088D01098B0108
8901088A01088C02098801078502087F0106760002710001720102730101750002790006
7C01077D01057E02048004077902047102036901016501026000015A0101550201510500
651F0C7E3C1678380124D30200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075901D9F76484C260E3A0D03
3806033601053C0206490105650408800307990505AB0C02AC2D02E39819D6A605D5A701
E2A810C75C0DBF1A02CD0C09CF0A0BD10B0BCF0909D50B0DD50A0BD90D0DDA0F0DDB100C
DB0F0DDD100CE0140EE1120CE0140DD018167E0504BA827CF9E0DBF8EEEAF4EDEAF7EAE9
F3E1DFF6D8D8E9C2C1DDAEAED3A09FD09B9CCE9B9BD7A8A8DFB5B6E6C4C3F1D7D5F4E4E4
F6ECEDF4F0EEF2F1EDF1EFEEF0EFEFF1F0EEEFEEECF4F2F3F3F1F2F4F0EEFBEFEBFDEBE6
FDEEE8FDF2ECF9F1ECF8F1F0F4F1EEF5F2F2F2F0F2F5F4F5F4F3F4F4F3F3F3F3F2F3F2F2
EDECEAE4E0DCE8DFD9E6D7D1DFC5BEC99F97AA6A64862D2A7508078105078601068C0106
9501069E02099F02099C01079801079600079502089200069101088E01088E0209890106
8600068600068802088200047C01037501027000016F0001710101740101760103790107
7900067901037901027B01047D02057C06097402046E01026901026200015A0000550101
530400671F0A75340D7E3F0327D60300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00759222B19065BFA59233140D340808
3504053601053F04084A00046C0509890508990202B10E07AC2300E5911AD5A304D3A601
E1A90FCA650FBA1801C90C07CB0A09CA0707C90506D1090BD40B0AD60A0AD70D0BD80C0A
DA0C0CDE0F0DDF100CE2120EDE150FBF15145F0606D6B8B5F9ECE8FAEBE8F0D0CCE3ABA8
DB8E8DCC6A6AB03A3BAD2A2BB02626B22527AC2325A92628A62C2DA33433A14241B06365
CA9093D4B2B3D9CECBEDE7E5F3F0F0F3F1F2EFEFEDF1EFF0F2F0F1F2F1F0F5F2F1F4F2F1
F4F3F0F4F3F2F4F4F2F4F2F3F4F3F3F3F2F3F3F2F3F3F2F3F4F3F3F1F0EFF4F2F2F6F3F2
E6DEDAE1CEC6DCBDB0C5978BAF6E64842E277C0E0C87070A8C030890030A8D01078E0205
9401059E0309A000099E010A9C010A9800079500059201079001078E01078D0106890106
8701058701058601067F01047501016F00016E01017001007401027702037801037B0004
7D01057A01037701017501017601027C04087A03077601047001026B01026501025B0101
5601005304006A230B702D0465710300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B717B89770D3C1B1C7B8B5321B1A31090C
3205083502083D03084801056C070A8D060CA10507B10B09AB1A01E28717D7A206D6AA04
E0AA0ECD6D11B51801C60A06C90B07CA0909CB0909D00A0AD40E0BD50A08D70D0BD70B0B
D90B0DDE0E0DE00F0BDF0F0BDD140FBB1514520202C8ACA9FDE8E2E5B7B1C06660B3302D
B81F1DC21817C81413CD110FD21311D0100ED21313D11315D21917D01C1ACD211DCF2B29
CA3A39952E31613837E3D6D4F2EDECF0EEEFEFEEECEFEDEEEEECEDF0EDEEF1F0EEF5F2F0
F5F2EFF9F2F4F5F2F1F9F2F3F6F0F1F7F1F2F8F1F2F7F1F0F8F0EFF8EEEDF9EBEDFDE7EA
DAB6B5BB827CA0524988261F8712108E0D0C900406930205930105930107910108900207
9201079A020AA1020CA1030D9E030C9901079702079302088E00068C00058D01068B0206
8800058801078301067C01037301016E01016C01016E01017201017501027A02047D0204
7F02057F02057A02037600037602067702077C040A7A05087100026D02036B0204630201
5C01015601005709006B22077731014AA70500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028DB0DB39065D5C4B3D4CBC7C8BFC13A282A2D0B0D
2E05083101063702063E00015B010484070C950104A90908A91703DF7F15D9A208D7AA04
E0AA0ED07310B11A01C40C09C50907C40708C60606CA0807D10C0AD20A08D40A0AD70B0E
DC0E11DF0F10E0100EDF100CDE140FC81717690304A46E68EEB6AABF5B52B61E19C8120F
CE0D0AD50C0CD50C0CD50C0AD60F09D70F0AD8110DDB110DDB120DE01510EB1F16F7261D
F22B22D2302C620D0BBDA6A4F3ECEAF3EEEEEFECEBECEAEBF0EFEFF1EEEFF3F0F0F5EBE8
FDE3E0FFDDE2FFDEE3FFDFE3FFDFE2FFE0E3FFD9DDFFD7DAF2C3C6E6B3B5DB9AA0BF7279
8D313688191B8C0D0C930708970507970306960305940102920103930105930208910108
9201099801099E010AA0010C9C010B9701079400069201079002078F0106910107900107
8E01078801077D01037400006F00016C00006B00006E01016E00017001017401017A0202
7C00027C0104790004760005740106750106750509780C106F060A6A0104670102610202
5E02015C02015704005B0E016D2403833C0327D50300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0028DB0BAC8559D2BFAED2CCC9CDCCCDD3CFD1463B3D24090C
2E070A3403093B03094202075301047404098A03069D0504A61503DA7915DAA209D5A802
DAA70BD47A12B11D00C00C06BF0604B70001C50608CA0709CD0708D20A0BD30B0BD50B0E
D70C0ED90D0ED90E0DDB0E0DD80F0CCE11129C0708AE3F38E47263B82016CA100BCF0A08
D20C09D40C0AD30A08D70F0AD40D06D80E0AD8110BDB120CDC140BE0160DEF2215FA291B
F72A1AEB34288F191489605BF4E8E4F2EEEBF1EEEBEFEEECF0F0EFF1EFF0F4F1F0FFEEEC
D19594D57274DE7276E17377E07375E07273D9686AC15356A23A3D9F3234A42C2FA12123
961211990D0A9E0B089D06049C04029A0403960202950303910102900104940409900107
9200069901089F030B9C010A9A020A960006930004920106920107940208940206910105
8E02068702067B01037100006F01016D01016E01016F01016E01016D0101710201770202
7902027A0204790105770106730004700003680305C1666AA549506A060B6201035B0000
5C01015B0201580201530400621302762A0145A00100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007A9A35CBB2A0D2C9C6CFCDD1CECFD3D4D3D65D5657250D10
2C08093503093C02064703085402086901077E0206990809A01303D37215DCA30CD4A804
D6A508D37D11AE1D01C10C07C50A08BF0405C70609CB0709CF080AD1090BD10B0ACF0A09
D30C0BD00A0AC90404CA0303CD0606CB0706BF0806BE1712D22C22C71009CF0C07D10A08
D10B06D10C07D20F07D41107D31005D31307D21608D31807D31C08D51F0DE2301CE63624
E53B28E04636AE4035815249EDDFD8F1EDEAEFEEEAF1F0EEEFEFEDF0EEEFF3F0EFFBEDEB
EBB8B3E18A84E78881E7857FE8867FE68379E47E77D87570CD6D68C96760C65E57BE544A
A73C2C9E2D19A028149D210E981907941404900E01900C008F09018D06018E0403910205
9301069800079D030A9801079601059803079702069802079802089501079000048F0104
8B01048001037801027100007002006D01016D01006F01006E01016C01016D0101720101
7401017601027801037A01077500056E010467020591373EB05C64AF565D7115185C0303
5901005802025301025101005B0800701E033C940000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004DAF119D7551D3C2BCCFCCCFCDCCD1CFD0D3D4D4D77C76771D0A0D
2503053502084003074501075201066D040B7D0206930406990C01C66314DCA00FD3A603
D7A407D38111AF2001C20B05C80909C7050AC70408CA070ACF090DCF090CCD0909CD0A0A
CA0807C50303C30201C40101C60302CD0707CE0B09C80806C80A05CB0B06CB0C03CD1005
CB1203C71505C51905C41F08C2230AC42D13C7371CCC4529D35539DA654CF38C78F79C8C
FAA798FCB3A5F9C3B9EDD0C7EFE5DDEFEAE7EFEEEAF0EEECEDECEAF1F0EFF3F1EFF4EFEC
FAEBE5FFEAE2FFE8E0FDE3DDFEE5DDFEE5DBFFE4DCFFE6DFFFE3DBFFE2D9FFE1D7FFDBCF
F1C3B1E3AC97E1A489DA9A7CD48F71C87E62C17257B55F46AA4D35A4402A9D2F1F8D0F0A
9105089501079B0309990106960105970308980208980208970106950106930208900008
8902077B01027501017201006D00006A01006B00006E01006F01016C00016C01016F0001
7101007401027601027801047501057001056C020667070BA851589B464F9F4B528A3638
5803025701035001015001015D07016E1604585A0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063720B8A6049D8C9C7D0CED1CCCDD1CDCFD1D3D3D69F9A9C251114
2C080D3604093B00054301074F010570070F7F020696060AA11104C35714DC9D10D2A202
D6A206D68513B02401BF0C03C60908C6060DC3050AC3060BC6070BC7070AC60506C60506
C60405C30101C20201C40203C60303D10B0DD30F0FCB0A09BE0A05BD1608BB1F0BBF2E15
C33D21CA4F35D26548DA7959E38D6EEA9F82EFAC92F6BAA2F8C4AFFBCFBFFFE2D7FCE6DF
FAE8E2F7E7E2F6EBE5F4EBE6F2EDE9F1EFECEFEEECF2EEEEEDEBE9EFECECF0EFEEF1EFEF
F1F0EFF1EEEEF4F1F0F2EFEFF3F1EFF2F0EEF2EFEEF4F0EEF5F1EEF4F0EEF2EFEBF2EDE8
EFE3DDE9D7CDEBD7C7EAD6C4EAD3C0EBCFBEE9CBB9E9C7B4E6BEAAE7B7A3E4A693A6493E
840707920308980209970209930107920108920007920007950106960107950108910009
8601067700017200007402016E00006900006D01007101007101007001016F01016F0101
7001007101017201017200027001026E01026C0104700C0FC3676D711A23A858619B4E53
7523235C05065100024B0101570400690F03711E0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00742C057C4C3FDACBCAC9CACBCBCCD0D0D2D6D3D4D8BFBCBF2C1B1F
2A080C3302063B02084303084C01046502077C02068D0305A41403C25112DE9C13D2A103
D5A107D68512AC2300B90A01C10604C3060BB60306AB0003B50407BD0305C00304C20304
C10203C20101C30202C40203C90506D30D0FCF0A0DC0090B920402B34733E28769ECA184
EFB299F2BFAAF1C8B5F1CFBBEFD4C1EDD5C6EBD8CDEADBD2EEE4DCF5ECE7F2EDE9F0EDEB
EFECEBEBE9E7EFECEAF1EDECEEEDEAEFEDEEEFEEECEFEBECF0ECEBF2EEEFF3F1F2F0EEF0
F0F0F0F1EFF2F1F0F2EFEEF1F3F2F3F0F0F0F1F0F1F1F1F1F0EFEFF0EFEFF0EDEDEAE7E7
ECE6E7E5DCDAE5DAD6E3D8D2E2D7D1E0D6D0DFD5CFDFD4CCE1D5CCE4D4CAECD0C6B3746B
7B0D0C8B020794040A8E01068B01078C0009910108920008950108980208970208930109
8601067700017200007300007101016D00006E01007002016F0201700101720201710101
7101007101006F00016F01026D01006D01026A02047310118C3034AD5760A5576074292E
994A4C7320235305084700014F0201640D056C18013A950000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0053B11A6C20096C332DD7C2C0A7A5A4CCCCCFD2D2D7D3D3D8CFCDD1372C2F
27090A3104083802074303084E010662030877050A8300029A0C00B7450EDE9C15D1A203
D5A107D88511AB2200BA0903C00604C20609B80407AA0103B00003BA0103BF0205C00106
BE0102C10103C30203C60405CA0808CF0B0CCD090CBA0A0C7202027D4134DCB69DEED4C1
E8D6CAE5D6CEE3D8D0E3D8D0E3D9D0E5DAD4EAE2DEEEE8E6F0EBE9F2EDEDF3EFEDF3EDEB
F2EAE9F3E8E7F2E5E4F7E9E9EFE9EBEDEAEAEEEBE9F2EEEFF2EFEFF1EDEEF2F0F1F1EFF1
F2F0F1F6EFF0FBEBEEFCEAEEFBE8ECFAE7EAFAE8EBF8E7EAF7E7E9F8E8E9F4E4E6F0E1E3
EBDCDDE4D3D4E4D2CFE5D3CDE4D4CDE3D5CDE1D6CFE2D7D0E1D9D2E2D8D4ECDAD5CA9994
7E1E1C87090B8C0B0C961A1B8D121586070D8B030A910208940108950108960208930308
8601067B00027702027501027302016F00016E00016D01006A00006D0001700001720101
7301017302027302027001026D01016A00016601029035359F4C4FBA6F75AB656E9B565C
A15A5E883B426E21284A02074A01015E0B06671301555B0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF002EE012B27A54621B0B62201AAF8D89918583CFCECFD1D1D6D2D1D7D6D6D84F4748
23080A2F050B3502084002074E04095901056C0306860708980D04A93809E09A16D2A104
D39F05D98612AA2100BC0B05C10607C5060CC3070DBB0409B80105BB0104C10408C10206
BF0303C00104C20405C80707CC0A08D10B0CD10B0DC10B0E8407085B2420D4B6A8E8D6CC
E4D8D2E5D8D3E5D7D0EBDAD0EAD6CDEDD6CEF4DCD8F7DDDEFCDFE1FDDCDFFDDADAFFDBDC
FCCBCCFFCDCFFCBFC1E3A3A6875E62BCAFAFEEE9E6F1EEEEF1EFF1F0ECEDF0EEEFF2F0F1
F2EFEEFAE5E7E8ADB3EC9FA5E79298D3828AD0838DCE848DD78D94D38B92D28E96CE9197
CE959AD0979CCE9696C48F87C69489CA9C91CFA69DD4B2ACDABFBBE1C7C7E5C9C9E1B0AE
8A2F2D7F0D0BCB605CE88280C35D5DCB62658812168A030B9102099101079301068E0105
8300037B00027701017601017301017000016F01016D01006D01016E0101700201730201
7301027401027301017001016E00026B0002670103721A1DC1777AA5626764232BCA8A92
9C58608A3F498A414B530F1447010158060569110570200000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0059C229AC80665D1C115D130D91625D8E7C7ACDCACDD1D3D6D1D1D5D5D5D7696367
21090C2C040B3302083C01074703075202076002047601038E0801AA380ADE9715D3A104
D4A005D98912A92300BB0B04C20709C6050BC3040BC2050CBB0106BA0105BE0206C00207
BF0205C30207C40407CB090BD00B0DD70C0FD90F10D00F0FAF1111690907E0AAA2F9D5D0
EFCEC8E6BDB6E6B4A8E4A99DE5A096E79B94EF9C98F59DA0F18F92E98081E47776E37172
E06162E35A5CDD5151D14C4A903432886663F1E7E3EFECECEEEEF0F1EDEEEFEDEEF0EEF0
F1EEEBFEE4E5CA7A7BC64D4FC63C3DB7282CAA1D25AE2027B4252BA91F27A2252D952B30
8C2E319033368B2D2C892C2481251A83291D822D22803229964C4AA55E61A86364AF6262
9732318C201EDC7B7AC56A69953A3CC96F72C15C637F040C8E040C8D00088F01088C0207
8301047A01017701017701017501017302027001016E01016D00006F0101700101700101
7201017201017100016F00016F01026D0102690204620408600E14934C539E5A6397545D
8A454E9F5860954E585B161C4801025704046910086E1C0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE8351A07C6761241A60120D87524FB5A1A1D7D2D7CFD2D6D0D2D6D2D3D6878286
200B112B060C3303083901073F01064C01085C03076D00018C0903A63509E09A18D6A404
D6A206DF9118AA2700BB0C04C40809C6050AC5070BC10308BB0105B90005BC0104C00207
C40408C6040AC9060ACC070BD20A0DD70C0EDB0F0EDA120FD31915B91D1AE87471F99997
E68580C55F55BB4F41B64234B63D31B83C33C1423ACB4A45D04F49D55751DA645DE16A65
DD524FD33733D5463EE1695FD38177C8A59EF2E6E2F2EDECF1EFF1F2EEEFF1F0EFF2F2F3
EFEFEEF8EAE8F5C4BFEA9D96E17A72C14039B61E1DBE1717BD191AA81A1B90211F9F4B45
C27F78DA9993DC958DD58C80CA7C6FBB695CAE5A4DA24A3F9C41399335308624217E0F10
870E10901F21CC6C6EC46E6FD986899B464DC3656E8B19228A030C8C01088C0208890107
8401057D01037601017401007401017201007001016F02026E02026E01016E01016F0101
7302037401037301037101017001026E01016A01016401035F020658070C6C2129C07883
752E38BF7982AC6570671F274D02045905046910096D18003E970000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC875C997B696C332B62140F814A4CDBC9CCD3D1D7CDD2D5D0D2D6D2D4D8AAA8AB
1C0E1225050A2B01043501063C01074B01085A0204760405940E07A02F05E19C1CD6A505
D7A405E0931AA82700BB0C04C10506C7060BC8080AC4050ABD0104BC0106C20308C9070B
CA080CCB080DC90709D00A0CD40C0EDA0E0EDC120DDE1810D6180DDB2319D82924CF2D2C
C5302BB02C22A93426BC5140CE6C5CE78A7FF4A39AFCB4AAFFC1B6FFCBC3FFD6CDFFD8D1
F2A9A59B2E2A9B4840FFD7CBFFE7DEF6E7E2F4EFEAF0EEEBF1EFF0F5F0F2EFEEECEEEEEF
EFEFEFEEECEAF4E8E4FCE9E2FFE1DAF8BEB5BF554FAC1D1BA21B1B6B110CB68178F3D1C8
F7E2DAFAE7E0F5E0D9FAE1D8F4D7CEFBDBD2F7D2CAF5CAC1EBBAB3ECB4ACDB948C98312F
911113870B0FD56E71C97277BA6A6ECE7A82C96B74901D2689020B8F010A8E0108890006
8501067D00037600017300007201017201016F00016D00016A00016800016801006C0101
6F01017201027501047401047001026C01016901026501026402045F02065B050D73202B
74242F6C1D28994F5A6F232C5A070B6006066A0E076E15003D930000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B918A0805DA88F817140395F14117E464BDFCDD3D0CFD4CDD1D5D0D1D6CFD3D6BABABC
1B14161901042501043203083D06094902086106097A0608940E07A02D03E29B1CD7A407
D6A505E0961AA92801BD0E07C00607C5050AC50509C5060BC30509C3040ACA090ECC090D
C90708CA070ACB0806D20C09D70D0CDA0E0EDD150FDF2016F24636E43123D42016BE1F17
A2271FCE796EEFB5A9FBCEC2FCDCD2FDE1DBFAE5E1FAE9E4F8ECE5F8EDE9F5ECE9FAEAE9
FBD9D69F56545C2A21DFCCBEF5EEE5F8F4F0F3F2EEF2F1F1F2F1F1EFECEFEEECEDF0EEEF
EFEFEFEEEDEDEEEDEBF2EEECF4EDEAFBE9E4F8C5C1AA45437C1B19633530E9D8D1EDE4DE
EAE7E4EAE9E7ECEBE8F0EDEBEEEBE9EDE9E7E8E2E1F1EAE8EDE5E2EEE1DCF9DAD6BA7372
8A1417920A10981C23D87179CD717AD5767FC45963870A128D02099101089201098E0107
8400047D00037901027601017401017401017201006E00006B0001690101670000690000
6C01017001037301037301027001016B0002680103640002620104610105630109660610
6707116509137B263077242D650A0F6807096C0C087115033C910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC226A98E719D8B818059555A1817652C34D8C3CACCCBD0CBCED3CED2D7CCD1D4B5B8BA
201C1D0F00011700002701063402054501065600046D01048B0C079C2D03E39A1DD9A607
D5A605DC9315AB2C00BB0C04BE0506C30709C5070AC6070DC40409C7050ACB080DCE0A0E
CD090BCD0809D30C0CD60E0BD90E0CDA100EDD1510DF1F15F34638D02318AF18108A241A
CF9489F2D3CCF8EBE5F2EAE6EFEBE7EEECEAF0EDECEEECEBEEEEEBEEEBEBF3EFEEF6EFED
F8E0DCAE746D531E13BDA391E8DBCEF1EBE6F3F1F0F1F0F2F3F2F3F6F0F1F9ECEDF8E2E6
EBDDDFEEE9EAEDECEAF0ECEBF0EDEBF0EBE8FDE3E0CC8A886C21215B3835E6DED7EBE6E3
E9E9E8E8E9E8EBEBEBECECEDEBEBEBEAEAEBE5E5E6E7E7E7E9E9E8EAE9E8F2E5E4DDADAE
86202394080D97080F8E0A14991E2B9D242F8E0E168C030A900107930208940208910209
8701067E01037900017700017701017501017100016E00026C00026A01016B02016A0101
6B01026C01016E01017001016F01016D020468010561010460000661010865010967010A
6C040C6C070E7D2027832A3166080D660507680A086C11033A8F0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC82EB7A08B92847F9C7E7B551A1C5A1F26C9ADB3C5C2C7CCCED3CBD1D4C7CBCFB4B6B6
322F2E0900000E00002001052F020541010755050A6503077707048E2803E19B21D8A506
D5A505DE9515AB2D00BC0D04C20807C30709C6080BC6060BC9080CCC080CCF0B0ED10A0F
D0090CD20A0DD40A0CD80E0FD70C0DD90F0DDA130EDD160ED91812C71B177506059F6E65
EFDAD1F1E8E4EFEAEAEDEBECEEEEEDEEEEEDECECEBEDEBECEEEEEDEEEBECF0EEECF5EEEB
FBE8E3D19D91612315886353E8D5C5E8DDD7E5E1E0E6E3E3E7E4E3F5E9E9E5BCBFC57980
85494DCCB7B8EEE9E8EDEBEBEAEAEAEBE8E9F3E5E5EDC0BF7E3B3B461818CCBFBBE8E4E0
E6E6E5EBEBECEBEBEBE9EAEAE9EAEAEAE9EAE6E5E5EBEAEBE8E8E7EBEAE9F0E7E7EDCBCA
9C46449710109E05099C040B99040D94030C9202089201079300089301099101098E0108
8801068001047B01027A01027800017903037201026D01016D01016E01016E02026B0102
6900016900016B00016C00017001026E01036600036101055D00055C00046301076B030A
6C040B6D050C700D1274121869090D630407620606680F0277270000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
88A943B29C8CA296948B706F541A1C521317BE9CA1C8C2C7C9CBD0C8CDD1C1C7C7B5B5B4
4A43440C01030F00002101042F02073B01074801055A02076903018A2901DC961ED6A306
D4A406DF9618AA2B00BC0E05C00705C6080BC30709C8070ACA0A0ACC090ACC0A0BCE0A0B
CC0707D1090AD40B0CD80E0FD80E0CD80E0CDB120EDB110BD9120EBE1616570101AA9089
F2E8E1EEEBE8EDEBECEDEBECEEEEEEEBEAEAEAEAEAEDEDEDF0EBECF1E6E6F3E1E0F9E1E0
FCDAD3F8BAAC7E3325572A1FE4CEBDE8DBD1E7E2DFE8E5E4E9E7E3F9EAE9F0BEBEC24D50
A33333916262F1E5E3EDEAE9EBEBECEAE9EBF0E8E9FADCDC9B5A59651E206E4A4BE0D6D5
EAE9E7EBEAEAEAEAEBEBECECEDEDEDEAE9E9E6E4E5EAE5E4E0D8D7E8DDDDEDDEDEF0D2CF
B067628C0E0BA1070AA30308A202099C00079A02099702089401079202088E01088C0106
8901048401037D00017C01017D01027A01027601017201017101017001016E00016D0001
6C01016C01016D01027102037503057202056A01046401055E01045C00036501076A0207
6802076903086D070C6904096B070C68090B610605630D0074260100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78F5DB29E929B929199818056211F511011A47E81CFC6CBC1C3C8C7CBCFB6BCBBB1B1B0
655E600B02031201012401053001073D0108480207590207720803842100DB981FD4A205
D5A507DF9519A92900B90C03C00705C50809C60A0AC70808C70807CB090ACD0B0BCF0A0B
CD0A08D20B0AD40E0BD70E0ED90F0CD90E0DDC0F0EDC100DD8110DC51818650403836260
E9DFDBF0EDEBEDEDEDEEEDEDEEEEEEEDEBECEBEBEAEFEDEEE9DDDDE3C0BFEEAFADF3A2A3
ED8F8DE7786FA93930500E06C3AB9AE7DACBEBE6E0F3F2F1F7F5F3F0E7E5FED7D5CA5A5A
BB3935702E2BEFDDD9F1EAE8EBEAE9EBEAEBEDE9E9F7E3E3CA8E8D81222368191C8B6669
E8DDDEECEBEBECECEDE9E9E9EBEBEAE9E9E9E8E6E5DAD0CED1B5B4D2A5A8D29EA0DEA5A5
E5928F981A18A20609A9040BA70309A101079B0208980106B41C20C22D3195060B8B0003
8B01048702057F00017E01027F02027C0102790101760201740101730101710101700101
7001017001016F01017000027200026F01026C01056701046001045F0105630105650105
64020566020768050965010769050B6B090C650908631205742A0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9363BBA79E928A89AE9D9B5A2E2B511011885B61D0C2C9C0C0C5C4C7CBAEB3B3B3B2B3
7D7A7C09010416010329050C34020A40030B4601075F030983110D801A00DB9820D6A406
D6A607DF9319A92800BB0C03C10906C50807C50907C70908C80809C90708CA0607CF090B
CF0B0BD00A09D30D0AD60E0ED70D0CD80D0DDA0E0DDC110FDB120ED41816A414145A0D10
BB9E9EDFD8D7F0F0F0EFEFEFEEEFEEEEEDEDEEEEEDEFECECEEDFDEDDAFADBC605DC94341
CD2F2DD02821C42B26680C08947567E3D5C6E9E4DCF2F2F1F0F0EFF3F0EDFEE8E7C97776
AE32306D1D1BCAB1ADF2E8E6EFEBE9EAE9E8ECE9EAF3E5E5E8B8B6932B2B9B1E2172151B
8F6268E3D7D9ECEBEBEAEAE8E9E9E7EBEBEAE9E9E7EADFDCCCA5A494484990292D9E2E31
B4383CA31315A7060AAA0308A80208A10006980105980104B21418C22327B41E248E0105
8E01078C01068501027E01007C00007B00017A0002790202780202730000710000710100
7201017101017202017101017101037001056D01056700046000035C00045E0005610106
61010662010566040866020867030A69060B650A0A6E21157E381400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9063B9A69EA69E9E8D807D734A49500E116E3A43D2BCC6C3C1C7BFC3C7AAACAFB0AFB0
928F8F0D050717020426030B30020B3801083F0007550209760D0B821D00D8951ED6A507
D5A605DA8F16A82600BA0B02C10705C70908C50807C80808C70607CC0A0BCD090ACF080B
D10B0BD00A09D20C09D60E0ED60D0CD90E0DD90F0CDB110DDE130DDE1410D41B19A41417
69161BAA888EE5DDE0EEEDEEECEEEEEDEFEEEDEDEDEDEBECF2EBE8FCE3DFF9BEB8D76E65
C53125D7261AD0231C96211D643930DCCCBEE9E3DAEFEFEEEDEDEDEEEBEBF8E8E6D89A9A
A332308729259F7A77F4E7E2F1EBE9EDEAEAEDEAEBEFE7E6F8D4D2A84746AD1C1CAD1A20
7E161E86565CDDD1D2E8E6E5E7E6E5EBEBEAE8E8E7ECE8E5F3DBD7D89C989A35319F1718
A90E13AB080DAA0408AB0408A90208A6020AA10309980305B11E23A8161D990A118E0209
9001089202068C01038100017C01017A0102770001760000770101760102730000720000
7101007000007101017101027201047301057002066701035E00025A01035B01035F0106
63030961020664030765010767030A66050B5F08096D2218CBA99C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE976BB6A89F9A9898968D8C8866664E0F13582028CAB1BBC0BDC3B8BBBFA9AEB0AFB0AE
A2A29F140D0C19040624040A2E030C38020B40010A4700075F0604761901D0901BD6A708
D6A807DA9017A92700BC0D05C20806C60809C40606C8060AC80708CB090ACA0607CE070A
CF090AD10A0AD20B09D60D0DD60D0BDB0F0EDB110DDF130EDE120CE2120EE11612D91A1A
B71E2175121B9A6A72DFD0D7E7E5E8EDEFEEEAECEBEDEDEDECEBEBEEEAE6F7E7E1F8CDC2
DF8676C53B2BCF2A20AC221E53140DD1B9AEE8DFD7F2EFEDF0EDEDF0EDEEF5EAEAEDC4C4
B05B58A5524D9A726DEFDDDAF0E9E7EEEBEBEFEDEFECE6E7FAE0DEC0706CAC1E1BBF1618
B3191E84191F79434AD5C4C7E6E3E2E8E7E6EAEAEAE9E9E8EBE6E3F5DFD9DDA59EA43C38
A41312AE0A0DAE0509AB0307AA0207A80109A50209AB151BCC4C50D65F6382080A850004
8F01069200059001048701037D0001790001780101780102780102770201730001730101
7201007101007000007101027201037101036D01036802035E0101590101590103580003
5B01065D01066102076101056605096505095C0507641B11C6A59800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE9B6FBAAEA58C8D8DA5A0A27C6363470F13451014B69BA2BDB8BEB7BABEAFB5B4AFB1AF
B4B7B32723211C0A0C26050C2D01093E040E46040D49020A5905046B1600D0911FD5A609
D4A506D98D16A52300B60701C20806C50707CA0A0ACB090BCB090ACE090BCD090ACE080B
D10B0CD20A0CD40C0DD60C0DD80D0DDD1010DC110CDD110CE0140DE2120EE41310E51512
DF1A18CA212492171E77343DC1A6ABE0DCDDEDEDECEAEBECE9EBEAEAEAEAEEEDEBF5E9E3
F3CEC2E89686C13D30BB2A24610E08A98C84EBE0D9F1ECEAEFECEDECE9EAEFEAEBF7E6E6
F9D5D0FBD5D0F3DCD7F3E6E5F2ECECEDEAEDEDEBEDE8E4E5F5E3E2E4A4A2A52422BD1211
BF1111B1161A881B2169393AC9BDBAE8E4E0EAE7E8E8E6E7E8E7E7EBE6E4F3DEDBDCA39E
A0342EA30F0FA60205AE0508AE0508A80106A40107A1070DBE363DC5494E9D1B1E910409
9201069301069401078E01058400037A00017801017900017A0200750100730001740102
7201017101007202017301017301037001036B01026802035F0102590003560003550004
5500035900055D02075E00056102066105075E070763180FC5A29600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB986BBCAFA799999B8A87889E8A8A4314163F0B0BA4878AB9B3B5B8BABEBEC3C5C3C8C9
CBCFCE3D3B3D1E0B0F28070E2D02093F060D430309480108610B09691300CC8C1DD4A309
D5A307D98A18A62000B50802C30B08C40705CA0A09CA0808CC0909D00A0CC70305CD090A
D00B0CD10A0BD30B0CD60B0ED80C0DDC0E0FDA0F0BDB110BDE130CE21310E41412E71712
E81812E51B16D7201EAD21236C1B1F967A7AE1D9D7EBE8E7EBEAE9EAE9E9E9E8E7EDEAE8
EFE2DCF4CEC3DF877AB632297D16107C5552EBDEDBEDEAE7EBE9EAEBEAEBECECEEEEECEB
F0E9E6F1E9E6EFEBE8ECE8E9EEEBECEBE9EBECEBECEBE8E9F2E5E5F1C2C3A83939B61715
BA1410AF18149A252262231E786059DCD2CDEBE5E4E8E5E7E6E5E6E6E5E6EEE6E7F1D8D6
D5928E961F1BA50C0BAA0507AF070AAB0409A70308A4020A9E040D99050C9C060B980206
9200059502079701089602088D01068201037C00017C01017A0100760101740101760101
7301017101007301017401017501037301046E0104680203610103590103560103550102
5300025801045C01065F000563030863050860070767180FC9A59900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9667B5A89F9897968E8A8AA08F8F4B1F1F41090A8E6B6DBCB4B5B9BBBFC1C6C9C6CDD0
D2D7D95152551B0B1124050C2D060A38060A3F0307460004610A07691301C68619D29F08
D3A008D78515AA1F00BB0A05C40907C80908C80909CA0A09CD0909CF090ACE0909CD0809
CF0A0BD10B0CD10B0BD60C0DD90E0EDB0E0FDA0F0CDA110CDA120EDC1211DC120FE21610
E91A11E61710E11E15CE271FA12E2863312BBFAEA9E4DDDAEDEAE9EAE7E7E9E8E6EAE9E8
EBE6E4F4E2DDFAC1B6BF4941A0241F5B2220E7D6D3EDE8E6EAEAE8EBEBECECEDEDE7E5E5
F2EAEAF2E6E6F0E7E9EBE7E8EBEBEAECEBEBEDECEBEBE9EAEEE7E7F6D5D5B8615FA5201C
9A1A12811D14AA6358C3998FDCC7C0E6DCD7EAE5E4E9E6E9E5E4E6E8E7E8E7E4E5EDE2E2
EDC8C6AE57529B1511A30508A60308A60308A60107A40107A10107A00108A00108990106
9100049301069802089902089301068B01048300037D0100790001760101760000790202
7702027301007301017501027702057401046E01036701026100025B0004570103550103
5601045801045D030761020663030665040863070966160ECFAA9E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99262C2B5A99897939B97968F7F7E552928480B0B794F51C1B6B7BFBFC4C9CED1CDD1D5
D3D8DB7072741B0F12280B0F2B04083505093F02084F050A5E0908641100CB8B1ED4A10A
D4A008D68315AA1E02BD0B07C30606C9080CC90B0CCA0A0ACE0C0BD00B0CD10B0BD0090B
D10B0CD20B0DD30C0DD4090AD80E0DD80D0DD90F0FDA1312D61313D20D0DD00B06DE140D
E21912DA1C15C72519B03327C27165DCB6AFE9DCD6EBE4E1ECE9E8EDEAEAEBEAE8EAE7E7
EEE7E5F3E0DEFDC5C1C84E49BC2C275C0C0BBCA3A0EBE2DDEAE9E6EAEAEAE9E9E8E7E3E1
EAD5D5D1A5A9A6777C7D6164D6CBC9EFECE9EEECEBECEAEAE9E6E4F1DCD9CD8E8B862522
530602B4897EF1D7CDEFDFD9EBE1DEEAE5E3E7E5E5E6E5E6E5E4E7E3E1E3E4E1E4E5DDE0
EDD4D3BF7D778A120F9905089C02069F0107A10108A000079F01059E01079B0106960005
9000048F01049300059600069300068F01068801038100017C00027A01037A0103790103
7600017300017300017400037401057301046E01036900026401025E0103580004540004
5200045100045300055A01046103066303085F0407621107AE756000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99161C3B5A99F9D99858281A99C9C5E37364C0E0D64363AC7B8BBC6C7CCCCD0D4CFD3D8
D5DADE86878B1B1112280C0F2C050A34040B40030A53040B5705045B0F00CD8F1FD6A209
D7A30AD57F15AD1F01BF0C08C30607C9080CC7090BC80708CD0B0BCE0A0BD10B0CD20B0C
CD0707D20A0CD40C0ED60C0CD60C0CD70D0DD90E11D40D10D00D0ED00D0BD20C08DA140F
D51B17A81612A14036E9B1A6F8D8D1F1E5E1EFECE9EAE8E6EAEAE8E8E6E7EBE7E5EDE4E1
F2DBD9F7C7C7F09191CE3533CD28237A100F8A6763E8DBD6EEE9E6ECEBEAEEEDEBF1EAE9
F0D1D09C4B4F9C393D561415A88886EFE5E2EBE7E8E8E7E7E9E7E5F0E3DFE0B1AF7B3130
420F0BD9C8C0EBE3DDEBE5E3E7E5E5E7E6E7E4E4E5E2E2E3E1DFE0E1DCDCE3DCDCE4D5D5
DDBEBBB8726C840D0B9303059401059600059901079C0209990006990106980107960107
9100058F01059101049401059301059101058D02058601038001047A0002780102780102
7500007501027501027501047300047300047001016D0203660102610104590104560105
5400055001054F00055401055A01045D03065A0101620D0384351400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9060C0B1A69E9B98908D8DA2989A6A4648490E0E522226D2C1C5C9CAD0CDD3D8D2D8DE
D5DADE9C9CA11E1415280B0E2F080D35050C3E020A580A125B07085D1200CE9120D6A409
D7A109CD7411AE1C00BF0C06C40606C8090BC8070AC9060ACD0A0BCE090BD10B0CCF080A
CE0808D20A0BD30B0CD60C0ED50B0BD80D0ED70C0ED90F10D8110FD9110DDE1510D61411
B31413630C0BD9B0A8F3E2DBF0E6E5EDEAEAE8E8E8EAE8E8E8E8E6E6E3E3E3D6D5ECCAC8
F2ADADE07174D13839E02624DB231F9D19175E2B29E3D4CEEFEAE7EDEBEBEFEEECF2EBEB
FDE0DFBE6668AC3132791B1A7F4D4BEEE1DEEAE5E4E9E7E8ECEAEAF0E7E6F5D2D3995353
4B0F0CAA9590E5E2DEE7E6E6E8E7E7E7E6E8E5E4E5E3E0E1E1DBDADBCECBCEB6B0C79E97
BF7D7696312C8E0807950204950104930002950004950106940105940106930007930108
9201069001059001039301049503069001048A01048601058001047A0002780102770102
7500017300007400017601037702057501047201026C01026401025D01025A0103570104
5300044E01044C0004500106550004570103570101650D0286311100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BA905DC6B7AC969593A4A1A5897F84856769430D0D48161BC7B2B7CACAD1CFD7DDCDD6DD
D6DCE2B0B0B51F181A22080B2D060B33030B3700074600085806095D1100D09320D7A60A
DAA40DC76D11AD1900C00B05C50706C50709C70509C90609CC0808D10B0CCF090BCF070A
CF090AD40C0ED40C0CD60B0ED40A0AD80C0FD70D0DD90D0EDB0E0DDF120FE1140FD71613
A10F0E4A1313D8C7C1EFE8E6EBE8E8EDE9EAE9E7E8E9E8E6E8E7E5EBE6E3E4D3D0D19B9A
B94C4BD03130E42722EA211CE5221CC02323560D0ACAB7B2EAE6E2EEEBEAEDECEAF1ECEB
FAE5E4D08585A82E2E96292862211FE3D1CEEEEAE8EBEAEAEBEAEAECE7E9F7DDDFBD7876
7F27265C2827CFC1C1E8E7E5E5E5E5E7E4E7E1DDE1E1DCDDE2D8D8CBB5B0AD8074913F34
8B1C158E0907950303990102990103970203940003920004920005910006910108900108
8F01078F01059001049000039001048C01048600038200028100028A0A0C840C0D730101
7402027401027401037300027801057902067501046C01036300025D00015A0002590003
5400034E01044900024D0004580207580206550001620A028A341600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78D59C3B5A8A5A6A589898E9E989C836B6B411211420D11B79EA4CCCAD0D0D7DBCCD5DA
D7DCE2BFC1C5201D1F240C102E070D33040C33010640010858090B651700D49722D7A608
DCA40FC56712AD1701C10C07C40607C60609C80508CA0608CB0808CE0A0BCE070BCE070A
D00A0BD20C0BCD0705D40B0AD50C0BDA0E10D80E0DDA0E0EDD0E0EE1100EE41412DD1512
B71613520203A7908FE9E2E2ECE9EAECE8E9E8E6E7EBE8E8E6E5E3EAE7E4EFE3E1F1CBC9
E28E88CE473DDD2E20E8241AE7221AD428256B0B0A9D837EEAE4DFEEEAE8EBEAE8EEE9E7
F5E6E3E7AFAC9E352EA3352E6C221ABFA79FECE6E2EAE9E8EBEBEBEAE7E8F5E4E4E8ADAB
9B302E7B1819733E42CDBBBDE6DFE0E3DEDEDFD9DCDDD8DAE0D8D7E1D0CBCDA295A04D3E
8D12099304029701019902039701029501029201029101039201069302089201098F0009
8E01088E00059101048F01048F0106890004840003890002980407B11E21D14B4EBE4647
7A0A097101037001027101007A0304870B0F7600036C00026700026201035E00035B0104
5401034D01014900014D0003550207590208550002610801903A1F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B58D57C3B7AAA2A5A4909497979697806F6F3E14143D080C987D83D2CFD5D0D6DAD2D9DF
D5DCE0C6CACE282628220B102C060E36050F3502083C0109570A0B691C00D79924D8A90A
DCA410C06010AF1601C10A08C30708C60609C9070AC90608CB0909CD090BCE090CCE080A
D20C0CD20C0AD10C07D50E0AD80E0CDA0E0EDB110EDC100CDF120EE31210E31310DF1310
D218159710115F1A1EC4ABB0E7E0E3EBE8EAE7E5E6E8E6E7E7E5E5E8E7E6EAE6E5F0E5E2
FCDDD7F2AFA4D66152D73226E1251BD524208B16176F4743EADDD9EDE8E6EDEAE9EDEAE8
F1E8E6F2D2CCC17F73C07468AA7164BFA69CECE4DEEBE8E7E7E8E8EBEBEBF3E9E9F8CCCB
A73F3AA71E1D86161B74353CC7ADB1DFD5D5DFD8D8DBD6D7DBD7D7E0D6D5E6D0CAD6A598
A850428C0F079404029601029501029201028F00018E000290010390000691000891000A
9202099101069101058E01048D01068802078400039A0207AD050CAF060BA5080AAB1A1E
AA272C7300017000027201027A02038E11157601046E00036B0204670103630204600307
5602054F01034A01024B00035100065600075A01026408018F361D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18954CABFB2A1A6A59EA4A6808181A193934824263B090B765A5DD4CED4CCD0D5CDD4DA
D5DDE0CCD1D52A2A2D1E090F28030B35030F37040C3A01074B0506621800D29823D4A608
DCA513BD590DAF1400BF0907C4070AC30408C50608C60506C80708CB0709CD090AD00A0A
D00C0AD10B0AD10C08D40D0AD70D0CD80C0CDB0F0CDD100BDB100AD80B08DF110EE21212
DD1212D01919A014196B1720AD868EE0D3D9E7E3E6EAE8E9E9E9E9E9E7E8E9E9E7ECEAEA
EFEAE7F7E3E0FBC6BDDE736ACE2F27CC1E1BA21D1E4F1717D9CBC6ECE6E3ECEBE9ECEBE9
EEEAE7EDE2DEF6DED9F9DDD7F7E0D9EDE1D9ECE6E2ECEAEAEDECEDEAE9EAEDE6E6F4D4D3
BD625FB21B19B4151A8D131A651F25AD9194D7CDCCDCD8D6D8D5D5DCD8D8DED5D4E7D3CE
D7AB9DA852458D120B9303039100029000039001048E01038E01048F0106910108910108
9301099302089102058C00038802047F02048000029D0408B10208B40406AE0203A90307
9F050A8401037400027602057D07098F161A7300046E01056C01046701026201025C0003
5501044F00034900024800024F01055502055A00026407018A2E1500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18651CFC2B5B6BABA8B9394999B9C8C83834D2F2E3C0A0A694B4BD8D1D5D3D7DBCAD1D7
D5DCE0D5DADD393B3F1C0A102A040E33020C3702093D0105520706641A00CF9825D1A40A
DAA114B8500AB01300BC0604C4070BC30409C40608C5070AC80708CD090BCF0B0CD00B0A
CF0C0AD10C0BCF0A08D20A0BD40B0CD70C0CDB0F0DDD100BDA0F09DD120CDF120EDD0D0D
E11111E01315D71919B91C207C111A864A56D0B8C1E1DBDDE6E4E4ECEAEBEBEBE9E8E7E8
ECECEBECEBE9F6E7E4FECBC5CB5C57BF211EB42121590A09B9A09CEDE5E2ECEBE8EBEAE8
EEECEAE8E6E3E9E5E4E9E4E4ECE8E6EDE8E6EFEDEBECEBEAE9E7E8E7E5E7EBE7E6F2DCDB
DC9390AB1F1EBF1214B20E149212195D1217957776D3CBC6D9D7D3DAD7D5DAD6D6DCD4D2
E5D2CBD7AAA0A44D448C0D0B9102049202059101058E00038C00038D01058F0106900006
9201089302098F01058A0103840205750102760001980409AF0309B10104AE0002AC0102
A802059403057C00017601047E0A0C9B282A7101046E01046D01046601025F01015B0102
5401025101044C02054701024A0103500104550001640802862C1100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8DAD49D3C3B7AFB2B1969B9E989B9B8881804B2F2D400C0D603C3EDDD3D8D6DAE1D5DCE3
D1D6DDD5DADF4042471D0A122F081037040E40030C4E070C600F0C681B00D39A26D2A50C
DB9F15B24708B21202BE0706BE0407C4060AC50709C4050AC70608CC090ACC090ACD090A
CE0B0ACF0A0BD00C0CD40C0DD50D0ED70D0DDA100ED90D0BDB0F0CDE120DDE110CE11110
E11110E31212E1130FDD1817CD1F229D17206E1D28A38083D8CDCCECEAE7EAEAE6ECEBE8
EBECE8ECECEBEDEAE7F9E2DFECA5A2B62B27C52423871110935957F3DDD9F0E7E4EBE6E5
ECE9E8F0EBEAECE8E6EFE9E8EFE9E8F1EAEAF0E9EAEEE8E8EFEAEBEEEAEAEAE5E6F5E6E4
F7C4C2A8312FB70E11C20E13B60F15941115570B0B81625FCDC4C1DCD8D4D9D5D4DBD6D5
DFD5D6E7D2D1CC9B9592302B8B05059201049101048E02048C01048B00028C01028E0103
9102079001098B00058700048302056F0103690001890308AA060CB00307AC0001AA0101
A902039B03048100027902057801047702047301036F01036D01036701026000015A0102
5501035101044C01044801034600024A000256000165060281260C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B68853D2C1B6A7A9AAABB1B58A8D8F9A95966147483F0A0D542A2DDACCD1D6DAE3D6DEE7
D1D8E0D5D8E14D4F551E0A132C040D39050E43050D4F060D510302681D00D49B22D2A308
DCA017AD4006B21103C00908C00609C2070AC30607C3050AC50609C9080ACD0B0CCC0809
CC0A0ACF0B0DD00A0BD10909D40C0DD50B0CD40B0AD80C0CDC0F0FDE0F0EE11211E2110F
E2120EE61411E71712E61612E31916D91C1EBB1F227A1517875858D9CBC9E9E6DFEDEAE5
EBEBE6EBEAE8EEECEAF8E9E8F6C0BFB43532CC241FBB221EA93E3AFDC2C1FCD8D8FAD7DA
F8D6D9F9D6D9F9D3D6FBD4D6FAD2D5FAD5DAF9D2D7F9D1D7F8D4D8EFCDD2F3D4D8F6D2D5
FFC8C9BD4849BA1315C20D11BB0A0EAC090E8F0D11580A0C795959C8BDBBDDD5D4DDD8D8
DBD5D8DFD6D7E1C8C4AC6661810B089003068F01038D01038C01038A01018A01018A0001
8C01028B010687000487010483020572020560000072010395050AA30306A60202A80203
A802059A03067F01037300047902087801057300047000036C0002660103610203590001
5501035101054A01034600014300014900015E02046F060384230C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CD37D2C3B6C0C3C59BA3A79FA4A78C888A6952523E0B0E491B21D9C7CED7D9E0D2DAE1
CED8DED4DAE1575A611F0E172A060E3302093A010A44010B4C04036D2502D49C20D6A509
DCA017A73700B21003BD0805BF0607C00609C20508BD0207BE0206C8080CCB090ACB0709
C90609CB0709CE080AD00809D30B0BD30A0CD40C0BD80C0BDB0F0DDA0C0EDE0E0FE31111
E61510E91611E7160FE81711E81713E61714E21C19CC252386171966393BD4C8C4ECE7E3
EAEAE7ECEAEBEDE9E9F5E4E4F0B7B8B83636C41E1ABC2B26C7544EBD605EC46B6EC36169
CD636ACE6067C85B60C15258BD4F55CA5D63CB5D65C65C63C35E66B95B63B96168C66C6F
D76C6DC53937BF1412BF0B0CB7050AB00308A6080D88101544050679635FD1C6C5DED5D7
DBD5D8D9D4D4E2D2CEBF8A837E14108D03059001048E02048C01028A01018A01018A0101
8800018801028601038500028201027602045D00015D01017501038701039403049B0304
9C04078A02057000016C01047802077B01067901077401046E01016700016100025B0001
5300015101044D02044801024500014B000162010473040386210B46990400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DCA34D1C3B7BFC3C69EA6AA9EA4A7848485725F5E3F0F11411116CFBCC0D4D7DBCED7DD
D0DBDFD5DCE25E636A190B1425050C31030A39030E43020C500805722A08DBA225D6A509
DE9C18A83300B20C01BD0808BD0506BE0307C3060ABF050AC1050AC50408CB090ACA070B
CA060ACC080BCE0A0CCE0809D30B0BD60C0EDA100FDB0F0DDA0F0BDC0D0CE11011E5110F
E5130FE5130CE7170DEB1811E71611E61510E91B13E11D19BC2525550D0CAB9792EDE4E1
EAE8E7ECE8E8F1E7E8FADADED9878CB8262ABD1D1B820D0CEDAAA3ECADA4D17F79C05553
BE4140BC3737B83231B52F2DB5312EB3322DB23432AA322FA333329E35359D3737AB413E
B13932B32920B91D15BA140FAF0807AD0608A404088E0A0D5607054B2922BFAEA7E1D6D7
DCD6D8DCD6D6E1D3CEBE8F867F18138F03069101038E01028D01028D02028C01028B0101
8902018701018600018500018400017D02036501015200005A00006A00017601037D0003
7E01057001045D00026400027901067F01057F01067901047101006C0002690104600202
5801025101034D00024901034701014F0000670305740402801A0544960200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CC37D8CABFB5B9BBB2BBBE848D8F929394877878401213430E13BCA8ACD0D4D6D0D9DF
D0D9DFD4DAE07074791B0E1724050B31030B38020A3F01074E0603772F0BDCA222D9A50A
E09919A82B00B50D02BF0808BE0608C1070AC30709C3050BC20409C8060AC9060ACA070B
CA060BCC080BCE0A0CD10A0CD30C0BD70D0CD70D0BDB100CDC110CDE110EE00F0DE5130F
E61410E71610E5140EE91610E81711E5140EE4180ED81A16A618157A342DDDC2BBF1E3E1
EEE1E2F2DEE0F6D1D3F3AAB0C04348C41C1FC61C1B941416894B49F9D9D5FDE2DBFFD5CF
F9BDB6EDA7A1D88E85D1867CCE867BD18C83DF9D95E5A8A1E8B1ABEEBCB5EEBCB6F8C3BB
F6B8ACDF9284D6786BB64338A31D15A5120E9C07077D0304590D07906755D1B9ADE4D4D0
E1D6D4E4D6D4D9BDB8AC6C647F0D099202039501039101028E01028C00018E01018C0001
8A01018701008601008600018601018402037D0A096409075608077223225E0B0B5D0104
5D01045700035200016301037B02068201058402078001057701027101016B0103640203
5D01035401024D02034701024301014F00016A03047302017C160246970300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D9CDC3BFC4C5A1ABAD959E9F8486867F7271441819481015B0969CD7D8DDCFD7E0
CFD7DFD7DBE27D8086190C1326050C2D02073805093D03074A0702813A12DCA221D7A308
DA8E17A82500B80D03C1090AC00509C4060BC5070AC7060BC60508C70508C9070AC80609
C9070DC9060ACD090BD0080AD30A0AD70C0CD80E0BD80D09DA110ADB100ADD100AE1120E
E3140EE81811E5140EE6130EEA1611E91710E81B14CB14119E1C1BE9A19EF8C5C1F9CACC
FAC3C8E99EA4D26C71C0373CC72020D11717D01715C11D1E87181CAD777CF1DCDCF6EAE7
F6EAE6F6E6E3F6E5DFF3E2DBF9E9E1F6E7E1F5E6E2F5E8E5F0E6E3F1E7E5EFE7E3EEE6E1
F0E6DFF4E1D9F7D7CFEEBDB4D1877EA94039991B17800906AB5247D09181CE9D91CBA19C
CBA3A0C89895BC7B7594302C8C06049301019401029101018E01018E01009001008E0101
8C01018801008701008600018601018601018205039B37306C211CD69A97CD92935C1818
4E00025200015C00016F02047D01058302068601068702077F02057401026C0102650001
5E01025500024F02034500013F00005000026E04067403017D150245950200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D8CCC2C6CCCDACB6B89DA5A7787C7B908684563232440D119F7F87DAD6DFD1D7E2
CED7E0D6DBE486898F1A0B1326050C2D02093301064003075107028C4312D99F1ADAA40A
D68416A71E00BC0E06C20809C3060BC7050DC6060CC8060BC70608C80708C80707C7060A
C7060BC80509CD080AD0090AD50C0CD60B0BD60C0AD90F0BDB0F0ADC100ADE110AE2120E
E4150FE5150FE6160FE7150EEA1712EB1713EA1B15DA1917E24748EF7678E76B6FDA5B62
C33D47BC2631C92228CF1A1BD61715D71414D51413D11516C31E23951E28AC6970EDCED2
F3E5E7EEE8E8EDEAE8EBE7E7EDEAE9EDEBEBEBEAE8EDEBEAEBEAEBEAE9E9ECEAEBECEAEA
EAE9E7EBE9E6E9E3E1E7D9D7EED4CFE8B7B0BB69628E211B971F1BA0302CA33B3AA64343
A441419B31318E16168E08079603049601029401029100009101009102018F02018C0102
8B01018A0100870000860101870101860101820202851613AA534E85423D995C596D2525
5F06076802057502077E02068201058B050A8E050B8B01088502067800027001026A0001
6201015901025101034801024200015401017104067401017F150547950300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8AAA45DACEC4BEC5C7C2CCD1838E90888F8F9894924C2E2C440D108E6972DDD6E0CFD5E0
CED8E1D3D9E38F8F981D0D182B071030020B3401073F0206580F058E4612DAA31BDCA30E
CF7712AA1B03BA0C07BF070AC20509C5050CC6050BC9060CC70508CA0708CA0809C9060A
C70609C90708CC0809D20C0DD1090AD50B0CD90D0CDB0E0BDD100BE2130FE3130DE71611
E51510E71611E1120DE5140FE7170FEB1812EB1A13E71814DF1D1BDE2323DE2325DB2026
CC1118D1131AD71718D61213D61312D51313D51314D71416D7181BCD2025AE222BA13F48
CA8890EFC1CAF7D8DEF7DEE3F9E4E9F8E5E8F6E3E6F7E1E5F9E3E9F8E3E7F4DDE2F6DCE0
F7DDDFF4DADEEAD4D7E2D1D3E2D4D3EAD8D6ECC5BFC0736E9019179C0C0F9E070D9B060B
9E080D9C06099A03069801039801029701029601029300019301029201018F01018A0002
8A01018B02028802018600028702038701048601048104078212139C3C39A34846A34140
9727287F04088301078601068901068E030A91040C8E02088801067E01057501036D0102
6401015901015300034B01024800005D01027502047702028014064D9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B0814ED7C8C0C3C8CDA9B4B98B999B8992948483825E42424911127F585FDED6DFCED1DB
D0D8E1D2D8E191939C1B0C172A050F31020B35030A3A01054504008C5017D8A51BDBA30F
C66A11AB1903B90B08BC0509C00609C4060CC6060CC7040AC80609CB0709CB0909CB0909
CA0909CE0B0DCF0A0BD10A0CD40C0ED4090CD90C0EE01011DF100CE0100BE3110DE5140F
E51510E51410E00F0DE71511E8170FE7160FE91810E91813E71612E81816E31715DA1212
D40E10D30F11D91516D20F10D31011D71515D31112D51213D91615DA1919D41C1ECA2126
B8262EB43844BB535DC96B77DE8791E897A0DA8691DC8693E38998DD8491DC7F8CD97B86
CB6A74C76A73C57279B06D73B27F84C5A0A2E1C3C2EBBFB9A54C46950B0AA60309A60107
A40006A100049F00049C01039A01039700029601029600029400039401039200048D0101
8C01038A01028701018600028601038600038700048600068201077E04077E0507840609
8603088802088A02098C020891040B95070E94060B9003088A01078101057801046E0102
6501015C01015501014D01015000006701027B03057D03047F12064C9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5EC935D6C6BDCDD0D5ABB5BAA1AFAF7E87887B7B7E84696C47101371474EDDD3DCCED1DB
CED3DCCED5DD8D9298160A1426060D32030C37010B44060D490A039A601AD6A516DEA412
BF5E0FAD1604B90807BC0508C1070AC3060BC20409C7070CC8070ACB090ACB0909CD0908
CE0A08CF0909D10A0AD2090AD60D0DD70B0DDB0D11DF0F10E0110EDF100CE1110CE61512
E2120EE2100FE41211EA1613E5140FE81711E6150FE91813E81713E61815DB110ED10D0B
D00D0DD4110FD51311D31111D41313D41211D71514D81312DC1814DB1513DE1A17DE1B1A
DB1C1FD11C20CE2126CC2329CB272DC6252EBF1E2AC3212EC21E2CC41F2DC31F2BC11B25
C21C22BD1B20B2181E9F141B8E131D7E1B2489464AC89694D58E868E1510A00406A40003
A20102A00003A001049E00049B00049A0105960003960104970106970107930003900102
8F00038F01058B01048700028500018501028701048601058601078501068700058C0208
8E02098E020991050B91030A91020A95030B96050C8F01078A0107820005790003700102
6601015D01015702015201015901016E02037D01037E03037B0D034D9C0C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC733D9C9C0C6C8CDBFC8CD8B9799858E90929296654E524B141864353DDBCDD5CCD2DA
C8D1D9CCD5DD90979E18101729081034030D39020D3B0105480A01A36A1BD8A414DEA114
B64F0AB11503BC0807BD0407BE0408C2050AC20509C20308C30408CA090CCC0A0AD00A0B
D00A0BD20A0AD50D0CD50C0AD90F0CDC100EDC0F10DE0F0FDD100DE0100EDE100EE11111
DE110EE51311E71512E61510E71611E4130FE3140EEA1711E91814E41614D70F0FD00D0C
D00E0CD10F0ED71513D31111D21110D51311D81511DC1614DD1713DE1716DD1715DF1917
DC1916DD1916DD1A16DB1614DA1717D81719CF0F14D21217D31115D7151AD31114D31214
D11113CE1012C30C0FB4070CAE0710A00811890C13761417C36461A42624A10408A50106
A101029D00029E01039F01049D01069C01089A0106990105990106970006940003930103
9100039101048D01048901028802028601028601038500048601058701058800038C0005
90010890010890020A8D010792030C96030D99070F93030B8B01088401067D0204740101
6901015E00015801015700006502027503037D00027D0203780B0149980800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC832D6C4BBC7CACFAFB8BD8E999C8E989A888A8D7C696C43101358282ED7C9CEC9D0D6
C3D1D5C9D3DA9AA1A61B111826070E33040C37020A390205400701AB7318DAA714DF9F16
AC3F04B51303BE0A07BD0307BD0408C3060CC4060BC5050CC6060BC60408CA0809CE0809
D10B0CD1090AD30C0AD60E09D80F08D70C07D90F0BDA0D0BDE110EDD0E0EDB0D0DE11111
E41412E41310E4140FE61511E71712E71713E61612E91813E51612DB0F0FD40C0ED10C0E
D40F0FD20D0ED41110D10F0FD00E0FD61414DA1714DE1816DE1816DC1514DB1615DE1818
DF1B1AE01A18DD1914DE1815DD1816D41211D41212D61413D71414D71314D21011D20F10
D10E0FD10F12C3090EB8070DB0040AAC0208A5040999070B960B0EA30E11A30207A50106
A101049E01039F0104A001059F01089D01099C02089A01079A0106990106960004920104
9100049100058F01058B01038A01038801028600018501028500018601028701038B0105
9101089101098F020A8B01088F030B95040D96040C94040C8C01088401057E0103770103
6E02036201025900005D00016D01017801037F01047F03057A09006B600A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59C42CD8C7BACCCFD3B2B9BFA5ADB17F888A8083859A8B8E3F13154B1C21CEC1C3C7CED3
BFCDCFC8D2D69DA3A71A121727090E2E030838040B3D050A450B01BC841ED9A510E29E1D
A83400B71104BE0808C00609C00709C4070CC50509C60308CA070BCA0709CD090AD10A0C
D20B0DD50B0ED50D0BD70D0AD70D08DB0F0DD70C0BD70B0CD90C0DDC0E10DC0E0FE41213
E41312E51313E2110FE61413E61511E71413E71512E51413DD100FD30A0AD30D0ED40C0F
D60F10D40E0FD71313D00F10CE1010D31113D71415D91415DA1515DB1515D91614DD1717
DD1717DC1615DB1513DD1716DE1817D61111D61314D81514D91415D61213D10E10CF0C0E
D00C10CF0E14C1080FB4030BAE0108AC0107AA0106A50106A50208A30007A50108A40107
A30106A10106A001069F02069D01069C01069B01079C03089A0107990106970106920105
9000049001069002078F02058D01028700018500018400018400018400018600038B0106
91020991010A90010B90040D91040B94030B94020995040C8D03098400057D0004780003
7001036702036101026801027201017801017E02037E0204780700902D0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C22ADAC9BCBFC1C7C5CCD58F979C7A82849497987B6D6F3B1214431317B9A7A9B4BBBF
B4C0C2C6CFD19EA4A81B141926070D2F030937040B3C0508470D00C28A20D9A410DF961D
A42900B70F06BD080AC2080CC3070AC40608C70606CA080ACD090ACD0A0AD00D0BD0090C
D20A0CD60B0ED70D0ED70B0CD70C0BD90D0FD80C0DD60A0DD80C0DDA0D10DC0E11DF0E10
E31111E41213E31110E20F0FE51410E81411E61412E41314DA0F0FD60F0FD81111D80E11
DA1214D50F10D61314CF0F0FCE100FD01111D31313D41313D71415D81415DA1716DC1816
DD1715DC1715DA1714D81412DD1917D71413D81515D71414D41112D20F10D10D0FD31012
D10D11C9090FBC040BB10208AD0107AB0106AD0309A80109A9030BA6010AA5010AA30008
A10108A3020AA101079F02069B00039A00039A01049A0105980004980003970103940104
9100049101058F01059101059002038B02018601018400028401028401028500038A0106
8F000891010A93030C95040E96050D95040A94040A93050B8C02098500078101077B0106
7200046A00036A00027602047901027701017A01017C02037407008F321500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC32CD8C5BBC5C8CFB3BDC48A95988C94967E838584797B3B13153F1013A99698B3B6BB
B6BFC2C9D1D4A0A7AC1810182C091331010B3703093902054A1300CA9525D8A50FD78A17
A62303B90F0ABE070BC1060CC5080DC30506C70807CD0B0CC90608CB0808CF0C0ACF0B0C
CF070AD50C0FD60C0FD3090CD50B0DD60A0DDA0E10DB0D0FDA0E0DDB0F0FDC1010DF0F10
E21010E21011E2110FE61313E81511EC1914E61612DF1210D80F10D81112D60F0FDA1314
D60F11D00C0FD10F10CF100FD11312D31514CE1110D11312D41415D21214D41514D51814
D71D1AD1201BCD251CCC241ECE251FCD221ECD1F1DD11E1CD31817D31313D51112D71112
D71114CE0C11C1080EB40209AF0208AC0107AB0209A9010AA8020BA50108A20107A30107
A10107A00007A10207A102079E01049C01039B01049A0105980104980103980204940104
9200049000068F01069000059001038B0101860000850001860102850102870004890006
8E010992020B92010B93020B93020A96050D94040B93050C8B01088700088100087E0108
7600057200037A00058401068201047800017801017802037007008F361700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BF29D0BEB3CBCED5ACB5BA9CA7A9777F826C7072A59C9E3E1C1E380B10A59295B8BABF
BCC5C7CDD6D9A2AAAE16101828071231030C35020A3601044B1800CE9E26D8A711CF7D15
A41B02BA0D0ABF070BC0060AC5080BC20406C20403C70507C9060ACD090CCE0B0CD00C0C
D20B0DD20A0DD20A0DD30B0DD30C0DD50A0DD80D10DB0E0FDA0E0DD90D0CDA0E0DDF110F
E1120DE41311E2130FE81612EA1611EC1A14E31711D80E0DD20C0BD30E0ED3100ED71213
CF0D0FCC0C10CE1011CD1012CD1010D11315C90E0ECD1212D01717C81516C41C19C0261E
B22A22AB362FBA554DCE6D65E5847CE6817AE47872DB635FCA3F3CC52420D01A18D81716
D31011D21012C80C11B9040AB10209AC0209A80107A60006A70106A50105A30105A40105
A101049F01039F01059F01059F00049E01059C01049B01059901049500029101058D0206
8F02079002068F00058F01048D01018A01008700018601028701028801048902068A0106
8E010992010A92010B92020B92020A94040C92020A8E020A8701078400088101087D0107
7701047A00038A02089403088C01037D00007800017803036E040092381A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C028CEBDB1C4C7CEC1CBD1929E9F727C7C969B9B7C75773D1E2031060B9C8B8FBBBDC1
C4CDCFCDD7D9A0AAAC1411161F070C29030A300208370706502103D0A126DCA918C26D15
A11601B90A08C00809C2070AC30608C90A0CC60808C70609CC0A0CCE0A0CCF0B0CD10A0C
CF090AD30B0DD10A0BD60D0CD50C0CD60B0DD90E10D80B0BDB0F0DDB0F0DDA0E0BDD100D
DE120CE2140FE51610EB1812E91812E1140FD80F0AD20C0AD00D0AD20E0DCF0D0DD41213
CC0C0FC90C10CA1011C90D10C90F0FCE1414C61112C01816BC201CAB241F9E332CAE5D53
DA9E95F3C8C2FCDCD7FBE1DCF9E1DDFCE1DDFDDFDCFED8D6FCC3BEE88E89C2403BC41F1A
D01514CF0F10CD0E13C0080DB5060CAC030AA80209A80208A70105A40104A20104A30105
9F01029F01039E01049D00049E01049C01059B01049B01039900039401038700047B0002
7F01048B03078E02058F01048D00028B01018700018701028600028901048A01058B0107
8E020992020A94030C92030B94070E93040C94050E8D030B8600068301067E00067A0104
79010285010497030A9C01089501038701017B00017702036F040090331800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C027D2C2B3C6CBD0C5D0D88B999B8E9898868E8D7671713E2022370B0EA18B8FC7C9CE
CCD4D7CDD7D9A0AAAC1515181A060B2703092C03082D0202532605D2A225DDA61AB65C11
A51404BC0C0ABF0708C10609C50709C9080BC80A0BCB080CCD0A0BCE070ACD0809CF070A
CF090AD20A0CD60E0ED60C0AD60B0CDA0C0EDB0F0FDC0F0BDE110CDE110DDF120DDC0F0C
E0130EE41811E71812E71410E51712DB100ED50E0BD10E0CD3100CD81412D41112D00F11
CB0D0FC90C0FCC1213CB1213C81312C51715BD1D1AAC231E9022199C4A42DAA59DF7D7CF
F6E5DFF1E6E3EFEAE7EEEAE9EAEAE8ECEBE9EDE9E8ECE5E5F5E6E4FFDCD8F5ABA5BC3E38
C71E1BCF1414CC0C12C3080EB6050CAA0107A70108A70108A60007A20103A000039F0004
9F00049C00039D01059D01049C01049B00059800029800029A0002940003890105780001
7300008301058C01068E01048E01038C01018800008600028700038901048900048C0107
8E010791010995050C8F020891060D91050D9407108D030B8600068200057E0105790002
7C00008F02069D0208A102079C03068E01047E01027602026C03008C2F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55C025D1BFAFC7CCD1ABB7BE95A3A68D99986771709795954224253E0E11A68D91CECFD4
CDD6DACDD4DBA0A9AC1211151A03092B040B2C02062B030162340ED29F21E1A61DAE4E0C
AA1303BD0B0CBF080AC10609C5070BC5050AC40608C9070ACD0A0BCD0708CE0809D1090B
D20C0CD30B0BD20B0CD60B0CD90D0DDB0D0FDC0E0EDF0F0CE3140FE3120EE3130FE21210
E3140FE61711E71712E71511E31510D9100FD40E0DD6100FD50F0DDA1516D41211D21111
CF1111CE1213CE1616C71615BE1C18AF211D9A27209F4B44C89187E8C6BFF1DFDAECE3E0
EAE6E4ECE8E8ECEBEAEAE9E8EAEAEAEBEAEBEBE9EAE9E7E8ECE9E8F0E7E5FADCD8DE908B
B5302BC81919CB0E13C60B11B9050DAF040BA60007A50007A60108A20105A001059D0104
9C01049A00049A00059C02069D03069900039800029900029C0204990104930205870306
7A00028302068D01078F01058E01038D02028A02038902048901048C01038B00038D0105
90010792010892020892030A8D020992060D92060E8D030A8701078402087F01067C0003
8601059A050AA10207A50308A00408910306800103730102680200862A1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C127CCBAA9C9CED2B3BDC59AA8AD768485798484888989452A2B3E0D10A4878BD2D2D7
CCD5DBC6CFD79AA1A7140E1422080D30040D34050C310402784816D5A21EDF9F1BAB4004
B01206BC0A0DBF080AC2080BC4070BC20609BD0205C5060ACB0809D10B0CCF090AD20A0D
D30B0ED60C0CD80E0ED90D0EDA0F0FDB0E0FDD0F0FE1100EE41410E4130FE51410E10F0E
E4130FE51410E61611E51511DF1411D50D0ED30D0ED71212D51211D61213D41310D11312
CE1513CB1A19BD1D19AA241D972E26A1564ED1A29AEDD3CCF2E5E0EAE4E3E9E8E7EAE9EA
E7E7E9E8E8E9E6E7E8E1E1E3E7E8E9E7E8E9EBEBEDEBEBEDECECEDECECEBEDE7E5F2D4D0
E49793B62829C61317C80D13BC070EB1060CAA040BA50108A7040AA30208A001059B0002
9A00029800039701069900059801039701039902049B02059B01039B0105990206910205
8701038801048F01059001048E01028B01018B01028B00048B00048A01048A01058C0106
90010792020893020995040B90020993060C92060C8D030A8901088300077F0106800004
92020AA2040CA20209A402099C02058E01048201037101026301007E250E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C026C6B4A3C6CACECCD4DC859398808E907985856C6F704D3434400E129F8186D2CED5
CDD3DACDD4DD9A9FA5170F1623080E2B030B2F030B2F02028C5C1ED6A41BDA981AA32F00
B10F06B80508BE070BC00609C00607C0070ABB0302C5080ACC0A0BCD090AD00B0CD40B0E
D60B0FD70D0DD70D0BD80C0BD90F0CDA0D0CDB100DDF100DE3130FE31110E51410E61312
E61511E3120FE41611DF140ED70F0CD30E0FD00C0ED20F11D41212D21211CE1711C21A14
B8221DA92B23A03F36B7766CDEB7AFF0DBD4F2E8E3ECE7E6E9E8E8E7E6E8EBECEEEBECEE
E8E9EBE9EAECECEDF0E8E8EAEBECEEEAEBEEECECF1ECEBEFEDEDEFEEEEEEECEDECF1EAEA
FBD6D6BF5C5DBB1C1DC71012C10C0FB3050AAA020AA70308A60208A50108A000059C0104
9B01049A01049700049700059A0105980004970105970104980003990005990106950106
9301049302069201059001048D01028900008901028C0105890104860002860003890006
8C000790010892010996030B96040996060A94060B8F040B8901098100067F0005880106
9C040DA3050E9D00089C02089602058A000281000273010264010081250F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C025C8B4A2C1C5C9BAC4CC9EACB0909EA05A67669397974F39393E0F148D6F76D3CED5
CAD0D6CED5DD9A9DA21C111822070E2702092C0307330704976A1DD7A61BD38E1B972000
B10C08B70307BD060ABF0708C00607C10609C10607C40608CA090ACD090AD20C0DD30B0E
D50D0FD70D0FD40D0BD80F0DDB110DDA0E0DDB100CDF120FE2120EE3120EE51511E3140F
E3140FE2130FE21913D40F0BCF0D0BD01010CE1010CC1311C91713C6231BB2271DA53A31
B2645BDBA59DEACCC3EFDED8EDE4E0EAE6E5E6E6E6E5E4E5E6E7E6E8E7E7E8E7E7EAE8E9
EAE9E9EAE8EBE5E7E9E5E5E7EAEAEBECECEDEDEDEFE5E5E7EAEBEDEBECEEEAECEEEEEDEE
F5E4E5EEB0B0B02D2CC31414C30D0EB50609B0060BA70308A70409A50308A101069D0105
9B01039A0103990105980106980106970004950003930104960106970106960106930104
9401049402059301059102078F01068C01048C01048B0004880003870102870102870104
8800048C010791020994020A95030A96050C95050C90030A8B020A850006880106940106
9F030A9B040B8E02088B01058F02068C01048302027301016701007F200A21CA0200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD22C8B3A1C3C7CBBBC5CEA8B5BB7A8588818C8D9296984F3D3F3A0F157B5F66D5D1D5
CCD2D7D0D7DE91969B170F1423080E28030B31040A3A0702AB791ED7A51BC278159B1B01
B20C09BE080DC0070CC0060BC3060AC40409C50709C8070ACA0809CD090BCF090AD20A0C
D30D0ED40D0FD31010D91716D81211DB1011DB0F0DDF120FE1140FE0130FDB1811D61B14
D81C14DC1D15D51A13CC140FC81610C61B16C3241DB4251CAF3328BE5B51D7948AF1CCC5
F6E2DCF3E7E3EAE6E3E8E7E5E7E7E5E7E5E6E7E3E7EAE6E8E8E5E6E8DFE2EDDDE2EDD5D9
E8C9D0B595A0B2A1AAD4D0D6E2E2E4EBEBECEBEBEDECEBEFECECEFEAECEEE9EBEDEFEFF0
EFE8E7FBD6D5B95353B61616BF0C0EB9080BB3060BAD060CA50208A50309A20107A10109
9D01059B01039A0103990103990105950105940105910003920003920005930006920105
9100049201069000058E01058D01068D01098C01068B0004890103880102850001850002
8901058C000790020992020994030A96050C97070D8F02098A00078B000795010A9F010A
A0030B8D01077700038914178504088B04088202037501016A01007C1D0843950300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59BF24C3AE9DC7CDD0C5D1D998A5AB8A949891989B6F7174564448350B1483686FD3CFD4
CBD4D6D3DCE1889193110D1220070F27020B2B0205431102BD8A21D8A31AB35F11A21602
B40909BC060BC0060BC4070CC5060BC4050AC50709CA090CCC080BCC090BCE070AD20C0D
D20D0DCC0A0BC90F0EE62E2FCA090CD90F12DC0E0EDF120EDE1310CD0F0DBC1F19E96E66
D35A4FCA4B40C74639C6463DC85348CC665BD57D73E7A399F4C4BCFAD9D4F7E6E2F2E9E8
EDEBE9E9E6E5EAE9EAE9E8E8EBE9EAEDE4E8ECDDE3F2D9DFEEC9D1E8B1BDE69DABD87B8A
C35765A63D4C601C2A61454ED1CBCFEDEDEFEAEAECEDEDF0EFEFF2EBECEFEBECEEEDEDED
E8E7E5F6E0E0D28487B02022C41316BD080CB5050AAD040AA8040CA5010AA20008A10108
9F02069A01039A01039A01059600059001048E0104920206910102910102910005920106
9202069001058C01048901028A0104890105890104880003880004860102820001850203
8B02078D02088F020894040C95040C98060E97060F90030B8D010895010AA0010BA5010B
A0040B8401057402058B181D7901058203077C00037001016701007A1C0843950400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BE22C2AC9BC6CBCFBAC6CEA4B1B59BA4A969737592969A58494E320B13836870D6D2D8
CDD5D9D3DDE280898E140F1421050F2B030B280001411300C79525D9A01AB0530FA61203
B7080ABF070DC3090CC6080CC40709C4060BC4090CC1070BC1080CC4070BCD0B0DCF0B0C
D20F0FC00808B91010BA1313C2080ADB1012DE0E0DDF120DDD110FCA1010870202B66C68
F1BFB9FED4CCFFD4CCFFD6D0FFDCD3FDE3DBF9E4E0F6E7E3F4EAE9F0EAE8EFEDEBECEBEB
EAE9E8E9E5E5EDE4E4EAD8DBE8CBCFE3B2B9E6A1ACDB7F8BC3525EB6303EBA2634C3212D
C81E26C32026901B213D050DAA999FEEEDF0EAEAECECEDEFEBEDEEECEDEEEAEBEDE6E7E9
EDEDEDF6E9EBEBB2B6AE2C31C7161AC80D12BE080DB20308AB030AA6020AA20007A10107
9F02069A01039701019901039701068F01038A0005900208920106930106930205910104
9100058F00058C01058800028800028700028901038800048801058601048001017F0101
8601048A02068D010791020894030B98051096050F94040D97010BA2020DA9030CA70108
9C030A7D00027702077A02077500047802078413166E010266010076190843970600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
53BB1EC6AE9DC4C6CABAC3CAA9B4B97A85898A9598989FA35C4F533A131B80646DD8D2DB
D2D8E0D5DCE57D838C1810182707102F030A3305054C1C01CE9E29DA9E1EA13B05A30901
B70809BF090DC2090DC00508BF060ABD060AB7090CA502089D0106A80407BD090CCB0B0D
D20F0FC30D0FC32828DD4646C91512DA0F11DE0E0DE0100CDF100CDA1614B61112750B0E
965B60DFC1C6EEDEE0F2E6E8F1E9EAF3EAEDF1E8EBF1E9EAF1EBEBF3E9ECF3E9EBEEE2E4
F1DCDCEEC8CDEFB5BEE897A1CD656CBE4048BC2C36C3222DCB1E27CA151EC91318D1171A
D11818CD191AB022235B090D644649E4E4E6E7E8EAEBECEEECEEF0EBEEEFEAEBEDECEDEF
EBECEEF3EBEEFCD3D7B84B4EC31B1ECC0F13C40B0DBB080BB2050AA80209A30006A00005
9F01059B0004980002980102980103960207920209920108930107920006920004910104
9101059001068E01068C01048C01048D01058C0206870104880106880105840103820102
8400048801058E020690030795060C97050E95020B9A050CA3040CAB050EAB020AA50108
9603097700017602067C040977010777030876070D6F03066701026E120542950500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD20BEAA97B8BCBCC6CFD6A1ADB488959B9DABB06E757A675A5F3811197B6068D9D3DC
D5D9E2D7DDE7767C85140E1625070F2D030B3406055B2B0BD2A22CD59622972A00AB0D08
B50709B9050BBF070EBF070CBB080CB1070A9D0104BB2E34D5585DB027299C0405C30E12
CF0E10CC0F10E1373AE23A3ED21516DD1112E11110E21210E2120DE11411D81414C1161B
95111A882937B56F7CD198A4DFB0BAE2B7C2E4BBC4F4CBD1FACED5F5C0C9EEADB9E49AA5
D67B85C4525EC13944C62935CE232ACE1C22CF191CCF1418D21518D4141AD41518D21516
D31716D3191BBD1C1D8A1A1D441113C8C5C6E7E9EBEAEBEDEAEBEDEBECEEEDEEF0ECEDEF
EEEEF1EFEAEDFADFE2D07A7DB92023C81014C50C0FC0090CB6060BAD0209A60007A30109
A100089C0106990103960001950001960105960107940109920108910108920107910006
9000069101079001078F01068F02048D01038C00038A00048B0005890105860004830103
83010387010490040A8E01088F020A93030B97030BA40710AB050DAB0209A90209A30108
97030C7500036D020578050B7600057B04096E02076B01046901026C0B0142930400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52BB1EBFAB97BABEBFBBC7CEADBAC2A8B5BC6D7C7F91979C695E62331117785E64D6D1DA
D5DBE4D7DFE9696F78160D1621060E2C050D3106046D3E14D2A129CF8C21901C01AB0909
B6080ABA060FBB060FBA070EAF060A9F0103A00308C82C35C63038B524288B0000AF070A
CB0D0ECE0B0DD00E12D31116D81012DD0F10DE110DE21210E1140FE0110FDB1111D20E11
C81115C01620B71F2AAF222FB02D38AE2E3BB13642C84C5AC44654C13846C02F3BBF2530
C5222ACA1D23D41E20D5181DD5161AD41517D01312D31315D71618D81519D71619D7161A
D41416D01317C7191CAE2225580A0C948889E4E8E8E8EBEBEBECEEE9EAECEBECEEEBECEE
EBECEEEBEBEEF4E5E7E3A3A6AC2327C81416C60D0EC0080ABA080CB3060AAA0108A50108
A101069C01049900029600019701029601039501059301078D01068B02088E0209910208
9000069101079001078E01068D01038C01018D01028D01038D01058A0107870005850004
8500048800068D020A8E010A91010A99060E9B020AA8060FAE060EAC040BA702099F0007
98050C7501045D00026A060C7302087B050B8E24286802036F0305700B0142920400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B81BBFA893CED1D3BFC8D2B2BFC88493998291939DA5A96C6368341218775C63DBD6DF
D1D9E2D7E0E95D626B1B0E1627070E2E050C34060589571AD5A325C1771A8E1301AA0A0A
B5080BB8060EB80811B207109D03079C0104B50710C00A13BD0912B10A0F8F0000A90609
CA0E0FCF0C0DD30E0FDA1014DA0E11DF0F11DE110FE0130FDF120DE01410D7110FCD0B0B
CB0B0ACD0E10CD1114D01417D11618D2161BD2191FCF171FD01921D2181FD51A1ED3181B
D11718D11515D71616D81918D51817D81D1AD31915D31C18D31D1AD31917D71F1CD6191B
D41518D21419CB1618BE1D227B1216614547E1E3E4E5E8E7E7EAEAE9EBEDEAEBEDEBECEE
EAEBEDEBEBEDF0E8E9F3C6C9AB373CC11719C60E0EC20A0BBD080CB6070CB0050CA8000A
A301089D00049900039801039802059400029301029201058801037C00018301038E0207
9102068F01058D01058D01058B00038A00018C01028E02068B0106880004880004870103
8600038701038E020890010A98040CA70B13A7050CA70309AD050DAA030AA301089F0007
99030A7C040A5C090C4C00046301067C050D810E156F0004700203720C0243930600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
29DB0DB59A84CBCDD0C6CFD89EABB3839297A6B4B7747D826A616836141B7A5E66DED9E2
D3DBE3D7E0E950555E1C0D1527060C2D0508360904A4741ED7A525AE5C138F0D00A60708
B1050BB3030BB0070D9F040B8D0002A8060CBD0710C4060FC0070CAD070A8C0000AC090B
CD1011CC0809CD0708D80D11DC0E11DC0E10DB0D0DDF120FE0140FDC1210D00C0BCD0E0E
C90C0CCB0B0CD00F10D21010D61411D61414D61918D21817D31D1AD31D19D61C1AD51B19
D21715D11513D01918C9211DC62D25C9372FC5382DC63E33C8463AC8493FD14F46D2433F
C61F1FD4181CD2171BC7171BA21F22451114D3CFD0EAECEBE9EBEAE7E9E8E8E9EAEAEBED
EBECECE8E9EAECE9EAF6DADCB65B60B81C20C40D10C30B0DBA0409B5050BB3050EAD030A
A702099E00059A01049701049400049100029200019200029002058501028501028C0103
8F01028E01028B00038E01068D00058C01048D02048D01058B01078900068C01058B0003
86000187000290060C93030AA30811B00811B0070FB1080FAB040BA80309A40109A00107
9B020981030AAE5C615D23255903077E040A86060D7C020674010370070044920700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC8F74C7C6C6C3CCD5AEBBC1AAB7BD7D8C91868F956C656A32141B7B626ADDDBE4
D6DEE7D9E2E94A4E561D0E1427060C2C0508340800B48421DAA5279B4009970E02A70608
B0040CB0040CA9090E8A0205880203B10A12BE060CC3050AC1090DA60407890000AE090A
CD0F10CF090CD10B0CD40D0ED80E0EDA0D0EDB0F0EDA0E0EDF1514D30D0EC9090AC8090D
C70B0CCC0E11D01013D01112CE1813C9211BC52D25CB4339CF5247D2554BCF4B41C73830
C52A23C9231EBA1F1D7D0908D98A83F5B4ABF1B4AAF3BCB0F5C3B7FCCDC4FECDC6FDBCBA
BA3E3ECB1C1FD11518CE171ABC22245608099B8B8CE8E8E7E9EAE9E7E8E8E9EAECEBECEE
EBECECEAEBECEAE8EAF3E2E4D28E90B12528C51215C1090DB9050BB4040BB4050FAF030C
AA020AA200089E02089901059500049401049400039500039201038E02048C01048E0303
8D01018C00008D01028F01069202089101078E00058C00058C00068C01068B00048C0105
8B01068900048E01069E060DAC080FB70B14B4060FB30810AC050CAA040BA60108A10108
9C01088C040C85232B954F565C030883040D86010881010678010371050044910600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00947452CCC9C6C2CBD1C0CBD492A0A884939896A1A76C686C31161B79626ADFDBE7
D6DEE7D6DFE63C3F471D0C1429070E2F06083E1000C6962CD79E278D2C019B0C03AB060A
B2050EAE050F9F080F790001890205B1070EC1070DC6070CBD080BA003048E0000B80C10
D00E10D50C0ED50B0ED60E0ED70F0DDA100EDB100ED60E0FD61011CF090DC8080CC80A0E
CC0E10CD0D11C71113BD1918A7211AAE493FD99085FECAC1FDD4CBFFD6CEFECDC5F9BCB6
ED9F98D17068A6453F4B100E98817DEBDFDBEEE2DFEDE4E1EFE6E4F0E7E5F4E8E7FDE0E0
C46C6FC5262BD3191BD11617C71E1E7911136D4F51E8E7E8EBEBEBECECEDEDEEF0ECECEE
E8E9EAE7E9E8E8E9E9ECE4E4DEACADA32B2EBC1316BD0B0EB8070CB4050BB3050BB1040B
AD030BA70109A201069D01059A01059800049702049601039201028F0202890001870101
8C01018D01008D01018D01038F00049101059201069001068F02078C01058A0004880103
8901038C0002960105A50409B1080EB5070FB1020CB2060EAC0209AC020AA70108A00106
9C010895020A91151D710C1473040B89030C890108810004790103730600655B0700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0084623CD0CCC8C5D0D5ACBBC2819299A8B8BC7681896A676C31151B816770D3CED9
D6DEE7D3DCE52E3038210C1429050C320604512000CA992BC98E26741500970A07AB060C
B1030CAE071193050C710001890307B2090FC3090DC5090FB9090E970103950102C10E13
D10E0FD40C0ED70D0DD90F0FD40D0ADA100ED9100CD91211D00C0DCD0A0EC9080CCD0C0D
CD0E0EC91010B41416780B08A86960F1D0C9F7E7E3F2E9E7F3EDEBF1EBEAF4ECEBF5ECEA
F6E6E2F7DBD5E6C5BE8D7671766D69DCD7D6E5E3E5E7E6E8E6E5E7EAE7E9EBE7E8F6E4E6
D49295B72A2FCE181AD41719D11E20991A1D4A1C1FDBD8D9EBEBEDEDEDEFECECEEEAEBED
E6E6E8E8E8EAE7E8E9EDE8EAEFCFCFA7474AB0161CB6090EB3040CB60711B3060EAD020A
AD040BAA0209A70208A203079B00049800029600029100028E00018D0101890000880101
8800008B01018B01018A01018E00029101059100059201078F02068C0104880104880001
8C0001950103A00105AB040AB40810B4060CB5070EB3070DB0060CAD040BAA030AA30207
9F01079B010991040BA5262C8F0E178B010A8B010880000476000173060085220600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F6C46C6C2C0BBC6CDAABAC1ADBDC4798990808B90716E7133151A816970DAD6DF
D8DDE8CDD6DF2B2C35210C152B060C360803693810CE9D2DAC721F6B0C01900708AB080E
AF050CA908118904096D0003810206A7060DBA0A0DBC0B10A8060B8E00029D0506C60C10
CF0C0DD40E0FD20C0BD0080AD40C0CD50C0BDA130FCF0B0BCB080BCB090CCC0B0CCE0E0D
CA0C0BC213148A0D0E612A28E4CFC8F2EBE7EFECECECECEDECECEDECECEDEAEAECECEBEF
EBEAECEDE9EAEBE6E4E6E2DDD8D4D0D3CFCFE6E5E8E7E7E9E7E9E8E8E8EAE8E7E8F3E8E8
F6C8CAB53D41C91B1ED11318D2191DB620274F070CADA3A4EAEDEDEDEEF0ECEEEEEAECEC
E5E5E8E9E9EBE9E9EBEAE6E8F2DCDEAC6266A41C1EB40D11B60910B4060EB2060FAB020A
AC030BAB0209AB0309A702069F00049900039701049302068E00018D01018B0202880001
8901028A01018B01018E01029001049101069301099101088D00048B00048C01048E0002
980104A20208A80208AC0209B40510B5050FB6060FB2040DAF030BAC0309A90308A70209
A30107A001089A030992030B8D020B8A00088902077E010373000073050089230900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0093714CC7C4C2BEC9D0BAC9D19AA7B07D8B9195A1A475737432151A866C73DBD8E0
D6DEE7C5CBD32220292007102C060C33050481511BD7A5349A5B1B760C02940407AC070E
AF060EA6060F820207650001760105920309A10409A1040A9002078300029E0607C90E12
D00C0ED40C0ED20C0BD20C0DD50D0DD50D0ED10C0FC60408C6060CCA090DCD0D0DCE0C0C
CD0E0FBB13156907077F5F5DEAE0DDF1EFEEEEEDEDEEEEF0EAEBEDEDEDEFECEAEDECE5EA
DECFD7E2D2DCEBE3E9EAE8E8EBEBEAE2E1E2E3E3E5E6E6E8E7E9E8E7E8EAE7E8E8ECE7E8
FBDEE0C4656AC12023D21A1FD3171AC51E226E0E147A6368E9ECEDECF0F1E6E9E9E7E8E9
E8E8EAE8E8EAE2E2E4E5E2E5EBDEE0CA92949A1F22B21014B1070CB0040BB0050EAB040E
AA030CAC030AAE0209AD040AA501079C01069701069400049100029001008E01018C0103
8A01028A01018B01018D01018C01038E01059100099100088F0005900104930005990104
A40106AA0108A90108AA0109B1020CB5050FB60711B3050EB2050EAE040CAB040BA40106
A202079F020899020993010A8E00088901078803077F010472010070040088210900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C6B46C2C0BDBECBD2ABBABF7D8990A9B7B97784886E6A6E34161C8E747BD9D6E1
D1DAE3B0B7C119131E21060F2E040A3506069F6F20D39E2E853A0E8A10079E0609AC040C
B0060EA9051088050A6400026C02067F02088701098602087F01057E0001A3070AC50C0F
D10C0DD30B0DD20C0BD30B0DD50E10D10B0DC70709C3040AC7070ECB080ECF0D0ECC0A0B
CE0F10BA171A5C0506917B78ECE7E5EDECEDECEDEDECEBEFEBECEEEAE7ECEDE3E7DEBBC1
9D56638C3D4DA26879D4B9C4E6E1E6E9E9ECE6E5E8E5E5E7E7EAE9E5E6E8E3E4E6E9E7E9
F4E3E5D79096B9272DD42124D7191ACC1B1D93191E50272CE2E1E4E9EBEDE6E7E9E6E7E9
E8E9EBE9EAECE6E4E7E4E2E5EAE2E5E6BDC19F363BAE1318B2090FB2060EB0040DAE040D
AD040DAD030CAF020BAF020BAB040B9F01089901069500029401029301029102018E0202
8B01018901018902018C03028B02028F01049301079301079200039601059C0105A10005
A70206AA0208A60208A40207AE060CB3060FB90A13B3060CB1050BAF050BA90209A40106
A000079A02098B01058D040A8D03098700038701057F01057401016F030080190400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B6A46B0AEACC4CED5AAB7BDB1BDC27E8D8F7D878D716C6F33151B947A82D4D3DE
CCD5DFA4AAB51C141F280A162F040A3A0A03B6852AD29C30711A00910C09A4060BAF050C
B3040DAC030E8F040D6400036201066F01087A040C78030A760105880105AA0409C60A0D
CE0B0AD20C0BD10B0AD50C0ED30D0ECC0A0BC7090CC5060DC7080FCB090FCB080CCE0B10
CD0E0EC0191C610708866F6EEAE8E6ECECECEBECEEEAE9EEEAEAECEBE8EBEEDEDFBB7A81
AC2A35B8202BAB2634822735956F7BDED7DEE8E7EAE6E6E8E7E8EAE6E7E9E3E7E8E7E8E8
EDE3E3F0BDC1BA373FD2242AD71A1DD0181BB01E244A080FBBB3B6E6EAECDEE0E3E8E9EB
EBEBEDE9E9EBECECEFE5E5E8EAE7E8E4C9CBA24F52A21519AF0A10B30810B0020CB1040D
AE040CAB0109AE020AB0020BAD030CA501089E02069A01039501029100019001018E0101
8C01028B01008801008700008A01018E00039200059500069B01089F0207A40207A40106
A501079E0206900102950306A6050BB3070EB6080EB5080EB1050AAF0509AC040AA40006
A001079902098600048001048803088700058701068100057701026D01007D190500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00856143BBB8B8C3CCD6C0CED69BAAB178888D959FA57A757A33181D947C84D6D4E0
D0D8E18F94A0150D192306122C0307411200C79735C48B2979180298090AA80309B2060C
B4050CB0040C9E08116D00055C01056B0C138A2E33882D337002089B070FBB0A10CA0B0C
D10C0BD20A0CD20A0DD70E11D30E11C6060AC10609C3060CC7080DCA090ECD0A0ED00B0F
D00E0FC2151A72090C705355E7E2E3EDEBECE9EAECE8E8EAE5E5E7E8E5E7EEDEDEBD7A7E
B02529C5171BC7181EB62029711521725761D8D6DAE4E4E6E2E2E2E4E5E7E4E7E7E9E9EB
ECE7E6F8D5D8B95257C6282CCF191CD2171BBC1B20610A0F7D6C6FE1E4E6E1E5E6E7EAEB
E8E9EBE9EAECE6EAEBE3E5E7E7E7E8EADADAB5767992161AAC0B12AF0610AF040EB20710
AE030CAD020AB0040BAF020BAA010AA8030AA502099E01079701059200048F01018D0001
8D01038C01018900008901018C02028F01039500049D0106A4030BA60109A60107A50004
A200059600038301027C0001940308AF0810B60810B5070EB2050AB00509A90105A60208
A101079C01088F01088200048401068801078600068201057901026F01007A150400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00896547BBB9BAC1CCD5B8C5CE77868EA7B6BB7D878F6D696E2F1318977F87D5D1DD
D2D7E07C848D110C1520050F2804054E2105D19F3BAB6A1F750C019D0A0AAC060BB4080C
B5060BB3040BAE0A12830307620204C97E85FEC3CAE3A1A8760F12AE1316C00A0CCB0A0C
CF0C0DD30D10D20D0FD00A10C7060BBF0308C00609C2050BC80A0FCE0C10CE090FD10A0F
D31013C815198A0E13532F32E1D9DDEBE7ECE7E7E9E5E5E7E5E5E7E6E3E6EBE0E0D09C9C
A62A2CC01619C81217C2151B9E1B243D080FB0A8AAE1E1E0E5E5E5E7E7E9E6E8E7E7E7E9
EEEBEBF7E2E2C97E80AC272AC92023CE171BC3191D8013194C2C30DADADCE1E4E5E3E8E8
E5E9EAE6EAEBE6EAEAE6E8E8E2E3E3E6DCDDCFA2A48D2327A80F16AE070FAB030BAC020C
AB020BAD040CAD030CAC030CA6010AA50109A502089D0206970109940108920104910104
9101049102049001038C00018E01019200019D0104A50107A60108A70109A60007A40104
A201059E020698050B840104880204A90A11B80C15B60610B3040CB0030BAE040AA80208
A100089C01099301078700058601068801068701048402057B010370010079130300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00967053AFACADC9D1DBB3BFC8B0BDC587969B7F8A906D676B3313199F868CD5D2DB
D2D8E267717A0F0B131C050B230203623715D7A43E9149137F0A039C0509A70207AD0305
B4060AB20108B5080F9F050B81080D8C343C934D557B2E32AE3C3BB91817C40C0CCD0B0E
C9080CC20206CD0D0EC9080EC2040AC1070AC3070BC5080EC5060ACB0A0CCD0B0CCF090D
CE0C0EC710139E13173F0B0DC6BDC0E7E4E7E5E3E6E7E5E8E5E5E7E3E3E5ECE6E6DFBCB9
9E3D3AB81C1FC41217C7151AB41B2057070C706061DCDADBE6E4E5E4E4E6E4E5E5E8E7EA
E7E6E6F0E3E6E2AFB1A03539B52024C31216C012189F1C233F080FBAB4B7E2E4E5E7E9EA
E4E5E7EAEBEDE8E9EBE4E4E6E6E6E7E4DCDEDBBABD983E42A41419AC080FAB060DAC030C
AB020BAA020BAC030DA9020BA60109A40108A10107990105940006980108980105950104
9201039101029001039101029300019C0104A50106A90108A90109A60007A50007A40105
A10103A100049F02069303078A0004A0060DB20910B70911B3040CB3050CB0040CA70109
A0010B9C010A9701079001068901058600018601038301047B01037201007A120200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956F4BBBB5B2C7CFD7C3CED8A8B6BE7C8B9097A2A8767376301319AD979DDAD8DF
D4DCE5525B65130C1420060D2504027C4F1DDAA43F8331078B0C04A2070AAC050AB0050A
B5070CB8060CB6050CA90107A41015BB4349BB5458D16464BF3333BD0E11C70B0DCA0A0C
BF0106BF0207C90C11C4060BC10609C0060BC40A0DC5070DC7090BC90809CE0D0CCF0C0D
CE0C0ECA0E13B41A1E4B020597888AE3DDDFE8E3E7E5E3E6E3E3E6E5E5E7E6E3E3E6D0CD
B26864AA2020C01616CB171ABE161B7E1017422325C8C5C5E5E5E3E7E7E7E6E5E7E9E7EA
E7E5E8F0E8ECF7D6D7B66669A62427C01419C11116AF1A2053060B88787BDBDBDDE5E5E7
E5E5E7EBEBEDE8E8EBE4E4E8E3E3E5E1DDDFE0CCCDA55F6198151AAA0911AD070FAE060E
AD040CAB0109AC020BAA020AA70209A50207A40208A3040A9F02089F010A9F01089A0106
9500039000018F00029601029D0003A50207AA0107AA0107A90108A60007A50107A30106
A00004A00105A001069E02099A0108A5030AB1060CB6080EB4060EB5050FAF030CA60009
A2010A9D01099800059401058B01038701038402048301047F02057400017B110300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805A32C4BDBAC3C9D3B9C4CE7F8D94A7B6BA8290946464672F171AB6A2A9DADAE1
D4DEE5454D57150B131E0509250503986C24CB9234771E018A0602A20409AE060DB3050E
B8070FB9050EB6030CB00108AC050BB0151CB52529AC1519B60C10C3080DCA0A0DC8080B
BE0005C00309C3090EBE0409BE0508C1070AC3080BC6060BC80A0CCB0A0CCC0C0ACE0D0C
D00F10CB0D12BC161D67070C62494CD9D2D4E7E4E5E5E3E6E4E4E5E4E4E6E4E3E2EBDEDB
CC99939F2B28B81615C81516C5171A9D191E3906089E9999E1E1DFE6E6E6E8E8E8E7E5E8
E6E4E5EEE8E9F3DEDDE2A6A9A53638BE1A1DC21016B8181E74111851363AD2D0D3E2DFE2
E4E2E6E6E6E9E6E6E9E3E3E8E1E1E5E1DEE1E5D8D8C48F908F1C1FA60B12AD0710AE040D
AE030BAE030BAC020BA9020AA70109A70109A9040BAA040BA8030AA6020BA3000B9F0108
9A0104980103990002A00104A40004A80107AB0209AC0109A90108A70107A50107A30106
A00004A00104A20107A6020AA7030BA90209AD030AB5080EB5070DB4050EAD010BA7020A
A001089C02099701079101068A01048400048100048201057F02067600027B0E02439002
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008E643DB4ABAACED6DFBFC9D2B0BCC38A9A9D828E916763662F181CB8A9B1D8D9E1
D2DBE22F3841120B131B05092B0C02AF8330B47A27690B01900806A6050BB0060DB2030A
B6050DB7030BB9050DB40208B6040ABF0A10BE0A0FBE080CC3080BC8080BCA080ACC0A0D
C40609C5080EBD030ABD0409BE050AC0040AC4070BC50609C80A0CCC0B0DCB0E0BCD0E0D
CC0D0EC80C11BF1216830E13401D1EC9C2C3E8E4E5E6E4E5E6E6E6E3E3E5E4E4E3ECE6E4
DDBDBA9A3F3DAD1618C81419C7141AB1181E57080C655658D8D7D5E4E6E5E5E5E3E4E2E2
E8E6E7EAE7E8ECDFE0F1C9CBB05557B91F21BE0F14B812198D161C380C10B4AFB0E2DFE0
E1E0E2E3E3E5E1E1E3DEDFE0E0DEE2DFDCDFE5DDDED4AFAF922F32A61016AC060EAE030C
B1030DAF040CAC020BAA030BA70209A6020AA7030CA6020AA60209A5010AA5000BA60109
A50107A50106A60206A50004A70106A70007A80108AA0108A80106A60106A50106A20105
9F0003A00103A40007A70108A60107A70106AC0209B50811B70A11B2040DAC010CA5010B
9C00099800079200068D01058700038201047D00047F01057C0104750101790B01418D01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00855A31B8B0AFCBD3DCCAD4DDB1BDC67081868D999E79767B321A23C0B4BCCDD2DB
C7D2DB1C242E110A101F0708371500C3943D99591D6B08018F0709A8060DB1070DB5060D
B6040AB90509B90509B80308BA0308C4070DC80B0DC50809C40907C7070ACA090BCA090D
C5090CBC0308B80206BA0409BD050ABF060BC3090CC00409C10408CA0A0ECA0C0CCA0D0D
C90C0DC2070CBF0B10A1141A3C0307AEA4A5E2DEDFE5E5E5E5E5E5E4E5E7E5E6E6E7E4E5
E5D3D1AF6967A92022C5161CC71318BE181E7C11183C1C21BFBCBDE2E3E1E2E2E0E3E2E0
E7E7E7E8E7E8EDE5E7F4D8DBC57E80AA2224C21617BE1114A51A1F4403078B8183DCDBDB
E2E2E2E2E2E3E1E1E3DFDEE0E0DFE1DEDEE0E1DDDEDBC1C29D4C50A0141DAE0913B0050E
B2060EAC0109AC030BAA020BA70209A7030BA6020BA60109A7010BA7010DA9000BAF010A
B3030BB10409AD0207A90006A90105A90108AA0107AA0107A90107A60106A50105A20104
A00004A00105A30108A50109A50105A60004AE040BB3070FB3050EB0030DAC020DA4000B
9D01099801089200068D01068801078100057C00037C00057A0105720002750A02428F03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF007A4B23BEB3B1C3C9D3C7D2DA7E8D959DACB2838E94625E61301922C7BAC5C8CED7
B7C2C8151B22160A0E2206054F280BD19F46803A0D750A038C04079C030AA8050AB1070E
BA080DBC080BBE080ABD0409BC0308C6080CC90B0DC30809C20708C8080CC6070AC1040B
BA0308B50208B60409B50309B9050BBC050BBE060BBD050BBF050BC1070CC5090CC3080B
C40A0CC0070CC10810B2141B570709796769D7D7D4E5E5E5E4E4E4E3E3E5E5E4E6E6E2E5
ECDFE0CB9998A32E2CC21B1CC81517C315199B192039030A8F878ADCDADCDFDDDEE0DFDF
E3E4E3E4E5E7E7E5E4F4E4E5D8A7A8A12B2EBE1819C01113B3181D610A0F584548D1D2D3
E0E2E1E1E2E2DFDFE1DFDFE1E0E0E1DEDEDDE1DFE0DECDCFA5686D92171EAA0A12B20810
B2060EAD030BAD040CAE050CAA040BA6020BA6020CAB050FA7010CAC010DB2020DB7020B
B9040AB8040BB3020BAD0109AA0108AA0108AA0107AC0309A90108A60006A40106A20006
9F01059E0004A10106A50108A50106A50106AA0108B2050EB80A13B0030DAA020CA4020A
9B01069700069300068D01068801088001067D01067C01067C0306740103730801438F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956A42AFA49FCDD3DBBFCCD3AAB9BF92A0A57B84885A5555341C23CEC3CCCED4DD
A5B2BA0F131D18090F2205046E471ECD9A437025047A08058E03089300059C0105A60107
B5070EBA060DC0090DBE050AC1070AC90C0ECA0C0DC90B0EC40709C7070CC5070CBC030A
B6020BB1020BB0030AAE010AB2060DB9060FB7020BB8030BBB050DBE060CBF070AC2090D
BF070AC40A0DC50D12BC141B790C1346292AC5C3C1E3E1E2E2E0E1E5E3E6E2E2E6E5E3E7
EAE3E3E1C1BFAA4B49C02322CA1618C9161AB0181E5A09125F4E54D5D2D5E3DEE0DFDEDF
E0E1E1E0E4E5E1E3E3EAE3E2E9CACAA54549B41A1FC01217BB161D7F11173A181BC0BEC1
E0E1E1DFE1E1DDDEE0DEDEE0DFDFE0DDDDDEE0DFE0E3D9DAC4979B8C2126A90E14B20810
B0060EAC020CAD050DAC040BA9030AA3020BA3040EA6010CAC020BB4060EBA040EBB030C
BD050DBC040DB8030DB3010CAD0109AB0209AA0107AA0107A80007A70108A60209A4020A
A10107A00106A10207A00107A00109A40108A80108B1060FB20810AB030AA60108A00006
9C00069800069301068D01058601078201077D0107780104780102750202740700418D02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF009B7048A79B95D1D7DFC3D2D9B6C7CE75858C8A92976D6869372228D2C9D0CDD4DE
8F9AA611101C18080C2106028B6529B48538530901800B0D93040B9C030CA3040BA90108
B4040CBA050EBF080EBD0409C1070AC80B0DC90B0BC9080BC6080AC50608C3080CBA050A
B5020BAE010AA702099F0108A00308AE060FB5040FB9040FB9040DBD050DBF080DBD060B
BF080DC0080DC20A0EBD0F16921016330506A5A09EDDDDDDE2E2E1E1E0E2E2E2E3E5E3E5
E6E4E2E8D4D3C07A7AB22627C7191BC51014BA171C7A0F1838191FBCB8BCE1DFE2E1E0E2
E1E1E3E0E1E4DFE0E1E5DFDFECD8D9B56D71A51D23BC1119BF141B9C181F3B0307A59C9F
DEDDDFDFDFE1DFDFE1DCDDDFDEDEDFDFDEDFDDDBDDE3DCDDD1B0B294373CA71318B2090F
B1070CAE050BAF050EAC020BA8040B970004950106A5040CB2070FB8070EBA040CBB030C
B90209B90209B9030BB4020CB1030BAB0006A70105A70105A80107A60108A50107A30007
A10106A00105A001079801069201089A0109AB050DB1060FAD040CA70107A60108A00107
9B00069901079502078B01058301067D0106780105740002740101740101750700418E03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805328C9BBB4C6CCD4CAD7DF80929A95A5AC818A91534C513B242BD4CBD2D3D9E3
767E8A130B1919050C1F0501A37B37905E245707057D0509900007A3040BAB0309B3040E
B7050DBA050CBD060BBC0309C0080AC7090DC9080BCB090CC8080AC6080DBB0509B20207
B0030AAB020A9D00048F00028B00019C0107B0060CB5040BB8030BBC050DBC070DBB060B
BD080DC20D12C00B10BE0C14A7141A4704067F7576D4D7D6E1E3E2E0E2E1E1E0E1E2E0E1
E2E1DFECDFE0D0A1A2A23032BC1B1CC51719BD181A951A1E3B070C978F91DCDBDDDEDDE1
DFDFE1DFE0E2DEDFE1E2DFE1EFE1E3C49193972429B11119BB0F17AE192254050A6E5D60
D6D6D9E0DFE1DFDFE0DDDDDEDDDDDEE0DFE0DCDCDDE0DDDDD8C3C2A3595A9C1419B00B10
B2080DAF050BB0050EB0040EAE050DA3040A9B0206A8050AB60610BA050DBA030BB9030B
B90308B90509B70208B5030AB20409A80004A20004A00004A60208A40006A20006A20107
9E01059E00049F01059802068900038C0003A9090FAE050DAC030BA80208A501069E0006
9900069401059101058901047F0004770104760205740103730101740202760A02418F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00825021B5A59DD0D6DEC2CED7ABBAC392A1A97F878E51464D462F37DAD2D9D2D8E3
5F6571180C1820080D2A0C00B28841743C1A63080587050D9C050DA8030BAF030BB4040E
B6050DB8050AB90409BA0308BD0508C7090DCB0A0DCA070BC6080ABE0409B20207A70004
AB020AAA010BA40208A003099E0408A20206B3080BB40408B40309B6040CBA070FB8060C
BA070CBD080FBE0912BB0913B01119660A0D493234CACBCBE2E4E3DEE1E2E1E2E2E3E2E2
E4E4E2E6E1E2D8BEBEA55756AA2D28B62D25B12F289B342E5E2B2780706ED5CFCDE3E0E1
E2E2E2E0E1E0E0E2E1E1E0E3EAE2E4D5B1B2973538AC141DB90D16B5131E710D15402729
C5C6C9DFDFE1DFDEE0DFDFE0DFDFE0DEDEDEDEDFDFDEDEDEE0D3D4BA838591191DAF0D13
B50910B3070DB1050AB00207B7060CB90910B1060BB00308BA070CBC050CBD050DBB0409
BB0409B90408B50207B20306AD0205A501049F01049C0003A10207A10005A10107A20207
A100059F0004A001059E02069A050A920107A5070FAA040BB00710AA030CA602099E0107
9600049301058F01058700047F01047500027201027100036F00036F02027B150C46960C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00814B1AA08D83D2D5DDC3CED9BCCAD676868E838C936C6369533F49DCD6DED0DAE5
424A56170B13230706472108BF90465C1F0967050591060FA7060FAF050DB3040DB7060C
B60509BA0609BB070ABC060BC0080AC8090DCC0A10CC0A0FC3080CB70309AE020AA70007
AB0209AD020BAD030BB0040CB3080DAF0407B7080AB80509B6060CB3040DB5060EB8070E
B8070DBB080DBE0B13BB0914B40E158B141832090CB4AFB2DFE1E1E0E1E3E1E3E2E1E1E1
E1E2E1DFDEDEDFD4D3C49F9BC58B80DA988CD99E91D2A296C7ABA2C8B9B5D1C9C5E5E0DF
E3E2E0DFDFDFE1E2E4E0E0E2E5E1E3E4C8C9994347AA1820BA0E16BA131A8A151A310A0B
B4B4B4DCDDDDDFDDE0E1DFE2E0DFE1DDDDE0DDDDDFDEDEE0E5DCDFCDA3A7922930AF1118
B70911B9080EB9080BBA060ABD070CC0090EBE080EBB050CBD060BBC040ABD040CBD040A
BA0208B9030AB60409B30409B1050BA90208A201059B0001A10206A10006A30107A60108
A50208A20005A10106A00006A2040B9F010AA8050EAE050CB0050EAC040EA6020C9E0007
9800059201068D02078601057E00047701047402056F01046A010369010273140D44980F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00834F1ECBB8ADC4C9D0CCD8E28898A18F9EA5899297544B525D4A53DAD6DECBD7E0
2E3741180C132107056A4421BC8B4454110070050790020AA8060DB0030CB3040AB8070C
BA070ABD0709BD0809BE070BC2070AC8070FCA0910C8090EBF070BB40209AE010AAB0209
A90007AD020AAF040BAD0208B20509B20407B6070AB60609B3040AB3030DB1030CB4030B
B8070DB7060CBA0B11B80812B50912A5171E4B020778636ACFCDCFE2E1E2E0E1E1E1E1E2
DFE1E0E0DFE0E3E0DFE7DEDBE9DDD6EEDED9EADFD8E9DED9E7DFDBE6DFDEE3DFDDE2E0DF
E0E0DEDEE0DFDDDFDEDEDEE0E2DDE0E5C7CBA0484FAD171FBF0F16BB0E149B1419380002
888284D7D8D9DEDCDFE1DFE4E0DFE4E0DFE4DEDDE2DDDDE0E1DCDFD7B7BC9E444CAA131C
B7080FBF090EC50D10C2090EC3090FC0090EBB050DB8050DB9050EB7040CB9030DBB040D
BC040DB7020BB5030BB2030BB1040DAB0109A501079D0003A10106A40007A50107A70106
A90108A70108A50106A40007A30109A6010AAB040CAD0309B0050CAB020CA6010C9F0109
9901079201088801077F02067A01057501037301046D01046800036401026B110C4D520C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B5323B8A49CC9CFD6C3D1D9A4B3BA9AA9B07E868B41353D6B5962D9D7E1C0CAD5
1A222D180C132007068E68309D692F5E0A017C040798060FA9080FB1040DB5050CBA060C
BC060ABF070AC0090BC1080CC1060AC6080FC3060DC50A10BA0409AF0006AC0109AD020A
AE030BAF020AAC0208AB0106B10408B10207B4050AB2050AB0020BB3030EB3030DB8060E
B7060CB5040CB80910B70711B60910B01017820E174B161FAE9AA3E0D9DEE2E0E3E1E0E3
E2E0E1E4DFE2E4E0E2E4E1E1E6E2E1E4E1E2E2DFE1E4DDE0E6DEE0E5DCDFE2DBDEE2DADE
E0D9DAE0D7DBDDD4D8E0D3DADFC9D0D89FA9982630B1111BBE0D13BC0911AA101955050A
5A4B4DCFD0D2E1E1E3E1E1E4E3E2E7DFDFE2DEDDE0DEDDDFE1DEE0E2CCD1B86F77A2161F
BB0A10CA1114C90D10C6090FC2080FBF090FAE0309A40207AA040CB3060FB2020CB5030D
B6030EB4020CB5030DB2030DAD020AA90108A502079F0104A30207A50107A60007A90207
AC0309B1050BAD0209A70007A50107A70208AD050CAD040BAD040BA8010AA6010AA00109
9901069001088100057601057600087601077101066A00046701026300016A0F0D5B0F0D
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00905323AD958ECFD4DBBCCCD3C0D2D974858D6A7379493F46786972DAD8E3B3BBC7
13182214070E1F0602AB8243743C1971120888060A9A040CA50209B1060EB4040CB9050B
C0090EBF060CC0080BC1090BC0090BBE060BBA0209BC080FB3040BAD0109AD020AAE030C
AC0109AD0208AB0205AD0208AE0107B00209B2050BB2050BB2050CB2020CB3040CB6050D
B6050CB7070FB5060DB80A12B5080EB60C13AB131A7E0D186C232FB1838FDBC1C7DECAD1
DECACFD6BFC8E0C7D1D9BCC7CEAFB8CAA7B0C9A1ACC89CA8CF9FABCA96A1C68F99C38793
BC808BC0808BBD7987B97080B76271A63540AB1721B60C13B9080FBD0A0FB40F15710B10
3A2122C6C8CAE3E4E6E3E2E5E0DFE4DFDFE3DFE1E4DFDFE1DFDEDFE4D8DACE9A9D9D2125
C11416CA0E12C6090EC6080FC3070EBE080FAF050C9D0106A00006AB020AB0040CAF010A
AD0009AE010AAC0109AB0109A90109A70107A40207A00005A40107A60107A50107A60005
AC0208B4060DB2060BA70104A60105A80208AA020AAB010AAA030BA80209A50108A10107
9901049303088302067600067801097300066E01066B01036501015F00016309095F100F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00874B1AB2978EC4C6CDCBD7E08FA1A8768A8E7884883B373C837680DBDAE599A1AD
0E101B1304092D1001B78B4A5B220A60060285030A9E050DA60309B0050BB4040CB7030C
BB060CBE070CC1080CC1080BBF0709BC060AB60308B4050AAB0108A90007AC0209AC010A
AB0208AB0307AA0407AA0208B0050BAC0109AF040AB2050BB4050BB3030DB3030DB6050E
B6070EB6070EB3050AB70A0EB70A0EBA0E12B70E14B0111AA21621931F2DB65864BD6775
B45F6CAB5160AB4E5CA84556A03A489E3140A330429F2A3AA02836A22735A62534A7212F
A81F2DA71D2AA71D2AA91B2BAF1A27B3141CB80F15BD0F12C00D11C51114BF12168F1217
310508AFB0B3E5E8EBE2E3E5DFDFE2E1E2E6DFE0E4DEDFE3DBDDDDE4DFDFD4AEB09F3537
BD181BC50E12C20A0DC2080CC0080DBA040BB3030CAB030BA70209A80108A90108AA0108
AA0108A80007A60006A60007A40006A50107A30107A10107A50109A60109A60108A70107
AB0208B5070DB4060CAD0106AB0207AB0209AC030BAD050CA90309A60108A70208A20106
9A01069201078901087F00077F02087802067001046D010467010260010261080664130F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00894A178E6C62CFCDD4CAD6DE9CAEB493A6A6828B8A292324978B92DBDCE67E8691
100D19170407492913B78A4B4D12015D010287060E9E030EAA050AB0040AB4040AB6050D
BB060DBD060BC1080DC1080BBC0406BC060AB8070AB20409AB0109A70107A70108A80108
A90209A80208A70208A70309AA0308B0040AAE010AB3040EB3030DB2040DB2040DB4040F
B60610B80811B4070EB5090FB70A0EBC0D14BB0C13BC0D14BD131AB5111BAE131EAC1623
AC1723B11926B21722B51823B3141EB2101BBC1823B91722B7131DBA131EBC121DBC121E
BB111BBA121BB61218B81019B70E16BB0F14C01315C11213C71417C91115C81518A6171B
4102058C878BD8DCE0E5E6EADFE0E4E2E3E7E3E4E8E2E3E5DCDDDFE3E0E1E5CDCDB15E60
AE191DBD0D0FC00C0EBD070ABF0A0EB7030AB20108AE010AAB0109A90006A70004A80005
A80007A70007A60107A50107A40107A10006A20107A30107A60209A70108A60108A70108
AA0209B1030CB4060DAF030AB0050CAE030AAE030BAC030AA80208A80309A60207A10106
9A01059200078B01088601078001067900047201036B00026800036201026103025F0A06
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4816886256D8D1D7BEC9D0C0D1D87E8E92767B7D2C2024A79AA1DADCE5626975
120B141B04046845259A69364D060174050C8F030DA0020DA80209B1050DB3040BB7060E
BC070EBF070DC0090CC0080ABB0405C00B0DB40407AE0107AC030AA90108A60104A50006
A70208A60208A001069F0004A60208AF0309B1020CB5040DB3030DB2040DB0020BB4030E
B4040EB80611B70711B4050DB60A10B5090FB70A13BD0D16BD0F15B80C13B80F15B20C14
B71217B61116B81317BB1418BA1316BB1218BD1318BB1319BA1318B91117BD1519BC1317
BC1517BB171BB61719B8181AB61415B81515BA1615BC1415C11517CA191BC61717B11D1C
5E0C0E5F4E51CED0D3E0E2E4E4E6E8E5E8EAE4E5E8E3E3E6E0E0E3E1DEE1E7D9DBC48589
A42123BB1010C10E0FBC090BBB080EB4040BB1030CAC0109AC020AA90107A60103A80104
A80007A70007A40004A40105A40207A00006A00005A30106A70208A60107A40007A50008
AB030AB1050EB1040BB0040BAD020AB0030CB1040DAB0108A80007A80108A70209A10108
9B01079400058E01068701067F00037701037001026B02026601026202016001015C0502
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F4A18A27A70C6BFC6CCD6DE96A8AF7E8D9384848B2C1D25BAADB6D8DBE5444A56
180C15200404916B3B784322620C0485080E9A040DA6030CA90109AE0209B3040BB8060D
B9050CBD050EBF060BBD050ABC070BB60409AC0106A80107A90209AA0108A80206A90209
A80309A70208A40107A30108A70209AF030BB4040BB4040AB20309B3040DB2040DB4040E
B60610B70510B80711B5070FB1080DB0090DB30D10B71212B71112B61213B61514B41513
B11712B01714AE1914B5211CAF1D19AE201CAD211DAE2320AB261FA6251FA82A21A92B25
A82E28A32D27A23029A33029A4312AA6312DAB3631AC3730AE342EB53531B83733AC3B36
732D294B3633C3C2BFDFE1E0E1E4E3E5E6E6DFE0E2DFDFE3E2E0E5E0DEE3E2DADECFA5A8
942829B31615B80E0DB90E0EB2070AB0040BAE040CA90108AA0209A80107A50004A80106
A80007A60007A50106A40105A20106A20107A40007A50108A50107A30006A30009A6010A
AA0209B0050BB4070DB2040CAF0209B1030CAE030BAA0108AA0209AA010AA9030BA4010A
9D01099401078A01078402067F01047C01037401036A01016100005F01015E02016C1813
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00934E188E655CCCC7CFCDD9E28D9EA58B989F82818A2E2028C2B8C2D2D5DF2C303C
190B12270902A87E475C230D5F070184060B9D060EA7040DAA040BAE050EB40810BA0811
BD0810BC050DBF070DB80209B6050CAF020AA70007A30005A60006AB0209A80106A90209
A90209AC0107AD0108AE020AAC0209AC020AAD050BAE0407B2060AB3060CB3060CB5050F
B3040DB70810B4080EB10C10AC110FA81610A51A12A41D13A22116A3261AA62E23A9372B
A63E30A44538A74F42B9655BB7675CBF736AC87F76CC867CCE8E84D4998FD79E92DAA59A
DFAEA2D2A69BD9AEA2D9ACA3DFB3ABE4B8B2E8BCB5E7BBB4E9BAB3E9B7B2F1BEB9ECBFB9
DABDB6CABFB8D9D7D3DDDCDCE0E1E1E1E2E2E1E2E3E0E0E3E0E0E3E0E0E2E3E0E2D9C1C1
975451992B27A1211BA11A15A117139F100FA00A0CA20409A30107A60107A70107A80109
A80108A60007A50106A40008A5010AA5000AA50009A40008A40106A40107A6020AA50108
A80308AF0609B30509B3040AB2040AAE020AAA020AA90109AB010BAC030EA8010EA4010C
9E010A9300088001057701027C01057C01047600026D01026300015E01015B02027E2E29
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00944D17895C50D1C9D2C1CED6BCCBD36C7A8168666E30202ACDC5CFC3C9D2191F27
17090A381707B185514B10005B03027E030899040DA3060EA1060B9C0207A20408AE070D
B7090FBC070DBD0810B2020BAD0109AC010AA80209A50106A70108AA0009A80108A9020A
A90006AD0107AF0207B1020BAC030AA601089B0103A00105AF070DB0030CB3060CB60610
B2040DB40A10A10A0E88100FA23F35AE5648B56858C47F71CC9080D59F90DDAB9DE5B7AC
EAC4B8E8CABDE9D1C6EDD6CEECD8D1EBD9D3ECD9D6ECDBD7ECDCD8EBDEDAEBE0DAE7DFD9
E3DFD8E4DEDAE5DFDBE4DEDBE5E0DDE4DFDEE5DFDFE8E1E1E6E0DFE4DFDEE6E1E0E7E2DF
E1E0DCEAEAE6E6E6E6DEDEE0E5E6E8E3E4E5E1E2E3DFDEE2E0DFE3E0E0E2E3E2E4DAD3D3
D3BCB6C99F97D09891C0817AAE6961A1544C9B3E3A9018179A0509A50108A50007A60007
A80108A70107A40005A50108A50009A50009A6010BA40008A70308A60107A50109A40109
A60308AC0509B20409B5060CB3050CB00309AF040BAD020BAC020BAB020DA8010DA4020B
9D010994010A8102057100017701057A01067601037001036701026002015A03027D302B
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00954D1883534ABDB2BCCDD7E0A1B0B86F7E836B6C71332730D4CED7AFB7C110161D
18080654301C98683B4806006305067F020898040D99030B9100068E00078E0005990005
AA040BB8060CB9070FAB0109A50009A9020CA8030AA70107AC030AAB0209A9020AA80108
AB0207B1040AAF0207B1020CAD040BA8030B9C01069E0006AE070EB1040DB4070DB4040E
B3050EB10911920B0F450201AE8B82E4C8BEECD7CEEBDAD5E7DDD3E6DCD3E6DDD7E5DBD9
E4DCDAE3DDDBE1DDDBE3DFDEE3DFDFE4DFE0E2DDDEE2DBDDE5DFDFE5E3E2E0E1E0DEE1E1
E0E3E3E2E1E5E0E0E2E0E1E2E1E3E2E0E2E4E2E3E6E0E1E4E1E2E5E0E1E3E0E1E3E0E3E3
E1E5E5E3E6E6E5E6E9E2E2E5E4E4E6E2E3E3E1E1E3E2E0E4E0DFE4DFE0E4DFE0E3DCDBDC
E4E0E0E1DADAE4DADAE2D6D6E1D2D1DECBC8DAB8B5A55C5C890A0E9E0108A60109A70108
A70007A60107A60107A40107A30108A50108A50009A50109A40208A50108A3020AA0010A
A4020BA70108B1050EB2040DB0040CAF030AB0030CAF040DAD030CAE060FA8020BA5010A
9E01099201088601087A01037801037C02067600046E01036500025F0101570100792A24
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0099511C78473DB2A7B0CFD6E0A1AFB78C9CA06E70743E373ED7D3DC9099A20B0F16
1706047650317746274D0A015E020483040D9A050F98020B9101088F01098F00059B0108
AB030BB6060DB5060DA70008A10008A50107A60108AA0208AD0208AB0109A70107A80108
AC0308AF020AB0010BB2030CAC0208AD030AAC040BAB020AB3060FB4040EB3050EB4060C
B5060DB50811A11117430103786767D3CBCBE4DFDFE2DFE0E1E0DEDFDEDCE2DEDDDEDCDE
E0DEE0E1DFE1E0DFE1E2E0E3E1DEE2E4DDE3E1DBE0E0D8DFE3DADFE0DAE0DCD9DDDAD5DB
D9D4DADCD3DBDED7DCDCD6DBDFDADDDCD6DADAD2D8DCD3DADDD5DCDBD4DADCD5DBDED8DD
DDD9DEDBD7DCE0DAE1DFDBE0E0DDE0E2DEE2E4DEE5E6E0E7E3DFE3E2E1E5E1E0E5DCDCE0
DFE0E4DFDFE3DCDCE1DCDBE0DAD7DCD9D4D8DDD0D2AB7A7C7E10159C030AA60109A70209
A60108A50006A50106A40107A30108A2010AA3010AA40109A40008A400099F010B980009
9D020AA40109AD030CB0050EAC020AAD010AB2040EB0050FAF050FAB040CA70209A40107
9C01069000068801088201067D01047B01057501036C01026301015E01025801016E1E17
2F880200FF0000FF0000FF0000FF0000FF00
00FF00954A165B291EB3A6ADB3BBC4BAC7D08B989F4E4F54494349D8D8E06A737D0B0A14
1B0705936B454F1F0C4807015B000180020B98040D9701089200069400089C020AAB040E
B5070FB90710B3050BA80107A50107AB020BA70107AA0107AF0309AC0209A90108AA0108
A80108AB0109AB0106B0040AAA0108AE030BB0030AB4050CB3050BB3040BB2050BB40710
B4060CB7060FB2121967070D503436C9BFC2E8E2E4E6E0E4DFDADDD9D1D5D9CDD2D3C6CC
CDBFC4D0C0C5C4B0B7C3ABB5C7ABB2C4A2ABC19FA9C29AA7C89DAAC799A7C0929EBF8C9C
C18C9BC78E9CD599A8D699A7D697A4CE8C9AD593A0D5909FD995A5D592A2D695A6D092A1
D69BAAD09AA8D39EADD1A1AED5AAB5DDB4C0D8B3BFD4B2BCD1B2BBD6BDC6D2BDC6CEBFC7
D0C4CDD4CBD3D3CED5D8D3DADCD5DCDBD4DCDCD2D8B591947E1E239A060EA60109A8020A
A8010CA60008A40006A40107A40007A3020AA3000AA3010BA3010CA4010CA3030D980109
980009A1010AA60108AD050CAE040CB2050EB2060EAF060CAD050CA9030AA7030AA30108
9A00068F00058801078301067D00057A01077400056C01026201015D01015701016F2019
2E870100FF0000FF0000FF0000FF0000FF00
00FF00924A185C2B23AC9DA2ADB5BC929FA8808B914F4D525F575FD5D6DF3C455007050D
1F0B019B724A400F014B030169020686010A99040C9C01099B0109A1010AAB060EB00610
AF0810B20912AD060BAB040BA90209AC020BAC0209AC0109B0010BAC0109AC020AAC020A
AC0208AC0109AD0208AE040AAE0509AF020AB3040BB3040BB3040AB3040DB3050EB4060F
B5060DB80711B40A14900A13520B0FD9AFB5E6C4CAE0BBC4D1A5B0C68F9DC28490BE7A85
B56A77AA5A69A34F5B9E4351A03E4B9F39459B343F9F31419B293A9B25379C24359E2133
A12133A51F30AC2233B22233B72433B61F2EBC2432B82130B92233B71F32B82134B21F31
B22233AF2332AF2638AC2A3AAE323FB23B49B54152BD4B5EC25465C55D6FCA6C7EC47183
C3798AC88495C18897BA8B98BA909DBA97A2BEA2AAB48A8F8F343996070EA6020AA7020A
A6000AA60009A50107A30006A50108A40109A2010AA2000CA1000DA3010CA3010B9F0109
A0030BA00008A40007A9020AAF050DB2040DB3070EB1070AAD050BA60108A6020AA2020B
9B02099100068901078001057B00047800057401036D01036501025D00015701006C1D13
31890200FF0000FF0000FF0000FF0000FF00
00FF00944C1A4D1B11A09295A5ACB06A767B838B91605D636E666ECFD1D9252C35050205
351F137F59373B05005903077D040C90030B9C030CA1010DA5020CAC040FAE050EA4030F
940107970309A10409A70308A90209AA0108B0030CB1010AB20309B00208AE0106B0020B
B2040AB00108AE0108AD0107AD0107B1040AB1040AB3030DB2020DB2010DB4060FB4040E
B5060DB60711B60811AF0D1699111AB84752B64A55AC3A49A42838A62132A51B29A81928
A61322A5101FA50F1CAA111BA90E17AE121CAF141DB1131CB1111AB2111BB5121EB40D1A
B70E19C2111CC9121CD0141FD3151DD31319D6151AD4131AD3131DD2121CD3131CD0111B
D0111BD2141ECB111BC60F19C20F18C2101BC41121C41122C91724C11221BA1425B11324
AE1526AE1B2CA61C2F9E20309927369C35459F414FAD515DAB343F99030DA6020AA60108
A50108A40007A30006A30106A30107A30109A2010AA3010CA3010BA4010AA40009A30009
A20109A20108A00005A50107AC020BB2050FB3060EB1060DAD050CA70109A301099E0109
9A01089201078900058000047A01047801047401036D02036301015B01005601006E1E14
31890200FF0000FF0000FF0000FF0000FF00
00FF00964E1B4D1611A492988A8F968F999D7A82853532397B777DC1C4CB14181F0C0102
593D286A432B3D020164030886050B95010A9F030EA5020DA7010CAE040DA9050E95010A
85000584000498050DA5020BA50007A80107AF0309B2020AB50309B30308B20208B5020B
B4020AB70309B60208B3020AB00106B20408B00509B1040AB3030DB3010DB4040EB4030D
B5050DB60610B60610B50710B40A14B8111BB9131DBB111DBD0F1BBF0E18BF0F17BF0D19
BB0A16B80813BD0E16BA0D13B80B13B70A13B70C14B91217B71115B71014BA0E14BF0C15
C40D14CD1017D21118D20E15D50F14DA1315DA1113DB1318D40D14D60F15D70F13D50E13
D30E14D00B12CF0C14CC0B13C90B12C60812C80914C80A13CE0E15CA0A11C50911C40913
C10712C10B15BB0714B50715AF0915A80915A006159D09179D0511A3020CA70209A60008
A40006A20005A50108A40107A20105A00005A00007A4020AA30109A20109A30109A4000A
A4020BA10007A00105A20004A70007AE040DB2040FB2060FAA020AA9030BA5020A9C0106
9601059101068A00058001037900027501027200016B01026001015A0100570100701D15
31890200FF0000FF0000FF0000FF0000FF00
00FF00974E184F170F927C828F9097727B7F5D65672221268F8B92AFB2BA0C0B11170403
805B3D471A104904046B020786000798030C9E010CA4010DA7020CAB040EA3050B8C0006
7E000380000591020B9F010CA20108A80207AB0004B20207B50208B40109B50309B7030C
B7020AB70208B70207B60209B10107B2040CB1040AB3040BB4050CB6050FB5030CB8040F
B8050EB90711B7070EB8050EB90810BA0A12BA0911BB0712BD0913C00B14BF0B13BE0A13
C00D18BC0811C20D15C00C15BF0E16C00E16BA0B13B70C13B70D12B60B0EBF0E12C91115
CB1113D21118D41217D40F13D71113DE1718DD1416DB1217D50E15D30C12D71014D60F13
D50F15CE0B12CC0913CA0811CE0C15C90913C70610CB0911CA0810C6040DC80811C50811
C2060FC3080FBE060EBA060FB1010AAF040BAA030CA9030BA6020AA7010AA70108A60107
A30007A40107A50108A50108A30108A10007A10108A3020AA10109A0010AA2010BA2000B
A20109A00107A00005A20006A70209AB010BB0040EB2070FA9010AA7020BA200099C0005
9801059001068A01078001057801027401017201026C02036301025C0100590101711D17
388F0800FF0000FF0000FF0000FF0000FF00
00FF00964E19481108947D8295999D596464535C5C26232899929B92929C0B070D1D0602
8F66463C0A0254060A73040C8A040A97030B9C0109A3010BA9020CA9040F9B040B860106
7E00068300088F030B99010A9E0108A50107AA0107B1020BB3020AB7020BB70209B8030A
B70408B60309B6040AB40409B2030AB2020CB3040BB20109B20208B5020DBA060FBC0510
BB060FBE0710BB070EBB070EBD0910B8050DB90710B90510B8070FBA0912BA0A11BB0C11
B70910BC0A14BF0B14BD0914BE0D15BF0B15BD0C14BB0B15B6080FBF0F12C71113CE1214
D11013D31017D41116D60F14D71113DB1415DE1718DB1317DA1217D70F15D60E13D20B0D
CF080DCD0810C8060ECC0813CC0915C80611CC0812CD0911CA0810C6040DC70711C40711
C1080EC2090EBE060CBA060EB4040CB0040CA80107A60107A80209A90109A90109A50108
A50007A50108A50107A50107A10007A00109A00007A001079E00079F0009A3010BA30109
A20106A00007A00008A10008A40109A9020AB0050EB40811AB020BA60109A201099D0107
9600068D00068700077F01067600037301017101016E02036702035F00015B020168120D
3A910A00FF0000FF0000FF0000FF0000FF00
00FF0067720E4610059881837375796A747562686A141115A29BA2636369070207260F09
82573E3401004D00046C010788020A9401099E040CA5030EA6010AA7030F920107800004
7F010883010A8A0109A3101AAD151D9D0007A8020AAE010AB2030DB3020BB50209B70209
B70408B40309AE030AA20207A00207AE020BB7060BB60309B30208B5020CB9050EBE060E
BD050DC1080FC20A0FC40A10C30A10BE050DBE070EC10A12BE0B10BE0D13B90B11B80B13
B2040DBA0A15BD0C14BD0912BE0C14BF0B16BC0914BF0A15C10D13C40D11C70F11CF1116
D21017D20F17D41015D71015DA1315D91214D81114D71014D91116D70F15D91116D71012
D40D0FD40D11D20C13CD0911CC0912CC0912D30E15D00A10CC0910C6070EC1060EBD050E
BB040BBD060CBB060DB6030DB0020BAC030BAA030CA70008A80109A80109A70108A50007
A50007A50106A50107A50108A10109A001099D0108A002099F0107A00208A5010AA50109
A30107A10107A00108A00009A10109A4000AAB020DB10512AB020CA50109A000089C0007
9600088E01088700078001087601046F01026F02026E02036701025F00015A0100610905
388E0800FF0000FF0000FF0000FF0000FF00
00FF0066700E490F07886D6D7472756C7275525757141113A9A3A8434348040102351F19
653D2A3B05034E00066D020A87050C8B010797020BA0020CA7020CA7040D8F0005800004
80010880010A7E010695061099070F950106A5030AAB020AAC0109AE020AB2020CB6040C
B7050CB30309AB03099A0103920000AC040AB9070AB90509B70308B7040AB9050EBB060C
C30B10C90C13C6080FCA0C12C90C13C5080FC50B11C50D12C00D10BC090EB90A0FB7080F
B80911B80712BB0712C00B14C10A14C10A16C10C16C60E18C60E13C90E12CA1013CB0E14
CD0E15D3111AD41016D81317DB1416DA1313D61112DA1417D81015D60E12D60E12D60E10
D81013D70F13D20B11D00B13CC0810CD0911D30E15CD0912CA0810C4060DBD040BBA030C
B9030BB70209B7030BB5030DAD020AA80109A8010BA8020CA60108A60007A70107A60007
A50106A50107A40107A10107A00107A00107A00008A001089E02089D0106A2020AA20109
A100089F00089D010A9D01099E010AA00109A5010AAE050FAA020CA6010AA2020A9B0109
9501098D01088700078101067301036600006901016D01026A01026301015C01015D0501
378B0600FF0000FF0000FF0000FF0000FF00
00FF003995015318107F63628B8788595D5D4244421C1717A5A2A526262A05000150392A
3F1B1337000359030C7A050F88030B84000492020B9F030DA5030CA2040D8F0107840005
8001077C020970000482071085050A880005A1020AAB030BAD030BA90108A60006AA0108
AF0308B5050AB2050CAC030BA60308B3040BBB050BB90308B90409BA060DB50109B50106
C30B0FCE0E13CE0C11D31016CD0C13C6080EC50C11C30C12BD080FBD0912B8050EBD0A12
BC0A11BD0C15BD0914C00912BF0810C40B16C70F17C70E15CC1216CD1114CC1011CC1215
CB0E12CE0D15D11116D41215D31012D91516D71213DB1618D91415D81113DB1416D91013
DA0F13D81013D50D11D30D14CC0810CD0B13C8050FC7050FCB0913C3050EBB030CBA030D
B9010AB7020AB8040CB3020BAE020BAB0209AA030BA6000AA7010AA60107A60004A70207
A40107A40008A20108A00005A10006A30107A201079F01099901069701069D02069F0105
A102089D01089B01079B01079B00079E0008A20109AB050DAB050FA6010BA1010B9A010A
9300098E00098800088101067802046B01016B01026D01016B01016602015E00015B0200
33870200FF0000FF0000FF0000FF0000FF00
00FF003B9701430A038163636B66675A5B5C6362612D2727A8A7A91212140600005E4433
2706013901055E010A8003108C030C8C000895020B9C010AA0020A9C020A8F0107870006
8501067D0106670103620104690001830105A2030BAC020BAA0308A10004A00004A40005
AC0207B5050BB30209B30109B5040ABA050CBE050DC0070DBE060BBF0810BA040BBE070C
CA0C11D10E12D51114D50F14D51118CB0B12C3090FBF0910BD0910C00D12BC090EC00C12
BC0B0FB90B0FBB0B10C20B12C70F15C80F15C71015C81115C81113CB1215C91014C81215
C51413C71517C71517C71416CA1616CE1816D21B18D41B19CF1513D01512D71919DA1719
DC1317DB1014D90E13D40B11CD060FCC0811C90712C6040FC80712C2050FBB020BBB020B
BB030BB7010AB5020DB2020CAF030CAD020AA90108A70108A60108A60308A50207A40107
A40108A20108A10107A00006A10106A10107A101099D01089401059200039700049B0004
A001099F01089E01079C01069C00069E0108A1010AA7030CAC0710A6010A9E0209900107
8C02098D020A8801088101057A01037202026E01026F01026D01016801016101025B0100
65100300FF0000FF0000FF0000FF0000FF00
00FF00399500460A027251536E68696A6A6C4544443E383A9B9B9D0708090B0401533D2E
1C01003A01065F030A7F010E8D010C92000A9B040D9D020A9A000997020A9101098E0108
8D01088A020A7A060E9F3B4295282C93060DA4020AAB020AAC0408A70104AA0306AC0308
AD0306B5060CB60409B8040BBB040BBC0309BE050DC0060DC0070DBE040DC0060CCB0D13
D00D13D41013D00E0FD20E12D41014D00E14C90E14BF0810C10F14C11214BD1111BB1212
B71412B71613B81614C11617C31415C51215C81316C70F13C91113CA1217C1121AAC161B
AF2C27B23631B13835B43B38B63D39B9413BBE443EC54842BF3F3ABE3D3AC33C3AC52A2A
CD161CD10B11D60D12DA0E16D30B15CF0913CD0912CB0811CA0710C60610BF040CBE050C
BD040CB8010BB3010CB1020CAD020AAD030CA9010AA70108A50007A40109A20008A40007
A50108A30107A00106A00007A00108A1010AA1010B9C00099902089401049601059B0106
A0020BA1010B9E01079D01079C00089C00099F020B9D0109A1040DA1030D970209820004
7D00048301098001067D02067A01047400027200037100026F01026901016302025A0100
64100400FF0000FF0000FF0000FF0000FF00
00FF003A95004A0B04714F51877F7F5E5C5C3835324D45477C7B7E0201021C130E432F25
1800003601045D02087F030E8E020D93010B99020B9C010C96010A93000B92010B92010B
93010B93020C950F1AB73B46A31D269F040BA60208AC020AB10409B20308B20308AF0208
B00209B30309B70409BA040CBA020ABC040CBE070CBE050DBE050BC4070EC70810D00C12
D20E13D41014C8070CCE0B11D00E11CE1113C41013B81015B4191BAF221DA92C25AD3C35
AA4138AF473EAF433BB03B35AD2C28B12320BE211FC21817C71515C81518A70D13590001
AC7774E1B6B1E5BCB6F0C8C4E9C2BDEFC7C2F3CAC5F2C8C2F3C7C2F3C4C1FBC4C4F1999B
B92A2DC60F14CE0A0FD50C12D60E15D00910CF0910D00C10CF0C11CA0A11BF040BBA0308
BD070DB5020CB0010BAE030BAB0209A8020BA7010BA6010AA50009A5010AA40009A40008
A50007A30106A10106A20208A2010AA1000B9F010B9D010A9C01099B01099800079A0108
9C01099E010A9D00099D010A9C000B9C010C9C000B9501099100089C061195030E840308
7A00057C01087300046F00037402067501047100036F01056F0105680103620202590100
630F0300FF0000FF0000FF0000FF0000FF00
00FF003B96004B0B017C58596D656452514F4742405952556160630401022F211C2A1714
1900003700015B00047C010A89000A92020B97010A99010D92010A91000A8F010A91010A
91010A93010B91010C95030EA1060FA40208A80307AC0209B0040AB2040AAF0307AF0209
B4050CB5020AB60309B6010AB9040BB90109BA0207C0050CBF050BC60910C6060ED00D12
D20E10D40C0FCB080BD00D11CF1215BF1314AB1B1A8B1A1B933E38BE7E75DBA9A1EEC5BD
EACAC0EAC9C0E5BFB9E7BCB7DCA8A3D08B85C06962B1413BB62A26BF2120A71B1C450204
665A5EC8C8CAE7E3E1EBE5E5EBE6E5E9E5E4E7E3E3E4DFDEE9E4E4E5DFDFEFE3E4F5CCCE
B5494EC1171CCB090FD50D12D50D12CF080ECF0B10D00D11CB080EC5060DBD040AB9040A
B9050DB2010AB0030CAD030AAA020AA7010AA7010AA70108A70109A50109A20009A10109
A10107A10107A10108A20209A20109A0010B9F000B9F010A9C00089A0106990007980007
9A00069C01089C01089C00079C01089C01099E020A9C010C96020D95030F88020A790104
7C02077F01077B03086C01036B00027301047001026E01046D01046801036202025D0200
67120600FF0000FF0000FF0000FF0000FF00
00FF003B96004B09006F4D4D6961636B6A6A353331706B6C404043040001402E26190503
2200024502056002057701078201058F020B94020A95020C8F00098D01088F020A91010B
8E010B91010B91000A98020BA00309A20106A60105A80106AB030AA80107A40005AA0106
B20409B7030CB20107B6020BB8030ABF060CC1060DC2060DC2080EBE030AC2050BCC0B0F
D00D0DDA1214D40F11CF1415BD191B8A13117B322CB68D86E0CBC3E7DCD7E9E1DFEAE4E4
EAE5E4E6DFDFE6DFDDE9E2E2E6E0DDEADDDAE8D4CFE1BAB5D2918CBD5D599F3835521215
2E252BB9C0C4E0E3E5E3E2E4E8E7E9E3E3E5E3E3E5E5E5E7E8E8EAE4E3E5E7E3E4F0DADC
C67478BD2128D41219D50D10D30C0FD10B11CD0910CB0810C5060DBF040BBA030ABA050C
B6020BB3020BB0030BAB0208AA0209AA030BA9030AA60107A80209A40008A10108A00008
A00007A001079D01079F01079E01079E010AA1020CA2010B9D0109990005990106990007
9A00079900059B01069D01089C01089D01079D01079C01099B030F91010D810108760001
82020789020A85030B7B02097300067503077001046C01036B01036902046201025F0301
6F190D00FF0000FF0000FF0000FF0000FF00
00FF003C97004C0A01664142857C7E605F601E1B1A8B868728282A070000412F26150100
2901014A02066101047101047C00038B010893020993020B8E01078C01098E010A91010C
90010E92010C94010B97010A9C020A9F0106A20106A90309A90209A50108A10004AB0209
B5070CB6040AB40309B7020BB9040CBD040CC1060DC2050DC2070EBF060CC40B0FCC0E0F
CD0B0CD30E11CC0F11B61418760A0C7B4544D9C5BFEBE5DFEAEAE4E2E3E1E2E4E3E5E5E7
E7E5E8E6E2E5E4E3E4E4E4E4E3E3E3E2E1E1E2E1E0E6DFDEEBDDDAEDD1CED7AFAB614242
131216A4ABAFE1E5E7E7E8EAE3E3E5E6E5E7EAE9EAEAEAEBECECEEE6E5E8ECEAECEFE3E5
D2969AB1292FD81C20DF1418D50D11D00A10CB060FC5040DBF030ABB030ABC050DBB040D
B9040DB4020AB2030BAE010AAC010AAC020BA80209A8020AA70109A50007A20108A10008
A10107A001079F000A9E010A9E0008A10109A1010AA0000A9C0108970005990106990005
9A01079B00079B00069B00079C01099B00079B010798010996020D8D020B820207830207
8B040A84010681010880030A7501066F02066A01046701046A01056801055F01025D0301
74201400FF0000FF0000FF0000FF0000FF00
00FF003F98004C0900754F50736A6B4F4C4D251F1F928D8F1413140E0806362520160000
2C00034E01056703077201047B00038A02088E02088B01088A00078B01098C010A8F010C
91010D92000B96030D97010B9801099B0006A10107A8020AAA0209A70108A50207AB030A
B1030AB6040CB7030CB6020DB8030BBD040CC0060CC5080FC3080EBD050ABB0407C70C0E
CB0C0FCF0F14BE1014820C0E4B1919C7B5B5ECE7E4EBEBEAE2E3E4E6E5E7E1E1E3E4E2E5
E4E2E5E6E4E7E2E4E3E3E4E6E2E1E2E0E0E0E2E2E0E3E3E3E3E4E2E7E5E4E9E5E3D5D2D0
6E72718A8F91DFE1E3E9E9EBE4E4E6E1E0E3EBEBEDEAEAECE9E9EAE8E8E9E8E8E9EAE6E7
E8C1C6B04149CB1A22DC1219DA1016D20B11CB070FC3020ABF030ABE040DBA010BBD060F
BA050EB6020BB4020AB10109B0030CAB020AA70108A70109A70109A60108A40107A30107
A20006A10007A0010BA0010CA10009A3020BA1010B9F020C9A0209940005970106970005
9900079C01099D01099D010A9B01099A010798010793000596020A90020A810004850208
8B030A8301067B00027F02067600046D00046801056501046902056501025E0101590100
66120700FF0000FF0000FF0000FF0000FF00
00FF003D98004D0A00744F4D655D5C5854552C26288D888C09070919100F241311190101
3101035001046902067401057B000484000784000784000785010988010A8800078B0009
8E010A92010A92000A94010A9600089B0106A10209A7030AA60207A40107A30106A80206
AF0108B5040CB3030BB5010BBA050BBE060BC2090BC5080EC6090FC1070DC2090EC4080E
C6080FC60D13B0181E4E03048E7877E0DAD9ECEAE9E8E8EAE0E0E2E6E4E7E4E4E4E1E0E3
E0E1E0E3E3E5E1E3E2E2E2E4E3E2E5E4E2E4E3E2E4E4E4E8E4E5E9E5E8ECE5E8E9E6E7E8
E6E8E7DDE0DFD2D6D7E7E8EAE7E8E8E4E4E5E9EAEBE9EBEBE6E8E8E6E8E8E7E9EAE7E6E9
F0D8DDBD6871B91B24D6131BDA0F18D70E14CE090FC6060BC3070CC0050DBF060FBD050E
B9020BB8030CB6020AB4010BB1020BAD020AA80108A60108A7010BA6010BA50109A30107
A40108A30108A2000AA1000BA10009A2010AA2000BA1020D9B030B920006940106980006
9A01089E010AA1010A9D00089C02099B00089A02099701099B030B9C040E93040B8A0107
8B00088D020A8701068601068202077301056601036301026401026402035C0202540100
5F0E0400FF0000FF0000FF0000FF0000FF00
00FF003F99014B0A00613C39756B6A6D69692B2428827C810501022A1B1B1B08071D0000
3300015401056C02077100057701057E01097C01077B00097E000B85010A8903098A010A
8B02098E010A90010A97030C9A010A9B02069E0007A40208A101069E00059B0003A10003
AE040AB4030DB2020CB5020CBA060CBE060CC0060CC5090FC1060CC3090EC60A0FC4070C
C80C13B90A10880C11360E0EC3BCBAE7E6E5E6E6E6E8E8EAE8E8E8E8E8EAE6E7E7E2E2E4
E0E1E0DFE0E2E1E3E2E6E2E5E6DAE1D2BAC5C7AAB9D0B9CADACEDEE4E1ECDEE1E7E2E6E9
E6EAEBE8E9EADDE1E2E0E2E1E7E9E8E3E5E5E6E8E8E4E8E8E3E7E8E5E9EAE5E7E9E7E7E9
EDE0E4D597A0AD242DCB1119D71119D70E16D30E14C9080FC2050DC10610BD030EBB010C
BB020DBC040FB6010AB6020BB4030DAF010AAA0109A60109A50009A5010AA6020DA5000A
A6010BA5010AA4010BA3010AA3010AA2010AA2010B9F01099A0209940106960208990108
9A00089E0009A000099F01099E010A9D01099D010B99020B9302079C050CA0050C9E040C
9B030C94020B90030A8E02088602087702076802036002035B00015B01025602034D0100
5D120800FF0000FF0000FF0000FF0000FF00
00FF004099014A09006E4A47766C6A534F4C392F306D666B0500002C1919140101230102
3D01025E03076B02047001047402047601067702077800097D010B83010B87020C86010B
82000681000788000895010A9B010A9B02079E0008A7030AAA040BA60108A10006A30005
AC0208B6050FB0000AB3040BB9060CBD060DBF050CC3090FBF060BBC040BC1080FC1060D
C1070EBA12186C080A3C2727CDCBCBE3E3E5E6E6E8E8E9EBE9E9E9E4E5E7E8E8EAE5E3E6
E2E2E2E4E3E5E7E4E8E8D8DEC38F9AA34659982A3E91294286354C925E74B09BACCACAD5
DBE0E5E4E6EAE4E8E9E5E6E8E5E7E6E3E5E5E5E8E9E3E6E8E4E7E8E4E6E8E7E8EAE5E5E7
EAE2E6E1B6BFA7343FC71821D7131BD40F17CF0C14C90911C2040DC1060FC0060DBE050C
BA030AB90109B8020BB7030CB5030BB3030BAD010AA70008A50007A40109A4010CA5010A
A7010BA5010AA3010CA1000BA2010AA2020BA000099C020A9203098801078F030A96010A
9A010A9C010A9F010AA1010CA1010DA1000CA1010C960108850002900206A80810AB060F
9F040E8801078402078E030B8101056B01026502045B00015400015800025802044E0000
62160C18C50100FF0000FF0000FF0000FF00
00FF003F9A014A0A007553516A625F5854514A42444C474B0801023522220E00001F0001
4705066003046A020270010271010373000574000779010A7C020A7D010B81010A82000B
80000680000689020896020B9D010A9F020BA00108A8030AAE040CAC030AA60107A80208
AC0208B3040DB10309B00309AC0106B30309BC070CBC050AB50105BA050DBD060FC20710
C60A15B40E175D0305493638D4D1D4E6E3E6E8E7ECE7E8ECE5E9EAE8E9E9E7E5E9E6E4E7
E5E3E4E6E4E7EAE3E7D1AFB79E3946BE1F2DCA1823CC1827C6212EA61D2E6F11226B394B
A89AABCECEDBDBE0E5E2E6E8E1E4E4E2E3E4E3E4E6E4E5E7E7E8EAE7E8EAE7E8E9E4E4E6
E6E3E5E9CED3AE555EB81A23CA0E15CC0C14C80910C5080DC3060EC4060DC4060BBC0208
BB0409B8030BB7020BB6020BB50209B10109B0020BAC0209A80108A7030AA40108A50009
A50009A20109A20109A3010AA3010AA2010A9F00099A01088500046C00007301058D030C
9801099B01069C00089D000AA0010CA5010CA6010D9F020D920208940208A70710A9050E
98050E78000372000188050A8503096D01026402036002045B00035B0103590202530100
61120A318A0200FF0000FF0000FF0000FF00
00FF003D9900460A006847477269696965675E595B2F2C2E110807251313100000250001
4000015B00016900016D02026D01037001077201077301077101077400077F020A84020B
8401078300058A01079A040DA2030DA0010B9F0008A50109A90209A90108A80206A90209
AA0106AF020BB0030AB4060FB0020AB30209BA060BB90308B70207BF0810C1070EC60A13
CB0C18BB101A660509412E2FD6D4D7E8E6E9EAE9EBE9EAECE9EAECE7E7E9E8E8EAE6E4E7
E8E8EAE8E6E9EAE1E3B5858CA82A33CA161FD01016D61215E01D1ED81B20C11922981625
5D0D1F69485BA7A7B3C4C9D1DEE3E6E2E4E6E4E6E8E2E5E6E5E7EAE3E7E8E4E8E9E3E5E7
E4E5E6ECDDDFC28089A91F27C10C14C70B11C6090EC70A10C3040CC8060DC7080DBF040A
B80109B7020BB7020BB6020BB3020AB1020AB5060FAD010AAA010AA7010AA7020BA6000A
A50008A50108A50108A50008A4010BA2010CA0000A9C01098F04097703056A0001800207
96020A9B01059D01089F010CA3020DA6010CA6010CA3020C9E030B9A0108A1040DA3050E
96050A7F01047A020584010889020A7802066B01026A0205630001590001550202510100
5D0D0632890200FF0000FF0000FF0000FF00
00FF003F9C03440B006C4B4B83797B4440466C676B1F1A1C180B0B1906071A0101350304
4B02025F02026A02036D00036B01056F01067201057201076D00037201057C010984010A
8201058500078B010897030C9F030E9D01099E0007A20008A40106A60107A60107A60006
A80007AC010AB0010AB3030AB5040BB8050AB9070CB4040AB8060EC20A12C1080FC10810
C1040EC0121975090C31181AC5C1C5E5E2E8E4E4E6E8E8EAE3E4E6E7E7E9E7E7E9E7E6E8
E7E7E9E9E8EBEFE6E8CC9CA3A82731CB161DD21014DC1417E01819DB1417D71618CA141A
B117227310203615256F6B78BFC3CADFE3E5E1E5E6E1E4E5E4E5E7E4E5E7E3E5E7E5E7EA
E2E3E5E7E1E3D1A5ABA02B33C3161CCA0F14CB0C12C90A11C4060FC3050EC4070EBF050B
BE050CBA030AB70409B60309B20209B1010AB0010BAF020BAC0009A90008A80108A80109
A70108A70208A40107A00007A0010BA1010CA0020C9B01099401078701057A0103840106
9602089C02059C0106A0010AA2010BA40109A4010AA0020A9801099B040C9E030C9B0107
A00A0E8F04098803098801078802097B01057100047101046D03055D01025000014D0000
580C042E880100FF0000FF0000FF0000FF00
00FF003E9A01460A007E5A5B7166673E393B767072100A0B2517151302021D0000390202
5302026503036C01026D00036C02067101077602077502087101057400057C0107830109
82000588000989010892000A99010B9C01099F0006A30106A50004A50106A50108A50008
A70209AC010AB2030CB5020CB3030BB00309A90206A40005A80107B80710B5030BB5010A
BE060FC01019890C122A0507B1ADB2DFDEE3E8E9EBE8E8EAE6E7E9E8E9EBE8E9EBE8E9EB
E9EAECE6E6E8EDE5E6E4B9BFA52E37C6141BD41216DF181CDC1519D60F13D30F12D20F14
CC1319B11A235306101D070F9D9CA2D8DCDDE2E4E4E4E4E7E6E5E9E3E3E5E5E6E8E5E5E9
E3E3E6E5E2E5DDC1C7AA4D54B7171FC60E13CB0D13C60910C0050FBB000BBC030DBF060D
C0070DBF060CB90308B70309B5030AB4010AB3010CB1010DB2010CAF010BAA0109A80208
A60107A60108A30109A00108A00109A0000B9F000A9C01099702078F00048901048F0106
9801089B00079C01089D0109A2020CA2000BA2010A9D01098F00069102099D060E9B0309
A0090F96040C8F020A8D02098403087903077402077302066F0205660304590100510100
580B0430890200FF0000FF0000FF0000FF00
00FF003F9B02480B00795455625657534B4E726B6F080102180A0A1101011F01003B0002
5802026802046B01036A00046C01057402087802087400087501087501067C010781010A
84020A8B010B8B010891010A96010B9E010BA20209A60208A60107A30107A20106A20109
A50107AB010AB1020BB4010CB5050DAF020BA80309AA040AAD0309B8050CB8030ABC030C
C1050CC30A12A6141A3A0102847A81DBDADFE6E7E9E8E8EAE6E7E9E6E7E9E9EAECE6EAED
E6E8EAE4E4E5E7E1E0EDCACDAC424BC71922D41118D8141AD61317D00C13D31016D41016
D01017C4171D7E0D142A00046B6269D0D3D6E5E6E8E6E5E8E5E5E7E6E6E7E2E2E5E4E3E8
E4E3E7E1E0E3E4D3D7B56F77A81B23C30F14CB0E13C1040BBE040CBC030DBC030DBD050E
BB030BBF060EBE060EBC040BBC060FB7010CB5010CB5020EB3020DAD020BA8010AA6020A
A60209A50108A10107A20108A20108A001079F010A9C0109990107940104900003950106
9901089B00089C01099C01099F010AA0000AA1010A9E020B96020B90010798030C99050D
91020995070F8B01088802097401066401026800036E01036C0103680203600201580100
5C0C05328B0300FF0000FF0000FF0000FF00
00FF00409C034809007B56548074743B31356A5F62090302180C0C110000280101460102
6003046901056901036801046A01057202077600067500087700097801097801077A0008
8401098E020B91020A9100099500099E030B9F0009A10109A20008A10006A30208A40009
A50108AA0109AE030BB0010AB2020CB2020DAF050DB0040AB7050CC1080DC90B10CB090F
D30E13D8131AC41C215B050748363CCFCDD3E6E7EAE2E3E5E5E7E6E5E6E8E8E9EDE6E7E9
E9EAECE5E5E7EBE7E7EBD3D4B75E63C31F26D11319D4121ACF0F17D10F17D20F15D31016
D31115CB131A9E131A470005382328C9CBCFE4E5E8E4E4E6E7E8E9E3E5E5E4E5E8E6E6EA
E3E3E7E4E4E6E7DEE3CD9CA2A12A2FC1161AC80D11C80B12C2060DC1060EBF070EB9020B
B8030DB9040DBA030CB9050CB60209B7030DB5040EAB020BA4040B9F050E9A040D9F0610
A2040DA4020BA4020BA50207A30106A101089F010A9D020A9A0108960006920004960207
9A02099B02089A01079B01069C01079F01099F010A9F020C9E020D96000A8D01088F060C
8F050C91050C92040C8A020A7702086001036401037104076B00026300006002025A0100
600E07338C0500FF0000FF0000FF0000FF00
00FF00439C044A09008B6663776A6A372C30584E4F0601010902021702023704054F0202
6102016701046302026201026701036E0104730105750108760107750108740005790105
8302098A010A8E020B91000A9400089A010A9C00079D0107A001099E0007A00105A4010A
A60108AA0109AB0109AF030CAC010AAB020AA90108AB0108B00109BC050ACD0D11D30D10
DB1013DF1318D1191D7E0A0E2B1013B6B5BAE1E2E5E6E7E9E8EAE9EAEAECE6E7E9E7E8EA
E9EAECE9E9EBEAE8E8EBD9DAB36E72B6252BC91319CF1118CF1118CF0F16D10E13D20E12
D31013D01218B6161D6D07102C050AA7A6ADDBDDE2E5E5E7E9E9EAE7E7E8E3E3E7E4E5E8
E3E4E6E0E0E2E5E0E4DEBEC3A34147BA181EC1070DC50710C50811C0060EBE060EBB030C
B8030CB6030CB5020BB2020AB2020AB0030BA7030B8B02057A0102A12129CC4B57A6252F
8C030B9E050EA4020CA40107A10207A1020A9F010A9C0008990106970007930006910106
9502089A01099D02099C00079D01079D01079E00079F010A9E010B9A020B8D0106880104
970A0F9703089F070E95040D85020A7101066B00027301066E02056100005E01015C0201
5E0C06328B0500FF0000FF0000FF0000FF00
00FF00419B034A0800886061604F52463B3F3C3437080101080001180000380101530203
6103016302035C00015F01036601046C00057102067301087300077401077401067C0108
83010A8701098B010892010A9401089800079C02079B01069C02059C01079C0006A00108
A50108AB010BAE030CAD030CA60006A40005A70107AF040DB10208BB050ACC0B10D91114
DE1215E01318D314189D12172D0002928F95D9DDDFE9EAECEAEAECEDEDEFE8EAE9E6E6E8
ECECECE6E6E8E7E5E6EDE2E2D5A4A7A92D34C3161BCA1116CC1116CD0D14D10E16D30E14
D10F11D21015C4171C95121A4201076F676DCDD2D6E4E8EAE6E7E9E5E5E7E3E3E6DFDEE2
DFE0E1E0E0E3E4E1E5E9D4D8B2666CAA181FC00B12C2070FC1060FBF0510BD040EBC040E
BA050EB6020BB5020DB3020CB0010BA9020B96060C7000017302069008149A101EAC2B37
7B01078B02099F030BA40209A100099E010B9F020D9D010A9A01069401068C0005850002
8C00059A01099D01089D00089E010A9E010A9D00099C00089E020A9F020B9A020B930108
9A080E9E060CA0060D95020A8600077B02067201027301057202056602025D01015B0201
5B050032880300FF0000FF0000FF0000FF00
00FF00449D054A0800855B5D7C6A6F4E41452A25260F05050F00001B0000380101530101
5F02025F01025B00005B01016201036B01076F0107700107700006740106780106800108
8601088801088A00078F010A9201079500079701069801069700059A00089D01099F010A
A4010AAA010CAE030CAC020BA90109A70108A60006B4050EBC0810C4080FD00D12DA1115
DD1317DA1014D31015B315194602035A5358D2D6D9EBEBEEEAEAEAE9E9EBE8E9EBE9E9EB
E4E6E5E7E7E9E1E1E2E8E2E1E2C0C4A64249BD1921C91218CD1218CC0D14D01018D00D14
D20F14D31015CA141AB1161F61050C3E2C31C1C5CAE6EBEDE2E4E7E3E3E6E6E6E8DFE0E2
DEDFE1E0E1E4E2E2E5E7DDE1C692979E2029BD0F18C30A12C0070FBF050FBC050DB9040A
B9060CB7030BB6020DB7030FB5030FAA040E8403096800018B09129F030EA1020E9E0614
87030B81010799050DA2030AA2010AA1020D9E010C9C010A9A01089400059101068C0205
9001069901089C01079D01089C00089C01099C01089C02099D010A9B010A9A010C9A020D
9C060F93010899071090030B8101067902056F02056C01056E02046801025F01015B0100
5E070234890400FF0000FF0000FF0000FF00
00FF00449D04510B00875D5F705F635045471510100C0101130101280202430202580202
5D01025C01015901005A00025E01016901076D01066D01056E01047301057A0105810108
8401078701088800088D010A9101099201069400069601079700079A00089E030AA0000A
A3010BA7010BAB020AAC020BAC030DAA020EA60009AF020BB40309BD030BCD0D13D41013
D71112D60E12D20F14C0151A680A0C2C1C1EB9BFC2E6E9EDE7E8EAE6E5E9E3E4E6E0E0E2
E0E2E1E2E3E5E1E2E2E5E3E2E4D3D4B86D73B01D24C8131BCD1017CE0C15D10F17D10F16
D10F16D00E15CA0F17BE141B820F1328060AA5A6ADE1E5EAE3E4E8E4E5E9E3E4E6E2E3E6
DFE0E3E1E2E5E1E3E5E6E3E5D3B1B5963139B20F19BE0811BE0811BD060FBC060DBB070C
B6050AB3030AB5020BB7020CB7050FAA07107301055B0002880910A0040CA5020EA2030F
91070E73000287040A9E040EA2020CA1010B9E020A9B00089B0008990108960106940106
9A02099B00079C01079C01089C01089B00079C01099C010A9C030C920008920109960109
9A050F89010785020988030C7900046F01026701035D00016403056402045F01025D0102
60080466140800FF0000FF0000FF0000FF00
00FF00459E03520D008B61615648495247480A07070400011000013002044C03035C0204
5C02015A01015801005900025C00016700046B00066B01056C0103730107780105800009
8401098700078801078C00098D00099100099200079500089801089A00089E020CA0010A
A10109A00006A60207A90108A60108A5000AA9020CAD010AB40207BA0207CD0C11CF0C0F
D00D0ED20E12CE0B13C00E167F0A0F200305888B8FD1D6DADFE2E4E2E2E4E2E2E2E2E0E1
DFDFDFE0E0E0E2E4E3E3E3E3E8E0E0CB969AAA292EC8161ECE1018D10F17D41219D10F17
CF0D16D00E17CE0F16C40E15A3161C3B00066C676FCDD1D7DFE3E5E4E7E8E4E5E7E2E3E5
E1E2E4DFE0E2DDDFE0E0E0E1DDCBCE9C5257A4141CBA0B15BA0611B9050FBB060DB70309
B6040AB3040CB3030DB3020CB6040FA90A126B01044700006C060B90050E9B040C9A020B
8B080E640001730307990510A1020DA0010B9D01099D01079B00069B0207960006950108
9801099B00089B00079C00069E01089E01099C01099C010B9A010D920109910007960109
9A050E8A02097C00048302097F010876010673030A6101035B01025B00016001015F0102
61080566160A00FF0000FF0000FF0000FF00
00FF00469F044F0B007953506A5C5B483D410402020600011401003201014B0201580201
5802015301005101005401015A01016701066B01066E01066F01047300077B010881000B
85020B88010A8801088C01098E010A90000992000A9301089401089700079B010A9E010A
A10109A40108A60107A90209A60107A70008AE030CB8040DC60C0FCC090FD10C10D00D11
CC0B10CB0B12C80B12BD0B139711163101025C595DC1C5C9E1E3E3E1E3E2E1E1E1E1E1E1
E1E1E1E0E0E0E1E3E2E1E2E3E6E3E2E1BDBFA73D42C51921CD1117D20F17D00F14D00E16
CF0D16CD0B15CF0F17CD111AB7151D5B040A3F2E35C1C6CBE7EBEDE6E6E8E4E5E6E1E2E4
E1E1E3E1E3E4DEE2E2E0E2E1DFD8D8A67477931A1FAF0911BA0812B8040FB9060FB6030C
B7040CB6050EB4040EB1020CB2020DA907107403073E000044010366030B7B050C7D060B
6A0408500101680207910410A0030FA0020D9E020B9D02099B0106990208930107910006
9501079901089B01089D01089E01079E01099E010A9D010C9A010C97010A97010A97010B
9D041096040E85000786020B84020B7E02087903096A0003630103630203610101610102
60080467190D00FF0000FF0000FF0000FF00
00FF0046A0064C090086605F695A5D433A3D0200010800002002023D0303500201560100
5201005101025000015101015800006400036C02066D01066E01047201077A01087F000B
84010C87010B8600088A01088E010A90000A92000A92010A9500099800079C020A9E010A
A10109A50109A9020AAA010AA70007AE010AB9050DC2060ECD0C11D20C0FD10B10CA0810
C3070EC40A12C30A11C00B12AA11174F030734272BB6B7BCDDDEE1DFE0E2E3E3E5E2E2E4
DFE1E0E1E1E1E2E4E3E3E3E5E5E3E3EAD1D3AF5B62BA1C24C91217D10F17D10E15CF0C12
CF0E14D00C15D21019CE0D17C2111C7D0A1329080C9EA1A6DEE3E5E4E6E8E3E4E7E3E4E6
E0E3E4DFE3E4DEE2E2DDE1E0E0DFDEB9999A8E2B30A80D16B40710B6060EB70610B6040D
B4030BB5030DB3010EB1010EB1030EAC050F8A060D4D01013400014200044C00034B0002
3F000240000367020B9405139F020E9D010B9D020B9C01079A01069600089001068E0004
9400059900079C01099C01089D01079D01089C010A9E020D9B000B9A010B96020A900107
91010A94020D8901088302097E02097901077501067001026D0103670102620001620202
5E020162110900FF0000FF0000FF0000FF00
00FF00459E054B08009169664E393B372A2C0300000B0101230100400201500202530201
5100005101025201005501015901006300036801056800036C01037100047A02087E000B
82010A86010A86000989000A8D010A9000099100099201089601089900089C0109A0010A
A20109A6000AAA020CAB010AAB0209B4030CBB030AC70910CC0A10CF0C11CB0A10C5080F
C0060DC10610C30913C00910B50F17700A1020080B9C9EA2D3D7D9E2E2E4E2E2E4E1E1E3
E3E4E6E5E5E5E1E3E2E3E3E5E4E3E4EDDEE0C5878DAF242DCA161DCF0E16D20F17D00D15
D00F14D00D15D20F16D41018CF131BA0141C380107747177D4DBDCE5E7E8E2E5E6DEE2E3
DFE3E4DEE3E5DEE3E4DDE2E2DEE0E0D1BEC191454D9E131EAF0711B4050FB3040CB4040C
B3030CB3030EB30111B20312AF040EAD040C9F060D7503094800026124276427293E0507
3300033D00016B020A9604119E020B9C010A9B01099B01099B010A9601099101068E0003
9300049800069B00079D01089E010A9E010A9D01099C010B9C010C98020C8F01098B030A
8C020A90020B8802087502076801066801056B01037202037303066601025F0001600202
5D030062100700FF0000FF0000FF0000FF00
00FF0047A006500900734744553F3D271A1B030000090000240203420202500101520100
5201005100015101005801025B01016200036A01066B00046F01017300027A02067E0109
80020B85020D84010A87000B8A000A8E00099101089502099801089B02079C0109A00008
A10008A6010BA9010BAB0009AF040DB3020CBA050DC50A10C90A0FC90910C3070CC2070E
C0070CBF060CBF070DBE080EB90D14890D132B00036B6A6EC0C5C8DFE1E3E1E1E3E1E1E3
E2E4E3E0E0E2E1E3E2E1E2E4E2E1E1EBE1E4DCB2B6A53138C51A1DCC0E13D21116CF0D15
D11015D20F17D10F14D20E14D11117B7181E55030941353AC2C7CCE1E5E7DFE3E4E0E3E5
DFE3E6E0E2E6E0E4E7DDE1E3DDE0E0DFD4D5A26971911723AD0C17B1060FB1020CB3030C
B4050EB1030FAF0211AB000EA9010AAC030BA70409990C10811E208D4B4DCD90937B3C3F
42000159010584050D9C030D9F010A9B00079800079B000A9B010A970109930107930106
9601079800089A01089B01089D010A9D010A9C01089B010899020B8D010A7E0005810108
8A030C8C030B8503096800025100015C00056D02057401047303056502035B01015D0201
5C030165140A00FF0000FF0000FF0000FF00
00FF0048A206520C0071433D5C4643160D0D0100000700011D0000410203550303550101
5302015401035302005700015E00046501046B01066E0105700103730105760207770109
7201077502097A020A83010B89010B8A010A90020A9501099801089A01069B00069C0108
9F0008A40009A60009A90209AD020BAF010BB00106BF070CC4080DC60A0FC1070CBF060B
C0070CBF080CBF090DBE0A0EB90B119F11194202063C353AA6ABAEDEE1E4DFDFE3E3E3E5
E1E2E2E2E2E2E2E2E4E3E3E3E4E3E4E6E1E2E1C6C7A74C52BC1E23CD1318CD0E13CE0C14
D00E16D00D15D10E16CF0C14D00F16C1131A780B11290C11A7AAB1DCE0E4E1E4E6E1E3E5
E2E4E7DDE0E2DFE0E3DEE1E2DEDFE1E4DCDDB98E9389202BA70C17B10812B1030DB2020D
AF020CAD030DAD030FAA010DA9020BA80109A9030BA2060CAB2E32B1565C8F464D7E2F36
811D2386070F9B040EA4010CA1000B9C01099B01099B0109980108950108910006950007
9800089700089900089C01089C01079D02099B01079A01079402098201077600057F020C
7E01097C010584040B77050A5D01045A00047004087501037002045F01015801005D0201
5A03016A1C1100FF0000FF0000FF0000FF00
00FF0048A3094E0C008E615F4029270F04040100000A0000210101410203530202550204
5201005201005201005701025E02056501056A01056C01066B00046B00046C01067A0E14
A33D428220296501057B020A86010A8A00098D01099301099701069A01069C01079D0009
A10109A50108A50007A90208AE020AB4050CB5040ABF070CC3090EC2090EBE060CBE070D
BD050DBE060FBE080FBE0B0FBC0C12AB121A5D080C1F1012868A8DD8D9DDE0E0E0E2E0E1
E1DFE0E4E2E4E4E2E5E4E2E5E6E4E5E3E1E2EAD9D9BB797DAD2025C71315D11317D00F14
D31018D30E15D20D14D10E14CE0D12C8131999141B33000579787FCDD2D8E3E4E8E2E3E5
E1E2E4E2E3E5E1E2E4E0E0E3DDDDE0E1DCDECFB4B88B3840A0121CAF0811B50812B1030D
AD020BAA020BAD030EAA020CA6010BA5010AA5020BA7040FA30815981321A12A39A12836
9B131E9F0610A5010CA6020CA101099B01079A01099A010A97000995020A920006960107
9901089A010A9B00099E020A9E01099F020A9D01099A00069703098701078100058B030F
88040F7800067D020A7B02096E05085D00026904086D03066702045C01015900015A0100
590200681A0F00FF0000FF0000FF0000FF00
00FF0047A2084F0D017C4F4A361D1C0C02010400011101012601004001014E01024F0101
4F00015101025201005500025A01026301066801056A010666010363010266010289151D
89161F760C165D000571020B86030A8C010A9000099301089601079701079B01089E010A
A20109A40107A50107A90108AE0309B8050CBC050BC1060DC3090EBD040ABB050CBC070F
BC0711BD0713BD080FBF0A0FC00C11B410157C0D132001046B6B70C4C5C8DFDFDDE2E0E1
E1DFE0E3E1E4E3E1E4E3E1E4E6E4E5E2E0E2E9E1E1D0A3A5A42C2EC6181BCE1314D01015
D00D13D10C13D20E13D00D11D10F13CB0F16AF151C4F020A494147C2C9CEE2E4E8E3E3E5
E1E2E5E2E3E7E0E0E3E0DFE1E1DFE2DFDCDFDACBD09B5E6696171EB00C14B3070FB2040E
AF050DAE040DA9010BAA030DA8030DA4010BA2010BA4000DA5010FA505159F04139F0313
A40211A7030EA7010CA5010BA3020C9E02099C01069B0008970009940109930007970108
9801079900079C01099C010A9E0209A1010AA1010A9F01099C010995010991010997030F
93030E8600097F020B7600057103066501045E01025D01015D01025D01015E01025D0101
5B020164130900FF0000FF0000FF0000FF00
00FF0048A3084F0D0171453C2813100801000500001701013202024702034C01014C0102
4C00015001015501015701025801015F01056501046801056201035A000163000382040E
8A040E83040F6401056401067E020B8A010990010994010997010A9600099901089C0009
A00108A10108A3010AA7010AB1030DBC060DC1080DC80D12C2090EBC040ABA040CBD080F
BA0610BD0811BD080EC20B10BF090DBD1117950F163401034D484DB2B6B8E1E2E1E3E0E1
E4E1E2E0DFE2E2E2E4E4E3E5E5E5E7E5E3E5E8E3E3DEC0C1A74548BE1A1ECD1317D11218
D21017D31019D10E15D31116D11015CE1016BD131A730B122A1218A5AAB0DDDFE4E2E2E5
E1E2E4E1E2E5E1E2E5DEDEE0DFDFE2E1DEE2E2DADEB1878B8D2127AC0E18B50B14B2070F
AF050DAF070EA80209A60009A8020BA40007A5010AA5010CA4010CA3010CA4010DA5010C
A6010BA8010CA8020EA5010CA4010CA2010C9F01099B010798010898020996010898020A
9801089800079B01079D01099F0109A10009A1000AA2010CA2020B9D020C99030D960510
90010B8E030B8A030B7E01087701076F00066B03076101025F0102640204650303600101
5B010063100717C30100FF0000FF0000FF00
00FF0049A4094D0C00825A5121120F0601000901011800003903034D03034D01014D0101
4F01015201015801015901005701005B00036201056701085C02054D000069020885020D
8D020A87040B6B02065C00047A020A8901098F010893010797010798010A9801089A0008
9E030B9E010AA4030BA80208B4040ABC060BBF060BC1070CBE050BBC060DBA060DC00810
BF0811C10A13BC070DC20B0FC00A0FBA0811A710194F04092F22279D9EA3E0E0E2E1E1E1
E1E1E3E0E2E3E2E5E4E3E4E6E4E5E7E5E3E5E3E2E2E5D2D5BB7076B51F27CA131AD2131B
D3111AD00C17D31018D00E16CE0D14CF1016C5111995131B30000875757DCBCED4E1E1E5
E4E4E8DFE0E3E0E0E4E0DFE4E0E0E4DEDEE0E4E2E4C9AFB18D363DA5131FB00A14B10710
AF060EAB040DA9030CA7010AA9030DA5000AA20109A3010CA2020D9F010AA2010CA3010C
A5000AA6020AA7030CA4010DA2000DA0010C9D00089D02099C02099A0108970108970109
98010A9900099C01089D01089F0109A2010AA2000BA6020DA7040FA1050E900108860108
89020A90030C8C01098601088102097C02087A03097001056C02056401035F01015F0203
5901006C1A132E860000FF0000FF0000FF00
00FF004DA70C5310037A4F491709070400000800001B00013901024B02044900014B0102
4D00005300005701005901005701005B000062000363020654020444000169040980030A
86020A7F040B6302055A00047B040A8C020991010A93010A94000898010A9701079A010A
9C01099D0008A10107AC040AB4030AB9040ABC070CBB040BBB050CBA060FBA050EBF0610
C0070FC00711C0080FBF080DC00B12BD0A14B1101A6B070F21070E8B8A90D5D5D8E1E0E2
E0E1E1E0E3E4E0E5E4E2E6E7E4E5E7E5E5E7E4E3E6EADEE2CF989EA7262EC6171DCE1017
D10F18D40F19D31018D00E17D00F16CE0F16CA1119AC161F4902084C424ABABEC4E2E5E7
E0E1E3E0E1E3DFDEE2E0DFE4DFDEE3DDDDE1DFDFE1D8CACD97585E94141EAC0A14B10812
AE0610AC0510A7000CA6010DA6020CA2010BA00009A1020DA0030E9D010B9D01099F010B
A1000BA5020BA50109A3000AA1010CA1010B9F01099D01099B00089B010A9A000A9A000A
9901099900089A01079B01079F010AA2010DA4010DA9040EA7050DA6081397040E870106
8C030B91010A8A01088601088601098002087E02097801057301046702035C01015E0202
58000075251E2E870100FF0000FF0000FF00
00FF004FA90D561303683D381204030300000800002401013B01014A02014800014B0102
4F01025702025902015C02015B01016202046500056202084C020437000057030773050A
73030A6302075101065601047A020B8B010992010891000995000998010A9B01099D020A
9F010AA00008A50208B1050DB8040CBA060DB8050BB8040DBA050EBF0A12BC070EBC040E
BE070FBD050FC10911C20911BF0A13BE0B16B50E18870D172A000769646CC4C4CAE3E3E6
E3E4E4E0E1E4E1E2E4E2E3E3E5E5E6E5E3E6E4E4E6E7E2E5E3BFC3A43A40C11A1FCF1319
D31319D31019D20F15D20F17D00E16D00E17CE1019BD17216A0810291217A8ABB1DCE1E4
E1E3E4E0E0E2E0E0E2DFDFE2E0E0E2DDDDDEDEDDE0E1D8DDAD7F85871A22AA0C16AD060E
AC050DAB040CA9030DA6020DA4010CA2010B9F00099E01099D010A9C010A9C000A9D010B
A0010BA4010BA4020AA2010AA0000BA1010C9E00099F020B9D010C9C010B9A00099A0008
9901089900079A01079B01079E0009A2010BA8030FA8030DAA050EA90512A2041095020B
90010991020B89010886000786020A7900057401057701067301046B0205630103610101
5A01007020182E870100FF0000FF0000FF00
00FF004DA80D521202754E4B1006050300001001003303044902035003034A01024B0102
4D01015402015801015C01025A000063020568020864030B4703062800003801014D0205
4E01054400034100025801037D020B89000790010892000A95010B9700099801079C000B
A0020BA3000AA8030AB2060FB6070FB8080EB6050CB6020CBB0710BC070FBD080EBB060D
BE090FBD080FBE0A10BB060FBE0912BF0A15B609149F121D45020C3A3139B9BAC1E2E2E5
E1E2E4E2E3E7E3E2E6E4E2E5E6E4E5E5E3E4E5E5E7E5E3E5E6D0D3AA5C60B81E25CE131B
D01218D31117D11014D10F15D41318D00F15D01219C313198D111A2E0109858389D1D3D8
E0E1E4E1E2E4E0DFE1DFDFDFDEDEDEDDDDDCDCDCDCE1DDDEBEA0A4842831A5101AAC060E
AD060EA9020CA7020CA5030CA5020DA3010C9F00099E02089D01099F020D9D000C9E010C
9F010CA2010BA3030DA0000B9F020D9D010C9E010A9F020C9E010C9B010A990108970006
9801089901089A00089C01099F0109A5020AA8020CA9040EAA0712A3020DA60611A0030D
97020C87010783020988030A88020A7B02087200047401066B01035F0102630305620102
5C02016D1C132F880200FF0000FF0000FF00
00FF004FAA0F521406724E4C0802020300001601013B03044C02024E01014C00024D0101
5001015400025801005D01015B00016201036701046302074C0206260000260000330102
3901043A00044600026803078101098A01088F010892000A95010996000997010A9A010B
9D0109A5020BAC080FA20309A10409B30912B70611B8040FBB0510BC0710BC070FBC070F
BB080EBB0710BB080EBD0912BD0912BD0814BB0C15AC111C640811231017A3A6ABDDDEE1
E1E2E4E1E2E6E3E4E8E3E2E6E5E5E7E4E2E6E4E3E5E3E2E4E7DCDEC28990A9252CC8191F
CE151ACD1418CE1519CE1519D0181ACE1518CD161AC6181AA91E2546040B594F55C6C9CD
DFE0E3DFDFE1DEDEDFDFDFE0E0E0E0DDDDDEDFDFE0DFDCDDD0BDC19148529B131FAE0A13
AD0610A8010CA9040EA7030BA5020DA3010EA1020CA2040EA0010D9F020D9D010C9C000B
9C010A9C0109A0030D9E010C9D010C9B010A9B00089C010A9B00099A0108980007990107
9A00089B00089B01089B01069E0007A40109A8040CA7030EA807139D010BA50712A6040F
9D030E8402067700048202088301077B01077A0208740205670203550000570101620204
5D0001600C0430880200FF0000FF0000FF00
00FF004FAA0F551709623D390900000400001600003901024B01024D01014C00024F0101
5301015900025900005E01025F01016301036501036301035803053401012901015C3033
8355583E05085D03077A03098701088D010A91010A92010A920108930108960208980108
9A0106A7050DA8050C9702038D0001A7050FB4040FB7030EBA0611BB0713BC0611BA0510
BA0710BC0812BB080FBC0811BB0A12BF0B14BA0A12B40F18810F162101047D7D84CDD1D5
E2E3E7E3E4E9E1E2E6E3E2E7E2E1E6E1E0E5E3E3E8E2E2E4E7E2E4D5B5B79A4042B32D2F
B72A28B72A26B52B28B42B28B22B27B32C29B5312CB02F2C9D2F2E5C222345393CB3B5B9
DEE0E3DEDFE2DCDFE1DBDFE0DDDFE0DFDFE1DEDEE0E0DEE0DED3D7A06A728C1520A90A15
B00812AD040EAB040CA9040CA8030EA5020DA3020FA2010EA2010E9F010B9D020A9C000A
9C010B9B00089D020B9E010C9B000A9700079900089B010A990109990109990109970108
9A010A9B00099C010A9F010AA10108A3020BA7040FA90411A8091499020B9A050EA20611
9B030D8F050C7C00047E03087901047300047803097201056B0204610305580000630203
630203630C082F870200FF0000FF0000FF00
00FF004FAA0E551607542C250D00000B00002202014103034F03024E01014D0101500102
5401005A01045B01035E01025E00016201026201026201026304064B0203380309996B74
8E6269621D24760A1285020B8B020A8D01098E0109920108910106900106940008980009
9D000AAA050EAA040CAA080EA40409AF060FB70610B90410B90510BA0612BA0410B9030F
BB0711BB0812B7060DBA060FBB0A14BB0712BF0C16B90E179C161D3701044C464EC2C5CB
E1E2E6DDE1E5DFE3E6E4E5E9E0E1E5E3E2E7E1E2E6E0E1E5E2E2E5D9D1D0BB9996CC9491
D89B97D59B96DFA8A1DBA39ED69F9AD8A39ED7A29CDCA9A3D1A6A1C2ABA8BCB8B8C0C0C3
DBDADEE1E1E4DDE0E2DCE1E1DBDFE0DEDFE2DEDDE1DFDDE0E1DBDEBD999F87222DA50B16
B0050FAF030DAC030CAE0911AB050FA8040EA3020CA3020DA1030E9C01099E030B9E020C
9C010C9C000B9C010B9C010B9C010B9A000A9B010A990109970008980108980208950006
9901089B010A9D000BA2020DA4020BA2010AA4020DA7040FA807129C060F8F0109980911
9101088D03097C00047A02077C030A7300066F01056B0204690204680405600102630103
63010268100B31880300FF0000FF0000FF00
00FF0050AD0F591D0D5E3C370900000D00002C02014904045002024B00004D0101510002
5601015901045801025D01045E00015E01015F010262010266030461070C752D377C414F
8D4C5B7D202D7E030E89010C8C010B8E010A8F01099100089002068C00059302099A010C
A0010CA8020AAE030CB0040DB2060EB5050FB9060FB8020EBB0511BD0713BB0712BB0712
B90611B80711B80810B90611BA0913C00C18BB0914BA0B15AB131C56060A2B1C21B1B2BA
DFE2E6E2E3E7E1E5E8DFE3E6E1E2E6E3E2E7E4E4E6E3E1E6E4E4E6E3E2E4E2DEDEE7DFDE
E7DFDDEAE1DFE7DFDDE9E0E1E8E1E1E4DEDDE5DFDEE8E2E1E5E1E0E4E2E2E3E2E4E2E1E2
E2E1E3E1E1E4DEE1E3DCDFE0DDDFE1DCDEE0DCDDDFDEDDDFE0DDDFCDB5B88E3940A20F1B
AF0512AD020BAD050DA9040CAB050FA8020EA6020FA2020DA10611A20C159B020C9D010D
9E020D9C000C9C010C9B000B9C010C9D020D9C010C9A000A9A00099B010A99010A990009
9A01089C01099D020A9F020BA1000AA3020AA5030CA6030CA9060EA70A1292040B840208
90080F90030A8201057A00057E02097B020A6D01066200025F0001630103650102670203
6501016C120E358C0700FF0000FF0000FF00
00FF004FAB0E6026175B3C380800000E00012A01014601015002024B00014B0100510102
5C080A5B080A5201015901025C01035E0105630206640104640103620105680B16721827
6F0E1D7A051386020E8C010D8C000A90010A91020892010A8E01058C000592010699000A
A2020DAD040CB1040CB3050EB2050EB40911B90910BB0710BC0612BB0713BB0712B80711
B60610B70711B70812B60610B90911BB0A15B80712BB0A13B7111B7A0A142402098E8D97
D1D4DAE0E4E7E0E4E4DFE3E5E1E2E4E2E2E6E3E3E5E4E2E5E4E4E5E3E3E5E3E3E5E2E2E4
E4E3E3E3E1E2E3E2E3E2E1E2E1E1E3E1E0E3DFE0E2E3E3E6E4E3E6E3E2E5E2E1E4E0E1E4
DEDEE3DFE0E4DDE0E2DBDEE0DBDEE0DCDEE0DDDEE0DFDEE0E2DDE0D8C1C494444BA1121C
AD040FAB020BAC030DA9020CA7000DA90310A5020EA2020DA106119E05119D030E9C000B
9C000B9D020B9D010B9D010C9C010C9B010C9B010C9A000B9C020B9C010A9C010A9B0009
9B01099B00089C01089E020BA1010BA5020DA8020DA9030CAC070EA8060E9D061087020A
86020994040B8E02088501098002097402086B0309600106610204660103690103690102
6703016C120E358C0700FF0000FF0000FF00
00FF0051AC105A1D103F1E1C0800000F00002C03014604034E01014C01034900014D0002
5002064A01025202025701015A02035D020561030761010564010464010369010770010B
77020B82010F8A020F8E020D8E010C91010B8E010991010A8F01059100059601079B0109
A4020BAC040BB1060BAF050BAA0309A80309B40710BA0810BB0610BA0612B80711B7070E
B4060EB3050FB30811B4070FB5090FB3040EB6060FBD0B11BC0F179D111B4302094E404D
B9BCC4E1E4E9DFE3E3DEE2E3E0E2E2E0E1E3E3E3E4E3E3E5E4E4E5E3E2E5E3E3E6E3E1E4
E4E2E5E2E1E3E2E3E6E2E3E6E3E3E5E1E1E3E2E2E4E1E2E3E1E1E3E4E3E5E1E1E5DFE3E6
DDE1E4DEE0E3DDE0E3DADDDFDBDEDFDCDEDFDCDCDEDFDEE0E3DCE1D5B9C1903B44A3111B
AF060FAE030DAC020DAC030EAA020DA7020CA2000BA3030D9F020C9E010D9E020F9D020D
9D010B9E030B9C010A9B010B9A000A9B010B9A010A98010998010A9A010A9B01099B010A
9A00099C010A9E020DA0020DA2010EA3010DA6030DAA050EA8030BA8070EA507109B0810
8C010992040D90020A8A02097E03076400015801055701055F02056602056901046C0203
650200640B074B4E0600FF0000FF0000FF00
00FF0052AE125C1E1042221F0B00001300012B01014201014A01014B02024A01014D0102
661B1F530A0E4F01035002034E03044E02055303075702075F03066802066B0004740008
7E010B89010F8D010E8F020E90010C93010B8F010990020A9001079301069802089C0008
A60309AF040CB2030BAE010AA90208A50208AE040CBA0A14B6040FB80511B80711B5040E
B2030DB1030EB40812B0050DAF050DB60B13B80A0FBD0C12BD0C13B4111B820F19390310
7C6B79C6C0CDE0DFE4E1E1E6E2E4E7E2E2E6E2E2E5E3E2E7E5E4E9E6E2EAE5E2E8E5E0E7
E3DEE2E3DDE4E0DEE4E2DDE5E4DFE6E5E0E6E1DBE2E1DCE2E2DDE3E1DCE2DDD9E1DBDBE2
DBDAE1DCDBE2DBDAE1DCDBE1DDDCE1DEDCE1E0DCE1E2DAE1E0CBD7BD8693901F2CAA0D16
B1060EB0050FAD020EAD030EAA010AA7020CA2010BA0030B9F020B9F030E9D010D9F030E
9D010B9E010A9C010A9B010C9A000B9B010B9A00099A000999010A990109990107980108
9900089B0109A0020CA2010BA4020DA4020DA3010BAA050FA7040E9F010AA5060FA2050D
97030B8A01098703098101057C02066D02065B00035301025801025D0103600102680202
660201600702600F0400FF0000FF0000FF00
00FF0054AF136528194225220C00001800003402024B04054C01014D0101510201500103
5F10145404094C01054300023C02035B1F226223274C080C4C01036001046D0002790109
85010E8C020F8E000C8F020F8E010B8F01098D01078C01088D01089201079501079E0107
AA040CB2030DB4030EB40410B1040EB2060FB4060FB1030CB60710B80612B70610B60611
B0020CB1050EB3050DB0040DB0050DB60B12B70A10BB0C13BB0A11BD0F18B1121D890D1D
5B081C773F56B389A0D1B2C6C7B3C1D1BFCBD9C4D0D5BDCADBBECCDAB8C9DAB7C6D7B1BF
D5AAB8DDADBDDAAABFD7A7BDCE9CB1D7A4B7D19EAFD6A3B3D9A5B5D8A5B7C596A8CB9DB1
C095A7BA92A3B78FA0C59EAFC9A4B4CAA4B4CDA2B3CC98A9B66B7D9C2C3DA50F1BB20710
B2030DB0030EAF0510AA0109AB030AA60108A5020CA4030FA0010C9E010A9D000B9D010D
9E030D9D010A9D020A9C010A9C010B9D020B9C010A9B010A9B010B9B010A9A00079A0107
9A01089E0308A2040CA2010BA4020CA2020BA2010BA6030EA60510A0020CA5040FA6040D
9E040D8701057E01037F01067C01067302066B0006660205620003620306590001620203
6704046A100C691A0F00FF0000FF0000FF00
00FF0054B011672D192F14100D01001A00003801014E03044C01014B00024F0202500104
5102045103054A01024901038030389B4854A4505E9C48554C01035900036F010682020D
89020D8B010F8E020D8D010E89000A8800088B01088C00098D0209910109940106A20208
B1060FB4030EB50510B50512B50510B5040FB80711B70610B70711B80711B6050FB0030B
AD0209B0050DB3070DB3050EAD020CB50710B80B11B80910BB0A10BE0C12C00E17BB121D
AE14239D142A9319349E354FB1556CBA6076C05F75B9546ABF5268BD4A5FB84458B53D52
B6384EB7374EB33149B33049AF2C44B12E44B02C3FB02B3EAF2A3DAC293DA9273DA7273E
A6273FAA2D44A52A40A62E43A73246A83248A83047A8253CA81729AE0B1AB60811B80610
B4040EAF020BAF040DAE030CAB030AA60109A6020BA6020DA4010DA1010C9E020D9D020E
9A000B9B010B9A010A9B010B9C010A9D020B9B010A9B010A9A01099700089A01079D0209
9B00089E030B9E020BA1020DA2020DA3020DA2010CA4010DA90710A7050FA8040FA7040C
A0020B92010A8A020889030A7E02057200037503097303076F01066B03075A01025C0102
640304650D096E211600FF0000FF0000FF00
00FF0054B1126229122A0F0A0D00002101014304044D01024A00004B01024B00014D0103
4B00014901014E000262040871040D7804137A06167A05156D040D6001046E000781010D
87010C89010D8C020F8D020E8800088901088C00098C00098C0108900007960005A40208
B0050BB4050DB3030EB4020EB90611B8040FBC0712B9050EB7070FB4050CB3040AB2060C
AF0709AF060DB1060EB1060FAF040DB2040DBB0D16BE0F16BE0B11C00B14C20B15C30E19
C00E18C0101BBE111FBB1322B91528BD192AC2192AC71A2BC91928CD1828C91825CA1725
CC1725CD1724D01926CD1524CC1522CB1421C91420C9131FC8151DC5141DC2101CC00E1C
C00F1EC00F1EBE0E1DBF0F1EBC0E1CBB0C1BBA0D1CBB0B1ABB0915BB0612BB040FBA0610
B3020CAE030BAC020CAA010CA9010DA6020BA4010BA4020BA4020CA0000A9E010B9C010C
9D020F9C020E99010D98000B9D020B9C01099B01089901079700079A02079D03099C0108
9C01099E020C9D010AA1030DA2020CA3020EA2010DA4020DA8040EAA050FA7040FA4030E
9F020B9801099402098F02098501077801047401047501057502067102056201035D0001
660405660A07701F1600FF0000FF0000FF00
00FF0056B2146C3219260B070E00002702024703045002014C00004D01034D01014B0102
4701024500015A02046E02057401047D01097F010A81010B7C030B6C02066C010881030E
86010D8A020D89010B8D030D8800078B00098D010A8A01088C00059300079C0108A80309
B3060BB4050BB5050FB5040EB6050EB6020DB90510B90510B4040CB5080EB5080DB1050C
B1070EB20710AD030CAE030CB20610B5050FBA0A12BE0E18BF0D13C30C14C20A13C40D16
C20E14C30F14C00D12C40F17C51019CB141BCB1217CC1017CE1119D0111AD01218D01217
CF1218D11218D3141AD3121AD2121AD11119D01016CF0E15CE0F16CA0E14C80F14C90F15
C60914C70A15C90C16C30912C30912C10911C10811C00712C00714BF0614BB0411B6030D
B2030DAD020DAA020DA6000CA6020EA5030FA3020DA1000BA3000CA1000B9F010D9C000D
9E020F9C010E9A010E98020D99020B9B01099B01089A01079701079701089A020A990008
9A01089C010A9D020BA0010AA0000AA3020CA1000AA2010AA6050DA90710A6040EA4030D
A3030D9E020B9901099301078C01078202077701047201056F01046D0205670204630002
6501026506036C191000FF0000FF0000FF00
00FF0054B2137E482B1F0B070C00002801014B04045303024C01014B01024B01014C0102
4501034801026302047402057801037C000681020B84010982030A6C02066401057B030D
84030D87020D88010B8A010B8801078C00098D010A8C00089101089601079E0008AF080F
B1040BB2020BB4040EB90912B4040DB7030EB70610B60410B4040EB4040EB60610B4060F
B0040FAE020FAD030EAE030BB3050EB70711B70711BB0B15C00D16C20C14C30C12C20D13
C10E13C11017C00F16C10D16C61118CA1116C70E13CA0F16CB1117D1151BD01317CE1115
CD1013D21318D6151AD31017D41119D10E16D10F15D00E14D00D15CE0D15CB0D14CD0F16
C80911C80813C80A13C50910C2080FC20910C10711C00711BE0511BA0310B90410B4030D
B1040DAB010CAA010EA8020FA6010FA3010FA40410A2020EA5020EA5010CA1000D9C000D
9B010D9C020E9B020E97000C9A020C9B010A9A000899010998020C97010A950109940008
9700089900099E040D9F0109A2000BA3010DA2010DA3020CA5040DA6070EA60D11A50D13
A1060E9D030C99010A9701079000068700077E0106730105680003640103640103680103
680102650200630D0500FF0000FF0000FF00
00FF0053B3136B381A1905020F00002C00004E03035302014A01014801014B02014B0204
4001024A01036703047702067800037D000682010885010C81030C6802055D000376030C
81010D84010E88010D8B020D8A01098C00089000099202089201089300069B0106AC050C
B0040BB3020CB6060EB5030EB6040FB8040FB70610B5030FB70610B4020EB50410B2030F
AD020BAE020EAC010BAF020BB2040CB90914B70712C1101AC5121CC30B15C50D15C20E14
BF0D13BC0B15BA0A14BF0D18C40F18C91019C70E15C70E16C80F15CE141AD01317CF1216
D01215D41316D41115D61319D41117D20F15D20F15D41218D20F16D00C15D00D16D00E16
CB0B12C90A11C6070FC60A11C2080EC20910C0070FC10911BA040CBA050EB9050FB6050E
B3040CB1040DAC030DA8020DA3010EA1000FA2020FA5030FA6020DA5010CA0010C9B000B
99000A98010B98010B99010A9B010B9A020A980109970108940108930108920208920109
95010B99020C9C020B9D020B9F010CA1020CA3020DA2010AA2060D9D1213A12F29A63E3A
932222900B1295030C9601099200098A01088301087A02076F0104670103660104680104
6A03046A030169110800FF0000FF0000FF00
00FF0054B314622F121C04001800003B03045403035402014D01014A0002480101440202
3600014601026703057601067B010681020683000881010B78040C5E01055A010477040D
83030F89031188010F8A010D8E010B8E01099201089401099401079201069D0108AA030B
B0040CB5040EB6050DB5050EB5050DB8060EB5040EB60410B5030FB60410B5050FB0020B
AC010AB0020FAD020BB2040EB3030EB40610B60611BA0913C00F18C00C13C00B14C20D16
C10E17BB0B15BA0A14C1101AC20E17C50D16C70F16C80F15CC1218CF1218D11217D11118
CE0F14D00F14D00F12D00D13D51217D20E13D20F15D41118D31018D20E17CE0B14CD0B13
CE0D13CA0A11C5070EC60A11C3080FC3090FC20910C00811BB060FBB050EB9050FB7050E
B6060DB0020AAE040CA7030CA1010DA1010DA3020EA3020DA3020CA4030D9F010A9B0009
9B010A9A00099A010A9A010A9B010B9B010C98010A96010894010A92000992010894010A
96000B98000A9B010B9B010A9C020A9D010AA3040DA2040C9A0C10A53F3CE5A9A3E8B4B4
E09AA1A24249870B1290050C8E030A8701088300087E01087600066F0105670102610001
6702026A050379231C00FF0000FF0000FF00
00FF0055B4147341201C04001E01014303045704035401015002024C01014601023E0102
2E00014002036304057301057A01057F01087C020875030960020649000155010672020B
7F010C84010D86000E8B02108D010C8D00089201099201089401079500089E0108A80209
B0040DB6050FB4040CB3040BB3050CB90912B4040EB3030EB3030DB3020EB3040EB0030C
AD020EAD010DAC000CB0010EB3050FB50711B50710B80812BC0D14C00D13C30E15C40D17
C00D16BC0C16BC0D16C01118C10F13C40E12C70F12CB1116CB1014D31318D21116D10E16
D21114D31016D11015D21015D41116D51216D20F13D41118D10E16D00E17D00E16CF0F15
CA0B10CA0B12C70910CA0D14C70B11C4090FC1080FBF060FBC050FBC050FBB030FBA040E
B9060EB10309AE040CA9040EA3020DA0020D9D010A9C00089D010A9E010A9D01099C000A
9C010A9C010A9C010C9C010C9C010D9A010D97000A940109920008910008910107940109
96000999010A9C020B9B01099A00089D020AA1050CA2080F8E1115C98486E0BEC3A67380
802F42C86C7987252B89212383191B79050B7E02087E01077901067300036E0104640002
66010168040175201900FF0000FF0000FF00
00FF0056B4146A35141E03001E00004002035201035100024E0101480102410101390203
2300002C01015003036803066E030571040A6A04095B01074500023F000159020777030C
7E010B83010D87010E8C01118D010D8D010A8F0109920007950006990008A2030AAB030B
B2050FB3030DB2020CB3040DB3060DB50610B2040DB4040EB7080EB1030BAF030CAF030E
AD030CAE020EAD010DB2040EB20310B50711B3050EB4060FB90B12BE0D13C20E16C10E18
BE0E18BF101BBB0D16BE0F15BF0D11C60E13CB1115CC1215CB1012D51318D41116D41117
D41115D61319D31017D10F17D21317D31418CF1116CD1119C91218CC1519CC1318CE1418
CB1015C60B12C60B14C50A13C50A10C3080EC30810C30A12BD050CBD060EBB040FBA0410
B9050EB2030BAD040DA9030EA4010EA0010D9C00099B00079B000A9B00099B00089D020A
9B01099A01089B010A9D020D9D020D9A010A96010792010791000793010893010896010A
97000A9B010B9C020B9B02089A00099B010A9E020A9F0911841318DAA3A9DDBBC67F3747
8B15298C1D2BBE6F75D4999ABD7E8197444872070C7D050A7A01057800037601056D0103
6B0202680201741C152C860000FF0000FF00
00FF0057B4145B22031E01002201014203035001035001024C00024300013D0000390204
2001011E00003701014A01034F01035200074C01083F010535000244000567030B7C020E
80010C84010D88010F8C02108E020E8D000B8F01099301099701079D010AA6020CAE030D
B1010BB0010AB4040EB1030DAF010AB2040DB0020BB3040BB4070CB2050BAF030CAD010D
AE030CAE020EAC010DB0020EB2040EB2030FB0030DB40711B60C13BB0E16BD0D15BB0B15
B90D16B90E17B50912BB0C13BB0B11C30C13C90F14C90F13CE1014D10F16D31117D41217
D11115CE1015CE1219CC141CC8181EBF1C1FB01B1EA81D20B2302FB5332EB22C28B42421
BB1D1EBD1218C10D14C40B11C60B11C50910C1060FC0070FBE050CBD040DBB040FB7010D
B7040EB2030CAF040EA8020DA3000BA2000CA1010A9E01099B010A9A000A9C010A9D020A
9B01079A01079B02099A00089C020A990108950107920006930007940006970108980109
9801099A00099901099900089B01099F010AA1010A9E070F831319DCA6ACDAB3BC792432
94101D8C0F18AF6168DCB2B9683A42B8797F7427297D2023700509780206790104720103
6E01026901006C130B2E870100FF0000FF00
00FF0059B6145A24021B00002600014602035001024B00004601014301014001013D0303
2201011800002501003505033905043903083601092F000436000254010772020C7D010D
80010D83010D86010C8A020C8B020B8D010C8E00099301089801089E0009AA040CAE020A
B00108B1020CB5060EB50510B2040DAC0109AF030BB3030DB5050EB1020AB40610B1030F
B0010EAE020EAC010AAB010AB20710B1040EAE030CB0050EB50C13B80E17B90C15B60711
B70912B80C15B90E15B80A10C31118C50F17C50E14CB1116CF1115D3121AD11318D11419
CA1619C2191CB31C219F1B1E8D1D1F8B3434A46160C38C8AE2B1ACE8B7B2E4AFA8D79992
C77571AF4341AA1E1FBB1518C30D12C30910C0070FC0070FBE050DBC040EBB030FB9020E
B5020CB3040EAE030CA9030CA3010BA1010BA1010A9F00099B01099801099A010A9C0109
9B01089A00089B01099B010A9C010A99000997010A960109960009960108960107970208
96010798020997010999020A9D0109A00109A3040D9C040B881319D79CA2DDB4BD7C2331
950D19900B13974148DEB0B85F2D37935960A37273C48E8F691C1F6D0A0C720305710101
7101036A0001660C052F870100FF0000FF00
00FF0059B7155D28061D00002B01014C04045202014F0102490102460102460101440305
2C02011901003A2120A9908DA9929032161A2902092E00044701056B040D79020C7D010C
7F010C80000C84000B8C030D8A01098A01098D01089101099500089D0008A80109B0040B
B10208B3030AB60610BD0C17B3040EB0020CB1030CB4040EB6050FB5040EB4040FB1020F
B0010EB0020FAE030CAB010CAF0510B30811B40A12B60B13B60D14B50A13B70912BA0C15
B70912B80A14B90A14C00F19C20F19C50D18C60F16CD1419CB1217CA131AC4151ABB1B1F
9F1A1E841B1F883C3DA87173C9A5A4DFCCCAE5DBDBE6E0E0E5E1E0E7E3E1E7E2DFE6DEDB
E6D4D1E1BCB9C37D7BA83334B01217BE0B14C00710BF070EBE070FBC0610BD0612B7010E
B9040FB4020DAE010BA9020BA3010BA1010B9E00089D01089B01099701099A020C9B010B
9A00099800089900099E020B9E010C9D000B9B010A990109990109970108950107920107
9301079401079601099600089700079E030C9F020DA005118B0C17C67E86E4B7BF802B38
920C189309138F3038E4AFB768323D7E464FBA979BB4979B6F4447B5777A6716196B0509
7102056B010270160E2E870100FF0000FF00
00FF0059B8175726071D00002F01014B02025101005000024C01004A0102490201490102
3E02022501025A4247CCBDC6C3B7C038242D2D010844010762020B76020D7D010B7D010B
7E000B80010C83000B89010C8A01098C00098D010A92010B9500099C0009AA030BB4040E
B4030BB4030DB5050FB4030EB3050FB2040DB4040EB6050DB7060EB3030CB3030DB1010C
B1030CB0020EAE030CAA000BAD030EAF040EB1060FB40911B60C13B50812B50710B50A13
BA0E16BB0B16C00D19C3101CC20D19CD1420C81019C8151BC0181CAE1A20921B1D7F2626
8D5654C9ABA9E1D1D0E6DFDDE6E3E2E6E6E6E1E3E5E0E2E5E1E3E6E1E5E7E0E3E5E3E3E4
E2E1E2DFDBDAE2CFCED29D9DA2383DB0161EBD0C16BE0811C00812BB030EBB0410B6010D
B5010CB2010CB0020EAB020EA6020CA2010A9E00099D010B99010A94010995000997000A
9A020C9B010B9A00099C010A9D010B9C02099B00089B010A990109960106940007950009
9601089601079601079501089300089B020D9F020E9F020F950917A44753EFB9C28F414C
900F1B960611841721E09FA9773E497A434DC9AAAFAD9B9E8A7577BA9C9FA97D81722C31
69090E690204741A122E860000FF0000FF00
00FF0058B8175120031E00003201024F02035201004D01014700004800014B01014D0102
51060B481215290811462D3F371D2E37101D601C2463050C70020979010A7D010B7E000B
7E010980000A84000B89010D8A010B8C00098E010A92010B95000A9C000AAC040FB4030F
B3030DB3030EB60811B3060DB1030CB0030BB4040EB5060DB4060DB0020BB1030CB2030E
AE020BAD020BAD030BAA0109AC020BAE040DB20810B60A12B70C12B90B14BA0C15B60B14
BE101AC10F19C41118C30E19C5111BC01019B9161AAA1E21881C1B7E3534AA7F7CD4BEBA
E1D9D5E4E1DFE4E4E4E3E3E4E4E4E6E2E3E6E2E3E6E1E4E6E1E3E6E1E3E6E3E4E7E2E2E4
E0E1E3DFDFE1DFDDDCE4D6D4C29191982B2FB21118BE0912C00612BE0510BA020CB8020E
B4010CB3020EB00210AB020FA6010BA3020A9F020B9B010A99020B94000A94000998000B
9B000D9C010D9C000A9B00099B020B98010898010999010A970108940105940108950109
97010A94010994010995010993000A9A010E9F020EA3030EA009148D1924E49FA8AF6772
87111E970813870C19B6636F985C657C4A52C8ACB1A5949AB9A6AC8F777DB598A0AF8089
782B306203037319112E860000FF0000FF00
00FF005ABA195828092000003701025504055601024F0101480102490102480100500103
550108681D267B424F7341547D46577D34436D0D1971020C7501077901097E010C7F020C
7E010881000A86010C8C03108D010C8D000991010B92000B95010B9C010AAD040FB2030D
B4040EB4040FB4060FBD0E17B1050EB1030DB4040EB4060EB3060CB1040BB4070EB3060F
AD020BAD020BAD040BA90209A80109B00610B30811B40912B50A10B60912BC0C14BB0C15
C0121BC31319BE1217B9161CB51F2495181881231F864740B28E87D8C7C2E4DFDBE5E4E2
E4E4E3E2E2E3E2E3E5E3E2E7E3E2E7E5E4E9E0E1E4E3E4E6E2E3E5E2E3E6E3E4E7E2E3E5
DFE0E2E0E0E2E0E0E0E1DFDDDECECEB172749B1A1FB70D14BE0712BD040FBD050EB9020D
B8040FB2010CAF030DAB020CA8030BA6020CA1020C9C010B9C010B9A010B99010D9C020E
9C000D9D010D9C010C99010A9601089500079701079A0109980208920004910005920007
94010993010A92010993010993000997000B9E010DA3020DA30711940B16A4434FE59CA6
7D1E27871118A83940791B26BD747FA4717BBC9AA4A48C96B69CA5705158BC98A16E3A44
7F2F37610203670C0630880200FF0000FF00
00FF005ABA195E2D0E2500003E03035302025601024E01014601004800014B0001520102
5A02045F030C620D1B671626680D1D6F041376030E7500077400067801097A010A7B0009
7C010680010A86010C8C02108B010A8E000892010994010B98010A9F000AAE050FB3040E
B3040EB3030DB3050FB1030CAE030CB3050FB2040DB4060FBC0E17B5080EB2050BAE030B
AB0209AA010AAA030AAA040AAE040DB20612B10610B30912B20A11B10910B50C12B81117
B31316B11C1A9D1E1B87211E853934A27169C9B1A8DFD6CFE5E1DCE5E4E2E1E2E2E4E4E7
E1E1E2E3E3E7E3E4E7E2E1E6E5E5E9E4E5E9E1E3E7E1E4E6E1E5E6E1E3E4E2E4E5E1E3E6
E1E2E5E0E0E3DFE0E2E0E1E2E3DFE0D1B1B4993740B0111DBE0814BD050FBB030CB7020C
B8030DB4020BAE0109AA020BA8020CA5010CA2010E9D010C9C010A9B00099C010D9C000D
9C000A9C000C9D010D9B010B9901089901079B01099D020A990208940207910106930208
93020A92010A92010992010993000997010B9D010DA1020DA3030E9D0510900E1AB7535F
CB757F924247DB8C9273121E7E1726A24A5C7D3A4AAA7E8A9A76806F474EBE929B6D2F39
610A1066020366080331860100FF0000FF00
00FF005BBC1C5624092A00004503025602035201014A00014601004800014E0101530101
59010162020564010867020B6F010A77010A7A0109760006740107770109790208780107
7B010780010B86010C8C020E8E010A8F000993010B99010C9B020A9F0008AC030CB4040E
B4030DB4040FB1030CB1030CAF040DB1020DAF010AB50510B50710B70911B0050BAE040C
A7030BA4050DA0090CA20C0EA60A0DB10F16AF0E15AD0E13A60D11A81417A418199B1C19
90221C8B382FA16E63C8A9A2D9CAC4E3DFD8E4E4DFE2E3E1E3E4E4E2E4E6E1E4E5E4E3E8
E5E3E8E4E3E8E2E1E6DED9E0DDD6DED3CAD3C3BDC9CACBD5D8DEE3E1E5E7DFE3E5E2E4E8
E1E4E7DEE0E4E0E1E4DFDFE3E0DFE2DBCBCFAB676EA31823BA0914BE0610BB030DBA020C
B9040DB1010AAC010AA70009A6010CA6010FA2010DA0000B9E020A9C000A9C010D9B010A
9C01099D010A9D010C9D010C9B00089C01089D020A9B010A9B030C970108940006930107
93010892010891010890010791010795010A9A000B9E010CA3030EA0020CA00913940C1A
992736B65867C86E7C80111E8604138406176F091AAE717D8E666E895E67AA7E858B545A
5C0A1065030571130D33870300FF0000FF00
00FF005CBE1D4D1A042B00004703025603045001004A00014A02024E02024F0101530002
5A01015F01026001026400036D00077600087B02097500087400087900097A0108790109
7901077E010B85000E8C010D91010A94000B97010B9B010B9D010A9E0008AC050EB4050E
B4040CB1010CB0020CAF010AAF040CB1030DB1030CB50510B5040EB3040EAE030BA9030A
9B030A810409903230953F3B902F2B95292592241F942822912D27963E39984E48AC7269
C59D93DDC9C0E3DDD5E4E3DFE1E4E1E1E4E4E0E4E4DFE3E5E0E4E5E1E4E5E1E2E6DBD8DF
DCD2DADDCAD4DFC0CCE4B7C9E0A5B6C67F93652A414A3445ACAFB8DBE2E5DFE3E5DFE3E5
DFE1E5E1E1E5E0E0E4DFE0E4DDDEE1E2DBDDBD929695232CB20B16BC0710BD070FB8020D
B80410B2020EAB000BA7010CA6000DA6010FA2000BA0000A9D01079C01079B01089A0008
9B01089D01089F030B9D010B9D010A9C010B9B010A99000999030A980109970108960008
9501099401099201079402089301069701099B020B9E010CA2030EA0020CA206119F0511
9706158C06188905178D04128C010D8A020E76040EAF6A72956771A6727F96656F8A5860
722C3260050772150F4B4D0500FF0000FF00
00FF005EC01F4D1C072900004302015301025201005002024C00004E01014D0000520002
5800015C01015F000164010370010878010A78010A7400077400087D020C7C0109780007
7600077E000B85010C8C010D92000A97000B9B020B9D01099D020A9E010AA50109AE020B
B2050CB1020BAF010AB2040EB0020CB0020DB1030CB2020CB2020CB40510AC020AA70209
98050A6401034517178E7576D2B7B6D8B7B2D5B1A8D7B2AADDBDB4E4CDC5E7D8D1E8DFDA
E5E0DEE5E3E1E2E2E1DFE3E3E0E4E6E1E4E8E0E2E7DFDEE5D8D3DBD8CBD5DEC5D3E2B6C7
D792A5C86B80BE4D62B7364DB5253BB51E2FA11F2E44040F686066D2D8DBDFE4E5E2E5E7
E0E0E4E0E0E3DDDEE1DEE0E2DDE1E2DFE1E0CFB8BA9B434CAA111DB80811B8030CB8040E
B5030EB0010DAF020FAD0311A80110A6010DA4010CA001099C00089C01089B0108990007
9B01089C01089C01099D010B9E020D9B000A990009970108970008990109970108960108
95010B9300099401079702079800079B00099D010C9E010CA0030EA104119C040D9A040F
94030D8E030E91031092010C92010A8D010A79030CB66872A86B787429397C34429C666E
8A4B515A040671151061120700FF0000FF00
00FF005EBF1F501D072E00004503015502025401015302014D00004D01034E0101530102
5A02015D01016402046A01057101077501087500077401087400097A000A7E020C7A0108
7800067F010A88010B92030D95010B9A010B9C010AA1010B9E01089D010AA30109AA030A
AD020AAD020AAF010AAF010DAF010BB1030CAE0108AE0207AF0409B0020BAC0209AB030A
A1030A84060D4B010442202A887B88BCB8C2D8D7DBE1E0E0E2E0E1E3E2E2DFE1E0E0E2E4
E3E4E7E2E4E7E2E4E7DEDEE3DAD7DDD9CFDAD6C2CFDCB7C9D69EB1D4869CBB546CB6364F
B91F38C4182EC81225C80D1DCE111DCD1018BF161C70090F351D1FC3C6C9E0E4E5E2E4E7
E0E1E4E0E1E3DFDFE1DCDFE0DCE1E1DCE1E0D5CCCDA867709E1421B70A14B9060DB7050C
B4030CB0020CAF010DAE030FA8010CA5010BA4010CA2020D9D010C9B00099C01099C0109
9C01099C010A9C010B9E020A9D010A9C010A9B010A99020998020899020A970109960108
94000A9201099501089801089800089B010A9D010C9E010C9F020D9E020D9401098E010A
8701087D000481010A8A020B8F020A8B010982040C8D2532AB4B5B7507176E0613A3535E
9347505E04086B0F0A63130800FF0000FF00
00FF0030E0104E19053200004B03025903035901005601014D00014B01024C0000550101
5C01016101016701036C00057102057500067602067500077400067A000B7D010B7D010A
7D01058401098B020A93020C96020C99010A9C01099E010A9E010A9D010AA20209A9030A
AF040CB1030DAF010BB0020DB1020DB1030CB0020BAA0105AC0207AF010AAE030BAD020B
AA030CA2050E8F06106C0714520D206B3F5794778DB19EB1BAACBDCABFCCCDC7D0D1C8D0
D6C7D2CFBCC7CEB8C5D9B6C6D9A4B6D2889EC86982B8435BB3293EBC1D33C71A2CCB1424
D21422D6121FD20E18CE0913D00D13D00E12C91217971017320106939298DADEE3E2E4E8
E0E1E5DFE0E4DFE1E4DDE1E3DBE0E1DCE1E2DDDADBB78A90921C27B20D15B7060EB5040C
B3020CB2020CB0010CAC010AA80108A50009A4020EA1010E9D000C9C010A9A0107990106
9C010A9D000C9D010C9D020A9C01099C010A9B000A99010897010897010998010A960108
9301089301099701089600079500069800079A00099C010C9D010B9D020D95020C8B010A
8A060F7C01097A01098201098602097C020777030979030D8003108803107F030D71060F
700C136A030665060263110600FF0000FF00
00FF0030E0104A16033500004F02035C02035B01015901015101014E0101500102590203
5F02036302046500026A01056F01067601067800057800057801077C010B7C010B7F010B
81010887010B8C020A93020B96010A9B010B9C01099D020B9B01099A00099F0207A70208
AE030BAF010CAF040DB1030DAE020AAC010AAC020AAC030AAD0307AE0208AD020AAD020B
AA0108AC020CAC050DA50813960C1A840C207911297D213A7E2A448F4059AC627ACD8097
C8738AC86B82C15B71AE384FB0273FB61A30C1172CC91526CD131FD4151FD2121AD31119
D51219D30E17D20E17CD0A10CF0C10D10E11CC0F14B0131B50030964575ECACDD3E0E3E6
E1E3E7E0E2E6DFE1E4DDE0E2DCE0E2DCE0E2E0E0E2CDB2B68F3039A80E18B3030EB6030E
B6020DB3020DAF020BAC020AA80108A50109A4020D9F010C9D010C9C01099B02099B0008
9C010A9D000C9D010D9E010C9E010B9F020C9B000997010795000696000998010C940109
9100079201089401089601089600089701089801089B01099E010C9E010E96010C850005
87040B81020A7F040B83030C7C03096300015A00017003098101098A020B830108780105
7201046E0103640100600B0300FF0000FF00
00FF0000FF00521C073A01015202025E01025E01025A0001530000500102500100560101
5E01036000026401046500036A00027700067C02077A01087802087D01097D010883020B
83000888010D8E020D92000B96010A9C030B9E020B9E0209980008940008980008A8030D
AC010AB0020DAE030BAD020AAD020AAC020BAB0209A90107AB0207AA0106A90108AB010A
AA0209AB0109AD030BAF050FA9030CA70410AA0A17AF1422B11728B1182CB2192DB61A2F
B9192DBE182DC11628C81525CB131DCD121CCD0E19D21019D11016D21018D10E16D31018
D10F15CF0C14D10F14CF0B11D10D11D00D0ECD0C10C4171C73090F391D21C5C7CBE0E5E7
DEE2E4DFE2E4DEDFE3DFDEE3E0E0E4DBDCE0DFE0E3D0C0C49A535A9F121EB20512B6030F
B6020CB4010DAD000AAA0009A70108A40108A0010A9C010A9D010C9C010A9B02089C0209
9C01099C01099C01099E020C9F010C9D020D97020B94020892010797020A97020A920108
92000892000A93020A9301089600089600079700069901079D0109A0010D9D030E8F0108
8F050C8001067300037C030A7701076C03065B010264010579020981030A800308780204
7201026D0201640200610B0300FF0000FF00
00FF0000FF00511D073B01005D05046402025F01015A01015301005301024F0000520102
5D01056301046401036700036900027501067B02097500057300077E020A80010A84000B
83000A89010F8F011092000E95000A98020A9C01089C0109950007920009950008A4030D
AA020AAE020BAF040BAF040CAB030AA80208AC030AA70007A60107A90007AA030AAA0009
A80108A60107AA040CAC050CAD040BAF050CB60B14B70D15BC1018BE0F19C5121CC7111B
C8121AC8121AC71016CF1519CD1016CF1118CC1015CA1217CA1517CC161ACB181CCB171C
CA171CC71418CC1A1CCB1617CD1316D01014CF0C11C911179613183203069D9BA0DADEE1
E0E1E4E0E0E4E1DFE4DEDDE2DFDEE3DCDCE1DDDEE1DBD3D5A8747B901723AE0814B4040E
B4030DB2010CAE010CAB010DA8010BA6020CA2000C9F020D9C010B9B01099B01089B0107
9B01099A01099C01099B010B98030D8E030C83030A7E010687030992030C94020B940108
9200069201099201099101079300079601079701069901069C010A9E010C9C010B99010A
99050E90050E7F01067D02077D01057D03087004086000026A03076C0104710205720103
6D0101690201620200630D0400FF0000FF00
00FF0000FF004C15014100016907086702025E01005A0101560000560102510100520001
5B01036101036501036801046900047501067E020A7B010879000780010A84010B86010C
86000989000C90021095011099020E99020B9A010898010A92000991000994010A9D010A
A4010AAA0209AE050AB1060EAE050CAA0108AC0309A70107A70208A80007A70007A70008
A70209A50007A70209A70108AE050CB50A12BB0E14BB1016BA1217BC141BBB171BBC1C1E
BA1D1DB91D1DBD1B1AC51819C9141AC91319BB1113A71717B03630B6423CB64440BA4949
BE4F4EC05450C55A53D15D58C63B3CC4181ECC0A12CB0C13AD131A490204645B5FCBCED2
E1E1E6E0DEE4DEDDE2E0DFE4DDDDE1DCDEE2DADEE0DFDDDFBD9DA188262FAA0E18B3030E
B3030DB1010CAF020DAC010CAA000AA8020AA4010D9F000D9D010A9D020A9D020A9B0109
9800079801089A010B95030D84020973000693262C9C353971060A83040B900109930107
9301069300079301099201099201079401069801089901099C020C9D020C9D020B9C0109
9C020B9A050F90020A8E030A8401067E0206790408660002650104650203620101660102
670101680102630200630D0500FF0000FF00
00FF0000FF005216044E01016F06076801025C00005B0000590100580100540000570003
6002076101036602046800036E00047A010883010986010A84010983000B85020A85020A
8600078A010B90010D97020E9B020D9C010C9A020994010991010791010A90000A99010C
A3020BA80208AE070AAE030AAF040CAA0009A90209A60006A60105A60104A60107A60107
A70109AB040CA80108A90009B0070EB50A12B60F17AF151AA11A1B941E1DA7433FBF6761
BE6F68BC6B66B15451AB3B3AAE2929B11E21971415510303CBA19CE1BFB8E1C2BADFBFBD
E3C3C1E3C5C1E8C9C2EBC1BDE4989BAE2029CB121CCD0B15BE141C6B090E372125C4C4CB
DEDEE3E0E0E3DEDEE2DEDFE3DEDFE3DCE0E3D9DDE0DCDEE0CBBABE8D4048A0121BB0030D
B4020EB3010DB0010DAE000BAD020BA9010AA4010D9F010C9D010B9C01099D01099C0109
99000896010895020B88030A710002760108890D18A22D37A2343B7901078E030B940209
9501069401079301089100069301089300089601099801089E030D9C010A9C010A9C030B
98060E95060E99040D98030B8703077A01047F04097501047201056C02055D0001570001
60020266020263020165100700FF0000FF00
00FF0000FF005415045402016E04046701025E02015F01025901015301005601015C0103
6503076401036601036A00047201057E010786020A88000C88010C82010B800109830108
88010A8E030E8E010A95010C9D050D9C010B9801089401099101079001078D0006950109
A10309A90207AA0404AD0409AC030AAD030BA80108A70007A60106A80108A80107A90108
AB010AAE040DAC050CB0060EB0060EB00B159E1219720F116A2825AA7E78D2B7AFDCCBC5
DDD2CADDCECADAC3BED6B3AFD7A39EBA736D85433F270A0B7A7A7AD9DBDAE1E2DFE0DFDE
E1E0DFE3E0DFE3E0DDEBDFE1E7BFC4A83942C3151FD00F17C6111A8C10162D0307A09EA4
DDE0E4DFDFE2DFDFE3DCDEE1DEDFE3DEDFE3DCDFE1DBDDDFD2C9CD9A626B931420B00712
B4030EB2010DB0010CAD010AAC020AA70009A4010DA0010E9D010C9B010A9B00079C0108
9A010997020A8D030C7601077501068B040D92010D91030E8C08117B0005890309920108
93000794000695010795010897010A96010A9300079600079C010C9C000A9B0008950108
8200037C010490030B99040E8304086B02037604067E03057C0103760205630203510000
560000610302620200630E0500FF0000FF00
00FF0000FF005413025703016D03016601025D01005C02015701005300005600015B0101
5E01025E00016601036F01067401057E010786020C8A020E86010C81000A7D000682010A
8A020D8C010B8F010A96010C99020B9A000B9701079401069101079001078F0107950006
9F0107A80407AA0608AE090DAC050CAC030AAB0209AA0109A60007A80108AA0108AD020A
AC0109AB020AAA030AB30811B20711A10C1962060C442121B0A39EDDD9D4E0E0DBDFE0DE
E1E2E0E2E1E0E1E1DEE3DFDEE3DED8E2D8D1CBBEB8817D7B6C7273D2D9D9DEE3E2E0E2E3
E0E4E3E2E3E4E1E3E2E5E2E3E4CDD0B7626BB51922CB1018CC1319A7131B440206716A70
D0D5D9DEE1E4DEDFE2DDDEE1DDE0E3DEE0E4DADDE0DADDDFD9D6D9B08991881C28AB0B18
B30510B2020FAE010BAC0109AA0209A70108A3000AA0000D9F010C9D010A9B00089A0107
9A000895010A8002096400017D080E91020B96010B96010B90030B7F0105820206900209
9401099501099502089400089401099401099601089701079901089B010A9C010A98020A
8C030B7B010587030A92050E7601045500005A000077020688050A800307680002580000
5901006002025F02006310072C860000FF00
00FF0000FF005311005803026F05046802025D0000580001550101550101580101590100
5900006101026901027201057300007E010683010888000A86010B81000A81010884000A
8C010C90000C94020D99020C9C030C9801099702089300069101078E01088D0005930105
9B0206A50509A50207A80208A90209AA0108AB0209AB0009AA0108A90007AA0109AC010A
AE050CAC040BAB030AB40A12B00D15870C152F00027D7578D3D3D1E0E1E0DFE1E1E1E1E2
E1E1E3E0E0E2E0E1E2DDDEE0DFE1E2DEE1E0E1E3E1DEE0DFC9CECCC7CDCBDDE3E1DFE3E2
DEE4E2DFE3E4E0E3E4E0E1E1E4D9D9C98D92A42028C41218CC1217B5131A61080E3C2B31
C4C9D0DDE2E6D9DBDFDEDFE2DCDFE1DBDDE1DBDDE1DADCDEDDDBDDB99FA3872E39A20E1C
AF0613B20411AE010BAB0109A90108A70209A4000AA2000CA2010C9F010B9D010A9B0008
98010896020C7B050B59000175070C8F030C96020D96010B91030A7B01047901048E0308
9300069401079300069101078E02098E02099302099601079901089B010A9D010B9C020B
98020C8B030A8601068F050C82040A6802055700006E01068A050D850308710102680202
6502026101015B010067160F2A850100FF00
00FF0000FF005514015D04026F03026601015C0000580100540100530002570102590101
5C01006400026C020373010677010480020685020689020989020B85010C84010B87000C
8C010C93020F95010D9B030E9A030B9801089701059400069101098C01088B00068D0004
9401049D0207A00004A50107A80108AA0108AA0108AC010AAB0209AC010AAB0109AD020A
AA0008AB030BAA0108B10710A80A13700810200707A09EA2DFE1E1E0E0E2DFE0E2E0E1E4
E1E2E5E1E2E4DFDFE3DAD7DFCDC3D1D7CDDCDFDEE7E0E4E9DFE3E5D8DBDEDCE2E2DEE2E3
DEE4E4DDE1E4DDE2E2DFE1E3E3DEE1DCB5BB9E3239BE181ECA1215BB11157D0E1526070D
9EA1A8D8DDE1DCDEE2DBDCE0E0E1E5DEDFE3DBDDE1DCDCDFDDDCDECBBCBD934F5695101D
A90613AF0412AE020FAB010CA80009A60109A5010BA3010DA0010DA0000C9F010C9A0009
9B010B97030C79040A5000015D020681050D8D020A9001098A03097101036F0104890209
9201079501089401088F020980010575020481030791020999010A9D010D9C000D9D000B
9B020C91030A87020884010687020A82050E6801046C010484050B7F02067402046E0303
6B02026301015B010066160F2A850000FF00
00FF0000FF005A17016003027003026701015E02015902015401025101014F0001590101
6502026901046D01047201057601057F010884000788010884010B7C020C7B020C83020C
8B010B92010C95010D98000C98010A9B01099701089402078E01068A01058800028B0103
9301069C0107A10006A70209A70208A80108AB030AAE030BAE020BAF020DB1040DB1040A
AD0208AC0209AF040CB30711A6091469070E220C0EA7A6AADDE0E1DFDFE1DEE1E3DCE0E3
DBDFE2E0E1E6D8D1D9C39DAE904A63782F4D8C617AC2B7C8D9DCE5DDE0E5DFE3E6DEE2E5
DDE1E4E0E4E7E0E4E5DFE4E4E2E4E5E0CACEA55158B31A21C61114C00E139A151C330005
6F6D74D0D6DADDE1E4DADCE0DCDCE0DEDFE4DBDCE0DCDDE0DADCDCD6CED1A4727A891624
A60917AB0310AB020FA8010CA8020AA6010BA5020EA1010D9E010C9D010D9C010C97000A
9A000B98020C7C030A4A000143000362030A79030B82040B7A070C5E020463010485030B
91020994010896020A9102098202076C01026D01018802089601099C020D9B010D9C020E
97020D8A01088303097E010685020889030B7B04097301057D0408710001640001600100
6801026702015E010067160F2B860100FF00
00FF0000FF006119016503017604046801015D01005900005501015001014E0001580101
6702056B01066E02066F00027300057E010A84010A86020B7702086100035D010477020B
8A020D93010D96020D9A010D9B010B9B010B9601099001078A01058800068801058B0103
9101039B0006A60209AA020BA9020AAB010AAB0209AC0108AF010AB4030EB5060EB5050F
B10309B1040DB1070FB10711A609156E08111F070C9B9BA1DADEE0DFE0E2DCE0E3DBDFE2
DEE2E3E2E1E6D9C7D09B4D5FAA2035B11C358C1730601F38907E93D5D6E1DDE2E6DFE3E6
DEE3E6DEE3E6E2E6E7E0E4E7E0E4E7E4DBDEB77A82A72029C41217C40D12B0151C520308
4A3F45C0C8CEDAE0E3DADDE1DBDDDFD9DCDEDCDDE1DCDDDFDEDEDFDEDBDCB2919882212E
9E0A18A80410A7020BA7010AA7010BA6010CA4010CA0010C9E020C9C010A9B010B9B010B
9B000B9B010D8B060F5402053100013F00055201075802084E02054000005B010584020D
91010A91000794020896020A93030B86040A79000489020897020B9A010B9C020D9B010C
98020E8601087D01068304098702068D03088001057E030589080E7801046601015E0001
630101690203620201620C062D860100FF00
00FF0000FF006C1F066E07027703026800005D00005A01005601015201005201015A0103
6502056A01066A01046C010375000680020B87020B89040D7602085D01055200026D0109
89020C96010C98020B9B020A9C01099A010B9601078E01068801078900078A0206880002
900104970105A3030BA9020AA80108AB0209AD030CB0030CB2020CB70511BB0A14B4020C
B4050DB4050EB30911AD030EA808137E0D17210004838489D5D9DBDFE1E3DBDFE2DBDFE0
DEE2E3E3E2E4DECACFA6545FB31825C5121FBF1621A0192C4E0B206F6475CFD5DCDDE2E5
DDE3E3DFE3E6DFE4E4DFE1E5DDE0E3E2DFE1CFA7AC9C2931C3161CC80F15B91016750C10
291013A6ACB1D8E1E3D7DDDDDADEDFDBDEE0DBDCDFDCDDE0DADBDDDBDADDC4B1B7873B46
960E1BA4030EA9050EA7010DA7000CA7010BA4020AA1010C9E010C9B000B9A010B9A020C
9C020A9D020B92050E6704093801014212153A070B2E000429000233000160010789030C
93010B9100069201059501069501069001078B01078F01079601089801099C030D9B010B
9A020D90030D7E00048102068A02078702048002048102058B070C8002057202016A0101
680101670001630201610A052D850100FF00
00FF0000FF006C20066F08017704026A01015E01015A01015701005400005301005B0101
6301036601036700016D000177000381000887000A8B020C85030B7B040D6F0208770108
8D020C97010D9B020C9D020C9C020A9D020C9602098C01078700048901078D02058C0104
9002069300069D0107A6020AAA030AAC0209B0040CB3030EB5040EB5040FB60410B3030E
B3030EB2040EB20710AD030EAC09118D0E18310106625F67C8CDD0DDE1E3D9DFDFDEE2E5
DDE1E2DDDEE1E0D5D8B26F78AC1B28C40F1AC9121ABD151F8711212D0918A7A9B4E0E4E9
DFE3E5DFE3E6DDE3E3DFE2E5E2E3E6E4E2E4DEC3C7A3444DBA1820C70E13C00E13971419
3100037B7B7FD2DBDCD9DFE0D6DADDD8DCDFDADCDEDADDDED8DCDDD8DADCD2CACD945E66
8C1421A50715A6020EA4010CA6020BA50208A2010AA0010C9D000B9B000A9A0009980108
9901089C010A96030C800B10540B0DB58689A4808424070923000041000270030A8C0109
9101099000059301069501069401049301059401079601079701079A010A9B010D9C010E
9A020C94020C8401068001048602077E01027900027B0104770103790305750203710202
6C0101690101660202650D082B830000FF00
00FF0000FF00631B027108037A03026D01015F01015A00015500015301005301005B0101
6101026501026901027101027A01038000078601078D020D8B010A85010A82020A85010C
90020E99020E9B010D9B010B9C000B99010A9201098B01088801058800048A00028D0006
9101089400089A0007A60209AE030CB0030DB2040EB4040EB80410B8040CB7060FB4020E
B3030DB2030FB1050FB50B14AF0A11981019430207413940B9C0C4DEE3E6DCE0E1DDE1E2
DCE1E4DBDEE3E0DCDFCA9CA2A42833C5141ECD121BC8121DAB172243020D635A68D7DCE3
E0E4E6E0E2E6DDE3E4E2E6E9E1E4E6E3E3E5E5D6D7BA7278AD1C25C60F17C30B12AC121A
4F020853494EC9CFD2D8DCDFD9DEE1D6DADDD7DBDED6DCDFD7DCDED6DADBDAD6D9A9838A
811926A00917A3010EA4010BA30109A3010AA1010C9D000B9D010A9D020A9B0108980006
96000799000A98020C8B0710A2434B793C4585555F420F154901046C030887030A910109
92010890010790000694000696010696010597000597000598010799010B9B000C9C010C
99010B95020B8402067D02048102067C02047900047F03097401047302047102026D0201
690101680100630100670F092C840000FF00
00FF0000FF00681C037006017B03026D00006100015C00015701005401005201005A0100
6101026401026901027002057601037E01078601078C020C8D010A8700078600098A010C
8F010C97010D9C020E9E010E9F010D9B020B9401098E01098C01068A01048800048E0209
910009940109980007A6040CAD040FAE020EB1030DB4040EB8040CB90509B5030AB2010A
B1010BB1020CB3050FB2040FB0080FA20D175D060F24141BA3A8AEDBDFE2DDE1E2DDE1E4
DAE0E0DBE0E3E1E1E4DCBEC3A8454DBE1B24CD121CCE111CBD161F6B0A133A2430C8CDD4
DFE5E7E1E4E8E0E4E7E3E4E8DFE2E4E0E3E3E6DFDFC49296A1252CC5141CC70D14BB131D
6F0912321B21B1B4BADBE0E3D9DDE0D8DBDFD7DBDED8DCDFD6DBDDD4D9DBD9D9DBC0A7AD
7F2B36990C19A4020FA4010BA4020AA2010A9F020A9D010AA0030D9E010A9C00099A0008
9901099A010C9A010C95030E90121EA3404CA44A588825327C050F8C040C910109920108
91000591000693000793000695010797010899010898010998010A97010B9B010C9C020D
98000A9201078001047300027902057500017E020584020A7E0108710104650102630101
660100660100620100660E092D850100FF00
00FF0000FF007223057909017E03016F00006201005E01015900005800025801005E0101
6501016701016800016D01037200047C01078501088C020C8E020B88000A8700098C010A
91010B98010D9D020FA202119F010F9D020C97020B9100098D00068B00058B00058E0008
910107930109950107A0020BAA040DAF050DB2040DB4030DB8030BB8050BB7060CB2040B
B1010BB4050FB3050FB4040FAF030DA3061175091421020A84878ED2D7DBDDE1E1DCDDDF
DCE1E1DDE2E5DDE0E1E5D5D8BC757AB22029CA131AD01219C6151B8F121A2F0610A8A7AE
DBDFE3DADFE3DDE2E3E1E3E7E0E1E4DDE0E1E4E2E4D7B6BB9C343CBF1821CA0F16C01017
870D162A020984848BD4DBDEDCE0E3DADDDFD8DADDD7DBDED8DCDED7DBDDD8DBDEC7BBC0
89485191101CA30511A5030EA2020CA1040C9D010A9D01099D020A9D010A9D01099C010A
99010A98010A98010B99010D95020F8D05138A08178D061492030E93010B93010B930109
9300079300079501099301069200059501099801099901099A000A9A020B98010A9A010B
98010A93010A8A030A7901037C03077901037C02048202088102087603065F01025C0202
6903026A0202620100630A052E860200FF00
00FF0000FF00701F047B08018104017301026200005D01005B01005C01015D0101640101
6902036B02036801046B01047101067C01078501098C010C8C000B87000988010A8F000D
93000C98010CA00311A0010F9F020E9A000B9401098F01078C00058C01088C0108900107
92010A95020C94010A9B010BA6050CB0060EB3040EB70410B8030CB7030CB4030BB2020C
B3040DB2050EB1050EB20610AC030EA706128B0E1732010850505ABDC5CBDBE2E2DDE1E2
DDE1E2DADFE2DDE2E3E3DDDED5A9ACA62D35C81B21CF1218C81316AC1A1D4503096F676F
D4DADDDBE0E2DDE3E3E1E5E8DFE1E5DFE0E4E1E1E4E4D0D5AD5D66B31A26CC141AC61117
A4161F3E0107625C62D0D7DADADFE2DADDE0DADDE0D5D9DCD6DADED7DBDFD7DBDFD3CED3
996B74861520A20814A60611A3050FA1030DA1020DA1020E9F010B9C01099C010A9B0109
99010C97000998010A99010A98010B95010B95010C95010B96010A95010993000894010A
92000893010895020A9201088B01058C020893000999010899010797010797010998010B
97000B9300088E02098201058002068003067702057001067603077503065E0102550000
6602026A0202660101610702550A0100FF00
00FF0000FF00701C037C09018102027000006301015E00005C01005C00015F0202620202
6802026901026501016900047200067E020885020889010B8B020C8B000B8D010C93010E
93000A98000B9E010B9E020D9B010B94000B9101088E01098D02098E01098D000691010A
92010893000A94020C97010C9D020BAD050EB3050EB5030DB6020BB7030EB3020AB3030D
B1030CB0040AB0060CAD030CAD040FAA0411970B164A050C2F262EA3ABB3DAE1E4DBE0E3
DBDFE2DCE0E3DFE4E5E3E2E4E0C8CCA94D54BF1E25D0131ACF1419BF1A1E6D0C13402A34
CCD3D8DCE4E5DCE2E2DFE3E6DEE2E3DFE2E3E1E2E5E7DEE2C88F99A7242EC6141BC71015
B1121B5B050C403035C0C5CADBE0E4DBDEE0DCDDE0D7DBDED6DADDD8DBDED9DCDFD8D7DB
AA8C9380212E9D0C19A30611A2050FA2030EA3020FA3010EA1010C9D010A9B0109990109
99020B9901099A00089B010A98010994000793000895010A94010B93000A950108960107
9401089401079200059002088200027E00028F020999010A98010796000597000897000B
98010B9501089002088101057A00047D03086B02045300005A01016D04056602035B0001
650203690102660001640904590B0100FF00
00FF0000FF00771F028009018203037300006500006301025D01015B01015900005D0101
6501036600026300006801017201047D01078200068700088D020C8E000B8F020B92010C
93000A9B020CA0020B9E020D97010A93000A9102088F010A8D01088F020A8B0005900209
91010894010897010A96020C970009A20209AE030CB5040EB4020AB3020BB4040BB4040E
B2040DB2060EB1060CAC010AAC020DAB030F9A061064070D1E080D8B9099D7DCE1DCE0E3
DBDFE0DDE1E4DEE2E5E2E2E4E4D8DAC68589B32429D0161ED11219CB171E97151E310510
ACACB5DCE3E6DEE4E4DFE3E4DEE2E3E1E4E4E0E3E4E5E3E5D6B2B7A0343DC21923CB1219
BC10197F0E172D0C11A5A9B0D8E0E3DBDFE2DADDE0D8DCDFDADCE0D7DBDED9DDDFD9DBDE
BBA7AD813340970D1DA40613A2030EA3050FA0000FA1010E9F010B9C01099C0109970009
98010B99010B9A020B98020A97020993000794010A94010B94010A940209930007940107
9401059200049201059101058C02078601058D0106970109970108960107960107970109
98010A97010A8F01058301047500047201057206096204075500016303056A0306630102
6802046A0103660101660B065D0E0400FF00
00FF0000FF00792003830A028403027500016901006802036202025C01025B0101610102
6701046B02046701016800017000027D000687020C8A000C8E010D90030C8E010A91020C
93000A99020BA0040D9E030E95010992000990010891010A9000098F00098F0107920007
94000799020B9C030D9A020E98020B9B0007A7030AB2050EB1020AB2030AB2030CB0010A
AF040CAE050CAB030AA90109AC040CA70209A1060E83101826000563626EC2C8D0DADEE2
DBE1E1DEE2E5E0E2E3DDE0E1E1DDDDDDB2B6AB333ACA1921D4141AD2171CB71C234D030B
726771DEE2E4DFE5E5E0E4E7DFE3E5E1E5E6E0E4E5E2E4E5E8D2D6AE5862BB1F2BD11620
C8121C9D141D36000784858CCED8DBDBE0E3DADEE1D7DBDED9DDE0D4D8DBD9DEE0D7DADC
CDC2C791545E901321A50615A5030FA5030FA1010DA4040F9E010A9B00099B000A9A000A
98010A96000A93010994000895000895000795010B920009920008940006940006910006
9100069100059101059101069001078F0107900107930108930007930006930106960107
9801089701079201068C02067C02046E00027301057505085F00015B0001640103690004
6C01026D0202680202670D0860120900FF00
00FF0000FF00792104830C028603027801016B00006701006200005E01015F0101660103
6900046D01046B01026C000375010680010A8A020C8C010E8C010C8F020D8E010C90010B
92000B97020C9B030C99010D92000A92000A91000A93010B92000B93010B93020993020B
96010A9A010B9E020D9E030F9D050E9D010AA5030BAF050FB1030CB1010BB2020CAE020B
B0080FA9030BA60108A40007A50107A70208A203098D0A123B0207322C38A6AEB7DBE1E6
DDE1E3E2E4E7DEE2E3DBE0DFE0E0DFE7CED1B75962C5202AD6161ADB191ACE1F237A0E16
4B333BD8DADFE0E4E6E3E7E8E0E4E5E4E6E8E1E4E5E0E2E4E7DDDFC48690B32833CD161E
CF1219B81A2254040C61565EC8D0D5DCE2E5DCE1E4D8DDE0D8DDDFD9DEE0D6DCDFD8DBDF
DBD4D8A47981841624A40918A70310A6020EA5020EA4040E9E00079C01089C000A9D020C
98010896010995000A97010B98010A97010A95000A93000A9100089200089200078F0005
910006920106910105900106910108910107910208900209920209920107950209970108
9802099401079101068B01038303057A01057C01067E04066F01016502036602036C0304
6F02046E01016A010266090663120A00FF00
00FF0000FF00782403850D028A04027E0103700100690101650101600001600001670105
6A01056D01056F02057101067400057D020985010C87010C87010A8C020E8C000B8E010A
91010A95010B98020D94010B91000992000A92000A93010A92010A93010B94030A92000A
95020C98000C9C010C9D030D9B010B9C010B9F0109A8020CB30710B2020CB4050EAC010A
AC040DA9030CA40208A40108A80209AC030CAA050DA00D165D070F201019929AA4D9DFE5
DEE3E5DEE2E3DBE0DFDFE4E5E0E2E2E9DBDED49197BC2A33DC1E21E51C1EDC2025A61923
3F0A15C2BDC2DFE3E4E2E3E5E2E3E5E3E4E6E5E7E9E2E6E7E6E2E4DFB4BAAA343ED01E25
D9151BCA191F770C133D242BD0D6DBDCE3E5DEE4E5DBE0E1D8DDDED9DEE0D9DEE1D7DBDE
DDDCE1C2A4AD872936A30D1AAE0814AA0310A6010FA3010CA2010BA0010C9C010B9A0008
9A00089801099700099B010C9B010B98010A96000A94000B930109920109910107920005
9201069201079000068F00048F01059000088D030A83010586010691010A96010A950008
9400089401099203098502057601027A02048302078402087A0103700203650102630101
6D01037002036B0101640301630F0700FF00
00FF0000FF007B2304860D038903038002047301016D0101670101630102610102640003
6500036D020570030671000672010578000680010A82010B80000887010A89000A8E000B
92010B94000A94010B91020B8E010992010892010892000A92010892020B910208900109
94020C97010C9A020B9A010A9C020C9E010C9F010BA6020CAE030DB2030DB3040FAC0209
AA040CA8030AA6020AA40106A80108AF040DAD030DA909157B0812240109727682C8CFD8
DDE2E5DEE2E3DFE5E3E2E6E7DFE4E1E9E3E1F6CBCEC24B51DE2A2FED2729EA2B30D02F3A
67111DA18F97E4E7E8E6E8E7E4E7E7E5E7E9E6E7E9E6E7E9E6E5E7F4D9DDC1616AD82D34
E61D22DC1C219D161A3A0A10C5C5CBDDE4E7DEE4E6DBE2E3DADFE2DADEE2DADFE2D7DCDE
D9DDDFD3C2C7934751A2131FB10812B1030FAD0410A7010EA6010CA4000D9F000B9D0008
9C01099A010A9B010A9B000A9B000998010997010A97020A96010A930209930008930108
9200079100069000069000069101088F01078C02087F01037E000490020C9A020C9A010B
96010A9301078E01068101046D0001730103840207820105780103710304670204620001
6C02026E02016B0101660201600B0300FF00
00FF0000FF00822809890B038C03048301047601016F01026801026400036101025D0001
6101016A01056C01036C00056E00037600067E020A80010C7E000884010988010A8E010E
92020C92010C90000C8E010C8B0109900009900009910009910207910208910208900009
93010B96010C99010D9700099D020DA2020EA3010CA5000BA8010BB1040EB30610AD020A
AE050DA80007A70108A80108A90108B1030EB1020EB208159B101B45030E4D4552BEC3CD
E0E5E8E2E6E7E0E6E5E3E7E8E2E5E6E7E5E6F6E2E3DA8F91D34F51E15050E65D60DC626A
A95D65B19DA2F4F4F4E6E7E9E8EBECE7EBECE7EBECE7EAECE6E6E9F7EBEEEEACB2DD454B
F53133ED2728C9262854030CAEA2AAE0E5E9DFE6E9DDE4E6DDE1E4DCE0E3DBDFE2DBDFE2
DBDFE2DDD3D6AD6F79A11A26B70915BA0612B70511B50511AF050FA8000DA6020EA2010D
A0010C9D000A9B000A9B000A9B00099B010A9A000A99020B970109970108960009930108
9201089201089101079101079201089101079001078D02088B000894020B9C010B9B010A
9701089200058C00048702077C02067901038201057D02047001036501016903036A0002
6E01016D00006A01016605026A170E00FF00
00FF0000FF00862A088C0C038E03038502037601016F01026901016101015E01015B0000
6202036A02066A01036B01056C00057401087D020A7E010B7B00078100098401098A010B
8F020B90000C8E010C8F020E8901088C01098E010A90000990010891010A8F020A91010B
92000A94010B97010A99000A9D010BA2020EA3010EA2000BA4020AAC050EB0070FB2060D
B3070EB1040BB1030BB2020AB8050EBD0711BB050EBD0B13BA18217D132040202DC5C5CD
E4E8EBE1E5E7E5EBEBE4E8E9E7E8EBE9E8EAF0EBEBFBE7E7F9D1D1FFD7D7FFE4E4FFE6E8
FFEFF0FFF8F8FDFCFDF0F1F3EFF0F2EFF0F2EFF0F2F1F2F4F1F1F4F2EFF1FFDADEE7696C
F64340F73831E73835780C158C717CE1E4EAE1E6E8E1E6E7E0E4E6DFE3E5E0E4E6DEE2E5
DDE1E4E3DEE2CF9CA6A32230C20F1DC60916C20614BE0612BB0610B2030CAE030DA8010C
A4000CA1000BA0010B9E010B9C01099A00099B010B9B010B9901099A010A99010A970106
96000697020B93010992010892010791000693010794010996020A99010C9C020E9C010C
9A010A9600079301078F02098601068301068402057B01036C0001630102670202700203
7201017001016801016003016D1E1500FF00
00FF0000FF008125048B0C018E04018302027400016C00016901016502025F01015D0001
6101026502036600016B01046E02047702077C010B7C000A7900077E0009830009880008
8D020B8F010D8E010E8C000C8800088A030A8E020B8F010A8F020A8E010A8E0109900009
94000A9600099A020C9D020DA0020DA3010DA5020DA1000BA1020BA8040BAD030AB70A0E
BC080DC60D13C70C11CD0F15D11117D7171CCE1115D81B1FD72127B9252F651927C8B6C0
F2F2F5E7EBEEE9EDEEEBECEEE9EAECF1F2F4EDEEF0F6F4F4FAF7F6FCF9F8FEFCFCFFFDFD
FFFDFEFFFEFEFEFEFEFEFEFEFDFEFDFAFBFBF7F7F9F5F6F8F0F1F3F6F5F7FFE8EBF08383
FD5951FD4F42F84843A12029916571F8F7FCE4E8EAE3E6E7E6E8EAE1E4E5E0E2E5DFE3E7
DFE1E6E3DFE3E6BDC6AA3441CC1926D00D19CC0816C80714C10511C00712B7020DB3040E
AB010BA9010BA6010BA0010A9C00079B01079D010A9E020C9D010B9C010B9B010A9A0008
9B010A99000B95010A9201099000079101079301089600099A010B9D020E9D020F9B010C
9A00099801079500059001088400058001048302067C03057302046A02046401026D0203
7201017001016801006003006B1A1314C200
00FF0000FF008426078C0D038D03028001027101016B0101680100640101600001610103
5F01016001016401016D01017101027500067B01097900097A01087F010B83010A87000A
8A010A8D010E8D020E8A010B88010888010A8901088900088D02098E010A8F020A8F0008
9701099D010C9F010CA4020DA6020CA9000AAD030DAD030DA90109AE020CB4040DC40C13
CE1016DC171AE0171AE2161BE81D20EB2023EB2225F32A2EF33034ED3C43B03040BE8096
FEF7FEEEEDF0EFF1F3ECEDF1F2F3F5F1F2F6F5F6F8F0F1F3F5F7F6F5F6F8FAFCFBFBFBFD
FBFDFCFCFCFCFCFEFDFBFBFDF8F9F9F6F7F7F5F5F7F2F3F5F0F1F2FAF6F8FFD8DFEC7176
FA514BFC453BF43C37C332397F4451F4F0F6E2E6E7E4E7E9E3E5E8E4E7E9E2E4E7E0E4E6
E1E3E7E3E0E6F5D6DFB54A58CB1F2CD10F1AD10C19D00C18CC0915C60510C50712BD050E
B7030DB2020BAD010CA9020CA300089F0007A10109A2010BA4030DA0020CA0020D9D010B
9C010B9B010B97000993000891010791010995010A99010A9B010B9B010B9C010D9B010C
9900099901089700079301088701077C02057603066E01036F02026D0205600001660001
7201027001016801015F02016F1D18298400
00FF0000FF008D2B0C8F0D038A02017D02026D0100690101640101610101610001650105
6501056601036901037100057401047A01087B02097A010A7701097C000A85010D89010C
8D020D8C010E89010B8A00098A02088900088800088C01098F010992010A900007940006
9B0006A5020AAA040BAC030AB4060FB6030DBD050DBC050DBA030AC20710C60A13CD0B15
DB1319E71B1FEF2023F11F22F52225FA282CFD2E32FD2F34FF3B3FFC3D44F14554B93552
E39EBAFEEAF8F4EFF2F1F0F3F0F0F2F3F1F6EEEFF1EFEFF2F4F4F4F7F6F8F8F8F8F9F9FA
F7F9F8F7F8FAFAFBFBFBFBFDFAFAFAFAFAF9FBFAF9FAF7FAFCF6F9FFE9EFF199A3ED5559
F7463EFB4036F63733CB2F34692431D3D0DADFE6EAE0E4E7E1E5E8E0E2E6E0E2E5DBDFE1
DFE3E6DCDCE1E8D1DAB05363C4202ECE0F1BCD0C16CC0C14D00F18CB0D14C80B12C10910
BE0912B9050FBB0A15B0020EAC020DA9020DA6010DA5010CA5000AA7020CA8040FA5020D
A2020D9E020D9B010B97010A95010993000894000999010D9B010C9C010C9E020E9C010A
9C010B9B010A9900089501078C02077601055E00006101026D03046B0204650103690101
7201026F01016500015A00005F0E072B8601
00FF0000FF008B27098C0B018803017A01016A0000680100640101640001670102660003
6501016801026C01027101057501067C010B7901087501087001087A010A85010C89010D
8B020C8A010D8600098A01088C01078E000991010A94010C96000B9C020D9E030CA10108
A70107AF0208B30307BF080CC5090DCB0C0FD00E11D31014D00C13D20E17D31019D7111B
DA111AE71A23F11F25F52024FC2729FD2729FD292CFC292FFC3134FA2F35F9353DEF384A
D4405BE989A2FFE4F2FFF2FCFFF5FDFFF3FCFFF2FBFFF0FAFFF0F8FFEEF7FFF1F7FFF3F7
FEF9FBFEFEFFFEFBFDFBF5F7FEF2F5FEEBECFEE5E6FFDEE1F9C8CCF0969BF16C6DFC5851
FC4C3FFC4538FD423ADE373A701B26C6BDC6E1EAEDE1E6E9DDE2E5DFE2E6DEE1E3DCE0E2
DFE3E6DEE0E4E3D3DCB56675BB2132CE1321CF111BC90C13C80D14C50B13C10812BF0712
BB0511B80510B70612B50612AE020EAA020DA7010DA8010EA8010EA9010DAA020CAA020D
A5010EA1010D9E010A9C010C98000B96000996010999010B9E020EA1020EA2010CA3030D
A0020E9F020D9D010B9701088E02087F02076902056400036F04066801016501016E0102
7301027101016901025C01005F0D062D8601
00FF0000FF00822506880B028502017800006A0000680102670001690102690102640002
6401016801026B02037001047600097D010B7C01097200056B000479010885010A8C010C
8E020E8B010B8800088B000892010A96010D99010D9B010DA2020CA7010BAB030AB0020B
B5030BC00810C4080CCA090ED30F10DF1817DB1513D81012CF090FCD0812CB0711D10C16
D00A14D30A15E4161FF01C21F11A1DF82223FE282AFB2729FA2C2AFC2F30FC3336FC363B
F63A44EB495BEE7286F38EA5F497ACF492A7F290A2F292A1F295A0F8A0AAFDB0BAFFC7D3
FFE2EFFFEBFAFFEAF8FFDFEAFFC9D2FCAAAFFD9F9FF99090F97F7DFD746EFF655CFF594D
FF5146FF4940FE413BF140447E1724C3AEB8EBEEF3E4E8ECDFE4E7DFE3E6DEE2E5DCE1E4
DBDFE2DCDEE2E7DCE3BF7D8BB12232C91320C90E19CA1017C60C13C60D16C10915BD0614
B90411B70512B50411B2020EB2070FAA0009A8000AA9010EAB0010AD0210AD020EAB000D
A7010DA3000BA101099E000B97010A9202089402089801089E010CA4020FA5010DA6030D
A80611A606109F020B9A01098D01058402057B04086C01026F03056E02046F0103760203
7701027101016A0102610100630D062E8500
00FF0000FF007E2306870A008401007A01016B0000670000670001690102690102620102
6000016700036C01057000067801077F010C7F01087A01057600067E01098601098E010D
90000D8D00088D000791010797010A9D020EA1020FA4010EAA030EB1040FB5050FB8030C
BD040DC2060EC7090ECF0D11D10D0ED00A09D6100DD20A0BCB050BC4000AC6020CC9040E
CE0912CC050FD60C15E7151DF51D23F82125FE2B2BFF3030FF3530FF3631FE3838FC3536
FE393BFB3E46F84C5AF55264F35566F85B6CF75B69F45B67F7646CF5686FF36D7AF2798A
F389A0FE9CBAFC97B3F4879EF07686F26870F76567F8615FFB5B57FF5953FD4D47FC433F
FE3D3BFF3B39F93334EE383F821424997D8CE5E8F0DDE3E7DEE3E7DDE2E5DDE2E5DADEE1
D7DBDEDDE0E4E3DBE2C58B9AA72334C21221C50D1AC60E18C60E18C60E1ABE0714B80312
B80413B60511B3020EB1010CB2050EAC010AA9010BA7000CA9000EAC010EAE030EAB010C
A8010BA6010AA40009A1010C9100078500048D02089801089E010AA3000DA70210A80210
AB0714AC0C15A5080F9A020A8D00068700058202077200026A01036B0204730306790203
7902027001016900016201006811092D8500
00FF0000FF007F2204890C028503017B01026D00016A0101670101670102640102610101
6101016800036E01057300057C010784020B84010783010882010887000A8B010993020D
97061196030D9401099B030B9F020CA3020DA5010BAA030EAF040DB4040FB4040DB4010A
B8020ABE0309C0040AC6050AC90508CD0607DA1512D40D0ECC080DC9060FC9070FC8040E
CE0913CF0B13D50E18E61621F31D28FA242BFD2C2DFB2A2BFC2D2BFF322EFD3230FE302F
FD312FFE3436FD3A3FFB3B44FA3D46FD414AF83C45F93F45FA4449F64349F64651F14655
EE4B61EE4E69EE4B67F14B5FF14554F44149F64144F94342F53C3BF93C3BF83637F52F31
F42A2CF62A2DF0272CDC28308213235E4153CCCEDBDEE4E8DDE2E5DDE1E3DCE1E4DADEE1
D9DDE0DCDEE2DED9E0B18390972131B71120BC0C19BD0B17C4101DC00C19B90615B30313
B40514B20410B1040EB1020DB0040EAD020DAC020DA7010DA8010EAC010DAC010CAB010C
A8010BA5000AA40009A1020C8F01077C000185010698010B9D010AA1000BA5010FAB0513
AF0B19BC1E27A70A12A0060D9402098B02078502087A01066700016401016F0103760102
770102700101690102620101650E082D8500
00FF0000FF00862905860B018203017B01016F0100690100630101600000600001630101
6501016C00047201047A010582010788020A8701078801088A01098D010A92020CA20E19
B11D27A50D19A10610A5040DA9050DA9030BAA030BAC030BAE020AB0000AB00109AD0006
B10106B90107BC0208C80A10CB080CCC0A0DD31614C80A0CC80A10C3080DC60B12C10610
C30712C40712C90B16CD0916D80F1DEB1C29EE1E24F12024F72629F72429F9292AF92728
F82827F92A2AF62A2BF62A2EF42C2FF42C2FF42E30F63234F43333F02F32F33437ED3237
EB3539E7343AE9343DE73137E73236E83438E93738E0302EDE2E2CE02F30E02E2FDB282B
DA282AD9292ECC2327C129307E1D2A3A2030B0B6C1D8DFE3DCE0E4DCDFE2DADEE1D9DDE1
D6D9DDD7DADEDBDAE0A68590831F2DAA1321AC0915AE0813B00814AF0513AE0513A90111
A7010FA7010EA6010CA9030EA6000CA7020EA7010CA5000AA7010BAA020BAC010CAB010D
A6010BA3010AA1010AA0010B97020B8701058A010799010C9F020BA10109A4010CA60010
AA0415B41220AC0D18A60A119A040C8B02097E00047E03077403066800026F0103760103
7702036F01016700015F01006A140D2E8601
00FF0000FF00832504850A018002007901026F01006701016101005F0101610101650101
6700016E01037802067F000783010788000A88010888010B8B010991020C9F0C16B01924
BF2731AF111FA90814AA050EAB040CAB020CA90108A80108AE020AB20109B4020CB20108
B7050ABE070DBF060CC4070DC1050ABA0309B00102AB0103AC0107AB0007AB0209AA0008
AB000AAE020EB20410B2030DB90512C90A19D81620D9151DDC1B21DE1D23E02226E3272A
E32A2ADF2C2BDC3131D83234D43537D83D3CD63E3BD54340D84A47D84D4BDD564FDA5A53
DA6259DE6C63E1716BDF6E6AE0726EE57976E57B77DC746FD46F69C05B56DA736FDC7673
D26E6EC06060B55758A55051854C525F50588C9398D5DCDFD9DCE0D8DCDFD8DDE0D7DBDF
D7DBDFD4D9DDDADCE1AB99A16F293490192599141C990E149D0D15A10C15A20613A20412
A0010E9F010D9E000D9F010D9E010C9E010D9E010C9F010BA4010BA9030DA8010DA70210
A2010E9F000B9E000BA0020C9D020C9201079501089D010AA1010AA40109A30009A6010E
A60111A40111A103119C06108D030B86050E7904097702057F04077600027801047B0103
7B02037201026700015F0100650F082F8702
00FF0000FF008425058509017E02017601017002006901036202005F0101600101640100
6900027201037B01058101088601088801088701088700078A0008980510A50B18AE0F1B
AF101CA70614A90510A8030EA8010AAE020EB0030DB0030DB2020CB6030DBA040FBA050E
B9050DB20107BC0810B9060DB10209A90107A102049C00029C00049D01069C0206990006
9900079C010B9F010B9E000AA5040FA8010EB00915AC111CB2292DB53738C14A48D05E5B
DD706CE4807CEA9391EFA4A3FABCBAF7B7B5FBC1BBFDC5C2FCCBC8FCCFCAFAD0CAF9D3CC
F9D9D1F9DAD4F9DDD6F8DDD9F9E2DEF8DEDDF8DDDCF8DFDBF3DAD5EDD5CFF4DCD7F0D7D5
EFD6D6E7CFCFE6CFCEDDC8C6D4C7C6CBCBCAC6CCCFD7DDE0D7DBDFDBE0E3D8DCDFD7DBDF
D6DBDFD7DCE0D7DBDDB6B2B48467698D53568D46478B3C3D8A30348B282E8A1A22900C16
9A040F9B010C9A010C9A010B99010A97010B97000C99000B9C000BA2020DA2010F9F000E
9E010D9C010C9B000B9B010B9B010A9A010A9B010AA0010AA3010AA5010AA4010CA50110
A502119F000F9B020F8901087500027A030B78080F6A00017A03067D04067B02047F0205
7F03057501026B01016200015E07012E8701
00FF0000FF008223058108027C02007401017001006900025F00015B01015D0201640102
6D01047601047C01038301078801078801068801068A00078F010B99020EA90916AD0914
A70610A1000CA2010BA8030FAB030DB30512B50510B4020EB4030DB4030DB6040CB4050C
AE030BA80108AA010BA80008A101069D02099901079600069301059201059102038E0005
8E010692000A93000997000B9A010D9C0310950715650109864C53D0ABAAEAC8C3F4D4CE
F6DBD7F8E2E0F4E3E2ECE0E1EEE7E6EFE8E8F0EAE9EEE9E8ECE7E7ECE9E8EBE8E8EAE9E8
E9E8E7E8E8E7E8E8E7EBE9EBEAE8EAECEBEDE9E9EAE7E7E9E7E8E6E6E7E5E3E4E5E7E7EB
E7E7EAE6E6E8E4E6E6E1E4E4E2E5E4DEE2E3DBE2E3DDE4E6DADFE2DDE1E4DBE0E3D9DDE1
D9DDE1DBDEE1DCDDE0D7D9D8D3D0CDD1CAC7CDC2BEC9B7B5C5ADADC0A1A2BD8C8F8A2F37
8F08129B030C9C010B98010A94000793010894010A96010C99010C9C010B9D020D9C010C
9B010B9A000A9A010B9901099A010A9900099C01099F010AA3000AA6000DA7010FAA0312
A502109D000D97010B8A030976010578020879040A6E0105720509680203670203770305
8002057A02046B00006200005E0501444902
00FF0000FF008126067E08017801007401017201036901035A0000530000580101620102
6D01037801057F00048501078901068A01068A00048D000894010C9E0410A70612A8040D
A6040EA1020DA2020EAB0512AB030FAE0410AF030FB0030DB2050EAF040DAA030AAB060E
A1030A9B0008A1040C9F01089601079201089101079200088F01078C00038B0103870003
89000690010B94010C9A010D9C020E9F04129A0C1A5F0514442D3BCECFD7E5E8E8EBEBEB
E9EAEAEBECEDEAEDEEE8E9EBEAEBEDEAEBEDEDEEF0EFF0F2F1F2F4F6F6F8EEEFF1F1F1F3
EDEFEFEEEEF0EEEEEFEFEDF1F0EFF1F2F1F2F5F5F6EDEEEFEDEDEEEAEBECE8E9EBEBEBEF
EBEBEFE7E9ECE6E8EBE4E8EAE3E7E8E1E5E6DFE4E6DFE4E8DCE2E4DADFE3DBDFE2DCE0E3
DCE1E4DDE0E3DDDEE1DBDDDFD9DCDDD8DDDDD7DCDCD4D9D9D4D8D8D4D6D6CFC6C88C545D
8A0F1D9D020EA0010C9C010C96010993010793000896000A98010B9A020A9A000997000A
97000A99010A9800099600099501099600089A01099E010AA4020CA90210AF0515B20A19
A804109E010B9801098D01087600037502057E05087301046D03085300004D00006D0205
8002067B01036F01016501006006025B0D03
00FF0000FF007C24057B07017902017301017201016C01035A0101520000560000630101
7000027B00048101068600068901068C01078F010593010797020B9D030EA2040EAC0A11
AD0C12AC0D15AA0F17A70714AA0813A80410A5010EA7020CA7040CA1020A9D01099C040C
8F00078E00069601079601069200059100099101089200089000099100078F00048D0005
8F000797010CA10510A60411A7040FAB0510AB0C17860F20370F1FC4C1CDE7EBEFEBECF0
ECEEF1ECEDF0F0F1F3F2F2F4F1F2F3F2F3F5F4F5F6F6F6F7FBFCFDFEFEFFFDFEFDFFFFFF
FDFEFEFDFDFEFDFEFEFDFCFEFDFDFDFBFBFAFBFCFBF8FAFAF4F6F6F6F6F7F5F5F6F2F2F5
F3F3F5F5F7F8F1F2F4EBEEEFE8ECEDE8EBEDE3E7EBE1E5E9DEE5E9DCE2E8DCE1E8DDE2E7
DAE1E5DAE0E6D9DFE3DAE0E3DADDE2DADDE2D9DDE0D7DCDFD4D9DCD3D7DBD3D1D59B6F79
891424A60615A80110A4020E9B010999000999000A9B010C9C000C9C010B9C010C9B010D
98010D97000B97010A94000893000896010A99010A9E010BA4030FAC0715B6111EC01C27
B2101AA2030E9B010A90020A7801046E00027A04097201046F04066405075600006F0307
8103067C01027201016700006307025D0E02
00FF0000FF007D25067905017601017201017201007103036302025C00016301026E0103
7801038001058200058801088C01088B000791010796020999030997010AA0050EAA0B14
AE1117B41B21B62228A7121CA20814A10311A1030F9D030E9600099100089001088D0109
8700068800069101079400069600059B00099C020A9A00099901089D00099A00069E0109
A2010AA7020CAE040FB40611B70510C10D17C3111AB31C2A58091CCBB9C8F7F5FBEDEDF2
EEF0F3F9F9FBFDFCFFFEFDFFFDFCFEFFFCFFFEFDFFFFFCFFFFFCFFFFFCFFFFFCFFFFFBFF
FFFAFFFFF9FFFFF8FFFFF8FFFFF8FFFFF6FFFFF5FFFFF5FFFFF4FFFFF4FFFFF4FFFFF2FF
FFF1FFFFF1FFFFF2FFFFF0FEFFEEFEFEE8F9FDE6F9FAE1F4EDD9ECEAD8EEEADCF2D9D0E4
D9D5E7D4D3E3D2D4E1D2D5E1D4D6E2D4D7E1D5DAE1D6DCE3D4DAE2D5DBE2D4D3DAB98D9A
8C1829AA0615AE020EAB030FA3010B9F000AA0010BA1010DA2020E9F020D9D010C9D010D
9B010D98010C96000995000895000997010A99010B9C010CA20311AA0917BA1B26BD2029
B2141EA509139B040E8F030B8003087700057C030A6C00026B0103700508670002780206
8402058101017701026B0101670602610F03
00FF0000FF007B21057905017701017400017701027700026F01026A01016E0102760105
7E01058201068401058A01088D02088C01088F020792010A92010993020B9E0713A00612
A20A14A8121DB01F2AA3111E98051197010D96010B95020C8F01098C0009890107890007
8900068F00069801079F0008A40208AD050BAD040AAE0408AE0207B4040CAF010AB5040E
B8040FBC0712C00A13C60F18C60D18CF121FD0151DC91C288C1026A96A87FFE4FAFFE3FB
FFE7FDFFE6FDFFE4F9FFE3F9FFE4F8FFDFF4FFDEF3FFD9EDFFD8E8FED4E3FCD1DFF9CFDF
F6CBDBF2C5D7ECB4C8EAADC1EDABBFECA2B6EA9AAFEA94ABEA92A7EC92AAEB8CA8EA84A2
EC85A4E8829FE8809AE87B99E77797EC80A0E47898E47799E0799DD97AA1D37BA4D184AA
D28EB0D598B6D7A3BFD6A7C3D7ADC9D1ADC6CCADC4CDB2C8D0B9CFCCBBD2D0BCD1D299AD
94172AB20918B5040FB1040EAD050EA7010AA7020BA6010CA5010CA5020FA0010C9F020D
9C000C9B000B99000999010A97010999010A9900099B000C9F010FA60514AB0B19B0131F
A90D199F051191020B8000067F040C81040D81050D750106710103720305700002810206
8801048400027A01016F0001680401600C01
00FF0000FF007A20047805007701017801017E02018102037C02027501017301017A0104
7E01048200048500048A01068D02088B01088801068B01088A01078B01098F010D930210
95031299061798081796041694021293020D91000992010A8F01088E01098E010895010B
9B010A9E0008A70208AF030AB40509BB080CC61212D11918C50C0FC70C12C10710C50A15
BF050FC10712BE050EBF0711BD0511BE0512C40A16C20D1AB10F23AC284BBF517BB64B79
BE4D7CD15787D65A86DD608AE2698CE36A89E36D87E57085E37782E48086E2878CE18E96
E29CA9E5A5B6E3A0B0E398A5E59099E98287EB7478ED6B6DED6065F15B63F15562F04D5B
F14C5AF14C58F24753EF3D4EF03C4FEF394DEC3449EA3148E42D46DC2945D42445CD2645
C42443BE2444B92849B52A4CB12B4FA92D4EAE3B59AB405FAD4A6CB1597EBC678AC85E7A
9E0B1EB30513B4010CB2020DAB010AAB010AAA0109A90109A70109A8020DA7020DA5020C
A2010CA1010C9F00099D01099B000B9B000C99010B9B000C9F020FA30412AB0B19AB0E1B
A60A179C020F91020C7B00076E02066B03087201077901067C02067601037B0103880205
8A01038500027C01027201006C0401650D04
00FF0000FF007720037606007701017A01008201008801038801028001007900007B0002
7F00048601078701058700048D030A8A01088702078603098000057F010781010A85020F
85010F8D03129707159F0C1A97041298041096030D9401099301089601089C020AA6020D
AE050FB0020DBA070FBD070EBE080DBF080CC60F0ECE1614BD0407BC0309B70107B7010A
B5000AB4010AB5000ABA010EBA010EBC030FC10612C30713C60B1BCB132ACD1A36D72442
D92342E62D4EF44160FD536EFF5A6EFE626EFE6B71FF7977FF867CFF9689FFA89DFFB8B6
FFCED5FFD7E6FFD6E6FFCEDBFFC1C5FFA19CFF877EFF776BFF695EFF5C56FF5653FF514E
FF4D49FF4E48FF4542FE3C3DFE383AFF3537FB2C30FA272DF9272FF11F28EC1B28EA1C2B
E31A28DE192BDB1A2ED7172ED0142CCB142AC31225BD1125B71029B31231AC0F2EAC0A25
B30619B6020FB4020DAF010BAC000AAB0009AB0109A90008A90108A9010BA9030BA8020C
A7010DA5000AA30109A000099D010A9D010D9D020D9B000C9E010EA20311AA0B17AF131F
AA0F1BA0051295030E7E01086100014F00005F0206740308790409790205800203880205
8901038601017F01007601016E0300680F04
00FF0000FF007722027306007901027E01008701018D01029001018D0101870102830003
8101038802068601058301048903098801088000047F0007790004780106790007760008
720008840714A81D29AF1B28A20B179C05119A020E99000B9B0108A1010AAB040DB0020C
B3030DB2010CB6040EB7040DB8030CB50106B60203BF0907C00A0BBB0309B90209B50009
B8030FB6010DB9030EBC0410C20814CC101DCD1119CE0E18D8151FE51F2AE9222CE21C27
E82430E42232E32837EB3442F23E48F8484CF5494BF75451FE625CF7615AF66763F1686C
EF6C79EF6C82EB677CEE6578EE5F6BEF5356F54E4BF64742F63F3AF93A38F83636F93333
F93231F73030F3292AF02526F02425EE2223EB1D20EA1B1FE5191EE1161CDE141ADA111A
D20F17D1111CD0111FCD0E1CCB0C1AC80A18C50A16C10916BF0817BB0718BA081AB60314
B90514B70410B70511B1020EAC000CAB010CA9010AA90009AB010BA9000BA7010AA8010C
A7010CA6000AA6010BA3020A9F00089E01089C000A9C010B9E010DA20210A40413AB0D1C
A80B1AA3081695020E85010976040B5B01035801036100026200026E01047F0206870104
8801038701027F01017801017307026A1103
00FF0000FF007828077407007D01008601028E02039102029601029801039502058B0003
8401038602068202058102078101088201087F02057C01067A00057B00067D0209790109
75020A7E0410A31D2AA6131FA00A169C04119C020E9F030FA0020BA4010AAA020AB0010B
AF0009AD0008AF0109B2010BB4010AB80309C00B0BCE1814CF1A18C30C11BF0911BB0712
BC0814B90611B80510B80511B4030EB80612BC0812BE0711C50A15C80B16C70D18C20714
C40D1BBE0918BD0A19C3111DCE1925DC222EE62833EC2C37F4353DF6393FF83C41F73F42
F84046F93F4BF73C47F3363EF7383DFA3A3BF83835FB3632FA2E2EFC2C2DFC2B2AFD2C2C
F9282AF01F23EE2023EB1F20E71C1EE31A1DE0181EDA141CD31019D11018CF0F18C80C15
C60E19BE0A17BC0916BC0915BB0713BA0713B50310B20210B20312AF010FAD010CAD010B
AF030DB1040FAF040FAA020CA6010BA6010CA7020BA6010AA9030EA9020FA8010CA6000B
A6010AA6010AA30109A1020A9F02099E01089D00079E010AA0010CA0000DA20111A20213
A003129D021196020F8F000B8B040D7503076401026602046301036901037C0205850203
8701028501027F00017801017106016C1502
00FF0000FF007829097505008101008A01019001009200019902039C01049D0306960307
8701037C01037800027B02057B01057D00067B00037C000680010785010987020A900812
950E1988051295101B96071494020D95010C96010B9B010CA1010BA50007A90007B20309
B3030AB00109BB0810B8030DB5040DB7070EB6070AB40709B0060AAC0309A70109A8020C
A4020CA2000AA4020BA3010CA0010AA0010CA5010FA8000DAD020FAF0310B30815B40716
B30716B00615AF0614B40B15BC0E1BCC1626DB1E2BE7222DF02730F62D34FB3838FB3C38
FC413CFC3C3AF93936F93833FB3A34F93933FC3A35FB322EFC2D2BF82726F82724FD2D2B
F42424F12023F22225E71A1DE3181BE1191FDB161FD91621D0111CC90E18C80F1AC30D19
BD0C16B30612B10511B20711B30611AF0510AA020EA9020FA8010EA7010DA4010BA40108
A5000AA6020DA2000C9F010B9C00099C00099D00099E000AA1020DA5020FA6000EA5020E
A3010DA2020B9A01079301069701089C02089D00079F010AA0010BA1010CA20210A30514
9D020F9A000D97010D93010A91020A8203087101037303066F02046F00027A0103810204
8001017F01027D0102790201740A016C1600
00FF0000FF007B2A0D7B08018902028F01029401019501019903039E07089B0708940307
8702057700017300037601037901037C01067C01058001088601088A020C8D020B91040D
93060F8D020D85000989020B8B01098D0008910107990008A40209AD040BB00208B60609
B6060CB2030BB80911B1060EA50109A10109A000079B0007990007960007920007920008
91010790000891000794000B95010B99010E9D010E9F010EA40310A90412AA0411B10818
B20815B50815B80B17BB0C17C00E1BC81321D61A26E7262EF22F35F6383AFB4944F84D43
F64F45F54F46F45148F65149F34D42F64D41F94E41F13A2FF7382FFC3832FB3530FB3430
F8302EFB302FF72B2CF02326E91B20E61A22E41C26E11B25D5151DCF121BCC121BC50E16
C00B13BC0A13B80913B30511B10410AE040FA8010CA6010BA6020CA5010BA2010BA1000A
A2010D9F010D9B000B9900099800089800089701079700079900099C010D9F010E9F030F
9C010C9D010C9401088900039001069801099C01089C000A9C00099D01089C000B9C010D
9B020D97010A9200079101059000078501067700017601027400027600047A00047B0103
780101790101780002730201720D026A1900
00FF0000FF008231117C09018E04039502029A02049B02049705038D05057F02017F0306
7F02067500017200027701057B01047E0107800108810108840106870108890108890007
8B01098B010A8701078701078801078C00069301069B010AA5020AAE030CB7070FB5060E
AB030CA2010B9E020998000792010791000891010A90000A8E00088A0007880006870006
8800078B00088C01089100099300079A010BA1020EA4010EA7020EB30917B00412B70613
C4111CCA141CCF181DD51A21DB1F28D81F29DF262CEF3A3CF74D4BF76057F87364F67D6D
F38879F38F85F5978FF4968EF39085F48876FB846DFC725BFB5F4FFC5449FF4E46FF4A42
FD423EFD3E3BFC3A39FC3738F92F33F62A30F3262DED2227E92226E21D22DE1C22D7171D
D11319CC0F17C60B15C00713B90510B50611B0030FAF020EAF030CAC020DA7010BA6010E
A3010E9E000D9C000C9A010998000799000797010794000693000795000A97000A98010C
98010B9801099201088E000692010898010B98000999000999000999010896010895010A
95010A9201078E01038C01028D01048B02068201047F01047B00047B01057B0104750001
7200007401017401026D0100711205681B00
00FF0000FF00893A187C0B018D0201980102A005079B04058E0504800A0BAB43457B1316
7202047401037200017401037B01047E01067F01067D01057C0004810005870108880109
89010A8901088701078701068702048D01079401089D020CA4020DA8010DA9020CA80410
9A010B93000A8D00078F010A8901088801088A00078D00088D01098A00088B00078C010A
8E0008900009940208990209A00208A8040CAF020DB70612BB0711C10A14C80F18CF121B
DB1A21E9262CF02E31F7383DF73940F73F48FD4F53FF5F60FF736EFF978BFFAF9FFFBDAF
FFD6D1FFDEE3FFE1E7FFDEE3FFD6DAFFC1BEFFADA2FF907FFF786BFF6861FF5752FF554F
FF4E4AFF4947FF4647FF4446FF3A3DFF353AFF3236FE3035FB2E33F82C31EE2429ED232B
E72028E51F29DA1621D61520CE121CC20A16C00915BC0511BE0712BA0711B3020EAD010D
A9010EA5000DA2010CA0010B9F00099D00089A010697000596010797010999010B9A010C
99010B97010895010893010994010A95010C95010B98010B98010B97010C93010B910009
9000088D00058900018A01028B01038B01048901048501058001057B0003790102770102
7400017201017202016F05017216046A1C00
00FF0000FF0094471C7810018C05019C0305A70A0B9905058101019421239A29307D0C13
6E01027B02057A01037600017A00037E01057E01047900027A00027F0105840107850109
8501098701088803098B080E96141897101695061198020F9D020FA204129E020F98000C
91010A8A00078900068E030C8901088C00089000069500079700079800079A01089E0008
A1010AA3020AA50209AB030BB1030CBB0711C70D17CC0F19D5151EDD1D24E72329EE272E
F0292FF63138F7323AF7353FF63744F63948F7414DFB4B55FC5B61FA676BFB7A79F98081
F4858FF48698F38297F17B91F07285F06674F66066F14F4DF84846F43C3CF83838FA3837
FC3939FC3638F93134F92E33F92C31FB2D32F6272CF6272CF4262CED2027E81D27E81D29
E01822DF1823D8121EDB1824D1101BCC0E1AC70A19CA0D1BCA0C19C10612BF0713B80310
B4020FB1010EAE010EAA000CA9010CA50009A000079D00069D02079D01099F020D9D010D
99010B98000896000695010990010A88020B8B020C9A05129D03149B031594011091010B
8F01098C00058701028700028B01048D01048D01048A01058301047D01027C01027C0002
780103720000700200750C037117056B1F00
00FF0000FF00429D02751B02830A019A05059F05079303037C01017D030688050B810409
7000018001048803058101037C00027F01048101048300058100038001058001057F0006
81000889040E98121DA01C28AC2D37A11F29970F1B96061595000D94000C92000A8F0009
8D01078C00078D000593010A96020A9D030BA40209AB040BB1070AB70C0FB3070BBA0A11
B70811B80913B90A14B70811B3040BBD0B14C50F18CA0F1AC70A14C60914CE1019CE0E19
D1131DCF111CD31420D41323D31625D51525DA1A29E82533EF2A37ED2C38F33943F6434A
FA4C55F84B58F54453F33C4CF43948F73943F7373BF43030F82F2EFD302DF92924F92723
FB2A27F82727F42224F21E23F82429F21E23ED191FEC1A20E6161CE2151BDC131CD7121C
D00D18CF0E1ACD0E1BC70915C20512C30815C00614C20715C10713BE0511BB030FBC0411
B80410B7020FB60210B4030FB1020CAD020BA80109A50108A40108A40108A5020DA2010D
9E000B9C01099A01099601088C010A7500037B010A960617A1091DA0091D9C081995020F
9000098C00058801048700058B01058E02059002068C02058401027E00017E0101800202
7D010376010172040179150A671501349000
00FF0000FF004FAF0A9D56287C18078F08049102028902037701017A02038A0307820205
6E00008101059202058F000387000286000290030894040A90050A8602077E01047D0106
81010A8A0311970F1E9D1627A423329C1A28950E1C9106138F010C8F010B92010A93010A
95020899020A9B0109A1020AA7020AB0050EB6080FBF0E13C31214C61919BB0D11B5070E
AD040DA50308A30108A400089F00059F0108A5010CAB020EAF040FB00310B10210B50412
B60410BA0512BD0512C60B19C70B17CB0B17D8131DE1161DEF1F27F6262CF72B2FF62F31
F83736F93A3DF6393CF7383AF73637F93635F83531F7322CFC342CFB3129FB2C22FB2B22
FA2C27FB2D29FA2A28F52222F82324F72222EE1A1BEC171AE81419E61519DE1115D50D14
D00C15C80813C70B16C30814C00713BA0310B6010DB6010CB6020DB2000AB2000AB1010B
B1010BB2010CB3010CB1000BB0010AAF030BAB0109AA010AA90109A8010AA7010CA8020F
A5010BA3010AA0020C9A010992020A7F02077C00079404159D04199D04199B0417990211
96010D9101098B0107870005840105850203890004890104870102840102830202820102
7C010177010174070176170A621500369300
00FF0000FF002EDE0B7F410E6712018309038801027F0102730000750102870405830305
6E00008302069A0307A303089F04079801059902079B040A9202078501077E01047E0107
80010C8C0313950919990E1EA82331A11B29950B1A9003108B01088D000998030E9C020B
9D0208A10209A6030AAA040CAE050DAC020BAD040DAD050CA70408A10306990104970007
9400078E01038F000394010490010493000798010A9D000AA2010CAA0210AE020EB3020E
BA040FBD040FC90B14D5131CD61018E0181EE92022F22A2AF93331F73631F53834F13C37
F2463FF3504BF35955F15855F15652F4544EF65147F64A40FB4B3FF84234F83D2DFD4234
FC4036FD3E36FD3932F9312AFC312AFD302AF62823F82624F62122F31E1FEE1C1BE51517
DE1117D30C14CF0D16CC0B17C70A16C00712BC050FBB050EB7030DB4020CB4020CB3030C
AF010AAF000AAF000AAD0109AA0007AA0007AA0109A90109A8010AA8010CA8000CAA020D
AB010DA8010CA5010BA1020B9A01099101098E00099702109E04159C02169A01149A0111
99020E93010B8D01098502077501037402037E0105850104870104870102870102860102
7F0100790100750A036B1304671B0000FF00
00FF0000FF0000FF008548156312007F0B038101007E01027501017201018506087F0305
6E0001820306A5090DB1060BB3080DAE060CA202079B03088E01058101068002067D0108
83030E88020F920616990F1CA6202A9D14209206108F010C90020C92010A98010A9C0109
9B01069D00059E0004A00105A100059D00069900079600059300048D00038A0002890003
8B00048D01058A00028F00039401069D0108A6030CAA010DB2040FBE0814BF060ECA0A12
D30F15D91217E81E22EC2024EF2527EF2A2AFA3B37F94339FC5246FC5F54FB6C62FA7B72
F58881F59994FAAFACFAB4B5FAB0B0FAA5A3FB948CFD8174FE7264FD6859FD604EFF5F4C
FF5649FF5246FE4D3DFF4C3CFF4939FF4336FF3F35FE3730FD2E2BFD2C28FB2824F6221E
ED1819E6161BDC111AD9101CD30F1ACE0D16CC0D16CA0E15C30911C00710BC040EBB0510
B5030EB2010BB1010BAD0108AA0007AA0108AA0109A9010AA8000AA8010CA8020BAA010B
AC020CAA010BA70108A300079F00079E01089C010B9A010B9C010E9C011199021097010F
94010B9001098B00088201076B00026500027701067F00048401058600028A01028C0204
8702037D0201760B0467110050580000FF00
00FF0000FF0000FF004CAD0D6A1E00790E017E03018201017E03026F0000780505750304
6500007F0304A5080BAD0207AE0308B2070EA9050B9A01078D02077E00047B02067E020A
84040E880310910A1796101C900B148C040D8B02088D01098F020B91010A930208940005
9800069D00079F0004A10005A20004A100049F00069900049600039301009701029A0204
9D02059D00059B00059D0206A50209B2040ABB050DC70B15CF0E16D9121ADE1419EB1D1F
EE1E20F52727FB2B28FD3332FE3B38FF4843FF534AFF6057FF6F66FF827CFF918FFFADAD
FFCACFFFDBE4FFE3EFFFDEECFFD9E6FFD4DEFFB7BAFF9992FE7D73FF7168FD685CFF6255
FD574BFE5749FE5243FD4E3EFF4C3EFE4338FC3A30FF3830FC2D29FE2C28FE2B26FB2420
FB2322F01D1FE8181FE41722DD151FD50F19D4101BD10F19CD0C16CB0C15C30611C20814
BE0713B90410B6030CB4030AAF0008AD000BAD000BAD010BAC010BA90009AA0109AC0008
AE0109AD0009AA0008A50007A20005A10005A101089D00089B00099B010C97010A94010B
92010A8D01088A02068601077703076E00027801047F01048400048801048D01048D0204
8A0102810201780C036D15001DCA0100FF00
00FF0000FF0000FF0000FF00914C177111007C04008803028605047102026802036A0808
5F0000800304AA0F10A90407A50005A70108A9030A9E020A8C01067701036A0104720209
7E020C82010C83020C81010B8401098600078600068700058700068800068A0006900005
9C0109A7020CAF030CB2030AB7050ABA060BB9060BB00209B10709B20A0ABA0E0DBC0C0E
BA080DB8050EB80811CC2027C11018CB1016D00F15DB141BE0141AEB1C22EE1E22F72528
F62426FC2C2CFE2D2BFD312FFE3B36FE423BFA463FFB4E4DFC5758FB5B62F86169F76D7B
F4798AF6849CF2809AF17792EE7188F16F82F9707AF96668F85855FB5653FF5954FD524B
FD4E47FF4D44FD4A3FFB4037FC3D35FE3C34FE372FFC3029FC2825FB2522F31D1AF41D1A
F21B1AEE1A1DE4161DDC111BD8101CD40F1BD10D1ACE0D19C90B16C70B17C20815C00714
C10815BD0512BB050FB6010AB6010CB4010CB4010DB4000CB5010DB6030DB6020AB80309
BD060DB7020AB1010AA70107A20005A20106A301079E01069A0006990008970008930007
9101068C01058A01048901058002057B01027F01048101048301048701038900048B0103
8B02028404027B0E066F180000FF0000FF00
00FF0000FF0000FF0000FF004FAB0D751D007F09019007048F05037D04046A0D0C7E2F2E
5C06048D0C0CA6090AA70305A50006A50107A80108A8060E9402077300025900005E0002
7402097D0209830C11860C14830209820005830105810004810004860208850004920106
A30109B2030EBB040EC0030BC7070ECF0C13D21216C3080EC20C10C50D10C81012C50D11
C0070DBD060FBF0A15B3030CBA0811C30A12C3060ED10D15D00910DA1218DB131AD80E18
DF141CF12127F11E20FA2929FC322CFF3932FD3A33FD3F3CFE4142FA393FFB3C44F73D48
F53E4CF84656F64352F43E4EF63F4CF73E49F94146FE494AFE4645FB4240FC4543FD4543
FB3D3CFD3E3BFD3C37FD3733FC342EFD322BFC2E28FE2B28FA2423F61F1DF6211EF11B19
EB1517E8161BDA0D16D00A14D10E1ACC0B1AC40815BD0815B10713AC0915AA0613B10513
B6030FB90411B6020EB70410B5020DB8030EBB0410BD040DC20712C30611C70811CD0D14
D10F16C90A13BA040DAC0108A40006A50107A100059E02059A0004990106970005950105
9301058F00038E01038B0103860004860105870104850104840104840104840003870204
8B0608820604780D026F1A0000FF0000FF00
00FF0000FF0000FF0000FF0030DE0D782402800E01950D059405018E0709822124ECA8AB
6A1315930D0FA40609A70308A60208A50007A70107AE060DA7080D8500036F0103680002
7101077B01067701037B01058101068000048300058401058401038500048A0004970106
AC040CB7040FC30812CC0A13CF0A13D10C14CE0D14BF060DB7040AB5040BB1030AAF0208
AC0008A80009AA040DA5010AAD0710B90F19B4030FBC0410C30913C2070FCF0E18C80714
CA0511E71B21F21E21F92423FE2F2AFC2E29FB2D27FD2E29FC2F29FA2827FA282AFB2D2E
FB302FFC3132FC312FFD3330FA2F2EFE3333F62828F92D30FC3436FE3A39FE3B38FE3A38
FD3534FD3433FB312FFD312EFD2F2AFB2B26FA2724F62121F62121F21C1DF62222EF1A1B
EE191CE7151AD70D13CA0811C60815BF0715B40615A3030FA7121EDB515DAE26339B040F
AD0411AF010FAF020DB1040EB2020DB7020DC00711C40912C60810CB0A12D00C13D30C12
D40F14CE0B12C10510B2020BA90109A30107A001069C0104990003990104960003950103
9502059302059201049102048D01038D02058C02038700028501038301047E00027F0102
8607088009067D180854540000FF0000FF00
00FF0000FF0000FF0000FF0000FF007F3008871D099717079A08039A080B800D12701A1E
720A0D9207099D0204A00105A30105A60106A80207B3060DB6090FA20207940207870207
7B00037F00048001038402068601068901078E01099002098F01079001079802099F010A
AC060EAC010AB6030AC70A11CB0A0FC9060FC1040EB30008A90007A301089E00089D0008
9A000795000697010995000A9500089E020DA7020EAF020EB3020DBE060EC7080FCC0B14
C9030CE61A1CF01C1CF51F1EFA2523F5211DF7231DFA231EF6211BF8221FF92323F72422
F92622FB2A25F92A23FD2D26FA2B25F72824F32123EE1D22EC2023F32928FB332FFB322E
FB302CF92E2CF92D30FA2D2FFA2C2AF52725ED1E1FE91A1DE7181CEA1A1EE91A1EEB1B1F
E9171BEA191EDD1219CB0812C20512BA0513A704119000099C0A17A00E1FB126368F000B
A1020CA7000BA9030BA90108AE000AB8030FBA010CC10710C30610CE0E16D20F15D10D10
D10D10CE0C13C30812B0020BA80209A100069D0205990104980104980004970104960104
9101048901048E02069402069301049000028C00018A01018701028201047D00037C0003
7C02037B0901771804388F0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00883F0E8C2E119E23109B0A02970404901112962C28
89110C9304039902029B0002A30204A70106AC0107B5040ABC080DB30309B1060BA9050B
9801059001068C01058F02069101079501089801099C050D98020A9701089B02099D010A
A0020AA40108AC0309BD060EC4070EC4060DC70913BD080FAA00069E00049A0005970007
9300079000089101078C00078E000798010AA00008AC0109BB050BCE0E11D6100FE31718
E41615F0201DF6221EF3201CF2221EF72923F42A22EF271FED2921E82921E52C26DE2A23
DF2C24E1302AD52721D42720DB3028D32923D02723CA2220C5221DC4231BCF2C26D6322B
D42E28CD2722C11C1BC82325C82221C62120C11A1ABF1518C51B1FCA1E21C7181ACE1A1D
D51B1FD81A1ED3171DD0161EC50E16BE0C17AB0C158700088C06109A08189A071597010B
A7060EA90209AD0209B00209B9050EBF0711BE060EBE050CBF050EC60610CD0B14D00D12
D10F12CB0B11C10912AE020BA401099D0005980003950005970106960005970106980106
8E02047900018001039201089501079101048C01028B01018801018501038000047C0204
7903037D13076D170238930000FF0000FF00
00FF0000FF0000FF0000FF0000FF00965116792403901B059E1107910301870402961D17
910D079402019801019C0001A30104A90007AF0208BC070CC0090DB90209BE070DC30B11
BB0A0EA70206980004970207990109980108980108990108950107920006950107960007
9D0107AC060EAE020BBA050DC20910C50911C80C13C30911BE0B10B90D10AB0407A10007
9A0007950007920005900004970104A20307AF080AC10F10D61D1AE3261FE72920E5281E
E83024E32F24E03226DE362ED6382FD43F33D44437C63C30C9483CC85244BF5345BD594C
C66457C6685EC26A5EC77064C77165C47066BD6C60BE6E60BC7061B97061B66D61BD7165
BE6F63B6685BB06157AE5F57A85951A5554BA250489F4943A149429E423C9C39339B322C
9D2D27A029259F221DA3201CA21B17A319199A1A1A791312CF787AA240467D0A128E080B
AF1418B30B10BC0E13BF0D13C50E16C20B11C1090EC60D12C2090FC6070FD00D16D00D13
D00E13CC0D13C00910B0030CA3000A9B0108970106960008940007920006970107990107
9103077E01037F00039202099401088F00048C01028B0101890101860101810204790103
7607037E1E0E6D1F0300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A203762801871A03940F058B0201850001870200
9207039601029B0102A10003A90206AD0106B40408C40D0FC2090CBE050BC3090DD11013
CC0E0FC10B0DA801049F00059C01099800089300069300079201088F0007910008990109
A5030AB90B15B80710C10C14C0090FC20A10C40B11BF070DBD060CC61316C31214B50B0E
AE0D11A50C109E0E0E9F1211A81B17B2221CBC2D26BD2F25C13A2DC44033CA4D3EC65141
C65C4CC76757C56D5CC47467C47E72C3887BC18B7EC59588C39C8EC3A393BAA090C0A99C
C2AA9DC1AAA0C6B2A5C7B4A8C4B4A7C3B3A6BEAFA1BDAEA0BAADA0B6AC9FB2A99EACA398
B0A599ACA396A69C91A1968D9D93899B90859D8F879B8A8398887E948077998076987B71
96766C926F638F685A936555945E4E9256478C51447B4E44906F6AA07A785F282473221C
8C231B9218139C1613A31412AC1615AD1010B81213C01314C20E10C90F14CE0F16CD0D13
CE0E14CA0C13C60D14B7070FA5010B9C000B99010B96010B930009940108970107970005
9301068C01058D01069502099201078E01048E00038C0103890102860101800001780101
760B03751C0967210000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028D8067A36027F2203830B03860202870200910705
9606039B0301A10102A60103B00609AD0002B30204C91111C10809BD0409C50B0DD11011
CE0D0CCC0E0FBC070AAD0306A100059C010993010995040E96060D95030C97010A9F010B
AC040DB4050EB7070EB8070FB8080CBA0B0FB80E10B10F12AB1011AD1915AA1C15A51F18
A227219E30279E3B30A14A3EA85649AE6153B16D5EAF7466AC7C6DAB8071AA8575AA8A7E
A78E82A48E83AA988DA89A91A79D96ABA59DAFABA3B2B2A9B2B5ABB7BCB0BCC0B6C3C6BC
CCCDC5D1CFC7CDCDC4D0D1C9CDCFC6CDCEC4CBCCC3C7CAC0C3C7BEC1C5BEBEC4BDB3BBB3
ACB4ABACB4ADA9B2AC9DA5A29FAAA69AA5A1969E9D9097978B93908A918C8A8F88878C85
85888281857C84857C817F747F7A6C80786880796878756776766B747166796E60806859
8763548A5B4D88524487473A8C3F33852C218F251D9F241DA51B15AD1514B61214C01417
C51316C60F14C51017B70710B00612AA06139F010E97000C94000C96020C970108980207
9702099401089401069200059100059001039202049102048B00028801028302027A0201
78100567160133910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00925616782C04720C007F02018B0401960702
9C0702A20402A70301A80101B20808B20406B50304C81010BF0709C0070CC50B0DCA0B0B
CC0D0CCF0F0FCC0D0FC50C0FB8090DA9050B9E090F9D0E15A41418A40E14AB0D15AD0A15
AE0911AF0A11A90B0FA10E109D1310981613941F188F29228F382E964A3D9B5B4B9E6756
9F71629E7769A081709B837497847695837994867E958D8692918894978E95998F999E97
98A0989FA39E9CA39FA4A8A7A6ABA9ADB3AEB3BBB7BCC4C0C8CECAD2D7D1D6DAD4DCDED8
E3E4DEDDDCD8DFE0DBE1E2DEE2E3DFE3E4DFDADBD7DCDFDBD9DED9D2D7D2D0D6D0C6CEC8
C5CBC5C0C6C1BFC6C0ACB3B0ABB4B2A4AEAD9DA6A599A2A1969E9E939A988D938F8A928D
868F8B848D8A838B897D848178807A798279798277768276747F73767D71777A6F7A7B6D
787A6B7574667471647971637E6F617D68588262528A5B4D90514490433A91342E952723
9A1D19A41A17A61415A40C0FB9141BB80B17B50B19A705139C000E9A000C98010A950107
9602089400079301069101059001049201049403049102038C01028801038502037A0101
771206691C001BCB0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B61678390B6810017F0602940B07990200
A10401A80503AE0604AD0403B30606BD0B0CBA0608C40F11BD070ABD050AC3090BC90B0C
CC0F0DD0100FD11011D11013CE1315C51518B01113AC1A1EAE2023AD1D20A8171B9F1418
9414148F191887221E86342C8C4B3F955F54986E6198786B967F729180728F84768C8777
8A88798D8B7E8F8C808B89818C8E868F908C92928F939493929794939C9998A29C9BA49F
9EA8A2A5AEAAA6B0ADB0B8B8B5BEBDC0C7C5CCD5D3D5DBDCE0E4E4ECEDEDF2F4F2F7F7F6
FAFAF9FBFBFAFBFBFAFEFDFDFBFAFBFBFBFBFCFCFCFAFBFBF8F9F9F6F8F8F4F6F6EDEFF0
EEEEEFECEAEAE2E2E0DADAD8D1D2D1CBCDCCBFC5C1B6BBB6B5B9B6B2B5B1AEAEA9ABABA6
A5A6A29B9F9B969D9A949A978D928F868E89848C86848C857F867F7F847D7B8078798075
747D71767C75747A73737A7271796E72786C76786B787568786F617A6B607C655C846258
87594E8A4B438639358123209B2122AE1D21B5181FB7131DAB0712A5020EA0020C960006
9300059301089001068A01038A00019101049303049001018D01038A01038301027B0400
791605378E0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009056236B17028A11069B0C05A10302
A60301AE0606B40907B40707B20502C00F0CBB0808B60407B50207BB0308C80E10CB0D0E
CC0E0FD11012CF0F12CF0F14D2151ACF1B1CBC1D1CA724239F2D2E942E2D8F3330873B35
8D534998695F9A786F917E718D85768C877B89867B8B897E8C8B7F8D8C828B8D838B8E84
8B8E838E8F878F908A8E8F8A91938E959894969996989C9C9EA4A6A4ACADADB7B5B6BEBE
C4CDCCCCD5D6D8DFE0E3E8EDE8EEF3F1F5FAF6F9FFF7F9FFF8F9FFF5F3FBF4F2FBF3EFF9
F2EDF7F0EAF3EAE6EFEBE4EFE9E3EEE5E0EAE0DAE6DED7E3DED7E1DAD4DED9D3DCD3CBD3
D5CBD3D7CAD3D7CCD1D5CCCFCBC4C6D0CDCCCDCBC7CBCAC5C9C6C3CAC6C3D1CBC8CEC5C2
CDC3C0CDC7C3C7C2BEC2BEB9BAB6B2B2AEABADABA7A9A5A0A29C999D969197938C8E8E84
898D8283887F83877F7C81797B81787B83787B8277787E73747B6F767D73767B73757870
737469756C6577645E7C5D5586544B8C423D943230992122A51B1FAD151BAB0E149F0309
9B02079302068901038601028700008D01038F01048F01028C01028900018502027C0501
7D1A061EC90000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A4672D7B2707961E0BA21004AB0A03
B20A06B60907BB0B0ABC0C0ABC0C08BD0B08B80705B00203B40105C1080CCA0D0FCD0F12
CC0F10CE1113CB1314C81619C01C1DB32421A4332C94453F8E5953936D669579728D7E74
8882758B877C8B89818A8B82848A7C8B8D838A8C828C8C828E8F858F8F8791938D92948E
979B93989C959B9F9BA0A39FA5AAA5ACB2B0B4B9BAC3C8CABFC7CAC4CBCFC5C9CFC4C8CF
C0C5CDBFC1CBB5B6BDAEADB5A5A5ADA09DA99B99A79D99A69C99A4948E99948C98948898
9688969A8C99988A969487959589969B8F9B988B958F808891838895878C9284888E7F80
9583828F7C7C8E7C7A8D7C7991827F9086818D8780918983958A869185808E807B8F807A
94847D8F827B958980978B81A0918B9F918CA59891B2A29BB2A29CB2A099B2A299AEA197
A79E92A6A1959F9C8F9B968B9794899390868C8B8086877B82877A80857C7E847E767E79
757F7772787176797376756E76726A7667607B5D5883514D853C388A2C2891211E951313
9F121593090C8902058A01048801018800018700028801018A01018601018103017C0800
791A0400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0050AD0F782704901D04A41303B41006
BE1109C5140DC2110AC3100ABE0D08C30F0DBC0C09B80908C00C0CC60E0EC60B0DC90F13
C61314BF1816B01B189F241F99393298544D966E64917D738A837985837B84857C82877C
83897D888B82888C848B8E858B8E828E8F8692938A92948B9899939B9D999DA09DA3A7A4
A2A9A4A8AEABAAB1AFA8AEAAA8ADAA9EA0A19495978E8F9288898C88878A868585878485
8784858A8687918B898B83828F87858D8382887F7D90868491868191857D90837B968680
92817A9180789B8C869A8D86988D86A19590A0938B9A8B7F9485789B8C7E98897B99887A
9A8978998877988977928273988A7B9E9385A49D8FA69D909D92839A8C7D9A8A7C8B7A6B
8D7C6A8979668879658777628A78668C796A8A77678975658D78688C75658D75648E7765
94816F9586749C8C7CA29283AA998CA8988CA39689A4998C9D968B9A958D92908C8A8B86
868A8181867B7C81797C817B797F7B75787672706D70696571605A745850744A4072312B
751B1981151485080B970A0F9303068900018301028401018601018302017F04017C0E03
6E160300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B742B018621039D1703B71509
C21508C7160BD12017CF1C16C5120CC20F0CBC0C0BC71919BC0B0BBF0E0CBB110EAD1110
A31E1B9830299B4F479E6E64987F768D837C84867D83877E848A81878E84858C7F898E84
8B918690938C8F938990928B91938C93958E9899949598939A9B9898999794969490908E
8A8B898485848C8E8C9899948A8982918F87938C85938D84938D83989287948D80989184
9D96899992849E9687958C7E9B9383988D7F9A907F9B8F7F93887590846F8F836C978973
968871978A758C826F9388759D907F998D7E958977968973988B76978B76998D789C907A
998C769A8D77978E779B907CA29585A198879D968499917E9B907B9587718F7E678C7A63
8B7A608A7A5D8B7A5E8A775C8C7B608E7B628C785F8D785F8C775E8D765C8B73588A7056
8C7259896E578B715A8B725C8E74609077658E7A6A9584759A887CA19288A1948CA0948A
9B93859590808E8C8085877D7E817B797B7975787675767373736E6C6D666A6760695A54
694A4367322D6F1C198B1716960F0E8B03048100018001018101017F01017E06017C1407
34870100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007E3C05772200982108B2190A
C82214C3160CC6180FC81611C6130CC1100CB80E0DBA1B1AAD120FAA1B149A261B913C30
8F584C9071678B7B7289837C858882818A827E8980848D858A958B8D978D8E978A8D948B
91978E90948E90938A8C8E87898A8583857F80817C7D7C777E7B7687817A8E8A808E8A7F
93908599958D9A988FA29E959894879B9587999281968D7C9C94819C94829A937F9B9381
948D7A918A7698927D978F7EA29B889E9885A19A889E938499917F98907B98907B988D77
988D77908670989179A1957F9C907D988B7B958675948671968A77998D7C9A907E9D9581
9F9883A09884A199859F9684A29888A39C8B9F988698907C9B8F789080678E7B638F7C64
8D7B60917F62927E618F7B5F8B795D8B7A5F88755B8A785E8C7A5F8A775A897458897258
8A71588B70588A70568E74598C7156927960A08C77A392819789789081718D7C6D8D7C6B
8F7E6C988877998F7D948E7E918D8187867D81817B7B7C7677787373746F6C6D6A686865
62615B60544D62423A6B2E25791B1487120E8506067E00017C00017B02017D0C02751507
2E850000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009A59187A2E04871F03A91D0E
C6291DBC1D13C3251DC11A14C1140DBC140EA7120D9F261F8C281C9247378D6151806B5E
78736880807A85878083857F878D86838C848A958B909B918E9B918F99908E958D888B86
8588827F807977776A78766A8582778B887D929084959083968F81988F8098928096917D
9693829B9788949083949183908D7E979181999581928C7899927F98907E99927F9B9281
9B938298927C96907A99917E9B94819892809E97869C9284A19786A097859C94819C937F
9C937E978E7A99917C998F7D9C927F9C917E998B789D907DA39985A096849E97849C9783
9D97849E9785A09887A099889F998AA39D8EA0998999917F948973918067907C648F7B63
89785D897A5E8B7B60897B5F8A7B60887A6085785E8479628276607D725B7F715A7D6F59
7D6E5980705A86735C89785D90806297866D9A8A76978A77958976978A7695857191816B
8B7B6387775F85755E8576628B7C6B95897A91877B8E887C8A867C7D7B737575706F716D
666B6561645D615D55614F46623A2F6A22197B16137F07087E03017C0500801406671204
29860000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029D808803B077F2708A93729
A91F18B32523E86D6CAE1916B71A11A71B128C261B985B4E8663547A6B5A727162707569
797E76848681868882888B84898E878A90898F948D8A8F87858C827E82767C7D727F7E73
8381758A86788C88748C867397907F9189799B938498928097917E958F7D9A9581958F7B
928D79928D7B958F808F89798E8B7A98928194927D9994809D96839A92809A927F9C9383
97907F958F7B96917B9C9481A095849D9583A19B899F97879D95849C9281A29886A19886
9E9784A19C8AA49E8DA49D8DA39C8CA49D8AA69D8B9E96839E9783A19A889D98869C9986
9F9A88A39C8C9E97889F998C9D9B8D9F9C8E9F9C8D9A9585968E7C8C7F6B8A7C67887A64
847962847D65827F6683816A85826E84806F817E6E83837483847786877A8E8E80908F81
959285908C7C938F7C98927D97917A968E78988E7B988B78978B77998B769B8D78998B75
978A7096886D93836A8A796187755F84725D8575618B7D6B8F8574928A7B8B87797E7D72
74766E6A6D6662635E5E5D585B52495C43375E281F6F1712810F0A7E0B027E1B0E560B01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A6692F793717D18076
992B27A52324E06367A5201BA3281B933D2E875A4A7565586E6B5F6C70636F7969757C70
82867C8B8C848C8E86888A8384867D83827B7F7D747C796E8280708A8876948F7D96917E
9D98859A938098937E99937D9A94809C94839A93819A9380958F7A94917D99958198917E
968E7B98917F9A9382968F7D958F7C9994819995829A94819B94819E95849E96859E9885
9995819996819E9A86A19A889C95839C96859F9B889E99879F99899D95849D9584A79E8E
A09A89A09B8C9D9B8A9E9A8B9C998A9C9989A39F8FA19E8EA39F8EADA797A5A1919C9A89
9F9B8E9C988B9B988B9B988D9A9A8F97998B999C8E98998C98988B979587949584979987
949787999F8FA5AE9EA7B0A29CA499979D968E989186938E7C89857D8A877F8A877C8481
808782858A81888C818A8B7E8C8A7B928D7B948D7A9C917EA0947E9F917BA0907B9E927A
9C90789D91789B8D779687719989719180678C7B638B7B648D7E69857763897D6B8B8171
8C87797D7D726F6F686667605D5D5657524853423657291E68170C751709651204500C02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0066CB2F91603EB1746B
A74945AC2B27A526209B32258F4C3B80614F726958706E626F736671786A767F6F7F8376
85877A86867B8180747D7B6F7C7669867E6F948B7A938B79928D7894917A95917C97907D
97917E9A93809B948198907C9B948196907D99947F98917B96907C9A94819A95829B9481
99917F9B948297907E968F7C98907D9B93839F9A8799927F9A93809A93829B95829A9583
9795819A98869A98859B97869896839694829696839795859E9A8BA09C8C9E998CA09A8D
9B978A9D9C8E9B9C8E99998A9E9E919D9F929A9C8E9A9B8EA5A398A9A79CA9A89DAAAA9F
ACACA2AFAFA5AFB1A7ADB0A8ACB0A8A8B0A7A7AFA7A7AFA7A6AEA9A0AAA597A39C9AA69D
98A39B99A49C98A39A98A19791998F848D837F89807B847D77817C727F7D737F7F798584
7C88867A868477837E80888085867B8F8B7C928A789C907E9D917C9F917B9F907A9B8F78
9C917A9E937C9D907A9E917C9C8E789989729A8B739585708F7F6A9889739384707D715F
827968857F6E8A8577827D716D6B605F5D53575247554335552A195F1E0D500E00268601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C6966D7C4030
9033299E2A1F9837278C53437862506D6A5A6A6C5E7072627379687B81707E8472808172
807C6D807869827D6A8F8876948A789387738C7F6B9B907C96907B96927B908C76948D7A
99927F97907F9992809A9280968F7C97917E96927D97917E96907E9D96859B96869B9787
9D99889D98889E9A889E9988A09A8AA29D909E9B8CA49F91A39F8FA39E91A6A092A39F91
A09F909E9F91A3A294A6A6979E9F8FA2A395A4A798A5A79CA4A59BA6A89FADB0A7AFB2A9
B5B9AEB4B8ADB4BAB0B5B9B0B3B8AFAEB5ACAAB2A7B0B7ACAFB4ACB0B4AEB0B6AFB3B9B2
B8BEB8B6BDB7B5BBB7A5ADA9A3ACAA9FA9A898A4A195A09E8794937D8C8B778580758179
7E8780868D84898D818E8F818C8C7D8081707A7969777263706E5F696A5D68685F64645D
5F645F5B65625F6E686F7B75797E778382778F8878968B7A9C907C9E917CA1937C9F927B
9F937EA0927E9D907B9A8D77948770998C76A0917BA3937D978871988B75938876827969
746D5D6B6656726D5D807A6A827C6B777262655F50574F3F513E2B572F1C460E01248601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8BF59804527
782A18914433875645705A4C6B66556C6D60707363787C6A7C806C7F816F7B7967827C69
8A816C8E836C938871968B77978D79998E79998D78978C7A98907B908A71928D7499927F
9C95839893839C9888A09A8BA6A090A8A192A7A495A7A294AAA597A39F92A19E91A19E92
A2A0939D9C8FA5A4989E9C959999909F9F98A2A49CA3A39CA9A79FB4B1ABBAB5AFB3AFA9
A3A39C9899939B9F969D9F9793978E8F938C919590929995909895919E9992A19C9BA7A3
AFB9B3B9C1BCB5BFBAB3BABAB1B9B8AEB7B3AAB5ADAAB2ACAEB6B2A8B1ADA7B0AAA6B0A9
A1ABA5909A968189857C82817D8482727B7967726D5D69625A67605D69616B776B7E887C
8E9488A8AAA0BBBBB1CBCAC0CBC9BFBBB8ADA8A294958E7C847C688B7F6B82705D7A6754
695B49544E3F4D4F42575E566870697A7D728782749187769C917E9E927DA1927C9C8D77
9D8F7A9C8F7A9C8F79968971998C739A8E759C90789D8F78998C75958B77979080817E70
6A6A5D5D60544D5245535444736D5B887E697D735F685E4E584B3B5A402C451606248701
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003AEB1DB07D51
6C3E237F5D486E5B496D6252736C5C7774647A7A677E7D69797864726F5E76725E918874
958A7292856C988C75988D79978F7A958D799A927E968D7A9F9582A39A86A39D88A19B89
9D99889B988A9A988C99968A9C988D9D988E9A988DA5A196A4A095A5A195A6A497AAA79C
A9A69AAAA89CAEADA6B2B1ACB0B0ABB3B2AEB8B8B5BBBBB9D2D0D1E5E1E4E7E0E5DAD5D8
BFBEBEAFB1AFA0A6A4969D9D8C93938893918D9999919D9F8F9E9F8D9F9F96AAA98FA09F
92A09D949D9C96A09E989FA09CA3A29EA6A3A2AAA4979D98949996929893969D95A1A79F
A4ACA4A4ACA4A8AEA8AFB5B0BAC0BBBCC4BDC3CCC6C6CDC8CCD2CCCFD5CEC2CAC2C2C9C3
D6D8D6EFEEF1F4F2F7F5F2F8ECE7ECDAD4D3BBB1A89C8E7F9A8974A78F76A284689B7A5C
8E7153816A4E6F61495953425453486A685C888270918674958A749F937C9E90779D8F77
9E8F799E90799C90799D927B9B90799B90779E947B9C917B978C769289768E897C76766C
646961444E443A453B3E46394D4C3B6D644E8879628577636E604C59442F4E281600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C99D68
755A386C5C42695E47766A577F7462827966827C6478735E6964526864557A7866908976
938975988C76988D77978D79938B76A199869A948198927F968F7D98907F989281979382
989385999287A29B939F9A919F9B91A7A29BA4A198A39F94ACA59AA7A095A6A293A8A295
A49F92A49F92A5A094A09B92A49F95AAA29AAFA8A2B0A9A5B8B1AFC3BABBC1B8BDB6AFB5
ACABAE989A9D8A9396848F957D89907584896E808469797E6778796373745C6D6C657571
7D8A83939F989FA7A1A6ACA7B0B5B0B4B9B5B7BDB8C3C7C2CFD1CED4D7D5DEE0E0EBEEEC
EBEEEDE6EAEAE4E8EBE1E5EADADEE1CCCFD2B2B2B6A5A2A5969093888280736F6B736E6A
7B73738C8287948990978B9294868892827B8D7A698D775F8F75599070518F6E4B8E6C48
8A69438768438368457C65496E5E4660553C75684F9182699C8D75A597809F937A9E927B
9C8F789C8F79998D799B907C998E7A988E79978C77958A75958A77938D7C88867D6A6C69
4A555039483E3C4A3D414D3F474B3C54513D6D664C82765C83735A68553B5D3E2400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007D9D33
6E57306C5D3C786A4D81725A83775F7A6F5A665F496A6451696755666557787868878272
8E8674958A769C947E928B768E8971948E7A97927E999582938C7B958A7A948B7A97907D
9A918096887B9C91849E94889D9789A19E919E9B8D9D95889E96879E95889E98869C9685
9B95849994829994829992819A91819B8F81999080988E839A9087958B83938C85898484
7B7E8161696D5A676E5062694D5C6348595B4E5F5D4F5C5966706C79817C8F9791A6AEA7
BDC6BED0D7D1DBE1DFDFE4E4E5EAEAEBEDF2E9E9F1E7E7EEE2E0E8D8D3DCC7C2CBB8B3B9
ABA5AA9D979B938D928882867E76787B6F6D7D6D677C685F7E685C836C5C84705B8A7760
907F6892806D9B8879A08F80A18F7FA18F79A18E74A08F6E9E8A689B8664967E5D8F7756
8E735095754E98764D93724B8B6E48876E4879633F8C7657A5947BA3967F9E927B9E927E
A0937F9A8D799A8E7B9F97829E937E978B769487749B907F9791828C8A816A6D6B4C5654
404E484352464755454A55454D53455355466C6D587D775E84755A826E4F6A4C2D00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6025
755A3179684584755384765A6B6248504A354F4C385A594763655565675B7A7B6E888576
8A8371978C7998917B8D88728E8C759B96828D8875807A68978F7C9C8E7B9385708F816D
91836C8F7F6993836E918572938B7896917F9590809B938498917F968F7F97917E96907D
9A94809993819994819B93819B93809C95829A927F9A928099917F958E7C888778767871
5A61604551513748483445433F4D48545F5762695E83867A98978CABAAA3C2C1BBD2D0CE
DAD8DADBD9DECECAD2BDBAC2ADA9B1948C94837881776A717B6C6E7F6E6E7F6D68836F65
8C77688E7868957F6D947D68987F69997E63977959987955987852947854917A5A988666
9B8C6C99896B9E8D72A09177A2947C9D90799F947C9F957F9D947D99917D908A77807968
7A6F5C856F509B794F9F794C9D794B9978488E6F457F6443A8947AA59680A1937DA4957E
A1917E9D8D799C8D788E81688B7C628E7D65887866877C6F8C8A83686E6C4C5758475552
46544C4B584B4E5B4C50594B535A4B596253737B6B9394817D72588F7A5B7B5B3800FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0C7D551C
81643D897551887A586C61444D4A2E4A4A33484A364B4D3D55584A5B5E5374756B818073
86816F958B799C917E8C8571928E7998927F8B8572938A7691856F84755E8E7F669F8F78
8F816790806794846E998B78978D789089758D8774908776938C79908876958B78978B77
958974928873958B77988B779A917B9C927F998F7C9D9480948C79938C7B858677686E64
535953404742444E43545B4E646959979989837F6F92867791837484776C7D70667E706A
7D6F6E7C6F6F7D6F6E80726C81716B87756C8D7A6E8E7B6A957F699B8066A185659E825E
9F8461A99072A99074AA9072AC9370A98F66A284569D7C4C9E7F51836C4882765F877F6D
8D8571918872958C779A9581ABA695B1AB9B9B96889190858C8B8282847B787B7270746A
6D6C5E7261459C7A4F9F7644A37B479F7845967344876944A18A7097856E98856D947F67
927D658C775D867257816C517D6A4C796A50756A5877756B6268644B59594857544B5851
4F5A50505C50525F525662545C6759616D5F737F7393998B95927D8774578C6A4100FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310835F2B
8C6E488C785673694A5550354B4C314B4D364D4F3A4E4F3D4B4E3D5052466263597F7F75
8A877A8D84729C917F988E7C9993809D96849189759E937D958B738A7C639080669A8A71
9A8C7294846B8B7A638C7A6390806792856B968970988B7395897194876C96846999866B
99856B98856A98866B98856B99886F9D8F7A9F917D9F917D998C78988E7C8A85736D6D5C
5B5A4A6360526F6B59746F5B7B755E887D66817158826C538870548D7458977F629D856B
95836B8D7F6B948573AB9D8BC5B7A7CABCADB2A39192846B8A7A5D9A8361A289639A855F
8E81627E76627F7766867C68968971A99776A58B6098794A9C7E51816F4E69665671746B
76766B7F7E7286867A949288AEABA2BEB9B09B998F8F8E8786857D7C7C72787A6D6D6E5D
6660487C6743A68453A27A44A97F4AA37A45997342987B549C8467927B618E775A897154
877151826E4E7F6E4E7F6F537F725A7F7967707366555F584C5A554C5C544E5C53535E53
5861565961565763565B675A6570636E7A6F7480768D968BB1B0A1816F5494704400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047B110916E3D
9477518471526E684F53523E4A4D364A4E374D503D4F51414F50415153455355495D5E57
7979708683778A85759C958496907D948D7B9C94809D937EA59A858E816B95856D9C8C72
9B8D72988A70847157978167A38D73AA977CA1927395876B95866A958564948361958161
9681619881629781619781629984699A88719989729D8C769F8E799E8E78988B73766D54
7E73598274597D6E4F7F6D4C8874519B8361A48C66A28963AB8E67AF8F6AB0926DAA8F6A
968160908168A19581AFA391BCAFA1B6ABA0A19689998F7B94896E96886C938669928B6F
91927D6D7468787F7593978A736F5F796A50AB916B9B7A4C99784A96805B544F3A696D63
84867D807F738783778E887DA0998FA49D919993868E877B81796B6E6A5A62614E66624B
8576569A7F53A3814DA37B46A77F4AA07B489D7E51947E5A8976598B785E8C795E917F64
96886C9B9076948D75898573858378666B6257615A52615B526257536153535F52596656
5D685A60695E606B616772676A746A757F77737E768D948DACA99B836F5498724200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3742C987441
93775283755A7C7B695156474C52404E54424F54444F544550534555594B54594B515449
5659526F716A7E7F748685788F8C7B97907F938B779D9581A69A889D918090846E94876D
97896E9D8E769C8C728C7A609B8971998A71A5997DA2967D9C8F77988B6F998D6E9A8E6F
9C8D709D8B719D8C6F9B886A9B896D9B8A739A8A719B8B729D8E74A1917A9D8E74847356
8E7855896F468D70429C7F51B5996EB6966EB59770AD9069AD9069AC8D6CAB8D6CAD9170
AA9273A590789E8F7B9E92829E94839A938298917F9B957F99947C9490798F8C76949581
A5A8989EA3979DA29698978B746B5A847054AD9269AE8C5E987442A2845A78684C5D5647
736E60786C5A8776608D7F68968E79B2AB99A29E8E8C8779837D707771637E7B68857C62
8E7A569B7E509D7D499B79479C7D4FA88E66AE9C7DA89B81A69A84ABA08DAFA696AEA798
A29E8E9391838384786D71686067625C65605D69625C695F5E6B5C5F6A5A5E695A5F6D5D
626F61646F6468746B6A776D717C7376817979847E8E928B9A93848E76569F753C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB8169D7844
917753857C657F817462695C545A4D515749535C4B50584752594A555C4E565E4E555B4D
545A4E5A5E57686C648788819293889491838C87769B95829F9786A9A292A8A38F9D967F
988D77988D799F9581A99F8B9E937E988F7BA39B87ACA593ADA593A39A88A7A18CA69F8A
A49E89A39A86A29682A1947E9E927A9B907C9B917C9D937A9B93799F957E998E76857254
8B6F4891703FA3824EBB9D6DAF956BAB8F68B2926CAC8C66A88962A48866A088689E8568
A186699E866F8C80708F8A7E88887BA6A897A1A191A9A998BEBEADC1C1B1C0C0B0B5B3A4
A09D8E91918280807079725E8D7A609C825EAA8C5FAC89589F7944A581519F845F89775D
968771A59178AC9378B5A289D7CBBCFDF8F3DFDDDA928F8A7169606A6051746951897858
947B54967C519B8255A68F68B6A586B4A891B2A998AFA89AAFA99EA8A59D98989194958E
86898071766C646B5F626960636964636B64626C64616A61656E626971656B7569657368
63716768766D6E7B746E7A75727E797B857F878D8795928A897B6795774D7C9A2900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051B9169B7741
8D7853827B657E7F746E7369596055585E51555C4D51594A565F50555E4F535B4D595F52
585F52585F535A615963656074756F8D8D859595899493859A97879B98899895859C9586
A39C8CA59F91A8A393AAA494A09A88A9A291A6A090A49D8F9E97879D94869992829A9382
989180A1988A9990829C93839B947F99907F98917E97917B97927C99917E9E9683AFA08A
A68F6FA1835AB4986DAB916AA68F69A58D67A98B66BB9670B7926B9F8362978265937D63
9F8368A58A727368597E7C74868882A9ADA4B5B9AFAEB0A7BBBBB4B5B5AFAFADA79B978D
817B6E7671607B745D827356967D59A4875DA78859A78552A47D49A47F4DA384589A825C
947F5E9B8264AB8F72A68E79A9968DB6A9A99A908E897E738877658B785E927E5F9F8868
A89272AD9B7BBAAE92B6AC96ACA697ADA89DABA99EA2A199A6A6A18B8C887C807C6F736F
676C65666D636A73666A7167686E676E756E6C766E6C766E6D766E6E766E6D787068776F
6879716A7A746F7D79717C7A7B8482858A858D8D858A7F718E76599C763F2ADD0C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BF1A9E7840
A18C67877F6A7E807270766A626A605F665B5A6156575D53596256505A4D555F515C6357
5A62555A65565B67595E635A63645E66676273756E898B82A19F97ABA89FA9A59CA39E94
979388919084918E81969284989584A09B8DA39F8FA39D8EA9A393ADA596A7A190A6A08F
B1AA99B0A69BABA195A89E90A59D8AA39B8A9D9886A29E8C9B96849A93829891809F9685
94826C8D7254967B579E845FA28B66A08965A78B68C19A77BE9776967D618F7E65937C67
9B7E67B0917A9A86768C817AC2BEBBD2D1D1C6C7C4C8C7C5C5C0C0BBB3B4AFA5A392887D
8A7F6A88785D917B599C8057A18256B19469B3986EAA8E62A68659A28356A3885BA48D62
A089639B82619C83649B856A9785719786779A89769B896F9A846AA59277B5A38AB8A993
BEB19EB1A999B0AC9EABA9A0A3A39D9C9C9794958E888C84767B7570736D70746E6D726C
6F766D6F776C767E737980767F857D79827A737F786F7D756D7B74717D766F7D76677A73
6C7F7A72817D7984807F8683888A868A8A81857D7085735B98774B56BF2000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A1773B
9C845E9187707A7C6C73796B697267646E655C655A5F655D5A6357545F535761555D655A
5D685A606C5B636D5D676D626568606668626669636669646E6E697D7B788C8A869E9D96
A3A39BA2A197A5A397A19E91A19E909E9A8D9894889994869B96869A95859F9A899F9B8B
A6A090ADA598ADA498ADA499B2AB9DAEA99CAFAD9FB9B7A9B7B2A5B4ACA0BAB3A5B1A999
A699849681648F7853957D549781589C865FA08663B08F6FAE90728F7B628A7A628E7A65
947B649A7E679D8571978679C0B5AEBBB3B0A09893958B858E807A8C7A718B7667907B63
927C5C96805A987C539B7F53A0875DAA946FA89574A99677AB9677AE9A79B0A07CAD9E7C
AB9D7EB1A386AEA086AFA289B0A58CB9AB94B3A48CB4A58BA89A82B1A593B2A99BB6AEA4
ADA79EABA79FA3A29C9899958A908A7E847F7E837F787D78747B73797F777B7F777B8077
7A8176838B7F878E84898E87868C8478827B737F7A76847F71807B71807A75857D71837C
6F817D7787837F89858589838989808B857785745D94764E7F9E3300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA1A
947647AA9C807C786571736570796B6C766B636F65636E655E6A5F5E6A5F5B665C5F6860
626C60656F626870646C7369686E64676A62676D63686F66686D64696B64696B646E7169
797A7489888298958E9E9B929F9E93A7A39BABA69EA4A1979D9D8DA0A08E9E9D8A989584
9994849D95889D96899B9589979385908D7F9390829690839C9486988D819A90829A9180
989078968C6F998C6A9C8C6695835C98855F9884609781619A866893836884765C8A775E
917C61957D6297836897866D9E8E7A9E8F7DA2927EA79680A89780AA977FB19B82B7A384
B8A582BCAB89C2B190BEAF8FBEB092C3B99EB7AD97B2A994B4AA96B8AF9BB8B09DB6B09C
B4AD9AB8B1A1B3AB9CB2AB9BAEA593BDAF9FBAAA9AB9AB9AB8AA9DB5ACA2ACA69EA6A19C
9E9A9693908B8A8A86878984858A8480857F82858381848283888281877E80857C868B83
848B818E968C8C938D858B88828B8876827E74807B7884817884817C87827D89827A8882
7E8B8884908B8890898B8D85807A6D87775F96754E79982D00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9F75389A7F5B8C7F686F6D5C727668787D72717B736A756D626E66646F66616D64626E65
6672686772676973696E766E6D766C6E736A6E74676F776A6E7669696F636D70646D7065
6C70676F716B76777175766F7C7D75817E79938F8B999892999C91A0A297A5A69AA8A699
A9A799A9A499A9A498A7A296A7A396AAA697AAA797AAA595A59D8DACA292A79D8CA39C88
A7A289A5A086ABA58BAEA58EB2A68DB0A389B6AA8EB9AB91BDB095BCB397BCB598BBAF93
C3B698CBBCA0C7BB9FCBBFA4D4C8AFD8CCB5D8CDB5D9CEB4D7CCB3CDC1AAC5B8A1C6BAA3
C4BAA3C7BEA9C3BBA7C3BEAAC4C1ACBFBCA9B9B6A6BCB9A9BBB8A9BFBCB0B9B7ADB8B7AB
B6B5A9BBB8AEBCB6AEB9B1A7C3B6AAC8B6AABFACA3B7A59DA699929F96909A948F938F8A
98959195959192938E8F918C8D918B9295909192908F918F8F948E8A9089888E87898F88
888F8889938D86908E828D8D808D8B7A89857C8B857F8D86828D89858D8989908B87918C
8B93908D928F94958E8C857788745B95714786A33700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2CDF0F99713A987F5B887D687B79697E7F747E847D777F7B707B756C767063716966736C
63716868736B69766C6F7A726F7A706D7568707768787F72787F71767C70777B6D74786A
72786D72766F70766E75766F73756D74756F7979747577727C817B83878291938F91928C
9FA097A5A6A0ABABA5B1AFAAB3B1A9B8B8AFB5B7ADB6B7ADB7B7ACBAB7ABB5B1A3A5A190
B6B3A2B4B2A0B5B2A3B6B1A5B7B2A5BBB6A5C2BDABC3BDABC3BFACCAC6B2CAC6B0CCC8B2
D2CFB9D9D2BFE1DBC9E1DCCBE4DFCFE3DECFEAE5D6E8E3D5E4E1D1E1DECFDAD5C7D7D2C4
D5D2C4D8D6CAD1CFC3CACABCCDCEBFCCCEC0C8C8BDCACBC1C5C7BEC2C4BEBFC1BCBCBDB8
BBBDB6B3B4AEB3B1ABB2ABA2B8ABA2B8A89EAF9F97A69993A49B95A29C979C97929B9792
A3A39D9C9E98969A959DA09D9B9F9B939795969997959A978A928C8E97918E98918E9690
88918B87928D86949182918F82918F83948F84948D7F8F8784908B8C958E8D948D929790
93959094918A8E82728E7756A1794729DD1000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDF0F9B753B957C579A8D77908E8085898080878279837E75807B6C79726B7770
6B776E6D77726D7871707B74707D73737F71737B6C7D8377787E727E8176808378818478
84887E7C817A72786E73776F72796F7579727478717279726F7771737A76747876787975
7B7D797B7F7E7D8183828787888D8B8D94939BA2A1A6ACACAEB4B2B0B5B0B7BAB3B3B6AD
B4B6ADB5B9AFC0C1BBB9BAB3B8BAAFC0C2B4C3C6B8CDCFC2C8CBBED3D5C6D2D5C5D9DACC
DFE0D4E2E0D7EDECE3F4F2EBF8F6EFFAFAF3FAF9F4FBFAF5F6F6F0F0F1E9EDEDE6E8E9E2
E5E6DFE3E5DFE1E3DDE3E6DFDDE2D9D5DCD4CAD2CCC6CDCAC1C9C6C7CECDBCC1C2C2C6C6
B0B3B2B8B9B7BABAB5BCBAB2C3BCB3BCB3ACB7AFA9B9B6AEB7B4AFB5B3AEB1B0AAA9A9A3
AFB1ABA5A7A4A3A7A6A0A6A59FA6A59BA0A0979C9B99A09D939D99929D99939D9B919B99
8A94928894908C98948B99958B99948F9C98909C988A989386918D929792979A9396968F
958C808B796192734982A33700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE2107294289A7F57A498819898898B8F85888E87848D877C878078847C
77837A707975737D7979868076847B79857B717C707A81787F847C7E847C81877F878E85
8C91898E938D797E76767B74787E76747B73737D737682787580787C868178817E7E827F
7B817E767F7E7680817B85887783857C87898491928591938793948E999A95A29E98A3A0
9EA8A4ABB4B0ADB4B1B1BAB7BBC4BBCCD4C9CFD8CFD0D9D2D8E2D8DEE6DCEAF0E7F2F4EF
F7F9F4FCFCF9FEFEFCFEFEFDFEFEFCFEFEFEFEFEFEFEFEFEFEFEFDFEFEFDFEFEFCFEFEFC
FDFFFDF5F7F6F0F1F0EAEDEBDEE3E1D9E2DFD7E3E0D4DFDED8E2E2D2DCDEC4CDCFCDD4D5
CACECDC6C9C8D2D4D1D2D2CDCDCBC5CAC8C3CAC9C4C3C5C0C4C8C3BEC2BDB8BCB9B4B8B5
B4B7B5AAAEACA6ACABA6AFAF9CA6A59BA4A3A0A7A69CA4A2959F9D939E9E949F9F95A09F
8E9A998E9A97929E99929C99939E9B929C99919A978D948E8E938D97958E978F838F7C67
9476527A9C362DE11300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0050BC1E9B7C4DA59377A0988792908691948C8A938A848E86
838F85818B857E89867C8B867A8982808C8577817A7C837F7E85827F8883818B8587918A
89928A8C928C898F8885898380857F7A817A818C837D88808A958E929C98828C89878D8B
7A83817A83837C86877B86898693948B999A8B99998795968797968D9B9C91A09F99A5A6
9FAAA9A8B1B1B0BAB9B5C1BFC0CEC8C5D0CDCAD4D1D7E1DFE1EAE7E3EBE8EBF0EFFBFDFC
FDFEFDFEFEFEFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFEFEFDFDFEFDFDFEFDFDFDFDFEFEFD
FEFEFEFCFDFDFBFBFCF5F8F8EAEFF0E3EAEAE3ECEBDCE6E5E4EEEEDCE4E5D0D9DAD7E1E1
D2DAD9CFD6D5D6DBDBD8DADAC7C8C6CDCECBD1D2D1C9CDCBC1C6C4C0C6C5BAC2C1B5BCBC
B4BABAAAB2B1A1ABAAA5AFAE9FA9A7A2ACAA9FA9A79FA9A89FAAAA96A1A299A5A598A4A3
9AA5A395A09D99A19F979D9C9097959095928B8C868C877C8A816E88765B92744D7C9D38
2EE21400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002EE213799C359B7D55A6947AA299889A988B909488
8B958A8B948D727D757E8B8488948E87928E828E8A828B897D8786848E8B89948E8B9691
88938E8E98938C95908D938E939994949A95939C968D9794939E9B9CA5A49099989EA6A3
98A19F7D88877D898A8490908F9C9A919D9C939F9D94A1A094A1A098A5A49AA5A5A8B0B1
B0B8B7B7BEC0C6CFD0BECBCAC6D3D2D0DAD9D7DFDFDBE2E4E3E9E9E7ECECF3F7F8FCFDFF
FEFEFEFEFEFEFDFDFDFDFDFEFDFDFEFEFEFEFDFDFDFDFDFDFDFEFDFDFDFDFDFDFEFDFDFE
FEFEFEFEFEFEFAFBFAF2F4F4EFF4F4E8EEEEEEF4F4E2E8E8E1E7E7E0E5E6DAE0E2D6DDDF
DBE2E3D8DFE0D9DDDFDDE0E1D7DAD8D2D5D3D5D7D7CFD2D1BFC3C2C2C6C7B9C0C1B6BDBE
B8BFC0B2B9B9AEB5B5ACB5B4A8B1B0A9B1AFA6AFAEA3ADADA5AFB09BA6A7A0ABAB9CA6A5
9FA6A59A9E9E939395918F8E89867F8C847886776189724F95764452BF2500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DE113799A3498774F9C886A9E957F
9B9A8A98998D878B808A92888F98918F9793909A988F9A9888949189939286918C919B99
8F9B988F9B9A909B9A8C9695949C9A9AA29F98A19F9AA3A39EA8A7A0A9A98F9A9A949D9C
A1ABA787948F82928D8E9D9997A7A2A6B1AFA3AEABB4BEBDB7C3BFB6C0BFB5BEBEC5CDCC
B5BCBCC2C7CAD1D8DAD4DBDED8E1E3D9E1E0DBE1E1E5E9ECE4E9EAECF0F1ECF0F1FAFBFD
FFFFFEFDFDFDFEFEFEFDFDFEFDFDFEFDFDFDFDFDFEFDFDFEFDFDFEFDFDFEFDFDFEFDFDFE
FEFEFEFCFCFCF0F0F1F3F4F5F1F3F5EAEFEFE9EEEEE8EEEEE3EAEAEAEFF0DDE2E4DCE3E5
E4E9EBDEE2E4DCE0E2D5DADAD9DEDECCD1D1CACFCFC9CECFC4C9C8C5C9CBC0C5C7B4BBBB
B5BBBCBABFC0B5BABAB3B9B8B0B5B6AAAFB1AAAFB0A9B1B2A9B2B39EA7A89EA6A79A9FA1
9797978F8A858C7F788D79698D73589A78507C9F392CE11300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050BC239E7B4C
947C589D8B71A094809B95869C9A909A9B96999D9A929995949C99969E9E949C9B919A9A
949F9D97A4A3899797808B8C949F9E96A1A19BA6A4A0ABABA5AFAE9FA9A97B87867D8889
A1ADAAA2AFAA92A19A929F9B9DAAA6ABB6B4B9C2C3C5CFD0C8D3D2C5CECECFD7D8D7DFE0
CAD1D1D7DBDEDEE3E5D4D8DCD4DADDDEE4E4E1E7E7E7EBEEE8ECEDE7E9EBF1F3F3F7F7F9
FCFCFCFFFFFFFEFEFEFDFDFDFDFDFDFEFEFEFDFEFEFDFEFEFEFEFEFDFDFEFDFDFDFDFDFD
FEFEFEFAFAFAF7F7F8F3F3F5F2F5F6EBEFEFEDF2F3E6ECECEAF0F0E9EEEFE0E7E8DBE1E3
E6EBEDDBDEE1DDE2E3D5DDDCD1D8D7CED7D4C9D1D0C8CECFC6CCCEC4C8CBC3C9C9BBC0C0
BCC1C1BCC1C3B8BDBFB8BEBDB0B5B6AFB3B6AAAEB1A3A8AB9EA1A4A0A0A19A97938F877F
8B78698F73589D79534CB9255CC52900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB921A17C4D9A7C5B9D866DA1927FA2998B9E988F9A98929897969B9D9B9CA2A0
9BA2A0A1A9A88D9896818B8B9CA7A69DA8A7A4AFADA4AFB0A6B0AF9FAAA7838F8A7F8B89
A2AEACB3BEBCB2BEBBAEBAB7B7C2C2BDC6C7BDC6C9C3CCCFC7D1D3C8CFD2CFD7D9DBE3E5
D8DFE1D4D9DCE1E7E7DDE3E4DCE3E4E3E8EBEBF1F1EAEEF0F3F6F7F1F2F4FAFBFBFDFDFE
FDFDFDFEFEFEFEFEFEFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFDFEFDFDFDFDFDFDFDFDFDFD
FFFFFFFCFCFCFCFCFCFAFAFBF3F6F6F3F5F6F6F8FAEAEEF0EEF2F4E9EEEFE1E7E8E1E7E9
E1E5E7DDE2E4D5DBDCD4D9DAD0D6D5D3DBD8CED3D2CDD2D3C9CED0C3C9CAC6CCCBBFC4C3
BDC1C3B9BDC0B3B7BBB3B7B8B3B6B6AEADABA4A09D9C959091857A8E7A67967A5CA38054
52BF282FE31600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0062C92C51BB24A47D4D9A7953997E61A08B76A29184A1958AA49D95
A29E98AAA6A4A8A6A2A7A8A5A8ACA8A6AAA8A8AEADABB2B2A9B1B0AAB3AEA4AFA8A9B3AE
B0BAB7B2BABCB5C0C1B3BDBFC0CACBBDC5C8BCC6C8C1C9CDC7D0D2CBD0D4C9D2D4D6DFE1
D1DADCD5DCDEDBE4E3DFE7E6DDE6E4E7EDF0E8EEEEEFF3F4F4F6F6F7F7F7FEFEFEFDFCFC
FEFEFEFEFEFEFEFEFEFDFDFCFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFEFDFDFDFDFCFDFDFC
FDFDFDFEFEFEFEFEFFFCFDFCF7F9F8F8F9FAF4F5F7EFF0F3EAEEF0E7EBECE3E8EAE3E7EA
DFE3E5DCE1E2DBDFE1DCE0E1D8DDDCD2D7D6CDD2D0CDD1D1CCD0D2BFC4C5BDC2C5BCBFC2
B1B3B4B0AEAFADA5A4A79C959E8F7E99836A9B7F61A47F584EBC2A5DC73034E71900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC42982A23DA881559C7A559A7C5E
9F886EA5907CAE9C8BB1A397B1A89FB3ACA8B5B1AFB3B2B0B3B2AFBCBBB8B7B9B4B5B7B2
BBBDBBB8BCBDBDC3C5BABFC3B7BEC1BBC1C5BFC6C8BFC6C8C3CACBC9CDD0CBD4D5D0DADA
D0DADAD5DBDEDAE0E0E3ECEBE0EAE9E7ECEDE9EEEEEFF2F3F5F7F6F6F6F5FCFCFCFEFDFE
FFFFFFFDFDFDFDFDFDFEFDFCFEFDFDFDFDFDFEFDFDFEFDFDFEFEFEFEFDFEFFFEFDFEFEFD
FEFEFEFEFEFFFEFEFFFEFEFEFBFCFCF7F8F8F8F8FAF2F3F5EFF1F3E9EDEDE7EAECE4E8EC
E2E5E9DEE1E4D8DADED9DBDED2D6D8CDD1D3CACBCBC3C0BFBAB7B3ABA69FA0958DA19185
9A8673998067A07E5E7CA04354C12C63CC3235E71900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE315
57C1274EBB24A98151A27E59A18262A58A71AC9682B29F8EB8A598BEADA1C3B5AAC7B9B3
CABDBCC7C0BFC4BEBFC1BCBFBDBBBDC1BFC2C7C7C7C5C6C4C9CBC9D0D3D3D1D7D6D0D6D5
DAE1DFDBDFE0DFE3E4E6EDECE5EDEBEBEEEFF2F4F3F7F7F8F9FAFAFBFBFBFDFDFCFDFDFD
FEFFFDFEFEFEFDFDFDFEFCFDFEFDFDFDFDFDFEFDFDFEFEFEFDFEFDFFFFFEFEFEFDFDFEFD
FDFEFEFCFCFDFDFDFEFDFDFEFCFCFEF6F6F9F7F8FBF2F3F7EDECF0EBE9EDE8E6E9DFDBE0
DAD7DAD2CDCFCAC3C2C0B6B1B9AEA4B0A195AD998AA28B74A28666AB8A6282A54757C22F
61CB3468D03400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005DC52B54BE28BA8D5A7E9F3FAA8158AB8563B59075
B59380B49686BBA193C4AB9FC9B3A9CEBBB3D0C3BAD7CCC3D8D0C8D8D2CEDDD8D6DCD7D5
E1DFDEE7E6E9E6E7EAE9EAEDE7E8EBE6E6EAEEEDF1F9F8FBFEFDFFFFFEFFFEFDFEFEFDFF
FDFEFFFFFDFFFEFEFFFFFDFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFCF9FB
FCF8FAFBF6F7F7F1F2F4EDEEEEE5E5E4D9D7DBD0CCD0C2BDCDBBB5C4B0A7BAA497B39A8A
AF947FAC8F76AD8D6FB38E68BB916259C63262CC3768D1376BD23300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0037E81A6CD036
66CC345FC63159C22E55BF2D55C03052C03280A84DB3916CAE8E6DAF9075B2967FB79D87
B9A290BBA698B8A799BCAA9FC8B6ACC6B4ACD0C0B8D3C2BBD8C8C0D6C6C0D5C6C1D8CBC7
D8CAC8D6C7C4DBCBC6DAC9C4DBCAC4E0CEC8DECBC6D8C6C1D5C2BDCFB9B5C9B2AAC1AA9E
BBA393C0A492BB9E88B99B83BB9B80BC9979BF9973C0986D5BC8375DC93663CD3967D038
6CD3396CD23637E91B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0106283 0.488926 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0106283 0.732558 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE1152FE11600FF005DC32B
5CC42D5DC52F5AC42E88A645B8895CB8885C5BC533AF875FAF895FB08C60AD895EAF8960
B0885E59C533B18860B0875EB1885F58C43359C4335AC53400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002EE1165DC22C5CC52FBA8A5DBA8C60BA8B62BD8C65BC8F68
BC926DBC9472B89472B89676B9987CBB9A82BB9E8B988579887D73A194829889758F7E6E
A99686BDAA98BDAB9ABEAD9CC2AF9BC3AD99C6AD9AC4A9976ADD5767DC5466DB5361D64E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32C
5BC430B6885E89A84AB98F65BA9068BD9773C29F7EC6A488CEAD95D5B29BCDA991CBAA91
CDAF99C5AC9AC5B19EE0CFC1D1C6C2A8A0A1CCC4C75554632C364F76808DC7C9CCAFB3BA
9CA6B4B9C6D5BAC9D5778994CCD6D8D9D7D3D9D3CEDBD4CFDBD4CFD9D2CCD6CEC8D5CDC8
D7CEC7D1C9BDD1C5B8CFC2B49ACF8769E35F68E05B67DD5863D8525DD14957C83F51C136
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32D88A5445DC734BA9168BE9977
BF9B7FC8A68CD2B298C8A992C4AA93E3CFBBE7D5C8DAC6BBDBC7BBDCC9BBCBB6A7C8B3A5
E1D2C7E3D9D2D3CAC4D9D1CCB8B4BA676673B8B4BAC6C2CBABB2C6A6B4CCC8D7E8AABCD2
223D661B3C696683A75069858D9FB3CCD5DCD3D5D5D5D6D5D3D2D4D1D3D4D0D2D2D0D2D1
CFCFD0CECDCBCFCDCBCECDCACDCAC9CDC9C7CEC9C5CEC6C4CEC7C3CAC2BCC6BBB4C4B6AB
BCAB9DB3A08EB29B8A86B36758CB4150C13500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002FE1155DC52D5DC52FBA8C62BF936DC19976C7A386C6A68DE5CBB6EAD7C5
D1BCABCBB3A3E5D3C6E7D6CCD1C1B6DFD2C9E1D5CDD1C4BCC6B6ADDDCFC6E4D9D4D7CBC6
D8CEC9DFD7D3B9B1AEC7BFB9D9CFD0DED8DDCCCACEDCDADFC0C6DA364A714A6388A1B2CC
4E6082354E766F88A7C1D2E7A5B6CBB3C5D5CED7DDD4D8DBD4D5D9D3D4D6CED2D5CFD3D5
D1D2D6CFD0D3CFD0D3CBCECECDD0D0CBCECDCDCECDCACBCCCBCACEC8C9CAC7C6C5C5C3C0
C4C1BDC4BEB9C3BCB8D2CBC6D3C9C1CDBFB6C1AEA2AE968454C43D28DE1900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE116
5DC42E8CA747BC8F64C59870CBA17DCEA68ACEAB94E2C7B4EFD9CBCFB8ACD1BCAFD7C6BC
DCCCC2D2C2B9E7DAD1E1D6D0D8CBC1D0C2B7D9CEC5E3D9D1DBD0C9DED3D0E3DADADED4D3
CCBFBBD4CAC6DFD9D6D7D3CFDBD6D3E0DFE1A9ADB7ACADB8BDB9C87276936D7996BCC8D9
C7D6E7A6BCD46F8DA8A3BFD76B85A14B6B87C3D6E2D0D9DDD6D8DBD4D7DAD0D4D5D0D5D6
D3D5D9D1D4D5D1D2D6CACED1C9CED0CBD0D2CBCFD1C8CBCECACBCFC7C8CBC6C7C9C5C6C8
C4C4C7C7C8C9CBCCCDCACBCCCCCCCDD0CECED0CECDD2CACAD0C2BDC1ACA583AF6829E11E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42E8DAB4BC0926B
C69976CCA284D2AB8FD5B295D9B7A0E2C1AFD3B6A7D8C1B2DCC9BBD4BFB1D1BDB0DFD0C7
EDE1D9E0D2CAD6C7BEDBCBC4DFD3CBDACEC5DFD5CEE7E1DCE8E1DED4C9C8DDD3D2E0D7D6
DCD2D2DBD1CFE4E0DDDCDBD9CDC8C6D2CDCCAAA7B0ADA8B2D1CBCDDAD9E2B3BFD38195AE
ADC4DB4B6580183B642B4E739AB0C9657B94AABECFCEDBE0D3D9DCD1D6D7D1D3D5D0D4D5
D1D5D8CFD4D7D2D6D9CDD1D4CCD0D3CBCED3CBCED3CACFD2C8CCD1C9CBD0C6C6CBC8C7CC
C5C4C9C2C4C6CBCCD0CFD0D2CED0D4CDD0D3CBCDD0CBCED0CECDCECEC9CBCDC4C3C8B9B6
AC979048BE3A24DD1900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC22C5DC52FBA8C5FBB9266C19B77CBA588D3AE93
D3B098D3B29DD7B6A1D9B9A1D9BBA6E2C6B4DAC0ADDAC1ADDAC5B5EAD9CBDFCDC0DCCCBE
E0D2C7DDD0C7DACBC1DFD1CAEAE0DCE9E0DCDACFCCDED6D2DFD7D4DCD2D0DED4D3E9DFDF
E9DFE2D9CECEDBD3D1D0CBC8CDC7C4D3CBC8E7E2E2DEDBDFC9C9CCD4D4DC717C9720375E
6C819DA0AFC46E7F9B6C829DC4D5E7C5D8EA87A0B6B8CFDBD1DADDD5D9DCD5D6DAD4D8DB
D3D6DBD2D6D9D3D7DAD1D5D8D1D2D6D0D1D5CFD0D4CBCFD2CACFD2CBCED3CBCCD1CAC9CE
C2C3C7C1C5C8C7CBCECED3D4D1D5D8CDD2D5CACED1C8CCCFC9CFD2C5CACFC9CBD0CCCBCF
CAC6CCA6A2A9938B8B78675A5883301BD30B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF005AC42EB98A5FBE8F67C39A72C9A07DCDA889D0AE94D4B59DD0B39D
D2B6A1D5B9A4DABAA5D9B9A4D6B9A4D8BEA8DCC3ADDCC6B1DFCCBBE6D7C9DECFC1DECDBE
DDCFC3E9E0D7E8DED6E2D7D2E7DDDAE6DDDBE2D9D5E2DAD6E9E2DFE9E3E2E3DAD8E2D6D7
E4D8D9DDD2CFDBD0CCE8E1DEE7E3DFDBD7D3E0DBD9CED0D579808BB5B7BEB7BAC68692A8
9FADC0CBD9E5D0DEEB9BB0C75B789992AFCE28486A6989A3CCDBE6D4D8DDD6D7DCD2D6DA
D1D7DAD2D6D9D3D5D9D4D5D8D1D4D8CFD2D7CED1D6CDD1D5CCD0D2CECFD3CDCDD0CBCCCF
C9CBCFC7CCCFC9D0D3CED5D6D0D4D8CED3D7CDD0D5C9CDD2C5CBD0C6CED1C7CCD0C9CBD0
CCCBD58081933B425B3942526363637467533CAF2100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
88A44489A749B88E64BC956AC59D77CAA483CCAB8BCFAF94D2B39ACDB199CFB59ECFB5A0
D4B9A4D5BAA5DABDA8DCBEA9D9BEA9DBC3AEE4CFBCE0CDBCE0CDBEDECCBFE0D1C4E5D5C8
E7D9CDEDE2DAEAE0DCE6DAD6E3D9D4EBE3E2E8E3E2E1DBD8E7E0DDE8E1DEE0D7D5DCD2CF
E7DFDDE9E3E0E0D9D6E5DFDCE6E4E0CFCECACFCBC8D8D4D5C2C1C8C6C5C9D9D9DACBD5E0
7189A0668199ACC0D3566D8A11346454759A95AEC87490A7C5D9E7D2DAE2D4D7DCD3D7DB
D2D7DAD0D4D7D1D3D6D3D4D8CED2D5D0D4D7D0D4D7CED2D5CDD1D4CED0D3CDCED0CBCED2
CBCFD2C9CFD2CAD2D5CDD2D5D2D3D8CFD2D9D1D3D8CCCFD4CACFD3C1C8CBC7CACFC8CACF
CACCD1B7BAC6575D71838EA36F7A89878C8FA2989066944600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42F8AA84A
BB8E6ABF9773C29E7BC6A382CDAA8DD1AF94CDAF96CBAF97CAAF96CDB399D4BAA2D1B7A2
D4B9A6D9BEA8DEC4AFE1C7B5DFC8B6DBC6B4E1CDBAE4D2C0E6D4C4E6D5C7EEDFD5EDE0D6
EADDD2ECE0D8EBE1DBE9E0DCE6DDD8EDE6E2EBE6E2E4DCD8DFD5D0E2DBD6E8E4E1DFDBD9
E2DEDDE6E3E1E0DAD7D9D2CCD9D6D2DAD9D9D9D4D3E2DBD9E2DEE0CFCED2C3C2C4B2B6C3
304668223D637D91A8B7C2D67489A88CA7C3CAE0F494AEC57091AAC7DAE8D2D7DFD2D5DA
D2D7DAD0D4D7D1D5D8CFD3D6CED2D5D2D3D8D1D3D8CED1D7CACFD3CCD0D3CCD0D3CBCFD2
CACED1C9CED1CBD0D4C9CFD3CED1D6CED3D7CDD2D8CED3D9CAD0D6C5CACECACDD2CACED2
CACFD3C7CCD1AEB6C28E9CAD90A1B297A7B6A1A9B1ABA5A26E9C521CD20C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0059C22D86A646B58C61BA926BBE9774
C29C7EC49F82C6A386CAAB8DCDAF95CDAF98CFB29DCEB19BCFB29BD1B79ED9C1A6D6BFA8
D8C0ACDCC4B0E1C9B7E2CABAE4CDBDE1CAB9E4D0BCE6D5C0E3D6C4ECDDD0ECDCD4EDDCD4
EBDCD2EBDED6ECE3DCEEE8E2E9E0D9E6DAD3E1D8D0E3D9D4DDD4CEE4DDD7E8E4E0E4E0DD
D6D0CCDBD6D1E0DCD7D9D5D0E0DCDAE8E5E5E3DDDCD7CCCBD7CED093949B9B9CA1D0CED2
B1B6C6A2ACC1B0BBCCD0D9E4ACBED34060857191B26A85A425466CA2BBD1CED7E0D0D4D8
D0D5D8D1D6D9D0D5D8CED3D6CFD3D6D0D1D6CED2D7CBD3D6CAD1D4CBCFD2CCD0D5CCD0D3
CBCFD2CACED1CCD0D4CDD1D6CCD1D5D0D5D9CED3D7CDD2D6CED3D7CFD4D8CACFD3C8CDD1
C8CDD1CBCFD5999FAD293A513E5570364A654153677E8891958C8B8F74651ED41000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002DE117B3885EB88E68B8916CBD9876BF9A7AC29F84
C5A289C7A58CC9AB91CAAD93CFB39BCEB39DCEB49DD0B7A0D1B9A3D2BBA5D8C2AAD9C5AE
DCC7B4DAC6B2DFCBB8E1CBB9E2CCBAE4CFBCE7D3C0EAD7C5E8D9C6EBDBCCE9D7CCE9D7CD
EFDFD6EADBD1E7D9CEE7D9CFE3D5CCE2D4CBE7DCD6EBE3E1E7DEDBDAD0CBDFD7D1DED9D2
DAD3CDDCD7D2E8E5E3E7E2E2DAD1CFE0D7D4D5CCCBCFC4C3D4C9C7DAD5D7D4D0D3CCC8C7
DCDDE2BCC6D3697D948196AA7F92AC1C3B6737587FC0D2E88C9EB49CB3C5C5D8E1CCD6D8
D3D8DBD3D6DBCFD3D6D1D5D8CED2D3CED2D5CED2D6C9D1D3CCD1D5CDD1D4CDD1D4CBD0D4
CBCFD2CACECFCDCFD3CBCFD2CACFD2CED3D7CCCFD6CCCFD5CBD0D4CED1D8C9CDD5CBCCD5
CBCED6C9CCD3BCBECA5F697D7B8BA1576A7E8191A488949FA6AAAFBCB4B2A98E851ED511
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0058C12C57C12CB1885FB9926DB99574BD9B7DC1A183C1A386C5A88D
C7A78EC9A991CEB29BD0B7A0D0B9A2D1B9A5D1BAA7D6BFACD6C0ADDAC5B3E0CBB9DEC9B6
E1CCB9E2CDBCE2CDBBE0CDB6E0CBB5E2CDB9E7D2BFE9D7C4E7D6C4E8D7C6EBD8C9E8D5C7
ECDACDE9D7CAE8D6C7E6D6C8EBDED4EADDD4E7DDD4EADFDBE1D7D2DCD0C8DED3CCE8E3DC
E7E4DEDAD3CEE3DBD7E3D7D6DECDCCDACDC9E9E0DDE6DEDBD2CAC6E1D9D7D8D5D7AFADB0
C6C3C89FA2AF44516E5E6D86D2D6E6A2AAC18998B4B8C9DCB8CCDE496A8390B1C6C8D9DE
D0D6DACFD4D8D0D4D7D1D5D8CFD4D4CED2D5CED3D6CDD2D5CBD1D5CBD0D3CDD1D2CBCFD2
CDCFD4CACECFCFD0D4CDCED2CBCED1CBD0D3CDD0D6CBCED5CACFD3CACFD5C8CCD5CACBD5
C7CAD2BFC2C7CBCCD3ACB3BF8996A793A6B68494A68797A29DA5ACAAACAFC1B7B89A7F75
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0083A243B2885FB68E65B69067B99570BB9878BB997CBD9D82C0A28BC0A48DC4A68E
C9A992CFB199CFB49FD4BCA9D5C0ADD5BEADD6BDADDAC4B2DBC7B3DDCAB8DDCBBADDCAB7
E0CAB7E1C8B8E0C8B8E1CAB6E3CDB7E1CBB8E6D1C0E4D0C0E5D2C0E8D5C3EBD9C8EAD7C8
EAD7C9ECD9CAEAD8C8E7D6C7EBDDD2E8D9CFE6D7CDE1D3CBE9DFDAE7DCD8DDD1CBE5DDD8
E3DED7D6CDC6D6CBC5E5DBD6EBE0DEDBD0CDE9E0DCE7DFDDCFC6C4CCC3C2C5C6CE92939F
C9BAC3EDD7DFDCC7D5D9C2CFD9BDC6DEC6D4675F7C2E3E618198B53551724C6D8CC6DAE5
CED6D9D2D7DACED3D6CED4D7CCD3D6CCD2D5CFD4D7CDD4D6CCD1D4CBD0D4CBCFD2CBCFD0
CCD0D3CACFD2CDCFD3CCCDD1CDD1D4CBCFD2CCCFD4C8CBD0CBCFD3C5CBD1C6CBD1C8CBD2
CACBD3C2C5CCCCCBD39D9FAD2D37504C607B2B415A536779808F9B878F969C9A9FA19492
668E4500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C12C
86A749B68D68B8936EBB9672BF9C78BE9A7ABD9C80BD9E84BFA288C0A58DC3A791CEAF9B
D1B39ED1B5A1D0B5A4D7BCAED9C1B3D6BFB0D7C1B0DCC7B5DBC7B6D8C5B4D3C1ADDBC7B2
DFCAB5E1CBB8E1CABAE4CEBAE2CCB7E2CFBCE7D4C4E7D4C4E4D0BEE6D3BEEBD9C6EAD6C6
E6D1C2EAD8C9EAD9CAE7D3C5E6D2C5E7D6C9E5D6C9E0D3C8ECE2DAE8DFD9DBCEC6DACCC3
DED5CEE2DBD5D9D0CCE8E0DDEAE4E1DAD0CDD8CCC6D7CECAC9C0C0C7C1C771778E7F7B9C
AF7C96C47283CE7082C65F6FB74956B64C5A9F5066513B59959EB4B8C7DB8A9FB4B9D0DE
CBD6DDCFD8DACFD4D8CAD1DAC1C8D6CBCED9D3D0D6CFD0D4CDD0D3C9CFD2CACFD2C9CFD2
C8CFD2CACFD4CBCFD3CACED2CDCFD3CDD0D5CBCDD2CBCBD3CCCED3C8CDD1C8CDD1CACDD4
CBCBD1C9CCD1CBC9D2B5B0BD5E5F756C78904F60778798AA8998A5AAB5BDBCC0C7B9B8BB
B5A29F44B22B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002AE015AA8559B28E65
B8926CB7916EBA9776C0A07FC2A282C1A184C4A38AC2A48CC4A891C9AE98C8AC98CFB2A0
D4B6A4D6B7A6DAB8AAE4BBB0DBB0A4DFBBABD8BDAAD8C1ADD9C3B1DBC6B3D7C2AEDFCAB5
E1CDBAE1CEBEDECABCE4D0BFE6D2BDE6D4C1E8D7C7E9D5C5E7D0BEE6D0BCE9D2C0E9D2C0
E8D3C0EAD6C6EAD7C9EBD6C8E8D5C6EDDCCEEFDED2E3D2C5E1D1C6DCCFC6DCD1C9D7CBC6
E4DCDBE7E0E0E2D6D4DACAC7E1D2CFE1D1CFD7C7C3E2D5D3E6DCDED9D1D987849E463766
8F416CA3203CB6172ABB111EBF0F1CBA101BAB202EDC9AAC9894A8B7C5D96B839E496B89
BDD3E2CCD4DACED3DBB5BFD1464D6E806D8BCAA8BAE0C8D2D5CCD1CECFD3CCCFD3C8CED3
C5CED5C6CED8C8CFDAC9D0D6CDD2D4CACFD2CACFD4CBCFD6CACDD3CACDD2C9CED3C8CCD4
C8CBD1C8CBD0CAC9D2C2C0CA9F9EAE737C90919EB38A9BAA909EA9A1AEB5ABB5BAADB2B7
AEA6AAA68D8400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02DAC855FB18E69B49270
B69271B89376BE9D81C2A488C3A68BC3A68EC5A691C7AA96CCB09CD3B6A2D5B6A3DAB9A7
D9B1A0D5A598E1A89DCD867DBD7166E0A694DBB7A1D6BBA6D7C0ABD7C2ADD6C1ACDBC6B2
E4D0BEE4D1C2E1CEC0E0CCBBE2CEB9E1CFBCE9D7C6E8D3C2E6CFBDE7D0BEE9D4C1E9D3BE
E9D3BFE8D1C1EBD4C6E7D1C3E8D4C4E7D3C4E6D2C4E2CFC1DECDC1DDD5D0E5E1E1D5C9CF
CCB6BFDEBDC4ECBCBFEAB2B2F9C2C3FCCDD0F6C9CDEABEC1F0CDCFDCBFC4C2ABBE513A64
854673A22C4AB81425C50B14CA0B13C80C13B80C18BE4D62503056556285788CAD243F63
9AAFC7CAD5E0CCD3E08E96B138265182355A8B1F3BB0596DD8A0AFDFC0CCD6C5CFC4BBC8
ADAABD8B8AA36C6A83A9ACB7CACED3CED2D7CCD1D7CACED5CACDD4C7CCD1C7CBD3C5C9D2
C7CAD2C8CBD3C7CBD2C9CDD27E8291232F484C5D75394B6160728396A6B098A3AB9EA0A7
948F9497828042B02700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002AE017AB835EAE8867B08D6EB39274B79578
B89478B9947BC2A188B19176C2A38CC3A693C4A695D3B4A1D6B3A0DCAE9EE1AB9BD39787
DE998AB56959EC9A8DBB5E54CA6B5DDA927DDFB49CD8BCA5D3BBA5D8C2ADDBC5B0DCC7B3
E2CEBCE4D1C2E3CEBEDCC5B2DFCAB5E0CEB8E4D1BFE8D3C3E5CDBDE5CBBAE4CCBBE6CFBC
E6CDBAEAD0BFE9CFC2E7CFBFE9D0BEEAD0C1E4CFC2E5D6CCD6CDCDB9B4BFA18EA3AD768F
C16279C85062C7404EC83743CB3847CE4151D04858CF515DD76972DE838FECA4B79E6485
722B53BD5271B51A2CC50C15C7070FC90810C20711AF1C2C95516E5E5B78CAD5E9A4B5C9
95ACBEC3D4E3BEC6D94D45666E3455951C31A3091BA20B1F9A172DA2364BA74C628D425B
7A334F77334E6E30479C7D86D3CED3D1D0D5D1D2D7CECFD4CBCDD2C9CDD4C8CBD2C8CBD2
C7CAD5C6CAD4C8CBD2C8CDD49294A05C6173687386425062808E9D93A2ABAAB3BBBBBFC6
B3B1B7B1A3A891746900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB82350BC2A7CA043AA8662AE8A6BB18F72B19075B3937AB6967C
BA987EC09F87C6A78FBB9A83CAA995CFAC9AD8AFA0DEADA0E5A69ABC655AB64F43D36C5D
D2745FBF654EED927CB85545DD7767C87663E2B29BD5B7A0D5BBA5DAC1ACDBC4AFDEC9B6
DFCAB9E2CDBCE4CCBBDFC7B5DDC8B4E0CCB7E5D1BCE7D2BFE1C9B7E4CBB7E2C8B4E6CBB6
E6CCB6E9D0BDE9CEBEE8CFBEE8D0BEE9D1C2E4D1C7D4D0D58685A17F5A82B35476C03143
CB212AD21F23D21B1DD21B1CD31B1ED21A1ED11A20CE1A22C71823C41E2DC0263ABD2F49
B42C46DB4B5FCB2732C80D13CB090FCC0910C80910B20D15DC7B88A6889C87879F8A93AD
2E3E62757CA16852757A39589C263BA70917B0040FAF030FAB0311A60615A308189D0A18
980C1890151B852E30D3AEAFD3CCD1CECECFCFCFCDD0CFCECBCCCEC9CCD0C8CBD0C7CCD2
C8CDD4C4CBD3C4C8D2C4C7D0B1B3BC9295A07A818D858F98879199879198979EA5A6AAAF
A4A3A9ABA6A9B1A19D43B42B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0047B6267F634992745BA88668AB886BAC896FAD8B72B08F77B09076B5967C
BC9C83C1A38CC6AA95D1AF9CD6AB9ADDA899CA8477AC5448DE7C6EC35B4CC65544D8634D
C95D45D26F56E28069BF5944E27968BA6451E6B09BD7B7A1D9BFA8DBC2ACDEC6B4DDC6B6
DAC3B3E2CBBBE0C9B9DFC8B8DBC4B3E2CAB8E7CEBDE7CEBDE2C9B5E3CAB4E2C9B3E4CBB5
E6CDB8E7CEBBEAD0BFEAD1BEE9D0BEE7D0C0DFD0CC8C90A85B4D7FA94C79C62438D41D20
D21D17D0221ACD251DC92623C32626C42A2CC4282CC22229C21F28C21A25C21823C01421
C01420C2121BC81217CB0B0ECC080EC8050BC7060CBF0910B728349740585C2B4D805579
6432597E375C9C324EA5192AAE0915B3030EB3020CB1020BAF020AAD020AAD030BA90509
A00D0E91241DC48C85DCCCCACFCDD0D1D0CAC3BEA5CBC2A6D0CDBFCDCFCDC7CCD1C6CCD4
C7CBD4C5C9D2C4C6D2C4C7D0C1C3CF6368792E384A64738346586467767E9CA4ABA4A8AC
97959A938D9193878546BC3600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25DB11648D3C5C4D4A272429766C65A38974AA8971AB8A73AC8C76AD9079B0947EB69A84
BDA18BC3A792D1AF9CD39E8FB86A5EDA8272B45845C6604CC9624EEF8F7BD7735ED2614D
BE4C37E0705BC14F37BE5339F08F78AA5540E7AD97DCBAA5DABEAADBC1AEDBC2B1DBC4B4
DCC5B3E2CBB8E0C9B7E0CAB5DEC9B3DEC9B3E5CFBAE3CBB8E1CAB5E5CDB7E3CAB3E5CDB5
E7CEB8EAD0BCEAD0BDE9D0BCE8CEB9E7CDBCDCCCCC5A6183684E86AC3459CD2225D02E21
D04938E17364DB8074C97C76C98585BB787FB5717DB26979AF5F71AC4E61AC4252B03947
AE2A38B32430B41923C01218C60B10C9070EC9060EC4060EBB0A15B81C2CB02437A51C30
A4152AA80E21AD0715B2060EB3010BB5010AB4020CB00209B1050BAD0509A9080A9F0F0D
972A24C4897FDAC7C3CFCECECECED1D3D2C5B7AB7DB8A65DCEC392CFD0BDCACFCEC7CCD1
C9CDD6C7CAD2C6C8D4C8C8D2C7C8D6676A7C585C6F5B67783E505D80919A9DA9AFAFB8BA
C5C8CDB3B2B7B1A9AC85726800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0024DB13
816850403C400E19360A173569676EA08A7AA78973AC8F78AF937EAC927EB49B88B99E8E
BDA291C5A896D4AB99B16B5BBB5646B44835D87A61DF836ABE5942D26755C45743D56A53
B0432EB94C35CB6A4ED7896DEEA88FA45A42E5A891DDB8A2DABEA9DCC0AFDBC0B0DDC4B3
D9C3B0DDC5B2E0C6B7E0C9B6DDC7B1DDC6B0E6CEBAE3CDB8E0CAB3E2CDB4E0CAB2E6CEB6
E6CEB7E8CFBAE8CFBBE9CFBCE7CEBBE6CDBCE2D1D06D6F8F5D437CA3395BC63935EE8570
FDBFADFAD2C5E2C1B4E5CABEE7D0CADAC5C2D2BFC0E0CCD3DCC6D2C4A7B6A9829492697E
8458747C4B6A823F5FA83A4FB5121EC3070FC5040CC7050DC4060EBF0811BB0911BA0A10
B8070EB9070EB6040BB40309B40209B3030BB1050CAB0608A70B0AA0100C9B1F19A64E45
D5A39DDBC9C5CFCECEC9CED0CDCFD2CFD0C8C5BC98B8A255C0AB5CD2CB9DCED0C2C5CDCC
C6CDD3C7CDD5C4C8D3C6C9D3C7C7D59594A38887956C727D7C848A8C96988F979A999EA2
AAABAFAEADB3B6B2B8A496941AD10E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC12765F48
2D2E390D1E42011648031541595B6B9F8E82A88E7AB09681B29A87B69D8CB69B8DBEA294
BDA18FBD9F8ACAA28DAB6D59DD8673B14C39D6715BCE6851C65A45BA4834C0543FE48E74
D1896EDC9C7FDDA98CDAAE96DDAE99BC8770DDAD95D7B69FD9BEAADCC0B1DCC0B1DEC4B2
DBC1ACDDC2AFE2C8B6E2CAB9DCC5B4DDC7B4DFC9B4E4CDB6E4CCB3E4CBB3E5CBB4E5CAB5
E6CAB8E7CCBBE8CFBDE7D1BCE8D2BDE6CFBDE4CFC6A69CAF5547728E516CD27E78F3BBA6
E6C9B6E5D2C3D7C5B5D6C4B5DCCFC5E8DEDADCD1D1DED4D3E8E0E0D7CBCDCAB7B7CEBFC0
C9C1CE9D9AB646436D603C69A12B47BB0C19C70710CA0810C6030CC1040BBD0A0BB6110A
B2110DB0110FAB0D0DA90F0FA80E0FA5100FA01511971C159C332AAE5F53CE9A91DBC2BD
D4CBCACDCDCFCBCED1C9CED2CBD0D4CDD1D2D2D0C2C7BB8DB7A159BFAE69D0C9A3CACDC2
C7CBCEC6CDD3C2C9D1C4C8D2C4C8D4AAADBA52566A303A4D74818B5C6A71869197A6ACB0
A6A5AAA29FA6A09AA292848737A82400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0094725542393E
0A183F061D5601165604184E454E679C908CA79082A89181A89381B79E8FB99D8EB99E8B
B59A83B89C84C09F87C99B85C87E6CB34C3CCC5746AD3B26E57D66C15B46D8735FD4866E
DBA68AD4AA8FD0AC92D0AF97D2B09AD2AF99D6B69ED8BCA6DAC0ABDBC1B0DCC3B0DAC1AB
DAC1AADBC0ACDFC6B3E1C9B8DDC6B3DBC4AEDFC6AFE5CDB6E4CCB5E3CAB4E5CBB4E5C9B6
E7CCBBE7CEBBE8D0BAE4D0B7E4CFB7E2CCB7E4CDBDDBC9C7847784C3A7ADE7C0B3E4C6B1
DDC9B3D8C7B4DECEBED8C6B9DCCCC3EADED9DDD2CDCEC2BBD2C6C1DCCFCED5C7C5DBCFCC
E1DADEE0DDEC888BAD322A6195446DB01327C40912C7070DC8050DC00609BB1911D55846
B75344AE5044A447459F4A49AC5B54B1685DB97B6ECA9A90DAB8B1DAC7C3D3CBCCCECED0
CBCED1C8CCD0C8CDD1CACFD3CAD1D7CAD0D6CDD0D1CFCEC0CFC09BB8A666C1B071D4CDAF
CACCC7C6CBCFC3CAD0C2C9CFC5C9D2C0C4CE40425843455D595F6F525D688C98A1B0BAC0
B6BBC1C3C4CCC3C1CAB3ACB05A894500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC10A6835D937B6D4B475B
06164902175901185E051B5A333D6290878AA69184AE9785AF9783B59A88B49685B3947F
B79A7FB99C80BD9E85C59C84C47E69A43E2AD25B4AC85744E68570CA6A56A4442CBA6D52
D4A285D0AC90CEAD93CCAC94CFB09ACFB4A0D5BBA9D6BDACD8BEACDAC0ACD9BEABD9BEAA
DABFAADCC2AEDFC8B3DDC7B2DDC6B0DCC4ABDDC4ACE5CDB7E4CEBAE2C8B5E5CBB6E1C7B2
E4CAB7E5CCB8E8D1BBE6D0B8E4CEB8E4CBB9E4CCBBE4CEC0DAC5BBDDC8B9E1CBB8DCC8B2
DAC6B0DAC7B6E8D7C9DBC8BBD7C2B5D9C5BBD8C8BFD6C4BCE0CDC8EDDCDBEDDADCD3BCBD
E2CACCE3CCD4C7B0C6553C678A426DB12239C20A16C6070DC30409BF080AAD0D0CDB6B66
8F4C4C916266AA838E5A3D4EC8AFB7E1C8C8E0CAC8DBC9CAD4C9CBD3CDD1D0CCD2CDCED2
CBCDD1C8CCD0CACED4C9CDD1C8CDD1C9D0D2CCCFCECDCFC6D4CDB6D3C58DBBA854CABB7B
D0CBB2C9CCC8C6CACEC6CBD1C4C7CFC8CBD371717F72707F6E717A868C938D949C9398A1
9C9FA8A2A5AFB4B6BFBCBAC18C7B7900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006E973BAF957E917F7B54546B
06174A01155C011764031B6124305B968C94AC9689B19886B19583B0907DB08F78B39178
BA997DB8997CC09F84CA9D87CA806DBE5A44CE5C46A93A24B3563DD68E72D29679D4A587
CCA68ACBA98DCBAB8FCBAC93CCB39DDAC8B8E7D7CCE1CDC2D9C0B2D9BEACD8BDAAD8BFAC
D9C2AFDAC4B0DBC5B0E2CCB6E0C8B1DBC2AADEC7AFE4CDB9E3CBBBE4C9B7E1C8B4E2C8B4
E6CBBAE2CCB9E5D0BCE6D0BCE6CDBCE7CFBCE6D0BBE4CDBBE2CBBADEC9B7D9C9B7D8C8B6
DAC0B0DFBCAFE2BCB1E1B9AEE7BAAFEABBB5FAD0CEFACBCDE6B1B3F1B8BDEEAEB4DB9096
D48288E48F98E6909FAF516BB43A57C62739C10812C4060DC2050BC2060CB6050DBE2932
A32C3B953243B55D707E2E47B36E85D296A4D59FACD9A9B5DAB3BEDBB9C3DDBFC9DDC6CE
DAC7D0D5C7CED2C8D0CEC9CECCCCD0CACCC9C2BDACCDC49ED0C387C2AF51C0A82DBFA938
D3C582D1CBAECCCCC4C8CCCBC4CACDC6C9CE8C8F9D464D60616E7D81919E73828C97A0AA
AFB2BDA6A6B09E9EA69A979F7F6E7000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007CA44BAF98819484749D8F8B4D4D62
0D1F53021962011668031763192654968E96AA9387AE9383AD917FB3937FB49279B59277
BA987DB8997DBD9C80CD9B839A4832A8482DD57F60CF896CD59B7FD0A387C8A489CAA98F
CAA98FC9A98ECAAA91CAAD94CCB8A4E9DFD5E7E0DDEADED9D2BFB4D4BBA9DAC0AED9C1B0
DAC4B1D8C2ADD6C0ABDEC6B2E3CBB5DBC3ABDEC6B0E1CCB7E3CDBBE2CAB8E2CAB6E2C9B6
E4CBB8E2CAB7E4CEBCE4CFBEE5CFBFE6CFBDE5CFBBE3CCB8E2CAB9DCCABCB8B5AFB6B0AF
D5AFABE19590DE7F7CDD7272D45E62D05259D24E5ACB424FC4343EC32E38C22631C01D27
BF1921C31C24C21822BE141FC00F1BC20A13C4070DC3060AC1060BBF040BBD040CB6050D
B10813AA0914A70A17A40A1AA00B209C0D229C122898142B981D339924399D3046A34456
A95566B16877BF8290C599A5CFB4BBD4C8C1B7AB8AB39F57BDA43BBCA21BBEA40BC0A610
BBA528C4B45CCCC28EC8C7A7C8CBBCC7C8C5ACABB32B2E415E6577505C6C4B596895A3AE
AAB1BDB2B5BEAFB2B7B6B7BC998F9118D00F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0079A246A89480A99D919D9388AAA19C595D6F
172B61021A6702156501145D1524518C868DA28A80AA8E7FAD8E7CAD8E79B5957CB7947A
BA967DBA977FBD9A82C3987EC2886BC38666CD9A7CCBA289C8A58DC5A78FC2A690BEA58F
C5AC97C3A991C6A990C8AD93CEBBA8E7DED5E7E0DEE2D6D2D0BBAED4BCA8DBC2ADD9C0AF
DAC4B1DAC3ADDAC1ACE1C7B6E1C9B6DBC3ADDDC3AFE0C8B5E1CAB7DCC8B2E0CCB4DDC9B4
E2CDBAE1CBBAE3CCBCE3CCBDE3CDBDE0CBB6E2CCB6E2CCB5E4CEBADDCDC3787C8A4E5472
A46B82B12B37C92226CB1B1DCD181AD0191CD0181AD3171AD31518D31617D31516D21414
D11312D21513CD1310C9120EC81211C30D11C30C13C3070EC2050CC2050CC1030ABE030A
BC040AB7060AB6090DAF050AAE060DAC060EAD0611AA0611A90814A80714A90A19A00716
9C09179B0C1A950E208D1627842E3BDAB4B5D5C8B8C8BC92C3AE5FBCA228BCA209BBA202
BDA508B8A213B59F28B2A343C3BA77C9C297C2B99E6E665B7370737173797D8388888F96
8C8F97909197949298A1A0A6AB9FA435A82600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00769D40B4A28B9C9087A79D969489819D938E757485
09194D02166100115D0112540D1A457D7882A0877EA7887CAB8C79AE8F7AB5927CB8967E
B9977DB9967EBD9982BF9A80C39A7FC2997EC39F85C2A38EBDA28EB39D8D9C8B7D8D7F73
958A7DAEA18EBEA890C7AD93CEB6A1D8C4B8D9C6BDD5BFB3D1B8A6D8BEA8DABFAADBC2AD
D8C0ABD8C2ACD9C2AFDDC6B4E0CAB4DDC5ADDDC3AFE2CAB8E0CAB7DDC8B2DDCAB1E0CCB4
DFCAB5E2CBB7E3CAB7E0C9B5E2CCB5E1CBB4E1CBB4E3CDB5E3CEB6DEC9BCAEA9B6364066
996D90B22D3DCF1E1DD41912D51A11D31B11D21D12D11E13CF1E16CE2119CB2318C72318
C5231BBF2219C1281EBD291EB62722A11721A61325B80F1BC10710C2050CC1020BBF020B
BB070AB51711AB1B15A41B14A11B149D17139E14129E1212A01111A20F0FA50E12A40B0F
A50A0EA2080DA108119E0914870D19C18286DAC9C5CFCCC2D6CDAFBCA957BCA31ABDA304
BFA603BCA004B39904B19B0DB19D1CB2A02CB29E3A8A783A45423769727B8896A0818F95
A8B0B4AAABB09C99A08D898F8B7C8235A72600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0051BE2AAE9882B8ADA69A9491C1B9B699908DB8AEAE92909F
13204E0B206401155B0214560B18477A7681A38C83AB8D80AB8C7CA98A77B3937FB4947C
B29378B9967EB99781BA9B83C1A187BD9E82BFA188B99F8C9D8B7B82726686766B877A6F
766C65726B61A89C89C5AF98D0B6A0D2B8A5D2B9A8D1B7A3D5BAA5D9BEA8DAC0AAD9BFA8
D5BCA5DBC2ADD9C0AFD9C2AEE0C8B2DCC2ADDBC1ABDFC7B4E1CBB9DFC8B5E1CAB4E1C9B1
E0C7B1E2C9B3E1CAB4E1CAB4E3CCB5E3CCB5E4CCB7E3CDB9E4CEBAE1CBBBD5C7C667657D
81637FB5545CC03226C7331FCA3D27CC482FD2563DD8624DDA6D5DDE796BDF8474E28F7F
E6988BE49C90DF988CDA988AD49A957A4459742E53A82841BA0A17C1030DC2020CBC0208
AF0808D85F54D08075B1756DB27E7A9A69699D6A68AE716AAE6864A95B57A34949A03D3C
A034319928249720219116198B181D90494DDEC7C8CCCBCCCFCDC5C6BA89BAA130BFA50B
C0A402BFA404BAA00AB39D06B39C04B39D06B19B0DA39025332C084B5056505D6B62727C
A8B2BAB5BBC1B1B4BAAAA8AEABA1A440B63500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0026DC11AA8F70B3A49DABA4A3ABA7A79B9797ADA6A6988E8F938E9A
232C5303155502145B021459061448726F819E887FA68A79AA8E7AAB8D79B1917CB2937A
B4967CB6987FB79881B89A82B89D81B99E82B8A08A9E8D7B8274669D8D7EAB9886AC9989
94857B6E6861797368C3B19FCFB5A0D2B8A2D3BBA4D2B9A2D6BDA6DABFA9D8BDA7D7BDA6
D7BDA6D8BDA8D8BDA9D8BFAADEC5AFDEC4AED9BFABDEC4B2E1C9B8E1C8B7E2C9B4E2C9B3
E2C7B3E1C9B4E1CCB7E0CCB5E1CBB4E2C9B5E2CBB7E6D1BCE4CFBAE0CBB8DECBBDC3B2AD
C1A5A3DEAA9FE09C89EAA793E9AD99ECB5A0ECB8A2ECBBA6E7B9A9FDD3C7F1CAC1E1BBB3
F3CEC5EBCCC3CEB4ADBAAAA6D0C0C5B397AC622B51B3435FB60D1BC2050CC3040BBF0409
B2080BBB4140DC9EA255374968647C7A8397657080CDD0D7D0CCD2CFC1C7D7BEC3DCBBBB
D9B2B0D0A7A4C59795BA8482AA70718F6466D2C2C4CCCDD1CBCCCBCFC9ADB9A44BBCA511
BFA504C0A90E8F7B079E8F11AC9E10B7A40AB39B04B09B198B7C337B776474787A858E93
90959B8F949893959A908F94A69FA2806D6800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0078A045BCAB9EBBB3B39E9C9DC9CACC989799CDC9CB91898CBCB8C2
39406102124C01145A011459051348625F7298827AA68875A88975AA8B77AF917AB0917A
B2937CB3947CB7967FB99980BB9C80BB9F85B19D8A7D7164918577A99787AE9985AF9C89
9F9084766F6B69645FBAAA9DD0B6A3D3B9A3D4BAA4D3BAA4D7BFA8D4BCA4D5BBA4D8BFA7
D7BEA7D7BCA5D7BCA6DBC1ABDCC5AFDDC7B2D8C1AFDBC5B3E1CAB7E0C9B7E0C9B7E1CAB7
E4CCB8E1CAB5DEC8B3E0CAB5E1CBB7E1CBB9E0CCB9E4CFBBE4CFBAE3CEBBDEC9B8DCC6B5
DBC1B2DAC1B2D3BEB4C6B3B0B89D9EBF9998D9A7A1EDB1A7EDABA6F4B1B1EDA4A7DE8E90
D08080C48281E0B9BC6460757A7595A8708DAB3E56C32F3FBB0A14C4060DC3050CBD0409
B8070DAD131DB740527C2542572A4DA297B079859B899BB75C648271617D9A768ACCA4AD
D4AFB5D8BABDDCBEC3DEC3C6DCC6C7D3C6C7CCCBCDCAD0D3CBCFCFD1CFB9BAA858BBA414
BDA504BDA7127D6B183D38035B570C9E971BAD9F0CAF9E0EB09F31867F4397987D9AA295
A6ABAAAEB3B5ADB0B3A4A3A8928B9179646600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0029E015AC967EB4ACA9A8A6A9A3A5A8B9BDC0AAABAF9F9CA18E868C908893
40435E031146000F530211570312465B5A6E99847DA08472A38673A78A75AC8C77AD8C75
B2927AB4957DB6957DBB997EBB9C80B99E859A897A736961978B80AA9889A99887A9988A
96898278717068635FB3A496CFB6A0D2B8A2D3B8A4D6BCA7D6BDA7D2B8A1D6BAA3D7B9A3
DBBEA9D7BBA5D6BBA4D8BFA8DCC3ADDCC5AFD8C2ACDCC4B0E2C9B7E1CAB8E0C9B8DEC8B8
E0CBB7DEC8B3E1CCB7E1CAB5E2CAB7E0C9B5DFCAB5E2CDB8E8D3BCE6CFBDDEC8B8DCC6B6
D9C4B6C9BFBE8587977B6A80BA7C8EC86370C94A51C83A3DC93238C62A33C4232CC42026
BD1D23AB2227DC868E957E993E356590476EA9152ABD0A15C5060FC4030BC2050BBC0509
B7060BB3060FAB0614A10A1B931D32B67A879E94A920264C60436B86304D8E192E901826
91212F932E3D9A3E4DA15262A66976C5A7ADD1CCCFC8CFD2C9CECDD1CFB6B6A34DBAA211
BDA503BEA8117C691B100C001519013335028F8814A79A14A99916948614978931928B4B
81805AB2B3A3B4B7B3B7BABCAEACB1998C8F18D10F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A48862B5AEA3B1B1B2A0A2A5C7C9CEA6A9AEC5C6CB8E8A8EC1B8BD7E737D
7E7D950C184702104F01105206134955526A9B8582A28677A28671A78B76AA8E78AC8E76
B09175B3947AB6977CBA997DBD9D82BCA18B8C7C6F766E668F867E9E91879A8E848F8780
817C7A686868696660BEAD9DCCB29CD1B59FD3B8A2D6BDA5D5BDA5D1B9A0D4BAA2D7BBA4
D6BAA4D6BBA5D8BEA7DEC3ADDBC1ACDFC7B0D9C4ABDBC4ADE1C8B3E4CAB7DFC7B6DEC9B7
E0CBB8E1C8B6E4CAB6E4CAB5E2C9B6E2CBB6E0CAB3E1CCB6E4CFBBE1CBB9DDC6B5DBC4B7
D6C7C37E8699505479B57998B73242C81D26D2181ED6171AD71319D8131AD51014D51313
D01312C21815B93637D39BAA3F325E7E4C7BA31C35C10C16C6060CC6070CBF0709B8110F
A80E14A20716AD0717AF0310A60916A43B46966E851C123C7C4C70871127A10614A4030F
A405129E05119B06139A0B198E0E1C8B3943DDC1C7CCCDD1CBCECDCFCAABB39F3FBDA50F
BDA402BEA7127E6A1A1B140324280E33380A807C28575207898317A59B19AB9B14AA9A1A
A39228A092459791679392848D8B8794898831A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF004DB926A59384A6A7A8ABB1B4A8ADB1BFC2C7A7A8ADB7B6BB908A8FA2989D837780
7A7890091345010F5101115306154C504F689784809F8372A58770A78A71AA8C75AE8E76
AF8D70B59378B6967BB9987DBC9B82BB9C898A776C6D67637C7875847E7B827E7B797775
6D6F6E5F6260817C72C6B19FCCB29CD0B69FD3B9A2D2B8A1D4BCA4D5BCA5D0B59ED4B8A2
D5BAA4D6BCA6D7BDA7DBC2ACDAC1ADDCC6B1D9C4ACDAC3ACE1C8B3E0C9B4DFC7B3E0C8B5
E1C9B7E1C8B4E4C8B5E4C9B6E2C7B5E3C9B8E1CAB6E1CBB6E4CFBAE4CFBBDFC9B9DCC5BA
D3C7CA4755775D5F8EAE5E79C1232BD61719DA1312DC1412DC1112DD1315D5120ECF1A10
C61D11BD2012AE291DCB817F75617E4A37689C3A5BB9121FC6080EC5090BB70A07DA5951
B1565E690F2B8C0A28AB0517B104109D0B16AC53684221436A43618422329F0913AA040C
AB030CA60109A5010BA4020A9E070E861219CA959BD4CBCDCDD0CDC6BE9FB49F41BDA415
BDA405BEA60E8A72162D1C05343216141600847E3B302B001B1D00636414A2991CAB9A10
B09D11AD9A18AC9D3CBBB17B9F977F84776B31A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00729D45B0AAA6A3AAAEA5AEB0C3CACDA7A9AEB8B9BDA2A1A4B9B4B58B8383ADA4A7
66667B18255403135301105204124848476097857F9F836AA9895FAD8D5AAD8C5DB59265
B08E64B29171B5957BB8977EBC9982BA9A87967F7567605F6B6B6D7271736E6E6E696967
6667636E6A63AE9F90C9B09BCDB19BCFB59FD1B7A2D0B7A1D3BBA2D1B69FD6B7A2D5B9A3
D4B9A4D5BBA7D4BAA7D6BEAAD6C0ACDAC7AFD9C5ACD9C4ACE0C8B3E1C8B4DFC5B1E0C5B3
E2C9B6E2CAB7E3C9B8E3CAB7E2C9B5E2C9B8E1CAB9E1CCB8E1CEB7E0CFB9DCCAB7DCC8B9
D8CAC7656E8D444E7EB2809DB22D36CF1B1ADA1714DA1310DB1211DA1411D02216EA6753
E88169E1876FDC8C77D5A093B29FAB36335F824774A7172CC20A14C3070DB5090CD66160
C1848D5D3350630E38A00C24B50712AF080FA125309B65793C244081465C8E1622A0040E
A9020CA70008A8030AA3080A9A0E0D8A1718945154DBCBCCCED0CFCDCCBCBFB379B8A536
BCA513BDA70AB59B185F44063F2F052922008D823C3A3205181902292C0777722070660D
A69A18AA9B09AE9C14B6A73AB2A35CA798703FB42800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00967F689D9FA2949FA5AAB3B9B8BDC398999FB0AFB3A5A4A6B6B2B3888382A49B9E
6E6C7D16204B02114F021050020F45424058978377A58756BC993FC39D33BA922FC59D44
BC974FB79462B59374BC9982BC9985BC9B88AD9284726460646163636165656263736D68
84796EA08F7FC5AD98C7AB95CCB098D2B6A0CFB39ED1B6A0CEB49CD1B49DCEB19CD3B9A4
D4BCA9D2BBAACEB9A8C7B5A3CEBEABD5C4AFDEC9B3DDC4B0DEC5B2E2CAB7DEC6B5DFC4B3
E4CAB8E2CAB8E2CCBBE3CABBE2CAB9E0C9B7E4CDBBE3CCB8E2CFB7E1CEB8E2CDBADFC7B6
DEC8BCBBB3C1515D836B678EB67389B52E36CC1C1ED81514DB1412D71411C71F18FB8F83
F3AC9AE1B09BDBB39ED2B5A3C9BBBB5A5C7D5B42749C304EBB0F1DC5080EBC080CAF2225
D2888B8A6A7C42103B870D31B00518B2040D9E0C15B467727862773E2A437E3D4E8D131E
A0050EA60108A304079F1C17BB6058A36359895F5DC7BCBCCCD0D2CCD0D1CECCBDC7BE89
B8A941B9A415BEA50DBA9F179B82164936009A882F4F410E211E031D2200928F4359500E
6F650FA29919A79B0FB3A316AD9A20A08B3746B92000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
27DC13806E628F93999BA3ABBCC1CA9D9EA8B1B0B7A9A6AAA7A3A5B1ACADA8A1A2897F82
8F899711173C020C46020F4C041143434356978369B39440C3A11BC8A50EC7A017BD9528
BE9A46B79359B49170B6947DB7957FB8977FBA9984A1877878655E7A6B6593847A9F8D7E
AE9884C7AD97CAAE98CCB198CEB29BD0B49ECFB39DCDB19BCEB39CD1B69ECDB29CD3BAA5
CCB9A7B5A495AD9B8DAF9E8FA8998ACBBCABDAC5B3DAC1B0DFC5B4E3CBBADFC9B8DDC7B3
E1CBB7E1CBB9E0CAB8E1C9B8E4CABBE4CAB8E4CDB8E7D1BBE5D0BBE2D0BBE0CDB9DFC8B6
E0C9BAD9C7C1BAB4C0626687695F85B27993B3414CC42226D31618D71314D01416C82B2B
E0706AEC9E93E3AD9DD4B4A3DDCDC7A6A6B9332E5F914C73AA1526C00810C1070DAD0E11
D37274BE95A148244A6F0F3AA80820B50310A8050E9D2F35B1878D8579884B344B7F3B4F
89111D9D060DA2040A921310D58D88D7B7B2BEB2AFBCBCBDCBCFD4CACED7CBCDD2CECDC0
C8C08FBAA843BEA518BEA307BDA30CB49C12B59C1D6853102D24011B1B00807D36554E05
58520384801F756D09A59817B2A014A28C1848BB1200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
50BF309A928D858E98A5AEB8B2B7C19B9CA3B1B0B6A8A5AAA9A3A7B1ABB0A9A2A58D8286
A19CA8192042020D45010E4B0311444343549A8554BE9E29C8A70CC7A704CAA613BA922A
B28F4EB08E64B08E71B39279B4937CB5947DBB9882BA9984B69886AF9484B39985BCA089
C6A991CEB099CDB09ACAAE98CBB099CCB29BCCB19BD0B69FD2B7A1CFB49ED1B7A1CFB8A4
B19F8EBEAB99D2BBA8D4BCABC4B2A2AC9C8DDBC9B9D9C3B3DBC4B3DFC8B7DDC8B6DBC8B4
DECCB9E0CBB9E1CCB8E2CBB8E0C8B5E2CAB6E2CBB5E6D0BAE2CEB9E2D0BCE1CFBCE3CDBC
E2CBBADEC9B8DBC9BECEC3C58F8CA05A547393738EBB6778B62E35C91B1ED31418D01318
C61B1FC12E2ED6645FE7A299DCBAB2D1C6CD44466B6444709C2740B90B15C1070DB90B11
B93740B86F7F7B4A6A680F3AA10A25B2030FAF040D971017C3868AD5CAD0938F9F48324C
7D3D5287142399051099081090222ACC939ADAC7CBCCCDD0C9CDD2C7CED4C9CDD5C8CDD0
D0CFC2C4BA87B6A235BDA30EBBA203B9A103B7A008A68F1465510A2E22008A7F2F706510
665E0F7A74205F5704675D0BAEA11DA997127AA71800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
729B457C7A7C697581A8B2BF8A8E99B1B0B7ACAAB09C9AA0B7B5BB9B989EACA3A89C8F95
867D8B33375803104801104E02114342434A9E8742C19F1BC9A707C7A602C8A50DBF9826
B5904EB08E6DAE9078AF927BB1927DB59681B99981BF9D86C09F89C0A18BBFA08BBFA08B
C9AA95C9AC97CEB09BCBAC97CCB09BC8AE97CDB19CD0B49FCDB19CCFB59FD0B6A0C5B09C
AF9A88D4BCA8D4B9A5D6BCA9D5C0B0A49284D7C4B4D9C3B1DCC4B3E0CAB7DEC9B7DDC8B7
DDCAB9E1CCBADFC9B5E1CCB8E2CFBBE1CBB7E0CAB5E2CDB9E2CFBBE1CFBBE5D2C0E6D0C0
E3CCBBE0C9B7DFC9B7DAC6B8D7C7C1BCB1BA736E89665A7CAB7C97B74E5DC02128CE1317
D01013CC1114C11719C13D3BE0908ACFADA890899F362E5A944467AF1122C00710C0070E
B40C15C13C49BB4B63981B37AA0B1EB2020CB2030BA007138F36449A8892CFD0D99C9DAD
49385174395187192A9807129A07148A1B2AC48A96D5C5CACBCCCFC5CBD0C7CED5C5CCD4
CBCFD0CFCDB8B0A559B9A523BDA50EB8A002B69F02B6A108AF98148D780F917D17807012
615508665E1D696210716C0E9D951E9C90119F8A1352C10F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
B4997F9699A196A5B6A9B6C39098A1B7BCC2A8AAAF9C9CA3B6B7BC949298BAB5BAA69DA3
918A9555587803114501114B0710394C4633AF9533C3A40FC4A502C6A802C5A405CAA41D
BD9642AF8C68AB8E7AAB907BAF937CB3967EB89880BB9982C09D87C29F89C09F88BFA08B
C2A691C7AD9AC8AE9ACAAD9BC9AB98C8AD98CEB39CCFB19CD2B39FD0B49FD0B5A1C7B19F
AD9A8AD2BDADD3BDACD3BDADCCB8ABAE9C8FD9C5B4D6C0ADDCC6B4DEC9B8DDC7B5DDC5B4
DDC7B6E1CCBBDFC9B6E3CEBBE2CCBAE1CAB6E0CAB4E1CBB6E3CFBBE4D2BFE3D0C1E2CDBD
E3CBBAE1CAB7DFCAB7DAC5B3DBC7B5D9C6BCD1C4C9989AB3494F78886A8CD16D7CC11F22
D01211D10F0ECE0E10C41416B62E2BDD948CDCC5CE3C3A5F7547729F1D35BC0915C2070D
BD050DB60911AE0713AE0816B0050FB4030CB4020BAA040F931B26885A61CFCDD1C7D0D9
9FA6BB382D49783D528A13209D0512990614881B2AC6909BD3C6CCC9CCD0C6CCD3C4CBD4
C8CCD2CACBC4B2AD82C3B663C1AC38B8A110B8A104BAA403B49B03B19908AE950BA68E11
6550047465216D631D444000958F26867D0E28E20654C51000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
BCA99777808D697B8F6B7A8987919A9DA3A99D9FA6B0B1B695959AACABB0979298A49CA3
867D89393A5904114208143E1F20207B6822C1A31EC4A606C4A902C6A900CAA804C7A215
B48C35AD8A64A98A76A88C79A98F79B1937DB6967EB9987FBC9B84BD9D87C0A18BBFA08C
C5AD9DD2C1B3D6C5B8CFB8ABC5AA9BC8AD98CDB19BCEB29CCDB09AD4B5A0D2B6A2D4BBAB
A59084C6B4A7CDBBADC7B4A5AE9C8DCAB7A8DBC7B5D9C4B2DCC7B7DEC8B7DCC2B1DEC4B2
DFCAB8DFCCBCDCC9B9DECAB8E0CBB7E2CCB6E3CEB7E2CEB7E3D0BBE5D2C0E3D0C0E4D1BF
E1CCB9E1CCB9DEC9B5DFCAB6DCC9B8D5C6BECBC2C6AEACBE736B908F688DE38194C6282D
D01311D3100CD10D0CC80B0AB91511B95145DAAFAC776E8A42315F9C3F5EB10E1CC0070F
C0040ABC060BB40B12A80C14A30716AB0514B1010EAD020B980911A5565DC1B7C3ABBDD0
7783A2443956753E54A83D489B0510A0020B980813882430D2ABB1CECACDC7CDD4C6CDD7
C6CAD5C6CBCFCCCEC5CFCEAEC7BB75BFAB36B9A414BAA307B39C02B59C03B09802AF9707
A38C0C9B87148270184C40039E922E897D1054CC1400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
CBB9A788919D798A9D83909EB0B9C0A2A6ADA1A1A9BDBDC48A8A8FC5C3C98C8990C4BFC6
918A95454866132146282A26806E25B99C1EC2A00CC2A30BC4A707C7A802C9A903CAA614
C19A36AE8A58AB8A71A98C76AA8D77B1937BB6987FBA9B83BC9C85BE9E88BDA08CC4AD9D
DDCEC5E2D9D5DFD6D2E6DAD3D3C1B6C7AD9BCAAC96CEB29BCEB29CD2B6A1D4B9A4D6BEAB
CAB5A4AE998CAE9A8DB39D8ECCB7A4D7C1AFD9C4B2D8C3B0D7C3B0DEC8B6DBC5B2DDC7B6
DFC8B9E6CFC1DFCBBADECCB9E0CEBAE1CDBBE3CFBCE2D0BBE3D1BCE2D1BEE4D2C0E4D0BE
E2CCB9E1CBB7E1CAB9DEC9BAD5C5BEB2B1BB72758F907491C87B95C54C60C2242FCC1418
D2100FD00E0ACD1108C3160AB32412C06451D1A69BBAACB835315A854D75A4192EBC0815
C0050EB2080ACF524FC1666E6B122F880B2DA70519AD020CA5050F93253658385A232C59
4B3E6784435D902434990F18A1020AA60108A4050C900C13985255D9C8CBC9CCD2C5CDD7
C4CBD6C3CBD4C6CED1CDD2C8B9B286BEAE56C3B13BBAA51CB8A00CB49C03B59E04B29D03
B19B04B29A08AB94117B670B7C6A1292841781B52100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D5C3B0848A985B6B7E6D7D8C919CA591949DADADB59E9CA49E9BA29E9AA29C98A09A949B
847E8743465C131C21746A2CBB9C1EC3A10DAD910F7D6601B49A10C5A605C5A208BC9615
B79234AF8B4CAD8A61AC8C70AB8B76B3927DB99882B79982BA9B86BD9F8ABCA292DACAC0
E1D7D3C7BBB7C1B2ABD5C6BFE3D3CBBFA898CBAD97CFB09AD1B49ED2B7A2D3BAA6D3BCA9
D5BEACD7BDACD5BCACD7C0AFD9C3AFDAC4B1D8C4B1D7C3B0D5C0ACE0CAB7DDC6B5DEC7B7
E1CABAE3CCBCE0CBBADFCEBBE1D0BEDECDBDE2CFBEE4D1BEE4D1BDE3D2C0E5D3C3E5D1BF
E4CDBBE2CCB9E2CCBADDC8BBCFC5C8536180676892B56B87B62332CE1A21D51418D41112
D0100DC60E06C32011D1553CDA866BE7B8A1CAADA1D5C6C6646280543B69982E4FB30C1C
BE0811B00B0FCF6466EFC5D0493057590F429A0B29AB020FAC030E99101F80395B1B0D3B
6F4C6F7A14279D0915A5030BA70208A70208A5070B950F0F7F3130D6C0C0C7CAD0C4CCD6
C4CDD6C0CAD4C0CBD3C5D0D1C8C9BAB9B488BDB371C7B864B7A336B19B15B39F0BB19F04
B4A104B6A003B8A005BAA410A9950FA1911A998B1F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D3C0AA7F838D48586980909D8B959EA4A9B0B6B8BE8A898EC3C1C5827D83C7C2C7807B7F
B9B4BA494B54272708A59127C2A10CBFA011826906604D088C740CC4A50ACAA614AF8B16
B99430BF9B3ABA964DA98860AC8B75B3917DB99883B89882BB9C87BC9F8AC1AB9BE5D8D1
D2C6C2BAA79FC0A99CC4B1A7E4D2C8C1A89BCEB19ECBAC97D2B4A1D4B9A8D4BAA9D4BBAB
D5BBACD5BAACDABFB1DBC1B1D8C0AEDAC4B1D8C4B1DAC6B3D8C3B0DBC6B3DDC8B5E1CCBA
E0CCBBE0CCBBE2CEBDE3D1C1E1D0C0E1D0C1E1CFBEE4D0BFE7D2C1E3D0C0E3D0C0E4D1BF
E3CFBCE2CDBAE2CDBBDFCABECBC4C83D4F74656897A85A75C2232ED41519D71013D30E0D
CE100BBC1005E55948F49D85DBAB94DFC5B1C8B2A5C1ADA6A198A53830598A456EA31126
B90611B70A0FAC2B31E0A9B545365C3A124A850D38A80315AE020DA00514A13B5237173D
553D5F792337970915A4030AA70108A404069E15119B4033A2766FCFC6C5C6CCD1C4CBD5
C2CBD4C1CAD3C1CAD3C6CFD8CAD0D5CACFC9CBCFBFCFCFB8C6BF95B8AA5EB0A233B3A61E
B1A313B3A30CB7A508BAA807C1AC1596821284751700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C7AF9693959B6877886C7D8C7C8995A4ADB5A0A5AA979A9FA8AAAE918F93A7A4A8837D80
A0999B4E4A41564C0EB89E1EC0A00AAC8F10594404604A07A5870DC7A407C8A40EBB9713
C49E1FC8A221BB9738AC8C5CAC8E76B08F7EB79683BC9B87BF9F8BBEA18EC0AC9EE7DBD5
CEBFBABEA99DBFA799CEB9ADDCCAC0C8B2A3D0B5A0CFB39CD1B49FD3B8A4D1B7A4D4BCA9
D6BFADD7BCADDBC0AFD8BFACD4BDA8D9C3AFDAC3B2DBC5B4D7C2B0D8C2AFDDCAB4DDCBB8
DBCAB8DFCDBCE0CDBEDDCCBDDECDBDE0CEBEE4D0C0E6D0BFE6D0C1E7D1C3E0CBBDD5C0B2
E5D0BFE0CABADEC8BADDC9BBD9CAC88589A3394674A684A7B14251C31C23D31417D30E11
CF0E0EC8120EC11F1AD35D51E59C8DD6AC9ACAAFA0C4AEA2BEACAE5049695D396794233D
B40A17BA070EA90E14C56C72C4A2B74D2C596E0B3DA3071FAF020EA9050E9718285F2748
261A426C415C821928990811A5030AA005089A2521D59F95CEBFBBC9CDCDC6CDD3C4CDD4
C1C8D2C0C8D3C0CAD4C6CFD9C5CDD7C7D0D6C7D0D4C8CFD2CBCDCBCCCCB9909168969955
959640ABA63CB2A625B5A611BDA811B39C19826D1482B21E4FBE0F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C4A786A8A5A857647555657586939FA8B2BB878F93B6BABE929398BAB8BD8E888CC0B6B8
8678729C8B6890781CBA9D13BEA111806409664E0C876D0DC3A112C4A008C29F17B39216
BF9F1DC3A01FBC973DAF8D61AB8B73B18E7DB18F7DB99A86BA9B87BC9F8EBCA698E2D5CE
DCD0CBBEAEA6C8B6ABDFCCC1CCB5AAC9AE9FCCB19CCFB59FD1B6A1D0B4A1D1B6A3D4B9A7
D3BAA7D4BAA8D7BDABD4BCA6D8C0AAD6BFABD8C3B1DCC6B7D9C5B5D7C5B2DBC9B5DBC9B5
DAC8B4DFCCB9E0CCBBDFCCBBDECCBAE3D0C0E4D1C1E6D3C2E4D1C0E6D3C2E3D0BEDFCCBB
E2CFBEDECBBCDECBBCDDCABAD9C7BCD0C5C881859F505277A47F9BB45262B7232AC71619
CE0E13D00F12CC1113BF1515BA302BD97B71EAB9ADDBC1B4BEAAA38C83933425508B3A5E
A91020BC0911B2090EBC444BFCC1D0915B7B720F399E061FB0030FAE040C9809148F4157
766786443A5A75425B841D2B980A149D050C8E0C11A95E5FD8BEC0CCCACDC5CBD5C2C9D3
C2CAD3C0CAD3C2CAD6C4CCD7BCC6D0C0CAD3C4CED6C2CCD5C4CCD6C6CDD2A9B3B59EABA3
B3BDA5B5BB92BAB772B5AC41B8A621C0AA1BA4900BC1AB2283AC1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
94BD64C3BDBF6E7C8D677B8C9DADB99DA8B191969CACADB29A989EB0ACAF978E8AB7A798
8D784FB99E4CB39419B99A129A8008AA9230654E00B3971AC3A10BB99513A88728A68938
B4963CB89942AD8C54AC8A6EA98975AE8E7BB09280B39684B89B89BD9D8DBDA193C9B5AC
DDCFC8E1D3CBD9C8BECCB5A8C9AE9ECBAF9ACFB49DCBB09ACFB49FD1B6A1D2B7A3D3B8A5
D3BAA6D6BEABD2BDABD1BDA9D5C1AFD9C3B1D8C1AFDCC4B4D8C1B1D7C2B1DBC6B4DBC6B1
DCCAB4DDCBB9E1CEBFDFCCBCE0CFBEE5D3C4E8D6C8E8D4C6E5D3C4E6D5C5E4D3C3E3D2C2
E1D0C0E0CEBFDFCBBDDCC9BADCCABAD6C6B8CEC3BFA59FAE645F7D7E6883B77484AE373D
BC1A1DC81315CB0E10CC0E10C41011B51C1AC95E5AE1A79BC7A89AB9A9A94842616F3F69
9B1C34B80A16BB050EAD0F19BF3D4EA72B419E0F26AB0515B2030EAE020B9E060FAB4959
C2A6BCACAEC354496573455C832131930C189908118A0F189C505BD8BBC4CAC9D0C3CAD1
C0C9D1BEC8D1C2CAD6C7D0D9C5CFD8C1CBD3C5CED5C4CDD5C4CCD7C3CBD799A3B2344451
727E776C7362919780929261B3A84BBAA823BBA914C3AF18BB9E2200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
60CF40D5CBC95B66766173848695A379838DB1B5BC959499B0AEB0A7A098BDAB8DA9904E
BB9B35BB9817BD9B12A688125A44016A57128B7208AD8E09C3A10DB08C16B18C3FA78653
A2835AA58764A78A71A88978AA8B7BAD8F7EB08F7EB69685B99A88BE9E8DC09F8FBFA393
BFA698C3AC9DC5AF9EC6AD99CCB19CCFB69ECBB19ACDB29DCDB19CCDB29DD1B4A1D0B5A0
D3BBA6CDBBAABBAC9DB7AA9BCCBCADD7C1B2D8C0AFDEC6B3DAC2B0DAC3B1DCC6B2DBC9B2
D8C8B2DDCBB9E2CDBFE0CCBDDECBBCDFCCBEE2CFC1E5D2C4E5D2C5E5D2C4E6D3C5E5D3C5
E3D0C3E0CDBFDECBBDDCC9BADBC8B7D9C6B5D7C6B4D4C3B9C6BBBF8D84985F516A9C7185
AE565EA82B2DBA1C20C71214C90D0FC50F0FB91817BE4D44DEA193C8ACA583788C432B55
973856B0111EBC080DB6040BB30814AF0713B20710B1030BAF010AAE0309A9060F951424
844B61C5BFCEBCBCCE5F546E6F465F822C3C8E0F189708148B0E1E9A4E5BD3B9C2C6C7CD
BFC8D0BDCAD2C2CCD5C9D3DCC7CFDAC8CFD8C7CFD8C0CBD4C1CCD6C1CCD798A4B44C596A
586262828A7F8D9590949789AEAA76B1A73DB5A71FC0B027BDA43125DB0800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
59C632DED0C88189987E8EA081909D8D97A0AEB4BA98999DACAAA8ADA38ABCA75EB39820
BA9C0CBC9B08B29212705807533E02796007BA9A13C3A00AC29E0FB38B1AC29C46AC8A54
A082689F8273A28578A58879A88B7BAA8D80AB8D7FB49584B89986BC9E8ABD9D89BE9E8A
C2A491C7AB97C8AD98CBB09ACCB09BCBB19AC8AF96C7AE96CBB199CDB39CCFB4A0D0B4A1
D2B9A8B3A294AEA195AC9F92B5A596D4BEADD8BFAED9C4AFDAC6B2D8C5B2D8C6B2DBCAB6
DBCAB7DDCCBBDFCEBEDFCBBDE0CCBEE3CFC0E5CFC1E6D0C2E5D1C3E4CFC1E5D1C3E7D4C5
E6D2C6E4CFC4E2CDBFDDCABBDAC7B7D8C5B4D8C5B4D7C4B5D3C2B7D2C2BFB9ACB5796C80
6D576DA27587AE5D67AD262AC21416CB1011C71010AF1611D3776BD2AAA0B8A6AE4E3E5D
8245609E212CB31519AF100EAD1010AA0F0EAD1010A90C0DA90C10A7090FA80A119A0F1B
883B4CB9ACB8CDD1DBC2C5D4685F7967455D7F2E418B0E1C950616860C1BA15C6AD0BFC7
C1C6CEC0C9D2C4CDD6C7D0D9C8CEDAC5CCD9C5CED8BECAD6BDC9D5BBC8D2B2C1D09BADBF
9FB1BFA2B0B6A4B0B5B0B9BAB5B9A6AAA86FB4AE5BC6BF72A89B59628D2300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
2ADF14DCCABE8F96A64D5E725D708099A7B0899197ABACB0AFAA9DB2A36AB39B29B89B0A
BC9D05B6990D8F770D7C67187F6501BC9B16C39F07C4A009B69219A58031A7844FA28160
9F8172A08078A48378A9897CAA8B7FAD8E83AE8F81B09382B69987BC9D8BC09F8BC5A691
C9AD98C9AB96CAAD98C9AD98C5AA94C5AB93C6AC92C6AC92CBB199CCB29BD0B49FD1B6A3
D4BCABA39183C4B6A9BCAF9EB9A896D3BFAAD5BEAADAC5B3DBC7B5D7C5B1DAC9B4DAC9B4
DDCBB8DCCABADCCBBBDDCCBBDFCEBCE0CFBDE0CEBEE3D0C1E5D1C3E2CFC1E6D3C4E6D2C4
E6D0C3E3CEC1E1CDBFDECABADCC8B8D7C5B5D7C6B6D7C6B6D3C3B3D5C4B7D3C1B8CFBEBE
9D91A15650695D4F6CB17386AE252FC51115CB1010BA150FC35A4DD7A99EB4A3A4ADAAB6
C2ACB5B37273BE625BBC5F51B85E51B05847AA5246A84E46A54843A442429C383C8B333B
804C56B9B5C0C6D0D8C8CFD5C9CAD77772875C415B7D3045890B1C9307167D0F1EB88C95
CCC8CEC1CBD1C3CDD6C7D0D9C8CFDBC6CEDBC2CCD8BFCCD5BFCDD6BECBD5ABBACE49617C
3B547457708667798587939A88908E969A86A1A587AFB49F7B7B71604D3900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00DAC2B0ABADBA4B5A6D6E7E8C9DA8B38D939AAEAEACB3A886AF9A40B29810B99A06
B7980B9B81135644005441019A7F0AC2A00AC4A005BF9A13A7842C9D7C55997965997C6F
9C7C77A17F7BA4827AA6857BAA8A7FAC8C80AC8D7FAD907FB89A89BE9E8CBF9F8BC3A791
C3A890C8AA94C6A792C4A590C2A58FC3A891C4AC92C9B096CFB49DCCB09AD0B59FD1B7A1
D3BCA7B9A491A59484B3A491D3C2ADD4C0ABD3BEA9D8C3B1DCC7B6D6C1AED9C7B1DCCBB7
DAC9B8DAC9B8DDCCBADDCCBBDFCDBCE0CDBCE1D0BFE3D1C3E4D0C2E4D0C2E6D4C5E3D1C2
E3CFC2E3D1C4DFCFBFDCCAB8DDCAB9DCC9B8D6C4B3D7C6B7D4C3B4D6C5B6D4C1B2D3C0B2
CFBFBEBBB6C54B51735D4D6FBB5B6BB9191BC31710B52113C76D5DDFBCB1ABA4A85B6A7B
BCC5D1CDB7B9C99E96C39A8DC19F95B69B92D6C0BADDC8C7C4ADB0D9C0C7AE99A5564859
817F8F566877B9CDD6C6D3D8C9D0D5C8CDD862637D563A587C23378C071588081588414B
D1C3C9C3CAD0C5CFD8C5CFDBC6CFDCC6D0DAC3CBD7C1CDD6C0CDD6BDCAD5B6C1D42C405D
415776475C726E7E8A8F9BA1929B9C999D989EA2998C91926D6F7C4E404400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00D0B39ABCBCC64F5D70788697707886A7ABAFA4A08CAF9F58AF961CB69907B89908
A0840E5B45005B480E998320BA9A0DC3A005C19D0EAE8C2398794594776694776F967772
9E7B79A5817DA5827DA4827BA9887EAB8B7FAB8E80AE9284B5988BBB9B8CBC9C8BC3A390
C8A895C7A894C1A58FC4A891C5A993C6AD96C9B099CCB19BCAAE99CEB39CD2B8A1D2B8A2
D2BBA6D2BCA7CFBAA6D3BEA9D2BDA8D2BDA9D6C3AFD7C4B0DEC9B7D7C2B0D9C7B3DAC9B7
DAC9B8DBC9B7DDCCB8DECCBAE0CDBDE1CEBEE2D0C1E1D0C1E2D2C3E3D2C2E2D1C0E5D2C1
E1CDBFE3D0C2E0CEBFDDCCBBD9C8B6D8C7B6D9C7B8D7C4B6D5C4B3D6C6B4D7C6B5D5C3B5
CDBFBCB1AEBB4D5674766C88A86066AD352BBD442FCB6E56D49F8CD3B9AEC5BBBC6F7588
525A76907A8CA67378D09C9CEEC3C9BFA3ACAA96A3A999AA937F94877087725B764E3653
6E5D738D8B9CB8BCC6CCD0D5CBD1D5C9D2DB9BA5BD221F427E425A800C198A0C1475262A
D0BFC0C5CCD0C2CDD6C2CED8C5CFDBC5CFD9C6CED8C1CBD4C1CCD6C1CBD5BCC5D38392A7
96A8BEA3B5C49EAEB8A3B0B8A7B2B5AEB6BAB2B9BCB1BABF959AA8514C552FA01A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00C5A285D0CDD36371837A8999747C86B2B2A8A1955DAA9427B09709B59706B0920E
7860094D390377631690760ABF9E09C2A00BB1921C9A7C3C93776093766F9577749B7A7A
9F7B7B9F7C7AA07D7AA3817BA7857DAB8B80AA8C81AB8D83B49488BA998ABE9D8BC1A08D
C4A28FC1A08DC2A58FC8AE97C8AF98CCB39DCDB39FCCB39ECDB39ECDB19CD1B6A0D3B9A4
D3BEA9D2BDA8D2BDAAD1BCAACCB7A4D5BEABDAC3B3D7C2B1DCC7B6D8C3B1D8C2B0DAC7B6
DAC7B7DDC9B8E1CCBBDFCCBCE0CEBEE0CFBFDFCFBFDECFBEE2D3C1E0D0BFE3D0C1E5CEC1
E3CEC0E1CEBFE1CEC0DECDBBDAC9B8DAC8BAD9C5B7D8C4B6D5C4B4D5C4B4D7C5B7D2C0B5
BDB0AE77737C6E6E7EBCADB3CDA599D8A28EDCAA92D4AD97CCAE9EC8B2A6C1B0A7B4A9AB
6E667C7561798F55658E3241A33B4CA64053A34055A03D54A13A529E364C9D2F45962C3F
9331449E4F60AF7787D2AFBDD8CAD5CACAD658627B3B3D58825766751D217D1B1C7E4341
CBC0BEC5CDCFC3CCD6C4CDD7C7CFDAC8D0DBC4CCD7C4CED8C2CAD5C3CDD6C2CAD96E7C95
374F6E657E94687B8A7E8D9689939B8790978B949B969FA79098A748475533A72500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF006ADB50D7D2D3707E8F63748497A1A399956FA59232B0960DB29703B3980C846C03
6E59066B5400A28613B6980BC09F0AB795159A7C2E9074578D716A917572977977987878
9878779D7B799F7E79A98480AA847EA9877EAE8E82AC8C7FB49587B79987BB9D8BBE9F8D
C1A18FC4A694C4A894C9AE99C5AC95C8B19CC7B3A3CCBCAFD0BCAFCBB4A3CFB7A2D3BAA5
D1BAA5D0BAA7D1BBABD6C1B1D9C3B2DAC2B3D9C2B4D8C1B3DAC4B4D8C3B2D8C2B0DBC8B6
DAC8B8DCC9B8DFCAB9DDC9B9DFCDBEDFCEBFDDCBBCDECDBDE2D0BFE2D1C0E4D3C2E3CFC0
E5CFC1E1CDBEE0CEBCDFCEBBD8C8B8D5C5B5D8C6B7D8C6B7D7C7B7D5C4B6D5C3B7D1C0B3
D1C2B7C6BAB1CABEB9CDBDB1CDB9A8CBB6A3CCB6A3C6B29FC2AB9DC4AFA4C7B6ACDDCDC7
B7AAB1776C7C755D6EA066749A38439B2027A1161EA9141DAA0F18A80C14AA0D16A40B14
A10A179A0D1B9211248B2239A96579D9BAC7A9A1AE8E8995958386937370977771AB9D98
C7CBC9C3CCD0C5CED7C3CDD7C9D2DCC9D2DCC6CEDBC5CDDAC4CBD7C2CBD5C4CCDC6C7894
1E335653698257677A8B95A19CA3AD959CA49CA4AB9098A18288983D405066514800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0060CF41DBD1D0757E8E5D6C78949A8B958940AA9515AE9703B19804B399127F6700
A38B20A5890BB8990BBD9E07BA9C13A587298F72488E73668F7370907373957775967775
9A7B789D80799E7E77A3807AA8837DAA857EAD887FAE8C82B29386B59A8AB99E8CBEA18D
C1A291C5A795C7AA97CBAF9CC5AE9CC1B1A4D7CDC8E0DBDAE5DDDCD2C3BBCBB6A6D0B6A4
D2BAA7D2BAA8D0B8A8D1BAAAD9C2B4D7C1B3D9C2B4DAC1B3D9C2B2D5C2B1D5C3B2DAC7B6
DAC8B8DBCABADBC9B8DECABADFCDBDDFCDBDDDCBBBDDCCBBE3D1C1E3D1C1E1D1C1E2D0C1
E3D0C2E2CFBFE2D0BDE0CEBBDDCCBAD5C5B2D7C7B7D7C6B7D6C6B7D5C4B5D1C1B3D1C1B4
D2C2B6CFBFB2D0BEB2D2C0B3CEBCB0CBB9AAC7B6A6C4B3A3C6B0A3C9B5AAC3B1A7C9B8AF
BDAEA7BAACAAA0969D85768394707CA6676CA1484A9F2F2FA12220A41E1AA01C1A9D1E1A
9B1D1C981F22961D268D1A28811C2F894253D3B5BFCFCBD0C9C9CBC7C3C5C2C3C4C5CCCD
C5CFD1C3CCD3C5CDD6C5CFD9C6D2DEC4D0DCC4D0D9C4CDD7C3C9D7C0C8D3C0CBD7AAB9CB
8294AB99ACBDADBBC8A4AFB8A5AEB7A7B2BBB2BDC7B2BDC7ACB5C63F485C6C605D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0057C330DAC9C18488956B757A99976FAA9830B19809B29B06B19806B29710776003
7E6809AE930FB99B07B69B0F9B841B8F76408B715F8E736D8E726F927374947274947273
9B7978997A759D7F77A3837BA6837DA5837BAB8A7FAF8F82AF9183B39888B99E8CBFA491
C5A896C9AC9BCBAF9FC8B09EB9A898A79E96B4B2B3BDBFC4DEDEE0DAD1CBCBB8A9D0B8A6
D1B9A7D1BAA8D1BAA8D2B9A9D4BDADD8C1B3D6BEB1D8C0B2D7C1B0D8C6B3D4C2B1D8C5B5
DAC8B9D9C8B8D9C9B8DECDBCDFCDBEDFCEC0DDCDBCDDCEBDDECEBFE2D0C2E1CFC1E2CFC3
E3D1C2E3D2C1DFD0BDDFCFBEDFCEBFD8C8B8D5C5B6D5C5B6D5C6B7D3C6B6D0C3B2D0C1B1
CEBEAFD0BFB0CEBCAECFBDAFCBBBACCDBDAEC9B7A9C5B4A4C5B0A3C7B4A6C4B3A4BEB09F
C2B5A7BBB0A4CBC4C0DEDCDEB2A8AD9482849177798D6A6BB2827EC18F84C08E85BA8C84
C59B96C09699A0797F9369708E5C67824B5B795462C6C0C5CACFD2C5CDD2C5CBD4C4CDD3
C6CFD6C3CDD6C4CED7C3CED7C3D0D9C1D0DAC2CFD8C1CDD5C6CDD9C2CBD7C1CDD98DA2B4
5F7A935B768B70859376838E828C95848D96858D998C97A28B98A73A485B6E666A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D6C1AE9F9FA1737468908840AB9715B19804AE9608947B02AE92128F760E
715900B4980FB79B118E7D16534816847261886F6B8C726E907471927371977675987374
9A75759977739E7E79A2827CA6857DA9897EA9897DAD8E7FAF9283B6998BBA9F8EB89E8C
BEA290C0A491C2AA95BDA8959A8D7DC3BCB5DDDDDDB3B6B9D7D6D5CFC3BDCDB8A9CFB7A5
D1B7A7D3BBACD1BBACD3BDAFD5BEB0D8C0B2D7C0B1D8C1B1D8C3B0D9C7B4D5C2B2D8C5B7
D7C7B9D5C8B9D8CCBCD7CABCD8CCBDDACEBED9CEBCD8CEBCDDCFC1E0D1C1E0D0C0E1D0C1
E0CEC0DECFBEDFCFBEDDCDBEDFCEC1D8C6BAD5C3B6D4C4B5D3C6B7D2C5B6D2C3B3D3C3B1
CFBFAFCFBFB0CEBEB0CCBCADCBB9ADC9B9AACCBCADCABAAAC8B6A8C3B2A3C2B4A4BEB1A1
D9CEC1C4BAAFBAB2AAC1B9B5B2A7A4AFA59DC1B9B5C5C1BFBAB2B3D9D1D1DCD6D8AEB1B6
C6CBD2949DAD3E4D64AFBBC8B6B3BE857B89635A6D848791C7D0D7C5CFD6C7CED6C3CCD3
C4CDD6C3CDD7C2CCD6C2CED7C3D0DBC3D1DCC1CED8C2CCD6C4CED8C2CCD7C3CEDB6D8096
3852712B4660697F906C7C869AA4AD9DA4AD979BA6939AA389909E424E626B686F2C9E16
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D3B897BDB6A5827C4EAE9F37B4A00FB49B04B29912755B00A88E18B3960D
B39509B89A0C9B851A342F043A3A347E7072856E6F8E72729173749071709677759C7A78
9C79759C7B76A07F7AA5837DA28079A6857CAB8C81AF9183B49788B49888B89B89BDA08C
C1A58FBEA28CC0A790B7A39096897CB2AFA8B7B8B89C9C9CBEB7B2C4B3A7CDB6A5CBB49F
CDB5A2D1B7A7CFB9A8D3BEADD5BFB0D4BFAED5C0AED5C0ADD7C2AFD8C5B2D3C0B1D3C3B6
CBBFB5BFB7ADAAA39AACA49DC2BBB2D3CDBFD9D1BED8D0BEDBCFBFE0D2C2DFCFBFE1D1C2
DFCFC0DECDBFDECDBFDDCDC0DECDC0DAC8BDD9C8BCD6C8B8D5C5B6D6C6B7D3C3B4D2C3B3
CDC0B1CFC2B5CEC0B3CBBDB0CBB9AEC9B7AAC5B4A5C5B3A5C5B3A5C5B3A5C4B2A6C0B0A5
C0B1A7BEB1A6B9AFA6B7ADA4D0C8BFBBB7AFC7C6C2D8DBDCCBCED2B9BCC1BDC5CE495D6F
63768963748B132D4E7993A9C6D4DFCAD1DB949CAB516070BAC9D3C3CFD6C7CFD6C6D0D6
C4CED8C1CDD8C2CCD6C3CDD7C5CEDDC4D0DEC5CFDBC2CED9C2CCD6C4CED8C2CDD692A2B2
7C90A48DA1B2A2B4C2B0C1CAA8B5BEABB7C0ADB6C0B2BBC3A9B3BD5C697B6B6D782EA11D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D0AC7DCBBA8D93842FAB9816B49F0AAC9504B0960F7C62059F8515B59807
B99905B498186257140D13133E3F517D6E75866D6F8E70729272779474799575789A797A
9B7977A07F7BA0827CA5877FA5847DA7867FAB8A81B09084B5988AB69B8BBC9E8FBE9F8F
BC9F8DBFA38FBFA48EBEA7938D7F728E867F918A87817974AA9D91C9B5A4D0B6A3CFB6A4
D3BCAACFB8A6D1BAA8D3BDACD1BEACD1BDABD8C1B1D7C1B1D8C4B2D9C6B5D5C5B6BDB2A8
978F899E968EA89F959F958F807B789C9991D1CCBDD7CEBCDDD1C0E1D0C2DFCEC1E1D1C4
E0D0C2DFCEC0DDCCBEDDCCBFDDCDBEDBCCBED8CCBCD1C6B5D5C7B7D2C5B4D0C3B4D1C5B7
CEC2B6CDC1B4CDC1B2C7BAABCEBFB2CBBBAEC2AFA3CCBAACC9B7ABC6B3A8C6B4AAC6B3AC
C2B1A9C3B5AAC5B9B1B8AEA6DDD7D1D2D0CCB0AEABBFC2C3A8ACB294969CAFB4B96B7988
6A7788BFCBD998AABD99B2C5C0D5E2C4D3DCC8D6DDA7B8C0B9C8D1C3D0D7C6D0D8C6CFD6
C5CFD8C3CFD7C4CDD8C3CCD7C3CCDBC2CEDAC3CDD9C4CED8C0CBD6BFCBD7BFCCD79EADBB
7A8EA36F879B74899A7A8D9A818F9987939C89929C8089927F8895536376646A7963493D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00C79A58C9AF61A9951CAE9B0BAB970D8B7701A38C11866D0C8F780DB59908
B5970999852128290E0711294A4B627F6E76866D6F907273917274927476947677987879
9A787A9D7E7D9E807DA1837EA48580A88883AB8983AE8B84B19389B89B8FBC9E91BD9E91
BA9A8CC2A392BFA28FBEA5919785779A8C80A59589AE9C92A29082CBB6A5D0B6A5D1B8A8
D2BCAACEB8A7D0B6A7CFB7A7D1BBAAD6BFAFD7C0B1D5BEB0D9C2B4DAC5BAC7B8B089817B
ACA49EC8BEB3C6BAACC4B8AEA19996767471A8A89ED5CFBFDACFBEDED0C1E0D0C4E1D0C6
DFCEC4DFCEC2DBCCBEDACCBEDACCBDDBCDBDD6C9B9D3C8B8D2C6B5D2C6B6D1C5B7CFC3B6
CFC1B8CCBEB4CFC3B7CBC3B4CBC0B5CDC0B3C9BBADC9BAABC4B2A4C4B2A6C2B1A7C7B5AB
C1AFA5C6B8AFCFC2BBB9AEA6BBB1ACB2ABA8ACA8A3ABABA6CECFD0C3C4C7C1C3C7D1D7E0
B1BDCA9CADBAA8BDCF3F607C99B8CFBFD2DEC2D2DAC2D1D7C6D3DBC5D1D9C7D0D9C6CFD8
C6CFD8C3CFD7C3CED7C2CED8C1CDD9C1CDD9BFCBD7BFCDD6C1CED7C2CCD7C0CBD8A6B4C6
3F5571435F79455E7081929F94A0AAAAB5BBA3ACB499A1A88B94A05666795C66756A554C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0065CE21C8A83AAF9910AA980C8172056B5B009B87147E6A0E79660BB2980D
B59B1F867A390F151B08133653536C7F6F77866E718D707391737691737596787A98797B
9B797CA28081A17E7DA2827EA2857DA98B85AB8C86AF8E87AE8F85B5988CB79B8DBA9E90
BEA290BFA18DBC9F8CC0A594978274B5A596B7A796A89686B3A090CBB6A3C9B4A3CAB5A4
D2BDABD4BDACCFB7A7CEB5A6D3B9AAD4BDADD3BCACD2BDAED8C3B6D7C4BD9C918F86807D
B7AFA9C7BEB4C7BEB3C7BBB4ABA0A07E7C7B888880D5CFBFDDD1C1DED2C2DECFC1E0D0C3
E1D3C6DDCEC1DECEC2DCCBC1DDCCC2DCCCC1D8CBBED2C8BBD2C8BAD2C5B8D2C5B8CFC3B6
D0C4B9CCBFB6CBBFB4CBC2B6C8C0B3C6BDB3C4BAAFC3B8AABBAB9DC3B2A4C2B2A7C0B2A7
C1B1A7BDB0A5B7ABA3B5ACA5AEA6A2CCC9C8D2CFD4AEACAFD8D4D8DBD5DAB2ABB1B4B3BD
6371872F44617F92AA203D5B6E91A8BFD5E1C0CED697A5AAC8D4DAC6D0D9C7D1DAC5D1D9
C5D0D9C0CDD6BFCBD6BFCCD8BDCBD6C1CED7C2CDD6BDCBD4C0CED6C1CED6BFCBD7A4B2C3
879BB271899F95ACBAA1B2BBB5C2CAA8B6BCACBAC0ACB8BEA7B2BD697A8C54627270625E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00C39F19B39B0C95840A5A4E005143009A86168C750B8D7609B09712
B49F3D877E610A112B09123A605F757E6E75856E708C6F7491717896767C97757B9B787E
9A76799E7A7B9E7C7AA1807BA68883A88B87A98B86AA8A84AD8D84B4978AB89D8FBCA193
BEA290BFA28FC0A391C2A595AC9284998676A09080A49081C4AE9EC4AFA0B4A196AC9C8F
C7B4A4D1B8A7D5B9ABD3B8ABD3BBABD2BCABD3BDAED6C2B4D8C3B8D7C3BD877B7B878383
AAA6A3B8B2ACBCB6B0B0A9A79894967A7B7B898981D3CCBCDBD0BEDED2C1DFD0C1E0D1C3
E0D3C6DDCFC1DECEC1DACABFDAC9BFD9CAC1D4C7BED5C8BFD1C5BAD3C6BCD0C2B9CFC5BA
CBC1B7CCC2B9CDC0B7CDC1B6CAC1B3C4BBAFC2BAAFC2BAAEC1B6A8C0B3A3BFB1A6BBB2A7
BBB0A7BAB1A7B3ADA8CDC9CB9E96A3978B9FA48DA4936F83B58995C2949CB88F93B8A0A3
9292A24C5A71A6B5C5A3B3C49AB2C3C2D4E0C8D4DBBCC7CDC7D2D8C7D2DBC6D0D9C6D0D9
C2CFD8BDCBD4BFCCD5BDCAD3BDC9D5C0CCD8BFCAD6BCC8D4BFCBD6C0CCD6C1CAD7ACBACB
7D92AB758FA46E85957D8E9A7E8C957F8B94838E97808A947D8692606F814D5E6F786F6C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0092B80DAF9B0F7B6F025D5201796705A7910DAC9509AD960EB19C27
92844368665F0B15380A163E6765797D6D7189727390727794737D96747D99767B987478
9B797C9C7B7A9C7B79A38481A48784A68886A98984AD8B83B18F84BB9A8EBC9D90B89B8C
B99B89C0A18DBFA28EC0A38FC6A796BB9F8FB9A190C3A999C6AD9CB9A597A4948CA7988F
B8A597D0B7A6D7BCABD1B9AAD0BCAACFBDAAD3C1B0D6C3B4D6C3B7D4C0BA897C7B827D80
8F8E919896999998999290937E7F837475749E9B91DAD0BFDDCFBEDFCEC0DECEC1E1D3C4
DFD2C3DDD0C2DCCFC0DACCBFD7CABDD4C8BDD5C8BFD3C6BDD2C5BCD4C6BED2C4BDCEC3BA
CDC4BBCDC3BACFC2BACDC0B6CDC1B6C8BCB3C4B8B0BFB5ABBFB4AABBB0A7BAB0AAB7B2AC
B6B1B1ACA7AE8D8595826E888253719A4C6A9E334EA4263CA21C2DA21F2D9F2C35AE5B63
E5BCC7D7CCD99096A3ACBBC87D94A7B9CFDDC9D6DFC8D2D9C8D1DAC4D1DAC4D1DAC4CED7
C3CED8C0CDD5BFCCD5BDCAD3BCC9D2BFCDD6BFCDD8BECBD4BBC7D3C0CAD6BFC7D8A1AFC3
213A594D6986536D8470839395A2ADA2ABB6AEB7C1A5AFBA868FA13E516A44576D7B7778
2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005FD00AAB9A13706200716101A08B0DAE9706AE9604AB9512C3B35E
8A81638A8C941922481019426F697D8572758D747590737792737A94757A95787B997B7E
9A7C7E9B7E7E9C7E7DA28582A48683A58684AA8984AA8981AD8E84B7978CB6968AB7998A
B89B8ABDA18CBEA28CC1A58FC3A793C3A694C5A996CAAD9AC8AE9BB9A4959E8E83A9998D
C3B09FCCB49ECFB5A0D3BDA9D0BDA9D1BFAAD5C4AFD4C3B2D2BFB1D5C2B6AB9B96776E6F
7C7A7F7F7D847E7D81797A7D727170847E76C5BAADDBCEBDDFCEBFE1D0C2DECFC2DED0C3
DACDC1DACFC1D9CFC0D9CDBFD5C8BCD4C7BECFC5BBCFC5BBD0C6BBD1C6BDD1C4BDCEC1BA
CDC2BCCDC2BCCDC3BACAC1B5C9BFB5C6BBB3C2B8AFBFB7ADBFB7B0B9B2AFB4AEB4A49DAB
81728B7C5C7B925576A54663A5243BA80F21B20A19B40814B60611B60711B00811A00C17
A2303FB26D80523D5372798E5D7288ACC1D1C9D6DFCAD4DBC6D0DAC5D2DCC6D2DBC5CFD8
C2CCD5BECBD4BECBD4BBC9D2BCC8D4BDC9D5BECAD6C1CBD5C1CBD7C3CDD7C1CAD7B7C4D5
374C68839BB48DA4B7A0B1BFB3C0CCB9C3CFACB8C4B0BCC89FADBF2D415E344663797A7E
32A72200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005DCB0D9A8409776703907D0EAD9609B09803AE9504B09920AA9C5C
8B857A64677809143C182047787085856F798D74788B6F749173798F717594787B957A7C
997B7D9C7D7E9D7E7D9F7F7DA48482A58482A6847EA8887FAC8F85AF9388B29589BB9C8F
BE9F8FC2A691BEA48DBDA38DBEA38EC7AA95CAAB97C8AB97C8AE9AC6AE9ABEA896C0AD9B
CFBDA8D5C1ABD6BFABD4BEABD0BEABCFBEA9D2C2AFD1C1AFD2C1B1D4C2B3D1BEB39A8B85
7E757580797A8A848298908B9B9188C0B2A5DBC9BDDDCBBEDECDC0DECEC1D9CABDDBCDC1
DBCEC2D8CCC0D8CDC1D7CBC1D7CBC2D4CBC1D0C9BDD4CBBFD1C7BCD2C7BECDC2BBCEC3BD
CDC3BDCBC2BBCBC2BBCAC2B8C9C1B8C4BDB7BFB8B5BBB6B5B5B0B69E97A57D6B85815978
A05574AB3B58A71A32AF0E1EB70A15B9080EBA060EB6030BBA030DBB050DB70309B2040B
AB08169B16269B5062907E8DC2CAD6BFCED7CBD5DECAD4DDC7D1DBC6D0DAC7D1DBC5CFD9
C1CDD6BECBD3C0CAD3C0CAD2BFCBD4BDC9D4C3CDD9C2CCD6C0CDD6C0CDD6C0CBD6BAC8D6
74859A899EB37E94A47E909C8C97A387919B848E9A848E997A83962B3C582F3F5B74787F
4C7D3500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6F03806C02A18D0EB09905B09702AE9404AF9929978A58
B9B6B45D637A07133D22294F796F82836F788B737A8A6E738D6F749072749376799A7B7F
99787D9D7C7F9E7C7DA07E7DA28281A88886A6847EA88680AC8C84AF9186B09387B79A8A
BDA08DBCA18CC0A791C1A590C1A590C6AA95C6AB95C5AB93CBB09AC8AD98CAB19CCEBAA5
D0C0ABD1BFACD7C3B1D2BDACCCBAA7CFBEABD2C0B1CEBCADCEBCADD1C0B0D9C6B6D2BFB2
BBA89FB0A096C1B3A8C9BAADD3C3B3D8C7B8DCCABDDBCBBEDBCBBEDBCDC0DACCBFDACBC1
DACDC4D8CBC2D5C8C0D5C8C1D6CAC4D5CCC4CFC9BED1C9BED1C9BFD0C9BED0C7BECDC4BC
CBC2BCCCC5BECAC3BFC4C0BBC2BFBFBDBBC0B3ACB990859980668196637EA9526EAC324A
AE172AB70E1CBA0A15BA0B10BB0C0EB70D0EB30C10B10C13B30710B7070EB9050AB7040B
B5040EAE09149A1F2AC0868F9E959EC7D1D7CFDAE0CBD7E0C5D2DBC5D2DAC5D2DBC3D1DA
C1CED7BFCCD4C2CCD4C0CBD1BDC7D0BFCCD4C4CED8C4CED8BFCBD6C0CDD8BFCDD9A6B8C7
6D839B27445D6D8A9F7A909F98A5B29FABB4A9B2BCAAB2BE9CA3B7303F5E293A56697076
6B5B4F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6C02A38E0BAC9706B09A02B09804AB930AAA97379F9573
8F8D925C617B08133D2C33567A73828370778870768B6E768E6F7592737994757B99787F
9D7C819F7D81A07E7FA28081A28281A38380A6837DA9847DAE8B83B6948BB4948AB6998B
BD9F8EBDA08EBDA28EBFA390C3A694C5AA96C7AB96C5AB95C8AE97CBB19CCDB4A2CDB8A6
D1BDACD3BFAED3C0ADCDBBA7CFBDA8D2BFADD2BDADD3BDAED1BFAED2C3B0D6C6B4D5C4B4
D3C1B3D9C6B7D9C8B8DBCABADAC9B9D8C6B7D9C6BBDAC9BCDACABCDACABCDACBBDD9CBC1
D5C7C0D3C8C2D6CBC5D6CBC5D8CFC8D3CDC8CCCBC8CBCAC6D1CAC4D3C8C0D4C6C1D1C2C0
CEC1BFCBBFBEC8BBC0BAADB7A392A294788E9B6C88A9607DAA4059A72134B11523BB121B
BC0F15BC1113B71311AF1812A91F17A72B23A73733A5393DA2252EA91019B4060DB6040A
B60208B40409A50A11A138417A5863BCC3CBCCD8E0CEDBE1CCD8DEC6D4DCC2CFD7C4D0D8
C5D0D9C2CCD6C0CAD3C0C9D2BEC7D2BCC8D1C4CED7C2CFD6C5CFD9C2CFD9BDCAD6A4B7C8
6C849D435F7887A1B49AAFBCA1B0BCB1BEC9B3BFCCAAB5C3A1ACC0384B692337535E6A6D
6D635600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00709702AD9508B09B05AC9905B39F19AB9927998B42C8BFAA
7B7A818A8FA708143A363E5B78727D816E758970758F7177906F7795737B97757C99787E
98787B9A78789F7D7DA07D7EA38182A28180A7837FAB857FAC8880B3928AB7998FB99C90
C1A192BFA18EBFA38EBFA38FBFA593C6AC98C7AC98C5AA94C8AF98CEB6A1CDB6A4CBB4A3
D4BEADD0BDACCEBBA8D0BBA8D2BDAAD3BDABD0BBAAD4BFAED1BFAED2C1B0D5C4B5D7C5B7
D4C2B4D7C5B7DBC9BCDECDBFDCCBBDDAC8BADBC9BBDBCABCD9CABDD8CBBCD7CBBDD3C7BC
D3C5BFD4C9C3D4C9C3D5CBC4D3CBC7C5C5C78E9CA9A4B6C5CAC8D2D1B9BCDFB8BBE2B3B8
CF9BA4C08896B4768AB66A81B85A72B64359B42C42B31B2BBB171FBC1315BC1716B51813
AE2019AE3328B54D3FBE6F5FCA8D7DC89788B68F8A6D505B794E639A3849A70C18B3040E
B60309B50309B0050E9A101899545FB5ADB5CDD6DDCFDAE0CDD8E1C7D5DEC6D3DCC3CED7
C6CED9C6CFD9C0CAD3C1C9D4C1C9D5BFC9D1C0CDD5C2CFD5C5CFD8C5CFD9C2CDD9AEBECE
7C8FA6748A9E8B9EAD7F909D808D9A7F8B97808A987E88957683932F405E24395457646B
6C665B16CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF005AC906AF9606AC9803AC980FAE9F34B6AA5EA2986AC1BCAF
7879808389A20711393D42607B727E846F768C727890727A92717A937179926F76947177
9874769A76769E7A7AA17D7FA58384A78584A5827FA9857FAD8982B3948BB79A91B89B91
C1A095C3A294C0A38FBCA18DBCA491C2A897C8AB9BC8AC98C7AD98CBB29DCAB29FCCB4A3
CFB8A7D4C1ADD4C2AED2BEAAD0B9A8D0BAA8D1BEAAD3C1ADD0BFABD0BEAED3C1B2D7C4B8
D1BFB2D5C5B8D8C7BDDACABDDBCBBDD7C7B9D8C8BBD7C9BDD9CCBDD9CDBDD5CABDD4C8BE
D9CBC3D9CCC5D6CAC4D5CAC4D4CBC7CBCCD065788F446287AFB7D4957182A95D6CB44F5E
B94656B83D4FB63347B42437B81F2FBD1D29C01A22BF1A1AC01D17B72015AB261AAE4032
BD6A5ACE9182C99B8CC1A293B59F91B29F91B1A19A8D86922D2745935A75941020AE040F
B4010BB6030CB1030CA50A119F4048BAA3AACED7DECCD9DFCED8E2C5D2DBC6D2DDBECCD4
C0CCD4C6CFD8C1C9D4C0CAD4C2CAD5C2CCD5C4CED7C4CED7C2CFD8C4D0DCC2CDD8B0BFCF
435A756E8BA36E88998599A59AA9B594A1AA96A2AE98A4B08D9AAA293B5B2A3F5B54616A
69645E2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE503AE9603AB990BA69625B1A761A8A37CADA99595938F
8E8E9859617B08163C484E697C737E826F768971778F737A92727A917078947278967378
9874769E79799E7A7BA07C7FA38183A58484AA8785A78481AE8C86AF9188B79A90B79A90
BF9E95C09F91C3A393C0A292BCA090C2A896C7AB9BC9AD9CC6AB97C9AF9BCBB39FCAB3A0
D0B9A6D5BEACD2BFABCFBCA8D0BAA9D0BAA8D0BCA9D2C0ACD1BFADD4C2B2D6C3B4D7C5B7
D3C2B4D7C6B9D8C7BDD8C9BED8C9BBD7C9BAD4C6B9DACBBFD8C9BCD9CDBED7CCC1D7CDC3
DBCEC6D9CCC6D6CAC5D7CBC7D6CCC9D1CDCDB5BECC5E73945E6C93A392B1A56C829E4253
A6303DAA2834B62834BB252DBB2329B72523B62A24B33228BB483BC76858D48677D69E8D
CBA595C2AA9CB4A397AFA497AAA195AAA294ACA29BAAA8B0393E5E6D54768B2436AA0A16
B5040EB5030CB2020CAE081098242D9C7481C1C9D5CBD9E1CFDAE4CAD7E0C5D1DCC0CED7
C3D0D9C6D0D9C5CDD8C1CAD4C3CCD6C2CED7C5D0DBC6D2DDC3D0DCC2CFDBC1CED9BBCAD9
3F56735C7D994F6E8295AFBD99AEBD9CAFBFA2B5C7ACBFD0A2B4CB2035582D435F5B6870
645F5C32A61F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE603B19B09AA9A1FACA55EA9A990969693BDBEC086878C
ACAEBA515C7519294B5259707C737E806E75866F768B71768D707691727797757B9A767B
9A76799C7878A17C7E9F7A7EA38081A78684A78784A78783AC8B84B09086B6998EB99C91
BC9F94C2A297C09F93C1A094BFA090C3A592C5AA98C5A999C8AD9CC9AF9DCCB4A0CBB5A0
D2BCA8D7C1AED0BBA9D0BDABD1BEADD0BCACD3BFAFD4C1B2D4C2B3D4C1B2D6C2B4D6C4B5
D2C1B3D7C4B8D9C7BBDBCBC0DACBBFD9CABCD4C6B8D8C8BDD7C9BED6CBBFD8CEC4D6CBC4
D8CBC4D8CAC6D9CCC9D7CBC9D4CAC7D6CCCBD0CACBC5C5D29BA2BA717792857C94A98B9D
B3828FBA7B86BF767CC87777D2827CD68E81DC9C8EDBA597D7AC9ECDAE9FC9B3A7C1B3A6
BAAFA4B7AEA4B2AAA1ADA69BAAA398AEA59CADA6A0D2D0D27F859F3131588D4D65990F1B
B1050FB2010BB2010BAF040D970C179D5B6A9696A6CAD9E2CDD9E2CEDAE2C8D6DEC6D4DC
C2CDD7C4CFD9C3CED8C5CED9C4CDD9C1CDD8C1CDDAC3D1DDC2CFDDC2D0DBC0CFD9BCCCD8
8699B453718D7799B493B4D17796BA5E78A25C73A0586F9D4B6293102554364C695A686D
5A595236AE2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CE07AE970BA89C3AA7A5809EA3A09EA2A8A3A6AD94989E
818590535C740A18395D62777D727D816E75856C748A70758F727794727899747B99737B
9C777C9D787A9D787AA07A7CA4807FA68480A6847FA6847EAA8981AF8E84BB9C91BA9C91
BB9F93BB9F93BA9D91BC9E91BFA190C4A491C8A996CBAF9ECCB1A2CEB4A2C9B29ECBB5A2
CFB9A8D3BFAED2BFAFD3BFB0D2BDAFCEBAACD1BDB1D2BFB3D2BFB2D0BCADD4C1B3D4C4B4
D2C1B3D5C2B5D8C5BADAC9BDD8C6BBD7C5BAD6C6B9D7C9BCD6CABDD5CCC1D8CEC6D7CBC5
DACCC6D6C9C4D5CBC6D3C9C5D6CBC8D4CAC9D0C8C6D3CBCACCC6C9CAC8CFBEBEC7B2B2BD
B1ADB5B3AAB0B8AAADC4B2B2D2BFB8CEBDB2CCBCB1C6B9AEC4B7AEC2B8AEC1B6AFBCB3AB
B8AFA8B8B0A7B4ADA3B3AEA2B4AFA4B3ADA4A8A39DAEAAA79D9EAE2A345872577A861A2C
A70612B0010BB2010CB0030CA309149B3E48CEBBC3CFD9E0CDDAE3CFDBE3C9D8E1C6D4DC
C6D1DBC3CFDAC5D2DBC5D2DBC4CED9C1CCD7C3CEDCC1CEDAC3D0DDC1CFDABDCDDAAEC0D2
8297B558749A31507E132F68031C5E01165C01155E00125B02145C011452273E63576871
5F615A5F4E3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CD08B29916AEA24F999A82A6AEAFB2B8C094979FABAFB6
8286926B748D0C1A396468797B6F79806C74886E778E727A92727A9371779571779A757C
9C757D9A75799C797B9E797BA27F7EA78280A5827FA5817DAD8883AF8E86BC9D94BB9D93
B99C8FBDA191BA9D8EBB9F90BFA291C5A593C8A896CAAB9DCBB0A1CCB2A1C9B19ECEB8A5
CFB9A8D3BEADD5C2B2D3C0B0D2BEAECFBCADCEBBADD2BFB1D0BCAED4C1B2D4C2B5D3C1B4
D0C0B2D1BFB2D8C6B9D8C7B9D7C7BBD6C6BCD6C8BCD8CCBFD5CBBED4CCC0D5CBC3D5CAC4
D3C7C1D0C6C1D0C8C4D2C9C5D2C7C3D2C8C5D1CAC7D1CAC7D2C9C7CBC5C2CBC8C4CDCCC7
CBC9C4CBC8C4C9C3C0C8C2BECBC3BDCAC4BBC8C0B9C5BDB6BFB7B2C0B9B2BFB6B3B7B0AE
B7B1ACB9B0A9B7AFA6B4ACA4B2AAA2AFA8A0ACA69FA9A5A0B0B0B65864833839648F4A64
9A0E1CAE050FB3020DB2020CAA05108E171EDBB0B4D6D6DACED9E2CBD8E2C9D7E3C7D5DF
C6D3DDC3D1DBC7D4DDC5D1DBC7D1DCC3CEDAC7D2DDC3CFDBC4CFDBBDCDDCB9CCE48CA5CA
29447807216000175F00125E01125F01125D01115D01115C01115C011359031749394C61
5C62615F544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0030E504B0971DA39A4E9799819AA2A39FA5ADA0A3AB9F9FA8
7A7B89565E7814213D6B6C7B7B7076816D76876E798B6F7A8C6C769573799874799C747B
9A70789E767B9E7B7BA38182A17E7EA4807FA78382A98684AB8784AF8D87B4968DB4978C
B4978ABB9D8EBD9F90C3A597BEA090C3A491C6A896CCAFA0C9AD9FCCB2A2C9B1A0CDB6A5
D0B9A9D2BDACD1BDADD6C3B3D1BEAED2BDAFCFBDAED3C1B2D2BFB1D3C0B4D1BFB3D5C2B7
D4C0B4D2BFB3D7C5B9D7C8BBD7CABED4C7BCD7CABFD5C8BDD1C7BCD4CAC1D3C8C1D4CAC3
D3C8C1D2C8C4D1C8C5D5CBC8D3C8C3D1C7C4D0C8C6D3CBC9D2C9C7CBC4C2CCC8C4CCCAC5
CAC9C5C7C7C4C6C4C3C4C1C0C5BFBBC8BFBACABEB9C3B9B2C2B8B4C1B8B6B8B5B99FA7B2
ADAFB8BDB0B0C0AAA7C3A8A5BEA29FBCA4A1C4B5B0B5AFABBEBEC0B1BCCF25325D806285
8B1B2CAB0913B2020BB1010BAE040F970B17BF7880DFD5D8D2D9E1CDD8E3C8D4E2C5D3DE
C4D2DCC3D1DAC6D2DBC6D1DDC5D1DEC4D2DDC6D3DDC2CFDBBFCDE2ACC2E06984B2142F6F
01196401166601126300115E000F5C01115C00105901115901105B011258010F4A0E1D41
545E655F594E15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00B09938908D58A6AB9DB1B8BC959AA4B2B6C09E9FAA
9291A14D546E2029447371807D6F7583717786707A876C778F707997757C9570759B7279
A1777CA47B7D9F7A7AA17E7FA38081A48180A48180AA8684A98581AD8B85B4958DB79990
BD9C93B9978CA9877BBE9B8FC1A092C0A291C4A997C9AD9EC8AC9CCAB09FC9B2A3CDB6A8
CAB5A5CFBBABD6C3B4D3C0B2CFBBAED0BBAFCEBCAECFBEAFD1C0B1D2BEB2D2BFB3D2C0B3
D4C1B4D2C0B2D6C5B8D4C5B9D4C7BBD5C8BCD5C7BCD4C7BCD3C8BED3CAC0D2C9C1D1C9C1
D5CAC3D3C9C3D1CAC5D2CAC3D2C9C2D1C9C3D4CBC8D3CBC9D1CAC6CFC9C4CBC7C3C9C9C8
C0C7CEB7C3D0A6AEC0AB9FB0D3AFB9DCADB2DCABAED8ABACD1AEAFC8B0B2B1A9B7384768
8182A1A47787B56670BB6066B75861B86269D6A0A2BCA9A7B0ACABA9AEB75563843F3D69
8C3E57A10F1CB3050FB1010BB0040EA3081298363FE7CDD1D1D6DCCCD6E0C7D2DFC6D2DD
C4D2DBC4D0DBC5D0DCC3D0DCC3D2DEC5D3DEC1CDDBB9CBE096AFD3314D84031D64011868
011265001263001160011360000F5A011159011158011058000F58000F56010E4D020F3D
3E4C5B5D5C532BA01700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00CCB67A80816E8690939FA5B0989DA8A3A7B29698A4
8687974A4E68252B45756F7E7B6C738573788670788A6F77907078927077977278987378
9F777CA078799E7978A37F7EA58181A48180A88584A88382AB8684AD8A85B5948DB79790
BD9C94BA988EB69489BD9B8DC2A291BB9F8DC0A593C6AB9ACAAF9DC8AE9CCCB4A5C9B2A5
C9B5A7CFBCADD3C2B3CFBEB1CBB9ADCEBBAED0BEAFD0C0B0D3C3B3D2C1B2D2BFB2D2C0B3
D4C1B5D4C1B4D7C6B8D9CABCD2C7BAD5C9BDD3C5BBD3C7BDD2C8BFD1C8C0D2CAC2D3CBC3
D3C9C3D2C8C4D0C9C6D1CBC6CFCAC1D0CAC2D5CDC7D3CCC7D1CCC4CEC9C2CBC9C3BFC6CD
7C94B0485D82867CA0B46F8CB8495BB3343FB4343EB73E47BE535CC77279D59CAC7D6587
654B7194455EA61D2EB41521B91320B11721AA3E43CFA4A1B5ACA9ADAFB293A1B6202E5A
8961838E1428B00916B4040EB1010AAD061090121DCF9CA4D5D2DBCCD4DEC8D2DDC7D4DC
C4D2DAC1CED7C3CFDCC2D0DDC1D1DDC0D0DEBCCEE57F97BF17346F011A64011667011365
01126200116000115F01135D011156021554021553011154010F5502125502114E010E3F
1E2D435C605B32AA2300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D3BB979297958896A199A3AEB3B8C39DA0AA9597A1
9294A1474E6132364C766D7B7E6E748571778870778C6F76906F75957177977177997378
9D767A9C74769D7676A27B7C9F7C7BA3817EA88584A88383AC8685B18A88B4908BB7978F
BB9C92BD9D91BE9E90BE9F8FBEA08FC1A493C0A594C6AB9BCBB0A1CAB2A1CCB5A5CDB5A7
CBB5A7D2C0B1D3C2B4CFBEB2CCBAACCCBAABCCB9A9D0BFAFD1C0B1D1BFB0D0BEB1D4C2B6
D4C1B7D3C1B5D4C4B6D6C9BDD3C8BDD3C8BFD2C6BCD0C6BDD1C7BFD0C7BFD2CAC1D4CAC2
D3C9C2D2C8C5D1CAC7D1CAC7D0C8C2D1C9C2D2C9C3D2C9C6D2CCC8CFCAC5C8C7C59FB2C5
2A4C797681B1AD779BAC233BC61927CA161EC9141CC6141BC01921B31C26AA2A38B55167
AC5B74D16C7DAB1421C20E15CA0E16C40F15A41619DB9794C3B3B0AAACADC3CED94A5A7C
584E7689314AA60D1BB4060FB3020CB0040F9D0A179F505BDECFD7CCD2DBCAD4DEC8D3DC
C6D2DBC4CFD8C4D1DAC1D0DCBECFDEBACFE5738CB60C2768021967011462011161011160
00115F00135D03165A0217530D1F4E28385F3C4D7711235B06195025386319275104123D
0B19365A6468568E4700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D4BC9DA7ACB0768593949EACACB2BD9899A39697A0
9096A13E4A5B42485A766D7A7F6D76836E778970788C6E73906E74926E759772789C757A
9D757AA2787B9F7678A07A7BA48182A4807FA78282A88282AA8382B38B88B28E89B6948E
B5968CBA9D8FC0A395BC9E8FBE9E8FC3A495C2A698C9ADA0CBB0A2C9B1A1CCB4A5CDB6A7
CDB6A8D2BEAFD1BEB2CCBAADCEBCADCCB9A8CBB7A6CCB9A9CFBDAFD1BEB0D3C2B3D2C2B6
D5C3BAD4C3BAD0C0B6D5C8BED3C7BED2C8BECEC4BBD0C6BED2C9C1CFC7BFD1CBC2D5CDC4
D5CBC4D7CFC8D4CEC8D2C9C6D4CAC5D2C8C1D5CCC5D3CAC5D1C9C6CECAC6C9CACC7A94AF
28497BAEA9D7A1506CBF1C2ACD121ACF1015CE0F16C71414C22523B73337A82E3D9F2539
9D2035C53E4DBE1924C91017CC0D14C70D12B10F13C15D5FD1ADAEAEA7A8A8ACB17E8CA2
263158865875911224AC0511B0010BAD020CA60713861A25DBB7BFCDCFD7CAD3DDC6D0DB
C5CDD9C5D0DAC5D0DBC4D2DFBBCFE87590BB0B2669011A6801146501126000115E00125E
02155B051D572A416D4C60807E8DA48492A6627392061B48223A606A7C8F6B74882B3552
04112F4755606A625A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D1B498BDC1C7808F9F9AA4B39CA0AC9DA0AAA5A8B2
6F7886233247484D62796F7C816E78836D77876E788A6E74907176906E74967278997279
9A7176A2797AA07879A27E7FA27E81A57F81A27B7BA98181AA8382B08A87AF8C86B6948E
B9978FB99B91BFA096BF9F94BF9F93C7A89BC3A79AC8AC9FCAAFA0C6AD9CCCB5A5CAB4A4
D0BAABD5BEB1D6BFB1D4BFAFD5C1B0CAB5A5CEB9A9CEBBACCEBDAFCEBEAFCEC0B0CFC1B4
D1C0B7CFBFB7CEC1B9C3B8B3C8BEBACDC4BED1C7BFD1C7BFD3C9C3D0C8C1D3CCC4D3CBC3
D3C9C2D5CDC5D3CCC4D4CCC5D5CCC5D3CAC3D6CDC8D5CBC8D3CAC7D1CCC9C9CACE859DBB
254579A4A0CDA85671BF1D2ACF1119D21115CF1015BC1713E87972D49494A26F7F965972
943C579D2037B51321C70F18CC0C15C50910BD0C13A51F25D09092B9A8A8A8A7AABFCAD7
3043666253787E2037A10916AC030EAB010AA8040E8F0C18BB7A85D6CED4C7D2DBC6D1DB
C6CFDAC4D1DAC4D0DCC2D1E87A93C00A276D011A6D01176A01146401165F01175C021C5B
0C255D6C8BB289A3BDA5B9C9ADBFD08CA0B7324871041C475A71897A8A92727B83606878
0B192F36465263625C13CD0900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C6A785BABCC18E9CAC9BA6B5999EAA9EA0ACAAAFBC
59667C091A3752556B796B77806D76826C75856D768970778F73789472789671789A727A
9A747B9A7477A17A7CA67F829F7A7DA67F81A57F80AB8385AA8283A07A79AF8D89B2928C
B99A94B89991BF9F97BE9F93C1A294C3A797C4A898C7AB9CCBB0A1CBB2A3CAB3A4CDB7A6
CAB5A5D4BDAFC2A896BCA38DDCC6B1CBB5A5CDB9A9CCBBABD2C3B4CDBEAFCEBCAFCFBFB3
D0C0B8C1B6AEA59A92ABA19CA99F9D9E9794C8C1BBD1C7C0D1C6C0D3C9C3D3C9C3D1C8C1
D3CAC4D2CBC4D3CDC5D3CBC4D4CCC5D4CCC8D6CECCD4CCCBD2CAC8D0C8C7CDCACDA7B7D1
26467A6974A7B37797B41F2FCE141BD11014CD1013B81A18EB948FCEB1AEC1B6BBA49BAB
6A547184506F9E324BB31524C50D18C60910C10A10AE1117C76B6DE6C9C8A6A5A5B6BFC6
647690272D547F4260920E1FA70411A9030DA7020B9B09148D2F3DDEC6CDCAD0D9C5D2DB
C6D1DCC5D2DCC1D0E294AAD0142F72031D7201186F011569011763021E5C2745737591B7
1E3B617D9DB95E798EA3BACD7B95AD4C698F021A4A1B3456697D897182866F7C7F6C787F
222E3E2D3B466B6C682FA51F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C29C75C0BCBF7D89998A94A2A0A6B2A5A6B2828897
29385408163758586D7769747D6971806A72846B74886E758C6F77916D7799717B9C777E
9D7B819B787DA07A80A47B81A0777C9E7779AD86899F777AAE85889D7675AD8A84B3938C
B5958FBF9F98BE9D95BE9F90C0A290C2A593C4A896C1A593C6A99AC5A99DC6ADA0CBB4A5
CFB8A8D5BEAEC5AA97C9AF99D9C1AECCB6A5CBB6A5CDBCACCEBFB0CEBDAFCFBEB1D2C1B7
CCBEB7A39892C2B8AECFC4BACCC1BCB1ABA7B0ACA6D1C8C1D1C6C0D0C6C0D5CBC5D3CAC4
D3CEC8D0CCC7D2CEC8D1CCC6D1CAC4D4CCC9D5CCCBD3CCCAD3CBC9D4CDCCD0CBCEC5CCE0
3C5B8B2A447BAA8FB4A2263AC91720D01015D01117BE191BD46F6ED6B2ADC1B7B5BAB8BB
A9AABA575879704F77A63D59B81422C20A12C30A0FB80D12A82D31D09B9BA79D9D929798
8A95A424335771557A80172D9F0516A5020FA5010AA10512830C1BC4959ED0CFD8C5D2DB
C5D3DEC2D0E0ADC2DE27427C021E6F021A7000176A001A630B2862567399A3BCD48399B0
5E758B61788B728696778CA14964880520520A204D556B7F6B7C82717F826E797C6E797E
35424F28373F676C6839B22D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0065D344C4BCB97279889FA8B4A9AFBAA9ACB77D8192
1B24450C1739626276766A747C6973816B74856C75856A7290717B916D7997717A967279
9C7A80A17C84A27A83A57C839A7076A1797BA77F81A27A7DB28B8DA27C7AAA8681B4928C
B3928ABA9B92BD9D93BB9A8FBF9E91C2A291C5A796C4A797C7AC9CC8AD9FC7AB9ECAB2A2
CBB5A6CFB8A9D3BBABD2BBA9D1BCA9CBB6A5CEBAAACEBCACD0C0B0CDBEAECEBDAFD3C2B8
CDBDB8A69A95CBC1B8CCC2B7CDC3BBBCB6AFACA8A0CFC8C0D0C8C0D1C8C0D4CBC3D2C9C2
D2CBC6D1CDC9D0CDC8CFCBC7D1CAC7D5CCCAD3CCCAD4CCCAD4CDCBD1CAC9D1CACBCBCBD6
778DB21E3F73767BA9A64F67BE1A27CF1219D01118C7161BBA373BE6A9A7C7B3B0BEB7B4
B1AFB4939CB52C3768966793A01B33BC0C18C0070DBD090DAB1318BA6466BFA7A59B9B99
B9C1C75C6C873B38617E365394091DA20210A5020CA4030F9208159A4D59DBCCD4C9D1DB
C5D0DFBFD0E74F689703216B011B70001A6B0120651C3E707C9ABAACC3D5B5C6D66D8296
98ADBF7E93A3A6BACD6D85A4132C5F0621533D567496AAB3849095748082757E80707A7D
3C495525363F596360675C4D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC735CFC2BA7E84928992A099A0AB989CA78F94A5
202849131B3D6B697C766A737B6B75816D77867078876D778E707B916F7A96717A97737A
96737A9F7981A07A81A47C81A17A7DA68083A78084A78083AB8587A07B79AA8483B28F8C
B4938BB8998FBF9D93C3A295BF9E91BE9E90C4A695C5AA99C8B09EC5AD9CC4A99AC7AC9D
CAB2A4CCB6A7CDB7A7CBB7A6CEBAAAD2BEADCCB8A7CBB9A9CFBEAFCDBEAFCDBEB0D1C2B7
CFC0BAA49894C8C0B9CDC7BDC9C3BCA6A198C1BBB1CFC9BECFC8BFD0C9C0D4CCC4D4CCC4
D3CBC4D5CDC8D3CDC6D2CBC7D2CAC8D2CBCAD1CDCBD2CECCD2CBCAD0C8C7D1C8C7C9C4C7
B3C0D63A5883374F86B383A5AE2334C9131CD01119CB1017BC1C23DB7D7ED1AFABC0B4AF
B6B0B0B0B3C14E5F8A5D568A953859B41222C10911BF0A0DB30D139E2D31E7BDBCB7B3B2
A0A7AA8D98AC1C254D7D5679820E25A10516A80310A5020E9C0613831C28D8B5BDCECFD8
C6D1E397ABCE0F2A6B021E70001A6D04256735598898B8D2B1C7D8B2C2CFB0BFCF435B73
6A859F6E8AA46280A51B3569031B56213963788C9C7B8B906974796C787971797C737D82
394854283A4256615C5C544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C12ADAC8BCA2A8B5A4AFBE9CA3AEA1A6B1B1B7CA
242D4D1A21426B6979766B7373646E826F7A826D76876F778C707990707A96717A946F76
98757B9C797F9F7C819E7B7EA58486A07F82A07E829E797DA983859E7878AE8786AE8787
B5918CBA968DBD9B8FBB9D8DBC9F90BDA191BCA18EC0A793C7AF9DC7AE9DC7AD9DC9AE9F
C9AFA1D0B8AACFB9AACCB9ABCBB9AACDBAABCAB5A7CDB8AACFBEAFD1C0B2CEBEB1CDBEB2
D0C0B7BEB1AAA29892AEA6A0A8A29CB8B0A8CEC7BCCEC6BCD0C9C1D0CAC2D1CCC3D6CFC8
D3CBC4D3CBC4D5CDC4D3CCC5D1CBC8CBC7C5CDC9C8CECACAD0CCCACEC8C6D1C8C6CBC7C5
C2C9D4889EBD27487D8F87B3A63F54C11924CC1019CD0F15C6141BBB393CE7A9A7C2AFAA
BEB7B2B4B3B6909DB92B386C93628CA1192EC11019C00A10B90A109D1319BE7778AC9A9A
98989B9498A540486A56486F7C264099081AA60311A5020DA10410890B18B37882D4CDD7
C2D0E744608F02216A011F6D0627685377A1A6C4DBB3CAD6B7C8D3B8C6D1B3C1D05B7088
2B466559779C0420530019521B335E63778F737E886F797D717A7D6A76766D777A6C7A81
293A492F444D5865605D564600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D7C4B3ABB1BE98A4B499A1AE9EA4B09A9EB2
292F4E2327446D69777569715E50597C6C75826D75846C738B6F758E6E76916C76957079
9B757D9B757C9D797E9D7B80A483879172779173789C7B80A68084A57D7EAC8484AD8585
B28C88B49188B9988DBC9D8FBB9F91BCA18FBEA391BAA18EC5AC9BC5AD9DC9B0A2D1B8AA
D1BAABCBB5A6CCB6A8CCBAABCCBAABCEBCADCAB8AACDB9ABCCB9ABCFBCAECCBAABCDBCAD
CFBFB1CCBEB3CCBEB6C5BBB4C9BFBACEC5BECDC5BDCEC7C0D0C9C2CEC8C1CFCAC3D4D0CA
D2CEC8D5CFC9D4CEC7D4CDC9D1CBC9CBC7C6CBC8C8D0CDCDCFCCCACEC9C6CEC6C4CEC7C4
C7C6CABEC9DC5B77A0485C8FB47A99B22131CE141FCD0E15CD1119B81A1FD87879CBA9A5
BAB3AEB4B3B1AFB6C6465A8564588B933151B40F21BE0914BA0810AC0F16AA4548C9A6A5
B3ADAEA4A6AD8991AA262C54814C6C8C0F22A10411A6020DA603119607148B3340DCC5D0
AEB9D5122F6902236C082B6D5D80AAB0CCE2B8CDD9BBCDD5BCCBD4BAC9D5B0C0CF96A9C1
50678D0F285800194E1F3D6671879EA6B6C0939DA4808A8D8690936B767769767A61737F
12243B4155615A67645D584C15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D3BBA6BBBEC99CA9BBA2ACBAB0B5C187899B
4449652A2D466C677473676F74656B7D6A737F6A71836B708B6F748D6F7596737D97707A
9A727A9F767BA27B7F9D787D9771798A696F896A6F896B6FA38183A68080AD8685AC8483
B28B86B38E86BC9A91C1A197BFA295BC9F8EBC9D8CBCA08FC6AB9BC8AE9FCDB4A5BBA392
C9B4A1CDB7A8CBB5A7C9B6A7CBB8A9CDBAACC9B7A9CBB8AACEBAACD0BDAFCDBBACCEBCAE
CCBFB0CCBFB3CFC1B9CBBFB8CFC4BFCFC5BFCEC6BFCDC4C0D0C8C4D0CAC4CBC7C1D5D4CE
D5D1CED4D0CBD3CECBD2CBCACFC7C8CCC8C7CCC9C8CCCAC6CECEC9CCCAC6CBC7C3CDC6C3
CDC6C8C6C7CFA1B2CA2545769F8FB89F3247C41622CF1218D01118C11118B63337D99D9B
BBACA8B4B2AEB2B5BA8A98B5303D738C5582A0142CBA0A17B90510B1081196161DC78B8D
D1C3C599999E939AAA2A355B6853787C1D349D0818A3020FA3010F99020E7C0C1ACEA1AF
9093B008215F0325684B709EABC8E1B8CCDABACCD6BACBD3BBCBD5BCCEDEA2BAD56983AE
163267021B51112C5866809A8294A196A5AB717D836F7C7F6C777A63727461737C3F536C
05193D48617557696B5C5E552CA21B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00CAAF92B9B9C2929EB09BA6B5A0A5B285899B
3E45602D324A6E687574696F776A6F7B69707E696F81696E856A708D6F7890717995717A
9A72799E7278A2767EA379838E646F9E757EA07D81866A6CA18586A48383AB8988B08A88
B69089B7928AB59389BFA195BDA093BEA091BFA091C1A192C1A595C2A796C8AD9BBEA490
C8B19EC6B1A1C9B5A6CAB7A8CCB6A8D1BAADCBB6AACDB6ABCEB8ACCDBAAECEBBB0CEBDB2
CABDB2CDC3B9CEC2BACCC0B9C9BFB9D0C7C0CFC6BFCDC5C0CDC7C1CEC9C1D2CEC7D3D0CB
D3D1CED1CDC9D4CFCBD2CCCAD0CCCACDCBC9CBC9C5CECDC7CDCDC7CBCCC7CCCAC6CDC8C6
CDC6C6CBC8CAC4C9D74D6892546395AE6E89B41D2BC91118CD0F14C80F15B8191ECF7070
CBA8A5B9B0ABB6B5B5B5BCCC4658864D3C6F89203EB3101DBC0912BA0B14A50D15A5474C
B395959B97989596A06069863535607D3E5D910C229E0212A1000F9B020E8A0714A15666
7F7192061C571B40779FC0DDB7CCDEBBCDD8BBCCD7B8CAD7B6C8DDA1BADA486698042562
031F581C365F6E839E657585738189707E816B747A6B767A6774795A6E763E51690A1D48
011345132A4E4E6473585F5C41752900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0094BE69C5C3C87B889897A0AE9499A4ABB1C1
1E27423B41586C697571686D74676B7C6A70806B71816A71886B768A6975916E7999747D
9D757EA37980A0757D9E757E8B626C9E767BA28182A18C8BCABABBD0BCC0B2979CAC8A8B
B38F8CB28F88B49388B99D8DBEA292BB9D8EBE9F91BFA192B79D8DB49C8EB9A496BCA897
C1AD9CC3B09FC4B1A2C5B2A4C9B2A4CDB6A9CBB4A8CBB3A8CBB5AACBB7ADD1BFB5CEBDB5
CDBEB6CEC2B9CDC1B9C8BEB7C5BDB6D0C8C1CEC5BECDC5BECEC8C0D0CAC2CFCBC3D2CFC9
D2CFCCD3CFCCD1CDC9D3CFCBCFCCC8CFCDC8CAC8C5CBCAC6CBCBC6CCCEC8CCCCC7CCC8C4
CCC7C4CDC8C7C8C6CE96A6C429477CA391B5A02E42C31820CC1016CE1016C7161AB43234
DEA4A2C1AFACB9B4B4BBBEC58998B630396B93577CA3192CB90C16BE0B12B20B13941A20
C39091CDC5C7A2A2AC8D94A9232D5776567B7B10299703159F010F9D020D970511811323
784B6E0C1A504971A0B1CFE8B7CBDEB6CADAB2C8DDA5BFDE748FBB1E3C73011F5C02255A
46618672889D9DAEB985939BA6B5BA7E8C928B979F71818C6376882F4561061843010F46
000B46000F4224375656606655493D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0061D245D2CCCE909AAAA4ADBA9CA1ACA0A7B7
1B26403D4A635E637565626E71656D7D6B717E6970836B748A6C79886674906C789D7682
9D74809F777FA37A8199717A8B666D957779B09B9BDACED0DBD3D9DDD3DAD6C4CBA5898E
AE8A8BB5918CB7958AB99A8ABB9E8EBA9A8CB99A8BB4998BA58F839481788C7B7391847A
B6A69ABEAC9CC5B1A2C7B1A3CBB5A7C9B2A4C9B3A6CDB6AACBB5A9CDB9AFCFBCB6D3C1BC
CEBEB7CBBEB5CBC1B9CBC3BCCBC5BDCDC6BDD0C7BFCEC7BECFC8C1CDC7C0CFCBC2D1CCC6
D2CECAD2CFCBD2CECBD1CDCAD1CDCAD0CDC8C9C7C3CDCAC7CCC9C7CACAC7CCCBC6CCC8C4
CBC7C3CBC7C5C9C7CBBFC6D544628E596997A76580B31F29C91219CB0D13C90E14B4171A
D17475CBA9A6BCB2B0B8B6B9B6BFD23D507B72608D952E49B30F20BD0A14B205109F0D17
B15F67C8B3BAA09FAB999CAA4551744B456D752643940B1D9F02119E020C9B010D880512
8237531D1B4D33598E9EC5EEA9C8EB95B3D76382AF20417903266401215C1A3C6C688CAD
89A6BCA7BCC891A2ADA4B5BF93A4AF8497A36F8295415773142850011145000C43010A42
010A43020E44091A444A5A685A564E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0059C837D4CAC6848E9B98A1AFA8ACB8858A9C
2632501F2F56142148313654645E6D7A68717F69718368728A6B778D6D7991707A977380
9C73829F7580A37A829A727B836268857072D0C5C6CFC5CBA497A1A89AA4E2D2D9AB9196
AC8A8BB18C87B7958ABD9D8FBB9E90B29486B19585AA948784736A9B8A83A5948E746964
9B8F86B9A799C1AA9CC2AB9DC7B0A2C6B0A2C5AFA0C9B3A6CBB6AACAB8AECFBEB6D2C2BD
D1C3BDCBC0B6CFC6BDCBC3BBCAC3BACEC5BCCEC6BED1CAC3CEC7C1CEC8C0D1CDC4D0CCC5
D1CDC9D4CFCED4CFCECFCBCAD0CDCBCDCBC8C8C7C4CECBC8CDC9C7CDCAC8CDC8C4CDC7C3
CBC7C2C8C4C1CBC9C9C5C7CE8B9FBE254577A490B59D2B3CC1141ECB1015CB0D15C21117
B53439DDA0A1C1ACABB9AEB1C2C0CB818AA847426BAF6884AA172BBB0A16B5030DAB0912
98252CB78B8FAAA2A99B9EA5747E99222A54744668820C1F9B03119E020C9A000C91040F
7D1C30563E620D245C193D7C1D3F7D0B2C6802226103245F1A3A6A647FA55978988FAFC8
2F4C6191A6B55D6E7C7B8A95637381596E86223960031647000C46010A4701094200083F
000A40020E4402123F41546761646010CB0800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0051BF28DBCFC39199A5A3ACBAADB0BD858A9F
2B355B020E41020C440A123E605D757767727E6A718068718669748E6E79907079987480
996F7D9C717D9B717A9B727A9C797E988083DCCFD5AB9BA5A189939A8289DDC9CEAA9396
A88A88AA8881B19086B8988CB39488B09184AE90849884797D716A9B8D8A978A8A736C6B
847C76B4A599BCA798C0AA9BC5AFA0C1AA9BC4AE9DC7B3A5C7B4A8C9B8ADC9BBB1CEC0B9
CEC3BBC8BEB6CEC4BFCAC1BAC9C2B8CDC5BBCEC7BFD1CAC6D0CAC4CEC7BFD0CAC3CFCCC6
D0CDC9D3CFCED2CDCCD1CDCBCECBC8CECDCACECCC9CCC8C4CFC8C5CFC8C6CFC8C5CCC6C2
CCC7C3C7C3C0C9C5C5C7C6C9BCC5D73C5B876170A0A05E77AE1A28C60F18CE0F17CA1117
B4151CD86F75D899A0CE9CA4CD9CA9C99CAFA87793D37C93B01E2EBB0B16BA0611B30610
9C1118AF6C6DDED3D4C0C7CF8B95AA2A3A6056466C70152B9307149C020D9A010C94020D
760814B98B9D6F71932C3F701D33681D36683C57816E88A8A3B9CEB8C7DA4D6177647C8F
657D8E7C939F899CA58091988999A71F355901134A010D48010946020A4502094100093E
000B3D01103E02113B32455B63686827A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DAC9B9949AA89DA7B79DA0AF7C8198
0E173F020B40010843030A3D514F6D7365737A676F7B666F836974886974916F7A95707C
976F7B9B707D9A6E79986B759E767D9E8287DFCDD49F8892A6878F9F8389D6C0C5A48C8E
A88986A7857EAE8E84B29287AF8F84AF8E80B09184917D737065627C7376756F72686262
7B726CA39489BBA799C0AA9BC3AD9CC3AD9CC4AF9EC4AFA0C7B4A6CAB9ABC6B9ADC9BEB4
CEC3BBCBBFB8CBC1BACCC3BACAC3B7D0C9BECEC6C1CDC7C4CFCAC5CECAC4CDC8C3D1CDC8
D1CFCAD2D0CBD1CECAD0CCC8CFCCC8CDCAC7CECBC9CFC9C7CBC4C1D0C9C6CDC9C5CCC7C3
CCC7C3C7C3C1C7C4C5C7C6C6C5C7CF8C9EBC2B477B9C88AE9A3044BB1823C60F16CB1318
C31218BA2129B2303BA92F3AA72A38A82A3AA52635B12431B6141EBA0C15B50910AF0A10
9D1116974A4AC1B1B5979FA78C96A65768862D305A703550880A1C9A030E9B010B96020D
8307119A5862D5CBD6BBC6D7B1C1D5B1C3D8BACCDCBACCD8B9C6D1BAC5D0A1B0BF8AA0B1
AAC2D56D8CA29CBACF748F9C9DB2C122395F00124D010C49010B4500093F000A3C010E39
0E1E3F293B5511254122364B636C6F2AA52100FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00D4BCA99EA1AE9DA8B98C91A27F859D
02083001063902074102093E4545667467797765717E6A72886F798E6D7992707C916C78
97707C996F7B9669739E6F79A0767F98787FDBC6CBB29DA3A2888ECDB4B9B69DA2A7898B
A5817EAA857DAD8981AD8A81AF8C81AF8F7FAE907FA48A7F6E5B58695F5F655E5E7B736D
9C8F849F8E80BDA799BDA797C1AC9AC1AE9DC4B0A0C5B1A2C8B4A5CAB8AAC8BBAEC9BEB4
D0C2BCD0C2BCCDC4BACCC5B8CBC4B8CDC6BBCEC6C2CEC7C3CDC8C4CAC6C3C9C5C1D1CEC9
D3D0CCD6D4CFDAD8D3D5D3CED1CECAD1CECAD3CFCDCFCAC9CBC6C4CCC8C6CECBC9CEC9C7
CAC6C6CAC6C6C9C7C7C8C8C6C7C6C8C0C5D46B7EA44F5882A0718C9F303FB22025B71B1A
B81E1BB4201EAD2222A82122A71F23A92327A82627A92726A62323A52324A1242299231F
8B28269E6664A297999EA4A9A2AAB9788AA118284F6B4C6F7A0F269504129C010D98020C
9107127A202BD7BBC5C8CCD4C3CFD8C0CCD8C0CDD8BBCCD5B7C6D2B5C4D1B3C4D7486381
43618D0421571C3B6E385B78648090374E6D02134B000F4B000E45000F3D07183B26394D
475A634F60662F4352182C3F5D666D55483F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CAAE94A2A2AB99A0B37E8599424966
01062E01043401063E02083F3F3F637267797B69737F6871886C768D6D788E6E78906C74
9770789B7179956A6F9C7177A0767DA07E83B2999DD9C6C9D1BCC2B69DA2997A7EAB8986
A5827AA9857DA9837BAD867FB08C81AE8D7DAE907DB194859F877B927E759180778D7B71
9A8579B59E90BDA596BDA896BFAA98C1AC9DC5B0A2C5B1A2C4B1A2C8B7A8C9BCAEC9BDB3
CDC2BAD0C6BECAC3B9CEC7BDC7C1B7CDC7BECDC7C1CDC9C2CBC5C0CDC7C4CFCBC6D3D1CB
D7D5D1D7D5D1D6D6D2D6D4D1DAD6D4D7D2D0D2CECCD0CCCBCCCAC9CAC8C7CDCACACCC9C9
CBC7C7C8C4C4C8C7C6C6C4C0C5C2C3C6C4CAB9BCCD9098B1827C91AA828DC57E7FC77872
C87770C77C71C58177C4837BC88781C88B83CB9189CD9690CD9691C8928EC48F8BBA8883
AF8985B5A5A2949698C0CAD1BBCBDA94A9BE31456748436872243E8E07179A020F9A000C
96030F7D0B18B8838DD2CCD2C5CED8C0CCD8BCC9D6B8C9D5B8CAD79AADBE72889E455E80
05225C02196201175D1835616B889A5C728C01154801134B05164220324D465864566668
5866645460603E4E5914253558676C625C5500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0098C26CACA8AF84889B84899F141939
02062E01043401063D020A3F3C3D5E7868797F6672856975886A758B6C76916F788F6870
986F769A71769B71759A70769E767D9E797E9C797DA08287A5878CA281859D7678A57F79
A7847BA27F76A58075A9847AAC8A7EB19183AD9080B09685B89F91B8A191B49C8DB59D8F
B99F92BDA395BCA394BEA895C0AA97C2AB9CC4AEA0C7B2A3C8B6A5C8B7A8C8BBACC9BFB4
CAC0B7CDC3BBCEC5BFCDC5BFC6C0B9CAC6BFCCC7C1C9C6BFCBC7C0CFCBC6CFCBC5D2CECA
D9D6D1D7D5D0D5D4D2D3D1CFDAD6D5D5D0D0D3D0D0CDCDCDCBCACAC9C8C8CCCBCBC9C8C8
CBC8C7C8C6C3C6C5C2C5C2BFC6C1C1C5C2C3C4C0C4BFBEC3BDBDC3BFBBBCC4B7B3C6B7B1
C7B6B1C1B4ADB9AEA8B8AEA9B7ADA9B2A8A3B0A7A3B6AEAAB1A7A5AFA8A5B1A8A6ABA2A0
A6A1A1D2D4D5B5BCC2A1ACB76B7B8D7083976779951F2850784868840B229903149A010F
9A02108F09168D3D48DCC9CFC8CED9C2CFDBBFCDD9B7C8D3B7C9D696A9B8768C9DA9BFD5
1B326503186102155F041A4E59758D748CA0071C41172C4F3E516654666C5B68685B6663
576160535E603C4A5415253257686D79797410CB0800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065D549BCB4B48A8EA1696D87070C2E
00042E020533010639030D3D3F3F5E766475816674866A77896A778E6C788E69748F6772
976F789B71799E737B9E737BA078809F767D9D7277A4797CA57B7DA1797AA27779A47978
A67E79A07971A37D71A68374AE8E80B39688B19585AF9585B39B8CBAA192B8A08DB9A28F
BAA292BCA395BEA697BEA694BEA793C3AC9BC2AC9DC5B0A1C9B5A6C8B6A8C7B9ABC7BDB2
CABFB6CCC2BACFC6C0D0C8C2CBC5BECAC6BFCAC6BFC7C4BEC9C6C1CECAC6D3CECAD4CECB
D8D3CFD9D6D2D5D4D1D3D3D1D9D6D5D5D1D2D0CED0CACACCCAC9CAC9C8C7C9C9C5CBCAC6
C8C7C2C8C7C2C6C5C1C5C4C1C3C2C1C2C1C0C2C0BFC3BFBEC0BFBEBCBCB9BBB9B6BBB8B6
B9B7B4B6B6B3B2B1AFB0B0ACAEACA9ADABAAAEACAAADACA9ABA9A6A6A4A3B6B7B6B9B8B9
9F9EA3A3A6AA989DA3949AA199A0ACB9C6D295A6BC23345D654E777715319405199B0210
9C010F9305107A1420CFA8B1C9CBD5C2CED8BFCDD7B6C7D1B8C9D5B8CAD8768DA1AFC6DB
42567F01135600125901164A4A6580657B884D60705A6D755D6F715A6B685B69645D6963
5B65655763672B3D481C303C55676A8B8F8C239C1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005CCA39C6BBB7737B8C4A516B000528
03072E16163C22234A070D35494965746374816A778569778766768864728A66738E6A75
956F7A9D747F9C727B9C6F7A9E727BA0747CA4767DA6787CA6797BA4787AA17477A37678
A276759F7470A47C71AC8879B19082B59687B59889B69A8CB89D8EBA9F8FBA9F8EB9A28E
BBA292BFA697BDA496C1A797C0A794C4AD9BC3AD9DC7B1A3C7B2A5C7B5A9C7BAAEC7BEB3
CAC0B7CDC4BCCBC6BDD0CAC2C8C2BACAC3BFCEC7C3C8C4C0CCC9C5D2CFCCD5D2CFD4D1CF
D4D0CDD3D1CDD2D0CDD4D2D1DAD8D9D5D2D3D0CCCECCC9CBCCC9CACBC9C9CBCAC8CDCBC8
C9C7C3C8C7C2C7C6C2C4C5C3C0C1C0C2C2C0C3C1C3C4C1C2C0BFC0B9B7B7BEB9BBBBB7B7
BAB6B5B7B1B0B7B0B0B5AEADB6ADAFB2A8AAB1A5A7ACA4A2B0A5A5AEA1A1A69E9DB1A9AB
ABA2A79F999EC4C1C5BCBABFB1B0BABFC7D79AAAC64152793F37617B2F4B8F0A1D9A0311
98000D92020E810816A2646ED3CBD4BFCAD3BDCCD5BBCBD5BAC9D5A0B2C12D435B5C7289
6B7D990D2051041853051B4860778C6E81886F7E816878775F6F6D5E6C685B69645D6A64
5B6867526067112332253D474B60618C94922BA52300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02ACDBBB0868B9A343C5902072A
0A0D2C49415A4E455E0E0E2C57536C7A6B7C7E6A77806875866576866172835F6E886270
9169759B717C9B707B9E727CA0727C9C6E77A3727BA6767DA4757A9E7073A07375A07275
A27575A37876A88179AD8B7DB09081B29283B49586B39587B39587B59889B69C8ABAA08D
BBA191BCA294BEA496BEA393C2A997C1AC9AC2AC9EC7B0A4C7B2A6C7B6ABC7BCB0CAC2B7
C8BEB5CAC1B9CAC2BBCEC6C0CBC3BEC8C0BCCDC4C2CDC6C4CCCAC7D3D3CFD5D5D4CECECD
CFCECED3D1CFD6D3D2D4D1D2D2D1D2D4D3D4D2CED0CFCBCCCCC8C8CAC7C8CCCBCBC9C8C7
C8C8C5C3C3BEC4C4C2BDC3C3B8C2C4BEC1C5C4BCC2C7BABEC6B4B9C6B2B7CAB1B7CEB1B7
CFAAB3D2A8AFCCA1A8CA9DA2CA99A2C9939DC48D97C08993C18490C0828DB97D84B87D84
B97C87B27985D3A0ACDAABBAB07F949C728C724E70866888623C5A9F4C638B08199A0212
98010E91010C8804137B2633DBC1CBC5CBD5C1CCD8BFCBD6B7C2CF7E8E9B9AAAB9708390
B2C2D066778F2F43643348628697A46C7C826E7D7F6C7A78677172626B6A5E69675A6867
5363692C3D5002132C314B594961646F7D7C51474000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0052B920CFB8A68A8C9D1B234203092A
23243B5E5260564A5C15122A645C7279687777636F7B6370816271825C6E7E56678D6272
906571986D77966B789A6D7A9B6D799F6F7B9D6C77A27077A17177A071749A6C6EA07372
A07573A57A76A9827AAA8679A98879AF8F80B49686B19585B59888B69A87B89D8BBAA090
BBA091BCA193C1A698C0A797C0AA99BEAA9BC1AC9FC1ACA0C5B2A5C5B6A9C2B9ADC6BEB3
C9C0B5CCC0B9CCC1BCCFC5BFCAC2BCC3BCB5CAC4C0CCC7C5CCC9CAD2D1CFD1D2D0CECFCD
D0D0D0D2D1D2CFCED0CFCED0CECED0D2D4D4D1D0D1CCCACACACAC9C7C6C7C7C6C6C7C6C6
C7C6C5C1C1C0C3C7C99DABBA658096B4BACDBF9EABCA8894CA7884C56D79B75966B54E5E
B34154B13A4BAB3443A52D3BA326349F1F2EA01E2D9C1A2AA0192B9C17279C16239B1824
9A16259A17279B1A2F961A30971B3092172E901A33891A308A1D2F9317299706169C0210
9A010E93000C8F02127B081AB67086C4A0B8C5B0C7C9BDD0C9C4D2A4A7B2BFC9D196A7B2
9EB0BC8EA0AA70838D6D7E8569767C6A76796F7B7C6F7A79676F71626C6D5D6A6E50616B
293A51041234000C2F152A42435A645666675B554E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B71AD4B6A08A8B9A101A39050C28
3D3C4B60555D5449571C172E6F657878657278626C7E63707E5E6D7A56668057688C616F
966A74966A75986C7A986D7B976C7B9C717E9D707A9C6C749D6E729D6E709B6C6D9D7370
A07772A67C76A88078A78276A78577AA897AAF907FB09384B39787B69B89B69C8CB89F92
BA9F92BDA294BFA697BEA797BEA99ABCA99CC0ADA0C3B0A3C3B1A2C1B4A5C1B7ACC3BBB0
C5BDB2C8BFB6CAC0B9CBC2BBCEC6BEBEB8B0CAC7C1CCC9C7CBC8C8CCCBC9D0D1CDD0D1CD
D2D2D1CFCFD0D0CFD2D0CFD0D1D1D2CFD0D0CCCCCCCBCBCBC9CAC9C7C8C7C8C7C7C5C4C3
C5C5C3C1C3C2C0C3C89DAEC42143728592BA92586FA42738B61E2CB91C26B91924BB1822
BD1623BD1421BD1422B7121DB61219B31015B4141BB01219AF1118AD1217AC1116A71012
A71013AA1116AB121AAA121CA50E18A40F199F09189B09179C0A169B09159F0A1799040F
9A020E96020D960212900416850C247A163279223E7B314A87495E8A65729E99A273808B
61727F7284886273776E7C7E6F787B727C7D75807F707B7A697274616C7054667420304F
010D37000735010733000B2F22364A54656A59565100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B414CCA88E827E8C060E2C080D26
5B566262545A514653201A2E72677876636F79616B7C5E6B7655647C5A69845C6B8F6473
966975986D78956F7E86687E7C637C8B6E8298717D9B6E769C6C719A696C9C6B6C9D706D
A27773A67C76A77F77A68174A68475A88776AF8F7DB29284B29588B09587B19B8DB49F91
B6A294B6A092BBA596BDA799BBA499C3AEA3C2AFA2C1AFA1C4B3A4BFB1A4C0B6ACC5BCB2
C8C0B5C9C1B7C9C1B8CCC4BCD0C8C0C4BEB8CBC8C4CBC9C6CBC7C6CBC9C5CBCCC7CECFCB
CDCECDCFD0D0D1D0D1CFCDCED0D1D1CCCDCCCDCECCCBCCCBC8C9C7C8C7C5C9C6C4C5C3C2
C6C5C4C4C4C4BEC1C2BAC3D24E6B973C5588AE82A0A22A38B81F26B71D1EB21D1BAF221E
AC2120AD2726AC2A2CA5292AA62F2CA6352FA43931A03B34A13D379F3E379E3F379B3E35
9B3E35A1443D9E3E3B9D3E3A973836933333923035902D328B242A851E24881C2386171C
8812198810178A0C168C0C188B0B1A890A1A880B1D850A1D7E0B206B18278C6F77A1A6AD
7E8C9395A5A78392948996977A83866E78797581816D797A6C76795A6973263854010D3A
01093B010836000734010A340616334559615257560CC80700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C79C7B7B717F060B2A0A0D27
6A616D64535B4B414D2C26376E667472636E775E697B5C68795664805B6A89616E8F6471
936775926C7E7B637D352F5916164A3831598E758A986C7698676B9766689C6C6BA17572
A47876A67876A27771A88277A58373AF8E7CB0907EB09183B09388AE9489AA988CAE9F93
B4A394B5A193BAA496BAA499BAA49BBDAA9FC0ACA1C1ADA1C0AEA2C1B2A7C0B5ACC6BCB2
C6BDB3C6BCB3C7BFB7CAC2BACEC5BFCBC5C0CBC7C3CFCDC9CBC8C4CECDC8CACAC7CDCDCA
CCCCCCCDCDCECCCBCCCCCBCBCDCECDCACCCAC9CBC9CBCECBC9CBC8C8C8C6C8C5C4C8C6C4
C5C3C4C5C3C4C0C1C1BCBFC794A4C12A44719A92AEAB7077BE6A69C77471CC817ACF8A83
D08F8ACF9791CB9894C99B95CBA09BC39F96C1A098C1A39ABFA29CBA9E98BCA09AC5ACA5
AB948CB49D96B8A09DB49D99AB9492B69F9EA98F91B0989AAA8F93AB8D90A78284A77C7E
A775799C656894575C8D4A4F8A41478133397C262E761A227415226416207D5C60BBBDC1
A7B4BB86959B8B979B6E7C7D707C7D6974746C77786875776572793F4F6504103C00083E
02083C010837010733000835000E302C41504D585A17921000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C092688F848B050C29171A33
5C515E64515B49414F36374B5A5B6E615A6C6F5D6B7357647A5A66815D6A885F6C8E6472
8D6476826480342C570A124C0610530D134B706180956D7A95656A9A6A6D9B6D6DA27574
A17271A57573A27570A87F77AC877AAF8C7CB49181B19082AE91869F8A7F8879707F746B
A99A90B5A195BAA498B9A397B9A499BAA79BC0ADA0C1ADA1BFACA1C0B0A7C2B7AEC0B6AD
C5BBB3C8BEB6C9C0B8C9C2BBCBC4BECFC9C4CCC8C2CECDC6CAC9C4CECDC9D0CECBCCCBC9
CDCCCCCCCBCDCBC9CBCECDCECECFCDCACBC9C7C9C6CACCCACACBCBC7C7C8C3C2C2C6C5C6
C1BFC3BEBDC0C1C0C3BEBFC2B7BBC88B98ACA6ABB9C4BABCCAB8B7C8B6B3C2B4AFC0B3AE
C3B4B3BDB3B2B6B0B0B5B0AFB4AEACAEACA9ADABA7ADAAA8AFA9A9AAA3A3AAA4A4ABA8A8
9A9C98989B99ACADAFACAFB1A6ACB1CFD7DEC4CED9ACBAC998ACBBC5D4DCC9CFD5C6C9D0
CDCCD4C7C4CAC3BBC2BFB6BBB8ACB1AA9C9FA48F929980867C5F6B755963756A6F8C9499
87959D6C7881717B816C777A6773746371716473736372745D6D7A142446020D43010840
01073C010837010833000A34010F351C2E444C5A5F28632000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B686539B8D90090F29323448
685C6862515B3A36472D36510E173A222543685D70715A66775A65815F6C886270896071
86627A59456C14124139396A20235B060D435A4D6F916C7A95666C98686B9B6C6E9F7071
A27372A97A78AA7E79A67E76A68075AE897AB08C7DB39184B4978C8C776DA6988F867B72
8F8279AD9E93B7A397B5A094B8A396B8A698BEAC9DC0AFA1C1B1A4BFB3A8BFB6ADC1B8B1
C6BCB6C5BBB5C5BDB7C4BFBAC8C4C0CCC7C2CCC7C2D0CCC7CCCAC7CDCBC8CDC8C5CEC9C6
CECCC9D0D0CECBCACACBCACBCACBCBC9CAC9C8C9C8CDCECCCACAC9C5C5C6C5C4C6C5C4C6
C2C1C4BFBFC0C3C2C3C1C1C1BFBEC0BCBFC0BABDBDBCBEBDBEBDBDBBBBB9BABBB6BAB9B6
BCB9BAB4B4B7B2B3B5B2B3B5AEAFB0AAACACA8A9AAABA9ADAAA7ABA4A2A3A5A3A59E9F9F
9EA3A2949B9AC7CFD1D0DADEA4AEB9B2C4D794ADCA7C97B357748BC0D6E5C6D4DFC5D2DC
C7D1DEC9D2DEC7D1DBC7D2DAC4D0D7C5CFD5C7CED5AEB7C4374458515D6D87929A839096
8E9AA38792997B858C838D9068747562737061746F5F707344556904123F040D48010840
00083C000C35020E300917360314331121384C5B6338333000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005EC631A28D8A1113292C2B3D
5D515A5E505A2B283F0E173D0109370C1239554F646E58647B5E6A836270876371876275
7A607C221842393259827191463D68090B3F5344678C64739463699A6A6B9E6D6FA06F6F
A1716FA67874A9807AA58077A58177AD8A7CB19181B49485B6998C8A756A85776D807066
8B7C6F8C8073AF9F95B5A196B7A498B6A497BAAA9ABDAE9EBCB0A3B9B0A5BCB3ABC1B9B1
C3BAB3C7BFB8C8C1BCC6BFBDCAC6C3CBC8C5CBC6C3CBC5C4CBC6C6CCC8C7CCC7C4CDC8C5
CCC9C6CCCCC8CCCBCBCDCCCECBCCCDC8CACAC8C8CACBC9CBC8C7C7C6C5C4C6C4C4C7C4C7
C7C4C6C1C0C0C0C0C0BDBFBCC1C0BEBEBFBDBDBFBFBABBBCBABBBABBBCBABABAB7B5B6B3
B5B5B7B0B4B6B0B1B5B1B1B4AFAFB1AAABADA9AAADA8A7ABA7A7AAA6A8A9A3A3A5A2A4A7
D1D5D7A6ABAEA7AEB4B4BDC698A2B07E8DA5304A6B768FAAA4B9CBC3D4E0C8D4DFC7D5E0
C5D1DFC8D4E2C3CFDDC4D2DDC2D0D9C2CFD8C6CFDA919CAB95A4B5708291AFBFC9B0BDC6
97A2ABA8B4BB738087768185677575657571637571607176253551000D42000944010B3F
02123A12263F344757475A6524354708182E4A5B663B3C3A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BD25AB8E831F1B2B2C2835
6F65695F515B1E193401063102093C050B35554D66735D6A7A5F6B7F5F6E826070856679
58486917103971607D876F89352C570B0D415B486C8E637198656A9A67699D6B6C9B6A69
A47471A67A75A47B75A58179A7837AAC8A7CAF907FB29382B095839682748D7C70AA9688
B5A293918276A5968BB5A296B7A498B8A69AB6A799BCB0A1BAB0A5BAB0A7BDB4AAC0B7AF
C3BAB3C3BBB5C5BEB9C8C1BEC8C3C2CBC7C6CBC6C4CDC8C7CCC8C8CBC8C6CECCC8CCC9C6
CCC9CACDCBCCCBC9CACCCACCCACACCCBCBCDCBCBCDC9C8CBC7C6C7C6C5C4C6C3C3C5C2C3
C4C1C0C2C1C0BEC0BDBDBFBCC0C1C1BDBFBFBFC1C4BABCBDBBBCBDB8BAB9BABAB9B4B5B6
B3B4B6AEB2B3B1B3B6B4B4B7B0B0B2B1B2B4AAABAEABACAFA7A8ABB4B8BAA7AAAC9DA1A2
A6AAAE9AA0A392989D848E97ACB4BE949EABB0C3D7BCD5EBBAD1E2C4D7E0C2D2DAC4D3DE
C4D3DFC6D3E0C7D5E1C6D4E0C3D1DCC1CFD9C3D0DB9EAEBAB5C7D3A9BCC68A9BA7A4B2BE
7A879178858C707C816E787B68737467767262737160727A122246010C44010E4303163F
20364D4961664F62614F5F5F44525B06162A475A663339380DC80700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD10B28D76463E48443F4B
62585B584C55120D2801053103093E030735564C69745E6D785B6A7D5D6D8262727B647A
2E254A372F5489728A7A64811712440E0C436E57778D616D98646A9A656A9C696C9A6968
A27571A27772A27872A37B75A9837BAB887CAE8D7EAD907FAE96848C7968A89788B29E90
B5A0939C8A7FA29084BAA798B9A699BBAA9DBCAD9EB9AD9FB9B1A6B9B3A8BBB4A9C4BBB4
C4BAB7C5BCB8C5BFB9C6C2BDCAC5C2CCC8C4CDC8C4CCC8C5CBC8C6C9C6C6C8C6C3C9C7C5
C9C7C7CECCCDC9C9CACBCACCC8C6CACAC9CDC8C6C8C8C6C9C9C9CBC7C6C8C5C3C6C1C0C2
C0BFBFBFC1BFBDBFBDBABFBBC6C8C7C9CCCDBEC1C4B7BBBBBCBDBEB8B9BAB7B6BAB3B4B7
AFB0B3B0B3B5ADB0B1ADAFB1ADB0B2A9B0B0ABAEB1A7AAADA8A9ADA1A5A99FA3A69A9E9F
979C9DA6AFAE9DA7A9A8B3B8D0DCE3B6C5D096ABBD59799983A4C0BFD6E2C3D4DFC3D5DF
C2D1DCC3D4DFC5D3DFC4D2DFC3CFDCC0D0DBB7C8D88298AF6F889A6E85925C6F7E7B8994
717E8777868A7683866D787B6873736474705E716F5D6F7A09193D010C42011040223651
4D6368546763566660535F5E4A576008182B425A672635390BC80800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B68A685E525666626E
685F654E46510A082402053102083D050A3B494161705A6B7C5E6C8261718264776C5A74
1510355F517290769056476D0B0C441B1649795D7790626E97636A9966699C6B6D9D6D6D
A07170A27672A77A76A37974A78077AC877BB18F82AE9283AD95868A786AA49388AE9C91
B29F95928074AA9788BAA597B8A699BAA99CBBAC9EB9ACA0B8AFA5BEB6ACC2BBB1C2B9B4
C3B8B6C0B6B4C4BDB8C6C0B9CAC5BFCCC8C2CECAC5CCC8C4CBC7C7C9C5C7CBC7C7CBC7C6
CAC6C6C8C6C8C8C8CAC9C9CBC7C6CACCC8CDCDC8CDC8C3C9C9C6CBC5C4C7C3C4C5BDC0BF
BBBEBEBFC1C2BABDBCBABEBDB8BCBDB8BCC0BDBFC3B9BDBEB9BABBB6B7BAB5B4B9B2B4B8
AFB2B5ADAFB3ACAFB1AFB5B6AEB6B7ACB6B6A9B0B2A6ABAEA0A4A8A3A7AAA1A5A89CA1A1
969C9CCBD5D4C8D1D6959FA99CABBE7E97AA8399AE2745656988A5C2D7E4C5D5E0C5D4DF
C3D0DDC4D2E1C2D0DFC3D1DDC6D2DDC5D3DE96A5B7394F6A415A709FB2BF8D9DA98A98A0
AEBDC375878A8A9A9B69777967737163736B5F72705F6F7B07153C010E410F2247506371
596C6B596A64566561556464465562091A313852660D20310C8D1200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B92C6E5A5C5A5563
635D66453F4E030223020532030B3D070D3B3E3954644F5E7B5E6B81616F826679534664
1C173B7865838E76952B2456070C473B315D89667A91616A915E659968699B6A6D9E6C70
A37174A37272A47571A47973A98177A98477AD8C7FAF9183B09586A38C7F88766C98877E
938178A59285B6A292B9A495BBA89BB6A499BCAAA0BAADA1B6ADA1BAB1A8C4BCB4C3B9B5
C4B8B5C2B7B3C7BDB8C8C0BAC9C3C0CCC8C6CCC8C7CEC9C6CAC7C6CAC7C8CAC7C7C8C5C3
C7C5C4C8C7C9CBC9CDCBC9CEC6C4C8C7C5C9C5C2C6C2C0C5C6C5C9C4C3C5BFC0C0BDC2BE
BBC0BDB8BDBAB8BCBABABEBDB8BBBFBCBDC2BBBBBFB7B9BBB5B6B9B3B3B8B7B7BBB2B6B9
B0B4B7AFB3B6B4B7BAA4AAAD868C8E909798ABB2B3A1A8AAA0A6A9A0A6A8AEB4B7BBC1C4
959C9F9CA6AA9AA4AD9199A5717F93748DA0AFC0CE90A3B1B7CAD9C6D7E0C8D6DFC9D6E2
C1CDDCC3D1DFC0D0DDBFD0DAC7D5DFC7D4DE93A1AEABBECD9BAEBEA5B6C1BAC7D07D8B94
94A2AA77878A6F7E7F69777569787466776F62747063747E09173D02113D374D63586E71
596C6A596B6859676753646B2C3C510B193B0D2144031432088C1700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052B927826B676E6876
68606E3730450203250209310913400A11395F586F6C5A65795F698163707E667A382F4D
322D4E816F896E60830B0D46070B455A486D8D6574915F67915E619867679E6F709C6A6E
9B686BA06D6DA3726FA47871A77F75AC887BAB897CB19083B29485B39889A99283A18C80
A99488B8A294B6A090B8A393B7A495B9A79BBAA99FBAAAA1B7ACA1B9B0A7BEB7AEC0B8B0
C1B8B1C1B7B1C5BCB5C8C0BBC6BFBED1CBCEB8B1B4C0BBB9C9C8C4CACAC6C7C7C4C6C5C2
C5C3C2C3C3C4C5C3C8CBC8CDC8C4C9C7C5C8C5C5C6C4C4C6C5C7C7C2C3C4C1C1C3BCBEBC
BABEBCBCC0BCBABDBBBABCBBB8B9BABABABDB8B7BBB5B6B8B7B8BAB5B7BBB5B8BCACB2B7
AFB3B8B2B4B8B8B7BC9392968F91928E91919FA3A4A5ABAEA2AAACA1AAAC9BA4AC8A99A5
929EA98C949CB1B6BFC8C9D4ACAEBACED4E0D5D9E4A4ABB4CCD5DEC7D4DCC6D4DDC7D4E0
C4D3E0C3D3DDC2D2DEC2D1DCC3D3DDC3D2DF9DB1C197ADBCA8BBC877899884929E75818C
7A878F7D8A90737E7F6E7A7A68777565757063737167757E11204107173A4B626F576C6C
5B6E6D56686A54656D3B4D61061236010C39000D39020F3409122900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057BB24876C6166606C
67616F252138020526121B3B3841621317386960746D5B66725C6679616C79667C201C3D
4C46657B6B8834305B050D4718164A785E7D8C5E6C92606892606399696A9B6A6B9B686B
9A65689E6A6A9D6C68A1736DA87F78AD887EAF8C81B39185B49386B69788B69B8CB19A8A
B59D90B7A092B39D8DB7A292B9A496BAA899B7A59ABCABA3BAACA4BAAFA7BEB4ADC2B8B0
BFB6AEC0B7B0C4BCB5C7BFBBC6C0BECBC6C7C8C3C5C7C5C3C6C7C2C5C5C1C5C5C1C8C6C4
C6C2C2C1C0C1C8C7CBCBC8CCC8C3C7C6C5C7C2C2C3C2C3C5C3C3C5C0C0C4BEBDC2C1C1C4
BBBEBEBCBFBFB8BBBBBABCBBB8B9B7B8B9B8B8B8BAB5B7BAADB2B7A8B3BDA7B4C1A0A7B5
A8A1AFBBA8B4BFA0ADA3858FA58D93A09094ABA2A7ADA9AEA5A7AA9DA6A998A3B02B4361
5F72908D8296B792A6CA9CB0B7869AB7879BC094A8A37E90C9B5C4CED0DBC5D0DAC4D4E0
C2D3E0C0D2DCC6D4E0C2D0DBC2D4E0B0C7D84764815E7B927A8F9D637583899AA49EABB2
7A88909EACB1707E7F6C79796976766675726976766A767E22324C0A1C3B526B77566C6C
566B6F4C616E2F405908163C000836010938010A37010D330F162E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD119B7866524850
67626F16162B0308252E324B47486125233C6B5F7074606B735C6777616D6D5D75130E32
5A5275675D820C1145060F4A392F5C83607A8C5E6B905E66915F6497646A9C676D9C656A
9A63679D6668A2706DA3756FA77F78AF8982B28F86B19085B59487B49587B5998CB59E8F
B49D8FB7A191B7A191B59F90BAA496BBA799BAA89BB9A99FB6A9A0BAAEA6C1B5AEBEB1AD
C0B6B1C1B8B1C6BDB9C5BCB9C6C0BDC6C3C0C9C5C5C6C3C2CBC9C5C8C5C2C6C3C2C5C2C1
C3C0C0C3C2C3C6C6C7C9C9C9C7C5C6C2C0C2C4C3C4C2C1C3C1C0C4BFBFC4BFBFC3BDC1C3
BABDBFBCBFC0B8BABEBABDBEB9BAB9B6B8B9B2B4B9ABB6C393A8BF6A7D9B6A6A89967491
AA6781B0566BAF445995283C9D394AB05B69C07C89C595A0B4979EB4A8ADA8AABA384E75
273A6C765A7C771D3B8915318E132C8F14298D152E8718307E3349D9C3CFCACFDAC3D2DE
C3D4E2C3D3E0C2D2DFC4D1DDC4D3E09BB0C14D67835E7890ADBFCDBACBD48B9CA5B7C5CB
84929A818F94717F826C797B6976776777766775756B777C424F630618354660734B666F
42596D17284B020D3B000839010636010736010936020B321D243A148E1300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6346584A4E
6E69770D0C24090A264D495D453F543A334972637175606B6E586277616F5B4D69110E35
656085302E5D040D4A0C114A655177805A70845C6A865C678D616897656C9B646A9D666A
9B64689C6769A16F6DA47772A77F78AD8781B39087AE8E81B29284B49688B29789B29A8B
B69E8FB6A090B8A293B7A193BBA597BBA799B5A498B6A99EBAAEA4BCB1A8BFB4ACBEB4AE
C0B8B2C0B9B5C7BEBBC5BDBAC5BFBBC4C0BBC8C4C1C5C0C0CBC6C7C7C4C4C5C3C3C4C2C0
C2C0BFC1C0C0C2C2C1C8C8C6C3C3C2C0BFBEC3C2C4C4C2C4C5C3C7BEBEC2BABDBEBABEBD
BCBDBDBFC1C1BCBCBEB7B7BCB6B6BAB1B6BBA9B6C47490B136527E7A7099914D709D2845
A61329AF0E22B70D1FB80D1DB40D1DB11123A41326A5273AAB4657C88290C39CAD807A9C
17225777638B7B1D3897071BA40414A60514A204139F0719860D21C18C98D4CFD9C5D1DC
C5D3E1C4D1E1C4D2DFC4D2DEC6D3E1A1AFBFBACBDCB6CADB8C9EABAFC0CB80929C819098
808C9379868A727E826F7A7E6B797B69797868777567767664717D101F3A253B5C213658
04123F000C4100083E01063A010536010734010B35010D3030394A1E9A1D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AC815C77696A
5A566609092219152E5E51623F3448453E5272626F745E695F4753776171463B5914163E
565B870B124A040E4D211F507C627D7856666749586247537A5A6492676E9A676B9D6569
9D67699C6869A47172A47574A97E7BAC867FAE8C82B29183B69687B49788B39888B59A8B
B79C8CB89F8FB59F90B7A193B5A294B9A799B5A699B5A89EB9ADA4BBAEA7BDB2ABBEB3AD
C3B9B5C1B8B5C2BAB7C4BCB9C7C1BCC7C3BECBC7C4CCC8C8C9C7C7C5C6C4C1C2C1C1C0C0
C3C2C1C2C2C1C2C3C4C2C2C3C5C5C4C2C2C1BFBFC1C0C0C3C3C2C4BDBDBFBEC1C2BCBEBC
BCBDBCBCBEBDBCBCBFB7B6BBB6B6BAAEB7BF839DBA2045797D7EAD974A6AA4172FB70D20
BE0917BC0712BD0610BC070FBB0510BB0511BA0915B40817AE0D1FA013289B2B42A75D7A
54325E553B638C4057930B1CA40210A8020FA5010DA3020E970817903D4AE1CBD6C8D0DC
C8D5E4C6D2E2C6D3E3C4D1E1C1CFE392A5BB869AAB8A9EAC778B9B8496A380929A788790
94A0A77C888D727B806E7A7D6A787968787667797565777565737B2F3E5A000E3D000B3F
01074000094200063D01083B0106350009320110331F33492E3C4429A92900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC83B837574
7272820809232B243A615260332A3C514C606C5E6E725D6A735A677860723F3456151E4D
26356A010D4B050D49473E657B5E73694A586A505B5F4A55553F4988666C97686D9B666B
9D69699C6869A37072A67778AA7E7EAD8681AE8C82B29284B59585B29685B09682B49A87
B49A8AB49C8CB49E8EB6A292B7A596B9A89AB8A79AB7A99FBBAEA7BCB0AABFB4AFC0B4B1
C2B7B5C3B9B6C3BBB6C4BCB9C4BDBAC4BFBCCAC6C4BDB9B9C7C6C6C4C4C3C1C2C1C1C0C1
C1C0C0C1C2C0BFC1C2BEC0C1C5C5C5C4C4C3BFC0C1C1C2C3C0C1C2BFBEC0BEBEC0C1C1C3
B8B9BAB7B8BABCBCC0BABABDB3B6BBA9B8C7375D8B34538AA2779E9C1933B80A1CC00914
C10711BF060EC00710BD060EBB060FBC070FB90913B50C16AE0D19A50A199F0B1D971025
922644863654B55B718F0D1DA10311A6010FA6010DA4010B9D051280101DD1A4AFCECED9
C8D3E1C5D2E1C3D1DFC6D4E49FB2CA24405F5E789199AEBD7F92A2899CA9C0D3DC86969F
95A1A978858A6F7C807180826A797A67767567787666777663737C1D2C4A010A3F010742
01064100073F01083E01093A000B3502123222384C4C636C28393B47463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064D1448A797A
4C4C610407233A344661566129263A4B4F6A403F5B64596E745F6F766075392E550F174E
091653020D4B16194E6F60806F54667559657659616F5660533F4B74595F8E666999686B
9C696B9D696AA06E6FA8797AA97E7EAB8580A9887EAE8D80B29283B09482B09682B29884
B79D8DB39B8EB7A091B7A294B8A697B8A698B7A598BAA9A0BEB0A9BCB0ABBEB3B0BEB3B1
C3B8B6C4BAB7C1B9B2C3BBB6C4BDBAC6C1BEC4C1BEBCBBBAC3C2C3C5C3C4C2C1C2C3C2C4
C1BFC0C1C0C0BFC1C1C0C3C4C3C4C4C1C1C1BFC0C0C1C2C3BFC0C1C0C0C2BDBEC0BEBEC0
BCBCBEBDBEC0BBBCC0BABEBFAEB5BB9DB2C81640776273A5964B6BAE1229BF0917BF060F
C20811C10612BF0511BC0510BC0610B70D13A7161BA42F379A37438E303E88202F8C1424
971125941227A92A3D9E12219F020FA4010DA5010BA3010BA0020F910A189F5563DBCDD7
CCD3DFC6D4E0C6D3E0C8D6E698ABC06D87A087A0B4A3B7C4C3D5E18598A391A3AE81929B
828E96768188707E83697C7D6A7A7A6D7B7B69777766767763737C293956010B3E000741
010743000A42010D40000F380618352D44524D646A52666A2A3B3D51514A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0061CB3BA28D8D
4D4D65060A254740505B505D1D1F3B17224E030B3C3433566A5C7069586F2E2650040843
010949030A453C37617E6982685061775C697758646D546050404B6751578B6467916064
9865699D6A6DA27072A7797AA77F7DA8827EAA867FAF8E84B19386AF9584B19683B09583
B49A89B39B8BB5A090B6A093B9A599B8A699B6A499BAA9A0BFAFA9BFB2B0BEB4B3BEB5B3
C4BAB8C2B9B6BFB7B3C0B8B5C2BCB9C6C0BEC6C2C0C5C4C2BFBFBEC0BFC0BEBDBFC1C0C1
C1BFBEC2C0C0BEBFBFBCBFBEC2C5C4C1C4C4BCBEC1BFC1C4BFC2C3C0C3C4BBBEC1BBBEC0
B7BABDB5B9BCB7BCBFB7BBBCB2B9C092A8C1133B77737CAF984461B21126C00716C00612
C00712BF0511BF0713BA020EB50510A6181BC47070A87E857963706A596B68506881556E
893D54851C308F0F219C0917A0020FA5020DA504109E010DA0020D990612811B2AD9B6C2
CDCEDAC5D3E0C4D2DFC6D4E392A5B6A4BBC9ACC1CF7B8F9C8597A283939C85959D87949B
7E8B917681866D7C7E6779796C7D7E6C7C7D6A797C6675786270783A4A62010A3B010941
000942010D4103143F192E463F55604C62644F636353676831424451554E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC22E886F6A
3A384F0F122B534958574B5B0C1032020B400209451B1E4B62597066566D25214C020944
0009471012456B5D7E776074624C5E7059686E57635F4E5A4A3C486850578A6164925E63
9D686CA26F70A17071A37676A37A77AB847EAA847DAF8D84AF9185B19788B29787B69A89
B49A87B6A08EB49F90B6A294B6A297B6A59ABAABA0B9A9A0BFAFA9C1B3B0BAB0AFBDB5B3
BCB5B3BDB8B5BEBAB6C1B9B7C4BDBBC3BDBCC7C2C1C5C1BFBEBDBCC0BFBEBFBFBEBEBFBE
BEBFBEC0C0C1BCBEBFBCC0C0BEC4C2BFC3C4BCC0C3BFC3C7BEC3C3BBC1C0BFC4C6B7BEC0
B2B9BCB4BCBFB8BDC0B8BCBFAFB6BD98ACC4163E7A616FA5954968B11327C10918BF0512
BD040FBC040DB9010CBB030FB20812AA3336C39594A59DA299A0A696A0AA7E879B515873
4B4665735572813C54831525970A169B030E9600099501099C010C9A020D880A1CB37685
D8CFDBC7D3DFC5D3E0BAC9DD647D97738FA3657F8D6D8592879AA493A3AA829097A7B2B8
808D93798589707E7F6372736B777B6B7A7D6575766574766573794B5B6F010C3C000B41
020E3E0C1D41394D64566B725163655165645267644E6563364C4D47504C1E981200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE115B09284
3F3B4F1B192F5C4E5D473C5103062D020942020947101343665D77675B731B1A48030A47
030D47312F5977637C7E66765848585B505E5A4F5A50475346374473535C8C5E64915D62
996568A06E6EA27372A57778A67B7AA7807CAC867FAF8D83B19387B19488B29688B39887
B49A88B69F8EB39F90B39F91B29F92B4A398B8A99DC0B1A7C0B1A9BBAEA9BCB1B0C1B6B5
BDB5B2BEB8B5BCB8B4BFBAB6C3BCBABFBABAC6C1C0C5C1C0C1BFBDBFBDBBC1C1BEC0C2BF
BCBFC0BEC1C4BEC0C4BABEC1B7BDBCBBC0C1BCBFC4BCC0C4BCC1C1BDC1C1BFC2C3B9BCBE
B9BFC1B3B8BCB4B8BCB6BBBFB1B8C0A4B7CB214880415A969D6588A7162BBD0816C10513
BF040FBE050DBB020DB9020DB20713A73338C3999AA6A1A19BA2A3BAC4C5AEB6BD959EAD
75859C3C4B694542637B547281273E8C091895020E98020B9C020B99010B930617822939
DEC4D0CED4DDC6D5E29DAFC918375B58799297B2BFA3BBC5899CA5B8C8D08F9BA5838D95
7B868C728083758183717E7F6C797A6877786778776678756776795A697905143904153B
2638514C616D5A6F725F7373596B69546765516868425C6038505835434525A21E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B89683
352E402C273C5E505F342C44010630020A43030A470B0F3D655E794D45630A0C3C020B45
0B11445E55767F65797E6473554B594B4857484453433B49543E4A774E578B565E965F65
9B656AA16E70A47274A57778A77A7CAA8080AA837FAE8B82B19085B19286B29686B19685
B49A8AB39B8CB49E8EB19D8EB7A397B4A398BEAFA4C2B4ABC1B3ABB9ADA8BBB0AEC1B6B4
C2B8B4BEB6B1BFB8B4BDB6B4BCB8B6C1BFBEC3C0BFC3C2C0C0BEBCC3C1BFBCBCBBBEBFBF
BABCBCB8B9BDBBBDC1B9BEC0BBC1C1BCC1C3BDC1C5BCC0C3BEC3C3BDC0C2BFC1C2BABBBE
BDBFC2B9BDC0B2B4B8B4B8BCB2BABFAEBCCC4669971C41829A82AD941D35B60A19C10614
C20410C0050EBF0510B9030FB50815A3272EC69495A7A09DA0A5A4A9B3B2A3ACAE939BA1
8D9AA596A7B9798BAB25315C785C827B1D34980818A004109E030D9C010A990312800C1C
C28F9ED3CFD8CCD5E49CACC17B95AF95AFC38EA2AEAEBFC983919C7D8893838C977C858C
7B868B737E82747F816F7E7E6C7B7B697979677A78677876677777617277273B4A3E5261
566972586C6D5C6F6E6174725C6E6E52686C425B69152C4223394E27394244413800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C49F84
382F3D3D374A5D515F231E38030732020A400109420D123D63607E282547010639020A41
25254E76647D816172826170634F5C4A3D4E4F42515A455276515C8350598F565E996167
9F696FA16E72A27074A5787AA4797AA87F80A98380AE8A80B49486AF9182B09583AE9585
B3998AB4998AB49C8DB39E90B8A59AC2B0A7C5B5ADBEAFA7C2B4ADBAAEA9BDB2AFC1B7B5
BFB5B3BEB6B0BEB5B0BFB8B6BCB8B7C1BFBEC4C1C0BFBFBDBEBEBCC0BFBDBCBBBABAB9B9
BDBEBEBABBBDB7BBBCB9BEBDB8BDBDBCC1C3BEC2C6BABEC2B9BEBFBBBFC0BDC1C3B5B8BB
B8BABFB9BBBFB6B6BAB5B9BCB3BABDAFBAC2809ABC16407F7078AC93425CAE1121BF0815
C20612BF040DBD030FB90311B204119D121CC27E82AB9F9D9DA3A2939D9E9DA8AAA3AAB1
8D97A0B8C6D1C8D8EE415985283064804D6D880B219703119601099D030C9E0211900819
914152DFCAD6CDD1DF8C9AAB97A9B98B9EAD788A99808C9787919C7A848E9FA8B2838D93
7782877983876F7B7C717F7F7281826A7A7B6679776879786978776175715C716E546768
596B6E5C6F705D70705C7174586F7A364E63091D40000F38192C492037424D4E4800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BF9570
3F31374840515B4F5E15122C020831010A3E010941151B4955577A0C0D3802073C060B3D
574F6F7D6274845F6E8C64728862716B49596B4957774F5B875661864E5890575F996167
9C666CA06C72A37175A27576A57C7DA67E7EAA8480B08C80B08F7FB19381AF9282B19688
B19789B3988AB49B8DB9A499BCA9A1C2B0A9B9AAA1C0B1AAC1B3ADBBB0ACBDB5B0BDB4B0
B8AFABBEB5B0C1B9B3BEBAB5BBB9B6C0BFBCBAB8B5BFBEBDBDBCBCBCBCBDBABAB9BBBABA
BCBCBDB3B6B7B5B9B9BABDBDB8BCBEBBC1C3B9BDC0BABDC1BABFC0BBC0C0B7BBBEB1B6BA
B4B7BCB6B9BBBABABDB4B8BAB5B9BBB3B9BEA7B8CC32558A2E4B86A57E9E99182BB90A17
C10610BD030CBC010DB6010DB3020DA70A16B05057B49999A2A5A48F989AB7C0C6D3DAE2
A3A9B4A6B1C0B8CADD6A81A611255B715E877818318D05148D000696020A9F0211980516
7D1223D4AAB7C6C9D9687C947B90A3677B8B7B8D9C8C99A3B9C3CD84909A919DA588969B
758085768183707D7D7684846E7D7F6A7C7E6779796679776878775F736C60746F5C6F6C
5B6C6C5E7274576F764C647721385A041644000C3F010C3C0C193C2035444E504E10CA08
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0069D547
5B48484F4354594D5E0C0A2702083005103D010A3B202855383F6901063A02073E1A1B45
6D5E767E5F6E8059678B5E6E885A6B8554667543537C4655844D5A8A525C9159609A6368
9D676D9F6B6F9F6C6EA27372A57979A67E7CA8847DAD8A7FAF8D80AF8E80B29387B3968B
B09589B0968AB29A8EB7A298B9A69DBFADA5C0B0A8C0B1ABBEB2ADBAB1ACBBB3ADBDB4B0
BFB4B1BDB4B0BBB5B2BAB6B4B9B9B5BABAB5BBB9B6BAB8B8BBBABCB8B8BBB5B5B9B5B5B7
BBBBBDBABBBCB4B7B7B9BABCB5BABBB9BEC1BABCC0BBBEC2BCC0C4BBBEC2B7BCBEB1B8B9
B5BABBB6BBBCB3B6B8B2B6B8B2B6B7B0B5B8AFBAC57791B51136727F7EAE913750B2131F
BD0811BD040BBD030FBA030FB6010EB107129D2029C28E90D2CCCC9EA5A9A1A9B1B3BBC3
9CA2AE8592A4617A92ADC7E0324A783C41727C3E5E870B1C92020C94010A99020C96010D
890A19A7616FB9B0C23F58757D98B0A6BBCBB3C3CF7F8D9597A4AD808F977482897A898C
778488707E7F6E7D7D6C7C7C7382846C7A7C6A797A6576756977766374726274715E7070
586D70576D7A354C68091D4900124A010C4A010B46000A3C04103622364C424A4E209914
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064CC3A
735A5557495850465906042204082D3137591A234825325D161F5002084002073B322E52
74607280606E845E6C845A69875A6B8351617843537D4654824B588A535E935B63996268
9A65699C6869A47171A57574A47676A47C7AA6827CA9887EAE8D81AD8D80B09285AE9185
AD9185AE9589B19A8CB39E92B8A69BBCA9A1C1AFA8C2B2ADBEB0AEB7ADAAB8AEABBCB1AF
BDB1B0BAB1AFBAB4B2B9B4B5B7B4B4B9B5B3BDB8B7BCBABABAB9BCB8B8BAB8B8BAB8B7B8
B9B8B9B8B8B8B8B9BABBBFC0B8BDBEB8BDBFB8BBBFB9BCC1BABCC2BCBDC2B8BCBFB2B7B9
B6BBBBB6BBBBB1B4B8AFB4B7B6BCBFB2B9BBAFB8BBA1B4C72A4D83324B88A475989C1829
B70A13BD060CBE0510BB020FB7010EB40310A10D15B46568B4A2A1A1A6A996A1A88D99A1
BBC5CC96A4B25C758BBDD7EA7B95B911265A745B8376112695061594000A97020C97030D
950713831A28AA8191929EB199AFC180939F8B99A17F8D927E8B937B8990758389718082
7A86896F7E7E7181816C7B7D727D7F737F7F6C78786975736C78786676766073745D7379
465D721C3156021144000C48010B4B00094D010A49010A3F010C37263C56313E4625A21F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064C933
8264575C4C5742394C02021F0C0D2C58566D262948222E5B020B40020741010336373152
725D6D7A5A6884606F835D6B815865875A677A4955804C58834F5B8E5965915A64925C61
9965689B6968A1706FA67575A57577A67A7AA47E78A7857CAD8C81AF8F81AF9082AC9081
AF9486B19A8BB39D8EB8A596B9A89ABDACA3BCABA4BBAAA5B9ACAAB7ACA9B8ADABBEB3B1
BAB0ADBCB3AFBBB5B1BCB6B5B6B1B0B9B2B1BAB4B3BBB8B8B7B6B7BCBCBDB8B9B9B9B9B9
B5B6B6B3B6B5B8BBBBB7BBBBB7BBBCB8BCBEB9BDBFBDC0C2BFC1C4BBBCC1BCBEC3B7BABE
B9BBBEBBBDBFB4B7BCB4B9BDB1B8BBB0B9BAB3BABCAEBAC36681A7133677837DAE8A2D45
AE0E1BB9050DBA020EB9010CB9020EB7020EAD0810A13136BE9698AEACAFA2ACB18E9BA3
D1DDE4C9D7E08DA1B1A0BCD287A7C91B396D454678752F4C8C071B93010D95000A97010B
98030E8706108D434D9388927F8F9D7E929E8B9CA59FAFB67D8A93A2B0B788969D738284
7A8788718080717F806E7B7C6E7B7B74827F6976756A777766777763797D5A6F7D344B67
0A1D4C000E49000A4B00084A01094A020B4E020D4C010D4107183C374D61233139453E34
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0065CA30
9B786562505637304103041D242036625769252441111B4B010A43010842010638393454
745E707C5C6C805E6D886170845B698256617F505A7E4B55824C588A535F8C575F905D61
9664679B696C9F6D6FA47173A57376A47777A67E79A7837AAC8A7FAF8F81AF8F82AF9184
B29888B09988B29C8DB4A192BDAC9DB8A69BBEADA5BDAFA9B7ADA8B7AFABB5ADA9B7AFAC
B3ABA7BBB2AEBBB2AFB8B2AFB7B3B1B8B4B2BAB5B4BAB7B7B7B6B7BAB9B9B9BABABCBDBD
B3B5B6B7BBBAB6BABAB6B8B9BDBFC1B8BBBCBFC2C1BCBEBEC4C5C9BEBFC4BBBFC3B9BBBF
B7B8BDB6B8BCB6B9BEB5BABDB3B8BAB4BBBBB1B6B8AEB6BB9BACC521447C3D528D9A6786
9C1426B60815B9040FBB0410B9020DB7020CB406109D121BB87479D5C8CCCED3D997A0A9
A8B6C0A6B5C08496A927486D5882AD5C7FAD12245C78567B790C249505139B030D970109
97000A92030C8018209B777F5E6C7996B0BC899EA8BACBD386959D7A888F7C8A92738185
717F807382826F7C7D6C79796B7A7B6778776B7C7D64797B59727A4C677C1F345B021247
010C4C010B4E01094E010A4D010C4D000D4C0110490D1F473C51645367701C29304A443D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B28C706856592B26350505193933446053621B1836040C3F010A420D184B1018442F2B4D
715F737B5E6D7E5C6B865C6C8759698657647F4E587F4C5587535D8C55618F5B63966467
96656899686B9D6B6FA26F72A47275A37677A77F7AA58077AC897FAF8D81AF8E83B09185
B29889AF9789B29B8EB6A092C1AD9FB9A69DB9A9A2B5A9A2B4ABA6B6ADAAB6ACAAB8AEAC
B6ADAABBB2AEBBB3AFB8B2AFB6B2B0B8B4B4B8B4B5B6B4B6B9B9BAB5B5B6B9B9BAB6B6B9
B6B6B8B7BABABBBDBFBABCBEB8B9BCB6B8BABDBFBFBDC0C1C1C2C6BABCBFBABEC1BABCC0
B7B9BCB8BABDBABCC1B4B9BCB3B8BAB3BABAB5BBBDB1B9BCAEBBC85C7BA21335738C80AB
8C263DAE0C1CB60410B6030EB7020DB7030CB4030CA709129F3C42BF9FA4A9A7AE9AA0AC
7585989AAFC1BACCDF3F5C7E557CA1A2C1E3173063524B7B71233E90081A9D02109C020B
99010B97030D870711925059A3A0AAB1C4CD8091998393997D8B917E8A907D898F7A888B
707F81738382707E7E6B79796C7C7C67797A6B7E845B74813954710D235400104E010B4E
020B5000094C01094D000C4E01104E03184A21375C50657658687056686C222F35474543
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B18565735D602A223308051B4E45535C505D13113202093D020A412C325F1E2048211F40
7164777F6372825F6E83596886596785586283555D804F578957618C58638C5860946266
96656599696B9C6A709D696FA37174A47777A87D7BA9837CAD8A81AC8B81AC8C81B19485
B29788B0988BB1998DB39C8FBBA498B8A59BBEAFA5B3A9A2BAB2AEB7AEACB3A9A7B5A9A8
B8AEACB8AFACB7B1AEBAB5B2B3AFADB8B4B4BAB6B8B8B6B8B7B7B9B7B7B9B9B9BBB8B8BB
BABABDBABBBDB9BABDB9BBBEBBBDC1B8BBBDBCBDBFBCBEC0BDBFC1C0C0C4BFC1C4BFC1C5
BCBEC0BEC1C2BCBFC2B2B9BBAFB5B8B5BCBDB2B6B9B0B8BAAEB9C095ABC5173B774B5A94
9C5E7C9D1122B30512B7040FB8030DB7030DB3020BAF051097131DBA7E85B7ADB4C9CED6
7F8EA1849BB0CDE0EE97AFC188A5BBC1DAF15268931F2A6274486E7D0A209803129E020E
9A000D97010D92051282242F9B7E868E969C909EA67D8C92A9B6B9838E938793988E9DA1
7181846F8080728283697A7B697B7D63777E566E81263E6303164F011054010C54000A50
00094D010A49020B4A000F49091E4C3B536F5D73815F7277617274596C6F2D3E453E4042
1D961000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D6B436F555422192B120E22594E5A564A5909072B02093C070E3F55547B2B284D151739
6E647979606E7D5C6B855E6C8A606D855A658557607C4B538351598C5861905C62956166
9765679D6C6F9E6C729D6970A06E72A57778A37A77A57F7BAA8781AA897FAB8D7EAD9282
AF9585B19889B29A8BB59E90BAA59AB4A398C0B0A6B1A49DB9ADABB3A8A6AFA5A4B6ADAB
B2ACA8B7B2AEB5AEADB7B3B1B6B4B1BAB7B4B6B2B2B6B4B4B8B7B9B9B9BAB9BABBB8B9BA
B8B8B9BDBDC0B8B9BDBCBEC1BBBFC1B8BCBDB9BBBDBDC0C2C0C1C4C0C0C4BEC0C4BEC1C5
BBBFC2B9BDBFB9BEC1ADB6B8B0B7BAB6BBBFB3B7BBAEB4B7ADB7BDABB9C84C69991A3879
9983AC8A1E33B10B1AB6030FB7020AB6020CB4020DB10410A10914A0464EC3AAB3D8D8E0
B3BCC98EA2B591ACC087A4B64B687CB8D0E39CAFCF1529605143746916308F06179A0212
99020F96010D970410800D19956168A3A2A7B0BEC585969DA2AFB48994977B878C768387
7281846D7F826E81846C7F84647A8548617A122957021454000C55010953020B53010A50
01094D020C4A020F470A2049476177677D86657A7C5F73755C7171566B6D3C4F562F3639
229D1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB21F7E625A2119261F192A60525E4A3F5006062A0107371F224B6A6582312E510E1135
6C647C78606F7A5B69835E6C885F6E85596785546085525C88555C8D59618F5A62925D65
98646A9A686C9D696F9E696FA37074A57579A57B7AA47D7AAC8680AE8B80AC8E7FAB9181
AC9385B19787B09786B49D8FB6A097B6A29AB9A89FB8A9A3BBACAAB3A6A4B3A9A7B4ADAA
B0ACA7B3AFADB1AEADB3B4B2B0B1AEB6B7B3B6B6B3BEBEBDC7C8C9C4C6C8BDBFC2BABCBE
B5B6B7B7B8BBB6B8BCB7BBBEBABFC1BBC1C2BCC3C4BCC2C4BDC2C5BFC1C5BFC1C5B8BCC0
BBBFC1BABFC1B7BCBFB6BABEB4B8BDB2B6BAB7BABFB1B5B8AFB5BAB0BAC389A0C0143978
5B669D8C48669F0C1FB20210B7020DB7030DB4020EB1020FAA0612941B25B7848CAAA4AE
9DA7B3687F982A51778BB3D08EABBEC5D8E6C8D7EC3F537F262E63744262800A20910213
93000C94010C96010C8A071286353D9F8F91ADB6BC8593997E8B907E898B7C8688758083
7281846D7D806A7D846379883C5675081F53001258010C5701095401095000094F01094C
01094C010B48031242415B72647C846B8081687C7B6076755E7374596D6F4E60651F292C
27A32000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB61D7458471E17202E283363555F39304604072D040A34413F5F6E647B3A355506072F
665E7A7760717C5D6B815C6A88606E8559668451608856628857618C5863915C66945F69
925E669561669A646AA16D72A16F73A57578A67A7CA57D7CAE8680AF8A80AE8E80AE9282
AC9282AF9584B19988B39B8EB59E96B6A29AB6A59CB9ABA7B1A4A3B7AAA8B2A6A3AEA5A2
AEA9A5ADA9A7A8A7A7979998939695ADB0AED1D4D4DBDEE0DBDFE3DBE0E3D6DBDFC0C4C9
B7BABDB3B7B9B2B7B9B7BDBEBABEC0B7BBBEB7BEBFBBC2C2BABFC1B8BDC0BCBFC3BDC1C3
C1C5C6BBBFC0BBBCC0B8B9BDB2B5BAB5B8BDB6B9BDB2B6B9AEB2B6B2B8BEA5B4C936558B
203D7F957AA28B172CAD0716B7020EB6020DB2000CB3020EB1030F9D0A18A553628D808E
CDD9E593A9BF1D446B6E99B6C6DEEDCBDBE4CAD9E7889BBB0F215667567F6E142D8B0517
92010D95020A96010B9304107D121CA1777986878A8793967A888A8D9B9B8A97996B797B
7182826A8081607A87355173061D5700135A010F5C010C57000C51020E4D010E4903124C
010B48000D431F335559727D657A7D6A7E7E677B7B5F74775D73775B6F73596C70152227
463E3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
58BD217C5D4620151C3A2F3A675763261F3904082E0A0E325B556F726478433D5D060834
50496B755F727B5C6A7C5B66825C698257648758658656628C5B668C58638F5B64905C65
9563699766699662679F6B70A06E72A47578A57A7DA88081AA8280B18B84B29085AF9181
AF9381AE9381B09886B0998BB5A197B6A49BB6A69FB6AAA5AA9E9BB0A5A1B0A5A1B0A5A2
ACA5A2A29D9B949392A7A7A6AAABA9C6CACACFD3D7BEC0C7BEC2C8CFD4DADAE0E7D2D6DD
B6BAC0B7BBBEB6BBBCBABEC0B8BBBDBBBEC0B5B8BABEC3C4BEC4C4BABFC1BDC1C5BEC2C6
BCC2C4BABEC0C0C0C5BCBDC2B9BCC2B7BBBFB6BABDB1B6B9AEB3B7AEB3B8AAB4C1788EB4
103373696FA18A3C56A50D1EB70612B6020EB4010DB5020EB5030FA90613922234876473
C4CCD8C8DBE97D9AB4769CB4C0DAE7C9DBE3CAD7E5BFD0E72C417033396C70355782091F
8F010E94010A94000894030C860813934951908184BEC6C98F9DA08796968A989D607376
6A7F81637F89304D70041D5900125C01115E010F5D010E5601124C061B492E456A1F3563
020E47010F40425D725D767A65797B6A7E7F657A7E59727C4B6777445E6C5069721F3138
3C3C3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0087604425141941333F66596717143203072F1E1F406C62767464774D4467070B3C
3C39607461767D5F6D825F6C8057668358668A5D69895A648C5A64905E688D5B65905D65
93616797676B97666A9C696E9F6D72A27377A6787EA67D7FAB8482B18C85B29185AF9183
AE9081B09281B29888B39F90B5A296B6A59CB1A29AB3A69FB3A6A2BAB0ADACA39EADA5A1
ABA6A2908C8AADABA8B0B0ABAFB2AED3D7D89FA2A8B3B4BCB7B9BFB6BEC2D8DFE3DADEE4
B9BDC4B9BDC1BCC1C4BABEC2B6BABEB5B8BCBABDC1C3C7CABDC1C4C0C5C8BEC4C7B9C0C4
B9BFC3BCC1C5BDBFC3BCBDC1BABDC1B4B8BCB7BBBFB3B8BBAEB3B7ADB1B6ADB3BDA2B2C8
2D4E822A447E997394931528B10616B5020EB6020DB6030EB6010DAF0310960B1AA86472
9C96A89BB0C37E9AB130566FB9D5E4C9DAE3CBD7E3C9D7E96F82A90F1E576D517C6F0E27
8B031393010D94000993000A900411841C279F777E98989C8993997B898C7482865B6D72
657C8938547403195702156200105F01135F02145B021651172E5746607A506983081D49
02134A051743526D7E60787B6A7E7F677C7F627886334B6A08204B041D4338546B2C4550
2D31330EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AA7F5E2C171A4D404A5850600A0B2B04082E3D3953695B6C6E5E7253496F06093E
2726536E5D757C5E6D805C6C8159668458658759648957628B58628E59658A5562915D65
9462699A676E9B676D9E696E9C666BA47275A97A7EA3797AA9847EAD8C83B19085AE8E81
B19285B19286B2978BB49F91B6A497B5A29AB5A59DB4A79EB4A9A4AFA6A2AAA29EABA4A0
AEA7A58D8987B0AFACADAEABB5B8B6CED2D39B9DA3B2B3B8B2B6BAB3BCBED5DFE1D6DBE0
B0B3BAB8BCC2B5BABEB7BBC0B8BBC0B9BEC1B9BEC1B9BFC2BAC0C3BAC0C3B8BEC1BABFC3
BEC3C6BCC1C4BEC1C5B9BBBFB7BBBEB2B6BAB6BABEB4B9BCB3B7BCB0B4B9AEB3B9A4B1BD
6882A710346F77749F872D44A80B1DB60411B8040EB6040CB4010CB1020DA50715932D3E
745E7A647E9DA3C2DB638398C8DEEBC9D9E1CBD8E2C9D7E3B4C5E01D3162413E70682341
85061994020E96000C94010C9402108408169B58628F8387838B8E808B8F76858A62767F
475F7D061D5801136001136400115E011559061E53314C6D556F82577182294061001344
1A35660A1D46557081627A7D667D82617A8833496D05174F01115001124A13294F3B5467
1C262A1E981300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE815A2C18154E424A453F5106092A0C0D2F584D62695B694D43595B5779080C3E
101344695D7A7D61727F5C697D5964875E6A895A678956628B57628C58628D58638E5960
9461679A676D9C686F9B686C9E6B6EA57476A6787BA97F7EA9857EAD8C82B19084B08E81
B19184B09388B1988CB39E90B39F93B09D95B1A299B0A49BB0A7A0ACA3A0ACA4A0B1AAA5
B2AAA78A86859A999BB1B1B3ACADB0C2C6C9B9BCC0ACAEB3ACB2B6C6D0D3D9E1E5C7CCD2
B8BAC1BABBC2B8BBC1B9BBC0BCBDC1BABEC2B5B9BCB7BEC1B7BFC1BEC5C8BBBFC2BEC1C6
BEC2C6BDC1C5BABDC1BEC0C4B8BBBFB2B7BAB3B9BCB2B9BBB4B8BDAFB3B7B0B4B9A7B1B6
9AABC2224479334780956384961126B00413B6030FB6030EB4020CB1020BA903118F0C1F
8C56713F4C6BAFCBE1C3D9E4C9DCE6CAD8E2C9D7E2C6D7E3C6D6E85C7095152255704A6E
760A1E90021193000C93000B93010E8B04128329349B8082999D9F939FA26D7D875D748B
0E285B03176302136603166401145719305F4C67805F788361778149637A061D490C2251
3A55800316404B66805D7786557085254169021753010F54000C50000F4A0214423A536C
121E272A631D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00BA8E5C311C11574B51352F430407281C1A356456655C526222223B5D61810A0F3C
050A3C544D6F7A61737C5966825D68855A698A5A6A8756638C5B6585555E8C59618D585E
9360659B68709D6A719F6C71A06F729F6E72A5777AA87D7FA88380AC8B83AF8F84B19084
B19186B3968BB0968AB29B8EB39E93AE9B93AB9C93ADA199ACA39DA9A19DA9A09DB6AFAB
ACA4A2A49E9E8A878A8E8D918D8E91B1B4B6D4D7DBD1D4D9D2D7DCD3DAE1BFC6CDB4B7BF
B7B6BDBBBBC1B9BAC1BCBDC3BCBDC1B9BBC0BBBEC3BFC4C8BCC2C5BEC2C6BCBFC3BABDC2
BBBFC4BCC0C5BFC1C6BCBDC2B7B9BDB4BCBEB2BBBCAFB7B8B1B8BBADB4B7AFB3B8A9AFB3
A8B5C05B769B12316F8376A386233CA90A1AB20211B5030FB4020DB0010CAC0210A00919
98394C99879D92A6BBC9DFE9C9DBE4CCDAE4C7D7E3C4D6E1C6D5E3A4B5D1132656534973
6D1D3685041390010C91000A93000C91020F7C0C17A06E72898484818E916D7F90263F69
021A60011466021463041B5B29416A587085657A8164797D5C74831C33590116482F476C
455D7F001244183061374F7C162D6201175A02155F010F58000C51020D49001042283E5E
192735312B2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0058C22C402615564A5028223B0408282F2C426356624841560A0F2F5A6084161A4A
01073D3A385E725D727958667E59667F56658557668B5A698856638857618B5A618D5B60
9360669663699C696E9C686DA06E72A16F73A77579A77B7DA98381AB8983AD8D83B09084
AF9285B09488B59A8EB59C90B5A096AA978EA3948AA99D95A99F9AA19796AEA4A3ABA2A0
B1A9A7B1ABA8ABA7A5ABA8A7B2B1B0ABABADABABB0B0B3B7B3B7BDACB0B8A6ABB2A6AAB0
B2B3B8B8B9BEBCBEC3BCBEC4BDBFC3BDBEC2BBBDC2B7BBBFBCC2C3B8BCBFBABDC2BABEC3
BCC2C6BAC0C4BCC1C6BDC0C4B9BCBFB2B9BBB6BDBFB1BABAAEB7B8ACB5B7AEB6B9AAB1B4
A8B1B993A7C018377145548D9055749B1125B00314B50210B3020DB0010EAD0110A70411
92142595687C5F6E83C7DDE9CADAE4CBDAE3C9D9E2C7D7E0C8D6E1C4D5E742587E2A3262
6F3E607A0B1E8F021093010C95010B94010B8706108B3F439581817D868D576D89051C5A
011767001563051C5A365073627989697C81687B7C627880324B69021949112853576D83
52677F03154800135600115A00115D00106101105F021059010D52000E49000F4217294C
2736482F2D2E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF005EC42B5433205547511C1834070A2C4A43596557672D28450409324E537A212452
030940161845685A737B5D6C7E5D69805966825663875564824D5D8854628B5A658B5A62
91606596666A98696D99696E9E6C719D6C70A67778A67B7CA67F7DA9857EB08F85AF9184
AE9284AF9488B1978CB49C93B39E96AB978FA6958CAB9E96ACA29DA09795ABA1A0A69C9A
ACA3A1B5AEABB4B0ADB6B3AFB5B2B0A8A6A5A6A5A7A0A0A1A3A2A6AEADB2A5A6ABA5A9AD
AAADB1ADAFB3B1B4B9B7B9BEBDC0C4BDBFC4B6BABEB9BEC1B9C0C1BAC0C3BBC0C6B7BDC3
BDC5C9BBC2C7B9C0C4BCC1C4B8BCC0B3B9BCB2BABCADB4B7AFB5B8AFB7B8ACB5B8A7B0B2
A6AFB5A2B1C244608F1735748D79A1891D35AB0718B60412B50210B1010EB0000DAB020F
980818944B5CB1ADBDCEDDE7CDDBE4CBDAE4CAD7E2C9D7E0CBD7E0C8D6E296A7C2142451
634B7370142E8A041593020E95010B9200098D030D7A151D9E767C7F8595223A68021A65
02196905215E3D597B637A876A7E816C807F6B7D85496078081F4C051D4B455D786B7D86
657685132750021358010D5D020D61000C5F011060011058000F4C071A4B0719410E1D3C
3748572C2F310EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0067CA306D48354F414D13102E0F0F305B516660546915123903093840446B32355E
040A3E05093B4E48677661727A5A697C56647F53618553618A55658C5767905F6A8A5B64
8F606794656C996A719D6D759F6F749F6F72A37676A67E7CA98481A9847EB18E85B09085
B09489AF958BAF968DB39E93B09D93AD9992A8958EAB9C97A89E9BA79E9CA89F9CB0A6A3
B1A9A5B4ACABB9B5B4B6B5B3B4B3B1B4B2B0B0AFAEA9A6A7A09EA1B4B3B7A7A7AB9DA0A3
A3A6A9A5A7ABABAEB2B2B6BAB7BBBFB2B9BCB7BDC0B8BFC2B6BEC0BDC4C7B8BEC3B9C1C5
BCC3C8BAC1C7B7BEC1BCC2C4B9BEC1B4B9BDB4BABDB1B6BAB4B8BCB0B6B9AFB7BBA9B3B5
A6B1B4A7B4BE8298B9133573525C918E49679E0E20B30513B60210B4020EB1010EAF0210
A40516922A3AEEC6D5DCD3E1D8D1E2D7D2E4D5CFE1D2CCDED4CCDFD3CADFCDC5E0494168
583A5D84334A8404168E010E93000C92010B8F020C7D06108E505D77758E0A1F5B011867
0721643D5C80627B88667A7D6C81826D8389596D8510265200154826405F657B876E8183
6D7E883F5471031551011059010D5B010E5C01115B0217530F2651445A7534475E07172D
42555E2A31321C941100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007F593E5448530B0A281C1A3665596B50465E070833030A3936395C474668
02053401063B262850695F75765C6B7A55627F546181505D8854638A55648C58658E5D66
93626B9A6871A06E779E6C75A07074A47478A5787AA57C7BA98380A98580AF8E85B09188
B0938BAF958CB0998FB29D92B09C93A9968EA99791AC9B96AC9E9BB1A6A4ACA39FAFA7A2
B5ACA8B3AFABB4B3B2B5B7B6ACADACB4B3B2B0ADAEACA7AAACABAFAEB2B4ABAEB0A3A6A8
A9AAADACAEB1A6ABADB3B9BCB3BABDAEB6B9B5BBBFB3B9BCB7BFC1BCC2C6BBC1C5B3BBBE
B6BEC1B3BBBEBABFC3BEC3C6B9BDC0BABFC1B4B9BBB2BABCB0B8BBAFB7BBADB5B9A8B1B4
ACB3B7A8B3B89FADC23453861935739578A089162CAE0A18B90613B3020FB1000EB20211
AF04179C0C21B44C66AA57749E5170974C6A9548679145669043668E41648D3F637C2C4F
862E4A8B1E328903138F010D92010D91010B8F010D8806147A2435624E7008195C031E64
37537F678091697E83677C7E678188567289142D5800164B142D535871816B7E836D8080
6D7D82697C8B21365C01144E0012550112560218511C395E4E687C5369714D5F6B041626
485C632B3536219C1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00946D4B4539430607242F2842695A6C332D48050C35050C374B4A68595370
05063102063C080D3E4F4B6B6F5C6C7A5A647C535D804F5C804B59854E5D8A55618F5C65
92616996656D9B6B739C6E759E72779F7578A6787CA97E80AA8281AA8682AE8D87AD8E88
AE928AAB9289B19A8FB39E94AD9991A7948EA8968FAE9F98ADA19CA79C9AB2A9A5AFA7A3
B1ABA7ACA9A79D9E9F9B9CA0AAABAEADADAEB7B5B6ABA7A9AAA9ACB1B4B6B1B4B4AEAFB0
B0B1B3A6ABAEA3A9ACACB2B5B2B9BCB3BABDB7BBC0BABDC1B8BCC0BBC1C5B9BFC3B8C0C3
B5BDBFB6BEC0B8BFC1BAC2C4B9BEC1BBC0C2B4B8BCB3BCBEAFB9BBB2BDBFADB6B9A9B1B4
AEB3B8AAB1B6A6B1BC798FB112326F6267998A415D9F1021B40715B2020FB2020FB0030F
B20212AD0417A70720A00B26990823980B249507229407229005229007238D04208D051C
8E05198F021390010D92010B92010B90000A8F000C8B0310780E20643F630B1758112D65
65809A6F848D6D8286677F88527089123160011D540C28534D677B667A806D7E7E70817E
6B7B7B6F7E83607382263E5B0C234D1029512E4A66607D895F787C536B6D495E67071B28
485F6533424126A31E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0072943B3A2D35070823423B51675A6E1A1936020B3414183C5F5771685D76
0B093101053B01073E191C485D536E795D6B7E556181505C84505C8954618C5865905F68
906268986A719A6E75956D758E6A71967378A47C81A47B7DA88080A78280AD8B87AC8D87
AF938CAB9489AC978AAD9A8EAB9A91A8978FAA9A92AC9F99A69C99ABA19EADA5A0B2ABA6
ADA8A68C8C8A92949695989C828489AEB0B3B2B2B4A1A0A2B2B4B5AAACAEBCBDBFAEAFAF
B5B6B7AEB2B4A2A7AAA9AEB1B6BABEB8BCC0B3B7BCBABEC3BBBFC3BABEC3BBBFC3B7BCC0
BAC0C3B9BFC2B6BEC1B8C2C3B6C0C2B6BEC1B3BABDB2BBBEAFB8BBAFBABCACB5B8B0B9BB
ACB5B8B2BBC09DA6AFBCCADD425F8F203B778C779F86273CA51020AE0714AF0410AC0410
B00511AE0511AC0512A60411A306119E07129B05119604109806139404129203108E020F
90021190031090020C90020B8F030D8D020C8F020E8B030E7A0A196F42600E17521B386B
67869E69828E667D903F597B0C285B001F5A0D2C5B4B687E60797E677A7B6D7E7C70827C
6C7D7B6F7F7F6A7B7D5F767B5B747F5D747D60767B6279795B7172536A6C425864071C2C
485F663C4B4B41393000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052BF2F281C200A0C24514C5F5C5468080C2C030B322D2D4C66596C6A596D
1C163A02053901064102073D27264F6C576E78536182566183535E83505B8A576190616A
93646B96696F996F7687636A896B747C616A95777D9F7C7EA47E7FA68281A98785A88984
AB9086A99185AD988BAB9A8EAA9A91A99C94A79B94A69C96A09693A59B97ACA5A0AAA5A0
9B99979A9E9DCDD3D2CACFD191959BA3A6ABABACB09397999EA2A4A6A9ABABADB1A3A6AB
AFB2B6A6A9ADA2A6AAA2A6ABB3B6BBB4B7BCB2B6BBB3BABDBBC0C4BBC0C4BEC3C7BCBFC4
BEC1C7BABEC4B8BDC2BAC2C6B9C1C4B7C0C2B5BDC0B4BCBEB0B9BBAFBABBB1BABEB0BABC
BBC6C9D1DDE2A3ADB7A9B5C08AA0BA2E4D7E32477C8A70968A374F921A2A98111F9C121C
9D12189C1618961618961B1C911A1D88161A8B191E86191D851A1F7F171D7B131879141B
79121C760F187B12197C10147D0F157C0C12810D157A0C126914198566761924550A2661
3B5C8C416088213D6D031D5A021C59163260536E85687F86687E7F667A796D807E6E807D
6A7D7C6D7E7F6D7D7D697A7A6B7C7B6978766977776678775A6E6E53696E2E45550E2337
4D626B49595C43413B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0058C3303321201310255D566747435902072B060C315049616F5B69715C6C
3126460304370105410105410708385343617452637C525F7F525C82525A8A5B6291636B
94656E966A7190676F936E7795767F755E677D686E9E7D81A78184A88284AB8787AA8A86
AC8F88AA9186A99489A9978CAF9E95A2948BA0968D9B948B9F9791A0969297908B9E9A94
A8A8A4AFB4B5D9DFE2D7DDE2A1A5ACA9AAAFAEAFB39DA2A5A3A6A896999BA4A6AA9FA2A8
A0A4AB9B9DA39DA1A79FA4AAB3B7BDB3B7BBB1B7BBBAC1C5B6BBBFBDC2C6BCC3C5BFC4C7
BDC1C6B9BDC2B9BCC2BDC2C7BBBFC4B9BFC2B4BBBEB4BBBDB2BBBEB6C1C2CED7D9B3BDC0
ABB5BBAEB9BFAAB3BBA7B5BCA9BAC5B9D0E8415F8D2E42726B658589677D87576D986373
A56E71A56E6DAB7774AB7A77AA7D7CA67A7BA67A7DA37A7DA57E809D7A7C97787E94747B
8364707B626D8C6A6E895F5E8B5F5E8D5B5B8E57598453538565638480844B5A760B2259
021F5E01205B021F58082357334C7260788B6E82887080836D7F816D7E7E6E7E7E728282
6E8081697B7D6D7C7E6D7C7C6C7A796C7A776674746373735D7072566A75152C421F384C
4F676E4E616040463F0FCB0700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF005BC32C52392F1B1223665D6D36324D050A331B1C3E615668715C67735C68
4D3C5A0602330307400206400A0A395E4D69775364794E5B7C4D5881535B8C5E679C6E78
9C6E78976B758E646E936C77896A7677616B7A64699D7C7EA78082A98285AA8687AA8987
AD8F8AA88E86AA968CAC9B92AB9A91A6998F9B92889E968C9A938AA19993968E8A9D9A95
BDBDBAB7BBBDB6BCC1B7BDC4B6B8C0ACAAB0AEAEAF9EA2A39A9C9F9192949C9B9F98999E
989AA094989F90969B989EA3B8BEC2B3B9BDB2B8BDBCC1C8B7BBC0BBBFC3BEC3C6B7BEC1
B5BDC0B5BCC1BBC1C6BAC1C4BEC5C8BCC2C5B9BEC2B7BEC1B5BCC0B2BBBFB7C0C3B3BABE
AEB5BBB3BCC2CED9DEA7B7BF9CACB7C9DBE6A9BED47F98B87D97B2A3B6CB617595425A79
C0CED8CDD2D4D1D3D4D2D4D6D3D3D6D2D4D7CFD2D8D0D3D9CFD3DAC7D0DE7389A1ADC0D6
5362754155658B959D7E8182868A88A0A19F8785878B8D8D9CA2A07985867A8892576A84
334A6F2C466B405A785D75896E838D6E82857081847181846F7F7F6E7E7E6F7D7E6E7F7E
6E80816D8082697A8064757A6576766273706476746274745C6F7745596E03163A27415E
48656F506665424B43209B1300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE01361412D271C246860701E1E3C040B3131314B6B5D68705B62755E69
5F4B620D063103063D01043A12103C6A567076506180536183545F885965936571986A76
996A779A6B77956B7687626D836570775E658B6D70A07A7BA67F7FA88282A78484A68785
A88C88A38B84A8938BAB99929E8E869D9187A2978EA1978E9F978D9D958C98908A93908B
ADAEADD6DADCD1D6DAD5D9DFBCBDC4A9A9AEACADAFA3A8A8A0A4A5A2A3A3ABABADA0A1A5
989B9F93979D888F93969D9FB2BABCB0B7BBBABFC7BBBDC6BCBFC5BEC1C7BCC0C5BEC4C7
BDC2C6B9BDC2BABFC6BBC2C7BCC4C7B6C0C1BBC0C4B5BCBFB5BDC0B2BABEB4BBBFC2C8CC
BDC2C8B0B8BFD2DCE2AFBCC798A6B3A0AEB9ADBFCB97B2CA5F84A7B7D9F46384A45B809F
C7E2EECEDFE5D0DDE4D1DCE3D3DBE3D0DAE2CCD8E1CAD7E2C9D6E2B4C5DC223E655F7D9A
74899A6B7E8BADBDC5A3B0B688959BC5D3D994A1A77B898C808F917787897B888D76848B
73838E6F828C7084897183867484877083837385867284856F7F7F6C7D7B6D7E7C6F8280
6E82816B8182566B76364F5B5B72775E72705E72715870754E657A12244A000D4001123E
233C554E686F4755522F6A1E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006F4929342225695F700F0F2F080C304D485C6F5C61715C5E755E65
6C586A1B133702043503063A19174169546D7753627F545F8355618659658E606C92636F
9969759A6B76986E78946D77906D759A787D9D787BA57D7FA67E7EA67F7DA4817FA48683
A18681A18A83A8948BA39189A6978EA4988EA1948CA2968E978D85958C839A918997918B
989594B5B5B7C0C2C6B1B3B7A0A1A4A0A0A4A6A8AAAAAFAFA6ABABACB0B0AEAFB3A5A6AA
9B9EA2999DA2888F929DA5A7B0B7B9B2B7BBBABFC4BEC2C7BDC0C5BBC0C6BAC0C5BBC1C4
BDC1C6BDBFC5BFC1C7BCC2C7B9C1C5B9C1C4B8BFC3B7BFC1B6BCC0B4BCBFB4BBC1D2DBDF
CAD0D6AFB6BDAEB7BDB1BBC4AEBBC995A9BCC8DDF0728FB50D39735982ADA3C2DAB2CDDF
CDE1EAD0DFE7CFDCE4D0DEE5CFDDE4D0DCE5CDD9E5CDDAE6C9D7E4B1C0D3596D8AA1BBD1
B8CBD9899AA8A8BBCABFD0DE7E8E9B83949D808F9678888A798A8D79888C7A878D768286
7785887585887284857385857386866F84836D81817688887282816F827E697B796F8281
6E81806A7E7F3F56650E273E57747D566E71556D763B546A11254E020F45000945000B41
03143C3B576848595B3C372B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00875A31422A2763576B09082B131435655969715C5E6F5A5A715C60
6F5C6934294703033103053A1B17416C566F7854638157638458648D626D91656F93646F
9969749B6D77996F789970789D747B9F777BA37B7FA67E80A67D7EA57E7DA3817EA58582
9D807CA3898299837BA6948BA3948B9E9389978C839A8E869A8E869D928A9F958E9C948D
948F8B9995939998989A9A999A9A97949493A3A6A7A4A9AAACB1B2A5A9ACAAADB1ABADB1
979A9F95989C8E92969BA3A5B3B9BBB3B8BBB6BEC1BAC2C5B5BDC0BDC5C8BCC4C8BCC4C7
BAC0C5BAC0C6BAC0C6B8C0C4B7BFC3B8BEC4B8BEC3B5BBBFD1D5DAC2C8CEB2BBC1B5BEC4
B2BAC0ACB7BBA6B2B6CBD7DEAABDD5415F81A6C0DB9CB5D343648E6489ABA5C1D2CCE2E9
D0DFE8D1DEE6D0DCE5CEDEE5CEDDE4CBDBE3CCD9E5CCD9E4C9D8E2C3D4E399ADC55D7D9B
98B7D19AAFC45B6E828393A47B889476848D88969A8191927B8A8D99A8AB768588798789
7583857382847584847383847283836F81826F82847283857181816D807F6C7D7E6E8182
6D7E81697E7E4F6573051B354E6C7E4D6A7B2B4262051643010B44010A45000944000B40
000D3C243C564B60633F3E3400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006986254D332954495A0606282626426B5E68725F60705D5F6D5B62
715C6A5647620604300104371C1A416C59707955647F54618459658C626C906670946973
956973986C769B717A9E757D9D747C9E747AA2787CA07678A47B7CA37B7DA47D7DA58181
9D7B799B7E799B857CA08E83A6968DA4978E988E85948A819C9389A39A90A0978F9D968E
95918A9B9891989691A09F9A93938E91928E989B98A3A9A8A9AEB0A7ABAFA5A8ACABAEB3
95999C8D8F938E9195959C9FB4BABDB8BEC1B0B9BBBAC3C5B6BFC1BCC4C8B9BFC3BCC2C6
BBC2C8B1B8BFADB5BD9FA9AFB4BCC2BDC3C7C2C8CCB7BDC1BEC5C8B8C0C4B8C1C5AFB9BC
BCC8CCCADAE0A4B7C1C1D3DDB8CCE2607A9A92A9C29FB4C4B6D0E56388A4A6C4D6CAE0E7
CEDFE7D2DFE7CFDBE4CEDDE5CDDDE5CADBE3CCDAE4CDDBE5C9D8E7B2C6DAA5BCD61F3E63
40617F8298A9798895909EA9B4C2CA808E969BA9AF9FACB17C898F78868B768589758384
7683857684867681837583847583846D7D7D6F80837080857281856F81836B7C7F6B7D7F
6A7C7E667A7B5E7280081D3C314B6F102851011145000945010846000842010B42000C41
010E3C10223E496062484B3F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0047AF195B3D2D453B4C070829403C536E5E676F5E63594F5A544B5D
6C5C6E64546C110E3604083919183F6E5B737C5967835B678C656E8B636C8C646C936A73
966C769D737B9B72799F767F9D737C9A6E779F757A986F71A0777AA57D81A47F829E7A7B
987876A38984A08D84A4948AA18F879C8C85988D849A91879F988DA1988EA39B93A29A96
95908B9E9B949D9B95A09F9A9B9B96999B96999C97A3A9A6AFB6B6AAB3B59EA5A7B4B6BA
A0A1A694959A8C8F938D9497B2B8BBB5BCBEAAB2B4B9C1C4B9C1C3BCC4C8B9C0C4BFC5C9
B1B6BDADB4BBB8C0C6B3BCC2BEC7CCBDC5C8BDC6C8B7BFC4B6BEC3B8C2C4BFC9CDADBBBF
BECDD3CBDDE6899DAAA5B7C2AEBEC9B6C8DB8EA9C793B3D0AACCE42A5474B3D1E7CDE0EA
D0DFE7D2DFE7D0DDE6CEDCE5CCDBE6CBDCE6CDDBE6CBD9E3CBD9EA677C948498AE768DA0
7E96A6BFD4DEA6B5BE909EA8BFCED98D9EA67B8A907D8A8F7A878D7A888C7A898D798889
7686867283827182817283837482837383826F81836E81847382866E7F816E7E816C7E7E
6A7E7F61767D556C830D204B011148000B48000846000846000845010943010D41010F3D
020F3C041533465E634C564A10CC0800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB41A6B4936372D3E080728524A606855605F5364171837101534
5A546A675A6D2E284904083614133E6D5B747D5C6C825D6A8E67728B646C936A73976D76
9970799C747C9B717A9C737C9D727C9E737C9F767BA0787B9D7579A0787DA17C7F9A797A
A08381A58F8A9F8F889D8D859C8A839C8C859A8E859A91879D968C9F989199928D9D9792
96908B99948EA2A099A09F9B9A9B979A9B99979997ACAEADA2A9AA9BA5A799A2A4B3B4B8
A7A5AB94959A8E95988D9699A7AFB1B4BBBDAEB6B9BCC4C7BDC4C8BDC3C8BCC3C7B9C1C5
BAC3C6A8B2B5B1B8BEB2BBC0B6C0C3B6C0C2B1BABEBDC5CAB5BDC2C6D0D5D2DEE6ABBAC2
AEBBC4B0BFC6B2C3CCAABDC9B0C5D2C1D8EE2C52831C4A808BB0D381A1BACBE0EFCFDDE6
CFDCE5D0DDE6CFDDE6CEDDE5CEDBE5CEDCE7CBD9E6CCDAE5C7D7E77A91AABCD4EABFD4E3
879CAFAAC2D3B3C5D27986957583917B8B947A898E86959794A1A77281859CAAAF8F9FA1
7486867286846F827F70817F7583847180826C7E8172868778878A7484866F7D826C7F82
687E87536C811B315B010F46000949010847010847010846000843010D4102153D142D4A
1025440113303D565F505D55219D1400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057BB1D7B563D2E202E0D0C275E54646A5B6639344E040B35030D36
464761675C6D4F455E0608320C0E396C5E7B7C5D6E86616F9269788D6571926872946A73
997078966D76966C75996E789B7079A4787FA3797F996F72A07779A2797BA27D7E987978
9F83819E88839D8D869D8F86A2948C9E8F889D8E889C90889A918CA9A29E9B979298958E
98948D9A968EA4A39AA4A39F9A9A99999998989898AAA9AA9A9B9D8E94968A9092ACAEAF
B1B0B49FA2A68B9396929B9FA6ADB0BCC2C5B6BCBFBAC0C3B6BDC1BABFC5BBC1C7B7BFC5
B5BFC4AAB5B9B0B7BDB9C1C6BEC7CAB6BEC2BCC5C9D5DDE1BDC5CDB6C1C9BECBD4ABB9C1
B1BDC3B2C1C6CCE0ED87A8C47598B7B2CEEA42648E2E588587A4C1CDE0EDD3E0E7D4E0E7
CFDCE5D0DEE6D0DEE7D1DFE6D2DCE5CFDDE7CBD9E8CBDBEBC6D7F15B749B5B729EA5B1D5
707696464B66969AAB9398A47D85917C8A9277858D8D9FA3BCCBD27E8C947B88917B898E
78888A7386847484817382817381836F7F807184847083847587897486886E7E86657B89
3F57780F2556011350000C4A01094A010848000845000940010C3D0B1D40324B604C6773
4A617105172E38515E4F5F5A336F2300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007C53342519211B182C675D69655968181736020A37030B38
34345465586A68596C1E183C070A345E55757A5F72866373916A7A8F6675916873946874
916770916870956B73996F789D707AA0737BA1757B996E71A07578A4787AA17A799B7A77
997C79A087839E8A849D8C84A5958EA3948D9E9089A09390988E89A59C97A39D97918E85
98958B9490889A98939999979A9A9A919190969595A8A7A79A999A9E9EA2929495ACAEAE
B5B7B6A2A4A4999FA299A1A59DA3A8BCC1C5BEC3C6BCC2C5BDC3C7BBC1C5B2B9BEB5BEC2
B2BCC0A6B1B4B3BCC1BBC3C9C1CACFB9C2C8BDC6CBCBD4D8B6C0C7B2BBC2B8C2C9CDDAE1
C5D6E0ACC0CBC5DBEC4165854A6F9298B1C9A6BED791B3D086A4BAD1E3EDD3E0E6D1DEE4
D2DFE7D2DFE7D1DFE8D1DEE7CFDDE8CBDEEEC3D6EFACC0E17880AE3C356C4F2F68683462
733256753754A16C84C8A4B69A889783858D8188917C8991818E9A74838B717F87758388
79878B7584847585847182816D7D7D708181708282718383748688728589637886253E63
03195601145A000F57010B4E010748000845010C4102143C1C304B475D6953686E586C6F
5D6F78142738364E5B50605F4A453700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00845B3524181F2822356C5F6B51475808092C030B3A020A38
312E4F6E5C6C6D56644E405B08072F45406379647889697795707F956C7A926673946773
916672916870986E769C727B9D727B9D737BA1787D9C74779F7578A4787A9D75759D7A77
9C7E7BA08682A28A86A28D879F8C869B8C859B8F889C928B9A90899F9590A49B95968F88
948E86928D8893908E9999989293928F908E9B9C99A4A6A49E9FA2A2A2A79B9B9FAFB1B1
B4B5B4B0B2B3A5ABAE98A0A39FA5AABABEC2B6BCBFB9C1C4B6BFC2B8C0C3B5BEC1B7BFC3
B9C1C4AFB9BAC0C9CEC1CCD1C9D5DCB1BEC6B4BDC3B6C0C2C2CCD2C0CAD0BFCAD0D2E1E9
8DA1B398AEBFAEC2CFA6C1D1A7C6DE92B1CABDDBF5486E8F7C9FB7CDE1EBD2E0E7D2E0E6
D2DFE7D1DEE8CFDEECCADDEEC6D9F4A2B6DB656C9B5B497C6A376B75214E7D0E35870726
8C06228807218209267D15317B2E448F677493898E81878E79848E91A0A67B898F788389
7C878B7A88897A8A89798A8A778688738484697A7A6B7E7D707F8272848A54687E02194E
00115D00105F020F5B000A52010849000C41081A3D2D46584F6A6E576D6C576869596A6A
5E6C74182938364F59526264514E4600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008D61362112143831416E606A3C324604072D030A3B030A39
312B4D6D58696E525E70596D20173A27244875657A816372906C7B9268759265718F636E
916672906670966B759C727B9E767EA17A819E767D9870759B7275A178799871729A7776
A0807FA186839E8581A18B859E8A839A89839B8E89998F899C928CA29894A49B979C948F
9C94909A94909997949B9B9A969796929492979997A2A4A59C9EA19B9DA1A9AAADAFB0B2
BFC0C2B0B6B8A6ADB0959DA1A9B1B3B3B9BCB9C0C2BAC3C5B6BEC0B9C0C3B6BFC3B8C1C5
BAC3C6C4CFD0C5D1D4B4C1C7B2BEC6B2BEC3B7C0C7BDC6CAD8E3E9D1DEE6B7C4CDBBC9D3
A9B9C7AFC3D0A4BCC6C2DDE9779DC12B5A8D769EC96E91AEBBD5E6CFDFE8D1DEE7D1DFE9
CDDCEACBDCF0C4D7F599AAD363639763497F783B6E801E478A0B2D94061E970115970211
95010F9301119201148D021786071B731526B88E97C7C2C7869198A8B6BC8C99A078848B
7B878D7C8A8B7B898A76868678878A77868A76858873858674858771848962758B04184F
01105D00105E010F5D010F55000D48152A50465F6C566E6F58706C5A6F6A576B69576C68
586A711525353A525C5366685555510FCA0700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006988271F0D0A413B466C626C262037050933010A3C030938
3931516F56687254606F536052425B1811326A5B737D606F8F6B7A916776916470936671
9265719468739569739B71799B737A9E777E9D757C956B729C73769F767A9770749A7778
987B799C817E9A827D9A847D98857E9B8A849C8E889A8E88988E889D9591A29B969C9691
97918D958F8C9E9B999999989A9B999294929C9D9D9C9D9FA1A3A5999D9FA8ABADAEB1B2
BCC1C3AAB2B3A4ABAE939A9EA4ACAFAAB1B4BBC1C4B3BABDB9BEC1BEC5C7B9C1C5B8C0C4
B4BEC0BBC6C7BDC9CAA9B5BCB6C1C8CFD9DCCBD4DAB6C1C6C2D0D7B2C2C9B3C0CAADBBC3
C7D7DFBCD5E787AAC4ACCEE93E66930D3B78416B97B9D5E7CCDFE9CDDEE8CEDEEBCCDEF1
BDCFF08C9AC6625E9367447D7F356A881B47940D2C9C061C9F02159F02119D020F97010C
94000C92000B91010C91000D90010F880619832D3DD0ADBA95949D7E8A907D8B907C8A90
7A888E7B898B7A888A78878B78888A76868978878B76868977858B75868C7083960B2052
01125A01125B0115560C215807164837506A577074576F6A5A70675B706A5A6E69576C68
50646D05172B425966566C6E5359561F981200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0043AC19250F06493E48685E6A13102C040935030C3C040A35
3C324F6E546272535B74555E6F57673628424F3E5880627386616F8F65738B606D956874
996B779C6F7B996C779C707A9B717AA078809E757B9B72749C7376976D7392696E977374
987A789C807C937B749E88819A88819E8D869D8E87978B849B928C9F9794A09A969C9792
958E8B8E88879D9A9990908F9395929394939A9B9C989B9CA0A6A69FA4A6A3A7A9A9AEB0
B5BCBDA9AFB1A0A4A7A5A9ADA3A8ADADB2B6BCC3C6B2B9BCB9C0C3BCC3C7BBC2C6BCC4C7
B5BEC0BEC8CAC6D0D2B1BCC1B6C0C6CED8DDC9D4D9B3BFC5B4C1C7C0D0D6C8D9E3B6CAD5
C4D7E4819DB81A426A84A6C28FADC886A9CE89B3D4BEDDF0C5DBEEC2D7F0B0C1E2898EB9
67568B6940787A2E6286173F960B2C9C061E9F05169E0512990511960813940B15890813
8805138C030E8F010A91010B93010D92021185081A7F303F9B808A808489808D91808F92
7C8D90798A8C79878D79888D78868A78868A7A868B768487738187738388738696152C55
021853051D532942695A728D1C2F502C445E5971765A716D5C716A5A6F695D706C586C6C
31465603162F4A626F586C6E53605B24A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004BB21C2A110451444B5D52600907260309302F345A0C0D2F
473B5272576376555D73545B775B66715B6C4E364A7E607085606E8C6370926773976977
966977976A77966A74986C769B707BA0777F9C7277986F71986F71966B6E966C6F95706F
967874947B749B837C9D87809A87809F8E87998A849A8E889B938F9E97959C97949F9996
968D8B968D8B9995918B8B879293908C8D8B979A9B959A9A9AA0A19CA0A39DA1A4A6AAAD
B2B6BAB5B7BBA7A9AEAEB1B6A3AAADA4ACAFBAC3C6BDC4C7BBC1C5BEC5C9BDC3C7C1C8CC
BBC1C6B9C0C4D0D7DCD1DAE1B6BFC5B6C1C6B5C0C5C0CCD2B5C1C7C8DAE4ACC8E07EA2BE
A9C0D39FB0C48CA0BAA2B7C8ABBED0A2BDDA4A6C95A0B8DD8F93BC7E719E7953867E3D71
802353841138910D2B980D209409168D08108D101784121880202685363B8848527B4153
7D374E7713258A041291020D95010D93000B9002107F0B1B965A648C8487858E91879598
7E8C917C8B907C8A9178868C7584887684897883897784896E7E8372848872848E29425A
1F385A4E6680657D8A687E882D42591D364E59727B5D72725E716F5A6F6A5D706D596D70
12263712273B4F696F576D6C58666135732700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0054B92031140355484F5A52640506260E11315C5A74171229
4F455470596275565D75545C755761785C677B5D6A7E5C6A845E6C9066748F64728F626E
976975986975986A749A6E78996E78A0747E9A6F769A727699717493686C93676996706E
93736F967C769D857F9B857F9A867FA290899B8A859A8E8A958D879994909D9894999390
938A8898908C96918C8A87828989848C8C88979997929797959A9C989B9FACAFB2A7ABAD
AFB3B7B8BABFA6A9ADA7AEB1A3AEAFA5AFB1AEB8BABAC3C6BDC4C8BFC4C9BCC2C6CED3D7
C0C4CAC1C8CCC0C7CCBCC3CAB9C1C7B5BEC4CBD7DDD4E3EAC5D3DCB2C6D7638AB14073A4
9DB9DBB2B2C7DAC8DBBFA7BD997D9B85678D7B59878653817F38668429548B1A40921234
99122B930C1E94111F8D18207F1D207A2C2B7E3F3E8053539075797B727E595E774A5476
2C2851693B5D780C2390041594011194010C94010E8D05168026349B8083818687808B8E
7F8A8F7E8C917D8B8F7D898C7C888B79898B77858A7381856F8083728586738588687D85
687D876B7F866B7F836A7E85455B6E0E263F57727C5D72736174735E736E5C716C5A7070
182D37385059546C6D5A716D56686146463800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDE103A1806594A52453F5504052522203A685F721B1325
5E525E6C555B72555B76575F7456617A5B677C5C687E5C6A896473936B7A8D6471926672
936571976874976A74996C77996D779B6E77966B73966E73956D7390666A92676997706F
95716E9576719E847E9F888299827D9C88839D8A86998B87988E8899928D9E9995999490
8F8885A29B988B86838B8884908C8893908C9898948F949291989999A0A2A9AEB1AEB2B5
A9ADB1B2B8BBA3A9ACACB5B7A1ABADACB6B8A7B0B2BFC7CBBEC4CABBC2C6BFC5C9C6CBCF
BEC2C6BEC5C8BBC1C6C4CACFD3D7DDC1C8CFC3CED4BDCCD4ADBDC6B1C5D27D9EC01B4C84
567AB38081A9774E6D823A5A872C4C8B24438D193694173395142D9213288F13238A151F
881C2380232884393D8954538A6967978683ADA5A5BEBFC5B0BCCA5E728A092247627EA0
2E436E3B3463681D3F85051A91011192010D93000C9003107C0C1A9D6A6E8B8787848E8F
818D8F7F8D8F7B8A8B7E8B8C7C898B7889897585867385856D7E7F6F8281718383718484
7184876F82856E7F826A7C815A6F7D0720375570795D72745E71715E726F5D726E576E6A
4258594F6766536967596F6B5A6D654D524700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004C220B57434B39334B040727363349685B6A1F1322
6B5A656F565C75575F72545D6E515B7657637959627C5A66825F6C8A6271916775926774
90636F946773946974986D779C71799C7079996E76966D74956C718F6367956A6C946E6D
9A75729B7875987B77977F7A9A837E9986819E8E88A2938E978D88968D899F9895938E8A
9F9B97A7A39F908C89938E8B918D89989694999B998E9392969B9C9A9EA1A1A6AAA0A4AA
9EA3AAB2BBBEA2ABADBCC3C6A8AEB2ACB4B7ABAFB3B0B6BBC8CED3BFC4C9C1C5C8C3C7CB
BDC3C6BDC3C7B8BEC6C9CFD6DCE0E7CAD1D8BAC3C9B8C4C9C8D7DDC3D5DDB4CADD779CC8
0E397E3B56937F79A7926C908D4D6A89364C892A398827338628338330377D383B7F4745
8E62609A7D7C9B8D8DB1B1AEC1C9C7CAD7D7CBD8DCC1CFDD49627594ADC0768CA49CB4C8
7C94B6131D516137617508218C021492010F92000B90010B850511863A40968283858A8B
808B8C7C8A8B7B8A8B7C8A8C7C898C7B8A8C79898A7284847485866F80806F8080708082
6F80817081827281836C7E816577821F38465772785C73755D72725F72715C706D5A6E6A
5B6E6D516866455C5B596D6B5C6E69575E541E960F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006032155842472C2640070A294E475A64545F291A26
6B586170575B7053586F51596B4D5670505A75545E7756607B586386606C8C636F8C606D
8E616D9669759268729970789970779B7077946971966D74956C7293686B9D73759B7676
9B78779977769B7D7A9A807B98827C96847F9E9089998F87978D88958B8899918E999590
9E9C97A4A19D99959299959191918C989D989CA2A18B909195999C959A9EA1A7AD999FA7
828992848C9299A3A6BEC7CAB5BCBFB5BABEB6BABFB4B9BEBFC5C9C5C9CEBFC2C8C5C9CE
D5DCE3D7E1E6C3CDD3B8C1C8BEC6CDBEC8CEBDC7CDBCC9CFCEDFEAB1CBDCADC5D996AFCA
4667946183B552719E596E95535C7E7E778B8A76818A6F799C838A9885899E9496ABA9A8
C3C5C4CAD1D2CDD8DACAD9DAC9D8DDC6D8DEC9D7E0BBCCDE658296BDDAE8C0D5E27994A6
8AA7C7152A5C4233646B173686031990010F92000C92010B8D040F77141C9D757988878A
7F8A8B7B87897D8B8E7B898B7D888E7B898C7382846C8081748589738184738284738084
7482837180807281836E7C817180876B7D8365797C5F77765D73725F73715E726E5D716C
5D6F6E586C6C33494B5268685B6D6B5A635B229D1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0076461C533D40201C370E0F2D6156675A4A56332637
5A4E5F5C4A556950556A4C536D4C56724E5974525D75545E7D57628259658A5F6A926570
946572956672966A74966D76966E769A7177976D73976D75976D75966D72986F729C7577
9A7879997B799E827F9D858098827D927F7A9E918A978D86948B848F86808F888197938E
A2A09BA4A19D9E9A9897969391938E989C979BA09F8E92968E95988F979B9DA5A97C848B
949DA39DA7AA889395B2BABDB7BEC1B7BCC1B9BFC4B6BDC1B2BABDC4CACFC4C8CFC0C5CE
C7D1D9C8D3D9BEC8CEB8C2C6BAC5C8D4E2E6D4E3EBBAC9D1AEC0CF516C8397AFC2B0C2CF
BED5E8A9CBEE739DCC8CB5DC7094AEC1D7E5CAD6DCCFD5DBD0D6DBD1DADFD0D9DFCEDADD
CDDADFCBDAE0C9D9DFC8DAE1C7D9E1C7D8E0C8D6E3C2D4E94968897092B294B0C5486178
37526F536A911C1F516C375A7A071E8F021292000C92010B8F020B7D070E9252588F8687
828C8E7F8A8B7E8A8B7C8A8B7B898E7A898C778688748588748388758386748386737F84
778286748284728084728084717E83707E836B7E80657B7B5F74755E72715E73705C706D
5C6F6D5D70702A41463E585E54696B59655F356F2600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002E970649343316162F1E1D38685C6A4A3E4C302C45
1818371C17315A4B5A674D566F4E586F4A56744F5B78525E7C5460835765895B678B5F69
8D616B91626D946772926772956D769B737A936A6F9B7176986D7592666C9B71739A7274
9B777A9F807F9D827E9D86829B858098847D9A8B83978B849188808A827B8B867D96928A
9C979398928EA49F9C9897959395919A9C9AA2A6A88A8F937B80837C83858F989A798286
8F989D8C969B949DA0B7BBBFC0C3C7B8BDC1B2BABDB4BDC1ADB6BAC6CFD2CAD1D6BEC5CD
B7C1C7B9C4C9CDD6DCCAD3D8BEC8CCC8D7DEAABCCAB5C6CFB7C6D0B7CBD8C5DDEDB4CEE0
B7D1EC3862950B408443729CC1DEEFCCDEE6CFDCE3CFDAE2CFDCE3CEDDE3CEDAE3CCD9E0
CCDBE2CADBE3C6D9E5C2DAE7C4DAE7C6D8E2CAD7E6AEBDD6142C59062250859FB7AEC3CF
90A2B3AABED7152451513C656C112D8A051692000E90000A90010A87050E7C242A9C8183
8287897F8A8C7E8B8C7C8C8D78888B78878B79868A77858878858A738387728185727F85
738085728084717F84728183707E827181866C7F85687D806276796074745F73725C716F
5B706F5A6F70324A5219343F465D645A69674E483C00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF003BA40F3B26220E0F292D2C43695F6A3931420F1131
04083005062B494157634C56694A526E4955724C5A76515D7A535F7F54618558638B5E68
8B606A8F626D9467739469749970799A727A997176976E7390646B94676C9A6E719C7376
9C777B9C7B7C9B817D98837E9A86809B8B829889819B8D869689859187838C847F958E8A
928A87928B88A2A09C92928F9599959BA09E909798838A8C828788888B8C7B7F8294989D
7E8488878F94A5ABB0B5B7BCC4C4C8BABEC2B9BFC4C1C9CDB6BCC0BFC5C9BDC5C7BCC3C9
B4BCC3C0CBD1D6E1E8D8E1EABBC4CDB9C5CFABBBC7C3D2DBBCCBD3C5DAE985A6CC5481B1
8DB3DB48709C285488779EBDC9E0EFC9DDECC9DDEECADBECCFDAEAD1DAE6D1D9E4CED8E1
CCDAE2CAD9E8A8BDD67D9EC1ACC6E5BEC6DFC4BFD7BAAFCB584D74373356AEB6C8C5D5DD
A5B7C48299B13349732322536C325580091D91020E92010A93010C8E030C7D0C159E6A6D
8883867F8C8C7A8A8A798B8D7A898C7C8A8D7C898C7B878B79878A708085738287728183
7281836F7D80738185728081707F806E80836C8082677D7D687B7E6276775C72725A7172
596E70556B6D415A603A5760415A615B6B6A56524900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BB119341C14090722403D537065722D253A030528
01042D0204293D344C644D5867494F6C4A53714D5774515A754E587D525E835561895A66
8A5C688C616D936874926772956B76946E76956F77966C7593656E95686E986F72997274
9C787B9B7B7C9E83819E8A849C8A839E90879A8B85978885998B899388868B828099918D
8E88848C898494938D8F908B90938F9FA5A37C858592999B7F8484919496777A7E95999D
959B9E98A1A2ACB4B8B9BDC0BFC2C5BDC0C5BBC1C7BCC4C8BAC1C4B9C1C4CAD4D5D6DFE2
C5CED5C0C9D2BDC7D0B4C1C9BDC7CFBAC4CCCDDCE6C6DDEFBFD7EBB0C7E0325789174A83
78A1C6A6C5DDB4D3ECC1DDF1C3DCF49CB9DC7186AE908DB1AD93B2AA86A3BC9BB7C9B3C9
D2C9DDD4D5E999A6C6122E623E4C7F563A64692A4F7126446B1D3B611E37826273A8AAB4
8494A23E5469647A9C0F1A4B6245706E0E268E051392010B94010C94010C8D09158A3B40
978586808C897B8B8B798A8B7A898B7B898C7B8B8B7A8A8B77878A75868A748285728383
7483846E7D7F6F7E816F80807082826C7F7E6A7F80697F7D687D7E6378775D7673587271
5A6F71566C6B4E64691A353F415B6358686963615C20960F00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056BB1E4428190E0920585067706273221934020229
01032E0304293A3047644B556B4D506C4D5170505572515777535C7F56617F525F855461
8E5F6C8C5F6B90666F8F6470936874946A75946B75976A759666719568719C73779A7577
A07E809E7F7F9C817F9D87849D8B869D8D88978884988B87948B85918B8788827D918C85
8F8A858884808C8A859693908D8B899B9C9B8186878E9497818589818588818588929699
949B9DA3ADADA9B2B4BAC1C3B9C0C2BABEC3BBC0C6BBC3C6C0C9CBB8C1C5C5CED1D1DADE
C2CBD2C0C8D1B9C3CBCAD6DCD7E2E9C9D3DBC0CFE15F82A4587EA3A6BED890AACA8EB6DE
9FC9F08CB2CF8EAEC4BBD8F26484B230497F614D817C37618623488B1F41841B3F7E2449
874062A26E8CB897B94032634331636B2E55780B2C81041B8204187A081B6B1F2F95828B
BEC9D099ABB8A6B9D02E436B38346268264385071994030F93000B97010C9405127D141D
A0787A8689867F8C8C7B8B8B78878A7B8A8D768889778A8B76888B77878A768587778484
7482837182826F81836D81816E82826C80806D81826D82816B8081657B796077745B7470
586E6D596E6C586C6D243F441F3B43546969626963229C1600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00583620160B1B6F63766E5E6F140C28020329
00012D0201273B2E45664D546A4D4F6C4D5170505672515977545F7E57627D525D825560
865A64895D678D626B8E636C956A74946872966A74956771966570986B749F747A9E767B
9E7A7D9D7D7E9C807E9A8382978382978683968985958D88C4C0BBCAC8C69D9B99888480
908A8687827F8D88859792908B86869796949799998081847C7B817C7C7F90919395989A
9A9FA29EA7A9A9B3B4BBC5C6BBC4C5BEC4C7B6BABDC4CBCDD9E0E3C0C6CEC3CAD1C5CDD3
CAD3D9CAD2D9BBC5CBCFDCE2C2D3E0C2D3E1B5C4D5809CB797B7D5C0D7F0AABFD97295C4
17498A245488A9CDEA99BBDD0F316D60629573284D90112C98081F99081D990C248F0B25
840E2B811B3B7117396E23477D3A5E9745607E0C228B061689010F83020F700816946771
CED0D6C1D1D97B8DA04960820F1A4A664263750A208F021194010C96010C950210820612
9552599286887F888B7A898B7B8A8D7C8B8F748688778B8B758788778789728081778585
7382837183847183867084856C80816E83847084857084837082826A7E7D667C7A5E7672
5C716F5B6F6C596C6B49656529484D4D6A6B5E6C6942382900FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00734A272412176F606E6A5B6C0B0521010327
00032A020225392E43654D54674B4E694C506C4E5570515974545D7A565E7C535C7F545E
875C688A606A895F688F636D9569739468729367719A6C7590616A9669719C7178A1797E
9E787D9F7D809D83819A848095807E9D8B87978B87B3B0ADD5D6D6D4D6D8BEBDC1817D7E
867F7E837D7B8A8582938F8C8A87859291909C9D9A8F8E8E8F8A8D8783868E8F91909397
91969B97A0A2A7B1B2B5BEC0B7BEC0CCD1D5B9BEC1C3C9CCC9D0D3BFC6CCBDC3CAC7CFD3
D9E2E7D9E3E9D0D9E1BFCAD3899BAAABBECBBECCD8B7CCDAAFCFEE89B0D88CB0D73A6193
0E3C80225082BAD9F47597BA0F316B7D729D7919369B0C1F9F0817A10C1B9B0B1C900F1B
84212C7223356C1E386E173378143290243E890D238E07168E03108A010C880C1A7A2C3A
A9959FA1A8B06F7D8A5667821928544538606A193488051792010C93000B93010D8F0513
80222E9E7E8483878A7D8B8F7A8B8D7A898D78888C798A8A778989778889728183738284
7281847081826F80836D81827083836E81836F82827083816E81806E82806B807E667B79
6376765D6F6F57696B476166193640415E625B6C6A47453600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008D5D303F2520705E685A4D6105021E030426
0206280202203F3345654D52694D506A4E526C4F5671555B74565C77555C79535B7E545E
825664875A67895D678B5F698D626C92677097697497697294666E91646A996D739C7478
A17B7E9F7E7EA186839A84809F8A86998782948884B7B4B4D3D5DAD4D5DEAFADB4817C7C
887F7D867D7B847F7B908C898787848989889998989392919492938786888A8C90898D92
8C93978F989BA6AFB1BABFC3B8BDC0C8CDD2BAC0C5C3CACDC4CCCFD3DADED8DDE2C6CED2
CBD6DCBAC9D2C5D0D9BDC6CEBFCBD5D0E3F0CDE3F5B0CBE0466E9B0E4380406F9C7FA1C0
7B9BBDA5C4DECAE1F37D99BB0D2C666C62907B1E3B9A0E219F0A1AA51222970B1B82191F
B98387A189926750664C2A476122456D11307E061E8F09198E02119103109005137A0E1D
8F5E6ABFBCC2BFCAD27D8B9C3F4E73191B486C3A5C7B071D91030F94020D92000B910210
7B0A189A666E8A86897D898D7A8A8E7B8A8C7A888A788789798A8C748589748487768588
7583867483847381847282827584857181826F81817185836D81816E82826E81816B7F7E
66787A5E7273586D6F3D545B0B2531415E625B706D4E524510CB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0046AF1C78594C735D6543374A03011D080722
2D2B4405021A473A496950566B4D506A4C526C4D556F515772525977545D7A535D7D535E
825463885966895A668C606A8D636C936970986B74956771936670946870966B729E777B
9F797BA17E7DA186829E89849F8D889B89849587849B9293BDB9BFB2ADB48A8285837A78
89807B877E7A807B788D8C888B8C888989869795959393948B8D8F86878B878B908A9094
88919497A1A3B9C1C3B8BEC1B8BDC2BABFC5B9C0C4C3CBCEC9D2D4D7E0E3D7E1E4C3CCD1
B8C4CAAAB9C0CDDAE1D4DDE5BBC8D698B3D15A83AD90B4D46E90B4416C9893BCDDA7C7DB
B4CBDCC0D2DFCFDEECA1B8D50F2C6756568B752948931023A30D1FA10C1F9107187A1C25
DCBEC2D5D7DCCCD2E18C92AB3D355A502D556213337A061A8701108E0110920312870917
7C333EC9BABFCAD4DA97A6B2657390101B4757406870142C8F051496020C95010C90010E
850515873C469282847F888A7A888D7C8B8E7A898B7685887384887284886F8283728484
76858676828475808475838579898B7485857183837185846D81826D81836E81816E8382
677C7D5D7274586D6E5267692A4248365052596D6950574A0FCB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049B11B84614E71585C2F2233030219221D2E
584D5A1006174F3F4D644C50694D4E6C4E536E4F576C4D5570505876515C7A535D7E535F
8354618959648B5C678B5F6990656E91666E93676E93666F9268719369729870789D767B
9C75779D7A7A9E837F9C88829D8A879D8A8A9786869183838B7E80887B7B887B78877B75
877D77867D78827C7885807D878581908F8B9797948B8E8D8C8F917F818683888D838B8F
8A91959CA0A6A1A7AAB6BCBFBFC4C9BAC0C5CFD9DAD2DCDEC0CACDCAD3D7CBD4D6C9D2D4
C1CBCDC5D1D6D2E2ECD4E5F3BDCCDF607E9E3260899CC1DCA9C3D9AFD0EF7DA8D55C8AB6
8EB3CBCADFEBD0DDE9C5D9EF2D4B803846817E4D728C162DA10E1EA60F2098091B7E1727
C3A0AAD4D8DFCBD9E0CAD8E4A7B4CE262E59422B576D1F3A860B1E9004129302118F0513
7913209C777E93999E83939B69798C323F652824506E314D80061690010B94000C91010C
8C031079171E9A76798083857B8A8D78888C7586887385877383867385896E8183728585
7786867584857282847184856F81857284857082837386866F81847083856F83846E8583
677B7F6175795B6D6E576B6A536968485E5D5C6D695B625720991100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B81E835D446C55552016270402163F3741
57484D1408135947526B4F556C4F536E51556C5157694C536E4E57714C5779525D7E545F
84576382545E8658638659658D616B92656F94676D94686D946870976D759971789D7479
9F77799C7A799D807D9D85829C8787A08B8D9A898990817F8C7E7B8E7F7B8B7D77867A72
877D76887E79847B77877E7D8B86848B8A87959593898B8B898A8E88888D82848B8A8F94
8D9197979BA09DA4A7B1B9BBBFC3C8B6BABFCAD3D5C5CFD3BBC5CAC0C8CED3DBDFD7E1E4
CFDCDFBDCDD4A5BBCB748DA4B5C6D7AAC0CEB3D4EAB5DBF7ABCFF07BA0CB114083083E7F
79A3C3CCE1ECD1DEE6D1E1F06682AC152D6C735F8C76173296091CA20D1C98081B830E22
945A6ADBD5DECDDBE1CBD9E1CCDBEA6B7E9F1E295C6E456C780E268F0615940111960414
83071785454D9E989CC3D0D3A3B3BF5E6D8A0D144268486D6E0D218A031091000B92000B
91020D7F07109252588E83867D888B76878977888B74868974858875888C73868A738588
7485866F80846C7F816C81826E82837083856C7F81708385748487738585708585708885
6C7F8364777B5F7172596D6C586D6B576B695F706D5E6661356B2100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002DDE108C6444604B49130C1B08051652454B
5342441B0D15634B566D4E556A4C516C4F536D4E556B4B53714F58734F5977525D7D5560
7C515D845664875867895A688D5F6A90646D90646C93666C94686E986C72976D72997072
9D75769F797A9E7D7B9D837F9C88869E8B899989858D7E798E80798F817C8D8078857A71
877D768A807C857B7A837A7A8781828E8B8B8F8F8E88898C84858A888990878990899093
8C94979BA3A59BA4A6C3CDCFD4DCE0BBC0C6C2C8CCC2C9CDCDD6DBC3CBD1CDD7DFD0DFE6
C5D5DBB6C6CEA5B8C6A1B9CCD0E2F1C3D6E19FBBD6356498285B97739CCC395E92385F8C
B0CDE3D1E0EBD1DEE6D0DFE9B0C3E219346D575D907333528F12259E0B1D9704188E0B1E
792032C9AEBAD0D8DFCDDAE2CAD9E1B6C7DC25386744396C6E1D3F88061C960215970415
8A0314731926A68C93C9D0D4BCC9D46F7D951B295240386368244080071790010D93000B
92010B8A050F7F252D9A7F837D82857B888C78858B77868D74878B7084877285896F8185
6E80846E81877084886D81826E82826D80836C80826D81837282867184866F84846E8685
7083856B7D806476785E72725C7070586D6B5D706E606B69433A2C00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008E65405D46430C051219121F5A4B4E
50404124131B664B566B4B516B4C526D4E556C4A536E4B54734E57734F5877525C7B555F
8057628257648457658457628B60688E646C90666F92676E91676C946B6F956C70996F72
9F77799D787A947472967C7899837F9B888499878396868091827C8F837D8A8078857B75
887D788B817D8A807E847B7A85807E8D8A898C8C8C88898B838589878B908A8F93858D90
90999BA7B1B29CA6A9A6B0B6B0BAC0B3BBC2BCC2C6CFD5DAD7DFE4CDD7DDC2CED79CAEB7
C2D3DAC6D6DCBDCAD4C0D4E7AFCDEAABCBE883A0C418447B24548F98C0E48EABC2BFD7E8
CEDFE8D3E0E8D2DFE7D1DEE8CFE0F44C69951F37717F648B841E3595071A9D071A9B0B1D
7F0A1D905764D9D4DCCFD9E1CCD8E0CEDBEA66779E19205B62315E7D0925930418950113
9002127B08178D5562949198919EA67C8A9B3C4D6F131A466B4464710A1D8C030E910009
93000A8F030C790C1598696D8885867F8A8D7E898E78868C74858975888775888C738689
7385896F82876E82866F83847183856D81836C7F837082867181877284896D83836E8685
72868670828466787C6376775F72725B706D687B7B6170704A463A00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009A6F46533E390A030F2A202A604D4E
453436322027664A4F6E4E516B4C516C4D546D4B526F4C53734F5777555D74525A78555E
7D58617F58627E5660835A63885E668D636B90666F9268718E656C90676D976F72997174
A1797C9C787A937272997D7B9E88859A86849E8B899583809587819086808B827C8A807B
897F7A867E7887807B87807D837F7C8A8787918F918A8B8C898B8D878B8F8F94998F9398
9AA2A5A5B0B298A4A5A5AFB3B6C1C6D3DDE0C4CDD0C5CBD1C0C8D0BEC6CEC4CED5BAC9D0
CEE2E8CFE3EACBDBE69BB2CC28518347739FA8C5E283A5C79AC6EE9CC8EF89ADC7C6DDE7
D0DDE5D4E1E8D3DFE8D3DFE8D0DFEC9AB3D213336D5E61917B334F9612269C06189C0918
8D0717701625C9ADB7D3D7DECCD6E0CBD8E5B0BEDA1F31674F3F7570193A8D071D950112
9501118C06167A23318C777EBFC9CFC0D0D96E809912214C55456C68172E88041393010B
94010B92020B860611883E4295848381898A7D888D79868B7A898C788A8C74868A718586
7386897184886F82866F82857382857486856D80826F82866C7E857386896E83836E8382
708484708283677B7B6477766679775F74726B807E6A7C7D4F514A0FCA0700FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00719032412D2807010C3D3035644D4B
3B2729422B2F6B4C4D6E4C4D6B4B4F6C4C516E4E546F4D5474535B74555C74555C78575E
7A535B805A627A556076515B845A658A5F688E636D9066708E646C8C6269926A6C987173
9772749C787B916F729C7F8098807F9D88869B88869483809A8C86958B839189828C827D
8B827C837D7687837D868481817E7F8683838C89898A898A878A8D858C90A5ABB0909399
8F979B8A96999EACACA7B3B3B5BFC3D3DEE3BCC5CAC3C8D0BABFC9D1D9DFD4DCE1BECBD4
AFC7D89CB8CEB5CBDEA6BAD05271978EB3D9C5E5FD89A9C93F6FA30F44883D6D9AC7E2F2
D0DFE9D2E0E8D2DEE7D3E0E8D1DEE7CADDF03A5B892B41788F698B85162C9C0D209C0A19
990B19850E1E9D5E6CDDD3DCCED5DECAD7E1CAD9ED5B709A232963703C65800A23940214
9A03119404137B0A1A90606AB4B4BDC2D1DB899AAE35496E2225536D39567F081B92010F
97010C97010D8F040F7A161C9D797C8485877E888C78868976858875888A7386886B7E7F
6F82847184877082866E81856D80837284846F82827082866F82887085886E83846E8282
7386866E8381687F7C607674657A786279776A827F687D7D575E581D960E00FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004FBA2937251C08030A493B3E604B48
301C1E533C406848486C4A4A6B4B4E6E4E536A494F6E4D5471525972525B73515C78545C
7A525A7C555F6D4A566C4A567B5561875D688C616B8F646E8E626A8E626891676B926A6D
946F719C797B9373759C7F809B83829F8A889784839A8B889A8D89948B85948C878D8380
918784857F7A87827F87848285828282807D8888868B8D917F87916975808B959B92989B
929A9D98A4A6D3E0E1C0CBCFA5AEB6A3ACB3B3BDC2BBC4C9B3BBC1D5DFE4D5E0E5C6D5DE
738A9F4E6C85AEC5D8CADBE7B1C7DD84A7D35D89BE719BC92C588F0B3D7C4C79A2C9E3F3
D0DFE9D4E0E8D2DEE6D4DFE8D2DDE6D1E0EB85A0BF133066746C95792942910E209A0C1B
9B0A1B960E20832237D3B3C0D3D5DFC9D7E0C9D8E79FB4D016295F5846777115348F0519
97011095010F8705138536428F7D87848E998294A15C708C0F1E4D6751766E11288E0515
96020E96010D94030F7E091193585D8B84867E898C79898B75868776898B7588896C7E7F
7382857282847385886F83856B7F816C80806D807F6F82836E81846F84876F8486708584
7085836C8280667E7B647A77607674607977728C89778C8B5F6A641F9B1400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C12E3520150E070C5142415E4A45
2716175B4648664B496749486A4B4E69494E6B4C516D4E53704F5875505C785260764F5B
7A535C77515C6F4F5B72525F7A5460855B658A5D6792636C9161698F5F66906368946A6C
9A72739B7878907271947B7A9C888695828094827F978884998D8898918A98918B918583
9186838A84808C87858C8786878281868381828384878F98516072687887828E94A4ADAF
9BA3A78C969BB0BBC29EA9B1A3ADB3A8B2B5D2DCDED6DEE2C0C8CFAAB8BFB6C6CBC5D5DA
B5C6D0B6CBDBC9E1F2C8E0F59EB8D61C457D0A3C84628FBF94B6D87D9FBCB6D5E5CFE4EB
D4E0E8D4DFE7D4DFE8D3DFE7D3DEE5D1DEE7C5D6EB2D4A784655877A4F6F8111278F0515
990819960818830B1F9C606FDBD4DCCCD6DFC7D7E3C4D5E84D648E252A61703A5F810921
90011093010B8D030F77101C936B75A1A6AEBFD1D99BAEC12A3E653A38636C2B4884081D
92011193010F93010D87060F7F2D349B83887F858A78898A778A8975898A738686738585
75858876878778878A7083867084866F83827183846E82826C7F836F83867285876D8381
6E84826E8382677F7C647B785F77736078756F88857A908E63716C346E2400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0061C83340271A190D0F5946435F4944
2616165D4D4D644D4F62484C67484F6A4B516C4D526D4D55714E57754E5A78505F784F5D
7A515D7D55626F4A566F4B568058618659638D5E6791636B8F5F698B5B648F646A956C6E
9A74759E7B7B937574997F7F97817E93807B93837C94858090857F99958C9A958D938785
8A807D8B8480918B8A958D8F8D8587807D7E7F81886B7A8C394F647B8A988D969DC8D0D3
B1B8BD8E969C8A939BAFBAC0C1CBCEABB5B7C7D2D6CAD5DBB6C1C8AAB9C1C2D4DBD0E0E6
C5D4DEA9C0D46E91B54673A38BB1D65E81AA4B72A59FC9EEB8D7F19EB7C4CFE2E8D2E1E6
D5E1E8D2DFE7D2DFE7D1E0E7D1DFE5CFDDE5D0DEEC748DAF132F67625886711A38890618
960515980717910B1A761B2BD2B5BFD1D5DDC7D5E0C7D7E59DB1D11225595945736C122E
8B051692010E90010F7E051383434E948D94BAC9D1A6B7C45A6C8C131C486B476A760D24
8F031492011091010D89040D720D179F727883848979878976898A778B8D75898B728688
75888A7286857384876E80837285867084837084857186876E81856F81847082846D8180
7084846F84846A7F80667D7D6076756279776E85847A8E9067767447413500FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0031E3174D2E1A251512604A43604640
3925234C3A3D5B464F3B242F5E444C694A516B4C536C4D5370505874515B744F5B744C59
784F5B8258638156617E545E7F545C8659618C5E6792636E91626D8C60698F666C977174
9A75779F7C7E9B7C7D987D7D947A798F7A768E7C769A8B849B92899B988F99938F948B89
89807D8B84818985828A8484878283828084788390324761667A8F89959E929A9E9AA2A5
989EA391979C8E979BD0DBDFD6DFE4ABB5BBA5B3B8B1C0C4C8D6DAC0CFD6BBCED9C8DDEB
BDD1E1A5BDD54266911F508597C1E2B5D3EC81A3CC4875AF3A659A95B5CFCDE0EAD2E0E7
D2DFE7D2E0E7D2DFE7D1DFE6D2E0E7D1DDE5D3DFEABDD2E82340732F3B71713D5D841025
920415940311960714871020A56A77D9D2DACAD6DFC6D6E38DA0B9364B762C2D5D6C3150
80091B90021091010D880410731A2497778080868D8D9BA58090A61A2B53504770681B33
88061790000E91010D8C020D79051188464E8B83857D8A8A78888C788B90788B8F738789
75898A7587877385877386887082857184866C7F826D80826F83847083857384866E7F7F
6D7F81697D7F687C7E6A7D7E66797A6176756C80837B8D926D7A7C53504600FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00563316331D18624A3F63483D
5C423D462F332B18233D283260484D674B4E6D4F536E4F556C4E536E4F5671505974535A
7E5F66A2848A83606B825864805360845964895F688F656E9267718B616A8E656D936E75
9672779D797E9D7B7E9576779073728F7773907D769588809D938A99928B9C9693918A88
88807E8F8A868884808C88848884857E838A51637D1E385698AABA959EA4929A9F919B9E
B3BABDCED2D699A0A6A8B2B9B9C3CAA6AFB6A6B1B8BFCDD1D2E0E4C6D6DF92A9BB4B6B83
A5C2D3BFD7E49DB7CD90B6D8ABD5F99FC6EA476DA10938870737807A9FC1CDE2EDD2E0E7
D2DFE7CFDEE5D3DFE8D2DDE6D2DDE6D1DDE4CFDCE3CCDFEC6881A510295E725F876C132C
880619920311990714930A1A7E2032D8B8C4D2D3DDD0D7E7717891979CBF312B557F4E6C
7B0E238F021193010D8D020D7707138E5961858185C6D2D6BDCDDC455A7D2229586D3B5A
7E0B208E010F91010B8E010B82030F721B2393787C7F868778898B788B8E788A8D76898B
75878A78878978898D74878974868A728286718386728486718483708385748386708181
6E8081687F7D687D7C6B7D7E6B7C7C65787A6A7E817B8E92738184585A530FCA0700FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00643B1841251A664B3D684C3D
6A4D444E373638252A5D494E5E464A694D526C4D526E50556D4F546D4C526F4E566B5258
A99A9ECBBFC4A089947B5365835566875B69845B668C636B9168708E656E8D656D97717A
98747B9D787F9572768C6B6C8D6E6E8C726E927F799887829E918B958B869B9390938B8B
8D86838883808C86838F8885868284767D8E182F51435A7782909B8991958F969B99A2A7
B8C2C5D1DAE09DA6AE87919AB6C1C7D3DCE2C5CED7A2AEB9B8C7D2A3B3BD9AAFBE7794A8
BFDDEAC9E2EDBFD7E75F83A921508E1C4D88769DCA294F854970A0B4D1E8D0E1EAD0E0E7
D1DFE6D0DFE6D2DEE6D2DCE5D1DDE4D0DDE4CEDDE3CCDDE6B3C7DE193362373D6F62304F
76081C8E0414960412940312850A1EA35266B37F97A475938655788D547889486B963F59
880D2191021194020D91020E810715925058ADA1A8A3AFB7AEBFCC6A8099172753685378
6C0F2889041390010C90010A8B020D74070F8F595E8883847D8A8C798B8D798B8D798B8D
76868B73838975848B76878C7584887281837283857587887284866F83856F82846E8282
6C807F69817E6C807F697C7B687B7C677B7C6D8285788C8D78898C5B635F219B1400FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075461C4B2A1E6C50416C4F3E
6B4D425C413F45333A362832463339664C517051566B4B506D4D53704E55714F58675059
B4ACB2C6C1C8A18E9C81596D865569875768865B688F64718D626E8A616B8C676E936E75
9872799C747B8F696F8B696B8F706F8F75738F7C799988879A8C8A938783968C898E8583
89837F86817C8D89858F8B8888898F505D7A132B516C7F96869096A3ABAED0D8DD9FA8AF
9DA5ACA2ABB2ADB7BF9DA7B0AFBCC4D3DFE7B8C3CF8897A47C8D99C8D8E0CBDAE2A1B6C6
A4C4E197BCDD92B5D64C709C0A377A21528BB4D8F788A9C87195B2C9E1EFD2DFE8D3E1E7
D1DFE7D0DEE4D4DFE7D4DFE8D2DDE4D1DEE5CEDDE4CDDCE4CCDDEC677F9F1228595D527A
631933820A1D9309189204148E0617870C2280112D80123282113384113089122D880B1E
8C07178D08128F09138908117E0D19753540998D967B858F818F9B8D9EAF33476B3B3C65
6B2A4781061990011092010D8E010C8305107E2E36978384808A8B778A8C77898B7D8F90
7A8D8F76898E79888F7A888E788689758486748387708284697C7D6E82836D82826D8283
6E82826F82816A7B7B687D7B6A7F8064787B697E81778B8C74878A5F6B69209D1800FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00299101522E1F6E51456C4D3F
6D4C41684A491F101827212E4F424B634C4F6B4D506B4B506A49506E4C546F4E56684F58
A2939EC3B4C285697C82566A855565885867895B6B8B60718B606E8B626B8A646B926E73
956E749A7178946C728F6C6D927573917977917E7F928283968A89998F8C968C88908681
8C857E88857D8988839090907A8396172E56324B6F8594A38A929899A1A8B1BAC39BA3AD
99A0A8B6C0C5D4DFE5C8D5E082909C9AA9B399A7B09CAAB38E9FA9CDE0E9CEDFEA8EA4BF
274E800E3F795A87B4B1D1F05B7FA889B4E393BBE75E88B64F7897CBE3F0D3E0E9D3E0E6
D4E0E8D4DFE5D3DFE8D0DFE6D2DEE5D0DDE4D0DEE5D0DEE5CDDBE5C4D5E5556B8C2C3B61
5A44626520337718247E161F8018207B1720801F2C7C1F2D7C2130802A3981303B873539
83323883383C81383B7D383A783D44856A71A7A8AE87919A9FACB5C5D3E07E90AD16234E
704A6E770B228D021491000D8F010B89030E740F17956D7183868878898C78888B7E8F8F
70828478898E78899077888D78898B77888B74858A7285876D81816E82826E83836C8183
6D7F83728184707F7F6D807F6B7F7F697D7D6B80816E84856F83845F6D6C453C3100FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00369D08532E1C6E5142684B3A
6C4B3F6B4C482E1B21180F1B261B24654E526B4C4E69494C67464C6A49526E4B546E4A57
7353617C5C6E7D5769805665865863885866895D6D865F7085626E855F67845E66946F76
9A7578956D718D6568906D6D917371977D7D9C87899585869B8D8C9C918F9A908B938984
9189828C87828D8B89959AA34A5D7F092957627C98C3CFD69BA1A58C939A8D959DB6BFC6
ACB5BDA0AAB3C4CFD9A4B0BC77879292A1AACFDDE4D2E0E6A3B4C0869FB38CA7BB94ADC3
47688D3F659198BCE1C6E4FE9BBBDC2C5892083C881D55919EC6E4CBE1ECD2E2E9D1DFE6
D5E2EAD3DFE6D1E0E7D1E0E7D2DEE6D1DEE6D1DEE6D1DEE5D0DBE4CFDBE4C7D6E597ABBF
6C798C776E7A927579906C6E90696C9874759C7D7EA1888AA9939B6D6273827B8A9E969A
9B9094928C918C898EACA7A99B9A9F929EA7C4D5DEB9C9D48A99A5B0C0CD899BB421345C
4E40686A193588051990010D90000A8C020C7C051086474C8C85847A89897B8A8F7B8B8E
7A8B8D7D8D917B8D92788A8F7A8B8F76888B72858974888A7185877488897286876D8284
7284866F80837081836A7E7E6D82816B807E667C7A6D82827386876470704B453D00FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A8105129146D513D6B4F3B
6C4A3E6B494260464643323B3A2C35654F53684A4B66464A66464C68454E6C46536D4551
71495579505E7C505E7E535E8256628459677D59686E536264505C6F58627F6067946F74
9A72769A7276936B6D957071917070957A79937F7F8473749788869A8D8A978C88978D8A
9289878F8887918F92858FA4102D5D193B6A7990A49CA6AB8C9295898E939DA5ABD4DDE5
C7D2DC87939F8C98A3ACB8C1BBC8CF9DAEB6C2D3DCC0CFDA9AABBC46647C7290A8CCE3F2
B3C8DD87A1C1799BCA537BB2709ACA204D8A073986376CA2BEE0F6CEE1EAD1DFE8D1E0E7
D1DFE7D2E0E8D1E0E7D0DFE6D2DEE7D2DFE7D0DDE5D0DDE3D4DDE5CFDBE2CCDBE3C6DBE0
C6DCE1C7D7DBCBD4D6CBD0D1CCD0D1CBD2D4CDD5D7CCD8D9BFCBD66B8299617E997992A6
9FB1BD6F8397617990C0D4DFBACDD78194A3A5BACAA3B7C57B8A977787938EA0AF586C8A
2227536933558008208F021092010D90010B890510772025967C7D80898A7E8E91798B8F
7B8E907B8E8F778A8B798B8D778A8E76898C74868A71848872858976898A728587738688
7486867185846F83836A81806D83826F85856D828270848576878B69757654504900FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B51951280B6B4E3A6C4D3C
6C493C6C48416347472C1B252E1F2C5F484D6A4C4D67474B67454C67444D6B45526C424F
7349547C4F5C80525E825662815763765160614453634E5C5B4C5A50434F6C57608A6A72
977078926770946A6F926B6F917274947A799985838C7C7A988A87988E8999918C958E8A
97918E9893938F919D4C5D840A2B673E5C8795A4B399A1A5B4BDBDBEC5C98C949DA2AEB7
8E9BA48A969F8B98A0CEDCE3D1DFE5A0B0BA8294A29FAEBAC2CFDC98ACC09DB9D2BEDAF4
A2BCDA7595BC15407E083D886495C892B8E0537DB279A8D2C2E1F3CDE0E9D2E1E9D1E0E7
CFE1E6D1E0E6D2DFE7CFDDE3D1DEE6D1DFE7CFDDE5D0DEE4D1DDE6CCDAE3CBDBE3C8DAE0
C7DAE0CBDBDFCFDAE0CED9DDCBD8DCC7D7DCC7DADFC7D8DEBFD0DC728AA523447234557F
B8D3EA6A839C344C6BA0B7C8B3C6D48395A47082929DAFBAA5B2BB818F98C2D2DCA9BBD1
19275361436B770F2A91051795010E92010A8D020E770A1296646A8787898090917D8F91
7B8E907A8D8D7A8B8B738685788C8C7B8E916F818477898C73858875868876888B76888A
7183857085856C81816A807E6E828371868973888A718586788A8E6C797B5B5B561F950F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005B2F056848346C4D3D
704D3F6B473E55383919050F39262F61464C6B4A4C6C484C6A464D6A434C683F4C704652
754C57784D5A7F525F7F55617C58656043516C5260785F6B75616C594E59544653826874
916B768F646E936A73906D758A6F758C767A968483988986938883938B85948D88958F8C
98938F9B999A858FA6142C640629666B86A69AA5B09FA6A9C8D0D3C3CCD2919AA4808B95
BCC8CECED9DF98A3ACA6B5BFABB9C3909EA9758690C0D0D9D3DFEABDCBE06A87AF2A5588
618DB69FC7E94972A02D5D9497C6EEA1CAEE5D87B4306089C1DFF1CDDFE7D1E0E7D1E0E7
D2E1E7D2E1E7D3E0E8D1DCE5D5DEE8D1DFE6CFDEE5CDDDE5CCDDE7CBDCE6CDDCE5CBD9E0
CEDAE3CED9E1CDD7DFCDD7DFCCD7E0CAD7E0CBD9E3CCD6E2C9D1E2939FBE182B6113275C
97A6C5B8C2D79699B2898CA09DA2B3B7BBCB8E91A3CACADAD3D1E1A1A0B1A9A6B8ADABC3
4C4B7150375C791F3A8E051997010F95010D91010D860612883A459785898890937E8D8F
7F8D938190928392937C908E7A8D8D7F91936D8083798C8E728485768A8A758989768989
7285866F84866C82836B82826B818273878A6D808473868876888B6D7D7F5A615C219B15
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B3B0C67472E6E503D
6F4F3E6C483D5A3A354327286245456847476B49496A47496A454B6D444D6C424D69414C
754D58794F5B7C525F79505C70515C5A44507359667E626E7B66716155614D4351796471
8B69738E677086616C7B5D67775F69806B748E7C7E988887968A879A908B988F8A928B86
95918C9A9DA257698B062665193B6F90A7BABFCACEA2A7ABA9AFB4959FA5A1ABB287939B
C8D5DCD3DFE79DABB68495A1A5B5BED1DDE4BDC9D38E9FAEA8BBD09AAEC65977A10D3A74
5E8CB6C2E8FFB1D1EB6D95C24274B1356CA86091C05D88A8CAE3EFD0E0E6D3E1E8D4E0E8
D4E0E8D2DFE7D3E0E8D2DEE6D2DDE7CFDEE4D1DFE5CCDEE9C3DAEEC3DBEFCDDAE9D2D8E5
D4D3E2D8D2E3D4C8DDD2C3DAC8B5D0C6AFCBC2A7C4BE9DB9BD95B6AE83A96F447170436E
8957798953708E506F8A4A68915370955976874869904E6E9A57788C4869874262884563
8543628C415F92223C91021698021194010C93010E8F04107F121FA76E75977F8790858D
8D868F87888D828A8C7C8C8B7D8E907D8F9274878B778C8D798D8D798E8D788D8E738988
73888972898B6D8685677F7F6B8282748A8C5C6E727284877B8D907082845C6865336C23
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00834D166844266C4D38
6C4D3B6C4C3D6B483C67443C6946416C4A446B4B4767474768454969434B6B444E6C454F
764E597B515D7C525E79545E614651604C58755D6A7A616E72626C5E576147414D75626E
8B6A748A656E7E5C659070798C72797D676E927D80968383958685998E8B9C928E8E8782
8F8B898C93A2223A6C0326693958839CADB9B3BCBEA9AFB3A1A7ABB7C0C4D4DDE2ABB8BF
8A98A2A0ADB4AAB9C196A5B0AFBDC8D1DDE7BDCBD87990A843617EB5CFE7B9D2EC6C8EB4
9AC4EB9EC7EA96BCE0406B9F073E920C489495C3E9BCDAEBCFE0E8D3E1E8D5E1E9D6E0E9
D6DFE8D4DFE7D3DEE5D1DEE5D2E0E6D1DFE4D2DFE7BED3E24667905D7DAC979BBE8E6D8D
955B7D934E6F883B5E8631547A22447E21447E1C41811A3E84173D7E0E347F0B2E810B29
8109258509268808268807248808258807278C0A2A8C09288D08298D09278B0724890721
8B08218B071D93041998021496011092010B93010E91020C8D0614841523822637853548
843E51854D5B87666F8A888A7E8C8E798C8E76898D768B8C798B8D7A8E91788C8F758A8C
74898B73888A6E84846F83836F838375898A65787A697D7F7D9193708486637071474035
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DA1086A4221704F3B
714F406C4B3C6C493B6A463B67433B6846406748446748486846496A454B6A464E6B4851
734D5779505B7B515B7A565F58414C584A556A5A656B5C66665F6854535C47424C79666F
88656D89626A83626891737890767A7E686C957E83937E82958585968C899B938E948D88
979799667391032162163A7D6883A7A2ADB7A3A9ACB7BBBFA2A8AEB7C0C7CCD6DCA4AFB7
8D98A1B1BCC2D5E1E7C5D2DC94A2AF93A4B099ABB58EA6B754748AC2DBEECCE0F295B4D7
2857940E45894275AF83AEDB2251923A70B1A1CEF3C9E2F3D1E1E9D2E1E8D2E0E8D4E0E9
D3DFE7D5E1E7D4DFE5D2DFE5D1DFE5D1DDE3D1DFE7CADEEF4869951035747170A367244B
871538971836930E2B971029950F258F0C208F0A208C0A1F8C0B1F8E0D218D0B1F8B091A
8F0C1D900D1C8C08198D0B1B8A081A89091B8809198709188A08188C0B188A09178A0916
8C09168E0B178F08178F08168D06148B06118C05118C05108A030F8A04128C05178A061A
86071A7F0B1E6B142296777B858C8E7B8E927B8E92788C8D788B8C72868875898C73878B
768A8E768A8B7084857084837385857589897286876C8183758D8E798F906C7C7D4C4A41
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047A90C72441F724D3A
7551446E4C3D6A49396C483B69443B67453F69484666474667474A6A474D69474D6C4A51
714D5676505A79505A78546057414D4D44505A54605C57625858624A4B56524853836771
8C656D8861698261688C7074816A6D867076947B83957F859786889A8D8B9A918C97918D
8B8F98293D6A03236D1232708DA0BCA8ADB4B2B5B8D6DBE0BEC5CE9AA3AE909BA4B8C3CA
B6C0C8A5B2BBC7D4DEB2C0CB8A9BA97C8F9BCADDE4CFE2EA9DB3C394AEC698B3CD85A5CB
184687073E8B376CAABDE3FF97BAE64C7CB92A5B93B1D3EDCFE2ECD4E2EAD2E1E8D2E1E8
D3E2E8D2E1E6D2E0E6D2E0E6D1DEE4D1DEE6D0DFE8CEDEEB9BB4D4153A7455649A6C3E5C
7E1A2E8C19268C18238E1E26861D2781202880232F7A232D81303881333B883C438C4348
8A434889464F8B485386434A89474E84464D86494F85464C84454987484B834247844147
864145864043873E42843B4181363C7C30367C2932792429741B1E75171B7710167B0F15
820E17800C176E0C1883565B8B8C8F788A8C7D90937B8E8F748789758A8B73878A778A8E
75888C73868970848672868770848474888872878973898C71888C768E91758989585C55
0ECA0700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B211724219724C39
744F42714F406A49396E4A3E69463B63423A67474566484863464863464967484B6B4A51
6E4A53714D54764F5A734F5E634958463C4B4A48564F4D5B51505C4C48546B5865896572
8B616B8C636B7F5B62795B608266698D7578937D81947F83978587968888988E8D999596
767F960B225E02206C2B4477A5B0C4B3B5BAABADB2BEC2CAA4ABB59DA5AF9FABB4D2DDE5
D1DDE58D9DA890A0AAB4C1C9B3C1CB8D9DAABDD0DCC5D7E47E94AB35587F4C749BC3E2FE
86A6CF4972A8699AD277A5D78DB7E71545841A4C8EB3D4F3CEE1ECD3E0E9D4E1E9D3E1E8
D2DEE4D4E0E8D2E0E7D1E0E7D2DFE5D0E0E6CEDFE7CEDFE7C9DCF143658E28497879768E
7C545F936064986869986E709874779F8286A68F92A79496B8A6AAA89A9EADA4ABA6A5AB
B2B2BB7E849A6E7791ADB2BCAAAAAE83858985878C888689888789828183ACACAEA6A4A6
8D888AB3AEAEA89FA1928A8C8E85878F8587998B8D928180957E7E9277748D6B698E6462
8C5A5B814B4E6F3E42745D5C848B8A798C8C7A8D8F7B8F90788B8F768C8D6A7F8174888A
788B9074888B6C8086697D816E818372878772878974898B73878C73898E788E915D6562
1F981400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774618704B36
724F426E4C3F6C4A3D6C483B6F4C3F68473D6545426648476246476146486446496A4950
704D55754E57764D5A77505E7353614E3C4A48404D4B44515C535F675A65856D788E6976
8F68738F676F8E696D8E6B6D947575937777957E7F958183908080958A889A94928F8F9A
46537A051E67031F6B50648FC1CBD8C7CBD0A6AAAF9FA3A9C4CAD0C5CED494A0A9B0BDC8
9FABB692A0AB92A1AAD0DDE3D5E1EAA3B4C27D94A493AABBAFC5DA46678B4F779CC1E2FA
A9C6DF7FA2CC1C4C900B4494598FCB517DAC426792C4DEF2CFE1EAD3E1E8D4E1E8D4E1E7
D3DEE3D4DFE7D5E0E9D2DFE7D3E0E6CFDFE2D0E0E6CFE0E7CBDCE9A9C4D87E9DB69CADBA
B0B6BCBEC0C1BEC2C3C4CACCC6CFD2C7D3D6C9D6D8CAD7D9CDD8DECDD8E18598B0527396
B1D0EF3455821236688BA9C2B4C7D28D9FA781949A9FB0B3B5C5C88D9FA5BFD0D9BFD1D7
8999A2A2B2B89FADB3919DA297A4A78E9B9D909EA28896978E969A8C97978891908D9392
909294888B8C8285877D84827C8B8B788C8D7A8D90798D8F7A8E92758D8E73878C74888C
768B8F72878A6E8286677B7E697D7F6E828274898A768B8D73878C728A8D758A8D5F696A
31682100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C4A16745035
7151406F50406B493E6C493E6D4B4068463E64433E64454262444464474A66454B6A4750
6C4750714854764B597C53607E586571535E5C45506A576179646E8870798F707893707B
8F6A758E69718E6A6D9674749876799173748F7776998683988A86978F8A9A97978E93A7
1629600220720B2E726B83A1919CA3A6AEB1AAB1B4A9AEB3D3DBDFD1DAE09BA5AF8A95A0
B1BDC5CCDAE1A7B5C0B0C0CBB4C4D19FB3C15772859DB8C8CCE0EEBED5EB6D8FB4608AB4
8BB6DD76A2CD114288064095528BC6AED5EEB2CCDFD0E3EDD3E2E9D3E0E6D4E2E8D4E1E7
D4E0E5D3DFE5D3DFE8D3E0E8D2E1E7D2E1E5D3DFE5D3E1E6CCDAE3CADEE5CCDFE7CADDE1
CDDCE0CDDCE0CCDADFCDDCE2CBDBE1CCDCE1CBDBE1CCDDE2CDDCE4CDDDEA89A2C50E3874
7198C97697BF4C6D95819FB9A0B7C6B6CCD68DA6B0B3C8D0C5D7E09EB1BD9AACB9ADBEC9
97A6B199AAB4A6B5BDA6B5BB9FADB4B6C6CC92A2A991A0A78B99A18C9EA28A9B9F8FA0A3
87969C80909885959C8090927C8D9074898C788D90798D9175888C778C8F74878D758A8D
71898B728989718689667B7C6A7E806C808173878B768A8D71858B72888D7A8D93677375
443D3400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00825117745030
72533E7051406D4C406D4B416B4A416B4A4166453E67464266474667484C65444C6B4853
69444F724755794D5D7F536480556480596682616A886A718F707790707894707B98727F
936D79936E768F6B7198767A98767C97787C987F7F978582998D889B928E9C979C727B99
061D6104267A1F44818399B1929B9FB8BFC1D2D9DDABAEB6A7ABB5A1AAB3AAB3BC8E98A0
C8D6DBD3E0E9AEBCCA94A6B4AFBFCACCDDE6A8BCCC87A0B3ADC6D796AFC5426693083B7E
4579AFB4E2FF83ACD84C7BBB4578B77FAFD9BAD9EED1E3ECD4E1E9D3E0E7D3E2E8D6E3E9
D2DFE5D4E1E7D3E0E8D4E2E9D2E0E7D2E1E8D4E1E7D3E0E5D2E0E7CFDEE5D0DFE6CCDDE3
CDDDE4CCDEE2CFDEE6CCDDE4CFDDE6CDDDE3D1E0E7D0DFE6CEDDE5CCDDEAAEC6E2315687
779EC99BBAD2B4D1E881A6C3A7C8DFC1DEEC748FA294AABABACAD89AA8B698A5B1ABB6C0
B5C2CBAEBBC6C4D2DCC2D1DA9BACB5A5B8BF92A5AC93A4AB97A7AF95A6AD8E9FA78C9DA4
85959E80919984959C899B9E84979B7B8F93758A8E778C8F77898F778A8E70828972858A
71878A718788708487697D7F697C8162757A6C80856C808472868A71858A788B906F7E80
48463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C5A1A74502C
71533C7053426E4E3F6E4C416E4D436E4F466A4A456848466A4A4C68494E694950694952
6A4651734A58794E5F7B4F627E51648459678A636B8F6C728F6D74926F78926F7B967380
99768198747C96737A9B797F9A787E9B7C819981839D8C8BA093919B91919996A0394671
031C6C01207727447B9AA7BB9EA1A7B5BBC0D0D7DDA7A9B19FA1AABBC2C9D3DCE3B2BDC4
9DADB49DADB6A6B4BF8F9FACAEBEC9D3E1EBB8C8D9728BA6597A9AACCCE67593B91A447C
5E8BBBB7DDFAADCCED648BC30131841E5BA49DC9EBCBE2F0D3E2EBD4E1E9D5E3EAD5E2EA
D4E1E8D3E1E8D7E4EAD5E2E8D5E3E9D4E1E9D5E3EBD2E1E8D1E1E8CFDFE6CFDFE7CEDFE7
CFE0E8D0E0E9D1DFE8CEDFE8D0DEE7D1E0E7D3E2E9D1E0E7CDDEE6CDDDE8C2D8EC9BC1E9
70A0D1A1CCEE9EC5E42255866090B8B0D1E798B2C69FB2C1B1BECBC0CAD4AFB9C3BDC9D1
C7D5DDB3BECBB8C4D1B3C1CF99A9B6A1B3BDA3B5BD9EAFB696A8B293A4AD91A2AB93A2AB
8B9CA48C9EA48C9EA3889B9F7183896F8388788C92819498899AA17D909474878E6F8388
6A8083687E806A7D826A7D8166797E5063695B7177617A7E667E8170848971858A708183
51544C0FCA0700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A60A744E27
6D51386F55406E513E7050416F50457053496E514B6F524F6D50516A4C50694B506F4F56
6947506D4753744D5A79505F7E5364855B688D646F906B75926E78906B7794707C977580
98767E9B767F9C787F9E7F83A081859E8184A0888B9E8D8E9C8F909D94988C90A5162863
011C7502207348608ECBD4E1AFB2B79DA1A6A7ADB2B6BAC0A3A8AFBAC3CBD1DDE6A8B5BE
9AA9B1A6B8BFD1E1E8C8D8E37D909E92A4B296A6B86882A1183E659ABBD8C9E1F897B5DA
6E99CB6090C493C1EF5B89BE0A3E8E1856A197C5E9CCE4F2D2E1EAD5E3EBD5E2EAD7E4EC
D7E3EBD6E4EAD7E4EAD6E5EAD6E5ECD5E2E9D6E3ECD6E4EBD4E2EAD2E0E8D5E2EBD1E1E9
D1DFE9D2DFE9D2E0E9D2DFE8D5E1EAD3E0E8D2E0E8D2E0E8D0DDE9CFDDE9C7DEF35D8AC0
0E4C9E437EBC9DCAED4877A375A1C5A1C2D6B4CBD9A9BBC8B7C8D1CBDAE0BFCCD5B7C7D0
CAD8E4BEC9D6B8C3D0ADB9C6A1AFBB96A8B2BACBD4A3B4BD9CACB897A7B195A4AF94A2AB
93A3AB8E9EA48E9EA286989E879AA17B8E9476898F788C91788C91768D906A8085637A7E
6A8084687E80697D836B7F826A7D8153686E556B735D7679657C7F6A7F836E86896C8082
5E605D1F961100FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A90B744C24
6E4F366E533D6D523E6C503F7053447255496D514A7155536F5454694F516B4F536E4E54
69464E714C5578515B7A515D805664865C6A8C63708D6876906C7A8F6A77936E7A97727D
97737C9C777F9E7A819F80839C7D809F8184A28A8EA28F919D90939C959E656E91061D69
011E7D01206D6D84A9B6C1CBA9AEB39FA6A9B1B6BAD6DCE2C9D1DA95A0AA8E9BA4B5C3CB
A9B9BF93A6AEC1D3DDB6C8D48296A690A5B5C9DBE9BFD2E76A85A4A2BEDEB1CAE399B8E0
164C930B50A32E71B4A8D5F76F9AC67FB5E4B3DFFCD0E6F3D8E6EED9E5EBD9E5EBDDE7EC
DCE6EBDEE8EDDDE7EFDCE9EEDAE7EEDBE8EED8E5EDD8E5EDD8E3EAD8E2EAD6E2EAD5E3EC
D5E1EAD6E3EBD5E2EAD3E1E8D6E2EAD7E2EBD6E2EBD2DEE7D0D9E8D1DDEACADEF5658EC5
134FA44683C2B5DEFABCDEF7BFE0FABADBEEC6DEECB4CBDAB7CCDBC1D4E0BCCCDAB2C3D0
B5C4D0C5D1DCC5D0DDCCD8E4BCCAD690A1ACA8BAC5A1B2BDA7B5C2A4B2BE9FAEB99AAAB2
99A7B1919FA797A4AD8B9AA380909971848A70828971858A7084896D8488687E83657A7E
6B7F82697E80667C80667E81687D804E666B4159605A727664797C677F806A8384697E7F
616867229D1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB01077491F
704E377054416E54416B513E7155457153476E514B7153546D5153694F506A50526D4E54
6C49516D495279525C7B535E825966865D6A8C65728D6874916C79906B79946F7A97737C
99777F9A7980A08085A18084A18185A4868CA0888DA190929E91969894A63A487B051D76
06268824468D798EAD97A0A6ABB3B4B3BABDAAB0B5C7CFD8ABB4C08B99A399A9B0D1E0E4
CDDDE376879390A1ABACBEC6AABCC7798E9BC7DAE7C6D5E899B0CF7899C789ACDAA7CAF4
3465A43773B95E98CCCEF1FFDBFCFF7CB4D786BBDCD0E7F6DEE8F0E0E8EDE4EAEEE7EEF0
EAEEF1E9F0F4E6EDF4E1EAF1DFEAF0DFEBF1DAE6EDDBE7EEDCE6EDDAE4ECD7E3EBD5E2EB
D7E3EBD6E3E9D5E2EAD2E1E9D5E2EBD4E2EAD4E0E8D1DFE7D1DEE8D1DEE8CDDEEDA9C9E8
79A9DD8FC4F4ABD4F1B9DAF45E86AF83ADCEB9D8EB9DB6C89EB4C8A6B9C9B1C1D0A2B2C0
C4D3E0C8D7E4ACBBCABCCBDCBCCFDEBBD0DDB5C8D3ADBEC7ABB7C3A0AEBB9DAEB8A4B5BF
A1AFBC9AA9B394A3AD90A0A98A9AA3798C92768A8F7284887083887084886D82866A7D81
6A7E7F6E8384697E82677F8362777B526B6E5B747A566F735F777A647D7C6279776B8082
64706E433B3000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A4917
704E336E513F6E53426C513E70524273524770524B6E504F6E50536E53546A50526C5156
6B4C566E4E5874515C77515D7E5561845B688B616F906974936D79956F7C936E7997757D
98787F9E8086A18388A5858BA4848AA5898EA0878FA08E939E929B9191AD182A6C031F80
0223841233758B9DB799A1A5CDD5D6D2D8DDA6ABB3969EA7B8C0CAC7D2DAA3B2BAB4C4CD
AEBFC883939D95A3ACCBD9E0D3E2E9B8C8D3A5B7C67F92A78EA6C7183E762D558CBBD7F8
C6E0F6C9EAFCBEEBFEA4DFF3AAE5F97FBEE197C9E8DAF0FBEAF0F8F7FAFCFBFCFFFCFEFF
FAFDFFECF2F7E8EFF6E2EBF4E0EAF2E0EAF1DEE8F0DAE6EDD8E4EBDAE4ECD7E3EBD6E4EC
D8E5EDD9E5EBD7E2ECD3E0EAD4E1EAD2E1E8D3E1E8D0DFE7D0DFE9CFDFE8CEDFEBC4DEF1
94C0EB326EB06BA3D6B0D9F647719A7DA5C7ADC9DCB2C7D6AFC1D1B7C9D7C9D9E8B5C7D5
B9CCDBBBCDDDA6B7C8A2B3C6A1B6C49DB6C2AEC5CEC0D1DAABBAC4B0BEC9A8B7C0A6B6BF
A4B3BE94A6B090A1AD8EA0A98C9EA47D9195798F936D82856F83866E8385708587708487
7387877286866C7E82697D8164797D566E706881825A7376637A7B617877667A7B657A7C
66757447473B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00814F18
704B2E6E523E6F54426F514273504476534872534A6D4F4D6E51537153556D52546B5154
694E566B4F5973545D73515A7C55618257678C61718C6471926D79926E7A96737E977580
9C7C86A1838AA2848BA08188A08088A3858D9D858B9E8B909D939E757CA108206D032288
0122812A4882A9BACD9EA5AAB7BCC1B4BAC0A2A8AEA0A8AECDD6DCD4DFE8A5B3BE8C9CA6
AEBEC5C7D4DCB0BCC3C5D2DACCD8E1C0CEDAB4CBE3A5C1DBC8DFF6849BBA93AAC8D5E7F3
EFFEFFE2FDFF88C1E34CA8D86BB9E1C2F0FFD4EFFDE7F5FCEEF4FBF5F9FCF7F9FCF3F6FA
EAEFF5E4EDF4E0EAF2DFE8F1DCE5EEDEE7EFDAE5EDD6E5ECD2E1E9D7E3EBD6E2EAD5E4EB
D5E2EAD5E2E9D6E2EBD4E0EAD1DFE8D2E2E9D1E1E9D1E1E9CCDBE6CFE0EBCEDFEBC7DDF3
6F9ACE1051A53777BBABD6F4AFD1E9AAC9DFB6CFE2C6DBEBBBCFE0A9BFCFC2D3E4A7B9CA
99AABEA1B3C4A0B3C29CAEBBBED1DDA8BCC69EB3BEB4C8D298AAB6A6B6C0A2B1B8A8B6BE
A2B0B998A9B37D8E998699A08EA0A67A8F95798E93768B8F708789708788748B8C768C8F
768B8C788A8B808F946F80866A7E82597072657D7D546C6C62777A61777763777963777A
6375744D52480ECA06
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00865317
6E482A6E503C70524173524774514874514973524C6D4F4D6D4E516D4D516C4E526C4E54
6B4D566A4D586E525D71515B7C55638458698D61708D6471946F7B93727C95767F987B83
997D859D81889F828AA2828BA08088A4858CA3888C9E898F9D95A64F5A89041F75001F87
0425834B689EC9D9EBA7AEB4A2A8ACBFC6C8D1D8DAB3BABFB2BBC3AEB8C2929DA896A2AB
CBD7DCDAE1E5CED5DCCCD6DDD0DDE5D3E2EEA6BED59BB6CBDCEBF5EDF6FBF0FFFFD0F2FF
AEDCF4B8EAFF92CDED7FC7E7ACDFF3EAFFFFE8F3F8E1ECF2E6EFF6E7EEF3E8EDF3E4E9EE
E6ECF1E1EAF0E2EAF2DFE8F0DFE8F1E1EAF1DBE7EED5E5ECD4E5EDD5E4EBD6E3EBD5E4EA
D7E4ECD6E4EBD7E2EBD5E2EBD2E0E9D2E2EAD0DFE8D0DFE8CFDDE8D2E1EBD3E2ECCDDEF0
9EBDE25887BF7EB0E4A2CCE9BFE0F88FB5D692B6D9BED8F09DB2C895ADBFA7BAC9AFBFCF
9DADBDC4D5E2C3D5E19DB1BDC6D7E4B3C4CF95A7B494A5B095A5B095A5AD94A3AB99A6AE
9BA6B094A2AC8696A07A8D94788A937D9199788B92768A9070858B71888C738B8D768F90
788C90788A8D7B8E9273868B6F83885A70745C7275506667677B7D667A7C64777B637678
607272565C551C950D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00657E0F
724B276E4C3873514075504475524875524B70514D6A4D4D684C4E6C4F506C4E526B4D51
694A52674954664B586D505C795764855D6A895F6B8F6670916C7594737B987A82967A84
987B859A7F889E838D9A7E86A2848AA28389A68A8E9F8C939B97AD28387205217F05258D
072A83516DA09DACBC9CA3A8A1A8ABC6CCCFD5DCE0C0C4CBAFB3BDB0B6BED1DAE0CED4DB
CBCFD5DADEE5D4DAE4D9E3E9E4EFF5D9E4EDD8E4F0EFFCFFF7FFFFF2FCFFC4E5F9559DD0
4495C994D1F1CFF4FFDDFBFFDBFAFFCAEBF8D1EAF9DAEBF2E1EBF1E8EEF4ECF1F4F4F6F9
F6F9FBF3F9FBEEF3FAE7EFF7E4EDF6E2EDF3DDE8F1D6E5EDD4E3EBD7E5EDD4E2EAD1E1E9
D4E2EBD4E2E9D4E1EAD5E2EBD3E1EAD1DFE8D1DFE8D0E0E8D1DFE9D2E0EAD4E1EACFDEEA
B4C9DDBCDAFB729DD16696C8B1D9FE35608B5178A3A2BCD6A6BACC9DB1C0B8CAD5CBDCE6
B9CAD6C2D3E0C3D4E39CAEBD9CAEBC9DACB995A6B19CADB69BA9B1909FA593A1A79CA9B1
99A4AD8E9CA4899AA2889BA1798D93667A8172868D788D93677E836E868A748B8C788E91
798E92768C9072888B748B8C72878963787D4D65695D7275667A7B647778647577637676
5D706E5D655E1C9610
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042A809
734A226F4B32734F3C74504275534673524874544F6C4F4E684D4C6C50506A4D50684C51
684C536245506147546549577B5967845F6B86606A8C676F916D7492717993737F9A7C88
9E808C977C87856E79836B76967B84A4868DA4888FA290989090A9112566021D80082A92
0B31885E79A7A2AEBAD0D5D8CACBCFB8B8BFB9BAC2B8BAC1BEC0C6CFD0D5E2E3E8E2E3E9
D4D6DDE1E5EED7DFE8DCE5EDEEF6FCE6ECF3ECF1F9F2FDFFCDE5F6BAD8F3B1DAF96FADD9
8CC6E7D1F7FFEAFFFFE3FCFF96CAE26FB7DAA6D9F2DAF0FBE8F3FAF4FAFEF8FCFFF9FCFF
F5F8FDE9F0F6E3EBF2E0E9F1DBE5EEDCE9F0DAE8EFD5E4EBD3E1EAD7E5ECD2E0E9CFE1EB
D0E1E9D1E1E8D2E0E9D2E0E9D3E0EAD1DEE7D1DFE8CEDDE6D0E0E8D2E1E9D3E1E9D1E0EB
B0C3D69FBCE316478E134B947CA6D28BACCC94AFCCA6BED2CCDEECC3D5E2B6C8D6C9DCE8
B2C4D299ABB99DAEBD96A7B496A7B3BACED5A2B5BEADC0C9BDCCD59FAEB493A0A68D9B9F
909FA48E9EA583979E83979D879AA06F838864797D6B83865F787A738C8E7B9093798E91
738A8D6F898C6D86876E8786708787708689677F816A8081677B7B637675627272647775
596E6B606D64336C20
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0046AA0B
754B1E6C4B2F6F4E3973524078574876564B7454516D4E4E694A4B68494B65484B65484E
684C545D434D644A566C4E5C7D5A6987617187626F8C67728C6A7291727993737E9A7A86
977A868B727E836D798E7985836B769D818CA286919F8D9A797B9E051C67011E8401228D
042A80748CB7AEB2BDD9D6D9D4D0D5BEB8C0C9C3CBDCDAE0DADBE0D5D5DAD9D9E0D8D9E1
E0E3ECE5EAF4D8E1EBDAE2ECE7EDF6EDF2FAEBF3FAD3E5F7749ABD8BB2D3D6EFFFE7FEFF
E3FFFFCFF5FFA8DAF4B7E8FE95D4ED80CDEBA7DBF2D6EDFADFECF4E0EAF2DFE6F0DDE6F1
DBE3EED9E5EDD7E4ECD9E5ECD5E2E9D7E6EDD6E5ECD4E3EAD3E2EAD4E2EAD1E0E8D0E2EA
D0E1E9CFE1E7CEE0E7CDDEE8CCDCE8CCDCE5D0DEE9CFDDE6CCDDE6CFDEE7D2E0E9D3E2EC
B2C4D78BA6C7486FA4406CA48EB0D5BFD8ECBFD9F08EAECBC0DAF0B7CBDD94A7BA95A8B7
9EAEBB99A8B5B8C9D4BFCED998A9B3C2D4DDB1C4D08C9FAB95A7B292A2AA99A8AE9AAAB0
8F9FA682939B85999F7F939A879AA175888F687D81647C7E5973746B8387798E917A8D91
768B8F718A8D6F878969818270888A738B8E6E8487677B7C68797A657676617474667B79
5D72705B6B6346402F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB111
764B1C6E4C316D4D3971503F70534372564A72544E6D504F6A4D4F694B4D684B4E65484E
674A52654A5360444E7254607F5E6B83606E84606F8A65738C6A7491717A94737D957580
9577828E75817F6A767C6A7478646E937D87A58E989E8EA15B629006227801248F022793
0C35889FB7DDBDB9C3CDC0C6CBC0C6CEC8CDD6CFD5E5E0E7DDE0E4D7DCE1D2D4DCD7D9E4
DBDFEAD9DFE9D7DEE6E0E7EFE6ECF5ECF4FCE1EBF4D1E0EFCBE0F4E6FBFFF1FFFFE5F9FF
A8D7F54F9BD2368ECE93D2EFCBF6FDC4F0FCBDE4F9CEE4F4D8E5EED7E4EDD8E4EED5E2EC
D6E3EDD6E3EBD4E2EAD5E3E9D3E4E8D3E4E8D6E5ECD5E3EBD3E1E8D3E1E8D1DFE7D1E2E9
CFE0E8CEE0E7CEE0E8CDDFE7CDDFE8CBDDE7D0DEE7CFDDE6CCDDE7CDDEE8D0DFE8D3E0EA
CDDDEAACC1D4B8D4F0AED4FA86AEDBB2D5F689AACD2E59839EBEDC97AEC39EAFC29EB0BE
CCDBE6B9C9D3BBCDD8CADBE8A5B5C2A7B8C2A6B7C491A2AF8F9FAB92A3AB8799A099ABB2
86959E7C8C947A8B92768A907A8D9671858C677D83647D805D767963797E72858B778B8F
778B90738A8E6D83886C848771878B768A916D80866C7F836A7D7F667978637876637C79
5D73715A6A634C493A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B714
774A196D4A306D4C3971524073584874594D70544A6B504B664C4C64494A66494C684B50
664B526B505871535B77596180616983616B835F6D8864728E6B778F6E78906F7896757F
9776819478846F58656D586486707A826B75A48F98A498AB4C578B072885012796012997
0E3A8DA3BDE2C1BDC7D2C3C8D6CDD0DFDDE0DEDCE1DDDCE1D1D4D9CCD3D7D8DCE3DFE0E9
DDE1EADEE2EAE7EBF0ECF1F7DEE5EECCD6DFD7E0E9DBE3EDE9F2FAEDFDFFD2EDFFBEE1FD
6FAADC2A7EC42781C6A1DCF6D4F6FFB6D9EB82ACCDCCE5F6D6E3EDD4E1E9D5E2EBD4E1E9
D3E1EAD5E2E9D3E0E8D1E0E5D0E1E8D0E2E7D3E2E9D5E2EBD3E1E9D3E2E9D1E0E7CFE0E7
CFE0E8D0E1E8CEDFE7CFE0E7CDDEE6CEE1E8D0DFE8CFDFE7CFE0EACFE0EACDDEE8D2E0EB
D2E2EEB7CCDCB6D3EE5E8CC31C529C7AABDE8CB2D848729B9BBDD9BED7E8BCCFDFA8BECC
CADCEAC5D7E7A9BECFB7CCDCA4B6C39DAFBAABBBC89CADBAA3B4BFB9CCD38B9EA59CAEB5
8E9EA686949D7C8B9383969C7B8E956D8188667E83657E8261797D617679687D806D8287
758A8F6D85896A82866F878B71868B788B9172858B6E8184788C8D667C7A647A78657E7B
5F73745868624C4A3B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A4A16704B306E4C3872533E74584876584C75574C6E524B654B48654B4B674D4E664D50
715B5E8B7579755A617D5D6583636C85636D86606E8864708F6F7991717993727C957680
9879839476817E636D8E6F79A2808A8F727CA08A92ADA3B545548C072B8F022B9F012D9D
0530878DA6CFBCBEC9CDC6CCD8D2D8DEDEE2DADCE1D4D6DBD6D8DCDDE0E4DFE3E7E0E3E7
E3E6EDE4E8EDEBF0F5E9F0F8D8E0E9D7E0E9EAF2FAEEF5FDE4F0FAB2D0EE4B7EB97AB0E1
A3D8F974B0E177B4E7AADBFDBBE4FF76A8D25B93BEC7E5F8D4E3EED8E3EAD5E2EAD4E3EA
D5E2EBD3E2E9D3E2E9D2E1E8D2E1E9D1E2E9D4E3EAD4E1E9D2E1EAD2E2EACFE1E9CEE0E9
CEE1E9CEE2E8CEE1E9CCE1E8CCE1EACCE1EACDDFECCCE0ECCBE0ECCAE1ECC9DFEFC9E1F0
C9E1F3ADCEE793C0E92965B3094CAF5793D7AAD4F7A9D1EFA5CAE5BFE0F8C5E2F9A0BFD9
B3D0EDA7C3E28FADCB9DBBD4A8C3D797B0C3B9CFE2AFC5D69EB4C5AFC8D5899FAB8A9FAA
8FA1AD8EA0A9899BA3889DA17D949871888C667E826B83866B80826981815D7776657E7F
738B8F6F87896F848A71868B72878D758A8D778C91758B8E7287896D817F647A77687E7C
5D71725C6B674C4B3C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
824E15754F2F724F3A72533F75574974564A75564A6F52486B514C684F4E684F525D4A4B
978C8CC0B6BA76636B7C5C68805F6A85646F8A66728C68748F6B75926E7892727B977783
97778393737E8F6E77AA8089B38791B18D97A9919AB3ABBE3A4986062A910431A90434AB
0432927E9CCDC9D1E0D5D4DCCFCCD6D4D4DCCED0D9D1D5DDDCDFE5E1E5E9E0E4E9E7EAF1
E1E8F0DBE5EDD5E0EAD2DDE9D4DFEBD9E3EDD8E2EFD0DEEFD1E2F89EBEE53368A56FA6D9
A9D5F4AED9FA90C0ED2565AF3C7FC87AB4E56C9AC0CBE4F5D4E2ECD3E0E8D3E1E9D3E1EA
D3E0E9D5E2EAD5E2EBD5E2EAD4E2EAD3E1E9D3E1E9D0E0EACADDEACBE0ECCBE2F1C8E4F1
C4E2F3C2E3F4C0E2F3BFE3F7BFE3F9BEE3FABBDFFBB3DDFBAEDAFCA7D6FCA5D4FF9CD0FB
96CDFA79B5EE4E94DC2C7BDD0754C64C96E675B3EC71ACE8649FE268A3E369A3E4457EC4
5187CC5588CB598BCC78A9E38AB7ED6691C68EB5E78CB2DF7096C2769CC181A4C57F9DBC
85A1BD7F9CB3819DAF829EAB809BA7718C95647C84687E836E85886F8A8A6F88896F8789
728A8C758A8D6F83896E868A71858C6C7F85768B90778C8F778A8C728686677E7D677D7D
596D6D5A6965545345
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8B5418754F2B73533C74554473544873544A7354487153486F514B694E4E6850525D4B4E
A0989DBCB7BF7967737B5C697E5E6982626C8664718C68748F6A7493717B94747F987985
987A859E7F8893707AB88B97C695A2B18D98A7929CAEA6BE314281032890012EA60334B0
03359C6789C1C6D1E4DEDDE6CFCCD5D1D1D7D6DADFDBE1E7DCE0E7E0E4ECDADFE7D2D9E2
CCD7E1D4E2EBD5E2EED0DCE8C9D6E0CFDCE5CCDEEF7791AE9FBAD8BDD8F39CBCE284ACD9
90BDE6ADDDFF6296CC0D51A7175CB09DD0F8C1DEF5D1E3ECD6E2EBD6E2EAD8E3EBD9E3EC
D9E2EBD7E2E9D6E4ECD3E4EBD2E5EFCDE5F2C9E6F6C1E5F8BCE5F9B4E5FBA9DEFE9CD8FE
8DD0FB7BC3F473BEF45FAEF056A9F04697E8408EE93586E42D7CDE2572D61D69D11865CF
1561CF115ACD0F54CF0E4FCF0B4ACC0C4AC5124ABE1249BB1044B91348BC1145B91041B5
0E3CB0113EAF0E3CAC0E3CAB0E3AA70B369E0E3A9F103B9C0C3795113E951643951D4695
29539F325DA13D67A34E74A85B81AC567C9F5C7C9864819668869461808A6B89906D888D
738B91758B9071858C728A8E71868B63787D73898D6D8589778C90768C906F84886A7F81
667B7B5F6E6B525047
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
40A60B754D2976533F74534373554972534875544A72514971514D6D514F654D4C5C4A4B
83787FAA9DA8735B6A7D5D697F5E6A8562718965738B677493707B95727E9473809C7C89
A3838FA8869197727FB9909EB7919E957A86AD9EA8AEAFC6283F80062E96012CA40332AD
083CA1799ED4BEC9DDD0CED8D0CFD5D0D2D7D0D4DBD9DDE5D1D5E0C6C9D7D2D7E2DBE1EB
D5DCE7BECAD5C4D1DFC5D1DDBFCBD4CCD9E4CFDEEF93ABC58AA5C0A2BAD1B2CCEC305A96
114B94437DBA94C7F34D84B865A2DCA7DFFFC1E5FDCDE4F0D1E5EED4E6EDD8E7EEDCE8EE
E0EAF1E3EFF5DEF0F6D2F2F9BEECFDA4E2FF86D4FA66C4F552BBF73DB1F42DA7F12098EE
148BEA127FE71B7EEA176DE11A69E21A60DE1E58D92457D4254EC92546C02B46C22D43BF
3446C03944BB3D3CB44037AE4436AC4635A4462F9C4F38A4462E9C49309C4F339F4A2E97
4327934128913D28913927903827943627913328912C278D26268C22268D1F29901A2990
14278E11288D1029900B278908268207287A0D2C76193A7B274C81395E89567A9C6486A0
7291A3728E9B718A93718B90748A8E697F836D85886C86876D8388788D90788D90718A8C
7286896C7A7B545049
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
45A90D764C2673543C74574472554775564A75544874544971514C6F534F664E4A634E4D
6750557258637658657D5D68805F6A8663708964728A677493727D9A78859C7B88A2828E
A98894B08B97AF8A95A4828D9D838CAB99A1BCB1BABABED5314B8A052D96022EA90234B1
0A40AC527ABBB8C5DEBFBFCAD6D7DFD4D8DFC2C5CFC7CAD5C7CCD7C3C9D5CED4DFDDE3EF
CDD4E0AFBAC6AFBDC8D0DDE6C6D0DBAEBAC8BACADAA0B2C79BB4CC9FBDD2C4E0FC436BA0
245A9B477BB0AAD3F3BEE7FE72BCE63598D471C5EFB0E9FEB8E8FBC0ECFCD2F2FDE1FDFF
E3FFFFD5FAFFB4ECFE7ECEF458C0F52EABEF1BA3F00F9CF20C98F80691F50790F90383F4
107FF4286EE55164DA6559CC6F54C4774BB78544AB923D9F9833919C2C86A02A82A02379
A11E72A41E6CA71D67A81A5EAA1A5BAA1856AA1551AB1652A81652A61951A51452A1124B
9F104998114995104A900D49900D4A8F0E498C0F4D8511508212587F175F7816666F1A69
651D6C561E71481F793A1C7D30207F231C791817731217730E1A73091D720723710F2F75
244983416792597A9A67889D6D8A976C868E698288697F84677C80687E81688082718A8E
84989E7D898D524947
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
49AD0C764A1D73543872574173574475564676554770534771534C6E5250634C4B624B4C
684D5275575F7556627D5C6985616D8A616F8D6472946F7D9B78859F7A86A3808CA3838E
A88A92AE8F9AB0909AB99FA7BEACB2CBBDC5C0B6C1B8BAD2425997072E95032FA9012FAD
0333A52D569EACBFDAB9BDC9D5D6E0CFD2DCB5B9C3B2B9C1D5DCE5D8DFE9BFC6D1B5BDC9
B6BEC9BAC5CDAFBDC4D1DFE7CAD7E0A1B1BC9DAEBAC2D5E596B4D0507697C2DDF6BBD3EC
BCDAEBD2F4FFC5EDFDA9E6FF4EB5ED2DB4F335B9F841BAF552BFF669CDF785DCFD78CDF2
59BBF134A4E51F9AE61297E90C96EE0496F00292F2008AF1018BF60089F50086F7067FF5
2A6CE68350BFBD368CD33074D92C68DC2B5EDD2652DC2047E02045DE1B3DDB173AD81539
D20D33D20F2FD00E2BCC132AC61A31BD1B30BB152EBB0F28B81A31BE3148AD1733B10F28
AD1329A9192EA50E28AA0520AF031EAE051CA8071DA2102899132F961333971235931135
9211368C0F37880C3D860C437E0D4675114A6810505A11574A115F3817651F126616166B
0D1A6D081E6E0926701A3D7A345786547392607B8F5F788162797D64797A64797D667E83
8A9CA381888C3E7432
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28D90878491876523774544076564577554777564B74544B71544E6E5350674E4D674D4F
6B4F536F515773535D805D6A855F6D8B6270966C7A9A75829E7B889F7C89A58391A68792
A68A95AC909EAB919FB8A3AEC8B6C0CDBBC5C2B3BFB4AEC64C5D9906278D02279F0126A2
062FA12A529CC4DAF6C4C7D3B7B5C2B0B0BCC3C7CDB3B8BDCED3D9D5D9E3B4B8C4A3AAB3
D0D9DED6DEE4ADB5C0ACB7C3ABBAC6A6BAC6AFC7D3C7E1F2B5D7F09CC5DAD6F9FFCBF0FE
A1DBF37BC6F052ACEE32A3EF28ABF91CA8F60F9CF60D99F30A96E919A7EB2BAFEE24A1E6
1593DE1A96E21B93E21E99E61C9FEC19AAF418AEFA12A9F80DA4F80BA1FB0C9FFE1995FD
5978EABE449DEE2A5AF5233FF41D37F21A2FF01B2CE21320E51523E11220DC0E20D30A1D
CE071DCC071ACA0819BB121EE4737AEE9FA3CD6C789A1C2FCC6473FFC1CAB65D71911D33
E18995EFABB4AB4357A00921AD0416AC05119B0C16DD7F86CF8F99C0838FB97986B06977
A758689D435594273E930D2899042095031D9304218C0727880C327B0C3768093E5F114D
4811553216611F1565101667091A680B246723427641637F5573815F7B7E61797A5E7579
7D8D92787A7B2BA320
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007B4B197451347958447655427755437B5A4C7757507255516F545069504D684F51
6C52567053597958607F5B67885F6D8E6671956F7A9D7B86997B859F818DA28593A48994
A88E99AA929FAF99A6B69FACC2A7B5C3A5B3C3A4B2B8A2BC505491072282032293011F93
0324921C3F8AAAC0DFACB2BEAFAFB7BABBC2D8DCE1C2C9CDAFB3BBB2B8C1C4C9D4B1B5BE
D1D8DED5DCE4B9C4D1B4C6D6C0DBF0B8DFFB86BAE3A0D9FE83C1F274BAEE5EACED3895E9
198BE61C98F90B83EE0576E90277E80885EE087FE70A87E60CA1F313A9EF1CA1E551BEE9
81D9EFAAEDFEB3F1FFAAF4FF87E9FF62DAFE3BC2FA20ADF7109CFA078DFA0782F71175EF
4956CDB42E82E31B3FE61424E20E20DF0D1CD70B19D00915D10918CE0818CB0516C60618
C10114C00314C00516A90B1CE28C98F2CDD3ECC6D085394FAA6176F6D2DDAF798F833750
EFC5D2E8CCD8AD5F79960A26A70215A503108C0D1CE3A8B2DCC8D3DAC9D9E0CADAE0C8D6
E0C7D7DFC5D0E0B4C09033489509209802139304119219238C1F2D7E0E217C0A217E0A26
7B0C2F710B37660D434E0F4D32125916105A0A135C061F5B21436B4D6F845A7680577076
6F81836D6F6D239A15
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007D4E1875533578584376554375564378594A7C5C557658567255536C51516E5456
74585C795C617B5C637F5E688A6573906B7794707B997982997D889A828DA18895A38A98
A68E9BAA92A0AD93A1B394A3BB95A6CAA0AFCCA0AEC39EB94D47820B1F7C021B84021B87
011D8513307894A7C4A7AEB7BBBFC3B6B7BED2D5DCB4B8C0B2B8BFC3CBD3D2DCE5CFD9E6
BECCDEB5CDE5A9CEF19BCCF978B5F2418DE01974DA1375E40F6DE30C5EDB0963E00473EE
017AF30183F90283F90287F7038DF7099EFA20B6FE37C9FB3BCCFC4FD5FF70DFFF91E8FD
9FE5FD96DCF76DBDED48A6EE218EE81382E81077E9106EE61468E5175FDF1E58D92C4FCB
5F41B1A71B68D51136D90C1FD40917D10918C50211C20312C50516C50516C40415C40616
C30415BE0212BD0314B6071BBE4055E3A9B6EDD4DFA7778C935771F2D2E2BA91A582445F
EBCCDBD7B8CB9035589E0928A80115A30211860919D298A6D1BCCE826181935F859B678A
A6799AAD93AAD9C5D495576C860A259003157E0611CE878BD1A6AB7E4F56A86D778B4651
8731447E152C8507258308277309305B0E3F37104C1311520418580D2B5C395977516E7A
5F75785C5F5912CC09
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0082521775523174553F7555427859487C5E51795C53795A56785956755755745758
7A5B607E5F667C5D6582626C8565718C6B7891737D927A8299848C9B88919C87939F8796
A68B99A68C9AAB8D9CB390A0B991A2C79AAACB9BACBE97B3473D7708157001127901177E
041E810F2870828FAEBEC2C9DCDEE2B6B5BDB6B8C1C0C9D3C2D1DFB6CCE1BDDAF9A1C5F0
7FAEE8518DDA2B74D31568D40B63D80461E10262E90267EF0060EB0865EE0470F00684FC
058EFF038FFC0699FF0AA3FF0BA7FF17B3FD22B6FA2BB6F81FAAFA1398F1168BEC1A7FE3
217AE12372DE2165D8235FD62D60DA395CD74951CD5849C16A44B7793FAD82349E933192
AB297EBF1450D20F30D60D1FD70B19D10B16CC0814C70512C80717C60413CA0815C70510
C70512C80614CB0815CB0C1CBE152BC3596CF6CFD9D5B3C386546AF0D1DFC7A4B6864B64
EECEDED1ADC18C2145A50724AD0216A402128A0618C68492D8C2CE876A7F84516C7F465F
743956704860D5BFD199677D830E2C8F03177D0514B98089C3B8BC827F83B6B1B6BDB4B8
CAB2BBA36A7A7A0D228904178A031782041C700A2E3D0D430D105402175B051E5333516D
566D775C605900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF006783157B583172553B70543D785B487A5D4F7C5E547A5C547C5D59795B5A795C5E
7C60657E626782666B81656E8468748B707C90798494808996868D9989939886929D8794
A18996A78E9BAB929FAD8F9CB593A0B6919FBB95A4AE8EA73F376E08156E00117501167D
031A7D11276E8A93B3A5A6B1BEC0CBB3BACCB1C0D9B7D4F895C1F15A91D73070C81359C1
0A54C80453D00356DB0257E0015BE70060ED0165F1036CF70574FA0A82FD0B8EFF0990FF
078EFF0289FC068BFB0286FA068BFB0886F60C77EB0862DA1262DC226CE42A5AD7435BD5
5451CA6246BC7946B5893EA79133999F3092A72986AD287DAC2474A8216FA624729F226F
9E206CAE1D60CC1542D91026E0101DDB0F18D80D17D40915D50A17D30914D40812D50913
D40814D50915D30713D40B18CD0F22B5283AF8BAC6EFD1DC936C7CE9CCD9D4B2C48B536E
EDCEDED0A5BA931F42AE0822B20213AB020F960516C37280E0C6D0D4C7D2D3C5D1D1C0CC
CCBAC7C0B7C1CFC8D5A5768D88133197041B8B0919A2606AC1B8BDAAB5B9AAB5BCAFB8C0
8D8A95AC8B9A6F13298404148C020F8B020F7F0419550C33160D4C04145A011555061D4A
3B5468535B5600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0044AB0D815C3373563A745841795B477D5D4E7F5E527E5E557C5D597D5F5D806164
816367816769826A6D81676D866B748E7581917A8795818D947F8B9A869298838F9F8996
A48D9BA48C9AA58A99A48997A58795AB8C98B493A0B295AD352F6705136D01157B011882
011C831939888DA5D199A8C492ABCE88AEE44E7FCA2763C00F53BF074FC70450CF014ED2
0250D70154DD0155E20158E60562F1066BFA056EFC0673FC0976FC0671F80571F6046CF1
0769F00B69EE1068EB1360E41E5EDE295AD4243BB32A269B4225977437A3923299A62F8C
AE2A82B62C7FAD2876AA2976A9307E9E307E903286873A8E773E966444A15852B34755B8
4155BC634EB1AB2D77E01C3EF11C27EE1A1FEB181DE8141CE6111CE4111AE5111BEA1722
E00F1ADE0F1BDB0C18DA0F1BD50F1FBF1B31E38F9FF2D7E1B097A4E5CBD9DAB7CA95617A
F0CFE1CA94AD9B1C3FB40820B80414B70613AA0A1AAA4052B78294AD8DA0A891A5B09CAF
B5A8BAC7C7D2CEC6D4AD738E890D2D990319930819984C57CBBDC5B6BEC4ADB6C1A9B1BC
AFAEBCB193A3731A3184041788000B88020B8004135D0C301C0F4B04105601115401164B
11274647525200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0048AE10865F367E5D447E5D487F5E4A81614F83635385635883625A836260866667
8568697E6465846D6F887075896F778B747F8F7985967E8D93798A987E8F9A80919C8192
A48A999D82929D8091A18392A88A97B493A0B6909FB495AF35306B061A77041F8A02208F
022493042E904671C23A68B71C57B51456C70445C00344C40145C9014AD30050D90253DC
0659E4055CE9055EEC065FEE065FEF055DEF0259EA055DEA0A59E60D50DB144ED51C46CA
2D42C43C42BD5145BB603BA97D38A0852D8B7313697516667D1A6A9226729C28769C317D
9739868F44918152A06556A45562B24067BF2F6ECD2676D91F7CE01A81E71685ED1588F0
1585F43876E9944CADE12C5CF5202FF11C20EE191EE9161CE7131DE4101CDF0C1ADC0E1A
DA0D19D60915D60917D30B16CF0A1ABE0F24C75E72F5D6E1C5B8C3E0D0DBD4B2C5A4758B
F5D0E5BB77969F1638B00319B50111B50410A70A19CB6A76E2B6C2CAB1BFBDA7B7B39FB0
A294A4C7C2CCCFBACB883C5B960C2B9D01179507189D4D5AD4C2CAC3C5CEADAEBB91909D
AEA5B3946D8078183389051B89010F85010B77010F5A0929230F4807135501125801134E
04163D3C444D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0050B315875B32835E47815E4A815F4B84645286665587655A87655D886965866967
856B6A836C6C86707387707889727D8A73808F77859379899376889C7E8F987989957485
9B79899D7D8C9D7D8CA1818EA98894BB97A3BA90A0BC9BB8403E7C061F8003269501289B
052FA50130A50434A90235B1033EC10141C90145CE0248D0034ED90657E4065CE70659E5
0655E10251DE014FDC064EDD094BD90D45D11340C82240C33337B3472DA065319A74288A
8925808D1F7295237095216B9A25709B317B7A2A784F21763C2D874C53AD455DB5456CBE
5481C97CA2D69AC2DE97CDE48AD8F068D0FB3FBDFF1FACFE0F9FFD0C9BFE098EFB0884FA
0476F81866E96A4ABAC42662E0122CE5121FDD0E19D50914D80B17D50916CD0111CD0613
CA0610CE0812CE0513CE0714CA0617BF0A1EB4384EF5CAD5CFC8D3DBD3DFC4A7BCBA90A7
F3CDE2A55274A51134B10317B30110AF020E9E0A18CE7684DEB7C6D1BECBD2C4D3D3CAD5
D3CAD5D2C8D5E6C5D89B42609E0B29A30216950817994752DBC5CBC2C0C9B5B3C0B9B7C2
C5BFC8AE8D9E7A1C3889051D8A010F83000875020C5E031A380B38120D4909165702124B
021239252D3600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDB0C895B2D836046825F4C83604E8865548C6B5B8A695E8A6A628B6E69866C69
826969826A6C846A73816674856B788E73818A6F7F90738590718391718291707F93707E
9B79879B7E8AA08490A48694AF8E9DB694A5AB8DA5AA9DC23C4A9007298E032CA0022DA7
022DA8002FAD0030B20034B9023BC30646D0054BD60650DA0551DA0450DA044DD80547D3
0842CD0C3EC71237BD1E33B53130AD4A2EA2612A94782583881C72951E68901B5F8E2064
82216579266D682B77583A8E4B4CAA3956B62D68CE1A70D6167EE12598EA47B9F078D9FF
A5F0FFB8F0FFADE6FE7DCBF040A5EE1D95F50886F30281F6027CF60279F6006EF10067F1
015FED0B55DF3834ABA22067D40F31D90B1DD50718CE0411CF0511D20714CE0412CE0915
CC0510CB0410CB0411CC0715C80A17C11523A52939EDBCC8DDD4DFDACDDDBB93ACCA98B0
EDBAD1983959A50F2EB20517B30210AB0410A01D28C275829C7284BDA3B4BAA7B6B6A5B5
B39DB0A6859CBF829E9D2D4EA60A26A704168F0B17C6848BD2C2C9A9A5AFBEBAC8B0AEB9
C8C7D2CAAFC28026458C06208E020F8802087A01066C020E5606223D103B1D1449050F44
05153B1F242E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008A5B28825F4284644E8665528A6956906F5E8F70638F726891766F8C746F
846C6B80656A765B657A606D886E7B876F7C8469788A6C7B8465758867788B65778D6879
9776859C808DA38A97A68F9FA390A69D94B17A7CAE40559D0E3293022C9F012DA8032FAF
0232B40234B70237BC0742C70540C7033DC60340C90442CA0741C8093BC21137BB1B31B1
2A27A344269A5F248D731D7B85196D8A17618A195C871E5F7C2167702E78512D7F34338C
2846A42355B52067CB1872DB1684EA1591F21198FC13A2FF0E99FA1598F61999F6168EF0
1B89EB187DE41478E50E73E8046AEA016AF00168F20169F30060EB0063ED005FEA005EE8
015BE70553DC2E46C08D257BD0133CDA0B1DD90915D90B16D90916DC0C18D90915D60914
D50712D30612D50A17CF0C18C7222AD2565EB76872DDC0C6DFD8E0B8A5B5AC8196B48298
C08BA1C0708AAD2D48B0081CB40210AB0513B84350F6C6CFD8C9D3CEC8D4D1CBD8D4CEDB
D7CEDBC4B4C4D6A6BC9D3350A30822A40513911621D2A0A6D3CAD2C6C5D1C2C1CFC0C4D0
CCCEDAD0B3C987264995062395000E8F010885020772020D550318410728340F36151039
0B163627262D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008D5C2585604086634C8D69558F6C5795725E987A6891776A988177927D78
87727180696B7C626A7C626D7E646F7B616C7F64708062708363728766758F6B788E6B79
9174839A83959588A08D8BAE616DA228428C103592052D9B0430A90130AF0231B20237BB
053CC20234BC0232B70136BA073BBF0737BA0F3ABA1836B4222AA4382295531E87711E7A
84186A8C135E8C12578616587C1B60651D684C287934358D2644A8194EBB125BCD1773E6
0E7BED138CF81495FF078AF71399FD0787F90381FB017BF80275F6016BEE0068EE026DF5
0166EF0166F10164EE0169F10166F10062EC0061ED0064EF0067EE016CF1016FF3006FF1
0476F8036BED235FDB80399DD62155E91627E9131AEB161CE91219EC151AEB151AE40F16
E51019E40F1AE4111DD81620DC525AFDC6CCEDD1D8E0D5DFDCD6E3DFD5E5E3D2E3E2D2E1
E1CFDEF3CCDFBA5772B2102ABC0517B60719BA3249EAA8B9E1CEDBBDB8C7B6ADBEB5ABBB
BDB9C7D1CDDBE4C0D69A3452A60C26A4081892262FD2AAAECAC2CBA29EACBAB4C4BEBFCB
D1CBDCBD8AA8951E44A408239F010F9701088B01097004133C04231C03262A0B2D281633
19192C1F5A1C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00966326875E3E87614E906854916952947059987B6798817296807496807B
877270806A6E7D666E7961697258627359647A5F6B7F626F8564728968768E6E7C8E7383
8A79907A779B4D58901C3685092D8F042D9C032CA1002BA50436B50438BA0438BC063BC2
0438BE022CB00428A70B2BA414289E1F1F90381D85632583801F728E165E941255901351
8015546C1B615221713827812231941740AA1350C00D5DD11070E90C73F20B78F90A79FB
0370F50472F40577F70575F7016CF10069F20168F40063EF0469F5005FEB0061EE0066F2
0067F1026BF2026DF00577F40376F20677F1077EF30883F30788F2068CF4058EF6038EF6
038DF8058DF81C83EF785EC4D7346EF72739FA2328FC2324FB2125F91F22F41A1FF11820
EB121CEE1621EB1521DF1822DB4453FEAEC2F1B2CAE6ABC8E1A7C7E3A8C6E3A8C8DEA7C5
E1A8C7ECA4C5BF4568B70D2BBE0417BD0519B30B26B23B57F1BACFE0C9DDDCCCDFD9CDDF
D7CCDFD8C0D7A961839B1A3CA6071F9C0817AC565EDAC5CBC9CBD2C0C3CDA8A7B5C6C5D2
D7C1D79E4D729F1136A9071DA704119F020A91020D71071D2F08310C0A3D0C09331C122F
271B2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0043AA0E855B368B684F906E56936F558E6C559F8573A994869D8A80917C77
89727182696B775E636E575D765D657258627B606A82666F846772866C7C85728B726A8D
495083152973072584062B980129A00129A3032BA6012AA8022DAD0331B30534B60632B2
0C2EA80D1D921C168335167756166E751564830E51901350911754851E606C2571462376
2E2C861B34991340AE0A47BD0F5ED6106AE60863E70765EA0565E9096CF30162EC005CEA
015DEC005BE60060E90060EA015FEC005EEE0061EF0169F20069F1026FF60374F6057CF4
0981F00F86EC198DEB2294EA2D9DEC38A9F23DB2F443C1F33CC3F533C5F62AC2F928C4FE
1FBDFF12B0FF1B9FFD6682E5C04089F12A46FA222CF91E24F0181EEE151DEA121DE7111E
E20E1DE3101DE20F1FD80C1DD2152FCC254AC82956C22556BE2054BC1F51B81E4FB62050
B41E4EB51A49B61036B80620B90417B80316B5041CAE102EB1375DB04F7AB4628CBD759B
CA85ABB86088981840A60827A60215970614C66F7CDDBDCAC4BAC9CFC9D6C4C0CFC4BECC
B690AA952E53A50C29AD0817AC0610A3030C9203106E0B28270A3F07104E0310460C1136
2C1E2B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004CB112895D308C6B4B9273579E7F659C816BAB9787AD9B92A8989090807C
8975747E6566755B5E795E657457637458647D646E7E67727C6D7C6F6987464A7B142166
031B7003228601259402299F0128A10328A20125A00227A20427A50927A611269E181786
2F11744E1266690D567C0C4A830E467E0E4871135257155F43267E2C339A2043B60F41B8
0A45C1074ACA0851D40553D80455D90559DF0151DE0152DD0256DF0051DA0155DF0054E3
0054E30059E6005FEA0167EE0069F1006DF50174F70384FB0488F8088DF41295F129A4EE
54BDF180D6F1A2E6FAC0F5FFC8FCFFC2FFFFA7F7FF7FE7FC62DDFA32C0F61BB4FA0EA7FB
059CFC0393FB0682F6326FE58A41A1D1275CE51B35E41628E11427DE1328D40E26D2112D
CD102BC8112BC51030C00F31B90E35BB153FB61243B11245AD0F45AB1045A70E44A61043
A30F41A10E3F9F0C379D0B309C082B9F0729A1092B990729950831950B39970E3F971041
9A14429D0E37A4072BA6021CA401159C0317981B36C46F8AAE6D8DB582A1CFAEC7DEC6DA
DFADC7932645A80D26AD0613AD050EA2040C8D0313640F361D0E4F06155D021456061243
251D2E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADB0A895B288E6A47937558A489709E8773A39083A1928AABA09B9C8F8D
8C78787B6263785D5F7D61667B6069785E697765747069804D5278172562031566021A77
021F8402238E01249703269D01259D0121980521990D2297151A8B2D19824D1571711663
7D0B47850C407E0D41680C46511558361C6B2224801128921237AE0639B90D53DA0651DB
0247D30247D2024AD40149D30048D3024BD70048D5004BD9004ED90256E20057E30059E5
005FEA016AF20271F4037EFA0284FB008BFA0397FC0BA7FD1DB6FB3DC9F96BE3FE98F7FF
B4FAFFB7F5FFABEBFD9EE3F883D5F459BEF22DA2ED1497EB0F97F20690F5048FFB0289FC
017FFA0179F90272F81067ED434FC885328DAC2365B11D54AB1F53A522589E225E922062
8E256C81266F822D7D772C7E6A267A6C2D83642B84612B895927875325834F25814B247D
4B227C4A20784F21774A1C6C4D196B4E16644F146053155A5610535F0F516910516F0F4D
770E497F0D428409398C0A328D07288F0625910828900E319011388F163D9B3459C26A8F
B14C70A01737AB0A20AD0612AA040CA0040E87051B520E3C15135B04146403176304154D
1D1F3300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF008A5C228F6B45907355A28A72A692809E8E83A99F99BCB4B2A19494
8771727F65657C63637F686B7D6A72726275585475222A5F06145E02156B021978011B82
02208C011E8F011D91031E94061E930B188A19147E3713715E1164841359900D4689093B
74093B590D4938125D201C75101F870E2E9D0832A70837B30332B50031B80B52DA0552DD
0145D20244D10145D00146D10046D20149D7014CDA0154E3015CE90164F0026DF60272F8
027BFB0484FD058BFC0698FC09A6FF09AAFF0DAEFF12B3FD1DB6FA20B4F62AB5F82DB0F6
2AA2EE2399EA1A92EC168FEC118CF00987F20587F90384FB0180FB017AF9027BFC0174F9
016FF8026AF60366F30360EE115AE42C53CE4249B94848B13E42AA3843AD2C3DAB253DAF
233DB21F3DB41D3EB81A3FB9173DB8163CB8153CBA123ABA133ABD123AB91036B51039B4
1135B10F31AC0E2DA50F2BA10F289C11289812269410218C132088131C81171B811C1D82
221D7E291D782D197233166640155D4C10515A0E47670C4172093A7D0934880D368F1136
9C0F31A50A22AA0619AD0612A8030E98020F800A244714480F156102176A051D6E021757
171D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF009565258F6A419174569A846B9C897C9D8F89BAB4B3BEB8BA948687
846E6E856E6C836F6E7A6C746E697D3C3F690A155402105F01136E021778031B7F001981
001A85031C890518870D16821E12763C0F67620E57820E4A8D0B3F8A0E426F094448094D
250C5D1214730D1F8A062899042FA70732B00126A50029AA0A41C5033CC5074BD6044BD8
003DC9003EC80044CF014BD50254E0015AE8015FEC026AF20575FA0278FB0482FD0688FF
0890FF0794FF0796FE089DFF059BFD0294FC008FFA0494FC0592FA028BF70389F80489F9
0586F90383F9047EFB0279FA0176FA0178FB0277FC0072F90271FB026DF8016BF60169F6
0166F40161EF015AE80159E60258E30756DC0A51D40A4FD0084ACC084ACE0647CA0547CA
0443C80240C40342C60648CB0343C60341C30645C90441C70340C50340C2023DC0023CBD
0137B90235B50131B0022EAA022DA5032DA3022BA001279A04279A01249604269905269A
05249506249508249309218C0C1F85101B7F141A781A177126166832105B470E505F0E46
770D388D0F2E9C0B23A208199F0312920413740B2936134B081562021C70042173021B5F
141F3D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB0128E6437927052957A668773689B8B88B3AAAAAAA1A08F7F7C
8B77718A79768A8189636580202B5E03145801156501146C03167701157A01167B02157A
041475080F6B170A623A0C5B660E537F0C43830B3C760B426013543A105F1D0E6910187C
08208C04239604269D0228A1022AA7032EB00732B40131B5033EC50042CE054ED9034CD8
0044CF014AD40154DF0462EC0469F3026DF80371FA077DFE0683FF0685FF0584FD0380FC
017CFB017AFA027FFC0182FC0280FC007BFA017DFC017CFB017CFC017BFB0176FA0176FA
0276FB0173FB016DF90168F80269F9016AF7046CF90066F30163F00163EE0062ED0163ED
0260EA015AE30157DF0056DC0259DC0255D70354D40252D0034ECE054DCD064BC80447C3
0647C00747BD0645BA0745B80743B30741B00A42B0083FAA0B46B00B46AD0B45AC0B44A9
083EA3093D9F083A9B07369409359207328F07308F072E8D062E8D072D8C052D8E042B8E
032A8F032A9304299202258D01218B02218B021F8B041F890620870A1D800F1C78171A70
2818673C16575C10477A113A890C2A810720650B31280F4D061564021E72032477031F63
181F3F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0C956533916C4C9276608A7467A4938E9B8F8EBBB2B0928682
8F827E8D888E5F6686152763041B6C02187301167301147203167501147404147208106A
160D5C2703424C063A6D0B38750936690B3F470C5127116617197D0A1A85061F8F052296
05249A02209A011E9901209A00209D0127A60231B30039C00347D00251DA075FE90159E4
0259E4045FEA0369F40574FC0678FE0677FE0473FD0275FD0276FB0478FD0174FB0272FB
0270FC016FFB026FFB016CF7016EFA0272FA0375FC0374FC016EF80070F90170FA006EF7
026CF80166F70161F30261F2015FF0005CEA015EEB0261EB0362EA0262E70462E60360E3
055CDC065BD7085BD4085CCE0C5AC80C56C01058BC1357B71454B31A52AD1F54A82358A5
2858A22E5BA1315FA136639E4169A04368994C6A98516F9B4F719C4F709B4D6E9B4D6F98
496B934B6B9248688D46668A47658C43648845638A3F5D843957803656802F5380264B7D
254A801C427D193C7D13337A0C2C7907297906267D03257F042381021F7F021E83042085
0720850D2081161A752A196745165556124449124816105303176802227803287B06276C
1E234100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00758E249069438B6E558F7666917C748E807CC5BCB99F9997
9998A05A64830B205D052074031F7E021B8001177C021476010E6C070F651209562D0A4C
47083B58082B5C09294F07323506431F1061121C7F08239106269C03249B012198011E94
001B93001A94001C9600219B0126A3012DAB0339BC0243C9034ED70258E20766F10769F5
0464F00567F3036BF70471FC026EFB0168F70267F80166F70269F90269F80167F70165F6
0062F40162F40161F20060F10062F10267F20165F20369F40265F20063F00165F20265EF
0062EF0265F10462ED015DE50560E6055EE20860E00962DD0A61D60C60CD105FC71762C2
1E60BB2764B53269B23E6EAC4C73AA587DAA5C7DA45F7FA36582A26D85A26D849E70899D
73899C75899C748B9C748C99778C977C8D97808D967E8D977C8C967D8E987C8D977B8E97
788B957588906B7E87667A826578826A80886C7F886A7C8664768060757D60778159747E
5B75805F79855A7281556B804C637E435D7C3952782C487327437527437E113075062776
04257C02237E0323810826840E237F162176141E70071E7403227D032883042D81092A6B
24264000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002ADC0D94693987694A8E72618A706692817AABA4A1BDBDC9
535F841022600F1C6A0D1A75051B7C041D8302187D0816730E0D5B1F05464107395D0B2F
5A0826430424250231160B500B136C051983032295032AA30128A30126A001259F01249D
02249E0228A5032BAC012DAD0130AF0136B60343C6034CD30758E20459E6045DEB035CEB
015AE8015FED0465F50162F4005EF1015DEF035DED015BEC015BEE025FF00263F40261EF
015EED015CEB015CEA015CEA025EEB015CE6015DE7015EE70260E80160E80464E70766E3
0864DF0963DA0E62D4105ECA1860C42265BF2867B93871B84B79B8547FB06186AE6A8BAC
728FAC7892A77E96A48599A384959F87979F8C99A18B9BA18D9CA28A989D849295899A9B
91A1A390A0A38FA0A58A9B9F8B9B9E86959595A0A2929FA192A0A38E9C9F88979B93A2A5
929FA38E9D9D879496829193808F93899A9B8D9B9D8895988390927B8A8C7C8E90778B8B
768B897E94917F93928294977D909576899072858D6579825C6F7C5A6F8050667E3F5979
2D4A741D3D70113475082F7D082F89072F8F062E91032B8F022A8F012889042C820D2A67
2E263900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00AC814986654289695489706194847AA7A5AD6A779E
142464281B644A1B624316641A106D0A177B0B12731D0B5C39063E52072D5A08274A0528
28012C0E023C080C5A031672021E8503239502279E0127A30128A4032BA7032BAA022BAB
022DAE0230B40135BC0741C70541C4013FC20546CB0248CE0146D0034CD8014CDB024FDD
004FDC0155E20157E70157E80156E7035AE7035CE70157E4035CE9035CE9025BE80159E4
0158E30156E10158E30158E2025BE20560E10661DE055DD50D63D41165D11764C5236ABD
3170BA4379BA5A84BC698BB77590B47B93AE8197AD869BAC8999A88A9BA58D9FA48E9FA3
8F9FA49AA9AB99A7A897A5A49DACAC96A3A49EAAAB97A1A39BA6A99BA7A798A2A2929E9D
9CA8AA9AA7A9A0ADB099A6A898A4A69CA7A8A1AAAC9CA6A8A0A9ABA1AAACA1AAACA4ADAE
A1A9AAA9B2AEA8AEAEA6ADB0A3ACAEA6B0B0A5AFB19DA4A89CA3A59BA4A695A1A297A2A3
8894958D9C9B8A999A93A3A391A1A193A2A394A3A5879798879697879697819294778B90
687D86576F7A4B6376415D7D2343750C3579073489043291022D93022C8C052D7C172A5B
16901A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009DB84C966F4984614B8F7466998C8C6B7390202F6B
2E1C616A17508F0E39870F3E500F54270E61330A56590D44650A2F520628320330190742
06064D020B5E031775021F8600239001299A012AA10129A30128A4012AA9012CAF0233B6
063CC0033BC10139C3013EC60647CA013EC1013ABE013CC0013EC30141C90245CD0246D0
024CD60151DB0354E00455E40256E40153E10154DF0155DD0155DE0154DD0156DD0257DA
0458D80455D30759D40C5DD20F5DCA155FBF2367BA336FB54D7EB6618AB67697B8829CB4
8FA4B696A8B894A4B297A5AEA0ACAEA2AEAFA2ABADA2ABAEA5ACAFA3ADACACB8B5B2C0BB
B4BEC0B2BCBDABB5B6A7B2B0A3ADABA5ADACA8AEADACB2B3B4B8B6BDC2BCBCBFBBC5C9C5
C4CAC9CDD0D1CCCFD2CFD4D7D1D3D6D3D2D4D3D1D4D1D0D2D0CED1D1CFD1D2CDD0CBC8C9
CBC8C8C6C5C3C6C3C4C7C5C8C0BEC1BFC0C2C0BFC3BEBCC0C2BFC2C3C0C3BABBBCBBBABC
B9B9BBB0B5B5ABB1B3B0B7B6AAB1B0A8B0AEA3AAAA9CA4A4959F9F95A0A0949FA08D9D9C
7E9091788D8C718385687C815A727E415D75284A74123C7A073182053285082B6F202748
0CC70A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0035E617B38251856044927A6E80798722295A2E1E5D
6F1E519A0E2DA90617A5091E840731690A41690A3B66093048072F23063D0D0A53071166
02136E021676021D8301228E01279802299F0028A1012DA40130AA0333B30336B90339BB
0138BC043BC1023AC1013AC00240C20341C20338BB0236B80137B7013ABC013CBF003EC3
0248CE0555DA0254DB0150D90151DA0252D90355D90255D50355D20656CF0B58CB0E57C0
1B5FBC2664B9356CBA4B78B55F83B27491B27D96AE8AA0B096A7B3A2B2B6A7B4B6A6B3B2
AFB9B8AEB7B7A9B2B5ACB6B7B4BCB8BCC4BEC0C5C3BFC4C4BDC3C2C2C9C7C9D0CED0D4D4
D8DBDDD2D6D7DBDFDFE1E3E3E8E8E9E9E6E8E3E1E2DFDEDEDBD5D7D2CFCFC4C0C0BFBBBC
B4B0B2ABA4AAA199A298909C9489958F828C887A8384777D82757B82737A837178847276
817374786C6C7A6C70786B70776A6C736969776E70766D6C7E74757E7777837B7B867B7C
867C7D8783828D8988938F8D9996969896959F9D9AA4A49FA5A8A4AEB2B09DA4A397A19F
8D999781908C7E8D8B7788876C80806076785B7178435E702545681136640F2A56292636
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0060C52787603B8F79733C3A562B1D54631A4D
980F2FAC0816B40812AC050F9D021687062662072E3706381406420A105B04156C021775
01157501177B011E880224930025990028A0012CA5083AB10336B00232B40135B90136B9
0133B60134BB0238BE0239BE0138BC023ABB0032B30131B10234B30036B5013BBB013FC1
0248CA0048CC014DD10454D50353D00551C90A54C20F56BA1F60B92E68B44978B3668BB5
7792B3859CB790A2BA95A4B39BA7B1A9B3B99DA6ABA3ACAEACB2B4B5BDBDBCC4C1C0C7C4
C6CBC9CBD0CEC4C7CAC5C8CAD6D8D6DEE1DEE7E9E8ECECEEECEFF1EDEEF0EBECF0E3E2E9
D6D4DCC3C2C9B5B2BEA49FAC9891A08E85918376827F727B7C6E75766A7072666B716566
7164646E64636F6362706564726464716261756563766A62776A6073665C75655D77665E
75675F74675B75675D74675D796B6274675C71685C6F66596D64586D6358695F55665D56
645D53635D51625B50635B52645B56645D596B625E756F6A7A7572817D7A817E7B878582
868883868A828489837A837D71807B687975627370596D6C4C636639535B20333C139313
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0034E515976C427765662A2049541E50921837
AA0917B50A13B1040DB1060FA704137B0423360537120F51020C56021366011A73021C79
01187800177C01208B032999022BA1032CA6022FAB0330AD002CAB012EAF0131B20130B3
022FB50134B90338BC0136BA0135B7043BBA0239B70237B60239B7013CB9013DBC0242C1
0447C5084DC4084FBE0B54BA195DB72F69B2517FB67192B98BA4C09FB3C6A7B6C2AAB6BC
B1BBC0ACB5BAABB4B9ABB1B7ADB4B6B5BDBCB3B9B9BDC5C3C8CDCDD2D4D6DADDDDDFE2E3
ECECF0F2F1F3F3F0F5F2EEF6E9E4ECD9D4DFCCC3D2B3ACBC9F97A8908A99827B8B746F7D
6E6A756E6A716C667065616A67666C6D6B6A706B69776D69796D67776E65787066797167
786F64786F62797063786F63766C61756B5F7A6F647A71627A74627A7260766C5A7B6F5F
7A6D61766D5B776F5D796F5E766D5D756C5B776F5D766E5C786F5E746D5C746E5C6F6A5A
6A67576969576B69586D69586B6555696356645E53615A4F6058505D544D60574E625A50
6763596E6B5F75726676756973756D6F766C676F665D696251625B485F573D504427691D
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00809F425947503D1E4879193EAB1222
B70F15AE0D12A8080EB61017AC08177C06252F0A410C1A66031C7103207B022382012282
012084011E87012391032B9E032CA5032AA70228A60127A50127A6012AAA002FAF0231B4
012FB60335BB0235BB0336BB0035B60136B5023AB70239B6033DB6023FB50743B70A46B2
0D45A52657A54774AD6E93BB8EA9C5A1B5C4AEBCC3BDC5C8BCC1C4BEC3C5C4C7C7C4C9C9
C3C8C7C4C9C8C8CDCFCCD1D0CED2D1D4D9D7E0E4E3EDF0F0F2F2F5F1EFF5E7E5EDD3D0DC
C4BDCCACA3B39B8FA38B8195857B8D857A8B867B8A756F7C74707B74727C6D6E75717476
6F73726F7370696F6E626A6B636A6860685F6B6E63737164797265777160757361777563
76705F797260797260797160796E60776E5F7A6E617971607C7562766E5C7A71607C7361
7A705E78705C756D59736D57756D5B74705776705C726C5A756D5D766F5D76705D716D59
6E6A596E6C5C6C6A5C6C69596D6A596C695A6C66576D6859666154665E506A5E4E655D4C
625C4D5E58495E59495F5E4E6462566A6B5E6B6B5E676A5E5963584E6052465747434A38
12CF0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CA9A6F6243515A1F4990142EB8151C
AA1214CD5B5CBF4C50A8141CB10A179709235B14471C1B6906238202258B02278F022791
02299303289501269503299C0127A001239E00219D0227A30129A5032CA9032DAD012DB1
012FB50132B40031B20131B10133B30133B10236AF063BAC0A3FA513479F315EA55E81B5
8AA3C3AFC0D2BCC9D0C5CFCFC7CDCACCD0CCCED2CCD4D7D3D5D9D7CFD4D1D7DCD9DDE1DE
E1E2E3E4E4E8EDEDF1EDEDF1EBEAEEDCDAE1C5C4CFAEACBA9794A2867D8F766D7E6D6876
746F7C827D8797949DA4A5ABA5A8ADA2A6ACA0A4A9888E91737C7E697677687677667473
667473667473636F71646E6F636C6B5E686060675A65695A6F6F62777767767563787461
76705C78725D776F5F766D5E776D5C756E5B766F5B78715D79725F7A6F607C7062776E5E
797060776F5D766F5D756E5B726B566F6B53736E58736E5A756E5E736D5B746D5C77705F
766E61726B5F70695B6F69596C65556D66566F6A5A6D6B5869675768625169604F6B6450
68645165624E58594755594A494A3F4F504659584D6163546166565861514E57494B5040
37712300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065C836743F42721D399B1120B1191A
A12828F5ACB2DA8B99991928AC0B17A907188B113848185E13217E04278F012693002895
022A9801299801279902279E02269F0225A00226A00127A20127A2012AA5032CAA012CAD
0330B00130AE0031AC0234AB0537A708379F16429A30569A627FAF8CA1C1AFBDD2B9C3CD
C3CACDCCD1CFD1D3CED2D5D0DBDDD9DDDEDBD9DAD5E1E2E0E2E4E4EAEBEDEDECF1E2E0E8
D2CFDBC0BAC9AAA5B5928D9E7D7987706B7867636E66646C6C6C71797A7D8E8F92929699
909498878F907C8687717B7B6B7575687171697271626B6A5B6868596967586867586968
56686956696C56696D586A6C5D6B6C5D68645C665E5D655963665C696C61747264787160
77705C76715B756F5C766F5D726B59756F58756E57746E56746E59776E5D776C5C756D5B
7A725F756E5B746D5B756F5C726B586E6852736D57736E597B7565767061767062746E60
726C5E736D5E716B5C706A596F69566E67556E69566E6C596D68576C6553655F4868654D
676653666857565A4C50554A343A323239323F433A4F5242575A476163515F5E50535645
4D493312CE0800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF006BC82A8E472E8720279E171C9B1E1C
BB6767D097A0BC7B88B5505DA4131FAE0612A4081E7E13463619690D2488032896012597
02279801289A01289A02269C0226A002259F0127A10129A20129A20128A00129A3022DA8
032DA6052FA108329A143D952C5195546EA08798B89DA9BBADB5BEBCBFC6C1C4C6CACACC
CDCDCDD1D1D1D5D6D5D8DBD9DDDDE0E1DFE3D9D5DBD0CAD2BBB4C0A79FAD8F86967A7382
6C6573675F6D66606A63616866686C6E74728087857F8885798380737E796C757267706D
65696765696463675F64695E65675E66675D66655C67665A63645A5D62565A5E53575C55
5058554553544053544457594B5D605160605663605C685E60675B64675A6A685C756E5F
746D5B74705B746F5C777060797060776E5B746D57756F59776F5A78705C77705D79735F
756F5C746D5A726A55756D58746B58726954766D59756F5C767061736E607370616E6B5C
726D60756D5D716A596D68586D69586D68556E67546E68546E67576C67546A664F69654D
6362506B6C5F595A533A403B29342F28342D2D392E3C4535494E3D5254415E5D4B5C5E49
56533C29A31500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C0713A8D210C9D1E17B24E4D
D89EA2D9B5BDE5C0CBE3A2B0951C2CB10D19AD04119C09276E1752281B7509238F012596
01249801249902269A01259A02269D0127A00229A30128A000269A032899022799072D99
10329326408F4B5C97717BA1868BA19B9CA8A5A5ACA7A8ABB0B0B3BDBCBFC7C4C6C9C4C7
D0CBCFCDCACDCAC9CFC1BFC8B0ADB997919D8B808B80707A77666D7063676E6365716968
6D6C696B6E6C6E7474697474677272636F6B626C6B6169675B645F61665E67695F6A6A5F
6C6A5D6F6C5C6E6B5B6B6B596E6B5C736F5F77715F7A72607871617A75657D7464786E5F
746B5F5E5B54464A4439423D444D4A4854534D5C5857655D60695D6B6F62757168706B5F
706B5D6F6C5A746E5D746E5E766D5D756E5B736E58736F59756E57736C54756E5A756D5B
776D5C756F59736D56746C55786D5A7B705E776F5C706957726B5A746D5E7D7768898576
7D75697165567164546E65566E69596F6958716A577069576C65566E68586A645268634F
6B695A6465594D4D48373C37303C342F3E33314034424F414B53445355445354405A5B45
5D59412EA91B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007769079E2D18B8615E
A77278DAB9C2BE9EAAE1B1C0A34051AB101FB20410AC0619940E35511560161B82022192
02249901249B01259B01269B01269B02259D02249C01239803269208298B163286314386
585F8D7672918A8095928895968E94A0999CA09C9FA5A4A7ACABADBBB7BAB9B3B7B3ADB2
A9A1A8978F98837C88706773675D64655A5B75676183736983766A7D766B75736972756E
66706C6472715B6B6C54636457605E58605A5C615960635969695E6F6C5F736D5F726F5E
7877658B8B7AA8A59AC2C1BAD1CFC9D3D1C8D5CFC7CCC1B7BCAEA4B6A79AB2A193AC9888
A18E7F9181767E7466645F515A594E484C424651484E5E5458635A64675F7170687D7B70
767568686655736C5E766F60756C5B736C5A716C56706C56746B56766B57756958756858
756856756A56756D57756F56766E59716956776F5C746C58706956726B58756D5E746D61
7A7064796D5E786B5B776C5C777060726C5C716A5A70695970685B6F695A696454666554
64665B52554D41423B3B3F363842363A4737404E404855494D574D5961545F6251555540
5A573E2FAA1B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002CD506A04924CF8C85
E9BFC4EACCD5E1BECBF9C6D6AF475CAC1022B40512B30512A5071F78134A2B167108218E
02259702279903289C02269A0124970125940324910925861C33803E4B825D5D82746C84
8173828B7984917F8792818892848995898D9790939B959C9B959C958D93867F82767171
675E5C615451675A566E615A74675B7C6E607F71628076677F7A6B727067686C67586361
5162624C5F60495B5D4E59575F60576966586D6A5A6E6C5B7876678782779E9C8FB8BAAD
CBCEC3DCDBD8DDDADFCFCAD5BDB6C2A79FA8998F938D807F84726F7E6C647E685D7B6457
7865557A69587E6F5C80735F7C73616E6D5A4F5446414D434D59545B625B63665D6B6B5F
7C7C72817F74777367756E60786F5D766C58736E56726D55716952726B53756A58776A57
776854756955756A54746952776A57756B57786F5A756E59736B58706956726958746B5D
766B5F776B5D7C6F607A6D5D776F5E766F5F726D5F726E607772666F695D666154636255
5A5C53494C4342463943483B464C3F4853434D594C4E5A514C57525D6860696D635B5C4A
58543C2DAA1A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051AD19D19287
D9ADB4CBA4B1C88DA1B44E68AC1931B60C1AB7050FB7060FB108168C10393C15650A2089
02269501249401259602239203238C0726821B307D40477C635E7C6F62757D6C7A7F7078
84727889757B8E7A809181879085898D83868780857B72776C636364595662574D696050
7368547C6E597B6C597D6E5981725A84735C7F705D786F606D6B5F62655F555E5D485958
3A4F4D394C4849554E5D61556C695A7B78688D8A7BA7A497B3B2AAB4B3ADA7A5A29A9896
908B8F8781889187908A8187897F838881808A8180887F79847C737B7467695F516B5F4E
6C5E4D6C5C46746044755E417562487A725A6B6C5B4851453847404B59545B625B63675A
6E6F627D7E71858578807C6E76705D746E57747058736E55766B55776C53766D57756C55
766A54756953716753766E59776F5C78715E746C59756D5A756C5A746D5A756E5C746C5B
776B5E776D5E786E607E73657971607570607774667474676E6E63656156665D545C5A4E
4E4E424B4B3D4E4F40515445525848525C4B545F50525C52505C545D68616A7168676858
59553C2EAA1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C48370
B5838AECC1CFE19EB0A42132B60D17BB090FBA060ABF0F13AE0B1987123D3B1869091F88
02249201228E04268D072582182E79333F72525271685E6E74636C7D69707F6D727E6E70
807172857578847579817679756D6E6A6462605A5560564D695C4D796954806F5785765B
83765B7F73597E70577E6F5582735683735881715A776C5A686558595D56495350344441
33433C4553475B6354727466888579949187928D838A847C857C797F7976867E7B877F7C
87807C7F7C777F7D777F7E777F807A7A7D7478777271716B686C665C655D525A5350554C
515249514D3C6F6044856B4B7C5F3E7560426C624D686B5B464D443A464049554E556053
6367596A6C5E7070628481728784737C786477715E79705A756951796C547A6E59736B56
756A57736854746C57756E5A78715F776F5B706A54766F59766C5A76705B746E586D6652
756958766E5D756D5F7773617773637471647471667172686B6C6465655D5E5B51555045
5750445653435C5A48595B4B5E61525962535862575561575D675E6168616A6D656B6859
5E563C2CA71300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A96C4D
DBA8A9E0A6B6B54C61B71B27C71314C60E0EBE0A0CB40D1795102E5E19571E1C7907248E
02248B062581122B742E3A6E4746665F56676A5D666D5F62736565786969796E6D7A706D
796F6B756B686D6460675D5763594E695E4D72664F7E6F5686755A88765988755788755A
84745A8072597F70577F6F558474568272537E6E52776A536B63515555483D433940493E
5B64576A6F617274667E7B6F7A736A7A73697B756A7B776B7C776C828175808176797C73
777A72727A707079716B786F65716A646F67676D67656B64616A6359645C565D56545850
4D4F464B4A3C6D624B8671537E5F3F785B3974624477745C6265573F484037433F47544D
5961536367556B6B5D6F6C5D807E70878575817C6A7E7460786C54776B53776C57746D5A
766E5A766B57776D55746B54746C58746C59726A55756E57786D5A746A57716954746C57
796E5C78705E767160797766787468767468726F656D6F666869645A5A535352475B5649
60594A645D4D63604F67675964685D5C655A58635A5C665E5F655F5F645E696B636E6958
63573830A60F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0090A346
D39A97E092A1A62634C1181BCE1613CE1415BC121B95153261225D2423790A2989082A87
0D297724356B424765524C5B5E555A655A5D695C5F6D5E5F716362706661756C6570685F
665E535F5647675B4772634C7D6C518371558472548573558A785A8E7C5E8A76588B7556
87745881725A7F70597E6E558071528273517E6E4F776B4E71694F5D58435855446E6B5C
7774667571627672617972627774667473666E73677A82768C938A838E87717F7B677875
5F716D5C6C685C6B6557645C5A655B5A62556264586765566665546765536A66556B6558
6F685D726B5D84775F806B4D7D5E3B795A3679624174684B75726064675D4047423A453F
4C554B565E4E66685A6F6E5F7374647777667C7A677873607A725D7B715C776C58746C59
746955796C57796B53746A52746C58746D5A736B55776E56786C567C715D7F7463776E5C
7B6F617A72647975677777697674697372676E6D67656862565A5655564E5B584D655F50
6D6656716A5D6F6A5E6D6C6063675F5B635A5F69615F6A625F66605E645D65665C69614D
614E2840B11400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053AF19
C4796B95343EA61D24C41A17D11815C6171E9F1A3865296721257C0B2B8908297B1D326D
3B42634B4956554E516057576057555F5855645C596C625E6E645D6B6456665D4A665B43
6B5D417769497F6F4C847150867051856F508672548773558874568A775686734F88714E
86725383725A7E715B7C6E557D705387795A8374567C6D5074684B695F43766D537E755F
776E5A716853746E5C6A6A5D565E574F605B576D6B667D7B788B8D657B7E526A6F496062
485C5A505C575B5E566163536666536968526B6752706D557E7B648C877397918490897E
7E776C7C73617E6F577A6547796140836B48826B4A7B684873664E7673626A6C63454E46
444C44757B6F74766A6E6D60726F60726F5C706C586E6C57706B57746D5A7B735E807863
7B6F5C75665076634A76684D726951716953706650766B56786D5B82766880776B7A7366
7B73697771667370666B6C6167685F6868625F5F5C545753565B535F62556A675A716D5F
747162797669747367686C60636A63616C64636D67646F65636B6162655B655F516D5C41
76592627DD0D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D5226D6867CBE5051BD2221C31618AF203675336C292E800C2D84122F76293762454554
544C4D5A524D5C554E605852645C55666057686259625C4F645B476A5D4172613F7D6945
826D4B84704F8673528976568873548A73548972538872538B755687735384714E86734F
8673528573578072597F72587C6F547F70548371558270537361437E6D4F8473567B6A4F
796A50726751535041313832293B392E4946355254365359364E562E474D2D4346384945
4C554B5B5E4E656452706F5B7B7B68969684ADAFA0BCC1B5BFC0B8AEAAA59A908D837872
7B6D617B6A557F6B51877558806C4F7D67467A623D785D36745E3A7164497A7A686A7164
4E544B5D5E52706B5E756F5E756C59786D56766C55726A536E63506C614E706551756D58
8277657D6F5B77624874624473664B746952766C587B72617F74677B70647971647B7569
76746974756B72736A64675D575B53555853585B575F625B62655A686B5D6F6F63767669
7A7A6D7476686E71636A71636B74696C756D696F69686F63686B606561526E60486E5429
70932200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
23D003A6593DD47471AF2123B724328D386838348514368A1B336E3D415C50474B544A41
5F554A625A50635B50645D506E65576B634F695E486B5A4275603F79633B806840826A43
886F4D856E4F8573568A795F8373578473558573548B77588B7454887152846F4F887452
84714D83704E837051806F52807052816F50806B4D826D4F7C67498872537E69477C6846
807155655C454443333C413736413931443C2F443C2C403B2A3C392D3E3947534B656C5E
8284769E9F94B5B6ADBFC1B8BABCB7A6ABA58C918C7A7E7B716E6F74706E78716D7E756B
8275668878668B79658E7C63816B50745F3F785F3B795F34775D31705D36756A4E6C6C5A
7070675E5A4E706657756C55766A4F74654776644977664C77664F6B5C46756A53756E56
776E5B7E746082705977664A796C537971597C74607B7362746C5C716B596F67596F685C
6261555D6357575D53535A535159535A6259646B60686F616F766674776A7E7E737E7E73
76776C71746671746973776B72766D6C736A6B6E656A6B5F6C6B5B6A62496F5830678C1F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00807F1CA3321EA31A1BA134565A3C851E378D2036713F404F5B4D435D4D3A5A4D39
605843675E4C6D63536D62516B5F486D5E4075614078603E7A613B7B623A806845866D4C
886F4F87705289755888785B847558847657847655857252867154887356937E61897254
836B4B866E4D866E4C86704E806D4B7D6A4A7E6C4D816F53826D50856D4C7D663E7D6A44
827457787059716C5776705D7E7A69909382A5AA9CB4BAAFCBD2CCD7DCDACED1D0C9CAC7
B7B6B4A6A3A38A85897670706C68686D6E68787A71909389A8A7A29F9E9A84857F727268
716C5E8278678274649485729F907CB5AA9690826D7D6948796137735D30705E366F6446
6C68556A665471665075654775634077633E725D3C6F5A3F77654C76664C6C5F46787158
78725D79725F86776584745E7F705B776B567468536D614D675E49655F48605A485C594C
53574B4C594D525D5656625B5C686366716770776C727A6B797F717B7E757A7D74797B71
757770777A71787A7173766B6E71676F71676D6B616E685A756952735F37658C2000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009F390A91211E8545753B3D8A293A793F3C51594A3966513365503368563C
6F614772654C6E6049706046756345746340786542806B4A806C4A826E4C877352847251
8572538875568C7A5C8A795B87785A8B7C608473558370508670518D76568B7453866D4C
866E4A876F48867046836E44836F47816E4B7F6D4E7F6F5488775B8672508069417F6841
7C694B7B6C527B6D557F715980715B8C7F6D9A8E84ACA3A2BDB6BEB0A8B68F8894777277
7068686D645E786F647B7164756E6167685B929288BABCB2CBC9C4B5B0AC9B968F8F877D
7D73647D715E877A67877D6A8D8677BEBCB69D97958A7E718772547D66417761386F5B37
6C62457B745B70624677613D7B633A78603779603C745E3F6D5B3E76674873654B786E59
8076667D72628172607C6B5375644C71634B6C5F45655B41635E455F5E4A5B5E4F555C52
525F57586962596B656070696B7871737E76787F76787E73797F75797F76797E77767B74
797E78787D76777A707174676F6F63716F626E685974664F7B623A6A922400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ED608883825714C723F3F743B37505341366A53346D5631715A39776344
7766467164446D624277694A7B6A4B7C6C4B7C6C4B7F6F5083735684735784735786775C
89795F88755B8D795C88745593806088755886735486705188705088714C877049886F4A
836945846C43826B42826B41856D437F67417D68467D6D4C8070528A795A877150836B46
8068447D67457A6442755F3C77603F7D67497E6752816B607F6A667B6967766967706C67
82807B7C7B6F827C6B867A667C6E59837A648A816E8E8476968A7F968A7D9488778F8370
887A67827560877864857967857D6F847E77877F7A877C728E7F6A8E7B5E826D4B735B38
726142776A4F7564457C66437C633E79623A8068447A66466C5D3F77694C7667517A6D5C
8173667F71617F6D5977664C7162486A62466961476360486060515D64585F696057665D
59686261716E6A78776B7A7774807C78837B77817A7981797A81797B81797D807B7C7E77
777B7273776D74756B7371656F695C71685478684C7E633672962900FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0076892C6E4F524635424F3930644B2E7259327961397D65407B6643
786746685E3F6E674B766A4F7B6B4D7E6D4C7F6C4A7F6E4E81705484735A86755D82745D
82745B8A795E8B795C8D7A5C8D7A5D85745886745790795A876F4C846D44866E45866B45
846843876B44846B4285684084673E85693E7F663B7661367766408170509380628B7354
8B704F836845826741856A41856941856D44846C448269487E674C7A6A564B493E4B5552
838F8D868C88979589958B778C7C668A7B6491806992826B93836D94866E93846D8C7C65
8B7965897A638778628A7D6B877D6D867E728C82778E81728A7A68837358776343735E37
73613C7464457B6A4E8170537F6E4F806F508473567E7058796D557B6F587D705C7E7564
7E73637E715F7A6B577167516B66516A69566A6A5B666C5F6A716C6A75706B76736F7D79
6C79756D7B7772818072807F74817F79847F7A838178817C7F857F81867F80827B7C7C77
7D7C737B7A6E787569786F617B6B577E664789673650BB1B00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0F653C1B50341E5D412371552F7F633B8269407F67407E6A49
6F6247655E496A665075694F7C69497C67427F68428068447D6744836D4E837057817358
8274598475598B7C628C7C6084735585735585704F866F4C836A4482693F846B41846B45
876D48866E46826A3F836A3D83683B856A3C84693A7D6435775F3278633A846F4D90785C
8E7457917556896C4982663E856942846B41826A3D7F693C7E6943776A4D65685822322B
475654969B9BA8A29F978C80887A6A83725E86735B88775E8C7B648B7C65907E69907E69
8F7D698E816C897E6C857C6C857D708881748B82758B7F6F8B7A677E694E745E3B7C6A43
8776517C69487E6E537F735B817861897F69877E6A817A67827A67857C67857D697E7865
827C6B827D6D817C6E7A7A6C7C7D73757A72747D78707D78747F7A7F8A877F8989818C8D
7F8A897D88857785837383827A8888808C8B80888983888784868380827D7C7D787C7D77
807E787B756A7E72617E6C5084643C6E8F272ADE0F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00653D085B3B13674B227E6337856A407D663F6F5C3C63573D
6F6A585B5C4D6768556C634A7562427A633B7D633A7E623A7E633B7F66427A6748817156
8375597D705484765B87785E8775588771538169487F6841806A40836C42816A41846D47
846D4A826A44836C42856D41826A3C866E40836B3C876A3C8366377D63367D653F7F6A4D
8C775E8772558B7252876F497E643C7C61357C61327B63337B653B73674571715B828A7D
9EA49EEBE9E8AFA6A7877A7094826E9B83699C83649A846494816897826AA08770A28C73
95846F89806E8D86798E8B7F7F7B6F888478847D6F7E72617767517D6C508E7C5D948564
918363807152867860877E6B8A82708C85738B8676878371857B68887D678B826E8C8676
918E8190908492928B8A8B868B8F8D8A8E8F848C8E859191859190899495889294899294
83898B89939284908E7F8E8B808D8A828E8C83898C8285848385827A7C797979747A7871
7A756A7B6F5E7E65488A683650B91B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006B470F67481A7D5F3185693B80683D6959354C422B444030
5052445E64556269586F705C6F674D736344735F3C7A63417C66437D6A497A694B7C6E53
82745B80735986775C857458847154846F50816B467F6A407E6B407F6C44836F48836E4A
86714F856F4A867047886F45866C3E856C3C856B3A866A3A8569398367397C60387A6341
7A6648826F538D7A5B8C77548C724D8164397A5C2C795E2C795F3176643D72684B827D6E
8A878093908C8C827F8B7A68AF9375BC9B7AB99674BA9C7DAE967BAF977EBA9F84B89D84
9B8675877C6F888075857F737C7467756C5C74685482735A9282678F806386765B85775C
887C618E8769978F79938C7C90897A8B8475837E6E898370968E7AA79D8AB1A89AA9A397
A7A49BADACA5ADADA9A0A2A1969A9D9CA0A39A9EA1979EA1939A9D8C9596949E9F919C9D
92989A929B9A8E9797848F8D838E8D7D86867D85827D827D7C7E797777727A766C7E7461
7C6B4C846A3B72942700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0020D404704B157D5C2C89683884683B70613A59553A494839424438
3E4539445042576355656F626F7263706C5B746A55776B53786C517B6F557B6F567B6E56
7E705980735B82755A837157826D50816E4D806C46816B43867049866F4D846F4D857250
85735086714E89734E876D44866B3E84693B886D3F85693B896C3F85673A84683C7E663D
7B67407F6D4881714F8272518C77578F775181673C7E62347B613278633772613E766A52
80796A7F7C70847C6D9B8970C8A88AC8A485C7A489C2A68DB6A08AB09985B09682A98F7A
8D78677F70618174647C705B80715A83745B887D61887F648379628279618B806A958C76
99947C9390788C8777847D718B877A999789B0B0A2BEBFB1BDBDB0BBB8ADC2BCB5BFB9B5
B5B4B0BABAB8B5B5B5AEB2B2ADB1B4A4A8ABA7A8ADA1A5A8A4A8AB9CA4A7969FA399A4A6
97A0A28E989886908F838C8A7F87867D8383797E7A7B7D777C7A737C75667E6D5382683B
6F95272ADF0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA5067C531C89673388693B7A643E6A6248595C4B50574C4A5248
444E443F4B3E455245525D54676F6774776E7672687974647A776278745E76705B776E59
7B735D7A6F5A7E715B7F7057827055826F517D6A487F6B47856E4D856E4F8A76568C7859
88755387755387735287714C876F46866F44836C41876F44866D43876E45836B43836C44
836D4784714F8474538070518675589686679786648B78538470487C693E75623971613D
74654B776D567066507A6950987F669C816999816C94806D8574647F705E86736185735F
8373608779648578637F755E827861857C678C847096927E9C99859D9A8495907F8D8D7B
979985A0A591ACB1A4C0C3BBC5C7C3C8C9C5C8CCC7C2C6C1C5C7C4C3C3C1C4C3C2C7C5C4
C2C2C2BDBFC0B4B9BBAFB6B6ACB6B5ADB4B4B2B7BAA7ACB0ABAFB4A3ACAE979FA4919A9D
8B9396848D8E8088867C868078807E787C7978766F7E76677D6C558266426F942D28DE0E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA504875C218E6B3783683D72664868685660685C5C675D536056
535F554E5A4E49554948534A4D585260696380877F898F847B8173737668757466726E5E
75725F7B75627D745F796F5A776D567C6F567F715583725686735789775A8A785C87765A
87765A8574598574588675578674538876548877548979568979578979588B7C5D8C7F5F
8E7E618E7E628C7C6089795D85755B86775D8F80689589709B8F739A8F6F9488648E7F5B
9080608275567F7558807659887A608E7E6693836F95897598907DA59E88B6AC97BBB19C
B7AC98B2A994B1A997AEA898A8A394A19E919D9B8EA1A393ACAE9EBBBFAFC9CBC0D7DDD1
E0E7DCE0E7DDD7DDDACCD1D0CDD2D5C6CDCEC3CCCCBFC7C6C5CACCC3C6C8C7C9CCC3C5C8
C3C6C8BDC1C2BEC3C3BDC4C4BBC4C4B8BFC2ADB4B8A7AEB4A1A6AC969CA28E94998C9095
868A8E8183867878787579747979727972657A674E85673F7596302BDF1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0043A80593692A8E6D3A78633D79745E6B6F63687167657366606E63
616E645C695D55635655615855605956615C5A656263706C87948D8A938D7A7F78777B6F
797B6D8080707B79697A78667E7C69807B67867E68867D688A80698D836B8A80688E836A
8D846D8B836C8A836A8B83698E866B8E866C91896F90886D8C84698F876D938B71918B71
958E75988E769A8C7695887091846D8A7D67867863847961837860867E648A83698E876C
938A6F958E7299947B9C97809D9780A09783A49C8BA4A08CA2A18FA9A696B2ADA1BAB4AB
BFB7AFB8B1A8C1BEB6CFCFC8DDDDD7E9EAE3F2F3EDF9FBF6FCFDF9F6F8F4ECEFECE8EDEC
DFE6E6D9DFE0D3D7DBD2D4D9CCD0D4C6CFD1C5CED0C5CDCFC3CBCEC7D0D1D1D8DACED2D6
CBCED3C6CACEC6CECEB9C3C4B2BCBEABB6B9A4ADB19AA3A8979EA195999D8B8E92898A8E
8180837D78797F746E7B6D5C78634688693E4AB71D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AAF09956A2982613279674A82817170756E6A746C69766C6B796F
6D797069766D68746C68746F6A767163716C61706D60716E6471706A7674707C77858E88
8C948C8D938B888B82858A7E8B8F838C8D808889798786758785738987748A89778E8B7A
9591809493809595819A9A849D9B849B9884979681928F7A8D8A7289856D918C75939079
9B98819A978296907D9A947F9E98849F9B86A19D889F9B849E9B84A29F8498957B98967C
99937D98947E9A96819E9D89A3A38FB1B09FC3C1B4CDD0BFDEE0D3EBEBE2F5F5F0FAFAF8
FFFCFCFFFDFDFFFDFDFEFEFDFEFEFDFEFEFCFEFEFDFEFEFEFEFEFEF7F8FAEAEDEEE9ECEE
E0E4E6E3E8E8E0E2E5E2E3E6E2E4E6E1E7E8E1E7E7E3E8E8DEE3E6D5DCDFD7DEE1D1D8DE
CACED6BDC3C9BCC3C7B3BBBDACB3B8A3AEB1A0A8AA99A2A4969C9F8F9293858382807975
7C6F667968528265426D922E54BE2100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0029DA079C6C298564347F71537B7E6F7A857C6F7D766A79706A7972
717E7775807C767F7D7882817986847686847181807C8B8A7C87877C87837B8784778582
7C89867E8B8986928E97A29C9DA6A09EA49CA3A89FA6A99EAAAC9F9B9F929AA0939A9D92
9EA0959DA0929FA594B4B9A7C2C4B6BEC0B3BBBFB2BCBFB1B7B9A8B3B6A5ADAF9FB5B8A8
B9BDAEC2C5B6BCBEAFC1C3B4B9BAAAB7B7A7BEBFB0B9BCABBFC4B1C6CBB6C8CAB8CDCFBD
D5D4C8DFE0D3E9E8DEEEF0E5F4F5EDFDFEF8FEFEFAFDFFFBFEFFFBFEFEFCFEFEFDFEFEFC
FEFEFEFEFEFEFFFFFFFEFEFEFEFDFDFEFEFCFDFFFEFCFEFDFEFEFEFDFDFDFAFAFAFBFCFC
FCFDFDFDFEFEFEFEFEFEFEFEFDFEFDF8F9FBEEF0F3EBECF0E2E5EBDADDE2D3D6DDC8CFD5
C2C9D0BBC2C7B4B9BDACB1B7A9ADB2A2A8AB9FA3A69598998F8C8C857D767969587B6143
916D3F4EBA202BDF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF009E671F845F2C7D7151777B6A758076717E7874817D727F7D
7681807882827A8385818B8C838E8F8996968593938894958995968E9B99919D9B8B9996
92A1A091A1A28F9E9F9AA8A8A7B3B3AEB9B8B9C3C1C5CEC9CED4CEDCE3DBDAE0D8E1E6E0
E0E4DDD7DCD3D2DACFC9D2C7C6CEC5C4C9C4C3CCC5C7D0C9C6CEC5C5CCC3C7CEC5CAD1CA
CBD1C9D1D8CFD3D9D1D9DED6E0E3DAE2E6DDE7ECE5ECF1E9F2F5F0F6F9F1FBFCF5FDFEF9
FDFEFAFDFEFAFEFEFDFDFEFAFDFDFCFEFEFEFDFDFDFDFEFEFEFDFDFEFEFEFEFDFEFDFDFD
FEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFFFEFE
FEFEFFFEFEFEFDFEFEFEFEFCFBFBFBF5F5F8EBECF0E3E7EADEE1E7D7DADFD2D3D8C8CDD0
C1C6CABABEC1B6B8BCABADB1A5A7A9A3A3A296928C83796B79644C8B6D444BB8202CE011
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DB098F64287A63407F7D6B78817772807775857E778782
7B8987838F8F828D8C8A94938D98988E9B9C8D9C9C909E9E92A0A097A5A499A7A49FABAB
A0AEAF9BAAAE96A5A8A5B2B4B6C1C3B9C4C5C2CCCBCBD4D4CFD8D7DBE3E0DDE3E1E3E9E9
E5EBEAE8EFEBE7EEEBE3ECE9E6EDECE4ECE9E3ECE9E7F1EEE8F3EFE7F1ECE5ECE9EBF1F0
ECF1F1F4F9F6F0F4F4F2F6F4F5FAF9F3F5F3FAFCFCFBFDFBFEFEFEFEFEFDFFFDFDFEFEFD
FFFFFDFFFFFFFEFEFEFEFEFEFDFEFDFEFEFEFEFEFEFEFEFEFDFEFEFEFEFDFFFFFFFEFEFD
FEFEFEFDFDFDFFFDFEFDFDFDFBFBFBF8F8F8F9F9F9FAFAFAFBFBFBFCFCFCFEFEFEFFFFFF
FEFEFEFEFEFEFDFEFEF9FBFBF1F2F4EDF0F1E8ECEDE3E7E9E2E5E8DCDFE1D4D5D8CBD1D3
C2C6C9C3C4C5B9B4B49D9692877A6D846F578E6F49779A3558C12500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00748F1B8361307C6C527677686F7A6F79887E788881
7F8F8984939085929294A0A095A0A198A5A595A4A49AAAA99BAAA9A2AFADA6B1B0A9B3B4
ABB6B89DA9AB99A5A8A1ADAFB0BCBCBFCACAC6D1D1D1DCDDDCE6E6E0E8E9E2E8E9DFE8E7
E3ECEBE9F0F0E6EDEEEBF1F3E9EFF0E8EDEFECF1F3EDF3F4EBF4F3E9F1F3E9EFF1EDF3F4
F1F5F7F2F6F7F3F5F7F4F8F8F6F9FAF5F8F7F8F9FBF7FAFAF9F9FBFAFBFCFBFCFDFCFFFF
FBFBFCFAFCFCFBFCFDF9F9FAF9F9FBF9F9FAFAFAFCF7F8FAF8F8FAF9FAFCF6F7F9F5F6F8
F4F4F6F1F3F2F4F4F4F4F4F6F3F4F6F7F9F8F8F8F8FBFBF9FCFCFCFDFDFDFDFDFDFAFAFA
F9F9F9F7F8F8F5F6F8F2F3F5ECEDEFEDF0F1E9ECEDE7ECEDE1E6E8DFE0E1D7D2D6C6C0C2
ACA2A195847993775E9A764C4DBB242BE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00718D1E816135786C537A7D6D7D857C7A847F
828E8884938F8696948F9E9E98A6A69EACAC98A7A6A5B3B4AFBABCAEB9BBAFBABBBBC6C6
BFC9CABFC9CABAC5C2C0C9C9C6CFD0CDD7D8D6E0E2E2EBEDE5EDEFECF1F5E7ECF0E7EEF0
E4EEEFE7F1F3E6EEF2E5ECF1E7EFF2E8EFF3E9EEF3E5ECEEE8F1F3E5EEF1E5EDF0E5EEF0
E6EEF1E1E9EBE6EDF0E2EBEDE5ECEFE6ECEEE6E8ECE8ECEFEAEEF2E7ECEFECF0F4E4E8EC
DFE4E7E1E6E9E2E6EAE6E8EDE0E0E4E6E8ECE6E9ECE8ECEFEAEEF1EEF3F3F0F3F5F2F3F5
F9F9FBF7F7F7FAFAFAF5F5F5F9F9F9FCFCFEF5F5F5F8F8F8F6F6F6F7F7F7F6F6F8F7F7F9
F7F6F8F3F4F4F2F5F4F5F6F6F2F1F3F0EDF0F1EEF0E0DADDCDC7C5B5A8A1A1887E9A7A65
A47C5955C02B2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00708D1C8161337F71557D7C6B7F837A
8790898996928998968B999993A1A297A6A79AA8A9A5B0B3ABB5B9B4C0C3B6C4C6C6D0D3
C7CFD2C7CFD2C6CFD0C3CDCEC3CDCFC2CDCFC6D0D2C9D3D6CAD4D9CBD4DAC9D0D8CAD3DA
C8D5D9CAD7DDCCD7DDCED8DED0D9DECED7DCD1D9DCD1DCDED2DDE1D1DBE0D5DEE3D3DDE2
D0DCDDCFDADCD1DBDDD3DDDFD3DDDFD8DFE2D9DDE0DEE1E6D9DEE2D7DDE1E0E2E7E0E2E7
DAE0E3DDE5E7DCE1E4E2E7EAE3E7E9E4EAEAE6EBEEEBF0F3EAEFF2EFF5F5F2F6F7F3F4F6
F5F5F7F5F6F8F3F4F6F0F1F3F2F3F5F4F5F7F2F2F4F4F5F7F5F6F8F5F5F5F5F5F7F8F7FA
F8F7FAF8F5F6F7F2F3EFE6E8DCCED2C3B1B1B19A94A58778A9856684A5465BC32D30E215
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D90B88612B81674481755F
87847A8D938E7D8683848F8D8D9A9998A5A39EA9A8A2ACAD97A2A4B1BFC1B1BCC2B7C1C8
BEC8CBC0C9CDC4CCD1C1CBCEC1CCCFBFCACDC4D2D3C5D3D5BDCBCEC5D0D4C5CDD2C8CFD4
C6CFD4C5CFD5C6CFD4C5CFD2C6D0D1C1CBCCC7D2D3C9D5D5C9D6D7D0DADCD2DADDCDD7D8
D2DCDDD0DADBD5DDE0D7DFE1DBE3E5DEE4E7DCE1E4E0E5E9E1E6EAD9E0E2DFE3E6DEE3E6
DCE3E6DDE7E8E2E9E8E2E7E8E2E6E9E3E7E8E6EBECE8EEEEE8ECEFEAECF0ECEDF1EDEEF0
F0F1F3EEF1F0EDEEF0EBEDEFF2F3F5F4F4F6F3F3F5F8F9F8F6F5F6FCF7F9F8F1F3EBE1E4
D6CAC9C5B1ABB69A8FAC8879B3866EB889615DC53230E31700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B112876431
806C4C89806C8584767E8279858C8698A19C9FA8A5A2ABABA6B0B2ADB8BAADB8BBAFBABD
B3BEC0B6BFC2BBC5C9B5BFC3B7C1C4BDC7C9C3CED0C4CFD2C2CDD1C3CED2C5D0D2C9D2D4
C7D0D2CAD3D7C4D0D2C5D1D2CBD5D7C3CDCEC5CFD0CAD7D7CAD8D9CDD9DAD0D9DBCDD5D8
CCD5D8CCD5D8D0D6DAD2D7DAD2DADCD7DCE0D8DDE0D7DCDFD7DCDFD6DEDDDADEE1DBE1E3
D9E2E3D7E0DFDBE1E1DBE1E1DBE0E3E1E5E8E0E3E6E4E7E9E5E8EBE9EAEEE9EAECEDEEF0
EEEEF0EDEFF0F6F5F8F8F5F6FAF6F8F6F0F0EBE2E3DCCFCDCCBAB7BCA39AB69385B38A74
BA8D688FAB4A5FC52E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB517906B35866C4487785A897F6B918C7D9A9A90A4A49FA9ABA9A9AFB0B0B9B8ACB6B5
B2BCBCB1BCBBB6C1C2B7C5C6B3BFC0B9C4C5B9C4C6BCC6CABFC8CDC0CACDC4CDD0C1C9CE
C2CCCEC0CCCFBFCDD0BFCBCDC4CED0C0C9CBBDC6C9BEC8CABFCBCCC0CDCEC5CFD0C5CED0
C8D0D2C7CFD1C9D1D3C7CFD1CCD4D6CCD4D6D0D6D8D1D8DBD4D8DBD7D9DCDADBDCD7DAD9
D4D9D9D4DAD7D8DDDCD7DEDDD6D8DBD8D7DBDAD8DCDFDDDFE7E4E8EEEBEDF0EDEDF3EEED
EBE2E0DFD4D0D3C1BDC8B0A8C0A397B29380B59075B78D688BA9485EC63031E31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADF0E48B518906C358C6E448A7152907C66998A7BA79F93B0AEA4ACADA7
B0B3AEB4B9B5BCC1BFBAC1C0B3BCBBB3BBBBB6BCBDBFC5C7BEC6C8C3CBCDC1C7C9C0C4C6
C5CDCDBEC9CABBC8C8BDC8C8BEC8C8C0C8CABDC3C7BCC3C6BDC6C8C2CBCBC6CFCEC7CECE
C7CDD0C7CED1C9CDCFC9D1D0CDD2D4D1D6D5D1D4D3D4D8D7D6D8D8D7D8D9DADAD9DEDEDB
DFDEDCDCDBD7DFDCD8DEDAD7DFD6D4DACFCAD0C1BCC6B5B0C5B1AABCA498B29888B39582
B28D72B68C668BA9495EC73162C93031E31600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002BDF0F4DB61C47B31E95724390754F8C755A
907E689787759F9082AA9E94B3AAA1BCB4AEBBB4AFC4BEB9C0BDB9C9C6C6C8C4C4CBC8C6
CCCAC8C4C6C3C6C9C5C8CCC8CCCECBC6C9C7C4C5C6C6C4C5C9C7C6C9C7C5CCC9C7D1CFCD
D1CFCED8D4D4D7D2D1D5D1CDD2CFCBD5D2CCD7CECAD7CDC7CABFB7C4B9AFBFB1A9BAA89F
B8A195AE9584AA8E78A98C70AC8A6BB18B67B5885E88A7465DC6325FC82F61C82C31E416
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
56BF234FBA204AB61F47B4219D754A98754F95745293765695785F987B669C816D9F8470
A28977A08978A48E7BA48E7AA4907DA69280A5917FA8917FAA927EA78E7AA68D7AA38876
A38774A48771A98971A7866BA48568A0805FA3815FAB8660AE875981A33F55C02C59C32D
5EC62E2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0106283 0.97619 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF800000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 178.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooolR
003o000F01O`2@0]h140;^0A04C@6P1L`2<0M;<_08bS=P2bSdD0^hQ:0;f7C02mQdd0_HI<0;V5B`2F
W3/0Rj@f08ZT=P2;YCP0RjHh05g49`0^hA80;n8C02oR52000?l02@3ooolR003o000302S8?01@T7P0
D91h0080D91h00<0N5Rd0:0Pl02P8?002P2P8?04052@N2000?l0c@3oool000X0oooo7P00o`005@0F
k`T0F;lR08:M<@2]OT40[7e20:mm@P2cP4D0/X570;:0B02dPDd0]7m90;R0A`2fPT/0]H1<0;N1B`2h
Q4h0]85<0;B1B02ePDL0[ga00;:0A@020:mmA0070:]i?P2]O3d0[W`n0;60@P2aPdD0K[4]02cP4P0L
003o00T0oooo7P00o`000`1@T7P0X23`0:0Pl00K0:0Pl1`00?l0c@3oool000X0oooo6000o`00:@0R
j0h0EkdP05Jm8@21WC@0Oide08fE>`2bOdX0]H9>0;R4E02lQEH0`XEI0<^7G03?Qel0chEL0=>2F`3D
Oe`0eg]J0=QfE@3FME@0eG9C0=IdE@3EMEL0eGQJ0=AlG03>OEX0agmI0;V0F`2fQUl0]8MK0:n2DP2/
Odh0[Wm<0:QjAP2UN3h0YgHk0:Ug>P27Sbh0OYX[09B:<`1eXbL0:mh>01L00?l02@3ooolH003o00<0
D91h3@2P8?080=1@N100X23`00<0D91h003o0000o`005@00o`3=0?ooo`002P3ooolE003o000C02[M
4@1D^b80R90e0:eiA@2cNd/0^GeC0<ImF@39ME@0cFY=0=9NA`3GD3h0fDLi0=Pm;P3I<RD0g2dR0=hZ
7P3O9QT0hB@E0=lQ50020>8N5P0I0><O5`3T7Q@0hQ`B0>HQ5P3Q7A@0gA`D0=LM50306A80TPd;08XF
4P2:71D0SRPP08le:P2C@S@0UU0m09eSB@2YMUD0[7iF0:MkC`2VND@0XGDi0:9b=02ULc<0KihO052h
5@0E003o00T0oooo5@00o`02052@N0D0X23`0`3@D7P00`3XJ3`0oh000?n0000F0?n000<0d51h1`2P
8?000`1@T7P00?l0003o000C003o0<d0oooo000:0?oooa800?l00380:Md?05>k802=Qc/0ZGQ:0;5g
C`30MeH0bV]?0<aI@`33?2d0b2DJ0<hN503E6A80gAPC0>@H4@3V5`h0jAXC0>XJ4P3[6Q00lAhB0>lN
4P3d8AH0lb0D0?@O503f81H0lQhD0?@O503d81<0m1lC0?<N4`3b7A80k1`A0<`>2@2Y0PD0Y@<70:01
1P2L10P0U0<708l42P281@T0N@L906l=3@1b6QH0PSP^0:5ZD@2ZO5T0Z7U@0:=b?P2JJBh0UVDT07NB
71@00?l02@3ooolB003o00H0X23`00<0d51h0?n0003oP0008P3oP0000`3@D7P0X23`0:0Pl0040:0P
l1@00?l0c@3oool000X0oooo4000o`00=`0;m`D0Dk`S09F;@@2bNU<0^FU;0;e<>031>B`0aBPO0</I
4P3A4Ph0ea8?0>0C3P3S5100iAHA0>DE4@3X6140jQL@0>hK503a7Q@0lQhC0?@P503d8AD0m24F0?HS
5P3j9AT0nbHJ0?XU5`3l9aL0mb8C0?XT503g8Q@0mB0B0?0N4`392@L0]`H70;D72@2/0@H0Z`@90:@2
202R0PT0W@4609H32@2:0PX0P@8807`52@1d20/0La4A07dU7P24?bd0SeLg09]W?`2LJS<0QGXO04V`
2P0]b`<04@00o`090?oooa000?l000H0:<Pl07QH]02P8?00X23`0=1@N03XJ3`Z0?n000030>QX?03@
D7P0d51h0080X23`0P1@T7PA003o0<d0oooo000:0?ooo``00?l003h02_L3052i6P1mVC80VhU00;Ia
B`2gDSX0/SLX0:TK50314a00d0h<0=D=3`3J3Q00gPh=0>8A3`3S4`l0g0h=0=L:2`3G2PX0e`T;0=/<
2`3T4`h0lAdD0?XR603j91L0nbDG0?XV6@3m:Q/0oB/K0?h/7@3n;Q/0oR`K0?`X5`3l9AD0nb<D0?XS
503i8Q<0kQdC0<<60P302PT0`PX;0;P5202a10T0[`@90:`31`2X0PL0Y08609L11`2?0@T0R`8708T1
1`280PL0Q@8808032@1i1PT0K`T907HM5024AB/0UF4g09AQ:`1[H@/0?ZD401?[0`h00?l02@3oool<
003o000602S8?01hF;@0X23`0:0Pl02h>;@0d51h<P3oP0020=1@N080X23`00<0D91h02S8?000o`00
3@00o`3=0?ooo`002P3oool;003o001001G_2026Tc40/8E00;M]=02`;aX0^AP?0<H>2`392PX0c`/<
0=@=2`3H40`0f@l=0>0@4@3X5A40jaL?0>DC2`3D1`H0d`L80=D92P3J2`/0g@h:0=h>2@3Z5Pl0nbPL
0?Ha803c=R<0lSh]0?55<`3bBcP0mS/[0?ha7`3o<1`0oRdK0?hY6@3m9aP0o2@F0?LU503P7a80^@D5
0;l=302n2`d0/`P<0:T4202[1@T0ZP@80:L22@2W0`P0X@<809/2202D0PH0RP4508`21`280PL0Q086
08P420240`P0OP<907X52`1a1`L0MAdC08M;:02;FBP0M5D@03V`0`d00?l02@3oool;003o0004052@
N02P8?00X23`0:0Pl3P0oh0000@0d51h0:0Pl02P8?00N5Rd3@00o`3=0?ooo`002P3oool9003o0013
02GG0P2;PB80ZWU20;N7>038Vad0aVHB0;L@0@3120L0a`T80<`92@3E30`0g14>0=<@303[;b`0fA4>
0>TF403]6@l0l1`A0=l?203J2`P0f@/80=X=2@3M3`P0h1080?8O4`3L8QP0jW]/0?faY03oa[`0om?9
0?oHc@3`NFd0o3@P0?d_603n;1T0oRTK0?hW6@3j:1P0gSh/0==HBP2/5a40^Q<@0;@;3@2V1PX0V`@8
09`5202T1@L0Y@860:@21`2J0@D0T`0409H31P250@D0Q00508<11@1g0080NP0207L00`1f0@D0N`45
07d11P1n10/0K0T506`Q3`2BG3L0ND<@04>U0`0<003o00T0oooo2@00o`000`1@T7P0X23`0:0Pl003
0:0Pl3X0oh0000<0d51h0:0Pl02P8?003000o`3=0?ooo`002P3oool8003o001603W73@2:ORh0YEHf
09Pd5033O1H0dJ<60<QY302j4`<0`@P70<T;203A30T0e`d<0=/?3P3:3@`0ebLU0=LC3P3/6Pl0kQ/=
0?4M403]7100kR0E0>LM4P3I5`d0iAlC0?4U5`3j:Q`0eBDM09eJE@3kk>T0n?3_0?Scl@3il^l0lZjY
0?Hg9@3m;aT0obdH0?hZ603m:AP0i2/K0;mdJ03lgmL0i:NM0<eYH02[;BP0UALA08TE3`216a<0XcD/
0:/S802Q1@X0W0890982202<0@D0R08508L110290PH0PP8407l1101j0@@0M@4307T11@1o0PL0P@<8
07d3201b1@L0H@l807Tl8@1nAA@0C8L201cP0`X00?l02@3oool8003o0004052@N02P8?00d51h0=1@
N0<0X23`>`3oP000103XJ3`0X23`0:0Pl00Xb3`:003o0<d0oooo000:0?ooo`H00?l004T04n`407V6
:@1nCRh0L2<E09/=2@2/4@<0bgHB0=6U1034K@`0]a@20<<:1`3>2`T0e0`90=/?3@3N4@d0gaHA0>@O
6@3Y6A00jaT>0>PL403H8QD0fU530>MiK`3^TXH0mJZN0?J[W`3dX9@0lX]o0>AYGP20>380hM7=0?Od
l`3dlo40m?;a0?_Jf@3/@SL0oC4N0?`_703c<Al0ec<S0<MXF@3fi]l0m??b0?GclP3hl>h0k]G>0>70
]03L_:h0f[RZ0<>9OP2@8B00U`<:09H12@2@0@P0S`4808/11P280@D0R`4708T11`230@H0OP4507l2
1`210PL0PP4708D22@250PX0MP4406@10@1K0`40H1X<07Pl6@1eC@T07=l200T00?l02@3oool6003o
000302S8?02P8?00d51h00<0oh000`2P8?0U0?n000<0d51h5@3oP0000`3@D7P0X23`02S8?009003o
0<d0oooo000:0?ooo`H00?l004T0Q7dW05Xa6@101`80F08409X72@2a40@0bVlB0=FY103>MPh0_AL3
0<`=2@3@2`T0eP`:0=/?2`3L3Ph0ga<=0=lB2@3V5`d0hQT?0<8P5@36I5X0o]gG0?[]j03hl>/0m_7_
0?Kbl03ilO00nNg[0?kZi@3hh=P0knKP0?Cbl03cknh0l_3^0?W[j03OHEL0icl`0=Y2=03@HUD0jjnV
0?k[i03elo40l_?c0?7bl@3_ko00iN3N0>KJf@3WeLl0[Wmf06lB402=1P/0W@<:09/3202E0@P0UP89
08`2202>0`X0S@4808`120270@L0P04607/11@1g0@<0N`44080120210`P0N`8506P0001P0@40F082
0506001e=aH0CH@100T00?l02@3oool6003o00030:0Pl03oP000oh0000<0oh000`2P8?0n0?n00003
0=1@N02P8?000?l000P00?l0c@3oool000X0oooo1000o`00C@0Ni0P0R88`05`b5P0i1`@0?P@705D3
1`2?1@L0[0d20<UW403GZ0@0eH4?0;lH0P3>30X0d@/:0=H<3@3H30`0f`l>0=dA3@3P50d0haD>0;XD
402WETh0mMOA0?G/jP3ain@0l]oM0>O<b`3SaLD0ilc;0>cGeP3dinH0m^k]0?GakP3bl_00l_3^0?;`
k`3flO00m/k70?G5^`3jem00nn[U0?W`k`3fl_<0m??c0??cl`3_knd0inCQ0>CEd@3H^[@0]Gaf07`I
5P2210L0T@8809d2202J0@L0UP0709D2202?0@P0SP8908T11`290PP0P`8607X1101b0080L`4207H1
0`1j0@L0O08407h31P1i0`H0K@8306810P1H0@40F0/407Db301AR@<02_D100L00?l02@3oool4003o
000302S8?02P8?00j6Pl00D0oh0000<0^3Rd0:0Pl02P8?003`3oP0030=1@N0030>QX?03oP000oh00
02X0oh0000<0j6Pl0:0Pl00Xb3`01`00o`080?ooob400?l001403?P602oR5`1Y_SD0J[hh08fZC02;
[E40[IQU0:>RI`2PQF/0YXe^0:J:K@2;^6H0]iYm0:B[LP2@^6L0=Nh[03;/:@0W003o00P0oooo8@00
o`00100Xb3`0D91h07QH]01hF;@40:0Pl0030=1@N02P8?00d51h00@0X23`0P1@T7PW003o00/0oooo
000:0?ooo`<00?l004h05>d60:fOJP33[j@0<a4?03D41`0n10P0F`@809@5202a3@P0b5H=0=JV103G
RQ00^1P10<T;203:20P0d@X;0=D<2P3H3@/0g0h=0>0@303P4`h0R`d<0<nb[`3fg]T0dXF10<YGE@32
=3@0_ahM0<0K702m7Al0^bHU0;`m>`3:IFH0ZGYj0>kWiP3bl?40l>o^0?7_k`3dl_40mO?`0?Kcl`3f
l_<0mO;c0?Kbl`3flO00nNk_0>3:b036V8l0XE1808TN6P2:1`T0T@8808l1202A0PH0W`8;09l2302I
0@L0U@8708h11`2=0@H0R@8608L11P1i0@<0K`4106h10@1e0P<0N@8407d21@1k0P<0MP4207P31P1j
10P0K`8306P20`1L0P40F`d306hX1P1:TP<7003o00T0oooo0`00o`000`0Xb3`0^3Rd0=1@N0060?n0
00030=1@N02P8?00X23`01@0oh0000<0d51h0>QX?03oP000:P3oP0000`1hF;@00?l0003o0005003o
00P0oooo7000o`00800Gl0`0>]/N07Fk@`2=/5P0]j9c0<2MO@3C]id0dkRU0=>gY03A^:H0d<6d0=77
``2UX:H0OH2A0:^ea026UJX0JX6O07Z@YP30bLl0emGB0=KCd@3Cd<d0d/g80=39`@2XdYh0VmB?09O=
Q`2=_gH0G==;05W=A@0hgb/05?0>7@00o`080?oooa`00?l000<0:<Pl052@N01hF;@00`2P8?000`2h
>;@0d51h0;Ph]0020=1@N0030>QX?02P8?00X23`00@0X23`00<0d51h0?n0003oP0000`3oP0040=1@
N00406RX?01@T7P0D91h02S8?1d00?l02`3oool000X0oooo0`00o`00C`1^]ST0eLRm0<Ro`@0d6Q`0
<0<703L21P1=0@<0S@@80:T92034B``0f:H60=R?3`2a6P40a@/80<D71`3:20L0dP/90=H;303N3a40
h10>0=lB3P2I3@h0Y6iX0=N9OP2o61@0cPd:0=D<303F3PX0f10<0=/A3@3N50l0lB<J0?8[8P2J7a`0
f<W70??^kP3^jn/0lNo_0?C^k03mhn00omkS0?oOh`3oh><0omSL0>bk_P3=QXd0SC4f08XC502E1PP0
U`<609D2102C0@@0T`8809812@2K0@X0WP4<09L11`2C0@L0T08709411`2?0@L0P`4507800@1/0000
K@4106l10@1d0@40N`4207/1101f00D0M@4607L93@1]10L0I`4206020P1J0`40F`h107P`0`0DjP80
1P00o`090?ooo`<00?l000<0X23`0=1@N02P8?001P3oP0000`3@D7P0X23`0:0Pl00P0?n000030:0P
l03@D7P0oh0001h0oh0000<0d51h052@N000o`001@00o`080?oooaP00?l002L03?P603_K7P24]4H0
[:IV0<fXR`3C]j<0g/Zj0=O4]`3KbKd0gLk50=_>a@3FbL40hMKA0=O<b03CblP0eLk;0<g<d@32`/l0
F6N909f/a01^QJD0TJ[408BK/P3>f=h0eMOI0=3DeP3AdmH0c]3C0<_?d03;cLh0b/[=0<K6aP35`l80
alC30<o;b03<`kd0ZKZB05c>BP0;n0P06P00o`080?oooaP00?l000<0:<Pl052@N02P8?000P2P8?00
103@D7P0j6Pl0=1@N03XJ3`70?n000030=1@N02h>;@0X23`00@0X23`00<0j6Pl0?n0003oP000103o
P0000`2h>;@0oh000>QX?0030?n000030=1@N02@L7P0:<Pl01X00?l02`3oool000X0oooo0P00o`00
D00YgA00ak2L0=3>c`3DdM@0?2X/03462P0l0`P0C@<707X31`2K1`L0_DD<0=RV1`3FT@h0/1d10<8:
1`3110H0b`L90=092P3B2``0e@`=0=492@3C2PT0_PX:0;H[9@3>=2X0c``90=8<203C3@T0eA080=HC
2P3G5@X0fQX<0>d]7@3^<b40`cDZ0;^OV03bk^/0l>o/0?7`k`3il>h0gZNT0=mnO03TOG/0hg]f0=I/
JP2fDDl0/d0m09lW7`2N7100W18709L<102C2080T0D309441P2B0PH0W08:09T22@2G0PL0U@8609D2
202B0@D0S`8507l2101a0@40K@4106l10@1^0@40K`8107H20P1i0P@0N@4707811@29:Bd0W45706X;
3P1L0P80F0820583001Y6@808Ld11P00o`090?ooo`800?l000<0D91h0;Ph]03XJ3`01`3oP0000`3@
D7P0X23`0:0Pl0120?n00003052@N000o`000?l000@00?l0203ooolE003o000]01O`2`16e2@0M[e3
0;^TM@3?Z8`0e[BJ0=joZ`3H_Zd0gLZk0=_:_P3Wf]00g<g50>7DcP3PeLl0i=cH0=_Ad03Tf]/0gMGC
0=;>b`3>bLX0b/K;0;FkbP1_QJ40MXZR04QSQ02R]l`0[/;A0=?Ig03Ce]P0d]KI0=7Ef03?dMD0c<oC
0<[>dP39bLh0`lG80<W<c`3@dmD0c=3C0<_>d03;bL`0`kVi06ZbHP0d^R<01o@301L00?l0203ooolE
003o000302S8?01@T7P0N5Rd00@0X23`00<0^3Rd0?n0003oP0002@3oP0000`3XJ3`0d51h0:0Pl004
0:0Pl0030;Ph]03oP000oh000080oh000P3XJ3`0102h>;@0X23`0:0Pl03@D7P30?n00080d51h00<0
^3Rd06RX?00Xb3`05`00o`0;0?ooo`002P3oool2003o001@07In;P3Cb/T0c/oB0=CDe`1HBdh0<0D9
03h21P1;0@L0M`@:09D5202a=P`0f:8:0=JC3@2`8P40a0/70<H62`371`/0b`P<0<X8203610@0``81
0<D30`3@2`/0bPT80<@>1P356`X0abPB0</i8P3ADSL0fFaA0>60IP3YU7d0n[b_0?[8_@3id/X0lNCM
0?3]jP3`k^`0kng/0??`k`3fk^X0nNgX0?WZiP3hjnD0n^_V0?[Zi@3ii]l0l=?70>K0[@3Q]Id0fZN@
0=:IP`37PF`0`F]I09<I5P2G0`T0U`8709D2202E0@P0UP4709@2202=0@P0M`4207410@1Z0@00KP40
06l10@1^0@40L04107@10P1e0@<0L@4406`62@2NATh0Y59J07d[;@1F0P@0CP4106<=0`0cWP06003o
00T0oooo0P00o`001@2h>;@0oh000=1@N03oP000j6Pl00D0oh0000<0d51h0:0Pl02P8?003`3oP003
0=1@N0030>QX?03@D7P0d51h00d0oh001`3@D7PI0?n0000306RX?000o`000?l000@00?l0203ooolB
003o000a02;Y4@15dbD0M;Xo0<:GL03:YX@0d:nE0=6eW`3D^J@0fkbW0=VoZ@3Ob[H0hM310>7A``3R
e<P0j^3I0>GJeP3Wgmh0iMkK0>KNg03Sf=L0hMSE0>ORg`3Gdm00^K[00<?4bP2IZ;X0VJfo09b_a01E
M9X0IhBO0<kJi03Dem`0d]KI0=?Ef03@dmL0cm?F0<kAd`3<c]40bLkA0<[Ae03@e=L0cm?H0<[>d`36
bll0b/cB07=gRP1TK7T0MhmU01[U4P0F003o00P0oooo4P00o`000`0Xb3`0D91h07QH]0070:0Pl003
0;Ph]03oP000oh0000X0oh000P2h>;@50:0Pl0030;Ph]03oP000oh000080oh0000@0j6Pl0?n0003o
P000j6Pl0P3oP0000`3@D7P0^3Rd0;Ph]0020:0Pl080d51h00<0:<Pl003o0000o`005000o`0;0?oo
o`002P3oool0DP00o`00:]P=078c7`39`;l0cloD0=?Df01mMGP0;PH903X220180PL0K`@808P2102^
;PT0f9l<0=JC3@2/8`00_PP30;d52@2[0@<0^0850<431@310P<0``830<P51P3@2`h0_@X<08dT6`3V
[I<0k<Bb0>_>`03Ze/P0j]_B0>cRg03bjnL0lnk[0?7[jP3`jNL0l^_[0>k/k03`kNd0l^k^0?;`lP3a
l?40mNoa0?O]l03ek>d0m^c^0?C/k03`inP0k>7R0>GGe@3Te]00h]K?0>7Fc`3Rell0k=G>09i?BP2=
1`X0S``@08T42`2@0PT0UP8809L2202=0PP0M`4207<20@1^0040K`8106h10@1a0@40LP4107820P1`
0@80K@4207DC4`2UDEL0Z5iW09=9C@1`8BH0B@4405L7101IA`46003o00T0oooo00<00?l0052@N03o
P0000P3XJ3`00`3oP000d51h0?n000040?n000030=1@N02P8?00X23`00`0oh0000@0^3Rd0=1@N03@
D7P0j6Pl<P3oP0000`3@D7P00?l0003o0004003o00P0oooo4000o`00=00hfQd0LkTo0;:KJP32Vg/0
aZB50<j^U03>/IX0c[>K0=JmY@3I_j/0hLRf0>3:^@3Td[h0imO80>gNe@3[gM80k>7J0>[Rg03Xh=X0
hMSC0>KPg03OfmP0hMcH0=_GdP3Pg=`0gMGE0;2`]@2IX;40HWFB0:jjc01kU;40Sj[4082L]03Ae]d0
dMKI0=3De`3@dmL0cm?H0<_@e03<d=@0bloB0<c@e03<dMH0cmCH0<gCf03:cm<0bLkB0;NmaP1RLhP0
K7b=08bFQ@0cab4E003o00P0oooo4000o`000`1@T7P0N5Rd0:0Pl0070:0Pl0030;Ph]03@D7P0^3Rd
00d0oh000P2h>;@50:0Pl0030=1@N03oP000oh000080j6Pl00H0oh000>QX?03oP000oh000=1@N03X
J3`30=1@N0<0X23`00<0d51h091`N000o`005000o`0;0?ooo`002P3oool0@`0Gl0T0/WYD068N4`2P
RHH0d=3C0=;Ae`2CSi00:@L;03D220170`P0H`8608H7202Q8`L0fIh=0=JC302Z8@00_`T60<@73@2k
10T0^P450<431`300P@0`P@50<X9203A2`d0`@/>070F503Na[X0i=SB0>GHdP3[f<l0lMWC0?OMgP3m
g^00o]_K0?c;c03na/P0]H640;b_[`3`k>X0lNk_0?7_l03bknh0lLW=0>ZIW`3CPXX0chB=0=F<T`3@
T9L0cYFJ0<nGV@35TXP0bYbA0=:/Y@3N`l40iLW90;I`KP2U=c@0eW1_0<]RI@292a40T@8809<11P29
0@@0N@4207D10@1`00400P1^0@403@1`0P40L`8207@10P1`0@40K@0206d>402cKG40I2<[0;=aN@2:
@4X0D`lD05040`1]6@<01P00o`090?ooo`06052@N02P8?00oh000?n0003@D7P0X23`1P3oP0000`3@
D7P0X23`0:0Pl00E0?n00080d51h00<0X23`0?n0003oP0000P3oP0000`3@D7P0X23`0:0Pl0040:0P
l0030=1@N03oP000oh0001P0oh0000<0d51h0?n0003oP0000P3oP006003o00P0oooo3P00o`00=`0/
h1H0Tj5A0;ZDLP30WWl0aJF;0<RWS`3=/IP0d;JP0=:iY03E_jX0g<Nb0=o:]`3Qc;T0h/fj0>WE``3Y
fLL0j]O;0>kMdP3YfLd0imW>0>OKd`3Xg]/0gM?=0>;Me`3QfmL0hMKE0=kDdP3Gc//0f]GF0<S6b@2^
]<40I7F=08BD[`2>Xkh0Rj:g0;_?f03Be]/0dMGH0<oCe@3=dmD0c=7E0<cAd`3;cm40c]3D0<c?dP3=
dMH0c=3E0<_?eP3:c=D0a<K>08B@X@1lSZ00UInX0;BZZ00^eB805000o`080?ooo`h00?l000<0D91h
0:0Pl02P8?001`2P8?020;Ph]0030=1@N02h>;@0oh0000h0oh0000<0d51h0:0Pl02P8?000`2P8?00
0`3@D7P0oh000?n000040?n000030>QX?03oP000oh000080d51h1P2P8?000`3@D7P0J:Pl003o000C
003o00/0oooo000:0?ooo`1404;A7`2VOVL0GaXB09MeLP3AdM@0dM;F0:JTY`0W20h0<`<803l21`1G
0`L0LP4209/P1P3JWPh0fIL>0:XU002o2PL0a@H;0<842P2k0@H0_`860<@320371@T0c`X<0=T>3`3E
4@l0ZA@B0>nSW`3[ZZ@0e8Qn0<icI`3DKVL0h7Ac0>1^K03QKV/0geYI0=Y;B036FeD0Z8J10?;Zj03a
ko00lO3a0?3_k@3^`l80eVQV0;`d<`2c7B00/AhR09X_<@2WEeD0]FAQ0:]GC02OBCd0UD4f09]9AP2G
A4<0Tbd]0;5:BP2nIVP0/U]P0:@h@02=0`X0SP8808P21P1j0@80MP4107<20@1`0P8206l10@0=0782
0P1c0@80L04106l10P1W0`D0JaTO08DnAP2FD5X0Z69[064K8P1B10@0K1D501o;0005003o00T0oooo
00@0D91h0=1@N03oP000j6Pl0P3oP0000`3XJ3`0oh000?n000030?n000030=1@N02P8?00X23`0140
oh0000<0d51h0>QX?03oP0005`3oP0000`3XJ3`0oh000?n0000@0?n000030>QX?03@D7P0oh000080
oh0000<0D91h003o0000o`000`00o`080?ooo``00?l002d0=mXN0:VCG`2jU6h0_9Ui0;fNP`31YHh0
bjfG0=2cW@3C^JL0el2`0=W3/P3Kb;H0f/Re0>7:]`3RbkT0hlfi0>OC`P3Vdl00jmS70>SDaP3[fLX0
j=O90>OHc03Vf]80h]OA0>7Hd@3JdL`0jN3M0=kCc`3FcL/0/k6j0:>AYP3IYK40diNV0<V6T`1RBfL0
PIB^09J^`@3?em/0c]CH0<[?e`3@d]H0c=7D0<_?dP3:d=<00P3<cm<02`3<cm@0blgC0<O<d@3:c=<0
bL[A07QjS01=GgP0NHZI0:>X[`2NWhd08]TF01<00?l0203oool<003o0003052@N02P8?00X23`00D0
X23`00@0^3Rd0=1@N02P8?00d51h0P2h>;@0103@D7P0X23`0?n0003XJ3`<0?n000050;Ph]02P8?00
X23`0:0Pl03@D7P00`2P8?020>QX?0070=1@N03XJ3`0oh000?n0003XJ3`0oh000>QX?0020;Ph]0L0
X23`00<0d51h052@N000o`004P00o`0;0?ooo`002P3oool0D`1X/3D0XHEe06PW8@2_RXh0d=7F0=3B
eP32`lH07PX>02P1100i0`P0E0<807P51`2J7PH0gJ4A0=bM402Y:040_`X70<L72`351P/0`0<80<T7
303;20/0bPP80=@<303L4@h0ga`C0>8]803?9R00]2`U0<ITF03QVX`0mKff0?_?a`3lf]80o>7L0?O1
_P2=?SP0mMoD0?O^j@3clNd0l^oa0>o^kP3_knl0l>cZ0?WZi@3je<d0a5mL07/O703Pa;`0lNGO0?;W
h`3ci=l0m>;M0?;JeP3]c/P0j[Na09`c<`2R:2d0bg1f0=9hP@2Z>d@0SP8:09012@290@H0N`4307@1
0@1c0@40L04106X10@1X0@00K@4107<1101d0@<0KP4206L10`1R0PD0G`<;06hE7`1j9c80Lb@]0688
2`1^4@D0?I8000D00?l02@3oool00`1hF;@0oh000?n000040=1@N0H0oh000P2P8?0[0?n000030=1@
N02P8?00j6Pl01D0oh0000<0X23`003o0000o`000`00o`080?ooo`/00?l003/0J[<g0;F@J@2iU780
`J610<>RQ`33YXl0bJfH0=:dXP3F]jH0gkZ]0=ffZ03H_j`0f/Fb0=_6/P3Qc[`0hLfn0>KC_`3Ye/H0
im2m0>WB`03Xdl00j]O80>[Fa`3^gM00h];60=c@b03Ne=40iM_J0=k>b`3Lc<T0i=WI0;2[_01[?6T0
Xb0l0;TD902m41`0a5e]0:R]`@1JMi@0aMCN0<;9eP1SGGd0eKS60=;>dP3:cm<0a/kG0<S?fP3;dMD0
b/oC0<_>e@3:c]<0b<cC0<W:d@2a[k`0PXfR08fMZP2V/[P0[Zba0:J=Q00C003o00P0oooo2`00o`09
0:0Pl0030?n0003@D7P0X23`0080X23`00D0d51h0?n0003@D7P0oh000=1@N00<0?n000<0X23`0P3o
P0000`3@D7P0X23`0:0Pl0040:0Pl080d51h0P2P8?020=1@N0T0X23`00<0oh00003o0000o`004@00
o`0;0?ooo`002P3oool0D`22Z4`0WH^106di=P2ON7l0c<gB0<kBe`31aLL060h?01L0000^0PH0CP45
06d1102D7@D0gZ0B0=VM3@2[;000_@T50<@72P361`d0aPD:0<d93P3=2@X0d``<0=P>303L4`l0galE
0>8e:02M7QD0ciB90?GOf@3ajnL0kng[0>k/j`3^kN/0mNo^0?SPg021BD00dkn`0?7[iP3blO40mO7b
0?WWjP3[gMl0k^_Z0?3]j`3`jnP0iKNd06@]:`3Yh]d0jNWX0>[ZjP3/k>`0j^[[0>KVi`3ZjNP0l^GT
0;9WJ@2F20h0U1@P09dT;`2=2A00TP8809@2202<0PP0O04207L10@1e0@40L00206/10P1[0P40J`42
06d10@1`0@40KP8306D11@1Q0@L0I@4906X32`1e51/0PbXa06H72P1Z3PH0>Xl000D00?l02@3oool0
1`2P8?00oh000?n0003@D7P0X23`0?n0003@D7P01P3oP0020:0Pl1H0oh0000<0d51h0?n0003oP000
403oP0000`3@D7P0oh000?n0000G0?n000030:0Pl000o`000?l000<00?l0203oool9003o000n00_h
1P1//cd0/8e[0;NDM@2mVWl0_j260<BVTP3?/Id0f[:P0=ZWUP35QgT0eXYo0=65MP3J^J<0el2[0=_5
/@3Td<00h<bk0>7>^@3Xe<<0i/jm0>SA_P3Xd;d0j];20>SA`@3Wd/<0gm370<Noa@34UZH0eh>=0=ii
P03TR980hI:H0=ZU/`1jA6`0/3mN0;hB7`392Q80^R0^06M@L@23U[40/<;C09ZN]@1`:dd0X2<i0;e/
O@2dQ9H0RfN006e=I@2i/[T0d=;G0<c>e038c=<0al[C0<S;d`2Y[;H0CEQ^05MWN@2KZ;40ZJR_0:BC
U00ebB@B003o00P0oooo2@00o`000`0Xb3`0N5Rd0:0Pl0060:0Pl0040=1@N03oP000oh000=1@N0<0
X23`00<0oh000>QX?02P8?000P3oP0000`3@D7P0X23`0?n000030?n000030=1@N02P8?00^3Rd00<0
j6Pl0`2P8?020?n000030>QX?02P8?00X23`0080X23`00<0^3Rd0=1@N03@D7P0102P8?000`3@D7P0
X23`0:0Pl0070:0Pl0030=1@N01XZ3`00?l001400?l02`3oool000X0oooo04H0U:aS09Z=RP1eBDT0
SEmU0<W8c@3:cm<0_L3002DM7P0?0000:08604L2201P0`L0OQL30=^O4`3JWPl0Zb`00;l;1P3520X0
a`L;0</92`3?2`d0d0T;0=@;303H3Ph0fQ4>0=`D3@3>5a@0QT8m0?7Qf@3_jnT0k^g]0>c/k03]k>d0
l>_[0?GXiP3lhM/0ZfaN0:^=O@3Xg=@0in?R0?3XiP3HT9@0U3i00=2j^P3/jn/0jnWZ0??Kf`1b<c<0
`K6_0>SXiP3[jn/0jnc/0>[YjP3YinL0in;Q0>oSh`3;Ti00V@/<09l42`2H0PX0UP8909@22@2@0@T0
R`4607l10`1k0@80NP8307810P1_0@40KP420P1/0@802`1_0@80LP8406H11@1M0@D0I04706/32@1]
1`d0K`/A06P82`1T2P@0MRL100D00?l02@3oool01@2P8?00oh000?n0003@D7P0X23`0080d51h1P3o
P0020:0Pl0030=1@N03oP000oh0001L0oh0000<0d51h0?n0003XJ3`09`3oP005003o00P0oooo1`00
o`00@00Bk@X0K9<m09n=G`2^S700/Y5g0;VHO`34YHh0bjRD0=BRT`3DRG`0_eU<0=9YE039JU80dW1L
0=5cH@3M]9h0fL2Z0=k7]03Pb[T0hLZi0=o9]P3Wd;h0hlZf0>C:]@3VcKL0jLnn0>W@_P3UdLH0THfX
0:U8J`3=8bX0dB4N0<dQ8@3;8RH0aadV0<8N;02m8C@0cblm0<XE6`3;20l0`@XA0;EKK01lIhD0HTU_
08TfDP2Y3ah0/@<>0:`43`2V1a80UaDH0:EMF`3EaLL0cL_30<k;`@3:cM00b<cD0<G9d`2o`L/0J6im
06ikQ`29TiX0XZ>X09nJW@1dYV4B003o00P0oooo1`00o`000`0Xb3`0d51h0:0Pl0050:0Pl0030;Ph
]03oP000oh000080oh0000T0d51h0?n0002P8?00X23`0;Ph]03oP000j6Pl0:0Pl03XJ3`00`2P8?00
1@3XJ3`0oh000?n0002P8?00^3Rd00H0oh000P3@D7P30?n000040;Ph]02P8?00X23`0;Ph]0H0oh00
00@0d51h0>QX?03XJ3`0^3Rd0`2P8?020;Ph]0<0X23`00<0d51h003o0000o`004000o`0;0?ooo`00
2P3oool0A@2iVW`0Uhj=07iLFP1d?d40bL?90<K9c@2b]KD0?SLi01@10P0]0`T0@`8905`3201o5P@0
f9hC0=^M402Y:@00_PX50<H92@372@P0b@P90<h:2P3@2`X0e0h;0=P>3@3J3`h0g14>0=@E4`1j8R80
d[nm0>cYj03_knh0k^g]0>o]k@3VblX0fWil0=eOG@3:@CX0Q4m40>GHb@3_k>P0lo3]0>BUX`2e=S<0
YWMc0?3Zj03[j^X0lNOW0;9UI@21;C40_:2S0>[Wi`3Zj^T0j^[Z0>KPgP31TY<0/FAW0<IXJ@2R3a40
Z@@:0:411`2I0PH0^b0T0:DB602=0@D0QP8407h10@1l0@80N@8207D20P0207410@0<07420@1a0@80
L@4406X11@1O0@D0H@4506<21P1V10P0IP8806T6301W4P/0NC4>1@00o`090?ooo`040=1@N03oP000
oh000?n00080X23`00<0^3Rd0?n0003oP000103oP0020:0Pl0d0oh0000<0d51h0?n0003oP0000`3o
P000103XJ3`0oh000?n0003XJ3`@0?n00080d51h00<0j6Pl0?n0003oP000603oP005003o00P0oooo
1@00o`00@`09mPD0Dj8a04A<?`15A4d0YXYe0:f?N02`UH00^in<0<b[V02nLf@0afMD0<aXDP3HL5d0
aUM20<eNB039IT/0bgYS0>:bW03K`:d0g<>c0=k6]03PbKL0g/Rb0>G>^@3Sc;D0i<be0>O>^03Yd;`0
jLnk0>?>a@1TFHD0^C=40>=_GP3WXYD0f:NQ0<RLX038Uj@0/Vn009e9G@2H>4d0Z2Tk0<8;4`371Ph0
_PdI0;<E8P2`3AX0/`H>0;@22`2a10/0ZPX;0:<R7P33R880eL_90<g?d@38`jT0`:iX0<o?^`37cM80
a/[D0<O9e@1gNHT0HFah08jJW`2^/kH0/K2e0:FIV007m0@04@00o`080?ooo`D00?l000D0:<Pl0=1@
N03@D7P0j6Pl0;Ph]0040:0Pl0040?n0003XJ3`0j6Pl0>QX?080oh000P3@D7P20:0Pl0030=1@N02P
8?00^3Rd00D0X23`00@0^3Rd0:0Pl03oP000X23`0P3@D7P20?n000030;Ph]02P8?00^3Rd00<0d51h
3@3oP000103@D7P0X23`0>QX?02h>;@30:0Pl0060;Ph]02P8?00X23`0:0Pl03@D7P0:<Pl4@00o`0;
0?ooo`002P3oool07P2jVh40YYjN081UH`1O92X0bko70;o3a`2][[00D4Y;01L2100[0`/0?04805D2
2@1l5@H0eidC0=RK3P2X9P00_PT40<H9203820P0bPP90<h92`3A2`X0dP`90=H>3@3I3`d0fa4=0=hD
3`2l61P0JAHK0<Rc]`80kNk^03<0kN_/0?OWi03XUXl0aC4U0=@U6`1m;BL0g<bn0>cYi03^k>`0j<70
0:<b<02CDTh0lnWV0>gZjP3^jNT0d8j<0:dK7P1n5Qh0/YBG0>SVi@3[jnX0j^SV0>Jl^02J=C40Y1<F
0:/62`2Z0`P0YP8:09d31`2]6R00V@XA08l22@2?0PD0O`4107X10P1g0040M`4207<0001b0@00L@41
07410P1c0@D0K08505`10`1K0@<0H@8806<31`1U0@L0I`@;06HE4@3;ZI`01@00o`090?ooo`040=1@
N02P8?00oh000?n000<0X23`1P3oP0020:0Pl0h0oh0000<0d51h0?n0003oP0002@3oP0000`3@D7P0
oh000?n0000W0?n000D00?l0203oool5003o001305ej?00L8c`01QY>02XfF@2SSh<0[IJ30;RMSP2k
Whd0`:290<N3L032F4H0bUm90<EKAP3ITGL0f:>70=J]T`3@YI00fKJO0=_0[P3L`k00g<6]0>;9]`3M
a[<0h/^d0>C<]03UbkD0il^j0>S?_03VdKX0i<jn09N9V`33SY80ilFa0=g<^`3Jb[h0hmSE0=[?c03E
a/H0eL_>0;nld@1HCGT0ZB@m0<P840341@`0`B@K0;8b:P2V;2/0ZcTd0:mBBP30QGd0dkjk0<k=c`3:
c]40bm3E0<kAc`37^i40`kAi0<c=`P35bm40a<WB07n3T`1AF6T0L7f50:fb]`2c/[T0Zj>Y02G<6`0A
003o00P0oooo1@00o`020=1@N080X23`00T0j6Pl0;Ph]03XJ3`0^3Rd0:0Pl03XJ3`0oh000>QX?03o
P0001@2P8?020;Ph]0030:0Pl03@D7P0^3Rd00<0X23`0P3@D7P01P2P8?00j6Pl0;Ph]03@D7P0X23`
0>QX?0<0oh0000D0j6Pl0=1@N02P8?00X23`0=1@N0090?n000070>QX?03@D7P0j6Pl0>QX?02h>;@0
X23`0>QX?0030:0Pl0060;Ph]03@D7P0X23`0:0Pl02h>;@0D91h4@00o`0;0?ooo`002P3oool0D`2k
XXP0Ti>C091nOP1=51T0`;6h0;Rk_`2^/[40IF=P01/72@0Z10/0?`<=04P12@1W3`<0di`C0=RK3`2W
9@00_PT50<L8203:20/0c0T:0<d82P3A2P/0d``;0=L=3@3L4@h0gQ8=0>4C3P3Q5a@0ba`M09/^=030
Y:X0j^[Y0>c/k@3/jnX0mN?M0>VZW03@Cd40Qa`F0;fSV@3^in80knc]0?;Ph03EV9@0c9jI0?7Wi@3^
jn`0k>WZ0>Ff]02d6aX0^ADH08hT:P2lZ:P0j>KS0>[Yj@3]iN80j<:m0;5:AP2Z2@/0[@@80:P1202V
20h0bT]@090B502>0PL0T`4608H10`1j0040N@4207P20@1c0040L`4207410@1b0@80LP4306X20`1L
0@80F04305P11@1M0PL0H04506@5201Q40`0aZBG00D00?l02@3oool20=1@N0050>QX?03oP000X23`
0:0Pl03XJ3`01P3oP0020:0Pl0l0oh0000<0d51h0?n0003oP0004P3oP0000`3XJ3`0oh000?n0000M
0?n000D00?l0203oool4003o001407^SBP1aIV`01QM:008GGP0H:El0WXn;0;2GQ@2cU840]YMm0;bM
PP38SWT0`EA00<=LAP36ME`0c9Mk0<j[S`3=[9<0d[RT0=g7^@3J_jh0fKn[0=_2[P3ObK<0g/F^0>;:
/`3TbkT0hlVd0>G;^@3Vck/0i/nj0>K>^`3Qbkd0g/Zh0=[6/P3Qa[P0gl2d0>K6`03Va<80klO:0=VV
ZP3T[[H0[GB>0:hbCP342140`PH;0<0Z;@2F@dd0SU=U0<bOZP3K]kd0el780=K8c`3Ab]00c/_B0<_<
d@39b/H0d<VY0<FaF03<_GX0blc20<K;cP2SYK00HVQf08:=U`2NXjd0Y:J`0:ZZ/P13^S/A003o00P0
oooo1000o`000`2P8?00d51h0:0Pl0020:0Pl0030=1@N02P8?00X23`0080X23`00@0d51h0?n0003X
J3`0d51h0`2P8?000`2h>;@0d51h0;Ph]0050:0Pl0070;Ph]02P8?00d51h0:0Pl02h>;@0d51h0?n0
00020;Ph]0<0oh0000<0j6Pl0=1@N02h>;@00P2P8?000`3@D7P0oh000?n000020?n00080^3Rd00<0
d51h0;Ph]02h>;@00`2P8?00103XJ3`0^3Rd0:0Pl02P8?020=1@N0H0X23`00<0P<00003o0000o`00
3`00o`0;0?ooo`002P3oool0D`2kXXH0VIRI09J;R`144Q<0ZYNI0;Vk_`33b<X0Rhf?01d;400Z1@`0
?`D:04L11P1U3`D0cYDB0=JE402X8000_PX60<P9203:2@T0c`X:0<`82@3A2``0dP/<0=P=3P3K3`h0
fa4<0=hC3`3S5A40jATB0>4L5`2S9B<0Yhf:0>SSh@3[jNT0jnWX0>gTh03a_[@0YBhW06`l>@3[h]l0
jn_[0>c[j`3aj^P0lNWX0>gZjP3/j^/0k>_[0?;If@2_=C<0ZQLA09d`:@2ONG80hMOB0>[ViP3Wi^L0
jnGV0>S5``2Q9R<0Z@D90:T42@2V0PT0W`<:09h42P2F0@H0UP8809@21`270@@0O`4207P10@1e0@40
M`8207<10@1e0@80M@8406/2101N0@@0E`4305D10`1K0PH0H04606@4201U3``0c:RL00D00?l02@3o
ool20=1@N080oh0000<0^3Rd0:0Pl03@D7P01P3oP0020:0Pl4@0oh001@00o`080?ooo`<00?l004D0
J;M50:>DQ01lMgl04REJ008HIP0=7UX0W8f;0:fAP02cTg`0^9Ek0;^JP02kPFP0a7YL0<jKP@38YH`0
aZVA0<JYT039[9<0flfn0>OMfP3C_Jd0f/6_0=[4[`3La;00glNa0>38/`3QbkL0hLZe0>?<^@3Sc;/0
i<jn0>C>^P3Sc;T0^k>_0:28U03?FE/0dd530=4e>`3>:C00bb0V0<TH703;6A`0aQDH0<@?50342@h0
`PH<0;d4302d1`l0[@TB0:H:602S3Ah0XADV0:<R<`2U=D@0ZTQH0:YUL@3?_:h0_jaQ0;fS5P2mYA40
`:i:0<:lR030_:`0Fe]R06=[MP2EWJH0XJ>[0:NW[@1UZU/04@00o`080?ooo`<00?l000<0N5Rd0>QX
?03@D7P00`2P8?000`3@D7P0j6Pl0:0Pl0020:0Pl080^3Rd1@2P8?000`3@D7P0oh000=1@N0020:0P
l0040;Ph]02P8?00X23`0;Ph]080X23`00H0j6Pl0?n0002h>;@0^3Rd0>QX?02h>;@A0?n000030>QX
?03@D7P0d51h0080d51h102P8?020;Ph]0030>QX?02h>;@0X23`00<0X23`4@00o`0;0?ooo`002P3o
ool0D`2nY8H0W9ZF09J>S@1B7ah0VWf00<?3b03=dMD0Z:^_01/@4P0Z2@`0>`@:05452`1N30<0dIPE
0=JB3`2/7`80`@T80<T930392@T0c``<0=4;303A2P`0e0`>0=H<303I3Pl0ea0A0=8?3`3G40/0g1XE
0;/V7P3ES840j]WD0>_Vi03[jNT0k>SV0?3Qg`3f`;h0b3Hb06/>3@37/Zh0k>[X0>cYj03]dm<0[6Q]
09EcL`3_jNH0k>[Z0>gTh@2/IV<0B`/70=_3^P3[hn00jNKU0>GUi@3ShN80i=oP0>GAd@2RA400U`<7
09/11P2N0@P0W04709X11`2D0@H0T@4509@11P2@0@H0R08307`10`1i0@<0N04207@10P1e0@@0M045
06d10`1S0@<0F@4405@11@1A0@D0E`4505l31P1P2@D0VEDj00D00?l02@3oool0203@D7P0oh000>QX
?03oP000d51h0:0Pl03oP000j6Pl1@3oP0020:0Pl1`0oh0000<0j6Pl0?n0003oP0009@3oP005003o
00P0oooo0P00o`00AP1N_C/0ZIfC0:JLU`2HTYP03Qe>00@GH0075Th0Sh620:Z<O@2`T7`0]YEl0;ZG
P030WH<0`Ij40;JLR@2FQGL0R7aa0926N02mZ980d[ZX0=Fn[`3F_:L0f/6[0=W0Z`3J`k00glN`0=o6
/P3Pb[H0h<^c0>39/`3Rb[H0h/^e0>?<]P3Tc[P0dL6m06iNO@2n=CP0cbTK0=4f903E@cD0eU540=IL
D03BGeD0cV5E0:Y8C@2O7cD0`0LA0<022`2n8Qh0]D]30:=7@`2R@Ch0YcTg0:<X:P2Q71d0W1@I094B
6@33UiT0dLg10;jZB`2oY@H0^j060;:M3@2cWQl0JUhX06=^N02=VJ00/;>i0::PYP1[Wf4A003o00P0
oooo0P00o`00101hF;@0j6Pl0?n0002h>;@30:0Pl0030=1@N03oP000^3Rd00@0X23`00L0^3Rd0>QX
?03oP000d51h0:0Pl02h>;@0d51h00H0X23`00<0^3Rd0:0Pl02P8?00102P8?000`3XJ3`0X23`0?n0
00070?n000030>QX?03@D7P0oh0000X0oh000P3XJ3`50:0Pl0030=1@N02h>;@0X23`00<0X23`4@00
o`0;0?ooo`002P3oool0D`2nXH<0WY^H09VCU01J:R/0TW9f0<W:d03@e]/0^K_001hD5@0/2Ph0>P@;
05P:4P1L3@@0dY/E0=:;3@2^7000`PT60<P82`391PX0cPX;0=0:2`3@2@X0d`/<0=H<3@3H3@h0f@l@
0=TA3P3J5A40/a@C09iNFP3bi>00jnWY0>[Xj03Wi^D0j=3?0?:][@3IEEL0gRDR09dI5`2QP7`0k^_Y
0?7]k03mh=l0]Da=07`d<`3^hMh0j^KV0>kYj037Ti<0B`l<0<Rl]`3XinL0inKX0>CRh`3NeM<0c[J`
0<>>Q`2B7AX0U@8409<00P2E0@D0U04609<01`2C0@L0T04409@21@2@0@@0R04507d10`1h0@80MP42
07@00@1f0@<0MP8506l10P1Q0@80FP4305D1101=0@@0D04605H1101N1`80QS4A00D00?l02@3oool0
203@D7P0oh000=1@N03oP000d51h0:0Pl03oP000d51h1@3oP0020:0Pl1@0oh0000<0X23`0?n0003o
P000;@3oP005003o00P0oooo04P00?l002SO5P2eYIP0/:f]0:bXZ@2OV9h0;SIJ00<DEP045540PgIl
0:R;N02^SgX0/YAk0;JGO`2jW840^9n708anL02XUXD0Y9>5079/IP2HSH40d[RS0=BkY03G_ZL0f;fW
0=RnY`3I_jX0g/J`0=_3/03Qb[P0h/Zf0>?:]P3Qb[D0hL^f0>;;^03Ud;/0h<bk0<nh[P3K/Z@0eJVO
0=f/W`3/]:P0m;fh0>6VX`3HYj80/ijR0:Z@Y@2Q=e80_PTC0<452`2e6Ah0VTmP07MZQ@2=VJ/0ViFV
0<NU[P3F/K80dJ^/0<RPX030[[00blo@0<FiP`2mY@`0Xhh@07U`302^WPh0YiHS08B2J02FW9`0WjBW
09fNX`2=Oh4A003o00P0oooo00<00?l0052@N03@D7P00`2h>;@30:0Pl080d51h1@2P8?001@3oP000
d51h0>QX?03oP000j6Pl00P0X23`00<0d51h0:0Pl02P8?000P2P8?001P2h>;@0X23`0=1@N03oP000
j6Pl0;Ph]0<0d51h00D0j6Pl0?n0003@D7P0X23`0;Ph]0030?n000050=1@N02P8?00X23`0:0Pl02h
>;@00P3@D7P30>QX?0H0X23`00D0d51h0;Ph]02P8?00X23`0=1@N00A003o00/0oooo000:0?ooo`10
0;nSP`2NWY`0UY6E06<m?@22GF80bl[A0<oGg038bm0081/M02T93@0d0`X0@`4805d>1@3EWQD0dHL@
0:dH0@332PL0a`H90<X62@3>2PX0c`P;0=8;303A2PT0e@/<0=T>3`3J3Ph0gQ0?0=lE4P2/4a40QeaJ
0>cWi`3[j>T0j^SW0>WWi03ValH0cVeZ0=Pd;03X8a/0bRHT08]ED@3/j>D0k^_Y0?SVi030IV@0PRTT
0=6l]`3/jNL0jnWZ0>Fj^P2=;2X0Qe1A0>7JfP3UhN<0h=_N0=c>b`2mTHD0TblT09@5102I0P<0UP83
09<1102B0@L0TP4909012@80T0450140R`4408H00`2F2`h0Zb`^08PE5@1c0@<0LP4107d5201a0@@0
H`4205`00`1G0@@0C04304d0101H0PL0G0D208dg6`05003o00T0oooo0P3@D7P01P2P8?00oh000=1@
N02P8?00j6Pl0=1@N0D0oh000P2P8?0T0?n000030>QX?03oP000oh0001d0oh001@00o`080?ooo`19
003o002<ZfL0[:Z[0;>e^@2XYZ/0V8nG05mPNP054d`0119?07U^MP2RQW@0ZHag0:n@M`2eUWd0_9^0
0:NBO`24Ng80XiB709B:PP1`KF`0THMm0=2fX03E^jD0e;^T0=JjY03H_:H0fKnY0=g4[`3Ka:h0hlZg
0=o9^03PbkP0h/Zf0>?:]P3Qb[D0i<nj0>7:^@3Ja[X0R8VJ0:UUNP3;>D80d2H[0<hM903:6A`0]adN
0<1fP`1S?f`0/a8S0<H63@2n2@/0[PTB0:X75P2U=dH0G4m^07/eE02I3ah0VQLT09/R<02L=T@0`9bR
0<[>d033]g`0_JD:09j95`0J6@D0GUdB08b24`2OTQd0V8hj0:VSM02VYIL0ViBD01?M300@003o00P0
oooo00<00?l00;Ph]02h>;@01P2P8?000`3@D7P0j6Pl0:0Pl0030:0Pl0030=1@N03oP000j6Pl0080
oh0000<0j6Pl0:0Pl02P8?001`2P8?000`3XJ3`0X23`0:0Pl0030:0Pl080oh000P2h>;@00`3XJ3`0
oh000?n000020?n000030;Ph]02P8?00oh0000@0oh0000<0j6Pl0:0Pl02h>;@00`3oP0020=1@N005
0>QX?02P8?00X23`0:0Pl03oP0001@2P8?020=1@N003052@N000o`000?l000h00?l02`3oool000X0
oooo05<0_J>20::VY@2BU9H0JTm?068k?P3CcmD0cmGK0<oFf@0Y:2/09@P?03H43@0k0@P0G1450=JQ
5`3>PA40[aD10<892@361PT0b0H70</82P3?2@/0dP`;0=4<203G3P/0fPl=0=d@303N40`0hA<@0=PE
502J5QT0/HZA0>OQi03YinP0jNOW0>cXiP3fi=l0kjnU0=Xo=@3A8Ah0NbDT0>SNf`3]jnT0l>WW0>K5
_P3GZJ00e/Bk0>cWi@3[j^/0lmcL0;9AC@2U6Q/0S4E;0<Jc]@3LeMD0g=OG0>;Cc`3@WI80UQhG09@2
0`2A0@<0S`4309011@2A0@P0TP8909821P2<0PD0Q08608l21P2a1@X0ZPD70:PC5`1g0@80M08408H=
3`1b0@@0JP8406<20`1J0PD0C@4304X00`1C0@H0G`D208db6@05003o00T0oooo00P0d51h0:0Pl02h
>;@0oh000>QX?02P8?00d51h0>QX?0D0oh000P2P8?0?0?n000030=1@N03XJ3`0oh000180oh0000<0
j6Pl0=1@N03oP0007@3oP005003o00P0oooo04T0<=DK0:RTX02_][T0/[Bh0:VVZ@2HSY80L6n600XG
D0034dl0LVQb0:>6J`2[S6P0/Hm/0;FDN02kVH00YX]m06m[J@1jMgH0KVi/06MVHP2`X8l0ckBN0=:h
XP3D^j<0e;RR0=JkYP3H_ZT0f/B_0=[5[03QbK@0h<Nc0>;9]`3SbKL0hlVf0>;:^03Rc[P0h<fi0=W8
`P1DGH@0]DaN0=LG5`3L4a80f1LC0=Y8>03?E440bgIZ06YKO@2P:dL0a0T?0<Ld<P2>AeX0S`/W0:d8
4P2;@5D0JcA<09h:502Y0P/0Y`8;0:08302LA4T0dlk>0<:gQP2lYAT0[iLB040a2P1DCQh0:2D206YW
5P2MSQ80[9/A0;>U@P2PTfh07=HB01000?l0203oool00`1@T7P0d51h0;Ph]0020:0Pl0060;Ph]02P
8?00X23`0:0Pl03@D7P0^3Rd102P8?000`3@D7P0oh000?n000020?n000030=1@N02P8?00X23`00T0
X23`00P0^3Rd0:0Pl03XJ3`0X23`0;Ph]03XJ3`0X23`0=1@N0<0oh0000D0j6Pl0=1@N03XJ3`0X23`
0=1@N0020?n000030=1@N03XJ3`0oh000080^3Rd103oP0000`3XJ3`0oh000;Ph]0020:0Pl0040>QX
?03@D7P0j6Pl0;Ph]0<0X23`00<0^3Rd052@N000o`003`00o`0;0?ooo`002P3oool0D`30Y8<0][Zj
09:GV01]FET0Db/[0=SAe@3?e=T0eM_O03Tk?`0S1`l0=@8;03d11@1K4@<0d9hH0<Ui3`2`4`00`0L8
0<@52@351`X0b`P:0=0;2`3@30/0c`X80=<;303I3Pd0gA0;0=`A2`3N40h0hA4A0=`F5`2K5ad0Zh6<
0>7Kg@3YinP0j^WY0>c/j`3ajNL0iIB>0;lQ7P275QD0dl>o0>c[j03^k>X0jNKT0>_Vi@3]j>H0k^c[
0>SVj03_h^40g9>@0;DI6@2R41L0GA8G0;BQWP3Jem@0f]KF0>7Cc`2nO780S`P809821@2@0@@0S@44
08l11P2A0@L0T@8708L2101e0@80Q`850;021`2^0080ZP8408P20`1f0@@0SATK0701101Z0@<0G`41
05P10P1?0PD0A`4204d1101M1080QR`A00D00?l02@3oool00`3@D7P0X23`0:0Pl0030?n000030=1@
N03oP000oh0000@0oh000P2P8?0@0?n000030=1@N03oP000oh000340oh001@00o`080?ooo`19052c
>02GWJ<0[kBl0:VX[@2]ZZ/0V92A07mkRP0;5TP00a1906eSI02fUS`0a9dR0;nI@@2fTfP0^YN10;NH
Q01lKFL0MVeZ0963MP2dWX/0bJjH0<ncW@3?]9h0d;FM0=6fX@3:]Z@0_JZJ0<JfY03LaK80hLRf0=o7
]@3SbkP0h/^j0>?:^P3Sc;T0iM2j0>;>^P3ObKT0Z:>b07aXR@2j@Td0daTI0=8G5@3VMVd0ijNG0=Vc
X@2ZXjh0Kc]V0;/=6@2g41@0_7n8060D?@2`1QH0YRXc07aTM01f<480W0PA0:<42@2aB480/H^60<O6
b03<c/h0a[j70;bV802dVQ00U7hH048f2@1CDal0GUH:09>=702MTA80ZIDQ02CM3@0@003o00P0oooo
00<0T71h0:0Pl02P8?000P2P8?001@3@D7P0X23`0:0Pl02P8?00^3Rd00D0X23`00D0^3Rd0?n0003o
P000j6Pl0=1@N0060:0Pl0030=1@N02h>;@0X23`0080d51h00@0X23`0=1@N03oP000^3Rd0P2P8?00
103XJ3`0^3Rd0:0Pl03XJ3`20?n000050>QX?03@D7P0X23`0=1@N02P8?000P3oP0001P2h>;@0X23`
0?n0003XJ3`0X23`0>QX?0@0oh000P3@D7P0102h>;@0X23`0:0Pl02P8?020=1@N0@0X23`00<0D91h
003o0000o`003P00o`0;0?ooo`002P3oool0D`2k[h<0Zjj^09VMX01dHf<0CAlR0=c@e@3Fg>@0dmSP
04M9CP0V2140?@D>04l73@1Q4`@0dj0G0<Ib3`2b4P<0_`L80<@72@341@X0b@P:0<d:2`3>2`/0d0/<
0=@<3@3G3@d0f@d<0=d@3P3Q4Q00hQ8?0>DD4P3M6QT0Z1`R08m;C@3:]kD0k>[U0>_/i`3]jnX0mLg;
0;D`;@2e7a`0bhj;0?GPg`3bh>40m>3P0?GOg`3fh>80mMkQ0?;Nh03cgMh0nlK60;HW:02n3Q80X0dB
070Q8P2k[J/0fmGD0=gFe`3M`l40TbXW09421@2?0P@0S04308/10P2>0P@0S04708D21@1a0P@0LP44
0:D52@2Y0@80Z@8308h2101f0@D0N@860781101Z0@<0H@4205P10`1>0@D0A`4204P00P1R10<0PbD<
00D00?l02@3oool01@3@D7P0X23`0:0Pl03XJ3`0oh000080d51h00<0^3Rd0?n0003oP0000`3oP002
0:0Pl1l0oh000P3XJ3`S0?n000D00?l0203oool0B@1fVV00SiVU0::U[@2YYj`0ZjN/0:2FV`2DSIX0
5Ai:008@B@1`IDd0aJ<F0<RW2P2iTc/0/8m_0;:CO02hUh40_9b70;VLR033YHl0c:jH0<f_VP3;/9X0
ck>N0=2eW`3>]Z40_JVF0=BkZ@2kZ9T0fLFe0=k7]@3MbKL0g/^i0>7<^@3Rc;P0h/^f0>??^P3SdKd0
i<jm0=k9^P34^;P0QgZB0:5KL035:2l0cADI0<LP8@3@Ee<0ek2]05aAM@2V8SP0_`P@0;XlB02><500
[0LH0:L84@2aQ8`0TXbM074aAP2@3ad0U`lH0;f0RP3>bll0alkD0<_>cP2o]7@0_:@A0;RQ102LQ`l0
MVHF06iS3`1`JAl0J64<0:FH601K_@l04000o`080?ooo`030=1@N02P8?00X23`00H0X23`00<0d51h
0:0Pl02P8?001@2P8?000`2h>;@0X23`0:0Pl0070:0Pl080j6Pl0P2h>;@20=1@N0<0X23`00H0^3Rd
0?n0003@D7P0d51h0:0Pl02h>;@40?n000060>QX?02P8?00d51h0?n0003XJ3`0X23`0P3oP0000`2h
>;@0X23`0;Ph]0020?n000040;Ph]03@D7P0X23`0>QX?0@0X23`00<0^3Rd0:0Pl02P8?000P2P8?00
0`1hF;@00?l0003o000>003o00/0oooo000:0?ooo`1D09W8M`30`lH0WZFX07]`L0124QH0e<;70=?I
g`3Bfn40FemV028:4P0f0`/0A08<05lG1@3GXQH0`fX<0;8>0P2n1`L0`@H90;h42@341@T0b`P:0</7
2P3>2@/0d@X:0=H=3@3J3P`0f`h=0>8@403V5100iaH?0>TH4P3V6A@0eb4N080Q8P3GblL0j^WW0>kY
jP3__l80^2h`0;0M6P3HPgd0afQY0<IBE@33BT`0^T530;m8B02lB4/0/4U<0;9BE034De00_2DP0;P<
302_1@P0V0X>05PV9038^[H0g]KH0=oDdP2ODT`0SP<60902102=0P80R`4208X10@270@80Q04207X2
101M0@40L@4208D2102=0`D0LP4406P10`1k0PL0NP4606d10P1U0@<0FP4204l110190@<0BP4106d3
10237PP08l`21000o`090?ooo`030=1@N02P8?00X23`0080oh0000<0X23`0>QX?03oP0001@3oP002
0:0Pl1H0oh0000<0d51h0?n0003oP000:`3oP0000`1@T7P00?l0003o0002003o00P0oooo04T0X9NA
08FDY@2KXjX0YJJ/0:>SZ02WXJH0S8B?02H]E`0<5ST0SWXZ0<BV1`37Z0<0`IX[0:b<K`2[T7/0]IIo
0;bKQ030WhT0`ZFB0<fgY`3>]jH0b:bI0<nbW03A]9l0d;JT0;^WV@3?^j/0_JZL0=W4/`3Mb;L0g/Fc
0=k9]`3ObkX0hLbj0>;<]P3SckT0i=710>?>_03PbkL0gLRf0=?5``21P9l0/g2;0<XL7@3B40d0b`l?
0<9;A02KQiT0OCEJ0;`:502l1`d0[PXD0:d54P2`0`d0UcDn0<75d01UI800MciC09/G8`2G2aP0_HZC
0<[<dP36c=D0a<Fg0<NkL02kYAP0]j040;6I1`2HP@X0R7HK061E3`2AQad0==d;01000?l0203oool8
0:0Pl080^3Rd102P8?000`2h>;@0X23`0:0Pl0020:0Pl080d51h102P8?002@3XJ3`0^3Rd0?n0002h
>;@0j6Pl0;Ph]03@D7P0j6Pl0;Ph]0020:0Pl0050?n0003XJ3`0X23`0;Ph]03@D7P00P2P8?040?n0
0080^3Rd1P3oP0030:0Pl080oh000P2h>;@00`2P8?00d51h0:0Pl0070:0Pl00307QH]000o`000?l0
00h00?l02`3oool000X0oooo05@0W<]k0;Fi^`2KY:L0SHJ6048@4`2lZ:`0d=OK0=;Jh01`M7T080XA
03D32`0o0@L0Ha/70=^T5P34HPd0]@d20;l720321`X0``D;0<D52P3:1`/0b`L;0<h:303B2``0e`d<
0=/@303M4@d0ha4>0>HD403V5@l0jALA0>DF3P3H6QH0T2HQ0>OCcP3^hN80m=SJ0=YgO03471l0[API
0<6BS`3ng=D0nKff0>>KT`3@QW`0dHb30>:SV`3[]k00ll2i0?Jh[03KQGP0[C0W0:DB3P2=1@H0MCX^
0=6i[@3SeM80gl[609Hm=`2B0P<0T`4308d10P2>0@40R`4108L100260@40Q083074:201T5QD0GP/;
05d1101E0080H`4307l21P220PH0M04206/10`1Q0P<0D@8304L10P190@40K`<307`F0P0Sb`84003o
00T0oooo00H0d51h0:0Pl02P8?00d51h0?n0002P8?070?n000030:0Pl03@D7P0oh0001D0oh0000<0
d51h0?n0003oP000:`3oP0000`1@T7P00?l0003o0002003o00P0oooo04T0ZjJT0761TP2NY:`0ZjZb
0:>QZ02RWZD0RhB>02`cB`1fJ2H0^i`B0:jC2@37Y`D0`9XU0:j;GP2[S7D0]IIo0;ZKQ@2nX8`0elRn
0=G:aP3Gb/@0ck^^0<f_V@3A]J00eKbX0<ZcXP34[Ih0e/2]0=W4/@3Ka[<0gLNf0>39^P3ScKd0h<jk
0>;>_@3TdKd0i=?10>C?_@3Rc;T0f<No07QlV02aH7P0bbPc0=4B4P3;3PP0bBPH0<ibG03;/Zl0GDM^
0:/G;02h2@l0e7Um06HG?P2W1AP0X10M04H[D`1^>EL0UaLU0:863P2V10X0T2PZ0=38c035cML0`lcC
0<G8]`2n/V<0_JTa0;BN2P2cWP@0]9d60:N@3@2GQQD0Am0@01000?l0203oool70:0Pl080^3Rd2@2P
8?00103XJ3`0oh000?n0003@D7P30:0Pl0030;Ph]03@D7P0X23`0080X23`00d0j6Pl0?n0003oP000
^3Rd0>QX?02h>;@0oh000>QX?03@D7P0j6Pl0:0Pl02h>;@0j6Pl00<0oh0000L0d51h0>QX?02P8?00
j6Pl0?n0003XJ3`0^3Rd0080oh0000<0X23`0;Ph]03oP0000`3oP000102h>;@0X23`0;Ph]03XJ3`7
0:0Pl003052@N000o`000?l000h00?l02`3oool000X0oooo03d0WLin0<?8b@2PZZ/0Pgmn04XJ7@2X
Ri80eMOP0=?IhP22QH/080T@0383200o0`L0Jb<:0=ZS5030EP`0^Ph50<882P361``0b0H;0<P62039
1`X0b@L;0<d92`3B2P/0e`d<0=T>2P3L40X0h18<0>@E3`3W5Q00jAH@0>XI503C5a@0eUmO0>fFV03O
P8P0dEEL0<`S903D5QH0cQPG0:<c>@3Q`<80mNSW0?;Xi@3aj><0l^WV0?7Yi`3^j>L0k^WW0>gXh`3`
hM`0i[fg0<UlM@2I;2L0[De40;U/IP2iLW40[5ME094A3`2E0@80T`420080T08101D0S@4208P10027
0@40QP4108TF4`2ME500/gMf05hA4P1S0@@0M`8508@31`2:0`T0O08406h10P1T0@80E08304L10P1:
0@80LP<407hE100SbP801000o`090?ooo`030=1@N03oP000X23`0080oh0000@0X23`0;Ph]02h>;@0
X23`0`3oP0000`3XJ3`0X23`0=1@N00D0?n000030=1@N03XJ3`0oh0001l0oh0000<0d51h0?n0003o
P0002`3oP0000`1@T7P00?l0003o0002003o00P0oooo04X0Zj:J06MhQ`2DWJL0WZ6V0:2NX`2MV9`0
[JN[04I3:`2hWAL0TWP;07eU2`38Y@d0^YDO0<2K>@2/S6X0]IB10;bLQ`2oYYD0flo90;bXWP35[j<0
dkjb0<jbW@3C]j<0e;^Y0=Jl[@3K`;00f<:^0=[5/`3Ia;40g/^g0=k;^P3Qc[d0h<no0>;@`03VdL00
i=310>7=_03Qc;/0f<W305QRR@2aDFL0dAHJ0=4?3P324@X0g5e>0=j_W036/:@0NW2608P]C`2h2A80
_eAL06E6KP2@2B/0ZP@@07@U@01I;dh0SA4O0:<4302O4A00^8Im0<W<cP33bm@0`L[D0<O?f039d<d0
bl^k0;6[K@2TWc80[jDT0;NW4P2bWAD0HZDC01C_10l00?l0203oool50:0Pl0030=1@N02P8?00j6Pl
00L0X23`00<0^3Rd0:0Pl02h>;@00`3oP0002`3XJ3`0X23`0:0Pl02P8?00j6Pl0=1@N02P8?00^3Rd
0:0Pl02h>;@0d51h00D0oh000`3XJ3`00`2P8?00d51h0?n000020?n0000:0>QX?02h>;@0j6Pl0:0P
l02h>;@0oh000>QX?02P8?00d51h0?n00080^3Rd103oP0001P3@D7P0X23`0:0Pl02P8?00j6Pl0=1@
N0D0X23`00<0N5Rd02S8?000o`003P00o`0;0?ooo`002P3oool0502k/HH0`LO:09nZ[P2<Shh0CR@T
08MQJ@3GeMl0dMWR092AVP0T2Q@0<`8:03d21P1^:``0fj@E0;]62`2j30P0`0H:0<H630381@/0bPL9
0P3;2@X0?P3>2@X0d`/=0=L<3@3N3`h0h14=0>DD3`3U5A00i1<?0>LF403Z6180j1PD0><L6P3N6ad0
d10D0=DD5`3E4Q80eQ@D0=DC503F6Q`0_2P^0<5GG`3FRY<0iZje0?2na03Y]K`0kKFo0>R]]@3QY:X0
fj>Y0<ZUZ03H_;`0gjn[09XP7P2R1@/0X@@:09h31P2J0@<0U`4209H10P2D0@<0T@4308`10P2:0P80
Q`4308L110260PH0R1DG094W9`2B7Al0QP<808T21`2@10/0T@@:08D11P1g0@@0JP4205P10P1<0@80
E`4107T310204`H09ld61000o`090?ooo`80d51h00@0X23`0>QX?03oP000oh000`2P8?030?n00003
0=1@N02P8?00d51h01/0oh0000<0d51h0>QX?03@D7P01@3@D7P00`3oP000j6Pl0=1@N00N0?n00003
052@N000o`000?l000800?l0203oool0BP2fYYL0EVEe09NS[@2OYJT0YZJ[0:NOXP26N780UX920;bO
4P1cF@/0YHL@0<>P402iVAX0`9`^0:f<JP2aSgd0^Y^70;bST`3Odld0_ZjV0=C1]P3;/ZD0c[>N0=6e
X@3C^:D0e;ZX0=JmZ@3G`:/0f/Fd0=S5]03KbKD0f/Rd0>3<^P3Oc;/0i=710>GB`@3Ud/00hLjm0=k;
_03KbK/0ZJFd07YYR@2f>dH0ba8F0=0?4P364a@0bUI>0>>m/@2UUi/0H31G0;<=6@2g9bd0ahjV08P;
;02_10h0U2Df05eAL01e@U/0SQ@P09H93`31SY00bL_A0<;:d`31b]D0`<WD0<;<e@33c=H0^<340:Vd
Y02e^i80^;9J0;bX7P2cWQL0@]H;3`00o`080?ooo`H0X23`00<0oh000:0Pl02P8?001P2P8?000`3o
P000X23`0=1@N0030?n000030=1@N02P8?00X23`00@0X23`0P3@D7P20:0Pl0030=1@N03oP000oh00
00D0oh000P2P8?000`3@D7P0oh000?n000030?n000080=1@N02P8?00oh000?n0002P8?00d51h0?n0
003@D7P20:0Pl080oh000P3@D7P60:0Pl0030=1@N02P8?00X23`0080X23`00<0D91h003o0000o`00
3@00o`0;0?ooo`002P3oool0E02Kb7X0b/cA0:Ja]025RH/0GcLk06/nAP3EdMX0c=CL08nEV`0P2Q<0
=P<=04042@1d>0l0fj@D0;Dg2@2k20L0_`H90<<62P351@X0b@P:0<h:2P3@2PX0d``;0=H=303K3Q00
g`l@0>0A3P3R4Q00h18>0>DC4@3W5Q40iQD@0>XH4P3W61D0e@l>0=0>3@3E4Q40da8B0=DC4@3I5A<0
gALE0=lJ603L6a/0eadM0=@N8@3?7R@0bATQ0<dI8`3;61l0bQLK0<4D602T3QH0Sa8K09@o@`2cC4L0
X@@70:@1102O0@@0WP4509/11`2H0@D0V04709@00`2A0@<0SP4508P10P260@80Q`4508H11P2800@0
SP8809032P2?0PT0U0<<09D430270@L0N`4406d10P1K0P40E@4106T30`1n0P<0NP`202K=1@@00?l0
2@3oool0103@D7P0X23`0:0Pl03@D7P20?n000<0X23`0`3oP0000`3@D7P0X23`0=1@N0140?n00003
052@N000o`000?l000800?l0203oool0BP2SaH/0IGB508nLY`2QY:T0ZJFV0:fMP02TRT80^IXT09Ej
3021Ja<0^YX?0;6>9@2YRdT0[HiK0:Z:MP2_T7h0]iV70;nOS`39]:P0d/2d0<bgZ03</Yd0cK:L0<nd
W`3B]j<0dkbY0<JeX`3E`K00fl>b0=W3/@3Lak<0f/Vc0>3=_03PcKd0i=;30>KCa@3Ve<D0hm;30>3=
_P3LbKX0e/Ji0:VOZ@29KH<0[DI@0;PO8@374aD0`Q<C0<UKE@3:Z9l0H4U[0:LL<02g2A00/Qh^0:/8
5P2`0`/0XQ/W0:jH[028PiX0LD5G090D802C7RX0a:>]0<?9d030b]@0am7J0<K>e`33c=H0[[S505=P
IP1gOg40TIIo0;BYB@2m[1d0J<LG3`00o`080?ooo`040;Ph]02P8?00X23`0:0Pl080^3Rd202P8?02
0=1@N0030:0Pl02h>;@0j6Pl0080d51h1P2P8?000`3@D7P0^3Rd0;Ph]0020:0Pl0P0oh0000@0j6Pl
0;Ph]02P8?00j6Pl103oP0000`3XJ3`0X23`0>QX?0050?n00080X23`00@0^3Rd0?n0003oP000^3Rd
1P2P8?000`3XJ3`0oh000=1@N0020:0Pl00307QH]000o`000?l000d00?l02`3oool000X0oooo04<0
V/Ig0<O:c`2OZJd0Ri6D060m@01H:2h0d<gB0<KBf02JXJH08@`C03D32`0i0PD0MSd=0=fS5@2a:@@0
_PX70;d420341P`0a@D<0<H52P3<20T0d@X;0=<<2P3G3`T0f0h90=X=2`3N40h0gPl?0>@D4P3T5100
iaHB0>LG4`3Y61<0h1<A0=<<3P3D3`l0d`l?0=4?3`3F51@0g1PE0=dG5@3M5aL0ga/J0=lJ5P3N61H0
e18A0=DC4`3G51@0dQ0A0=4>3`3:3100]0H<0:`2202O1PX0W@d@0:<21`2S0@D0W`440:011`2M0@T0
V`8809X11P2F00@0TP4409011@2;0@<0R0420080QP4200l0Q`4308h11`2@0PX0R`480984302E10`0
R04707h10`1c0P<0GP4105d00@1c0@80O`8507X9000f/0D01000o`090?ooo`040=1@N02P8?00X23`
0:0Pl080oh0000<0X23`0=1@N02P8?000`3oP0000`3@D7P0X23`0=1@N0140?n00003052@N000o`00
0?l000800?l0203oool08`2@d7<0Mh>D086@W02OXjP0[jN?0;NN;@2kW@T0[I0>071I2@2]SPh0`9`?
0;6;>@2TQ6@0XX=g0:R:O02]SX40]IN50;jNR`34YY80b:^G0<Z^V@39[YP0ajjD0<bbV`3A]J40_j^K
0;NZW036/j40fL:_0=[6/`3JbK@0g<^h0=k<_03OcKd0hlo00080iM7302D0im;50>?>`@3MbKX0f<Je
0=G4]P3=_KT0UHFC07aSN02KDV40`1LK0;lC403@RWh0VXfJ0:IRKP2h>SD0/3H^0:/_:`2W:2X0Vb4Y
09mkQ`3:dMX0[k2o06m:H02:52D0SR0_0<Jg_P33c=@0b=3J0<G=f@2obmH0]/CB0725W01mT9h0TIjT
0:2SR`2c/Wd0NWa:00l00?l0203oool01@3@D7P0X23`0:0Pl02P8?00d51h00L0X23`00D0^3Rd0?n0
003oP000oh000=1@N0080:0Pl0030=1@N03XJ3`0X23`00@0X23`2P3oP000103XJ3`0^3Rd0:0Pl03@
D7P30?n000030:0Pl03@D7P0oh0000@0oh0000H0d51h0:0Pl02P8?00^3Rd0?n0003XJ3`90:0Pl003
0;Ph]02P8?00d51h00l00?l02`3oool000X0oooo01`0VLIc0<K8c@2[/kT0Q8V;06A8BP1761`0`Kg0
0<7<c`2NY:P08@hC03@42P0m1@T0PdX@0=fP5`2_80<0_PP90<872`351`T0b0H90<`92`3@2``0e0/>
0=H=3@3G3@/0f@d=0=L;3@3J3@l0g`lA0P3T4Q80=P3U5140j1DB0>DD503I3`h0ePh@0=PA4P3F4A80
ca0@0=8A4P3F51@0fQDE0=`H5P3M5aH0g1LE0=dH5P3G4a80f1DE0=HB4`3A3Q00d@dA0<H9402a0PT0
[0470:X2202V0PX0Y@490:<1202R0PP0WP8609/11@2K0PL0V@4609L11@2B0@D0T@86090210290@40
Q@4208@10P2600<0SP4809822`2C10h0U@D<09@42`290PP0O`4607H11@1X0@<0K`8307L10P1m0P<0
MPL004RH2@@00?l02@3oool20=1@N0070:0Pl03XJ3`0j6Pl0?n0002P8?00j6Pl0:0Pl0030?n00003
0=1@N02P8?00j6Pl04@0oh0000<0P<00003o0000o`000P00o`080?ooo`1;06_MD`21RIP0OHVH0::S
X@2`WTl0]iX:0:b>3@1ZE@T0TGP?0<>P2@2/RBX0V7UT09]kM@2TPG`0Z8Mm0:b=P02cUHH0_Yj<0<FW
TP38ZI@0a:NA0<FYT`39/9P0cK:K0=:hX@3=]Z80_jbI0=?0Z`3G`jl0f/Fc0=[9]@3JbKP0g<^i0=o=
_03Rckl0hm730>CB``3Sd<80h]310=c:^@3IakL0e/Ff0=K5]@3A`KT0][;005]IN02c@dH0`3/[0=BQ
T`2?T9X0ViFT0<6BSP3:Z:L0`Zjd0:jGY@1aGG80MGB60;W5cP3:d]H0Y:Zl05d`B`282QH0Z7^00<C=
e035cm/0a/oI0<7=eP2lamD0HWF>07F9V`2@WZL0XJVY0:BZZP1YIW003>P700h00?l0203oool0101@
T7P0X23`0:0Pl02h>;@70:0Pl0030>QX?03oP000oh000080oh0000<0j6Pl0;Ph]02P8?001`2P8?00
1`2h>;@0X23`0:0Pl02h>;@0X23`0?n0003@D7P01P3oP0001@3@D7P0j6Pl0>QX?03XJ3`0oh000080
X23`00<0j6Pl0?n0003XJ3`00P2P8?000`3XJ3`0d51h0=1@N0040:0Pl0050=1@N02P8?00^3Rd0?n0
003@D7P0202P8?020;Ph]0030=1@N00Xb3`00?l000d00?l02`3oool000X0oooo03L0Ul9a0<S;dP2R
[;00O8:406UBE00l3Q80[jJZ0<;;cP2QZJd08@`F03@32`0h0PD0S5PC0=JE4`2`5`L0_`L;0<<73034
1PH0bPP:0</82P3@30`0d`X=0=@;3P3D2`d0f0`?0=/>3`3J3Ph0gA0@0>8A3`3S4Q00j1HB0>TI4`3L
40l0ePl?0=LB4P3C3Q00c`hA0<lA4@3B51D0cQ8A0=0E5P3<71P0aB@N0<4d;@3DCdP0fU9<0=Q7@`3>
9280eQDE0=DA4`3;3140]0<:0:`2202Y0PP0Y`880080X`4601/0X0860:021@2M0@@0W04509P1102E
0PD0T@8609011P2@0@@0R`4108L10P270@<0R04508`1202B0P/0T`8;09@4302B10/0R0480841201k
0@L0O04508`21`210@<0N08206l60019V`d01000o`090?ooo`030=1@N02P8?00X23`0080j6Pl00@0
oh000:0Pl03XJ3`0X23`0`3oP0000`3@D7P0X23`0?n000140?n0000308300000o`000?l000800?l0
203oool0B`1<gcH0WjB^07^7TP2UW6X0[iH@0:N<2@1cG@P0MEh<0;:C2`2bTA/0TgIH09AgM02KNWT0
Wgej0:R4OP2[Rh40/9650;^KRP32XHh0`j>A0<J[U@39/9X0bkJT0<jfY03B^J<0d[bX0=>n[@3F_jd0
fL>c0=[5]03JaK<0f/Rh0=o:^@3OcKd0gljo0>3@_`3Sd/40i<o10>7>_`3Lc;X0fLNh0=O6]`3Fa;H0
cKfd09nGU`2aYZL0d:jM0=6`V`37[j80akNb08EhR@2=Df<0X3E30:@Z>P2U8c<0XAd/09/V=P2QA5H0
^86A0:ZR/P1iJ7L0QdU80:nKV@34cM@0a/oI0<O?f`34cMP0`lcI04aNO01LM8/0Lh6?096IX@2DW:@0
IVYj02Nn700>003o00P0oooo00@0D91h0;Ph]02P8?00^3Rd1P2P8?000`3@D7P0oh000?n000040?n0
00030;Ph]02P8?00X23`0080X23`0P2h>;@20:0Pl080^3Rd00<0j6Pl0=1@N02h>;@0203oP0000`3X
J3`0oh000?n000020?n00080d51h00L0^3Rd0:0Pl03XJ3`0j6Pl0:0Pl02h>;@0j6Pl0080d51h00H0
oh000>QX?03@D7P0^3Rd0:0Pl02h>;@20?n000030;Ph]02P8?00X23`00L0X23`00<0d51h06RX?000
o`003@00o`0;0?ooo`002P3oool0E02B_fd0a<O>0:Ze^024S8`0GDY<03462`2/Y:P0bM;D0:2Z[00J
3140;@<903L71P2@HAD0ch/G0:d@1@3020T0``L90<P92P371PT0c@X<0=0;303A2P`0d@X;0=H=303H
3@l0f0/;0=/?3@3L3``0gQ8<0>@E403Z6180gA8=0=8<2P3A3P`0dQ0@0<`<3`3:3Q40b@h@0<hD5033
5A@0]28N0:I8@03JWYD0n=;=0?[Qg@3lhMd0o]cI0?:YY033<2/0d1DD0<h?4P2k1`d0[0<:0:P22@2V
0@D0XP440:41102O0@@0WP4409`11@2K0@@0U`4308L0101m0@<0S@<608h10`2;0@40Q`4208P10`2:
0@D0S@8809<32`2B0`/0U0H=09443@250@H0OP0607X10`2>0PL0W04808h10P1i0@80K`@004RI30@0
0?l02@3oool0103@D7P0X23`0:0Pl03@D7P20?n000030:0Pl03oP000X23`00<0oh0000<0d51h0:0P
l03oP000A03oP0000`20`0000?l0003o0002003o00P0oooo04/0;^@M0:bX[P1nQG/0Yi@T0;6I1@2G
OPX0TGXE0;:D2`2cUa40U7U508mcK@2CM7D0V7Qf09enM`2UPg`0ZXMn0;2@Q02gW8/0`JBB0<NZV03:
[i`0^ZZL0<_7a`3Le=40c[NW0=:jZ03B^ZT0f<6b0=W1/`3H`k80elFd0=[8^@3JbKT0glfm0=k=_P3O
ckh0h]720>?A`P3RdKl0gljm0=O7]P3Fa[L0dlBe0=71/`3@_k40d;ja0<fl[@37]ZH0ak>V0<BcY`2n
/:L0]:^`0:21Q`2HEeP0[eE?0:iED02^G5`0Vd]C08`oC02FIW@0blW=0<G8c036c]80a<kF0<G@fP33
d=X0a<cG0<7;e`27Vk00NY6T08jMZ@2EWjP0WZRc06ehRP0g/C803P00o`080?ooo`03052@N03@D7P0
d51h00H0X23`00<0^3Rd0?n0003oP0001@3oP000103@D7P0X23`0:0Pl02P8?020=1@N0080?n0002h
>;@0X23`0:0Pl03XJ3`0oh000;Ph]03@D7P80?n00080j6Pl00<0oh000>QX?03oP0000`3oP000102h
>;@0oh000=1@N03oP0020=1@N0<0oh0000L0j6Pl0=1@N03oP000j6Pl0=1@N02h>;@0d51h00/0X23`
00<0P<00003o0000o`003000o`0;0?ooo`002P3oool0E02D`F`0alcA0:Ba]P23SH`0I5=D03/=402h
[;40cMKJ0:2Z[00G3140:`@902`30P2GIaL0bGhF0;<@202o20T0``L:0<L82`3:20/0cPT:0<l82P3B
2``0e0d=0=L<303L3Pl0gPl<0>4C3P3P4Ph0hQ@?0>HH4P3V5Q40f0l>0=@?3P3G4a40da4B0<d?403=
4Q<0aQHE0;XL6@2Y;BL0]g5Y0>c@bP3`i^80knWX0>_Zj@3/jnX0k>SX0?GUh`3SUY40_RLS0<`B5@2o
20l0[@<90:L1202T0@H0X04409h1102L0@D0W@8509X0102I0080V@4408h21@1l0@<0R08708l1102=
0P80R@4308X1102:00@0SP4709<32P2A0`T0T@D<09053@250@L0O`4607h10`2J0`P0X`<809L31P1j
0P<0JP<004FF2P@00?l02@3oool0103@D7P0X23`0:0Pl03XJ3`20?n000030:0Pl03XJ3`0X23`00<0
oh0000<0d51h0:0Pl03oP000A03oP0000`20`0000?l0003o0002003o00P0oooo04/00?l00<:dX`2=
QT`0/Y/;09^21`2VRa80TWL50;2E4P1DC1T0Q71/08mcLP2DMG<0VgMf09elN02TPg`0ZHUn0;2CQ02g
Vh/0_Z:>0;nSS`2nZ9<0ZZ6F0;Vj^`3;`K/0cKNU0=6hZ03B_:`0e/2`0=O1/03IaK80eL>e0=73]`36
_:l0b;jc0=S?_P3Jckl0h=710>7@`@3Oc[l0g/k00=S7^`3Ea[L0e<Ff0=72/@3?`K<0cKja0<Zi[039
^:T0a[BV0<6bY037^k00^k:[0;^c[03:alD0a/C60:F[/`29UJD0:CeI0:Vfa02BTIl0UZ6[0<K?eP35
c]H0`/gG0<C?fP34d=`0`lgH0<?>f@1]PIP0G7B908ZMZ@2S[[L0XjZc07AoS`1<QTL03P00o`080?oo
o`03003o002P8?00^3Rd00D0X23`00<0d51h0?n0003oP0001P3oP0001`3@D7P0X23`0:0Pl02P8?00
oh000;Ph]03oP0000P2h>;@0103@D7P0j6Pl0=1@N02P8?0=0?n000070>QX?03oP000oh000?n0003@
D7P0j6Pl0=1@N0040?n000030=1@N02h>;@0X23`0140X23`00<0^3Rd003o0000o`003000o`0;0?oo
o`002P3oool0?`2@_6L0b<c@0:Rd^P1jQhP0HUIG03l>4@2jZ[00c=?K09ZPYP0M3180<0@<03030P2/
Na`0`VX?0;H=2@2o20/0`PL:0;l51`351`X0cPX;0=8;3@3F30h0f0h=0=X>3P3L3`h0h10>0>@C403U
4a00iA@@0>DE4@3O5100d`h?0=DA4P3E4Q80cQHB0<<L602e:B<0]V1H0<VIT@3XdL`0k>KU0>_[k03X
j>X0jN[/0>OXjP3Yj^`0k>c_0>g]kP3`iN<0l;Ne0;h];`343A40/PH;0:P32P2V0`T0X04509`10`2H
0@D0V@4509P1102I0PD0VP4409T21P0209021@0C08l10`2:0@40R`4408T110280@@0S@4709822@2F
10/0U0D:094530260@P0O`4608h22@2R0`/0X08909<2101j0@<0I040042B2004003o00T0oooo00@0
X23`0=1@N02P8?00j6Pl0P3oP0000`2h>;@0X23`0:0Pl0030?n00080X23`A@3oP0000`20`0000?l0
003o0002003o00P0oooo04/00?l00<^/L@2VU1`0YY4809Im3@2VS0d0]iP707IX5`0W;3`0PVic095b
M@2DMGP0VWUj09n0O@2TQGl0ZXV20;6BQ`2jWHl0_Ij?0<6ST@2oYI40ThIk09Z>QP2hYiP0d;NU0=6j
Z@3A^JT0dkj/0=O1/@3JaKH0^JfS0::JU02e[:40XYVC0:>QV03Id;l0h=330>7@a03NcL00g<fo0=W<
_@3CakL0d/Ff0=33]`3=`;@0c<6c0<fo/`39^:X0a[BX0<JdZ`34]:X0`[J^0<O1_@2b/Jh0];Jj0:^b
^P2NZkX0X;C608fX_@34e=d0^l[A0<KAf@36cmP0a<oH0<?=f@32cMT0`/kG0<7<f020TZH0FG>:06j2
T@2BWZL0TYZS06ejRP1TG5h03P00o`080?ooo`03003o002P8?00X23`00@0X23`00<0^3Rd0>QX?03o
P000203oP0000`3@D7P0X23`0:0Pl0020?n000070=1@N02P8?00X23`0:0Pl02h>;@0oh000>QX?00H
0?n000030;Ph]02P8?00X23`0140X23`00<0d51h003o0000o`003000o`0;0?ooo`002P3oool0@P2@
^V@0`LG90:bh_P1ePh<0LFQX03h?502`WjH0c=?J09ZMXP0O31<0:P<803<7102gR1`0]EL>0;@8202m
1PX0`0L80<4620341PP0c0T:0=<<3P3F3@l0e0d;0=X@3@3K3`d0ga8?0><B3P3T5A00ha@?0>8F4@3B
3P/0ca0@0<`C4@387AL0[34W0;9TF`3S^K00k^7L0>[Vi@3ViNH0inOW0>WXj03ZjNT0j>SZ0>SXj@3/
k>d0jNW[0>_/kP3/kNh0mNCU0<m_KP334A40]@H90:`52P2V10T0X@4609`1102J0@@0V04609L0102D
0@@0U`4609H11P2D0@@0U08509021`80S0440100R04308L10P280@@0S`8809@22P2F10/0T`@;08P1
20280@H0VP8809D32P2;0@D0SP8507/20P1W0@00D7D61000o`090?ooo`<0X23`0P3@D7P0103oP000
d51h0:0Pl02P8?030?n000030:0Pl03@D7P0oh0002<0oh0000<0d51h0?n0003oP0007P3oP0000`3@
D7P00?l0003o0002003o00P0oooo04/00?l007g67P2YU0d0IUP2091l4@2JP`d0]Id^04Y8>00b=UD0
Pfmd08maMP2FMWX0VgUl0:1mO@2SQ7l0ZXb60:j=QP2gVXd0_J6A0;nRSP30Xi80YI210:VHR032[Id0
_JZL0=2jZ@3B^:T0dkb/0=Bo[`3Ha;X0SHB30;6[YP31^K40[jJU08>3OP3Hd;l0gm720>7Ba@3Ncl80
g<_10=W:`03Cb;`0d/Fj0<o4^03<`KP0c<6f0<No/P33^Zh0`;:T0<2bY`2m/JL0^kB_0:bT[02^WZ/0
bk:i0;JTZ@1MJGl0TjBh07>=X`33dmd0^LG;0<OAfP35dMT0_lcF0;k;eP31cML0_lcE0<7<e`2EYk/0
LhbR08VMZP2GY:`0Uj>[07b9V01SIF/03P00o`080?ooo`03003o001hF;@0X23`00@0X23`00<0d51h
0:0Pl03XJ3`00P3oP0000`3XJ3`0oh000?n000030?n000030=1@N02P8?00X23`0080j6Pl00H0X23`
0=1@N02P8?00d51h0;Ph]03XJ3`40?n000030=1@N03oP000oh0000`0oh0000L0j6Pl0?n0003oP000
oh000=1@N02P8?00d51h01<0X23`00<0d51h003o0000o`003000o`0;0?ooo`002P3oool0E02?^640
aL[>0;2la026T980JV=U03P=5@2ZVZ00cmOL08fDU`0K2a40:`<:03l<0P36Tah0[D<;0;P92`301``0
``L<0<D62P3920/0c0T;0=4:303B3@h0cQ0?0=TI6@3K4100ga8?0=`C3`3F<BT0eS/b0=4b:@39<BT0
bdU10<iTF`3GRh<0kLc70?;Wh`3/j>H0jNSX0>[Ui`3/h>D0j]3F0>Nc_@3FT9/0W6A`0;^a]P3/k>h0
k>c_0>g]l03/kNl0k>SV0>2TY02k5QL0^`P<0;462`2V0`X0XP480:02202K0@<0V@4509<11@2B0@D0
TP4409801P2B0@H0T04608`11@2;0@L0R`4508P10`240040R08508l22@2C0`/0UPD<09@5302>0@T0
V`4;0:432`200@D0RQHJ08<4201i0@80J@4005mI1P@00?l02@3oool01P2P8?00d51h0:0Pl03@D7P0
j6Pl0?n00080j6Pl00H0X23`0?n0003oP000oh000:0Pl03@D7PJ0?n00080d51h00<0X23`0=1@N03@
D7P09P3oP0000`3@D7P00?l0003o0002003o00P0oooo04`00?l003gR1P2BPPT0NVX50:bE2@2cWbX0
SX=C04I;G@0l@5h0QW9d099cNP2FMW`0VWYl09amO02TQX<0Z8R50:j=P`2iVXd0^I^;0;nQS@30Xhh0
`ZFD0<>XU`30ZYT0YIF;0<JaW`3C^ZP0d;jZ0=G3/P3E`KH0S86108J4R02<Rhh0Ogn109NCRP3Mckl0
glo20=oA``3Ld<40f<^n0=?8_P3Aa[`0dlFn0<k3^`3=`k/0cL:h0<Vn]@31]jh0_KB/0;>/[P2HRYX0
TVAn09/eCP2Z6bh0[18O0:PW<035RYP0LFYk07j?XP2ncm/0b=;J0<GBf`34c]P0_lcE0;c:d`2oc=L0
_l[E0<7;f01/OiL0J8:M07bBY02Y]<00[;O206EdRP1KI7806=8?3@00o`080?ooo`03003o001@T7P0
X23`00@0X23`00<0^3Rd0:0Pl03oP0000P3XJ3`60?n000030=1@N02P8?00X23`0080X23`00H0^3Rd
0?n0002h>;@0^3Rd0:0Pl02h>;@20?n000030=1@N02h>;@0j6Pl00l0oh0000D0d51h0:0Pl02P8?00
d51h0>QX?0020?n000030;Ph]02P8?00X23`00l0X23`00<0d51h052@N000o`003000o`0;0?ooo`00
2P3oool0E02=]Eh0aLW=0;6l`P23SI00N7Ah03H?5`2]W:D0d][Q07n6S@0M2a<0;P<704LH0@3CWB80
Yb/60;/830332@d0``L:0<08302c1@X0/`H90<T;3@3:3@h0_Q`L0<TN7P3M3a00h14=0=PB402K8b<0
a8f=0??Bd03ihMh0mnOU0?CXi`3cjnX0knWZ0>kShP3]d]D0hZR^0=5iP@3@G6L0a2hi0<HM9@3=6al0
]1hQ06Xl@@3YjN/0jn_]0>c^k`3Zjnd0k>g^0?GGfP2l:bh0bPhC0;`8302[0`X0X`070:021P2J0@<0
V@4409<21@2@0PP0T`4709<11@2A0@D0S`4608X10`2:0@@0RP8508P11P220@80P`4308`21`2A0`P0
U`D>09L53@2R10d0ZP<;0:022@1i0@D0N`<807L21`1f20/0I`4105]F1`@00?l02@3oool30:0Pl003
0;Ph]03@D7P0oh000080d51h00H0X23`0?n0003oP000oh000:0Pl03@D7P?0?n000030>QX?03oP000
oh0000@0oh00103@D7P40?n000030>QX?03oP000oh0000<0oh0000<0j6Pl0?n0003oP0007P3oP000
0`3@D7P00?l0003o0002003o00P0oooo04`00?l001Sb1028LPD0Y8l;0:nG102YUT00XYjG03DmF`1;
BfP0R79i08e`MP2BMGP0VG]n09imOP2RPH00YhF10:Z;P`2`ThP0_9j>0;nTS`2oYHl0a:NB0<R[UP39
[iX0a[6M0=;0Z`3E`:d0ckfZ0=70[`3B`;40a[BY09f?RP2OUHl0]:RM0=C4]P3Mc;l0g<g00=_=`P3H
c<40el_20=?;`@3BbKl0d<Nn0<g4_@3<a;d0bL:l0<Bn_02`Z:l0VhBG09ECKP2/;TD0/a0N0;T;402f
2@l0^0H?0;L42`2[2aP0VcQ60:bIY038e=/0bMCM0<KBf`33cmT0`<cD0;o:dP31cML0`/gG0<3=f02A
X[D0F76807V@X02CWZX0Uj2/05eYP@1>FFX0;[HQ3@00o`080?ooo`03003o000Xb3`0X23`00<0X23`
00@0oh000:0Pl02P8?00d51h203oP0000`3@D7P0X23`0:0Pl0070:0Pl0030=1@N03oP000oh0000l0
oh0000D0j6Pl0=1@N02P8?00X23`0=1@N0060?n000030=1@N02P8?00^3Rd00h0X23`00<0^3Rd06RX
?000o`003000o`0;0?ooo`002P3oool0:02:]5/0^Kfn0;C0a`2?WJ80M75f03HA602YVJ40e]cV071f
O`0L2a<0<0D906@e403BVRL0X1L50;P7302m1`l0^@L<0:@31`32;CD0`CDj0:L72@3=3Pl0fB<V0=PM
7`3O4A00hQ8@0>8C3`3B4aD0[a4H0:dd@034IW80bWJ10=j<UP3MPhl0eFMc0<i?F039<SX0d1lV0=4I
7@3A5AL20=HF6@0E0=@F5P3:6A/0MAHI0:jWZ03Xj^/0jnc^0>c]k`3]kO00l^OZ0<MIG0384QD0``/=
0;@62`2X0@P0X`4809/1102F0@80UP4409D11`2?0PP0T0880080T@4701<0S`8508d10P2=0@@0R`46
08L01@240@@0S08808h12@2C10`0X0D>0:d5302X0PT0W@<:06d1101a1P`0N0<907@;3P1/0P@0F4l3
00@00?l02@3oool01`2P8?00d51h0:0Pl02h>;@0j6Pl0?n0003@D7P00P2P8?020?n000030=1@N02P
8?00oh0000l0oh0000<0j6Pl0=1@N03@D7P0103@D7P?0?n000030>QX?03oP000oh0001d0oh0000<0
d51h003o0000o`000P00o`080?ooo`800?l004X0ThX60:jJ1@2_VA@0ZiiV08F4RP0nAVL0EEI]08I`
MP2>L7L0UGAk09YiO`2OOGh0XX610:F3O`2/R800]YF<0;bNS`2nXHh0_j>?0<BYUP36[9H0bk:L0<ff
Y03C_Zd0d;fZ0=:nZ`3C_Jd0d/6_0=K5]P3D`[@0fLRi0=c;_03Jb;X0flZm0=W;_@3Eb<00eL[40=K<
a`2m_l40`lG90=K0_P3E]KL0aZBZ0;^CX@2ZJWl0ZdEM0;<S<@2h5QX0]AdK0;Lj<@2iG500W5AF09P_
?@2b1a00]P@90:/8402D?DL0`lS@0<kJh@36dm`0aLoI0<;<eP31bM@0`<cD0<C?f032c]T0Sj>g05ae
R`2;X:l0UJ:^09NR[`1PKhL0@51P03bV;`d00?l0203oool2003o00L0X23`00@0oh000>QX?03@D7P0
d51h1@3oP0000`3XJ3`0X23`0:0Pl0070:0Pl0030;Ph]02P8?00j6Pl00T0oh0000<0j6Pl0=1@N03@
D7P00P3@D7P20:0Pl0030=1@N03XJ3`0oh0000@0oh0000<0j6Pl0?n0003oP0000P3oP0000`2P8?00
j6Pl0:0Pl00<0:0Pl0030=1@N02XR3`00?l000`00?l02`3oool000X0oooo01T0RK1G0<kAd`2ia<d0
Pi:F08F4R@0d4QP0ZIVQ0=CMiP1MHV/08@/B03462@29EaX0bhdP09`?1P2g1`d0^0PA0:P5302Y10X0
`0XC0;L:4@2L0`D0c@d>0=<>3`3J3a<0ga0@0080h1<?03T0dPh=0</;2P3=4180dADH0=8H7@3?5al0
dATP0=@I7@3A5aP0e1HF0=LI603H7AX0da/G0=<K6@3G71`0e1DH0<lE6@2M61`0HDE70>?ViP3Xjn`0
jnc^0>[[k@3^j^/0cgn30<4G6@3430d0^PP<0;05302V0@T0V`0409P2102D0080T`4408810P230@<0
T08708h11@2<0@@0RP0108d2102:0@D0R00408L10`2;0PH0T04:0:08402W10/0[0@<0:<1202L0PT0
K0L;04`0101`0`X0N0L=07020`1KD0@01000o`090?ooo`080:0Pl03oP000X23`0:0Pl03@D7P0oh00
0=1@N02P8?030?n00080X23`9P3oP0000`3@D7P0oh000?n0000M0?n000030=1@N000o`000?l00080
0?l0203oool2003o001:07Zg1@2[V140/:EL0:ZUT023Q8`0>dEU061NLP27LGL0TG=j09=aN02GLgL0
WGUj0:>0PP2WQH<0ZhR20;BGSP2lWI<0`Z6C0<2ST@2oYI@0bJbK0<V_VP3;]:40dkfZ0=:oZ`3@^ZT0
d[n/0=;0[P3Fa;H0d/6c0=O7^`3Jb[d0elRj0=W;_P3Hc;l0f<c30=S;aP3Fc<L0[[Bo06aoX@2RM8T0
[D9B0;4c@P2g:SP0^R4Y0;XT8P2o?300`F=E0<JCQ02lXI@0[j6C0:JMWP1JAF@0WQ4O0;H33@2b0``0
XahV0;Z^^03>fN80amCN0<7>e`35c]P0`/_E0<C>f034d=X0`loK07b?Y01UQ9h0MY2P09VZ]`2O[kh0
Gg2;049CI@1<Pcd=003o00P0oooo0P00o`030:0Pl0070=1@N02P8?00X23`0:0Pl03oP000^3Rd0=1@
N0080?n000T0X23`00<0^3Rd0?n0003oP000203oP0000`2h>;@0X23`0:0Pl0060?n00080j6Pl0P3o
P0000`3@D7P0X23`0?n000030?n000030:0Pl02h>;@0X23`00`0X23`0P3@D7P=003o00/0oooo000:
0?ooo`1D06?1@P39b//0]/7909FSY`1dMG/0=1@K0:fMYP3GgnL0CE9J028:4@0a1`D0[7`P0;mj6P2M
2`D0/PD<0:d83P2@0PH0]PP?0<@63@2f1`/0W0D60<h=3P3?2@X0f0h@0=/>3`3M40l0g1<A0<`<3@38
30`0cPlA0=8D4P3?7a`0cbhX0=8i<P3A;bX0c24L0<TL6P2j>C@0ggI]0=ajK`3QR7h0j8N20<0_;`3A
61`0_A`O04h=3`3@c<`0j>[Y0>[[k@3[k>`0j^[[0=fZ[02e8B@0a0d@0;P52`2d1@l0[0<;09h11`2G
0@D0T`4309@00`2>0P@0R@4308h20`2=0@80T04708l11P2>0@D0S04708`11@2;0@@0S08609T5302^
2A80/PP@0:/52`2U0@T0W`89094R:@1i>Ch0KP@:08<32@1f0@<0Fd`41000o`090?ooo`0807QH]03o
P000X23`0:0Pl03@D7P0oh000=1@N02h>;@30?n00080X23`9P3oP0000`3XJ3`0oh000?n0000M0?n0
00030=1@N000o`000?l000800?l0203oool2003o001:07bj202ZX4h0Wj6K09nQYP2GVZD0<SmL06]Y
N@24KWD0SG5g09IdNP2KMW/0WWUk0:9mO`2WQX80ZHR20;FER`2kWY<0_j6E0;jOT`32Xi40b:^J0<^a
X03;]:00dkj[0=:n[@3A_Jd0dknb0=?0/P3E`kD0d/6c0=S5^@3Jb[h0elNj0=S:_P3GcL<0f<c50=O;
a`3EblP0dl[:0<2nb02PWk00/9bX0;NCV`31TiD0dZBJ0=>^XP3;/jL0`[BZ0;V_YP2bZj40/:VO0;Ja
[P1NHh00R3A:0:l43P2b0@`0Y`PB0:MkQ`3=f^80c=WR0<GBf`34d=X0aLoJ0<;>fP33d=d0`LoK09f_
a@1FLi@0E7BK03M@QP0^@gh062aV04AGJ`1DKT<=003o00P0oooo0P00o`020:0Pl0030=1@N02P8?00
X23`0080X23`0P3oP0020>QX?0P0oh001@2P8?020=1@N0d0oh0000D0^3Rd0:0Pl02P8?00X23`0=1@
N0020?n000030>QX?03oP000oh0000<0oh0000<0X23`0=1@N03oP0000P3oP0000`2h>;@0X23`0:0P
l00<0:0Pl0030=1@N03XJ3`00?l000`00?l02`3oool000X0oooo05@0A[DT0<k;a`2mbLl0T:2V07Um
PP0a5Q/0ZifW0=KNi`0e>40090TA03d?0`38V2`0ZE`D0:89202`1@l0V@L>07l2102j20h0aPP>0:`6
2@2X1`X0d`d?0=H<3P3G3`h0fQ0>0=P@403A30l0bPX=0<d>3`354A<0XR`W0=bUW03hf]@0n>7L0?SI
e03b`kd0eIJ?07YMFP3TfmT0j^CT0>cWi`3eiNH0c7n20<PQ903@6a`0RAHH09n;S@3/k>d0k>g_0>OX
j@3XjNT0j];C0:Di?02h41@0]PH=0;<63@2^10/0Y`8809h21P2H00<0UP4308l20P290040R@4108`1
0@2>0@<0T@4509811`2>0PH0R@4408X10P2F0@@0Z0@:0;@83`2c1Ph0[P@;0:T22@2P0PP0U@P?08/I
80261Ph0QP4607P10P1d8`@4003o00T0oooo00P0D91h0?n0002P8?00X23`0=1@N03oP000d51h0;Ph
]0<0oh0000<0X23`0=1@N03oP000703oP0000`3@D7P0oh000?n000060?n000030>QX?03oP000oh00
01d0oh0000<0j6Pl003o0000o`000P00o`080?ooo`800?l004/0OKT@0:6LJ@2U[;00X::Z07j1SP0i
A5l0LVei08E^M`2>L7T0UW=h09]dO02MN7/0XWio0:J2P@2ZQX<0]9B<0;RJS`2lWi00_Z2B0<:STP39
Zi/0bk6Q0<bdXP3B_:/0e<6a0=:n[P3A_[00dl2b0=C2]@3B`;<0eL>f0=S9_03Fb;d0eLZn0=C;`P3D
bL<0dLS40=C9a@3BbLH0d/[80<c7``3<b/H0bLS40<O3`@39`[`0akfg0<6i]02d/K<0]k2`0;b/YP2g
YZ40]:bW09jT/P1LAV/0X0hK0;<2302_10h0/5=K0=KHgP3;en<0a]CN0<GBg036dMd0a];M0<??g@2S
^=D0<df600@LH`0156000A9N004AF`014U/04bA>05aLEP06l`<03000o`080?ooo`800?l01P2P8?02
0;Ph]0030:0Pl03oP000X23`00H0oh0000<0d51h0?n0002P8?000P2h>;@20:0Pl0030>QX?03@D7P0
oh0001@0oh000P3@D7P30?n00080X23`0`3oP0020=1@N0h0X23`00<0oh0002S8?000o`002`00o`0;
0?ooo`002P3oool08018]R<0a/;00;?0a`2CXjX0NGf103<E6P2^X:P0dm[T02//=@0V2A40D20:0<jM
;@2<?a00WPP;0:`73`2910T0M`450;483@2l2a00V`<70;892`3B3@h0dP`;0=8:2`3H40d0c`/;0</9
303=3@d0bP`;0:H@4@2SOGP0lNcZ0P3/k>d0<P3[jnh0jn[/0>cXi`3OfmL0dlo?0>OVj@3XjNT0k^SX
0?K8bP2o;300dQHK0;HP9`1nEEP0k>k_0>_]k@3UiNP0jNW[0>kQh`2/HVH0[1DH0;D83`2b1Pl0[0<;
0:/32@2S0@D0V@0309D21@2>0@40R`8208T10P2;0@40S`4309411P2B0@T0S00408`1102C0@<0Y@88
0:`22@2e1A00]0D>0:h32P2Y0`P0Y@8809d22@2B0`/0S04:08@21@1c0000OQ@51000o`090?ooo`08
052@N03oP000X23`0:0Pl03@D7P0oh000=1@N02P8?030?n000030:0Pl03@D7P0oh000200oh0000<0
d51h0?n0003oP0008`3oP004003o00P0oooo0P00o`00B`1Oe2d0Si=n0:2V[P2SY[00S8bL03PnF01h
KgX0QG5i08e_N02FLWT0WGEk0:5jNP2SP800YH:10:Z6P`2aT8T0^YZB0;ZHS@2gUHP0`:6A0<FZV@39
[ih0bkBV0<fiZ@3C`K<0c[^_0=2n/03B`K80d/2c0=C1]@3Ea;H0eLRk0=G8_@3Db;h0d/[10=?:``3B
b/D0d/_40=?;aP3Bc<L0cLW30;6ka@20T:T0XhjW0<MgPP38LgP0b8V>08mmU@28Hgh0/cm:0;Lj@`33
Rh`0[jj`059LP02B<DP0/PLC0;833@2N5R00elG<0<[Dg`36dm`0a=3K0<?AgP31d=l0NY:i00hWK@01
56H0019R004BH0024UP00Q9F004@E`0244H0ATiC01SB3`0<003o00P0oooo0P00o`000`1@T7P0d51h
0:0Pl0030:0Pl080d51h00<0X23`0>QX?03oP000203oP0000`2h>;@0X23`0:0Pl0020=1@N140oh00
00@0^3Rd0:0Pl02P8?00^3Rd0P3@D7P20:0Pl0060>QX?03oP000j6Pl0;Ph]02P8?00d51h0`3oP000
0`2h>;@0X23`0:0Pl00<0:0Pl0030?n0001@T7P00?l000/00?l02`3oool000X0oooo05@0B;LU0<G2
`02ia/d0T9fS07b1Q00c5Q/0/ZB/0<S?f00N6R@09`H>068c4P3EXS40R2d=0:<62`2/1Pl0Q@@906/1
102?0`T0U0<908D1102d2Pd0d``>0=8<2`3D3@h0d0/=0<D42@3920h0cP`=0<h?402?3Q00^ZVV0>k^
kP3]kO00k>_^0>WLh02nTid0_iNS0>CLg`3ViNL0i^GX0>OYj@3XinP0n>7S0<I@E03D6ah0bAdP07<]
<P3Yjn`0inSY0>SYj`3Wi^T0j>7T0=RXZ`2W7b<0/PL>0;053P2]10h0[P<;0:/32P2N0@L0U`4509<1
0P2@0P40S08308X20@2=0P<0S`450981202B0@D0V0450:821P2Y0PP0Y`880;853P2f2100/@D=0:X3
2P2S0@L0V08809032P2;0PL0Q08607<10@1j4@@4003o00T0oooo00P0D91h0?n0002P8?00X23`0=1@
N03oP000^3Rd0:0Pl080oh0000<0d51h0:0Pl03@D7P05@3oP000103XJ3`0d51h0=1@N03XJ3`50?n0
00030>QX?03oP000oh0000H0oh0000<0X23`0?n0003oP0007@3oP004003o00P0oooo0P00o`00B`1Z
gD`0SINK0:J^^@2IW:H0TYBQ03e2E`1jKWP0Qg5g08i_MP2FLGL0VgEi09eeMP2QO7`0YX>10:Z5Q02c
SHX0^IZA0;fMT@2nWi00`::A0<>XV03;/J40cKFV0<nk[03A`;<0c;Z/0<jl[03A`;40d/2d0=C1]`3D
`kH0eLVm0=?7_P3Aakh0dLW00=C:`P3BbLH0dLW50=;9``3BblL0c<W506EoW`1fPK40[De[0<PH8`38
51`0^Q/T0;0nD02oI7T0]a4K0<L?5P30EeL0]k2_08NDZ`1a@600YPdK0;@43P2W1a<0_i2I0<_Cg@37
dm`0a=3I0<3@g@2G[/h01b1X004CHP014F0001=M00<GE`0K;5L09cQY01HYFP0?7DL0<cm?02_7900<
003o00P0oooo0P00o`000`1@T7P0d51h0:0Pl0030:0Pl0030=1@N03oP000oh0000T0oh0000D0d51h
0:0Pl02P8?00X23`0=1@N0030?n000030=1@N03oP000oh0000`0oh000P2P8?001P3@D7P0oh000?n0
003oP000d51h0:0Pl0<0oh0000<0d51h0:0Pl02P8?000`3oP0000`3@D7P0X23`0:0Pl00<0:0Pl003
0=1@N01@T7P00?l000/00?l02`3oool000X0oooo05@0A;<S0;Jc/P2mb=00TJ2T0822Q`0c5a`0]JRa
0;BkaP0I4A`0:PH?07m>6@3;U2d0QA860:`62`2a1@d0U`H?06@11@1h41L0P1PO08<32@2n2@d0d@`<
0=8;303E3Q00a`P;0<@63@392@l0cPX?0<l>3`2F41<0/Z>T0>c/k@3YjN`0jNSZ0=F//02^:2l0_1hV
090c?`2XUj00hn;U0>GVi`3Vj>T0kNGU0=N7S03@82@0dAPK08HC6@30_;h0i>OX0>[Zk03Yjnd0inKX
0>OBd`2S?D00/0TA0;033@2`1@h0[P<;0:h22`2W0PT0W`8709@1102@0@40SP4208/10@2:0P80S`43
09L11P2R0PT0Y@870:D11P2B0@@0R@840:L63@2f20l0/@D:0:/3202S0@L0T`88084110270PL0Q@46
07P10P1e30<4003o00T0oooo00H0J:Pl0=1@N02P8?00X23`0=1@N03oP0020:0Pl080oh0000<0d51h
0:0Pl03oP0005@3oP0001@3XJ3`0oh000?n0003XJ3`0d51h00@0oh0000D0j6Pl0?n0003oP000oh00
0>QX?00T0?n000@00?l0203oool2003o001;06[LCP2GXJ/0WZFc09fOZ020Qi@0>dEH07a^N@26KgP0
SVme09A`M`2LM7T0XGQj0:9nP02UP800ZX>20;:<R02gUXh0^Yb@0;nQU032XiD0aZZM0<Z`X03<]JH0
d[^]0=:n/03?^j/0cKVZ0=2n/03A`[@0dl:i0=71^@3=`[/0d<Jn0=;8`@3Ab/80e<_40=G>a`3DblH0
eL_50=?;a`3=bl/0E72H0:VUdP2b>4d0d18H0<TC5@3>FUT0X4MJ0:D_A0314ah0b@`C0;DV:`33Y:@0
Y:^f0518J`286Bh0Z`DA0:X43P2[EV40c]7I0<K@f`35dM/0[l;L02<nP0015fL00AAO00@JG@0iE8D0
JX2M08nP]@0X?FD0F6f305]TMP0T<T@0>J@`00`00?l0203oool2003o0003052@N02P8?00X23`0080
X23`00<0^3Rd0:0Pl02P8?002`3oP000103XJ3`0oh000;Ph]02P8?020?n00080^3Rd3@3oP000103X
J3`0X23`0:0Pl03@D7P30?n000030=1@N03XJ3`0oh000080oh000`2P8?030?n000030=1@N02P8?00
X23`00`0X23`00<0oh000:R8?000o`002`00o`0;0?ooo`002P3oool0E015/R@0^kVj0;g9dP2?WZD0
MGQo02lC602fZ;80Yjjg014<5@0T1@X0T60P0:]Z7`292`H0/0L<0;@52`2^2Q80L`<60>BQZ03SXJP0
TQ4D0<H:303A3@l0dPd?0<`83P301@T0`PD;0</;403@2Pl0da0C0:TB5P2JQ8P0jNO[0>GUi`3Vi>L0
g[jn0:HZ;03451P0/1PP03d83`39aLD0i^KW0>OXj03^jn/0h;2a0;/T9`3>5a/0XQHK09>3QP3Ri^L0
iNWZ0>KZj`3Ti^H0i]cM0:iSIP2[2a<0Z`<;0:`2302]10`0Z@8;0:D12@2Q0PL0UP490981102A0@@0
T@8408d10@2B0040X@460:L12@2V00L0X`4509/42@240@@0V@H;0;L94`2b10`0[P@:0:D1202H0@P0
Q`0508L11P260PD0N`4307D:0P@00?l02@3oool01P1@T7P0X23`0:0Pl02P8?00d51h0?n00080X23`
0P3oP0000`3@D7P0X23`0?n000040?n00080X23`3`3oP0000`3@D7P0oh000?n000020?n000030=1@
N03oP000oh0000/0oh0000<0d51h0?n0003oP000703oP004003o00P0oooo0P00o`00B`1RdCl0XZRb
09RP[@2LX:d0@DmX02lhDP1lJgD0Pfae08a`M`2FLGT0W7Mm09ihO02SNh00YWn10:V1P`2WPWl0]IJ?
0;bLU@2oWi@0`ZBD0<BXV039[Yl0b[>T0=6kZ`34ZID0e;f[0<fjZP3?`;40d;nc0<jo^02cZ:00_;:/
0;:/Z03Aal40dlW30=?;a@3BcLL0dlc50=G=b`3Dc<X0dL_<07B:[P1:G940[E=^0<lC6P355QP0fIZG
0;Ra]P1lJXD0VSE@0<8>5`2k3A<0bWn10:JVZ01?FgP0N4a]09H<7@2W0`d0Ta<P0<nob036d]`0_/gO
03E?S0026Vl011aU04UUT01MMiD0Kh^R07^BY@16HHH07cML06ioQ@1^NWl0;3U504n<A`0<003o00P0
oooo0P00o`000`1@T7P0X23`0:0Pl0030:0Pl080^3Rd00<0j6Pl0=1@N02P8?000`3XJ3`50?n00003
0;Ph]02P8?00^3Rd0080^3Rd0`2P8?0>0?n00080X23`00L0d51h0?n0003oP000oh000;Ph]02P8?00
^3Rd0080oh0000@0j6Pl0:0Pl02P8?00X23`0`3oP00<0:0Pl0040;Ph]03XJ3`0oh000=1@N0`00?l0
2`3oool000X0oooo05@0BkPX0;Fa/032c=D0UjJ/07n2Q`0b4aT0_k:i09RPZP0A31@08@D80:Ad;02:
?@d0TPT70:d42@2e1P/0]PL>09`83@2VAdd0YTU;0;TV9P3930d0``@80</=40351P`0``P<0<D83P38
2@/0c``=0<h<3P2i4aL0NUEG0>KRi@3Vi>L0i>CW0>KFe02XDdl0^QTL0<4H701[3180UXV:0>KViP3W
i^P0inKW0>oEe`2]>3`0`Q<H0;@G7@1eCe<0hnCU0>GUi`3Zj^`0iNGW0>?Mg`2oRH`0Y@lE0:`73P2]
10d0[0<;0:T22P2U0PP0X@<809/1202L0@L0UP4409410`2F0@80X@860:T1202X0@P0Y@470:<11@2Q
0PH0V@<809/32@2e2@l0]0D>0;04302T0@X0V`4809811P290@<0Q08407d2101g2P84003o00T0oooo
00P0D91h0=1@N02P8?00X23`0=1@N03oP000X23`0;Ph]080oh0000<0^3Rd0=1@N03oP0004@3oP000
0`3XJ3`0oh000?n0000:0?n000050>QX?03oP000oh000?n0003XJ3`01@3oP0000`3XJ3`0oh000?n0
000L0?n000@00?l0203oool2003o000V037V7`2QWj@0Vj>_09BHYP0N9TL0?41J07UZM024KGL0Rfmh
09A`NP2HMG`0XG^30:9iOP2VOh40ZX>50:J1OP2dTX`0^IZA0;nNT`30Wi40aJRG0<R^WP38[Ih0cKJW
0=2iZ@3@^jX0cKZZ0<no/03@`;@0c[ni0;R]Y`3<a;/0]:nW0=39`03Cbl80dl_40=?=b03BblP20=?=
b`0S0=79b@2`^<X0;4ak089WS`316BD0cA8I0<iOH@36];00Zjbg05aEQ02Z7C80`0T>0:h]<@2n[J`0
TI^Z02`_E`25:D@0Y@@A09h54P2eNhD0bM7N06f4[P027Vl03bm`07VF]@2a`m<0KHBJ07J?Y01TOJ00
42UK07:6U@1dOh<0Lgao0351B`1MGE@03000o`080?ooo`800?l000<0D91h0=1@N02P8?000`2P8?00
2@2h>;@0X23`0;Ph]02P8?00j6Pl0:0Pl03XJ3`0oh000>QX?0040?n000050>QX?02P8?00^3Rd0;Ph
]03@D7P00`2P8?000`3XJ3`0oh000?n0000;0?n000<0X23`103oP0020:0Pl0040>QX?03oP000oh00
0?n00080X23`00@0d51h0?n0003oP000d51h2`2P8?020>QX?080oh003000o`0;0?ooo`002P3oool0
E@14[a`0_;Bb0<?<e@2IYj`0M7Ym02lH6`38`<L0Qi2H01@;4`0S1`H0/Wl/070E0@2I1PL0/@D=0;P5
3P2h10d0/P@:0;TD6@2e3a<0`PT=0<X930321@X0`0H<0;h52@331`/0aPH:0<X;3@3=3P`0cPh?0<@A
5P1S7b<0gMOI0>KTiP3UiNH0j>?R0=F[Y`2X9RD0aaHI0:LI7P1U@480hN7P0>OViP3WiNH0k^CT0<]o
P@2l7Al0_1<I06<K803Cd=80hn7T0>GUi`3QhN@0h=gP0=Vm_P2L6Ql0[@L?0:l43@2^0``0Z@<:0:L2
2P2X10`0Y`<;0:@02`2R0@P0X0450:D11@2X0@L0Z`890:P11`2U0@L0XP450:811P2W0PT0Z0890;46
3@2e1`l0[@4<0:822P2H0@P0S`4608H110200@D0OP8507P70P0Qa`400`00o`090?ooo`07052@N03@
D7P0X23`0:0Pl03@D7P0oh000;Ph]0030?n000030:0Pl03oP000oh0001X0oh0000<0j6Pl0?n0003o
P0000P3oP0001@3XJ3`0oh000?n0003oP000j6Pl00@0oh0000<0j6Pl0?n0003oP000703oP000101@
T7P00?l0003o0000o`080?ooo`800?l004`05_0;0<2j^@2MY[@0XjRh02L^CP16Aeh0L69[085^M`29
KgH0TVmh09QcNP2MNGl0XX2309UiO@2SOX80Z8600;6;R02gU8/0_9b>0;fPT@2mXi40aZjM0<^aX`3>
]ZL0cKVZ0<fk[03<^:X0ckf_0<fm[`3@`;@0_[:Z0;ZaZ`39`KP0clS00=3:``3DclP0eLk70=?<b03<
b<L0d<c;0<o8aP39b<X0XkC=05MYV02d?E40cA4I0<8O903DWi`0^;Bb06ejW@2;@FH0_@dH0;0=502h
Oh00XJ6W06E]RP1O>U`0W0PH0:D33`2H<3`0b<OI01LeM00L?G/0VKK>0;W;e@2faM80G7:?03A@NP09
95L0IWZC07j8SP1dOX00JGMm02/nC@1KGeH01_<32`00o`080?ooo`800?l000<0:<Pl0;Ph]02P8?00
0`2P8?00103oP000^3Rd0=1@N02h>;@20=1@N0030>QX?03oP000oh0000<0oh0000H0j6Pl0=1@N02P
8?00X23`0=1@N03XJ3`A0?n000040=1@N02P8?00X23`0=1@N0<0oh0000<0j6Pl0:0Pl02h>;@00P3o
P000103@D7P0X23`0:0Pl02P8?020?n000030>QX?02P8?00X23`00P0X23`00<0^3Rd0>QX?03@D7P0
0P3oP0000`0Xb3`00?l0003o0009003o00/0oooo000:0?ooo`1E04>]6@2h/:l0bmCM096OYP23R8d0
<QXS0<O3c01bNhD04@X@02/>102^Mbd0J`P109`72`2c1`d0^0D:0;T52@2i0`P0aPT=0<D82@3620T0
bPT<0<462P2h0PH0_0D:0<48303010T0aPL;0<X=3@3930d0`@T>06l<4@38`L80iNGU0>GUiP3ViNH0
iM?A0:a5A@365AX0_QPN05`G7@3Ad<l0hn;P0>OWi`3[i^P0gJ^^0:XR903051H0M@lC0;B^[`3Rh^80
h^;S0>3Oh@3Ng^00g/o@09l`=`2^2A<0/@H>0:`22P2Y0PX0Y`<;0:H22P2W0@`0Z@0;0;422`2_0`P0
Z@460:T1202Z0@L0Z0470:D11@2Q0@@0XP470:D12@2V0@D0/@H=0;843P2/0Pd0X@4:09D11`2=0@H0
Q@4607`0101j0@D0M0D202770P03003o00T0oooo00P0D91h0:0Pl02P8?00X23`0=1@N03oP000X23`
0=1@N080oh0000<0X23`0?n0003oP0004P3oP0000`3@D7P0oh000?n000060?n000030=1@N03oP000
oh0002T0oh0000@0D91h003o0000o`000?l0203oool3003o001;0<Fi/@2KYkL0Ui^[0457H`1=C5l0
MFQ^07iZL@25K740T75i09QbNP2QMgd0VW9j09EbN02EMgX0ZHF50;6;Q`2eT8P0_IbB0;jQTP2oX900
aJZJ0<B[V@3:]:<0b[JX0<jiZ`3;]j/0ck^^0<jl[`3;_[40c/:h0<c1^`3@a/00c/O20<o;a03Dd/h0
e<o;0=7;bP3=b/P0c/g80<c:aP3=alH0bLS=07J;Z`2AIHP0a1HP0<X@5`36EeT0_JjZ0:Z`_@1DBW/0
YQ@X0;T94P2Z?T<0[Z:T09BHY@1:BVl0RQ`c0:82402?1Q<0X7nF00/YIP2C/Ll0^lgH0;W;e`2BZ/X0
8Smd00lYF01CJXH0OhnF06iiOP1ULgP0>deW01T^DP1GHf@07<HA00/00?l0203oool3003o00D0X23`
0`3oP0020;Ph]0030>QX?02h>;@0j6Pl00D0oh0000H0j6Pl0=1@N02P8?00X23`0;Ph]03@D7PA0?n0
00030=1@N02P8?00^3Rd00@0oh000P2P8?00103XJ3`0oh000>QX?02h>;@20:0Pl0030>QX?03oP000
oh0000T0X23`00<0^3Rd0>QX?03oP0000P2P8?000`3XJ3`0D91h003o000:003o00/0oooo000:0?oo
o`1E04B]6P2g[:P0a/oG09JUZ`1_LWD0<Q/S0<_8dP1PJG405`X?044O3@2TIbL0N0T409<3202W10X0
^PP=0;l9302o1@X0b@/=0<H:303620/0``H;0;H32P2c10X0]0@;0;/5302k10/0_`H<0<<930322@/0
``X?090?5@2GRh/0i>?T0>CSi@3UhnH0jn7R0;meM0356a`0aQHJ07P@5`2XXJ@0hMoO0>;ShP3SiND0
j<o?0:<h?02m5QT0U1<H08UlOP3Ph^40gn7R0>3Ph@3Ng]h0hMWK0:9>D`2Z31<0/PL?0:d43@2/1@`0
Y@8;0:L33P2]0`d0]P<>0;X4302h10`0[P4:0:/22@2[0PP0Z0480:D2202R0@L0X0860:<1202T0@P0
[P@<0;863`2X0PX0W`4709H11P2=0@H0Q04807`11P1j0P@0M@D202770P03003o00T0oooo00/0D91h
0?n0002P8?00X23`0=1@N03oP000X23`0=1@N03oP000j6Pl0;Ph]00M0?n000050>QX?03oP000oh00
0?n0003XJ3`00`3oP0000`3XJ3`0oh000?n000030?n000030>QX?03oP000oh0001/0oh0000@0D91h
003o0000o`000?l0203oool3003o001;0:C8T@2BW:/0WjFb01dW@@1AEVX0KfI]07i[L@26K7H0SF]g
09aeP02RN800U6ae0::3Q@39^[`0c[_10:f<S@2dT8X0^9R;0;bNS`2kWHl0ZI>60:FCQ`2o[9d0a[:S
0<^dY`3;]JP0c;N/0=6o^03>_[L0cL6h0<W1^P3?akl0clO00<o:`P3BclX0dlo;0=7>bP3=blH0c<[7
0<c<b03<b<@0c<S60;Zoc@1KJIH0/3=30<`@5`2n71l0cibK0;^g^@1/NI`0T41P0;X=5`2V3QL0`iZO
0:6Q[01TK8P0KCEE09/55@2L0`h0PBLn02Y0L`2/b^P0VK;@051^WP0?;fH0CfnC08fR/`2FY[00Sj2X
06]mS@0Z?F000Q14004=A00d@eX0;:PS00/00?l0203oool3003o00030;Ph]02P8?00X23`0080X23`
00<0j6Pl0?n0002h>;@00`2P8?002@3@D7P0j6Pl0=1@N02P8?00j6Pl0?n0003XJ3`0d51h0?n00002
0>QX?0030;Ph]03@D7P0oh000140oh000P2P8?001`3XJ3`0oh000?n0003oP000^3Rd0:0Pl02h>;@0
0P3oP000103XJ3`0X23`0:0Pl02h>;@20?n000030=1@N02P8?00X23`00/0X23`00<0^3Rd08300000
o`002P00o`0;0?ooo`002P3oool0E@17/A`0^:^U0<[Df`2@XJP0LgAi03TS:P3BdMT0BdeJ01T7301L
>aT0O3dI07l82`2I0`/0Z`@;0;P53@2n1`d0_`H:0<T:303:2@`0a`P;0;/62P2`0`/0XP4709L21@2/
1@d0]`@=0;/53@2m1``0_PP=0<4;402^41L0J4Q80=WJfP3Rh^80hn;S0>CSh@3I];@0]R<U0<DD5`2R
5a/0LUYO0>3Nh@3Ph>80h>7R0>WNg`2mOh80ZaTP0;4F7@1Y@DD0f][L0>3Oh@3Ng]l0h=oP0>3Mg@2i
PH<0XQ@I0;893`2`1@d0[@@=09d21`2P10T0]`L?0;X4302j0`/0^@@:0;@42`2Z00D0Y@450:H2202T
0@L0XP470:011P2H0PH0T@460:d73P2[0`X0YP4709d11`2E0PH0RP4507h11@1f0P@0M04107D60P0Q
a`800`00o`090?ooo`09052@N03oP000X23`0:0Pl03@D7P0oh000:0Pl03@D7P0oh000080d51h6@3o
P0001@3XJ3`0oh000?n0003oP000d51h00@0oh0000@0d51h0?n0003oP000j6Pl1@3oP0000`3XJ3`0
oh000?n0000K0?n00004052@N000o`000?l0003o00P0oooo0`00o`00B`2GbG/0UIj[09RL[@0Y=5H0
3Q]90411G@1lJG80QFUd091_NP2JLh00WgEo09I`M`2cXJD0/:2Y0<6^]P2[SY00[XZ40;RGR`2dUXT0
ZI2308ioN@29OGX0Y9J<0<2ZV`35[j00ak6S0<Zg[03>_kP0d<>l0<g2^P3;`kX0c/Jn0=3:a03@b/80
dLg80=C?cP3@c</0cL_80<k:aP3>bLH0cLO30<S4`@38alX0Jh6U095SP`3151d0bQ0G0<QGF`39Y:T0
]j6c09eXQP2d4b80]0L@0:M<D034^kl0Uin^04HlHP282a`0W08=08L;601SF7`083ae01XgK@1<J900
LHRT069nTP27WJX0NHZD05U/PP0:74l00P]60049@@013D007S1?03n>>`0;003o00P0oooo0`00o`00
0`3@D7P0X23`0:0Pl0030:0Pl0030>QX?02h>;@0X23`0080X23`00D0d51h0>QX?02P8?00X23`0=1@
N0070?n000<0d51h403oP0000`3@D7P0X23`0;Ph]0020?n000040>QX?02P8?00X23`0:0Pl080oh00
00@0j6Pl0=1@N02P8?00X23`0`3oP00>0:0Pl0030=1@N000o`000?l000T00?l02`3oool000X0oooo
03@0@JL?0:^IT03:d]/0W:^e071`MP1==d00e]OP03Db?@0R20X0NE8T06LK302<1Ph0Y`D=0;@53@2h
1P/0^PH:0;d62P3:2Ph0b`T=0<062P2/0@P0[08;0:T32P2Y1@/0[`H90;H52@2e1@`0^0L>0;T73@2m
2A40]`dF05`G6P2o_Kl0h>;S0>;ShP3Shn80h=GE0;M/I`38HeT0_VUP09b0O03Le]D0hn;Q0>7QhP3U
hN@0gKfn0:8Y<02i4AT0G1DI0;fm_`3Og^00h=oQ0P3Ng]l07`3D][P0TR4W0;<<502f20d0^0H;0;d9
3`2g1P`0_0H<0;d53@2l10X0^0@90;44202W0PH0W`440:411`2R0@L0Y0880:411P2O0@H0W0<:0:X6
3P2^1@h0YP8;09/11P2A0PH0Q`4507/1101b0P@0K@43078<200Sb`L00`00o`090?ooo`0:052@N03o
P000X23`0:0Pl03@D7P0oh000:0Pl03XJ3`0oh000=1@N1H0oh0000<0d51h0?n0003oP0002P3oP000
1@3@D7P0oh000?n0003oP000X23`00@0oh0000<0j6Pl0?n0003oP0006`3oP000101@T7P00?l0003o
0000o`080?ooo`<00?l004/0K>5I09^S/P2:SZ80210h0089@00W:U@0MfIc089ZM02?KWT0UFmk09U^
N@2MLW/0_:BZ0:N>U@2nYZ/0YhR80:V5OP2_SH@0[hn20:F;OP1aIF@0L6UX09N9O`2nZ9T0`ZjL0<F`
X039]jT0b;ba0<o3_03=`[X0c<Bi0<o7`03>b<D0c<S30=;?bP3Edlh0d/o:0=3=bP3=b<H0c/[70<c8
a@39aL@0b<O60;JmbP1QJY@0YC]=0;lH702k7Al0[BT_0:PV<02Z9Rd0[aXO0:PG6@2H>c/0/ZBW09VQ
[016DgD0N2M109X33P2A1A00/82;0;k9e`2kbmT0^/WE0;70cP1`RZD0>EMm05UhU@1GKhP00A5;004=
@P0<6d00=4EH01lcB01@L4l02`00o`080?ooo`<00?l000<0J:Pl0:0Pl02P8?000`2P8?000`2h>;@0
d51h0:0Pl0060:0Pl0030>QX?03oP000oh0000D0oh0000@0d51h0:0Pl02P8?00j6Pl403oP0000`2h
>;@0X23`0>QX?0080?n000<0X23`00@0d51h0?n0003oP000d51h2P2P8?00102h>;@0d51h0>QX?03X
J3`;003o00/0oooo000:0?ooo`1E04:W3`3;^:d0b=7I08bKX`1_KgD0GDYC0=?Gg`0S8RX08@L509=X
<`1R2`@0T08:0:`53@2f1P/0_0L:0;d82@301`/0b@P@0<P93P2j1@X0[@8:0:/12@2_10/0/0@90;@6
2@2f1PT0/`@<0;<3302h1`d0^@T?0;L94P1h3A<0N6=Z0=WGf@3QhN80gn7P0>;Ph03Xg]T0k]kI0>[O
f@3Wgmd0hn3N0>3PgP3Nh=l0h=kP0>G7b`2W<3L0_@lE06X:3P28PX@0fm[L0>7Oi03Pgn@0g]gQ0=c:
cP2NA4`0/@hF0<8;3`332@l0`0T>0;X53@2h1@d0^@<=0;`43@2f0`/0/P@<0:/12@2Q0@D0X`470:D1
1`2X0@L0YP470:@01`2U0@X0[0@;0:h4302V0@`0W04808d1201o0PH0N0440701101X00<0J0T702NY
1P03003o00T0oooo00L0D91h0?n0002P8?00X23`0=1@N03oP000X23`0080oh0000<0d51h0?n0003o
P0008@3oP0000`2P8?00oh000?n000060?n000030=1@N03oP000oh0001/0oh0000@0D91h003o0000
o`000?l0203oool3003o001<05WL@02KWJX0EUaf0086;P011CT082A@07UXMP25JWD0SVih09A]M@2J
L7D0WGAj0:>3Q`2lXjP0Y8B80:N4OP2VPWX0ZHAk0:n=P02`Th80ZI:50::=P@2bVXd0_ZJF0<6[V`36
/J80akJV0<Vm/@3<`KT0c/Fm0<_4^`3=al00blO10<o:aP3Fdlh0emGB0=SEd`3Ed<l0c/c;0<c:bP3;
bLP0b<G40<O5`P36`lD0];G20:^NZ036VYH0aYR@0;nIT@2oVY@0`9nJ0;jNV`2gVIH0^:VX0:FY[@2R
[k`0Ig^E05DfF02B1QP0V@8?09De@@3?cMD0`<gI0;S:eP26Vjd0A5f600<IHP087e/0IGnE00PMB@0^
@5T0EF=V05IRH@0Y>DH0HfYY00Cb0PX00?l0203oool3003o0003052@N02P8?00X23`00@0X23`00@0
^3Rd0:0Pl03XJ3`0j6Pl0P3@D7P00`2P8?00d51h0?n000030?n000060=1@N03XJ3`0oh000?n0002h
>;@0X23`0P3@D7P@0?n000030>QX?02P8?00X23`00L0oh0000<0j6Pl0:0Pl02P8?000P2P8?020?n0
00030>QX?02P8?00X23`00L0X23`00<0^3Rd0?n0003oP0000P3oP0000`0Xb3`00?l0003o0008003o
00/0oooo000:0?ooo`1E04NY4P2cWID0a]7H09f]]@1MG680LV5Z0<[>f00G51d080L409=T;`1e2PL0
V@D>0:`53@2h1P`0_`P<0<092`312@`0`@H<0<49402c0`T0[P<;0:h22P2/0PL0[P<80;842P2b1@/0
/P@=0;D53P2g1P`0]`L?0;L94@2U41L0IA8L0:^7T03PdmP0h=GH0>3Bf03Mc=40elC90=JoaP3J_<<0
e;>k0<j]/`3?Z[80c9bW0;mZM@2[5b00_@/A08T<4P1:=SP0emSJ0>;RiP3Ogn<0gmoQ0>;Hf`33QHX0
[aHK0<T>4@352@l0_`T?0:P32@2Z0`/0/@<<0;82302a0P/0[@8;0:P1202S0PH0Y@870:H11`2Z0PP0
/PD;0:L11P2W0PL0[0@;0:X32`2V0@T0W@4708X21`1f0@H0MP4806h11@1V0@80I0H602n81`03003o
00T0oooo00L0D91h0?n0002P8?00X23`0>QX?03oP000X23`0080oh0000<0^3Rd0?n0003oP0005@3o
P00;0=1@N0030:0Pl03@D7P0oh0000L0oh0000<0j6Pl0:0Pl03oP0006`3oP0001020`0000?l0003o
0000o`080?ooo`<00?l004`0<NPQ0:2OY`0_=5800PH^00lB?@0U:Dh0NfIf08MYM`2<J7D0Tfag09ec
O02NLgd0XGEl0:IjO02SN7T0Y7Uh0:1gL@2WPW@0/Y>50;>HR02hWXl0^J6?0;fTU02oYYL0`ZZH0<F_
X038]JP0akb`0<[0]`3=aKd0cLNo0<_6`03:a/40d/o;0=GAcP3Edm00emGD0=?@d@3;b//0b/[80<_9
a@38al80a/K20<;2`@34`L40_[fl0;bi^02i][@0];2_0;6/Z`2_ZJP0[:FT0;:^[P2SX:D0[Znd0:NY
/P2Z^</0@T=/08HE;@2K0Q00R@TE0<BY/`30cMH0^LWD07nCYP1_Pil01aYD00<GD01PMXL0H75h05e^
K01LJV@0F6EW020d@01^Ng/05=0?2P00o`080?ooo`<00?l000<0D91h0;Ph]02P8?002@2P8?000`2h
>;@0oh000?n000050?n000070>QX?02P8?00^3Rd0;Ph]02P8?00^3Rd0>QX?00A0?n000090>QX?03@
D7P0d51h0>QX?03@D7P0^3Rd0>QX?02h>;@0d51h00D0X23`00@0j6Pl0?n0003oP000^3Rd1`2P8?00
0`3XJ3`0oh000?n000030?n00003052@N000o`000?l000P00?l02`3oool000X0oooo0480A:D=0:22
N03;dMP0SZ2T05QKG@2=PHT0];S3018:4@0k7@X0QU<Y07<51`2N10h0[0D;0;H4302m1`d0`@P=0<07
2P2j1PX0/`D:0:X1202Z0PT0ZP<90:T3202[10X0[`<:0;<53@2d10d0]0D>0;H73`2f1`h0]`X?0;X>
502f3aL0ZQLQ0;@kA`2`>dP0[cA10:d[>02X8Bh0[R<a0:dN:P2b6bP0/QPT0;0H8P2b5B40]a8H0;hA
50364AD0/1DH03T41`2o_l<0h^?V0>;Si`3Qh^D0h=oO0=fn_`2_<S@0`@d@0<093@2i10/0/08;0:T2
202X0@H0Z@480:L11`2U0@L20:<11`0A0:L22@2V0@P0Z@890;@63@2^0PP0[P@:0:d42`2X0`T0Y`88
09h11P2>0@P0P`4707d21P1_0@@0J04306440`0aQ`H00`00o`090?ooo`05052@N03oP000X23`0:0P
l03XJ3`00P2P8?020?n000030=1@N03oP000oh0001H0oh0000<0j6Pl0=1@N03XJ3`03@3oP0000`3@
D7P0oh000?n000020?n000030=1@N03oP000oh0001X0oh0000@0P<00003o0000o`000?l0203oool3
003o001<02[N4`2[Xj@05Q`l01LI=01CBEd0>3A=07]YM`21IG@0Pee^08iULP2JKgX0WG1k09m_N@2T
LgX0WW5c0:5dM02TNGH0ZhIk0:n?P02cUXH0]IR80;VOS@2lXY<0`:FF0<6[VP33[J40a[BX0<Nn/P39
_kD0bl:k0<g5_`39`Kd0cLW70=?Cd@3?clh0dm7A0=7@d@3Cd]<0cL[:0<[8b@38alH0`/:o0;Vo``2T
/;/0aZN`0<NCW032Phd0`WB10;YXL`2fGFT0/5AQ0;1>G02[Be@0Z4UF0;MMKP2^F6`0S3eH07lgD@2E
7Bl0VP8@08l2402RF6P0a;[<0<;4dP2OZkH0UZNd07Z<W@1@HgL0LX2706mkO01UKVl0FVQZ02/lD00B
9Sh0EFQ[02^W90X00?l0203oool3003o0006052@N02h>;@0X23`0?n0002h>;@0d51h1`2P8?000`3X
J3`0oh000?n000040?n000050>QX?02P8?00j6Pl0=1@N02P8?004@3oP0000`3XJ3`0X23`0:0Pl002
0:0Pl0030;Ph]03@D7P0d51h00P0d51h00@0j6Pl0?n0003oP000d51h1P2P8?00203@D7P0oh000?n0
003oP000d51h0>QX?03oP000P<002P00o`0;0?ooo`002P3oool08`16Y0/0R69F0<_=e02O/;D0DDiA
0:NJX@2NXjd05`P<06Q59@1d>1`0PP@=0:023@2]10/0]@D=0;h73P302@`0_PH80;X82P2^0@L0Z`89
0:H11@2W0PP0X0460:<11P2`0`/0]@@=0;<43@2b0`d0]0@>0;P74@2e20l0]PXA0;d=5P2k3Q@0]@hE
0080]a8G0300^a@G0;/B602l4aT0^Q8H0;dD602l5AL0^ALJ0;LF602h5AD0^aDE0<HG6@2l6QX0GP`>
09N?TP3Ri>H0iNSZ0>CTi`3Qgn80imWK0;ACEP2n3a00_0T=0;@42`2_0P/0Z`890:H10`2X0@H0YP06
0:@21P2P00H0XP460:L2202T00L0Z0890;453@2`10/0[`<;0:h32`2X0@P0Y`8909h1202A0@H0Q`46
07/10`1^0P80IP4206420@0^PP43003o00T0oooo00D0D91h0?n0002P8?00X23`0?n000020:0Pl080
oh0000<0d51h0?n0003oP000;03oP0000`3@D7P0oh000?n0000I0?n0000408300000o`000?l0003o
00P0oooo0`00o`00C00Zf``0ZiZE00TA;@1<BEL0FTmI04Q0D`1hHfl0O5i/07mIJ@2BIg<0Ufej08eZ
O@2HLGh0WFed09a/KP2OMG40YWaf0:R1M`2XQgL0/9:10;>GR02eWY00^J6C0;jWV02oZYd0`ZnR0<:c
Y033^Zl0aknd0<[1^03>aKh0a/:l0<c9a`3=cLT0d=3>0=3@d@3Ad=40c/k=0<[;bP39b<H0a/G40<?4
``2f_/P0CFJC0:9;H02h7RH0]Q`P0;DM8`2b7bH0[R8S0:XW9`2W:2P0XbPV0:@Y9`2U:2/0XBHY09/O
9`2E6B<0TQ@M094<5@2@21<0R`XK088D:P2293X0R69]07f9T`24UIP0N8J907=lOP1bOWd0IG1e02Lg
E@012SP00@Tc0353D`0^WR`:003o00P0oooo0`00o`000`1@T7P0X23`0>QX?0020?n00080d51h1P2P
8?070?n00080j6Pl00D0oh000;Ph]03XJ3`0oh000;Ph]00?0?n000030;Ph]02P8?00d51h0140oh00
00<0j6Pl0=1@N02h>;@00P2P8?00103@D7P0oh000?n0003XJ3`30:0Pl0030>QX?02XR3`00?l000T0
0?l02`3oool000X0oooo05D0BJH<09Q`IP3;c]H0S9^R05QAF@2n/k`0Qh^F01l:302MMD40IQl>0946
3P2W10d0[0@;0;L73`2l1Ph0_`L<0;X52`2_0PT0YP460:X22@2Y0PP0ZP<90:T1202Z0PT0/0@;0;44
2@2c1@`0]0D>0;D53`2g2100/@`?0:`B402^61<0[A/F0:lT7P2/:b40Zc4Y0;E3?02gBT<0_5=<0;eM
E@31IUd0a6iU0;e]I030L6T0aGE`0<YiL`3>Mg80dGag0:MeL02]Y:00h>7P0>?Ti03PhN<0hN3T0>?M
h02eNGT0ZQdI0:`B4@2X2Pd0Y`D;0:L2202V0@H0Z0480:H11`2T0@P0Y0490:D1202U0@L0Y@4:0:P2
2@2b1P/0/`@;0;432`2[0PX0Z`8;0:T23@2Q0@/0S@4707h2101m0@D0L@4306800@1N0P80>i4?00<0
0?l02@3oool02@1@T7P0oh000:0Pl02P8?00d51h0:0Pl03@D7P0oh000:0Pl00_0?n000030>QX?03o
P000oh0001T0oh0000@0P<00003o0000o`000?l0203oool4003o001;0:F9O00<42`0HeUV05M:E@1;
B5T0Kem/07UIIP25GV`0T6Ed075HM@0G6U40DDM/09MZLP2KJf`0XgEd0:IgM@2UO7@0[8Uj0;:APP2[
THH0V8Yo0;:PT`2jY9P0^jNL0<6]X@31[jD0`[R_0<Jl/`38_kL0c<Bm0<g8``3=blH0c/g90<g<b`3=
bld0c/k=0<W;b@3;c</0alK50<G4a@32`<80_l34086?ZP2/VZL0aY>A0<RMU`38Y:40`:FR0;fWXP2g
Yj40]JBQ0;JVX`2UVYD0/ZNV0:fSY02m]KX0Z:B]0;R]/P2iXZL0[hnD0:AlP@2CHVH0P4A>07=>E@2N
Yjd0NHN>07J2Q@1YMWH0IgEf04IEJ00234000PPj0049=00C93l0=fXk00X00?l0203oool4003o0007
0:0Pl03oP000d51h0?n0003@D7P0^3Rd0>QX?0050:0Pl0030=1@N03oP000oh0001P0oh0000D0j6Pl
0=1@N02h>;@0X23`0;Ph]0030?n000030=1@N03oP000oh000080d51h00<0oh000=1@N03@D7P00P2P
8?000`2h>;@0d51h0=1@N0030=1@N0040?n0002P8?00X23`0=1@N080oh0000@0^3Rd0:0Pl02P8?00
X23`0P3@D7P:003o00/0oooo000:0?ooo`1104^V3026F4d0alWA08nMY01>Adl0dL[C06M^MP0_5`d0
YGM605D80P2<10/0WPD=09L2202N0`P0]PL=0;/8402/0PX0ZP<;0:H11`2[0PT0Z@890:d2202_0PL0
[`<<0:82202O0@H0/0H>0;D63P2c1@h0Y`/@08Pg<P3=V8/0f:fS0=bk[P3Takl0im390>KFc`3Xg=L0
j=cJ0>OKfP3Yh=d0iN7M0>;QgP3Sh>00hn7P0>;Qh@3ThN<0hn7R0>CRhP3Qhn40inOW0>?Si@3Si>@0
hN7S0>3Pi03QhN@0g=?B0=Rk^03=YJ40`92:0:]KF@2J1@X0YP480:P1202V0@L00P2U0@T04P2V0@X0
YP880:@22P2T0PX0[P@;0;@53@2a10/0[`@<0:d43@2X0P`0XP8:08`2201f0@80NP8507<1101V0@80
G@8103jF50<00?l02@3oool02@1@T7P0oh000:0Pl02P8?00oh000:0Pl03@D7P0oh000:0Pl01;0?n0
000408300000o`000?l0003o00P0oooo1000o`007`2EVVP07R4f06=GH@1:@4l04aa003/iE01eFfL0
QF9`08AQM`0c:E80BD=`030[EP2BIg40Vf]]0:5aL@2XNGH0Z7mi0:Z6N@2cTH80X8Ml08eoM@2EQg`0
]:6F0;RUV02n[Ih0_[:V0<2g[`35^kD0akji0<O2_`3<b<@00P3=bLL0:P3>b/L0cLg;0<c<c@39b/X0
bl_:0<K5a@36a<H0`<300<71`@2o_kl0_;jn0;bl^`2i^[H0][Jh0;:b]@2][Zl0ZZV/0:NVZ@2RXj@0
Zk2a0;No``2`^/@0OI>]07bE[@35eN40a]?O0<OBgP35dMX0a/oH08>?X01nSIT0Uj>[09RSZP1jQH/0
IWEc065cL`0L:dl00P]300DC>`0R<TT04B4h04=:C@X00?l0203oool4003o00040;Ph]03oP000oh00
0?n00080X23`00<0j6Pl0:0Pl02P8?000`2P8?000`3@D7P0oh000?n000090?n000030;Ph]03oP000
oh0000/0oh0000H0j6Pl0:0Pl03@D7P0oh000=1@N03XJ3`20?n000H0X23`0P3@D7P00`2h>;@0X23`
0:0Pl00:0:0Pl080oh000P2P8?00102h>;@0d51h0>QX?03oP00:003o00/0oooo000:0?ooo`0h04fX
3P1hAcd0`Ko809NV[01FE5T0em?L04iDG017:a/0MdHW05H60`2?1@h0V08;09012@2E0@L0/@D<0;D6
3@2T00P0YP480:X2202/0PT0Z0480:h32@2`0@/0[`<:0:d42`2[0PX0]0D?0;@63@2e1Pd0Z`dD05hd
=@3LeMD0h]oP0>3Og@3PgMh0h=kP0>7Oh@3Rgn<0i=gS0>7Jh03Rf^00fmOL0=WDfP3MeM`0g]SL0=cF
fP3KdmT0g=GK0=gGg03MfMh0g]WO0>3Lh03Rg^80iMoV0>?Pi03Qh>D20=kNhP0K0=_IgP3Ie=P0a:FW
08d:402V0@T0Y`890:D11P2T0@P0XP4:0:@12P2T00T0W`4;09/12P2Y0P/0/0D>0:d22P2a1@l0[@D>
0:L22@2P0@L0S04708811P1l0@D0L@4306<10@1K0@80Ce<=00<00?l02@3oool01`1@T7P0oh000:0P
l02P8?00oh000:0Pl03@D7P0803oP0001@3@D7P0oh000=1@N02P8?00d51h0080oh000P2P8?000`3@
D7P0oh000?n0000Q0?n000040=1@N000o`000?l0003o00P0oooo1000o`00<@1i[T`0=S4m06UOHP0j
<D<00PPg02d[C`1gGV`0P61`069>JP1BAFH0E4EZ03T_FP2CI6d0W6Q[09m`K@2TNG@0Y7af0:Z6O02`
TH00X8Yi0:FBQ02VU8L0[Yb@0;VWV`2j[Ih0^[:W0;ng[P34^[D0aKjh0<S3`03<b<D0cLS70<_8aP3;
b<P0c<_<0<_9c03;b/`0bLS:0<O5aP33`L80`L700;g0_@33a/D0_;o00;Zl_02g]kT0/;>e0;2b]02^
/K800P2Z[:l06@2PY:D0X:JX09RPX`2Z]Kd0Y;G409FabP33eMl0a=?O0<KDh034d]h0_lkJ096V]P20
Tj00Pi6K07R6R`1aO800IgAc061bM@085D<02Q]504=IH01BHV009cI503U9D006i0@02@00o`080?oo
o`@00?l000@0^3Rd0?n0003oP000oh00202P8?000`3@D7P0oh000?n000040?n000060=1@N03oP000
oh000>QX?03oP000d51h2P3oP0020>QX?0030=1@N03XJ3`0j6Pl00<0oh000`2h>;@80:0Pl0030;Ph
]02P8?00X23`00T0X23`0P3oP000103@D7P0X23`0:0Pl03XJ3`20?n000030>QX?01@T7P00?l000P0
0?l02`3oool000X0oooo01@0BZD<05`Z8@2`[K@0UZ>Z059>E03Gen00;S8l05Xl9P185`L0EP<308h3
302J0@T0V@490:T53P2d2140/0H;0:T32@2[0PX0Z`480:h22P80Z`8903l0[0870:h42P2a10/0]0D<
0;<5302d1Pl0]@H=0;H;501W5AX0g<G:0>?>e03D^<00c:F]0<6EWP2iQi00/gJ10;9^N02`J7@0/V5a
0:mIJ@2aEfL0_5]Z0<INK@32EV@0b5]Y0<QKJ`34FV/0a5m_0<5QL031JWL0b7R50<QmR`3<R9H0cYFR
0<ZLZ@3<Z[D0b[6k0<^f_`31Y:X0T1PN0:H22P2X0P/0YP480:D1202T0PX0X`4;0:<13@2S0P`0W08:
0:<12@2[10/0/@D>0;873@2[10/0Y`<:09l22@2=0@L0PP4607/11P1a0@@0I04205X10@1?E0`00`00
o`090?ooo`08052@N03oP000X23`0:0Pl03oP000X23`0>QX?03@D7PG0?n000030;Ph]03@D7P0d51h
0080X23`00<0^3Rd0=1@N03@D7P03P3@D7P00`2h>;@0X23`0:0Pl0050:0Pl1L0oh0000@0d51h003o
0000o`000?l0203oool4003o001<05_5=01RFV80J5mU02`W>`021cL09bI>07ILK022Hg@0@CEE07QT
P@0a:UT0BSYP09ASK02KJF/0Wfm_0:9fLP2UNWD0ZXAi0;2AP`2LQgP0ZIR=0::@Q@2bWY00^JRK0;Z/
W`2k/jT0`[Zc0<>h]P32^[H0b<>l0<g9a03<b<H0b/K70<_7aP38alT0b<S;0<g8c@39aLX0a<C60;bo
_`2o`L80^[jm0;Rl_`2k_/40^;Vk0;Bd^@2^/K@0[[:d0:ff]`2X[[00XZJY09nSY@2a^KP0b=7F09VU
]021V:`0B6N50<CFhP34d]h0`m7P0<GBg@2^_</0?EE]09JX]02LZk80MHN:07Z9RP1ULfh0Gg5f00@B
?`0`@e`0FF]X05IUH`0X>4X08cU<00K62@T00?l0203oool4003o0004052@N03@D7P0oh000?n000P0
X23`00<0d51h0?n0003oP000503oP000103@D7P0X23`0:0Pl03@D7P30?n000X0X23`00<0d51h0:0P
l02P8?002`2P8?000`3@D7P0oh000=1@N0020:0Pl0<0oh0000<0d51h052@N000o`002000o`0;0?oo
o`002P3oool0@01;YPh0CATA09fHW@1nR8`0H5aR0<S;dP0C4QL0GShX03`40@1a10X0V@<<0:<23@2Z
0`d0Y@@>08h21`2M1@/0Y`890:d22P2b0PX0/`<90;822@2d0`X0/P880;02202b1@X0/P@<0;<23@2d
1@l0]@H=0;H74@2]31D0^2hh0;@V<`2b6RP0/a@Q0;4?702`3QT0/PhF0;<>602d4QX0]A4H0;T?6@2n
3QL0ba8J0=<B6P3G4aL0f1<H0=@A6@3D4AP0dQ0H0<l@60383AH0a0`G0<H>6`394A/0`0lK0;X>702e
4b80YaHU0:8O;@2S:CH0XA0K0:L22P2V0@P20:@11`0C0:811`2S0PX0X`4:0:@12@2T0@X0X@470:@1
1P2]0``0/`H?0:X32`2T0PX0V`4808h11P200@@0N@4307020`1R0@40F@40051D3003003o00T0oooo
00P0D91h0?n0002P8?00d51h0?n0002P8?00oh000>QX?4`0oh0000@0d51h003o0000o`000?l0203o
ool4003o001<02WL5@1^HFP0IUmZ024N=`042cT0;2a>075JIP21I7D0=bm?07i[R@0A4dX0Je9^095O
IP2KJf`0WVa`0:9`L02TMg40ZX=h0:j>P@2^U8D0VhMl0:NCQ`2hXi<0^JJI0;^[X@2i[jD0`[Zb0<>h
/`34^[D0b<6m0<W4a039aL<0b/S70<O5``37a/T0bLO<0<K5b035a<L0`/;40;c0_@2j_k/0^[fl0;Zk
_`2h^K`0]KJj0;>f^P2a];P0ZJ^_08fBT`2TZj`0XJR[0:B]]02DWJ@0YZff09jT/P2b_ld0[[c80<OF
gP36dn00`];N0<?Cg@2__/`0X[K409NW/P20SYL0NXV=06mlO01XMg<0I7Eh00TH?P1=Hf`0FFa[04mP
J00@7Cl01ADi00FW40T00?l0203oool4003o0004052@N03@D7P0d51h0>QX?080X23`00<0j6Pl0:0P
l02P8?000`2P8?0:0?n000030:0Pl03XJ3`0oh0000D0oh0000H0j6Pl0?n0003oP000oh000=1@N02P
8?020;Ph]0040=1@N03oP000oh000?n000H0X23`00<0^3Rd0:0Pl02P8?003`2P8?020?n000050=1@
N02P8?00d51h0?n0003XJ3`00P2P8?000`1XZ3`00?l0003o0007003o00/0oooo000:0?ooo`0E04bW
3@1<50`0ThV>05mYJP1LFEl0XJ:[01<72@1U>RH0C`D707`32P2K0P`0Y04<0:T33P2D0`T0P0060903
2`2N0@X0Z@870;822@2e0PX0]`<:0080]`<902P0]0<90;84302c0`X0]@@<0;T53`2j1Pl0^`L@0;/8
3`2j2140^PHA0;`94P2m2a80_0/D0;l;502o3AH0`0dF0;/<502i3140b14D0<hA4`3D4QP0eQ0D0=dF
5`3M5AL0e`lE0=H>4P3B3140c0TA0<`:50392180b`PA0<P63`382140a0P@0<483P2g1@d0/0@<0:T2
2P2X0PX0Z0490P2U0@P0502T0@P0X@480:822@2P0@T0X`4;0:<12@2P0@L0XP070:P22P2b1`l0Z@8;
0:812@2J0@H0S04708011P1f0@80L08306D20`1L0P40De@>0`00o`090?ooo`08052@N03oP000X23`
0?n0003@D7P0X23`0?n0003XJ3a<0?n000040=1@N000o`000?l0003o00P0oooo1000o`00C00QiPh0
Mf=Q06MRK`0A4R`0<3IC04<oEP1bGFP0MV9c03LaD`19@f/061U>08EOM02BH6H0VVQ[09]VJP2NJ6T0
XG5]0:^4O02bT8D0]IF80;FKS@2fWi40]Z2@0;^VV02jZIh0^JfU0<2e[`30][00`k^d0<Jo_039aLD0
b<K40<O5`P36`l80aLC60<W7b@34`lD0`/;50<2oa02m`<80_;o00;Vl_@2h^[T0/kNm09FS]02BSj@0
/8:D0:YUM@2UKGL0^9NP0:^SZ01YN900Hf:409MHL@2WDfX0YE9W09ePM03>cMP0a=CP0<?Cg`33dmh0
N96X07VAX`2=WZT0UJ>Z092NX`1_O7h0J7If06YgNP0M;TP0CfQb03mDIP0?6d<00@Pg008;=@0@LQl9
003o00P0oooo1000o`00201@T7P0j6Pl0:0Pl03oP000X23`0;Ph]03oP000^3Rd102P8?090?n00003
0>QX?02h>;@0j6Pl00H0oh0000L0j6Pl0?n0003oP000oh000>QX?03@D7P0j6Pl0080X23`00@0^3Rd
0=1@N03@D7P0j6Pl102P8?020;Ph]0D0X23`0P3@D7P00`2h>;@0X23`0:0Pl0070:0Pl080oh0000@0
j6Pl0:0Pl03@D7P0^3Rd0`2P8?000`2XR3`00?l0003o0007003o00/0oooo000:0?ooo`1E03Bi1`16
40D0QW]n06I^L01KEU`0Hf=Y01L9201K;1l0C@0407X22@2I0`/0Y@<>0:L23@290@H0P@4908X12@2X
4a`0X`490:h12P2c0``0]P890;H42@2^0`X0X@870;<42`2f0`T0]08:0;`63P2m1@d0`PT?0<@:402n
1Ph0`@XB0;h<4P2i2a80/P@=0;`;5@2n2a<0_`/F0;h:5@333A80ba0D0=8@5`3C41H0fA8E0=TB503H
4A@0f10F0=PA503D3@l0d`dB0<d94P3<2A80dP`C0<T83`311Ph0_0D=0;`63@2c0``0[0<;0:T22P2X
0@T0Y`480:D01`2U0@L0X`490:012@2O0PT0X0880:D12P2T0@P0X@480:002@2S0@X0[P@@0:P22`2P
00P0V@0808/120200@P0L`4306l20`1W0@80G@4104e<1`03003o00T0oooo00D0D91h0?n0003oP000
oh000=1@N01?0?n000040=1@N000o`000?l0003o00P0oooo1@00o`00B`22IUL0I61_00h>9`1<A5L0
FDiO06iHH`1TDfT0>CQP014GD014>F@0NEIV07aHHP2HIV`0WFIZ09aXJ@2TLg80Zh=m0;6?Q02dUXL0
]9V:0;NOS`2gXI<0^JJH0;JWW02k[jH0_[B]0<:i]033^kL0a[nk0<S4`03:a/H0aLC30<?1`032`/80
aLG40<71`P33`/D0_Ko10;bn_@2n`;l0^[Zn0;>g_01`RjX0LV><0:<W@P2d3Ad0^PXG0;L:6@2^4b@0
/C]<0:9XPP1>?FT0Q2m809d65`2V1140V0PH0<:IY@37dn00aM?R0<CBh@2M[l40TJFd08fOZ@24TIT0
NhN<075lP01ZNGT0IgQf04=AH`0B8dd00Pa10047?@011cD02ALi02Y_=@09003o00P0oooo1@00o`00
1P3XJ3`0X23`0?n0002h>;@0X23`0?n000@0X23`00<0^3Rd0?n0003oP0001`3oP0000`2h>;@0oh00
0?n0000<0?n000030=1@N02P8?00^3Rd0080oh00102P8?000`3@D7P0oh000?n000020?n000040>QX
?02h>;@0X23`0=1@N0<0oh0000<0^3Rd0:0Pl02P8?001P2P8?030?n000H0X23`00<0d51h003o0000
o`001`00o`0;0?ooo`002P3oool0<00X`@@0CQ@<089cM01GFe/0H5aN03De>@0T5a80AQPA05@22@1n
10d0S`890:033@2V10d0R@4607l22@1g0@D0SPL?09T2202[0`/0[@8:0:h22P2d10X0[`@;0:021P2e
1@/0^@@90;T52`2h10/0``/@0</<4P3=3A@0aPX@0<@=4P2n2Q00^PT@0;X:4@2l2A@0`0XC0<<;5P36
3QL0bQ0D0<`@503<3Q@0dQ0G0=LC5@3J51D0fA@F0=PA5080fA0C02<0ePhB0<l:4P3=2Q80c0TB0<P8
402l10`0^P<<0;P32`2a0``0ZP890:P22`2W0@P0Y`460:H11`2T0@P0X@470:811`2Q0@T0V`870:02
202Q0@P0W@4909`1202N0@T0Z@<<0:T33@2R0P/0V04:08/12@210@H0L08306`10P1[0@80H@8104U7
0`03003o00T0oooo00D0D91h0?n0003oP000oh000=1@N01?0?n000040=1@N000o`000?l0003o00P0
oooo1@00o`00B`1cXU`0Gemb01dJ<P18?Th0DTmU071LK01JBFD05B5G00P@C01XE700L5AO05i8D`29
I6T0W6Q[09eYJP2UM7D0Zh:00:j=P@2cUH@0/YR40;FLS@2gXI80^JNH0;VXW@2m/:X0_kBa0<>h]P33
^[H0a;fi0<K2_`31_l00a<?30<;1`P30`L40`/C40<72`P31`/<0_ko10;fn_`2j^kd0^kbo0:Zf`P0i
FHd0XCaJ0;h95P311a40_`H@0;/84@2_5al0Wb0]09<D9P2A83X0[d=G09`:602V0@d0XP<>0:55DP3@
dM`0a]?Q0;;2e@1NN980X;C209R[]P28UYl0Mh>906mnP@1ZNWT0IgQg04=CIP012D400@Q2004<?00>
7c`0A5YS03]3@@09003o00P0oooo1@00o`00103@D7P0X23`0?n0003oP0060:0Pl0P0oh0000<0d51h
0:0Pl03@D7P00P3@D7P70?n000030>QX?03oP000d51h00@0oh001P2P8?000`3@D7P0oh000?n00005
0?n00080d51h0`3oP0000`3@D7P0X23`0:0Pl0060:0Pl0030>QX?03oP000oh0000@0X23`00<0^3Rd
0?n0003oP0002@00o`0;0?ooo`002P3oool0E@0Mb`40A@X307AQHP1KFe`0K6UZ00d=3`0a8QT0;P<4
05l22P270Ph0U08;09d22P2L0PX0SP4808L2201a10T0P1TM09L42P2/0P/0Z0<60:L21P2a1@X0]@<9
0;L42`2m1@`0`0L=0;l73P3120h0c@dB0=<@4`3E41D0bPdC0;l940303Q<0_PhA0;X@4@2i4A80a18E
0<LA5@384AD0bQ8E0<0C602j81d0_BLU0;lY:034;BT0bc4]0<LZ9`3?9RH0eADJ0=L>4`3D2a<0cPTB
0<X74@371a40_@<<0;d4302f0P`0/0<<0:d32`2X0@T0YP890:@1202U0@P0XP480:411`2Q0@T0W`4:
09D21P2G0@D0WP8809l12@2M0@L0W@480:422`2V10h0V`8908L11`260PT0O`8607L10`1`0@<0KP42
06H20P1P2@800`00o`090?ooo`05052@N03oP000oh000?n0003@D7P0D03oP003003o00P0oooo1@00
o`00C01jXeT0A4=J02`Z?P0g<dX0215404M2H@19?Uh00PU602l/F`1`FVh0M5YW05Y8E01jFUl0Uf=X
0:1]K`2TM7D0Z81l0:f:P@2`U8H0/iR60;FLR`2fXI80^:FI0;VYW`30/Jd0_KBb0<2h]P30^KH0`[^h
0<K1_`32`Kl0`;no0<30_`2o`<00_/?10;k2``2o`lD0_/;30;Nl_`2e^kh0^;fo0:>a`@10FY80YBe6
0<475@2o1Q00_0@@0:hG7@2fRH/0QH2;06iRNP1c?UL0R2Hk09H;6@2O0`h0W08<090<6P3=/l00a]?P
09j`a02;Xk80OI:M08RGW`2;V9h0N8>806YjN`1/Ngd0IgIh05ASL@012cl0115102/oE`1<H6@0DFIU
041=B`08iPD8003o00P0oooo1@00o`00103@D7P0X23`0?n0003@D7P60:0Pl0030=1@N03oP000oh00
00H0oh000P2h>;@01@3XJ3`0oh000?n0003oP000j6Pl00D0oh0000@0d51h0?n0003XJ3`0oh000`3@
D7P50:0Pl0030=1@N03oP000oh000080oh0000D0d51h0:0Pl02P8?00^3Rd0=1@N0040?n000P0X23`
0`3oP000102h>;@0X23`0:0Pl02h>;@30?n0000302S8?000o`000?l000H00?l02`3oool000X0oooo
05D07LX004X;101lIfP0BdU706EPH`020@80<24J02L10P1M0PP0Q`<>09H22`2L0@`0U@4;09812`2C
0P`0U@lJ0:d/=P2S0`X0[08:0;842@2a0`P0/P<90;L42@2j0`/0_@H<0;h53@311Pd0c0XA0=8>4`3>
3100c`dA0<TA4`2h41D0/QhL0:/d;@2Z@CP0[dDm0:ld;`2a8b00`1dK0<PE5`201`X0[7Md0>>i]03]
aL40klO20??9a03ca/80mZn`0;TZ;@3:3A80ePdD0=09403@2a00c@/A0;l42`2l1@/0/`8<0:d32P2X
0P/0Y`4;0:D12P2T00T0Y@080:811P2R0PT0X@0;09h12`2L0@T0V00709/12@2N0@X0W@4:09`1302I
0@X0U`<=09D33P1o0PL0N04606l00`1e0PD0L04406l11@1U0P<0GPP200<00?l02@3oool00`1@T7P0
oh000?n0000]0?n000030=1@N03oP000oh000280oh000`00o`080?ooo`D00?l004`0I/9803XeB011
>4X081dm00<:A@0j>5`0=c9G00D=AP1RDg80JeQW059;F@1<?T/0PEIN09MRI`2QKVl0Y7Ef0:QnO@2]
RH40/I>70;:GQ`2eW8/0/in@0;FRU`2n/:D0_[2Z0;nd/P30]k<0_[Rd0;ni]`33_kh0`l6o0<2o_@2m
`;l0_;k20;Zo`02m`L@0_L730;k2``2k_/00][^n0;Bh_02^^/H0<UB<09e7IP2n21H0`0D?0;/43`2]
6b@0]YbL0:R`/02OYjl0MHFI05mWQ`1W@f@0SP`M09d33@2I0a00ZF=a0<gDg`1dRZD0QIna09RZ]02B
WZP0OXR?07=oP`1cOh40JgUj06MiM`1SLgP072i804QLJ01NLW80Ef][03]CG@0^@T`06kTF2000o`08
0?ooo`D00?l000<0T71h0?n0003oP0001P2P8?000`3@D7P0oh000?n000070?n00080d51h00D0j6Pl
0?n0003oP000oh000>QX?0030?n000090>QX?03oP000oh000>QX?02P8?00d51h0;Ph]03@D7P0j6Pl
00D0X23`00<0d51h0?n0003oP0000P3oP0000`2h>;@0d51h0:0Pl0020:0Pl0050;Ph]03oP000oh00
0?n0003@D7P01P2P8?040?n000030>QX?02h>;@0d51h0080oh000P3XJ3`00`1XZ3`00?l0003o0006
003o00/0oooo000:0?ooo`0>01k;001;2P40LE]L04m=B`1KF5X0104202dK5`0^0@80GP4508012@2D
0P/0U`8=09012P2@0P/209412`0h09`43@2U0PL0ZP880:h42P2/0PL0]@@;0;@2202h0`/0_@@;0<46
3@321`d0b@T?0=4>3`3D3Q00ba@F09`M6`2QE540aiVB0>O=b@3Zf=80im;>0>G:a`3M];00chn90<5?
B`1h6Q/0BT150=?De@3Yi^H0i^CU0>GSi03Wi>D0km_M0;iOH`385A/0e@dA0=0:403>2a40a@H=0;`4
2P2i1@`0/P<<0:/32P2Y0P/0Z0890:L22@2R0@T0X@480:01202Q0PP0W`4;0:41302L0@P0V@4709X0
1`2L0@L209d1200;09d22P2F0`h0Q@8907`21@220`X0M08607811@1_0@@0K04406H20`1U3@H00`00
o`090?ooo`03052@N03oP000oh0002P0oh0000<0j6Pl0?n0003oP0009`3oP003003o00P0oooo1@00
o`00C01QcCd0?30j0516E`0@43800PY103LjH00>43h08B=?07mRM@1oGV`0G4ED07A?F`2;De`0W6E[
0:5]LP2TM7L0YWen0:f8P02aTX<0/9F50;>IRP2eWi40_ZbS0;n`Z02o/Z`0_[Fb0;bb[`2o]k40_[Vg
0<2n_02o_[d0_Kfl0;bl_02g^[/0^Kjn0;c1``2j_l40^ko10;Fh_@2h^[d0]kVl0;>j_P1LNZD0MV6;
0;0?7P301@l0^`8?0:/9502ePX@0VJ2P0;>k`@2T[[X0`=7V03Y<N`1m=580TP<>09d33P2>6BX0d/CB
08:DY`1jSI`0TinY08bGX01nRXl0N8:5079oP01]OGl0IgUh06EfL`1KKfd0G6m`05M^M@0]@el00a8m
01X]@`0[VRP8003o00P0oooo1@00o`00101@T7P0oh000?n0003@D7P50:0Pl0030;Ph]03oP000oh00
00H0oh000P3XJ3`;0?n000040>QX?02h>;@0X23`0>QX?080X23`00<0^3Rd0:0Pl02P8?00102P8?04
0?n000030>QX?02P8?00X23`00<0X23`00@0d51h0?n0003oP000oh001P2P8?000`3@D7P0oh000?n0
00040?n000050>QX?02P8?00X23`0=1@N02XR3`02000o`0;0?ooo`002P3oool0E@0Oc000C0X107EN
G`0m>SX0EeAE00/40`0Y5Q80?08406@21P1g0@@0SP8908l22P2<0@P0S`4;09813@2E0P`0V@8;0:01
1`2Y0`X0Z0890:L2202e1@/0]P<;0;P3302o1@d0a0L>0<473@352`d0c0`>0</@4`1o4A<0`ZZX0>_X
i@3Ui^@0i>CU0>KTi`3Ui>D0i>?T0>7Qh@3Th^40jMkL0;jZZ011@T@0_<330>KWj@3ThnD0jn[/0>WY
j`3/inT0gJb`0<8X;`3K4AL0d@/A0<P53P2n10/0^`<<0;/53P2d0`/0[`8;0:`22`2X0PX0Y`490:<1
202R0@P0X@490:012P2R0PX0X@4;09T11`2H0@H0V@4609`1202L0@T0W04809P11`2C0P`0PP4608P3
2@210@H0P0<807811@1X0@D0JP8506<10`1T3PP00`00o`090?ooo`05052@N03oP000oh000?n0003X
J3`06P3oP0000`3XJ3`0oh000?n000090?n000030=1@N03oP000oh0000<0oh0000<0X23`0?n0003o
P0008@3oP003003o00P0oooo1@00o`00C00dj240Ie5?05A8F@0622X05Ai702D^F`021cd0C49P085N
K028Ff`0OT]L0819E`2>Ef00VfEZ09iZK02SLW80YG]j0:V6OP2_SX40/IB70:nER@2dWI40_:VP0<6a
ZP2l/:d0_;:^0;jc/@2l];40^KJe0;^i]P2k^[/0^;Rk0;Vh^P2h^KX0^Kfn0;Vm`02k_/<0^[g10;Bj
^P2f^k`0/[Fh0;>h^`2N[[l0?5B;0:4fC02l1`l0_@@@0;D3402]BDh0/Zn`09jX/02MZ;@0GgR?08JP
_`1@@F`0RPTI09H22`2C1Q80Y6ak07Z@YP2IZkL0QI>J07Z8S`1hQHP0L7io06inOP1bOh00JGQg06Qg
MP1PLg@0AEY]014RD0013D`00@]301@TA00_LC88003o00P0oooo1@00o`00101@T7P0oh000=1@N03@
D7P60:0Pl0030=1@N03oP000oh0000d0oh0000@0d51h0?n0003@D7P0oh00202P8?000`2h>;@0d51h
0:0Pl0030:0Pl0060=1@N03oP000oh000?n0003XJ3`0^3Rd1@2P8?030?n000030;Ph]02P8?00X23`
0080X23`00<0^3Rd0?n0003oP000103oP0000`2h>;@0X23`0:0Pl0020:0Pl0030=1@N000o`000?l0
00H00?l02`3oool000X0oooo00X07l`004d:001]EUD0@Sdo04]8B`0I40l07`X90441101Y0PH0N045
0P2400L0B@270@X0RP0809012P2B00X0U@4909h2202W0`X0Y@870:H21P2b0`X0/`<;0;P32`3020/0
a@P>0<@83P332@h0aPP?0;/C6@1^?Sh0i^;Q0>SXjP3Sh^D0hn;T0>3Qh03Rhn@0hn;U0>CRi03ThnH0
iNO[0>KXj@3Vj>L0f=_K0>OXj@3Ti>D0jN_[0>KXj03Wj>X0l=SM0;]2B`3H4AX0e`hD0<X83@321Pd0
_`H?0;/43@2g0`/0/`8;0:d22P2W0@P0Y`4;0:D12@2T0@P0X`490:402P2R0@X0XP4<09L22@2D0@H0
V@470:012P2M00P0W04909T22@2L10d0T`@;08/1202:0PP0QP4607/21P1U0@<0I04206020`1J2080
0`00o`090?ooo`05052@N03oP000oh000?n0003@D7P0D03oP003003o00P0oooo1@00o`00C00ciAT0
SfiN04i2C`0>3BP0@SmH00hHB`021cd0ETUQ07mMK025GF/0PE=N085=F@2>F680UF5U09]YJP2SLG80
YGMh0:J1NP2^SH40[i630;6HR@2eX940^jZN0;f]YP2h[ZX0^Jn]0;N^ZP2l];00^K>b0;Zd/`2i]kP0
^[^k0;Ri^@2f^[X0^Kbm0;Zn_`30`L@0_Ko30;Rk_`2i^kh0]KVm0;:i^`2`^;d0CVZH07UIPP2_31T0
^P<?0;P23P2X5Ad0_j2T0:J_]P2kb=40RIb]06Z<[P0dBG`0OBM209H33P2H0P/0RQXS08=oRP2:WjX0
V:N_08RFWP1ePhD0LX6106mlO@1^O7/0JGUi05acN`0/@F80115<004:C@0134d01A=803A8G@0d=cL8
003o00P0oooo1@00o`00101@T7P0oh000?n0003oP0050:0Pl0030;Ph]03XJ3`0oh0000P0oh000`3X
J3`50?n00080j6Pl0P2P8?000`2h>;@0j6Pl0;Ph]0020;Ph]0@0X23`00@0^3Rd0:0Pl02P8?00X23`
103oP0000`2h>;@0X23`0;Ph]0030:0Pl0040=1@N03oP000oh000?n000@0X23`00<0j6Pl0?n0003o
P0000P3oP0000`3@D7P0X23`0:0Pl0030:0Pl0030;Ph]03oP0000?l000L00?l02`3oool000X0oooo
02h08<`104/:001_F5D0BD=403li?00[6QX070<304T2101/0PH0M08507X2201j00T0P@4;08P22`28
0@T0S04909T22`2M0@P0YP<90:@2202P00D0/@@<0;412`2g1@`0_`H=0<@93`301`d0a0P>0<D:4@2J
3140PG1_0>KViP3XjN/0j>SY0>KVi`3Qh^40hn?U0=k9d02kP8l0/Fj10;JAX`3?bmD0hNGX0>CWj03U
i^H0hnGU0P3Uj>T09P3VinT0k>7U0<=ZL`3@51`0ePlG0<d;4P321Pl0_`D>0;`3302i0``0]P<<0;42
2`2Z0@X0Y@490:D23@2V0@/0Y@4;0:<12`2R0P/0X08:0982202C0`T0V@4909l12P2P0@/0X04<09`2
2`2A0`L0Y0L>0:453P2<0`T0SP<:07/21P1S0P<0F00105T20`1G2`D01_410P00o`090?ooo`03052@
N03oP000oh000280oh0000D0j6Pl0:0Pl02h>;@0X23`0=1@N0080?n000030=1@N03oP000oh000200
oh0000<0:<Pl003o0000o`00203oool6003o000X0;:9J`1=?dT09R4c03/dBP032d006R5>04e4GP1o
H6l0QUYY08AEG`24DU/0SEUR09ITI`2IJF/0Wfaa0:AeMP2XP7/0[X^10;2@Q02aV8X0]9b@0;bXW02h
Zj<0]jn[0;J/ZP2g[Z/0^[:^0;Nc/02i]KH0^;Ni0;Rh^P2h^;/0^[bm0;Zl_`2j_;h0_/330;fo``2l
_/40^kk00;Nl_`80/kVk0280U:Nl045CR`2M:Ch0]PD@0;P33@2`1@l0[5aS0;6a^@25V:/0a=KW06f<
Y`1dSK<0ESUS09465`2L0Pd0TP@@09EUKP2DXj/0RYVN08:=T`1kRXd0LH:106imOP1XNWd0DFQk01<X
FP013E000@Y=004<C00B9eD0C65c05]/L00f?D002>D41`00o`080?ooo`H00?l000@0X23`0?n0003o
P000^3Rd1@2P8?0?0?n000040>QX?03oP000oh000?n000H0X23`0P2h>;@20:0Pl0030=1@N02P8?00
X23`00<0X23`00D0j6Pl0?n0003oP000oh000=1@N0060:0Pl0<0oh0000D0d51h0:0Pl02P8?00X23`
0=1@N0020?n000030>QX?02P8?00X23`00@0X23`00@0^3Rd0?n0003oP000:<Pl1`00o`0;0?ooo`00
2P3oool0B@0Oc@40B0X006mJF01KEUH09R0Q02dK6`0I0040D@<406X10P1_0P<0L`4707H12@1h0PT0
PP8;08811`2:0PP0W0<<0:022P2W0PX0[0<:0:P2202^0`X0/@<:0;042P2g1@/0^`@90;X52`322140
b@/G08d:402=PhD0j>OZ0>SYk03XjNX0inKY0>OVi`3Yi>L0/fI`0<@K9P3?5Ah0bAhW08dO;@23E6D0
[jRd0=[Nh@3Ri>D0i>GW0>KXjP3UinP0iNCV0=:QY`2l5Ad0bP`C0<L93`351Pd0aPL<0;`32@2h0`/0
]@8;0;422P2`0``0Z08:0:H22P2V00X0Y0490:@12P2R0@/0WP4:07h21@1_0@<0S`<:09`11`2N0@/0
0P2T0Pd02`2H0`T0Y0H?09l53@1i0@@0QP<907d31`1W0P@0G`0205T20P1I2@@06LD100800?l02@3o
ool00`1@T7P0oh000?n0000R0?n000030=1@N03oP000oh000080oh0000<0d51h0;Ph]03XJ3`01@3o
P0000`3@D7P0oh000?n0000P0?n00003052@N000o`000?l000P0oooo1P00o`00C01dSc40CC]003/b
@@0/9T002a1004M4I`10?5T0Nei]08MOK@25F6<0Q55J08mJHP2FHVP0W6Y^09iZL@2TLgH0YGej0:b9
P@2/T840/9J70;>LS@2gXiT0^JZR0;NZZ02cZZT0/JbX0;B`[P2d];40]kJd0;fm_@2m_l00^;Vj0;Vj
_P2k_/40^ko10;k2a030`LD0^ko30;Zn`02e^kh0/kVm0;>g^`2^^<40@EnC08=DN@2^21L0]`<=0;<3
3`2P7BL0_j^d09:R/`1NOi`0Ni^`0;W<hP0c?6h0O1Xc09H24@2F0Ph0RR/e0:RZ[`2;VIl0P8^>07B2
Q@1]OX40JWj503aDLP065eL00@YD004:D0022d/05BQB061gP@1TN7T0Ffma03I4B@0Cd0h7003o00P0
oooo1P00o`00102P8?00oh000?n0003@D7P50:0Pl0030>QX?03oP000oh0000P0oh0000/0j6Pl0?n0
003oP000oh000>QX?03oP000d51h0?n0003XJ3`0d51h0;Ph]0030:0Pl0030=1@N02P8?00X23`00L0
X23`00<0^3Rd0?n0003oP0000P3oP0060:0Pl0040>QX?03oP000oh000?n00080X23`00@0d51h0>QX
?03oP000^3Rd1P2P8?001@2h>;@0oh000?n0003oP000D91h00L00?l02`3oool000X0oooo05H08<d1
04D;001hHV80FEEH01`B4P0F10D0:P8205T30`1[0P<0K@4507821`1d0PP0L@4508012@250@L0RP48
09T2302N0@P0X`470:H11P2V0@P0ZP490;422`2d10/0/`D:0:`2202g1`h0^`H=0<053`2P3Q@0MF=W
0>CTj03Xj>X0inOY0>SXjP3XjN/0jnOY0<1[L`395A`0fA@H0=`E5`3B4aH0_aDN06`B7`1jMGd0g>3Q
0>?UiP3UiNL0iNKY0>?SiP3Obll0/BXa0<P?503:3180`@D>0<053P2o1Pd0^`D:0;H32P2c0@X0/@8<
0:h12`2Y0@T0Z0890:H2202P0@T0X@4<09h12P2A0PH0PP4409421`2L0@L0W`4:0:<22`2Q0PX0U@8:
09h53@2N1P`0T0@;08/220200`P0L`8606h31@1L0P80E0L201S40@800?l02@3oool00`1@T7P0oh00
0?n0000K0?n000030=1@N03oP000oh0000@0oh0000<0d51h0?n0003oP000103oP0000`2h>;@0oh00
0?n000030?n000030=1@N03oP000oh000200oh0000<0D91h003o0000o`00203oool6003o001<05Bj
7`1<>C<0CD5<01XH=`0[:dd0F4mZ034^D`1iGfl0PUeZ08EGI029F6<0SUYT09=PJ02FI6P0W6Q]0:=b
MP2WOGh0[XR10;2AP`2_U8<0/YZ:0;JRV@2gZJ80/JFR0;2VXP2]Yj@0Xj2O09nQW`35bLT0cM3E0=OL
h@30a<T0]KVl0;Vn_`2h_;h0_L?30;^o``2o`lD0^ko00;bm`P2f^[h0];Rk0:ne^@20Tk<0C5N>09XJ
;P2g0`l0]08>0:/64`2CEfH0_<_J04e_T02K_=00b][U065dVP1N=e`0S0@E09D22P2;2A<0Tg9f09BP
X`2:VIX0JWan06N0Q@0cCW400QEK004>FP034Td05BMI008>A@16GW00J7an065gO01BJW@0>4]A026N
7@L00?l0203oool6003o00040:0Pl03oP000oh000=1@N0@0X23`00<0^3Rd0=1@N03oP000203oP002
0=1@N080oh0000<0j6Pl0?n0003oP0000P3XJ3`00`3oP000d51h0>QX?0040:0Pl0030>QX?02P8?00
^3Rd00L0X23`00D0j6Pl0?n0003oP000oh000;Ph]0050:0Pl0050;Ph]03oP000oh000?n0003XJ3`0
0P2h>;@00`3oP000d51h0:0Pl0050:0Pl0060;Ph]03oP000j6Pl0=1@N03oP000P<001`00o`0;0?oo
o`002P3oool0A`0Pc@40B0/006iEEP1SFel040H601410@0]0@40H08306/10`1[0@D0MP8807@0201e
0@L0O`4908P22`2;0@P0U04;0:022P2V0PP0Y@470:81202X0@T0/@8;0;D33@2/0`X0ZP@:0;<42`2j
0`/0`@D<0;D?5P1O?T80hN7T0>SXjP3VinT0j>[]0>KXjP3Vhn<0cHJ<0<LI8P3F4aT0da0E0=@@5P3@
41L0XA8I04/a=`3@dmH0i^KX0>KVi`3ShnL0i>?W0>?Jg@2_ADd0``lD0<H93`2m10d0_0<=0;`43@2o
1Ph0_0D=0;L1302e0Pd0/08<0:P12P2V0PX0X`480:81202P0@L0WP4:09L11P2@00<0U`470080W049
00d0X04:0:022`2C0PT0V0<<09D42`2@10`0R08906`1101[0@<0K04306@20P1J1`<06LD200800?l0
2@3oool00`1@T7P0oh000?n0000K0?n000030=1@N03oP000oh000180oh0000<0d51h0?n0003oP000
7`3oP0000`1@T7P00?l0003o00080?ooo`L00?l002L0HD<f05=8E@0;32l0CDIN065DL00M7D`0Memb
085KJ@27FVL0ReUS08iJIP2CH6L0VFM]09]XK@2QKg<0YgYn0:f8PP2aTH@0/I:40;>LSP2fY9T0]:JN
0;FZYP2/Y:00[JNT09nLVP2a/Zl0]k^n0;Bf_036c]40al_A0;Vn`P2h_<00^Kg00;g2a@2l`/D0^l75
0;c1a@2m_/800P2f^[h08P2`];T0ZK>o03ABQP2;BfP0/PHE0;L43P2c0Ph0WRTh08B9X@2A[/H0QZBf
0<[Ih`2^_]H0=cQZ07X?9@2E0@d0T`8>094mB02=Si<0NXN;05]`OP0O>FH00QEP004CGP0?9E/0@eaf
024gG@0;7dl0FgAn06ImP`0dBF`011U;02e6G@0NKah7003o00P0oooo1`00o`000`3XJ3`0d51h0:0P
l0050:0Pl0030>QX?03oP000oh0000@0oh0000<0j6Pl0?n0003oP0002@3oP000103@D7P0X23`0=1@
N03@D7P=0:0Pl0050=1@N03oP000oh000?n0003XJ3`01P2P8?00103XJ3`0oh000?n0003XJ3`20:0P
l0030;Ph]02P8?00X23`00D0X23`0P3@D7P20:0Pl0030;Ph]03@D7P00?l000H00?l02`3oool000X0
oooo05H08Lh204T90020IfH0CD=600d51@0D0@40?P<306D2101V0P<0I`4407<21P1e0@P0M`4907P1
1`280PX0T08;09<02P2M0@X0W`480:41202S0PT0Z0490:d22P2`0P/0[P<<0:h32@2j1@`0c@`A0=L?
4`3D5a`0E1HJ0=CCf03TiNL0j>WY0>OXj`3Yj^`0jNSY0=2NX@2m8RT0d1<I0=0@603C3a@0da4D0;`D
6`163180^;Vn0>?SiP3Wj>T0iNGY0>?Ti`3ThN@0_79g0;hG70362Q00``L?0;l73P2i0`d0^0@=0;D3
2`2d0``0Y@<;09P;4P2c:380W@dF0:<33@2T0PL0X@8909h12P2I0@L0T`0509H2202L0PT0W04709h1
202O0PX0V`8<08d11`2@1P/0U`D<0903301d0PL0K@8506d1101Q0@40G@P401[60`800?l02@3oool0
0`1@T7P0oh000?n0000L0?n000030=1@N03oP000oh0000/0oh0000<0X23`0?n0003oP0000`3oP000
0`3@D7P0oh000?n0000O0?n00003052@N000o`000?l000P0oooo1`00o`00B`1bDCL0B3m<00d>;P1Q
EFD0BTQT00X??`1^Fg@0Oe]W08QKJP2:F6@0ReQQ095MH`2KJ6l0WFY`0:5_LP2XNgd0ZhR10;6@Q02b
ThP0/YZ=0;6NU02_XIP0[JBO0;2XY02_YjD0UI6C09nOXP31a<L0_l?80<gEfP2k_L@0^[_20;bm`P2i
_L40^l740;g2a@2m`<D0_L750;foa02f^[d0/[Vk0;6f^P2//[L0L8NV05QEQP2N4B@0]@<@0;<23@2R
1aL0OeUb0:6icP38g>H0b]SS0<KGi01:G8D0JRm>08l23`2C0@`0Q`lL09R4QP1lRi<09Ci/008FI@03
5f<09ciZ05ieP@19HGH04BQD024gH@0nEgT09Ci[008CF0013Dh06BiD028e:007003o00P0oooo1`00
o`001@3@D7P0oh000;Ph]02P8?00^3Rd0080X23`00<0d51h0:0Pl03oP0003`3oP0001@2h>;@0X23`
0;Ph]03@D7P0j6Pl00l0X23`103oP0000`2h>;@0X23`0:0Pl0030:0Pl0050=1@N03oP000oh000?n0
003XJ3`01@2P8?000`2h>;@0X23`0:0Pl0060:0Pl0030>QX?000o`000?l000D00?l02`3oool000X0
oooo05H08/h204X8001kGV00?cHi00`20P0J0000AP8206430`1L0040H@4306h21`1b0@P0L`4707X1
1`270@T0R`4809812@2I0@L0VP4609/11`2O0@T0Z04;0:h3302[0PX0Y`470;853P2l1Pd0e0lC0=hC
5P3H4QL0L@/>0:JVZP3Zjnd0jn_/0>SYjP3XjNT0i^GW0>C:c02X>3l0aADK0<d@5P3B3aH0dPlC0<dC
601k31@0EdY?0=KKgP3TiNP0h^;U0=oPh@3Rh^D0dZ^`0:@L90312a<0`0H@0;d53P2k1@d0]`<<0;@3
3P2Z0`d0O@<608`63`2N2AH0T`hH09432P2S0PX0X08<09h2302G0@L0S`4608`11@2L0@T0W@4809d1
2P2M0@T0WP8;09X2302I1@d0V`H=09<32`1o0PL0L@8507021@1S0P80G0@101[40P800?l02@3oool0
0`1@T7P0oh000?n0000L0?n000030>QX?03oP000oh0000<0oh0000<0d51h0?n0003oP0001P3oP000
0`3XJ3`0oh000?n000020?n000030>QX?03oP000oh0001l0oh0000<0D91h003o0000o`00203oool7
003o000T05=h900l<dD08R4l0516FP0^<eP03aA704]2H`1lFfT0PUQV08MEI02:F6<0SeiT09IUJP2K
JFh0Wfib0:MiN`2YQ800/9240;2CQ`2dVi00/9^C0:RJT@2VW9T0Zj6P0:nVY02b[JX0/k2^0:ZYZ`2Z
[:l0ZZbb0:Z]/P2e]k`0_;k30;^n`P2j_l40^[o30P2k`LH09P2l`LD0][^n0;:j_02_][P0ZkBf0:6^
_00^BH40TCmL0;84502c0Pl0[08@09DdAP28SZ00c=cV0<_Ih`39en40VJ_304@hHP212Qd0U08<08l3
3@2?DeP0GVf500<JI0036f40=e1d06UmP`1PM7l04BQC04ILMP0dAfL00A5J004?H00245d00a5=00`L
@`0_=d001n@41P00o`080?ooo`L00?l000@0d51h0?n0003@D7P0^3Rd0`2P8?030;Ph]0d0oh0000@0
d51h0?n0003oP000d51h1`2P8?000`3@D7P0X23`0:0Pl0080:0Pl0050=1@N03oP000oh000?n0003@
D7P01P2P8?040?n000@0X23`00<0j6Pl0;Ph]02P8?001`2P8?000`3oP000D91h003o0005003o00/0
oooo000:0?ooo`1802;>0P1A2`00O5iQ03<[;00@0@40:08204h20P1M0@80F@4005`10P1[0@L0K@45
07411@1n0@L0QP4808P0202?0@X0T`4609H11`2I00P0W`8:0:D12`2[0PX0[0<<0:P1302_0P/0^@<:
0=4?4`3G4A80e0lC09@@4`1cKW00i^W]0>OWjP3Rh^@0h>;Q0>;Si03Ufm/0^6ec0;`H803>3QH0d@lG
0=4?5P3=3aH0X18G02P62P33a/`0i>GY0>?TiP3Oh><0hN?U0=g:c@2F<CT0^0`E0;h7402l1Pd0^@H;
0;@32`2g10h0ZPL@06L1102D1`h0Y@8>09X53`1m0PH0X0<=0:412`2M0@T0VP4809H11P2G0PP0W047
0P2L0@P0302L0@X0U`8:09812@2H0``0Q`8808P3301d0@<0HP4206@31@1R0P<0G`D303>:10800?l0
2@3oool00`1@T7P0oh000?n0000L0?n000030=1@N03oP000oh0000`0oh0000<0d51h0?n0003oP000
0P3oP0000`3@D7P0oh000?n0000O0?n0000308300000o`000?l000P0oooo1`00o`00C01ZRC<0<BTn
03D`B`0k<e408RMB01/PCP0Z:E40N5i^07iEH`28E6<0SU]Y08eNIP2DIF`0Vfac09m_L`2UNWT0ZHB0
0;6?Q@2`UHX0/IZ@0:nKT`2ZVI<0Z9jL0:bSX02aZJD0]k6`0;Fd/P2b/Jl0YJ:T0:j]/@2PXjH0Z:^_
0;Fi_@2e^kh0]ko10;_1a@2k`/L0^/770;[0``2g_;l0/kRl0;:g^`2/]KP0Yk>i04]WUP1`Dg`0Z@XJ
0;D23`2`0Pl0VaPX0>k6e@3Jd^80e]7S0=?<g`3@b>00DCiS08@L<02A0@d0T@8<08H[=`11BWD011eV
03eLP01TNh<0KH:603E:K00C:e@0JWj505IYO@024eD00@iL008DE`0Z@6<07Rm603I3B00LU146003o
00P0oooo1`00o`000`3@D7P0oh000:0Pl0050:0Pl0<0d51h3P3oP0000`3@D7P0oh000=1@N00B0:0P
l0@0oh001P2P8?00103@D7P0oh000?n0003oP0030:0Pl080d51h0P2P8?000`3@D7P0X23`0:0Pl003
0:0Pl0030=1@N03oP000X23`00H00?l02`3oool000X0oooo05H08ll2054<001aEUH0:R@U00`10@0a
0P<0D`<305T20@1E0@00F@4206T11P1]0@H0L@4607h12@270PX0R04808d12P2B00T0U04809P1202N
0P/0XP480:H21`2X0PT0Z@8;0;<330301`/0d0dA0<h<3`3=31<0Y@hD04hj?@39c]80hN?T0>;RhP3P
h>00hN;R0>GShP3FZZd0^2H/0=0@603B41L0c`dF0<l>5`2k4a/0B`8808n<TP3TinT0hnCV0>7Ri03O
h^80gm[J0:5SI`2Y4AT0^PHA0;X63P2g10/0]@D>0;<33@2Y2A40FP4306X42P2;1@`0Q0D;06@2102K
10l0X08<09h22@2K0PL0U@4709D1202K0@P0W@4709h12@2M0@/0V04<09@12@2J0`d0R@8908D22P1n
0PT0KP8705l10`1P0@80H@D403B<1P800?l02@3oool00`1@T7P0oh000?n0000L0?n000030>QX?03@
D7P0oh0000@0oh0000<0X23`0?n0003oP0001@3oP0000`3@D7P0oh000?n0000T0?n0000308300000
o`000?l000P0oooo1`00o`00C015/B<0:bDi04LnE00T8T@08bM=02XZD00=4D80J5U^07aFH@23D5h0
RUER095PJ02HIfl0WVee0:5cM`2WNgd0ZXF10:n?Q`2^U8/0/YbA0:bHT02[VY@0[J6N0:nWX`2c[:P0
[J^Y0:Z[[02c/K40[:V/0:nb]02[[Jh0Yjb_0;:h^`2d^[h0^;g00;_1a@2f_/40]Kfo0;_1a02j_l80
];Zm0;6j_02[];L0Zk>h07f@[P19DXL0VAda0;D54P2b0Q00Z`HI0:hZ@`2Q;d`0UbY6098UA02>8d<0
R1Xd08d96P2B0@`0T04<088?7`0g<680;4Qi06^2S`1YOh@0BFIo00TRD`18H7@0KX2006amP`0[?f80
21eC02]6J01EKGH0:Ca803a=D00TX1/6003o00P0oooo1`00o`000`1XZ3`0oh000;Ph]0050:0Pl003
0?n0003XJ3`0j6Pl0080oh0000<0d51h0?n0003oP0002@3oP0000`3XJ3`0^3Rd0;Ph]00B0:0Pl004
0>QX?03oP000oh000?n000H0d51h103oP0030:0Pl0060;Ph]02P8?00X23`0:0Pl03XJ3`0^3Rd0`2P
8?020>QX?0030?n0002P8?000?l000D00?l02`3oool000X0oooo05H08ll304`9001dF5P081TK01H2
0@0o0`80D`8205810@1A0@40EP4106L11@1[0@D0L04507d12P250@/0QP0908`12P2A00X0TP4909P1
2@2N0PX0Y04:0:X22`2Z0@T0]P<<0<D83`3?3140b`X@0<873P332A80^0dD04D@502YZjl0gMkP0>?S
i@3Qhn<0hnCS0>CSi@3/f=X0^4UA0<dB6@3A3QD0d0lD0=4?5`3=4AX0S`lH05e7C@3OhnD0h^CV0>3S
i03Ohn@0g^7P0<F/[P2J92d0]0L@0;D53P2e10d0]08?0;433`2]1@h0N`@904P9301H51H0?`8405@1
1`2J1100W@4;09`22@2I0@T0T@4609401@2K0@P0W@4809h12@2M0P/0V`8<09<22P2?0PX0SP8:07`2
201b0PL0L@8407021@1T0@80H0<2036810800?l02@3oool00`1@T7P0oh000?n0000M0?n000030:0P
l03oP000oh0000@0oh0000<0j6Pl0?n0003oP000103oP0000`3XJ3`0oh000?n000030?n000030:0P
l03oP000oh0001h0oh0000<0P<00003o0000o`00203oool7003o001<037E6`0M62P0ETiR00X?<P12
?UX0?cID0086?@0X:540MeMW08=CGP29EF40TF9Z09MZL02DK7<0Rf]b0:1kO`2WPH40ZhZ60:bCR02]
VHd0ZYZB0:VMUP2VW9T0[ZNR0:BQW`2RYJ@0WJ6U0:b]/@2QY:H0[[2c0:j`/P2VZjh0[[6f0;Fi_@2i
_/80_<350;_0a02j_l<0^<340;S0``2d_;l0/;Zl0;2i_02kaLT0Z[G104MRT01dEW`0W1//0:@;5`2V
3AD0X@hE09`@5`2C3aL0Sa0H08T=5P252aH0Q@XD08H94@272140N``E04LiH00bD7h0EG6;03=<M@09
9U`0AF5i06IkO@1^P7d0KGin06QjO01SMg`0IGQi05M]K`0R>4P0AeYO048m=PH00?l0203oool7003o
0003052@N03oP000X23`00D0X23`00<0d51h0?n0003oP0000`3oP0000`3XJ3`0oh000?n000080?n0
00030>QX?02h>;@0X23`00X0X23`00<0^3Rd0:0Pl02P8?000P2P8?001@2h>;@0X23`0:0Pl02h>;@0
j6Pl00`0oh001P2P8?040?n000030=1@N03oP000oh0000<0oh001P00o`0;0?ooo`002P3oool0EP0T
d0<0D0T006A3@@0E3@h05`4204820P1A0@40DP410541001J0@80IP4506/0101a0@80O08808<23024
0@X0R@0;09012@2E0PT0VP8809h12@2T0@X0Z@4;0:d22`2g10d0a@X@0<T:40331`d0`0L<0;l73@2l
2a40FPL;06]ZKP3@dmH0hN7S0>;Th`3Qh^80h^;S0>_Qi031LWL0bA@H0=4?5P3A41D0dPlF0=8@5P2g
61h0Ba`R0=;FfP3PhnD0gn?V0>3Si`3MhN80gmCE09Y0BP2_2A<0/@8<0;@43@2`0a00ZP4<0:`32`2P
20d0QcDg0<f@T`1O7R00K`<909h2302K00L0VP0909T12P2C0@L0U@4709T1202K0@P0W@4:09`1202C
0P/0OP0508H22P290`X0J00205L00`1a0PD0L`<506020P1M0`40<hX50P00o`090?ooo`03052@N03o
P000oh0001h0oh0000<0d51h0?n0003oP0000`3oP0000`3@D7P0oh000?n000050?n000030=1@N03o
P000oh0000`0oh0000<0X23`0?n0003oP000503oP0000`20`0000?l0003o00080?ooo`L00?l004d0
;N4G02dO9P1ABel02`ld06EFI`1IAed010Dk00H8?@1XCVD0OE1L08MHH02HJW<0Uf]c095ZL`23J780
SG9f0:R2Q02[RHL0Zi280:^GS@2YVY00WYF<09nGT@2KUI00/k>_0;k3aP2j_/D0[Jfa09nRY02JW9l0
W9nU09RLX@2Y[[@0/kRl0;Vna02m`/H0^/340;Nm`P2k`LD0_<;50;Nm`02d_L00^lC70:nh_P2b_/H0
//GC06InX`25Qj00LF=l0;JOX`2nYJ@0_jRX0;bWZP2jZ:`0W9>O08IoSP1eKWP0Qg=b095fM`2=NWT0
LGZ502HnJ`0G<f<0:TE/05acQ01`PXD0KWmo0720O`1]Oh40JWYm06QhMP1TMG@0EVUd01P_BP1>IFT0
@DU100cI1`05003o00P0oooo1`00o`00101@T7P0oh000:0Pl02P8?020;Ph]0<0X23`0P3oP0040=1@
N0X0oh000P2h>;@>0:0Pl080^3Rd00<0X23`0;Ph]02P8?000`2P8?00203XJ3`0oh000?n0003XJ3`0
d51h0;Ph]02P8?00^3Rd0`3oP0001P3@D7P0X23`0:0Pl02P8?00^3Rd0>QX?0<0oh0000D0j6Pl0?n0
003oP000^3Rd0=1@N0020?n00003052@N000o`000?l000<00?l02`3oool000X0oooo05H09=44050<
001WAD802PD501@10@110P<0E@<305<20P1C0P00F`4406P11P1]0@H0K`4507D52`2461l0L08808@2
2`2=0PX0U04909T11`2M0@P0X`490:H0202/0PX0/`<:0;l730342Pl0`0L<0;l63@2o20h0_@`A07/<
4P0^8bH0^Kc00>;Qh`3QhN40hn;T0>GTi@3UhN80c9ZL0<0I7P3?41D0dPlG0=8>5@3@3Q@0aA<J05`;
4@2c]K/0h^CV0>;SiP3Ph^@0gn3R0>?LgP2WIfh0ZP`F0;<6402`0`d0[@<>0:T2302W0@X0YP@=0:HX
<P2H>4<0Sb8/09X53`2S0P/0W04809/12P2G0PT0TP0609P1202J0@T0W@8909h22@2K0@P0SP8807`0
1@240`d0OP8907T42P1Q0PD0K`<706`2101L0@40F`<103F=20800?l02@3oool00`1@T7P0oh000?n0
000N0?n000030=1@N03oP000oh0000/0oh0000<0^3Rd0?n0003oP0000`3oP0000`3@D7P0oh000?n0
000M0?n0000308300000o`000?l000P0oooo1`00o`00C@0<n0D0Bc8X040lD`0S9D<0KeeS06iHI`0<
2CL030dm075DJ@22EF00S5iZ09MYM@2JJgL0Tf]e08YZLP2LN7X0Yh200:J5P`2TRXD0Z9F=0::DR`2R
Uhh0VY:909NAR`2SXZ40b<[=0;Vk`02WZ:/0YJZZ0:Z/[@2OXJD0SiFJ0:J][`2f^l40_L360;c1aP2m
`lH0^kk40;g1a`2j`/D0^;o20;Fl`02oal/0^/370;S3b`2O[kd0X;S?05n7[`25YKl0cN7Y0=3Mi03A
gN@0cm[T0<_Hi01iSJP0Rj>h09>T/@2JZK<0UjJ]07b;S@1jR8`0MXB:07:4RP1bQ8L0LXF507:5QP1`
PGl0KH1n06f1P@0gCUh0FW9f059YLP0M<5H00@e202a4F`18EeL06jPC00D00?l0203oool7003o0006
02S8?03oP000X23`0:0Pl03oP000d51h0`2P8?000`3oP000d51h0:0Pl0020:0Pl0030>QX?03oP000
oh0000L0oh000P3@D7P00`2h>;@0X23`0:0Pl00:0:0Pl0060;Ph]02P8?00X23`0;Ph]02P8?00^3Rd
102P8?020=1@N0030>QX?02P8?00X23`00D0X23`0`2h>;@00`3@D7P0j6Pl0?n000040?n000030=1@
N03XJ3`0d51h0080X23`00<0^3Rd0?n0001XZ3`01@00o`0;0?ooo`002P3oool0EP0Td@@0C`d105<a
;@080@40808104@20P1>0@80D04205@10@1H0@80I04606T11P1R0@<0MPL=08@;5@1Q0@D0M`<:08h1
2P2D0@T0U`4909`12@2R0@T0Y0490:`22P2m1`d0a@X@0<07302l1`h0^`LA0;d84@312a00XA0F02X1
102<S900h^7P0>?Ph@3ShN@0iNCV0>CRi03Pb//0]2T/0=0B5`3A3aD0dPhE0=8@503=41H0S0hE07Mb
N03RhnH0hN;U0>;Ri@3Pgn80h=gQ0<:SZ02P5Ad0]0TB0;463P2/10`0Z0<<0:@12@2U0@`0Y@8@0:83
402T0Pl0Z08=0:D2302P0P/0W@4809L22@2E0@P0V08909/1202M0@X0X08:0:412`2L0P/0U@8;09D3
3`280`/0NP4706l21P1R0P@0GP4206820`1M0P40>7X50P00o`090?ooo`03052@N03oP000oh0001h0
oh0000<0d51h0?n0003oP0000`3oP0000`3XJ3`0oh000?n000050?n000030=1@N03oP000oh0000<0
oh0000<0d51h0?n0003oP0007@3oP0000`2XR3`00?l0003o00080?ooo`P00?l004`0H50Z038/A`13
?E<0LEeN071LIP0U7T<03`lm07=GJP22F6@0SfA_09IXL`2JKGL0Vg9j09ieO02SNWd0YGem0:F1P02N
PGd0Wh^20:>ES02HSH@0WYB;09nFS`2ET8/0VYND09ZJU`2IVYT0Z:f]0:N[[`2QY:P0T9>G0:J][`2e
_;h0^<730;c4a`2l`/L0][c30;2h_P2i`<D0^/340<?9c@2d_L80^LG:0;K5c@21VKD0WKG>076B/@2i
d]h0dMoX0=3Li@3>g^D0c=_T0<_Ii@2]`ML0EGFD07b@XP2AWj/0QiFL08JEV020SY80MhB607F3Q@1e
Ph@0LH620722Q@1`PH80KGj006YmO`0_A5X0>5=_00dMC0012TD00@]200hO@`1:H6<08Z8M1@00o`08
0?ooo`P00?l000D0d51h0:0Pl02h>;@0oh000=1@N0030:0Pl0030?n0003@D7P0X23`0080X23`00<0
d51h0?n0003oP000203oP0000`3XJ3`0oh000>QX?00=0:0Pl0030;Ph]02P8?00^3Rd00@0X23`00@0
d51h0>QX?02P8?00d51h202P8?000`2h>;@0oh000?n000020?n00080j6Pl0P3oP0000`2h>;@0X23`
0:0Pl0030:0Pl0030?n00020`0000?l000@00?l02`3oool000X0oooo05H09]<6050>0P1=<R`01`41
02X10P1<0`@0C04205410@1H0@40F04005l10`1U0PL0D@4307H32`270`/0I`8606/21`2>0PT0T`49
09L12@2I0@T0WP8:0:<22@2_10X0_@H<0;h6302l1Pd0_@L?0<0840302A00`@/@0;@=5`1M1P`0GUEK
0=kNh03QhN80hNCT0>CUi`3Ui>H0i]kP0;YDF`3<51/0dQ0I0=<?603@3QH0ca0F0;DC6`1?;cH0dmGI
0>;SiP3Ph><0h=oT0=kNh@3Jcm40V2hg0:h:502`1a00ZP@>0:P23@2T0@/0XP8;0:023@2P0@/0XP4<
0:H22`2S0@d0X@4<09h22@2L0@T0V@4909T12P2J0@T0W0480:412`2V0Pd0YPH@09@32`290PT0SP8:
08H120210PT0N08707021@1R0P80G082051D3@800?l02@3oool00`1@T7P0oh000?n0000N0?n00003
0=1@N03oP000oh0000@0oh0000<0j6Pl0?n0003oP000103oP0000`3XJ3`0d51h0?n000030?n00003
0>QX?03oP000oh0001d0oh0000<0d51h003o0000o`00203oool8003o000;05Mk9P0S7SL0FTmO0517
E`1;A5/0@cUG00h??01fFfl0R65]08iVKP2GKGL00P2MM7`0?`2MLW/0WWEi0:5iO@2PO7h0X8F20:6@
Q`2NSHD0VY2609nHS`2OV980UY2;09jKU02NWIT0VI^H0:V^[@2PZ:X0[:ba096DV02MYJL0/KRk0;_3
aP2l`lL0^L350:^c^02d_<80^/C70;W1a@2ka<P0^lS>0;[9d@2S]L40]/WJ05]oY`1iWKX0amcZ0=7N
i`3@gNH0c]cV0<gKi`3;fNL0RInf08nU]`2aa=40T9jZ082@UP25TYL0PI2D07f=SP1bQH<0LH:107B3
P`1_PX@0M8B606ioP@1RN84083AL004<B@0124L00@Y300LH@P065cT0@UYQ03B8;`05003o00P0oooo
2000o`040=1@N0@0X23`00H0d51h0?n0002h>;@0X23`0;Ph]02P8?0=0?n000030;Ph]02P8?00X23`
00T0X23`00<0^3Rd0:0Pl02h>;@01P2P8?000`3@D7P0X23`0:0Pl0090:0Pl0030>QX?03oP000oh00
0080oh0000<0d51h0>QX?02h>;@01@2P8?000`2h>;@0oh000=1@N005003o00/0oooo000:0?ooo`0b
02SD1`1F4`<0?B4N00H0000`0@40BP8104X10P1C0P80F@8105`20@1T0@D0HP8804810P1U10T0J`<9
05411P1X0PP0S`4909402@2G0@X0W08:0:012@2U0PP0]@D=0;T6302h10d0_@P@0;`63P2n1`l0_`L@
0<4:4P2j3AL0Q`dG04Xb>P3De=P0hnCT0>7Ri03Ti>D0iN?V0>KSiP34OH80b1LL0=<C6@3C41L0d@lG
0=0>5`3651d0BPdD0<;6b`3Qhn@20>3PhP0R0=gMgP3Pfml0VTeD0:X<5P2]1Ph0ZP@=0:D23@2R0@/0
W`4909d12P2L00X0W`4;0:@22`2Q0@/0X@4<09l12P2M0@`0VP0909X1202J0@L0V`470:012P2X0`h0
ZPD@0:84402C0PX0S@8:08H01`200@P0MP4607<1101W0P@0GP4104mD3@800?l02@3oool00`1@T7P0
oh000?n0000O0?n000030=1@N03oP000oh0000<0oh0000<0d51h0?n0003oP0001@3oP0000`3@D7P0
oh000?n000030?n000030=1@N03oP000oh0001`0oh0000<0d51h003o0000o`00203oool8003o000P
05BI900O62T0IUYW01HI?00P9DT0HEEY00h>=`1`G7@0S6Ie091WL`2EJg@0U6]c09Q^MP2OLg`0WW=h
0:9hNP2NNgX0WXB009j=Q@2SU8`0WY6;0:2HT`2JUY00V9F<09^IT@2MW9/0UYJF0::QX`2BUYP0/;6b
09ZNX@2LXjL20;_1a00Z0;Voa02e_l<0Z;>g0;Jna02laLT0am3D0;O1b02lbM00]LK>09Ncb@23X/00
JXb_0:_3eP3Ch>L0dMoW0=7Oj03Ag^L0b]_/0:jmf`1ADh@0OFB907eRN`2MTj40OXR@09:QZ01hQXh0
NHN;07B5Q01dQ880L8210763Q01dQhT0Efan01D[H0013e000@Q8004=@@0L;Td0Bf9/0354E00gD5d0
B5e51@00o`080?ooo`P00?l000<0Z8Pl0?n0003@D7P01`2P8?020=1@N0030;Ph]02P8?00j6Pl00X0
oh000P3XJ3`20:0Pl0030;Ph]02P8?00X23`00L0X23`00<0d51h0:0Pl02h>;@01@2P8?00103oP000
j6Pl0:0Pl02h>;@90:0Pl0030;Ph]03oP000oh000080oh0000<0j6Pl0:0Pl02P8?000`2P8?001@2h
>;@0d51h0=1@N03oP000j6Pl00D00?l02`3oool000X0oooo04D09m@7058C1010:BP02`410443101?
0P80C04205810P1H0@40G04206H21@1T0`T0>@8303P20`120@D0A0020702202=0@P0TP0:09H12P2J
0@X0XP8;0:X63@2[1P`0]`P@0;L33P2l1a00_@P?0;d93`2m2A00_@TB0;`:5@2V4Qd0@Q<L0<O8c@3Q
h^@0hn?W0>GTiP3UhnD0iNCV0<nUZ@2n72<0ca@I0=0C603A51P0ca8G0<XE6P1[3QD0WYbQ0>3Qi03P
h>80gmoP0=gMg@3Og]h0ZGAk0:0B7@2]1a00Z@<=0:H33@2S0@d0X08;09l2302M0@`0WP4<0:42302O
0Pd0W04;09h22P2L0@X00P2I0@P03`2K0@P0W0480:822@2X10d0Y@D@0:H74P2O10h0PP8708D32@21
0PT0M@8606T20`1L0P80H08204a>1`02003o00T0oooo00<0D91h0?n0003oP0007`3oP0000`3@D7P0
oh000?n000030?n000030>QX?03oP000oh0000D0oh0000<0d51h0?n0003oP0000`3oP0000`3@D7P0
oh000?n0000L0?n000030=1@N000o`000?l000P0oooo2000o`00C@15[a/0:R0[05Y?G@052S@06Qa4
06iGIP0j;Td0EdaX08aZN@2CJ7D0TVIb095WL02JL7T0WgIn09eeNP2PMWT0W7If0:23P02QRXD0WH^5
09^@RP2NU8l0WiNA09RAR`2FThl0UiRG09FGU02PXZ@0XJ:U0;Ff]`2[/;<0WZFY0;Rm`02h`L<0^<33
0;W1a@2ja<D0_l[?0;S4b`2h`LH0bmKM0<7>e`2P/l<0[lOD07NL_P1kWkl0]LgM0=;Pj03?g^/0b]_a
0:Bae01iJYT0M2]G08P>;P2@1A/0S0DK08<D:P2DIG00TYRO096NY@1jQX/0NhV:07Z9R@1gQXP0L862
07:3R00_A6X00A5N008>F0064dT0=DaM05M^K01HJfT0>DUE03QAF`1CFeT01?8200@00?l0203oool8
003o0003052@N03oP000j6Pl0080X23`00<0^3Rd0:0Pl02P8?000`2P8?00103@D7P0^3Rd0:0Pl03X
J3`<0?n000030;Ph]02P8?00^3Rd00H0X23`00H0d51h0;Ph]02P8?00X23`0=1@N02h>;@50:0Pl003
0=1@N02h>;@0X23`00<0X23`00D0d51h0?n0003oP000oh000;Ph]0030:0Pl080oh0000<0d51h0?n0
003@D7P0102P8?000`2h>;@0oh000?n000030?n0000302S8?000o`000?l000800?l02`3oool000X0
oooo05H0:=D805DG200c6aP04P4104D20`1>0@40C`4205L10P1J0@80G`4206@10`1S0@<0C`<405HX
;@1]=c`0JPL=08D32P2?0@X0TP4909811`2G0@T0X`<;0:T5302M10L0/@H@0;P43`2k1a80^`DA0;/7
4@2k2100^`TB0;d:502g3aP0GPX?09NGW@3RhnL0h>?W0>?Si`3RhNH0h^?V0=kCe@2fIfH0b6=P0<QW
HP36IV80aVQT0<I[IP2SJFL0WYZL0=gMh@3Oh><0g>3Q0=oOhP3Og^40b:fb08XL9`2/2A@0[@@=0:/6
3`2W0`h0X`8>0:02302N0`/0W@4<09d12`2M0@`0V@0909X12P2I0@T0V@8909P1202L0@/0X@8<0:<2
2`2W10l0XPH@09D3302J1@h0Q@8807`3201g0@H0LP8606X2101Q0`<0H`8304];1`800?l02@3oool0
0`1@T7P0oh000?n0000:0?n000030>QX?03oP000oh000180oh0000<0d51h0?n0003oP0000`3oP000
0`3XJ3`0oh000?n000050?n000030;Ph]03oP000oh0000<0oh0000<0j6Pl0?n0003oP000703oP000
0`3@D7P00?l0003o00080?ooo`P00?l004d0:ld@03@V:014?4l010Xh020NA01aEF80JU5P048eD025
I7<0SfAb09EXM02HK7L0VVih09eeO@2KLWP0W7=g09MaM02JOW/0VX=l09^:P`2KSXL0W9>?09nIU02F
T8`0V9BB09JGU@2GV9P0WZ6R0:6UY`2c^;T0YZf_0:2VZP2d^[d0][g00;c3a`2h`<<0_LO90;S3a`33
cM80`<[@0;[9d02hb=80/lSI07FH]`1IOZT0TKCA0<WLk02e`mh0Qh2_06i6N`219eD0UPdZ09d55@2J
1Q80S`@@0902302B0@d0RA0Q0:1mR@1oRXl0OHb@07Z:S01jR8`0N8N:07R6RP1eQ8X0@EIe00<GE`0T
>fX08SMH05UaL@1KLFX0FVi[02<fB016GV/0EFET017>2`04003o00P0oooo2000o`000`1@T7P0oh00
0>QX?0020:0Pl0030>QX?03@D7P0X23`00D0X23`00<0^3Rd0>QX?03oP0002P3oP0000`3@D7P0X23`
0:0Pl0050:0Pl0030;Ph]02P8?00oh000080d51h00<0^3Rd0:0Pl02P8?002@2P8?000`3XJ3`0oh00
0?n000040?n000040;Ph]02P8?00X23`0?n000<0^3Rd1@2P8?040?n000030:0Pl03oP000D91h00@0
0?l02`3oool000X0oooo0400:=H805TM3@0d7Q`07@4104d30`1;0000C`4205P10`1H0@80GP4305l1
0P1R0@80I0D807Tg@`25=T@0OP<>08/1302?0@X0T@0808h11P2G0P/0Y08;0:h3302a1@h0]`H?0;P2
3P2l1Q80^`LB0;T64@2h2140^PPB0;h;5P2j2aD0P@dC06iWKP3Oh^H0h^CX0>3SiP3Sh^L0i>?V0>CS
i@3Ugmh0imoM0>WPgP3YhN40i=kM0>OQh03Uh^40hn;S0>;Qh`3PhN@0gMoQ0=cNh03MgMl0elW<08hi
@02Y2QL0[@@<0:X53P2X0Ph0Y08>0:894`2K0P`0WP8=0P2L0@`0502M0Pd0V`4;09/12P2I0@X0VP49
09d22P2O0P/0XP4:0:H3302X2100TP@;08X530290PP0NP0507d22P1X0@@0G`0106@10`1V0P80DDl;
0P00o`090?ooo`03052@N03oP000oh0001l0oh0000<0d51h0?n0003oP0004@3oP0000`3@D7P0oh00
0?n0000L0?n000030=1@N000o`000?l000P0oooo2000o`00C@0Xf`l0@BdY038]A00X:T`0;bQ007AG
H01eEf00KE=R089OK@2@IW<0UFQe09QZMP2HK7H0WG=m09YaMP2GKG00UVe^09EiM02LQGl0WX^409Z<
Q`2JThl0WIND09F<RP2HTHh0SHb809:DTP2FVi`0X:>V0:b`/`2_/KH0Yjja0:ff^02la<L0_/C80<?9
c@2ma<P0b<oE0;O0aP35d]P0_LgH07BJ_@2V]ll0/[;709^H]@1kMIl0Q5Z508D`F`2=5CD0T`lU08lC
7P258BD0QCm307UDH@1L?U/0NAP^09<2402C0Ph0RB@c08b6R@22SY80OHbA07b:SP1iQhX0MhB90762
Q@1NLgh0DFMj06UnQ`0X?eH0Fg9h05ibK`1LL6l07C=1059[KP1HJfL07jhH00@00?l0203oool8003o
0005052@N03oP000j6Pl0:0Pl03@D7P00P3oP0000`3@D7P0X23`0:0Pl0040:0Pl0`0oh0000<0j6Pl
0:0Pl02P8?001P2P8?001@2h>;@0X23`0=1@N02P8?00d51h00P0X23`00<0d51h0?n0003oP0000P3o
P0000`3@D7P0^3Rd0>QX?0030?n000090>QX?02P8?00X23`0:0Pl02h>;@0X23`0=1@N02h>;@0X23`
0080^3Rd00<0d51h0?n0003oP0000`3oP0000`1XZ3`00?l0003o0002003o00/0oooo000:0?ooo`0a
02SF201M8Q@0:aLE01d10@1;0`80C04204d10P1E1@L0DP8205X20`1P0`H0H`4506@1101]2Q@0N@HC
08P23`2=0P`0T@8:09812P2?0@D0U`490:P3302a1@`0/0D=0;<73`2k2100_0LB0;T74@2e1Pl0]@LA
0;H8402g1a80_0/B0:<?6@1A=Ch0aLS?0>7TiP3Phn@0hN;U0>CSi@3Ti>D0hn?U0>CSi03Sh^@0h^;T
0>7Qh`3Rh^@0i>?U0>7Ri@020=kPi00S0=_Nh03Lg^00g]kP0=g=dP2B@4P0Z0`F0:d33@2Z0Pd0Z0<>
0:@23@2O10l0WP<?09d1302N0P/0W04<09/1302J0@/0V`8;09`12P2K0@X0W@8:09l2302S0Pd0Z@@=
0:T63P2Q1a00S@@;09432`280PT0MP8705l21`1P0PD0J08406T30P1D?PT00P00o`090?ooo`03052@
N03oP000oh0001l0oh0000<0j6Pl0:0Pl03oP0004@3oP0000`3@D7P0oh000?n0000L0?n000030=1@
N000o`000?l000P0oooo2000o`00C@0;m`@0CS8/028P>`1:A5P0@CE3075FG@1cEEh0NUYU089OK02?
IgD0TVIb09IXM02HK7H0W6mh09M^M@2CJFh0UFa]09QeLP2KPWd0VhF009j>R@2HShX0ViFA09NBSP2J
U940T8b909RGU02BUiL0X:FX0:JZ[`2[/[D0[KFh0:^c]P2na<T0_lC90<;6bP2na<P0`LO=0<oEf`2m
bLl0^lcE076D^`18Hi`0Peb008XeDP2=8CH0SB0`08HZ<@2<B4X0T6=U0::>S02g]kL0Wj^i05edSP1Z
Pj<0ARYE08H56@2C0@d0R@HB099/KP23S8h0OXb=07b;S01kRX`0MHJ70722PP1aPX<0L8:406ioPP0j
D600FW9g05mbL@1KL6`0D6IU04aSH@1JKVT0<I8[00@00?l0203oool8003o000402S8?03oP000d51h
0;Ph]0@0oh0000<0^3Rd0:0Pl02P8?000`2P8?0=0?n000030=1@N02P8?00X23`00P0X23`00<0d51h
0:0Pl02h>;@0102P8?000`3XJ3`0oh000?n000030?n000030>QX?02P8?00X23`0080X23`103oP000
103XJ3`0d51h0?n0003XJ3`50?n000030=1@N03XJ3`0oh0000@0oh0000<0Z8Pl003o0000o`000P00
o`0;0?ooo`002P3oool06P0Ze`X0HB<E02LB4@0S0@80B@8204`20P1?0P80G0lC04h110180P@0F18F
05852P1M0PD0LP4608L23P2>0@d0S`8>09012@2>0PT0T@4809X2202]10`0/`<=0:l3302_1@d0]PL@
0P2g1Q40>P2a0`d0/`H?0;053@2g2a80_0`C0;/>5P1n3AT0K3Y;0;FJZP3GbmD0f]7I0=gBfP3Pcm/0
gl_E0=c4c@3OaM80fl3?0=k2c`3K_lX0g/7=0=:jb03>^<@0b[K20=:obP3D`</0ekc80;ajR@2K5b@0
/0PA0:l43`2/0P/0Y`8:0:<33@2P0P`0W@4<09h23@2N0PX0W04;09`22`2K0@X0VP4;09X11`2J0@P0
W`<;0:812`2T0Pd0YP<=0:@43@2U1@l0X0D=08H21`200@H0MP8606011@1M0@<0G`8406H30`1U4@T2
003o00T0oooo00<0D91h0?n0003oP000803oP0000`3@D7P0^3Rd0=1@N0060=1@N0050;Ph]03@D7P0
d51h0=1@N02h>;@01@3@D7P00`2h>;@0oh000?n0000M0?n000800?l0203oool9003o001<064n;`0I
5c@0G4mN04TjB01ZDUP0KDiF07=AG01iEf40R5m[091SL02FJ7@0UVae09Y`M`2GK7@0UVab09adMP2J
NGP0WH9n09J2O@2KT8T0U8^509JAS02PWYT0X9fI09FDT02JWi`0T9BG09VPY02;TiX0TI^N0;No`P2g
_<40]kk20<C8cP39cmH0d=[P0;g7c033c]<0`/oF0:2fa`2S^/h0Q:?806^=]`21T:L0[:B]0;J_]02j
_Kl0b]?F0<_Ig@39f]l0b=SQ08^S^P2Q_M40HGbE038jJ@1f5S80T@4?09023029>Cl0QhV;07f9RP1m
Rh`0O8V=07>4QP1dPhL0M8:507F2Q01aP8@0L7n406EkO01OM7<0GW9^05a_KP0_ADT0D6IW04=e?P@0
0?l0203oool9003o0080j6Pl00<0d51h0>QX?03oP0000`3oP000103@D7P0X23`0:0Pl02P8?0=0?n0
00030=1@N02h>;@0X23`00H0X23`00<0^3Rd0=1@N02P8?000P2h>;@50:0Pl0030;Ph]03@D7P0d51h
0080oh0000<0j6Pl0;Ph]02P8?000`2P8?002P3@D7P0oh000?n0003oP000d51h0?n0003XJ3`0X23`
0?n0003@D7P20>QX?0030?n0002P8?00oh0000D0oh0000<0d51h003o0000o`000P00o`0;0?ooo`00
2P3oool0600Zf0T0IbdI01h;200Y0@40C@8304/00P1@0P<0D@<504X10P1U6Ah0X4aI09a8E@1C0@<0
N@8:08X23P2>0Pd0R`4<08X1202<00T0S`8909/21`2c1@l0]@D@0;D54@80]`H@03`0^0LA0;<43@2]
0PT0/PH=0;043@2g2A40^0T@0;d;4@2n41X0[Q@S09PG;`2XAEh0^V1f0;eJL02nCV@0]d5E0;HhCP2e
=4`0/Bi70;4^A02`;3l0[RXm0:PW?P2V9cl0Z2a20:L`A@2X<TP0Z2]20:/A8P2f2140]PD?0:l3302]
0`/0YP490:H2302S0@d0WP8=09`13@2K0@/0W04;09d22`2K0@X0V@4909X11`2L0@T0WP<;0:423@2S
0Pd0X`4=0:P6402X10l0Y0<<08h22@290`X0N04407@3201_0@H0H`8506020`1Z5a02003o00T0oooo
00<0D91h0?n0003oP0008P3oP0080:0Pl0P0oh0000<0d51h0?n0003oP0007P3oP002003o00P0oooo
2@00o`00C00lIQ/071`e05I;F@0G63P0<R]406U=EP1aC5T0NE=O08AHI02<H6X0T69]09AXL`2ILGT0
V6md09AXKP2KLW@0WG]m09b4O`2KQh00VH^40967P@2ARh@0Ui6=09bHU02EUY<0VYnN08>9R`24RX`0
QhjC09BLX02l_l<0^;k20;Nn`P34bll0^/;80;g8c@3Bfn80_l[B0;C4c`2lc]X0UKGC076F_`0lJIX0
b=o/0<gLj03@g>H0cm[S0<_Ki02gbmh0[<KM0<G=h01eNY`0GF^:0:^mb@1MLY<0DbU?08`4502B0@/0
Q0hG095nP01oRh`0O8b<07Z9S01jQh/0MXB807>1Q@1bP8<0LX640720P`1ZOh80HgMi05ebLP1IKW00
>U9I03MAFP1GG5H4003o00P0oooo2@00o`001@3@D7P0oh000>QX?02P8?00d51h00<0oh0000D0j6Pl
0?n0002P8?00X23`0;Ph]00<0?n000030=1@N03XJ3`0j6Pl00D0X23`00@0d51h0:0Pl02P8?00j6Pl
1P2P8?020;Ph]0030=1@N02P8?00^3Rd00L0X23`00<0^3Rd0?n0003oP0000`3oP0001`3XJ3`0X23`
0;Ph]02P8?00^3Rd0>QX?03@D7P00P3XJ3`60?n000@00?l02`3oool000X0oooo05H0:mT:06L^5P0K
1`D0=@<304d10@1<0@<0C04204P10P1D0@<0KP<807`43`1n0a00KP<907L22`290Pd0R`8=08/22`2<
0@X0R`4908l11`2P0PP0/`H<0;@43`2g1@l0^@D@0;T53`2f1`h0/`H<0;07302`1Ph0/@D?0;P94@2n
3aL0`@`C0<<=5P313QH0`A0I0<0B7`345b<0bAHQ0<hE8@3=5Al0cQDO0=4F7`3@51l0cQ<M0<dB6`3:
4QX0aA0I0<<<6@343AX0`@`H0;h;5P2n2QL0_PLD0;/4402f10h0[@<=0:P23@2V0`d0Y08<0:<1302O
0@`0W@8>09/23P2J0P`0W04909/1202H0PP0W0<:09/12@2M0P/0X@8<0:82302S0P`0Z@H?0:L43`2S
0`d0V@8:094220230PL0M@4507821@1Z0PD0H`8306XB30800?l02@3oool00`1@T7P0oh000?n0001C
0?n000800?l0203oool9003o001=04M/6P0/:3l0C49E0084;00P6cX0IdaD06m>E01eDEX0P5AP08YK
I`2<H6`0TVMb09A[MP2FK7H0UFM`09YcMP2NO7h0WXJ209j=Q`2IRXH0UH^70929Q02?RHD0SH^6096A
S@2>U9<0R8j@08>7R@2EVYd0YJf_0;_0``2l`<H0_LG80<79c03<eMX0`<WB0;g9d@36dMP0[L?G09bg
dP1JPJh0TkWI0;3>i@1mVL40N6JA09]GN02RI880]9B^0:VO`00e>6X0JBQ>07PC;@1c:Sd0X:>]07V=
Y00f=V80Na0V09@23@2D1100T5AH08>;R01lS8`0NXV<07V:R`1gR8/0MHB507:2P`1_PH80KX6106b1
P01WOG`0GGEc05U^KP1CJ6/0:4=;05eWI@0Ac0X00`00o`080?ooo`T00?l00`3@D7P20:0Pl0@0oh00
00H0j6Pl0:0Pl02h>;@0^3Rd0:0Pl03XJ3`;0?n000030;Ph]03XJ3`0X23`00<0X23`00@0^3Rd0=1@
N03@D7P0X23`0P2h>;@=0:0Pl0030=1@N03XJ3`0X23`0080X23`00<0j6Pl0?n0003oP0000`3oP000
0`2h>;@0oh000:0Pl00;0?n00004052@N000o`000?l0003o00/0oooo000:0?ooo`1F02[I2P1e@2<0
5@@303`30`1?0P80BP4204`20P160@<0I@<407L21@200@P0Q@4;07H32@1]0PT0Q@8>08P1302:0PX0
SP4:08l1202D0@P0YP@;0;83302e1@h0]PD?0;P5402f1100]@@?0;D5402_0`d0[P8>0;44302h21<0
_PhH0<<>5`333Q@0`0hC0;h>5P333aP0bQ4H0<P?5@3=4aT0d1<G0<lA503D4aP0eA8H0=8?5P3B41H0
d0hF0<l>5P3:2Q80b0TB0<@940322A00`@PA0;/53`2i1A00]0@>0:d33P2W0Pl0XP4?0:@3402V0Pd0
X@4=09/1302J0Pd0VP8<09/22P2I0@T0UP8:09@22@2E0@X0V`8<09h22P2R0Pd0X`8<0:<93`2T7Qd0
X1dP09L53@2G0@P0S@4807`21`1/0@@0IP4406T2101W2@@2003o00T0oooo00<0D91h0?n0003oP000
D`3oP002003o00P0oooo2@00o`00C@0cX180ASU603hcBP010bX07QPe06Q=DP1]CU@0M5=L07eEG`24
F6<0RUmY08eRK02EJG<0UfYc09EWL02OMW/0WW]n09b3P@2HQX<0WYFA0<k=c02JUiH0RhF208V4P@2@
S8X0V9RF08N6R029R8/0UIVL0::[[@2i`/<0_lC70<_Ae030alh0c=GJ0=;Kh@37dMT0[l3>0:^nd02T
a><0NI[201];Q@2M_]h0?dj308HH=02M2A`0U@dP07lL<P1_6cT0MB9308`Q>@2=1A<0PPHC0:9oR@2C
XJd0<T=Y06<XAP2@0a00U@8>08XP;02HPXH0OhV<07^;SP1gRH/0MhR907B3Q01bPX@0L8>506j2P`1`
Q8<0KX6006IlN@1NLW40F6][03EAE`1BJ6T08ilH00<00?l0203oool9003o00050830003@D7P0d51h
0:0Pl03@D7P01`3oP0020:0Pl0030=1@N03oP000oh0000@0oh0000D0j6Pl0?n0003oP000oh000>QX
?0020=1@N080X23`00@0d51h0;Ph]03XJ3`0X23`0P3@D7P00`2h>;@0X23`0:0Pl0050:0Pl0070=1@
N03oP000oh000>QX?03@D7P0^3Rd0=1@N0020?n000040;Ph]02P8?00X23`0=1@N0<0oh0000@0d51h
0;Ph]02P8?00j6Pl303oP0001020`0000?l0003o0000o`0;0?ooo`002P3oool0EP0[fPX0JcPI01`3
0@1;10@0DP8204/10P140P80>`4206D41@1h0@H0P08807/22P1P0PH0I`8908@23`270@l0S@8>0901
2@2C0@T0U0470:@22@2c1@h0]@D=0;@53@2g1Pl0]@@?0;D33`2b10h0[@8<0:h23@2b10l0]PLA0;T9
4`2o3QD0``dF0<4>5`2l31H0`Q0G0<D>503941D0ca8G0=8A5`3@41@0dQ0E0=<A5P3D41D0da0F0=8?
5`3?3AD0c0`B0<P:4@372a80a0T?0<48402l1Pl0^P@?0;T63P2`10/0Y@<=0:423@2P0P`0X@8<09h1
2P2L0@X0V`4;09`1302K0@d0U`4:09<12@2B0@P0U@4:09/22`2K0@X0W08:0:863P2V>CX0hkBc0;am
QP2N>400SA<H08D93`200@P0N04606h1101U0@80L1@?0P00o`090?ooo`03052@N03oP000oh0004T0
oh0000<0d51h0;Ph]03XJ3`01`3oP002003o00P0oooo2@00o`00C@17[QP0F494030X@0031BL08A/c
06M=D@1[Ce@0LeIL07QDG020EF40QeYW08YNJ02@IFh0UfUc09=UK02KLGH0X7en09j5PP2LRH@0YYjL
0=CEg02HUIP0R7mm08EnN`2<RXL0TI6@09BBTP29RH`0Ri2E09^TYP2i_/80`LO<0<C;cP3Fg>00bM;G
0;[9dP31bm@0b=OS0;oGj`0ZFHh0H8R^092`cP2T_ML0?DMk08/F;P2R3Qh0SA8M0:f6S@1WD6H0EbI6
07H<9`2?1QD0T@@B08DfA02o`lX0GVf804<[DP261AH0T`4<08H6502JIVh0Q8R;07^:S@1iR8X0MhR;
07F5R01ePhD0Lh:307>3Q01`Ph80KX:206f0P01RMGL0F6e_02@mAP1>IfP0;hlV00<00?l0203oool9
003o0004052@N03oP000d51h0:0Pl0D0oh0000D0d51h0:0Pl03oP000oh000=1@N0050?n000<0d51h
0`3oP0030=1@N0@0X23`0`3oP0090:0Pl0030=1@N03oP000oh0000<0X23`00@0d51h0?n0003oP000
d51h0`2P8?040?n000040:0Pl03@D7P0oh000=1@N0/0oh0000@0d51h003o0000o`000?l02`3oool0
00X0oooo05P0:mX:06Xe500N0P00B@8305010P180@80?@8202P10@1@0`<0J`<606h42P1K0@L0@P02
06P32P210@`0Q`4>08d13`2>0@X0TP0709L01`2W0`/0/`@>0;82302c1@d0]0D?0;@43P2d1Pd0[`<=
0:d3302^0Ph0/P@?0;@6402d1Pl0_0`C0<8>5`2n3QP0_@lI0;l>4`363Q<0c18E0=0B5@3D4AL0e14E
0=DB603B4AL0da@H0<hA603;51T0cA@H0</@5@362a<0a@XB0<<83P332A40_@H=0;/43`2j1@l0/0@<
0:L23P2P0@d0W00809/02P2K00P0W08:09/12@2M0Pd0VP4:09@11`2B0@P0T`4809L12P2L0P/0V`88
09/12P2O1Ph0[e]Q0=fkaP259SP0YDI@0=BIVP2ZHFD0N0H;07X11@1g0@@0K08306h?2`0/QP000?l0
2@3oool00`1@T7P0oh000?n000180?n000050=1@N02P8?00oh000?n0002P8?001P3oP0000`2P8?00
0?l00?ooo`070?ooo`T00?l004d09=P>07QLE`0N62d0;2Ll02/Q<P1YCU40K4iE071@F01iDed0PEAQ
08UII@2;GVT0TFI^09EXL@2DJ740Vg=h09mjN`2OQh80WH^809J9R02QV9`0Qgek08QoN@24OGT0RHR4
09:AS`2>T940Q8N<08R@U02TZjh0^[o30;o7bP38dM@0dM_M0<;<d02haL/0d^3Z09bbbP1^UkX0PZC6
08F^d@2cc=d0`]CW03=5O@259d<0X`hP08TA803Ca<X0c=KQ08nE[P179dh0OPdQ09434P235B80/JR^
07Z:V`0a<5T0O1DY09@2302=0a00P2Xb08^1Q01kRXd0MhN907>5R01aQ8@0MhF607B3Q@1dQHL0LXF4
06n2Q01_Ph<0HgQk05Y]KP1:H640CF9Q03N8;`03003o00P0oooo2@00o`00101@T7P0oh000?n0003X
J3`50?n000050>QX?03@D7P0oh000?n0003@D7P00P3XJ3`30?n000030>QX?03@D7P0oh0000@0oh00
00<0^3Rd0:0Pl02P8?000P2P8?001P2h>;@0oh000?n0003@D7P0X23`0;Ph]0L0X23`00@0d51h0?n0
003oP000^3Rd0`2P8?000`3XJ3`0oh000?n000030:0Pl0030>QX?03oP000oh000080oh0000<0X23`
0?n0002h>;@00`3oP0000`3XJ3`0oh000?n000050?n000040=1@N000o`000?l0003o00/0oooo000:
0?ooo`1702cJ2P1K8`<08@4104X20`1<0@80@`4103d20`0N0@40;P41048310140PT0=`450441101e
0`d0PP4=08L13P2<0Ph0SP4;09<12@2K0@T0Z`<<0;422`2e1@h0/P@>0;032`2c10`0]0D<0;443P2_
0Pd0[@8=0;043P2a10h0/PH@0;P=5@2j2a@0^0/D0;P=5@2m3A@0a0hE0<T@5@3A4AL0da<H0<hD5`35
5Q/0/AXN0:DX:P2`BTX0cG=_0<UWH@31BDP0]R4T0<<>50342A00`@L?0;h53P2k10l0]`<>0;443@2V
0P`0XP4<0:012P2J0@X0V`4:09`22@2K0PT0W08:09T12@2E0@T0U@4809L1202H0PT00P2I0@T03`2N
0@X0X0D=0;1JH03L];d0R1XW09T_=`3M/KT0QDmG09MBE01]4A@0M@@707410`1Z2@D0;hL1003o0009
0?ooo`03052@N03oP000oh0004P0oh0000H0d51h0:0Pl03oP000oh000:0Pl03XJ3`50?n000030:0P
l000o`00oooo00L0oooo2@00o`00C@0Pi@`0MeU:010;701?@TP0>bXd06a?E01]D5D0KDiF07E@F`1o
EF00PeEQ08QIIP2?Hfd0TfM]09I[LP2JLGH0WWQi09j2O`2NRXT0UHF208j0N`29OGD0Qgef08MmNP27
P800T8n=08R9S027R8l0S9:F09^RY@32b/d0`<K:0<C=dP39d]P0cmgQ0;[:d@2H[l40_M3N08nde01a
V/P08dn90;;=h03AgnX0DFZJ06e2J02J3Al0T@XM0:f0S@3?f^00c=[T05YZT01V:e00T@@F08l55P2?
HFT0^lO?03i:K@1P;Dd0R`<@09<130251Q00SemT07^7RP1gQh/0M8J:07:5R@1`PXH0KX:406n2Q01^
PH<0LhB70726Q@1[OX40HWAe05]`K`1KKV`0CUi600<00?l0203oool9003o0003052@N03XJ3`0oh00
00L0oh000P3@D7P60?n000030>QX?03oP000oh0000D0oh0000T0^3Rd0:0Pl02P8?00X23`0=1@N02h
>;@0d51h0;Ph]03XJ3`01`2P8?000`3@D7P0X23`0;Ph]0020?n000050;Ph]03@D7P0X23`0:0Pl02h
>;@00P3oP0020=1@N0030:0Pl02h>;@0oh0000<0oh0000@0d51h0:0Pl03@D7P0^3Rd0P3XJ3`20?n0
00030>QX?03oP000oh0000<0oh0000@0j6Pl003o0000o`000?l02`3oool000X0oooo04L0;M`;05XW
1`0U0@40C`<204h10P180@80B08302X20P1:<S@0^JJY030@5`0i0@H0H`<;07`230200@`0Q00;08/2
2`2<0@T0TP4:09T02@2^0``0]0<;0;H6402f1a40/P@=0;D53P2f1@h0/`<>0;423@2_0`h0[@<>0;87
4@2e2Q80]P/D0;L:4`2i31@0_0`F0<8?6P394A`0bA<I0<4F702T7B00USPi0:ieMP3@][H0hmWH0>?P
hP3Thn@0iN;Q0>CKfP3J^KP0/dM:0;LA6@2o2A80_PL@0;`54@2g0Ph0/@8=0:P23@2R0@/0WP4:09P1
2P2H0@/0VP4;09X12P2N0P`0W@4:09/12P2H0@P0U@4709D1200209H1200?09T22`2P0`l0XcM20>Zh
`@2=8Rh0T1HP0>:W/01f?dT0^YfQ07eMG`2PJVd0KQ0D06h=2P0^Q`400?l000T0oooo00<0D91h0?n0
003oP0001P3oP0000`3@D7P0oh000?n0000P0?n000030>QX?03oP000oh0000@0oh0000<0j6Pl0?n0
003oP0005@3oP0002@3XJ3`0X23`0?n0003oP000X23`0?n0002P8?00oh000>QX?0020?n000030:0P
l000o`00oooo00L0oooo2P00o`00C@1fET405`lK05A3A@19<cX0K4eB06e=E01aCUH0MU9K07eGH@21
F6<0PeQS08aRJP2AIg00TFQ]09Q_LP2ON7/0UWQf09b7P`2IQh<0TXEo08Z0N@29OWT0RH1l08EoO@2>
S8`0R8V<08Z?T`2@UiX0X:^]0:fg_032b/h0bm;H0<G?eP2jc=<0bmgS0;W;g01cUkh0LYBj07fYe@2X
`mL0d^3X0=?Oj02R]m80A4ao08/K<@2M2AX0Pb0`0=71bP3?f>00[;_B03/aIP2432H0U08C08@R<@2L
W:<0NXZO03XbF@1l2a`0T`4;09433028;cH0R8R907b8S@1gR8/0M8N:07:5R@1_PhH0LXB506n1Q@1a
PhP0KXB40764Q@1WNW`0I7Mf06AhM`1JHEd01?8200800?l0203oool:003o00030=1@N03oP000oh00
00L0oh0000<0j6Pl0?n0003oP0002`3oP0000`3XJ3`0d51h0:0Pl0030:0Pl080d51h0P2h>;@00`3o
P000X23`0:0Pl0030:0Pl0050=1@N02h>;@0X23`0:0Pl03XJ3`00P3oP0040:0Pl0030>QX?03oP000
oh0000<0X23`103oP0002@3XJ3`0X23`0=1@N02h>;@0X23`0=1@N03oP000d51h0:0Pl0060?n00003
02S8?000o`000?l000/0oooo000:0?ooo`1H02cL301A80<0:04105420P1:0@40B00104`10P1=3100
:@PA03lU=`1<5R40H`D<07D22P1n0@/0O`4:08@02`2:0@`0S@4:09812`2I00X0/0@?0;<33P2f2140
/PD=0;843@2e1Pd0/P@<0;833@2^0P/0[@<;0:/22P2`1Pl0]PXB0;P<4`2h31D0_Q0J0<<@6@3441X0
`10I0;8J7P23:BP0_inK0>7Ie@3Thn80i>CU0>;SiP3Ri>H0hN?V0>?SiP3PhN<0gmkO0=>d/`2H:bl0
^0dE0;l64@2j0P`0]P8=0;823`2Y0Pd0X`8:09d22`2G0@/0U00909X0302L0@`0V`4:09P1202I0@X0
UP4709@1202F0@X0U04909D12@2G0@`0X@<>09LA703TWjP0Vca808l:5P2fHfl0RU=L0;NPYP2iYZ`0
XXR?09AFG@1[3PX0;XH0003o00T0oooo00<0D91h0?n0003oP000B@3oP0001@2P8?00d51h0?n0002P
8?00oh000080X23`0P3@D7P00`3oP000X23`003o00080?ooo`X00?l004d0CVLX02HL8`1<=cL0Fcm2
06a;CP1]CE80LE1G07ADG01iEE`0OUQQ07=?FP25FfH0SfA^08iSJP2DK6h0VGEg09MhNP2LQX@0V8N5
09R<QP2@Qh80SXF008J1N`25PX80QhJ408N:S`28TIL0TIRK0:Fb]02a^kl0^/?90;_2b@3DgN<0Z[g;
07FBZP2eb]`0QZG808N]e00RDhh0Qj_90=;Pj@3CgnP0d=o[041LRP21AV@0V@dM09@=7@2@@580eLcG
0<[HiP1=GX/0KbU=09H3502;1Q@0Ug9l09FT/@0a@6L0LBU409@3402G0@d0Q`XC091gNP1lRH/0MXR:
0723Q01bPhH0LH>606j1PP1_PX<0L8B706n4Q01`QH<0Igml06=hMP1XP7h0IWEa00o<2@02003o00P0
oooo2P00o`000`3@D7P0oh000?n000090?n000030>QX?03oP000oh0000X0oh0000P0^3Rd0:0Pl02P
8?00^3Rd0:0Pl02h>;@0X23`0?n000L0X23`0P3@D7P20:0Pl0040;Ph]03oP000oh000=1@N0<0X23`
00@0^3Rd0?n0003oP000d51h0P2P8?000`3@D7P0oh000?n000020?n000060;Ph]03oP000oh000?n0
003@D7P0oh000P3XJ3`60?n00003052@N000o`000?l000/0oooo000:0?ooo`1H02gM3@1K:``0;`42
05D20`1;0@40B@4204h10P1N2A00KbPe070[?01d4R00L`4:07L1201m0@/0O`4908H1302<0Ph0T04:
09<12`2K0@/0/@D?0;@43P2d1Pl0]0L@0;<43P2d1Pl0]PP@0;863@2/0PX0[0<;0:/32`2b1a40]0TB
0;@:4@2j3QD0^Q<I0;@H6P2O92D0W4E10:amMP3Fal80i>?R0>?Sh`3Si>H0i>?X0>GUj@3RhnH0h^CV
0>?TiP3PhN@0h>3R0>7Lg031TY@0Ya`U0;h74@2l10d0^0<>0;42302Z0``0YP8<0:023@2L0@/0V`4=
09`13@2M0@d0V@4:09L11`2K0PT0UP8709411P2D0PT0T`4:09<12@2E0@X0X08=09h74P2J:CD0^F5[
0:Q7C@1f5b80XE9P0:9hQ02XRI<0Ug5i06lY<P1V1P@0<HL2003o00T0oooo00<0D91h0?n0003oP000
1P3oP0000`3XJ3`0oh000?n0000X0?n000030=1@N03oP000oh0001H0oh0000<0d51h0>QX?03oP000
0P2h>;@01P2P8?00d51h0?n0003oP000X23`003o00P0oooo2P00o`00C@1<MBD0=BLX04<`;P1QBd`0
IdY=06]<D@1_CeH0Me1N07UAG@1jDel0L4iJ089HH`2?HFX0SemW09=XJ`2LMgL0UGUh09N3P02EQH00
Uhj809J=R02>Ph00SHN408j7R022PH<0Gfmo07f:U@2^]kX0UInV0:fg_@2la/P0a]3F0;?3bP34e=`0
/<KH09:bd01YS;D0EX:f09Zid`3:h>P0e>3X0=?Pj03AgnH0SZ?004i;N@233R@0V0PH08X;7@2`PXh0
bmKP09jac011=6<0P`TN09423P23<Cd0[;Bk07:4WP1:<UP0Q`LJ09<1402=0`h0RdaC07f7RP1gRX/0
M8N807F7R01cQ8L0LHF50764Q@1^PHD0Kh>406n4P`1YOgh0HgYh06R0OP1`PX007j`G00800?l0203o
ool:003o00030=1@N03oP000oh0001@0oh000P3XJ3`20:0Pl0070;Ph]02P8?00^3Rd0=1@N02h>;@0
X23`0=1@N0050:0Pl0040>QX?03oP000j6Pl0=1@N080X23`00@0j6Pl0?n0003oP000^3Rd0`2P8?02
0?n000040>QX?02P8?00X23`0:0Pl0<0oh0000<0j6Pl0=1@N03XJ3`00P3oP000103XJ3`0oh000?n0
003XJ3`50?n000040>QX?01XZ3`00?l0003o00/0oooo000:0?ooo`1H02kN3`1B7`L0>@8105@20`19
0@40B`4205410P1N0P<0HP4506X1201i0PT0MP0707H12@1j0PP0O@4908H13@2>0P`0U04;09X1302N
0@T0/0D>0;@43P2a0``0/0<<0;43302e1A00]@L@0:h42`2Q0`/0UQ8E09`R8@2R6a`0XA/K09hS8P2Q
?CT0Zf1H0;^DRP3JclX0h^;N0>;Th`3Ri>H0hN7U0>7Kh@3Qe=`0h<?@0<fU/`2?NXT0d=KJ0>3TiP3P
hnH0h>7U0=oPh`3OdmH0Z4iE0;X94`2l1@h0^@<>0:l2302W0@`0YP4?0:41302M0PT0W04;09`12@2N
0P/0W@4;09`12P2K0PX0V@8:09H11`2E0@T0T`490982202D0@T0W@4<0:833@2Q2180VA0N0:DeA@27
2aP0R0@B094kAP2BIg00W6eg07Ti?`1[30X0?fX4003o00T0oooo00<0D91h0?n0003oP0009P3oP000
0`3XJ3`0d51h0=1@N0020:0Pl0030=1@N03XJ3`0oh0000<0oh0000<0d51h0>QX?03oP0005`3oP000
103@D7P0oh000?n0003XJ3`20=1@N080oh0000<0X23`003o003oool01`3oool:003o001=03JA4P17
<R/0Echh04Hb>@1>=Sl0JTeB06i?E@1bD5X0N5AN099^M`21FF@0PeMQ08iRJ`2?Hfd0TV]a09]hN`2J
Ng`0TGQf09B4O02KU8`0Ui2=08V0OP2;QX<0RXF407=kQ`1DJH40TIZP09jVZ@2RZJd0`/cB0:Rb^@33
dMD0]LSC09jgb@2bb]d0I8V_0:K<k@17L:T0EGb[0=3QjP3BgnL0dmoW0=;NiP3;g>T0<dYj07D`CP2@
11@0V0LD090Y>@3DcML0YK;504]@NP1j9Sl0T@8?080:5P2;MWd0YK?003DnIP1g6S80S`4?08l2301n
6bD0Qh>507R:SP1gRX`0MXR907F7RP1bQ8L0L8:40724Q@1bPX<0K7n006QmO@1ZO7d0Ig]m07J6R@0_
WBT00P00o`080?ooo`X00?l000<0Z8Pl0?n0003oP0001P3oP0001@3@D7P0oh000?n0003XJ3`0d51h
00X0oh0000P0^3Rd0:0Pl02P8?00X23`0;Ph]03@D7P0X23`0=1@N0L0X23`00L0d51h0?n0003@D7P0
d51h0;Ph]02P8?00d51h0080oh0000D0j6Pl0:0Pl02P8?00X23`0=1@N0020?n00080^3Rd00<0X23`
0>QX?03oP0000`3oP0001@2h>;@0d51h0>QX?03XJ3`0d51h00L0oh0000@0d51h0:R8?000o`000?l0
2`3oool000X0oooo00@0;n0@04dL1`0f0@40D`410P1>0@404@1@0040FP4105l00@1Z0@H0N04:07@0
1`1i0@X0NP4807X02@250@`0S`4<09T12`2M0@T0WP8:0:X22P2b10`0[`4:0080/@<=02X0/P8<0;<4
3P2Z0PX0V0D:05D<3@2`UYH0ekB]0=NbZP3QaKd0j=cF0>GPgP3Thn40h>CU0>7Tj03Ph>H0f<oH0>2n
c@3GTZD0`eaa0;H^A02e7Rl0La8O09fLX@3QiNH0h>3T0=oOhP3NhN80gn7P0;EnP`2a3AL0^0<<0;L4
3P2`0Ph0Z`8A0:H13@2R0@/0W04809/1202J0@P0W04909h2302K00X209P12@0C09L1202F0@X0U048
09L21`2J00P0WP4<0:44402L10d0U`@>09033`2B0@`0T04:09Pf?`2XJgP0N2ln09=IH01V3@/0HA87
003o00090?ooo`03052@N03oP000oh0002D0oh00102P8?000`3@D7P0oh000?n000060?n000030=1@
N03oP000oh0001T0oh0000<0d51h0:0Pl03oP0000`3oP0000`00o`00oooo0?ooo`060?ooo`X00?l0
04d0=j0=05Pk;P1[CT40BS@g04hk@@1[CU<0KDiD071>EP2<NX40bL36091aP@26EfT0RV1[08iTKP2A
Jg<0VgEl08m/L02>LW00UH=o09R<R02ES8X0RhF108Z5P@2;R8T0?De[06ioT02SZjl0Y:fb0;2i`02S
[[H0bMCL09RW/`2ea]00Wk_?0;3?i@20X<406dZ707NLa02>[//0d^7X0=7OiP3CgnL0d]kU0<kMi@20
U[<0@cYU07/<8@2E1aD0S`HG09PlD`2;?5d0RC1@08dH;02A1Q40Q`PD09A]MP2DXJ`0DF>205lcE025
1AH0T@4=08D43`2<I6L0O8^=07Z<SP1gR8d0N8N=07J4Q`1cQ8H0Kh:306j2P`1]PX40Jgim06UmO@1Y
OH00MhZ<03n2?@02003o00P0oooo2P00o`000`1XZ3`0oh000?n000050?n000050=1@N02P8?00X23`
0:0Pl03@D7P00P3XJ3`00`2h>;@0oh000?n000050?n000080>QX?02P8?00X23`0;Ph]02P8?00^3Rd
0:0Pl03@D7P80:0Pl0050=1@N03oP000d51h0?n0003@D7P00P2P8?030?n000040=1@N02P8?00^3Rd
0>QX?080oh0000@0d51h0:0Pl02P8?00^3Rd103oP0001P3XJ3`0d51h0:0Pl02P8?00d51h0>QX?0H0
oh000P3@D7P2003o00/0oooo000:0?ooo`1602CX301?6`H0?08105L20P1A0@40C04305410P1M0P40
IP8406h21P1f0@L0M@4807L02P1m0P/0O`4808X22`2E0`d0V`4;0:012`2N0@X0Y`<:0:l3302_0@/0
/08=0;032`2/0PH0[`<:0:d32`2V0`/0P0D<068/>P2UTZ40bKo90=?<d`3HeMT0gMKM0=W?e`3Ka=00
eZbl0<f:WP37Fg00`Bi30<HJ;@3=4b<0c@dH0<l?5@2T4AL0L5iR0>3SiP3PhND0h>7T0=gQhP3LhN40
aJJZ0:LB7@2h1Ph0]@@<0;423@2[0P`0Y@4:0:<23P2M0@/0V`4809`12@2M0@`0WP8:09`12P2J0PX0
V08909P12P80U@490100U`4809T1202M0@`0WP8=09D22`2;0`/0OP4908H22P280PT0P0`F09HW=P1k
1A80QR`e06H81`1S4PL00?l02@3oool00`1@T7P0oh000?n0000K0?n000030>QX?02h>;@0d51h00D0
d51h0P2P8?020=1@N0D0oh0000<0d51h0?n0003oP0000`3oP0000`3XJ3`0oh000?n0000O0?n00003
003o003oool0oooo00H0oooo2P00o`00C@0Hb`<0HD0a06a<?`19<C<0;R@_06Q=D01ZBDh0KTaD07]P
K02PR9P0PE]^08MHIP29GVl0R65/08eXK`2HLGH0TF]]09=hMP2FQ8D0VXj=09F;Q`2?Qh00RhR307^3
T`0]B6h0W:J^09VQZ@2V[[L0_<K>09ZX/`2U];d0Z;S10:c2d@1TPZ@09e:509^oh@1[T[l0AWJ^0:71
eP3ChNP0eN3X0=;Pj03Bg^H0dMkV0<gJi@1hRZD0JE=W08E7C`28@DL0S4Y@095GH@1mCUd0TFAX08UR
IP2@KW80XJ:Y09^X/P2P/<@0?SUP074B;02>0a80SP8<08<b>P21R8T0O8^>07R9S@1iRY00N8V<07>6
RP1`Q8D0KhB50762Q@1`P840K82006YoOP1`Q8D0EEQC00800?l0203oool:003o0003052@N03oP000
oh0000D0oh0000H0j6Pl0:0Pl02P8?00^3Rd0:0Pl03@D7P90?n000030;Ph]02P8?00X23`0080X23`
00@0^3Rd0:0Pl02h>;@0^3Rd1`2P8?000`3XJ3`0oh000>QX?0020?n00080X23`00D0^3Rd0?n0003o
P000oh000>QX?0040=1@N0040;Ph]02P8?00X23`0:0Pl0@0oh0000H0j6Pl0;Ph]02h>;@0X23`0;Ph
]03@D7P80?n000800?l02`3oool000X0oooo05P03?P404hI1@150P80G@8305H10@1?0@80E0820642
0`1U0@<0J`4407T11P1i0@L0N`8907l22`250@X0S@8<09D12`2M0P/0WP8:09T12@2R0PX0[`8<0:l4
302_0`/0[08;0:/22@2/0`L0[08:0:X22@2]0``0Y@PB09@;702F6bh0W2Lm0;U6G031AU`0`SiC0;dR
=0325RH0ba<R0=4C703C4AT0da4G0=8>5P3?3140d@h@0<@B5`1I82H0e=OK0>3SiP3PhND0g^3S0=cN
h@3HcM00WBTc0;<4402f0`h0/@8<0:X12@2U0@T0X08<09d12`2K0PT0W04:09d12`2O0P`0WP8=09P2
2@2F0@T0V08;09<12@2C0PT0U@4809L1202I0@P0W`4=09X23@2;0`X0O@8808032`1a0PH0H`8507d2
2@240`X0M@8406T20@1Q2`<00?l02@3oool00`0Xb3`0oh000?n0000N0?n000@0d51h00<0j6Pl0?n0
003oP000203oP0000`3@D7P0oh000?n000020?n000030=1@N03oP000oh0001l0oh0000<00?l00?oo
o`3oool01P3oool:003o001502KG2`1O?BH0K4`m06M8A@0f9c40ITa>06M7C01ZAU40L4MC07]@G@1o
Del0P5IT06a@G`1PCUX0PfE/09Q_M@2DKFl0TgIf08mmO02IS8T0Uhn:09F=R`2BSi<0>e5k05YcT`2N
YZT0WJBY0;>oa`2;Uj40`/oF0:6b_02__//0O9N^0;SAj01nVkl0>fFQ06:>_`13Lj/0an7`0=;Pj03A
h>L0dMoV0=;Oi`3@g^D0dMcU0<[KhP38f]l0cMOK0<gEe`3:emX0aM?K05UdT`22Vk@0G7><0;C8e@27
VZT0V:Ve09:R[P1@GX40IC]P08H87@2C0@d0P@dF08elO`1mSY40Nhj?07R:RP1iS8h0LhJ90080MHN9
00P0LXF606j2PP1/PX40L8J707B7RP1RIfD02>D4003o00P0oooo2P00o`000`1@T7P0oh000?n00008
0?n00080d51h0P3oP0000`3XJ3`0oh000?n000040?n000040=1@N02P8?00X23`0;Ph]0<0X23`00<0
d51h0:0Pl02P8?001`2P8?001`3XJ3`0oh000?n0003XJ3`0d51h0;Ph]03@D7P0103oP0000`3@D7P0
X23`0:0Pl0070:0Pl0@0oh0000<0^3Rd0=1@N03XJ3`00P2h>;@20>QX?0<0oh0000D0j6Pl0=1@N03o
P000:<Pl003o000;0?ooo`002P3oool07000o`00CaT40544101S0P80F04105D10P1A0@40G`4406D1
0`1Y0@@0N@8807P11`1k0@T0Q04<08L1302@0Q00UP4>09X22P2J0@X0T`0909/22`2Z0PX0[`D;0:l5
302[0`T0Y`470:P1202Y0@T20:P22@0j0:`42`2f2a80^@lF0;`B6@315Qd0`APL0<8G6P3;5AT0c18I
0;lC5P2o:BP0`Rla0<@c=@37=cH0c34a0<XD6@3<3A@0L0/?0:ZY[@3QhND0h=oT0=oNh`3LgN80gM_N
0:1DG02/2aH0]0@>0;423@2[0@`0Y`8;0:413@2M0P/0W08909/1202J0@X0T`<<08422@2<61h0Q0D;
09822P2D0@L0T`490981202D0@L0V@4809d2302M0P/0V`<<08l430260`T0P08706`21@1X0PH0JP84
06/10P1V0P40H`d5003o00T0oooo00<00?l00?n0003oP000;@3oP0000`3XJ3`0oh000?n000030?n0
00030=1@N03oP000oh0001h0oh0000<00?l00?ooo`3oool01P3oool;003o000V06Ho7@1_Cch0HT4k
03hV:`1XBD/0JdM<06]3C@1aBE@0NDiK07eCG`1ZCET0MUaX06]KIP1XEV<0SfQb08YVK`24K7<0UHF4
09J<Q`2ESXT0Ui:>08F<W00?;VP0UZRh0:fd]`2S[K@0Xjng0;K2bP2O[[T0YK>m0;?3d@27W[h0?V^J
0;7Hm01US[T0K9c>05>0ZP3;hN`20=?Qj00V0=?Oi`3BgnL0cmoV0<SLj`3>f^D0d]OS0=7@gP3=b]/0
b<;E0<Bgc@1cIHl0JEZ209Z0V`2ALh/0VGbD0;:@Z@2HM8d0PV1o06hlGP2;4bX0U`8?08l3402BD5T0
S8V>08F;T@20SXl0OHnA07F8R`1gRh/0MXZ;07:7R@1]Q8@0JX:206f0P`1fR8/0IG=b01G23P00o`08
0?ooo`/00?l000<0j6Pl0?n0003oP000203oP0001P2h>;@0j6Pl0=1@N03@D7P0oh000>QX?0@0oh00
0`2P8?001P2h>;@0X23`0:0Pl03@D7P0X23`0;Ph]0L0X23`00@0d51h0?n0003oP000j6Pl0P3@D7P@
0:0Pl0040>QX?03oP000oh000>QX?080X23`00<0j6Pl0;Ph]03@D7P01@3oP0001@3XJ3`0d51h0?n0
001@T7P00?l000/0oooo000:0?ooo`1H003o001B5P@0G`@406810@1J0@00F04005H00P1Q0PD0IP84
06/0101o0@T0QP4:08@12P250PX0R04909013@2I0Ph0V`8;09@12@2A0@T0U@4;0:H22P2^1`X0[`@;
0:X12@2V00H0YP450:H11`2W0@T0ZP<:0:d4302f3AD0[aDJ09/L702cEE00_VmX0;MPG02]<S80/AhQ
07@<303F/:X0h<6l0>?3`@3Val80j:f/0:hP:@3<3aT0U@lE07icN03Ng^<0gmoS0=kOh`3Lh><0fmkP
0:amP`2P4Q/0/P<>0;813@2^0@/0Z@4:0:813@2M0@X0W@4909/12@2F0PX0O@8607H1202F7BP0SQ/Q
08h32`2E0PP0U04809401P2C0@P0U`4909d2302L0@X0VPD=09L53P2H0`/0P@8607X31`1b0@D0I@43
05`10P1U0P80IA07003o00T0oooo00<00?l00?n0003oP000:@3oP0001@3@D7P0oh000?n0003oP000
d51h00D0oh0000<0d51h0?n0003oP0007P3oP0000`00o`00oooo0?ooo`060?ooo`/00?l004h0IEdJ
06m>?01/Bcd0JDDm06Y9A01XAdT0JdE=075;E01jDE`0NeAN05e8D`1bGVT0He]U05mCGP2:IVl0RFU`
08I^M02EP8<0UhZ809N?RP2CTI40AUV102m?Q02U/;L0ZJnc0<C=d`2JYZl0]L780:Rf`@2__/X0J8>J
0<3Gk@1aV<<0EXJj06NC``0LDY/0[mC_0=;Qj@3EhNT0eN3X0=?Oi@3BgnD0bmcX03mQTP20J8l0TSIG
08hUA@2<7CX0QaDb08PB;`263BT0Q`/R08/:8@2:2B00RPTR08/98@2<2Al0R`TL08d96P2C1QL0T@@@
09043`2:2AL0R1X/08@X>P25GfH0OXf?07R<S`1hRhd0MXZ=07F:S01_Q8D0LHB40764QP1bQhT0Kh21
02FR7P00o`080?ooo`/00?l000<0d51h0?n0003oP000203oP0000`3@D7P0oh000>QX?0020>QX?005
0?n0003XJ3`0oh000?n0003@D7P0102P8?000`3@D7P0X23`0;Ph]0090:0Pl0030?n0003@D7P0j6Pl
0080oh0000@0d51h0:0Pl02P8?00X23`1@3@D7P30?n00080j6Pl2P3oP0001@2P8?00d51h0=1@N02h
>;@0j6Pl00<0oh0000@0j6Pl0?n00020`0000?l02`3oool000X0oooo05P00?l005@D0`1R1080H`82
05/20P1C0@00F@420682101V0@<0L04508822@290@d0Q@4<08412@2;0Pd0S`4:09T3302J0@X0U048
09411`2B0@P0Y@<80:X51P2]1P/0[0<:0:T1202W0@P0ZP890:`12P2/10`0/PL@09D<5@1K61T0ZHV4
0=cAc03Of]D0gmGB0=g5`@3>YYl0OV=P0:FXZ@3Ph^40hN;Q0>?Rh@3We=H0/4iG0<DD7@2b4QX0HDA9
0=OKg`3Oh><0g]oR0=kPi03Kg^00_Z>Y08hH902a1a80/@8=0:`22P2W0@T0XP4=09d12`2K00P0V`49
08l32`1c0`L0SP<<09@23@2610X0QP<809<22@2E0PP0U@4809H12P2F0@P0W04:09`12@2?0PP0Q088
09H53P1_0P@0LP<508831`1a0PD0E`4006430@1S3`H02n402@3oool00`00o`00oh000?n0000Y0?n0
00050>QX?03oP000oh000?n0003XJ3`01@3oP0000`3@D7P0oh000?n0000N0?n0000302S8?03oool0
oooo00H0oooo2`00o`00CP1ONAH0M4lo06e<?01[Ac`0IdI206I8B01XB4`0KT]C07A?E`1gDEd0E4=A
05A@G@1@CeX0Le]W08]SJ`22HVP0QVia09EnP`2HRHT0VI:@0867U`0?:FT0G7:J0:na]P2na<`0VZB^
0<G@f02S/K/0ZKS20:Fg`P2/`Ll0K8b/07ZMb00XF9X0MJCE06:=``1ZU<40d^;[0=?Qj@3ChNL0d^3W
0=;OiP3?gnT0Khbb05UIO`27>TH0TT160958C@2BEE`0UfAZ09Q/LP2LN7h0PF=d09YjP@25Ifd0QfIZ
08m^L@2@K700WGMi099YK@27GF40REMK08E:B`24?3h0Q30f07I0A@21S8d0O8nA07J:S01cQXT0MXV<
06j2QP1_Ph@0LhR907>9S01fS8l0>HTe003o00P0oooo2`00o`000`2h>;@0oh000?n0000:0?n00007
0=1@N03oP000oh000?n0003@D7P0oh000>QX?0040:0Pl0030;Ph]02P8?00X23`0080X23`0P2h>;@6
0:0Pl0030;Ph]03oP000oh000080oh0000<0d51h0:0Pl02P8?000`3oP0070=1@N0<0j6Pl00@0d51h
0>QX?03oP000j6Pl103oP0001P3XJ3`0d51h0>QX?03@D7P0X23`0=1@N080oh000P2h>;@00`3@D7P0
0?l00?ooo`0:0?ooo`002P3oool07000o`00E1<106D40`1R0@40E`4105@10P1I0@80G`4106/20`1d
0@@0PP8708T12P260P/0Q@4;08l13@2E0Pd0V`<=09P2202D00H0S`4808h11P2M0`L0X`460:P22@2[
0PT0[04:0:/22@2/0PX20:`32P0j0;0;4`1B1``0ShZ=0=gNg@3PhN<0hN;T0>7Qh`3Iemd0fmON0>3R
i03BemL0g^?S0=kTh`3Ohn@0h]oP0=>QY`2a7bH0`Q8G050B6@2a]K`0fmoS0=kOhP3Mg^80fmgP0=35
a`2=?dP0Y0/H0;03402Z0@X0Y`890:@1302Q0@d0WP4;09/12P2910`0G`<508P43@2C0P/0PP8707@1
102@0PP0U@48090220250PL0S`<809/12`2M0@`0W08<08/32@2:0`T0O@@:06L110271@`0N`<506X3
0`1O0@40IaH?01G20@T0oooo00<00?l00?n0003oP0007@3oP0000`3@D7P0oh000?n000020?n00080
d51h00<0j6Pl0?n0003oP0000`3oP0001@2P8?00oh000?n0003oP000X23`00@0oh0000<0d51h0?n0
003oP0007P3oP0000`1@T7P0oooo0?ooo`060?ooo`/00?l004h0?J@<079??01^C3l0KD/o06M6?`1T
ATH0I4M:06a9DP1cBeH0N4mM06e?G01GBE@0LV5[08i^N@2?JG80T6e_09AfM`2EP7l0UHV609FDV`0^
?Vd01R=^08BDZ`2`][X0^;k30;:l``2S[kT0Y[Bn0<?Af`26W:`0Zl;C072A/P2F^]/0Nj;=0115T@1[
Vl/0X[kE0=;Rj@3Dh^P0e=oU0=CPj@3BhNH0d^7W0<?Fh`2/`/l0`lc@0<G>d@39e=T0b]WM0<cJh02Z
_=40HHFa049TT02H//D0UJZb0;?5b`2R/kd0XkBm09j^]P2P[K@0Wjfb08nNX`2=VYh0S9RJ08RAU@22
S8h0NHb>07V=T01gS8l0MHR=07>9S01`Q8P0JGeo0765Q`1dRHd0MH^?04mQCP00o`080?ooo`/00?l0
00<0D91h0?n0003oP0002@3oP0000`3XJ3`0X23`0=1@N0040?n000030;Ph]02P8?00X23`0080X23`
0P2h>;@00`2P8?00^3Rd0;Ph]0080:0Pl0040>QX?03oP000oh000=1@N080oh0000<0^3Rd0=1@N03X
J3`00`3oP0000`3XJ3`0X23`0:0Pl00;0:0Pl00;0=1@N02h>;@0d51h0=1@N02P8?00^3Rd0:0Pl03@
D7P0X23`0?n0003XJ3`00P2P8?000`3XJ3`00?l00?ooo`0:0?ooo`002P3oool0F000o`00FQL106P3
0P1S0P40E`8205410@1D0@40I`8306d1101d0@D0PP4808P120200P`0O`8<08l1302E0@d0V04;09T1
2@2D0PL0S04608X10`2H0@L0X@060:L22@2Z0PT0[P<;0:l2302a10`0[@880:h32`2]21<0APX>0:NV
ZP3Nh>40gN7S0=_OhP3LfN00ZWB907P_C@2WS:40fmkU0=oSiP3MhN@0h>CV0>7Ti@3Pb/h0[3Hm0<<@
501W2a40Kfed0=OLg`3Kg>00g]oT0=cMh03HeML0Y79j09P@7P2[0a00Z08;0:H12`2S0Ph0WP4=09`1
302I00/0RP<;04L00P1R0`X0OP@;06`5201S0@@0R`<:09D22@2A0PT0M`8507/21@2I0P/0V`4=09X2
3P270PT0OP4608L32P1g0`L0O@@806/00@1T0@40H`8106LF3`0F``490?ooo`03003o003oP000oh00
01d0oh0000D0X23`0?n0003oP000oh000=1@N0030:0Pl0030=1@N03oP000oh000080oh0000<0X23`
0?n0003oP0001`3oP0000`2P8?00oh000?n0000M0?n00003052@N03oool0oooo00H0oooo2`00o`00
CP14Z`d0Le8f06m@@@1^C480Jd]306Q8A`1XB4h0JTMB07=9E`1kD640PEIV08UWK`2@L7L0UG9n09Ib
N`2GM7X0VGUn09Z5Q02LTHl0NGbB00DMI`0C=7`0U9n]0<C;c`2VZK80]ko70:Zg_@2a`</0XK6m0<3A
gP20Vk<0Oijn039QV@2fh?d0N:3A03U][`2mf^h0e>;Y0=GSjP3DhNP0eN;Y0=CRj@3Dh^P0dN3W0<oO
iP3>gnH0d=oW0<oNi`3Ah>L0d=oW0<?Fj01]U/<0Y<OS06^E^@2P_Ll0Z;W80:Vd`02ia/l0/Kg90;g:
eP2O/KX0VZbc09JW[`2@XJT0QiVP08VKX01hRi00NXjB07f@U@1bQH/0KXB606f1Q@1YO800Gg=h06Z0
Q01cQh`0GfMT00Cb0PP0oooo2`00o`000`1@T7P0j6Pl0?n000060?n00080X23`00@0oh000=1@N02P
8?00^3Rd0P3XJ3`20?n000@0X23`00@0d51h0:0Pl02h>;@0^3Rd2@2P8?000`2h>;@0oh000?n00006
0?n000050>QX?03@D7P0^3Rd0?n0003XJ3`0502P8?000`3XJ3`0d51h0?n000020>QX?0030:0Pl03o
P000:<Pl00/0oooo000:0?ooo`0j003o001W70@0L@D306<10@1H0@40D@4105D10P1Y0PH0K0850741
1@230P/0R0<<06/21P1U0PL0T08=09L2302L0P/0V@4:08l11`290@L0RP8509D11@2U0`X0ZP8:0:`3
2`2^0PX0]0<>0;L6402c10/0/`L?0:/74P1;20h0Si2E0=cOh@3Lh>80g^;S0>3Ff`2X=dH0^aLZ09<J
;P29LH<0f^3T0=kSi@3Pi>H0h>?V0>?Mh02cFf80aA4G08d>4`0j:2`0a/kB0=[Ng`3JgMl0g=gP0=gL
gP2kXJP0T1dZ0:L43P80Y`4<01`0X`8<09d2302K0@/0W08<09H43P1:0P@0@@T=04D3200k0@<0GP46
08d2302B0@L0UP8809032@270PL0V08:09`33@2J0Pd0Q@880883202:0`L0P0<508X83@1d0P<0I@41
06H20P1R2`H05l<12@3oool00`00o`00oh000?n0000M0?n000060:0Pl03oP000oh000?n0003@D7P0
j6Pl0P3oP0000`2h>;@0j6Pl0?n000030?n000050=1@N03oP000oh000?n0003@D7P0103oP0000`2P
8?00oh000?n0000M0?n00003052@N03oool0oooo00H0oooo2`00o`00;@0Qe0H0LDl_06mC?`1_DD<0
L5=:06mCDP1ZCU80K4]B06m:E01hD5d0PeUW08iWL`2AK7P0UW9m09YfOP2NOH80Wh240:6<S`2MTiL0
A561004MN@0_BHH0]kk60:F[[`2na</0[;O00:Vg_`2caLd0X;:o0:6c``1[QZD0[/[U06fEaP0fL;@0
LZCG04Ei]`2jg?<0e^C/0=WUk03Ji^`0f^O]0=SVk@3GiNd0e^;Z0=GRj`020=CQjP0O0=GQj@3EhNX0
dMgY0<gNk`0iKK80Mj_J08jfe`2fd^<0/lOD0<;Bg02kb]D0`/gI0;k:eP2Q/K`0Z[_50:2_^`2IZ;80
Tj:Z08jMY@1mSiH0M8R=07>9S@1WOH40JWn206QmPP1YOX80CVE/065hN`1[PXD0IW9b017=2`080?oo
o`/00?l000<0D91h0=1@N03oP0001`3oP0050:0Pl0040=1@N03XJ3`0^3Rd0;Ph]0D0X23`00@0^3Rd
0:0Pl02P8?00^3Rd2@2P8?000`3XJ3`0oh000?n000050?n000050;Ph]03@D7P0d51h0?n0002h>;@0
1P2P8?000`2h>;@0X23`0:0Pl00:0:0Pl0030=1@N03oP000d51h00<0oh0000<0j6Pl0?n0001@T7P0
2`3oool000X0oooo05P00?l006PN101e1P80IP4105P10@1D0@00E`4106@10`1X0@80M04308@12@2<
0Pd0Q0<<07`22P2D0Ph0V`8=09`2302H0PX0S04808T11P2=0@D0T`4709`11`2Y0`/0/0@<0;@43P2g
10l0]P@?0;<33P2b1A00/0TA06L9401BC5@0d=GH0=gQhP3MhN<0g]cO0;=DGP354Q`0aa<M06T=6`2a
/KX0h>CV0=oSi@3Ri>L0i>?U0<VDV@2n5A`0/Q0G04011P2KW9l0fMgP0=OKgP3IgMl0f=_M0=K@d`2C
A4h0Y0DB0:D22`2T0PT0X@4<09d12`2K0@T0V04809T22`2161h0Uf5W06@k@@170P@0O0<:09412@2A
0@H0U@4609D11@2G0@H0V@4909/13@2K0Pd0S@8907l210210PD0N`4507H1101e0`@0K@8206L20@1V
3PT05/802@3oool00`00o`00oh000?n0000N0?n000050>QX?03oP000oh000?n0003@D7P00`3oP000
0`3@D7P0oh000?n000020?n000030>QX?03oP000oh0000L0oh0000<0j6Pl0?n0003oP0001`3oP000
0`3@D7P0oh000?n0000B0?n00003052@N03oool0oooo00H0oooo2`00o`00CP0Wf0P0M4`[06mD@@1^
Dd80L59906mBE01ZD540KDaC06e9DP1jDed0Q5]X08eWL`2AK7T0UW5k09YhP02QP8D0XhB90:6<T02K
Tih083=i00HVR01?JYd0XJZ]0:ne^@2i`/`0TZ6Z0<oOi023U9l0Zkg70:2d`@2``m`0PJ?A06jHc00g
LkT0U/GV0:cHj`2[dNT0gnS_0>K/k`3Zko<0i>cc0=o[l@3Kinh0fnG]0=KSj`3GhnX0eN;Z0=CRjP3D
hNT0dMoX0<oNj`2A^N<0WLcc08b`dP2N`md0W[G80:bmc@2c`m00b=OT0;C3d`2ld=h0/L?=0:Jc_`2Q
/[`0WZbh09:RZ`22Ti/0M8N<0724R01/P8@0K86206UnPP1UNgl0Eg1d05]cM`1SNgX0J7Qh02:M60P0
oooo2`00o`000`1@T7P0d51h0?n000070?n000D0X23`00<0d51h0:0Pl02P8?00202P8?000`3oP000
X23`0:0Pl0060:0Pl0030=1@N02P8?00oh0000/0oh0000<0d51h0:0Pl02P8?004@2P8?000`3@D7P0
oh000?n000050?n000030830003oool0oooo00T0oooo000:0?ooo`1H003o001X70<0MPD206L00@1J
0@40E04005H1001S0@80J@4207<210220@L0S08<08X12@280@/0T`4=09`23P2O0@h0V08:08h12@2;
0@D0R`4709<12@2H00L0ZP@>0;033P2d10h0^@D;0;@22P2a0@/0/P@>0;463`202Q<091@K0;o4b03M
hN<0f^3P0=kQi032PXP0_Q/T0<hB702D41T0PGV20=oUi`3Qi>P0hN?V0>3Sh`3E^K/0/adT0<4@6@1_
2A80LVQ^0=[OhP3Hfml0f=cO0=GJg03IfM/0X6Ub09l7502T0P/0XP4:09h22P2O0P`0W00909X12@2J
0@`0T`/F0:=0C02F>4D0Q0D>09412@2B0@L0TP0709<01P2F0@P0V@4909P12`2K0@`0VP4<08T11P1c
0080M`430842201n0@P0J`4306D10@1T0@00IPh901O20@T0oooo00<00?l00?n0003oP0007P3oP000
1@3@D7P0oh000?n0003oP000d51h00<0oh0000<0d51h0?n0003oP0000P3oP0001@3@D7P0oh000?n0
003oP000d51h00D0oh0000<0d51h0?n0003oP000703oP0000`1@T7P0oooo0?ooo`060?ooo``00?l0
04d0MddU06mC@@1`DD80Le=:06iAD@1^DU@0JdmF06e?F@1eDUd0P5MU08eTLP2DKWX0UW=n09enQP2S
Q8X0XhF<09n:T02ASJ802R=i008SP`1LMIl0[kJj0;Bj`02_]kl0^LK?0:Nh`@2T/[/0c=[Q0;G6eP2O
]m00EgNQ0=;Wn@3Fm?h0S/g/09KCk`3<j?P0lOKk0?WkoP3]loP0hncd0=oYl03Jinh0enC[0=OTk03G
i>/0en;/0=CPjP3Bh^T0d=oX0<oPj`2Ta^P0>GNj09Fmg02S`]T0^LgM0;_=g@2/_/l0[/3A0:6c``2Z
_l/0/<G>0:Nf`@2V]Kh0WJfg08VKY025V9d0MX^?0725R01cR8/0MHV:07J7R`1ZOX80H7Mi05eeMP1S
NGT0IGMh02VI8`080?ooo``00?l000<0d51h0?n0003oP0001P3oP0000`3@D7P0X23`0:0Pl0090:0P
l0<0^3Rd0`2P8?001P2h>;@0X23`0:0Pl02P8?00^3Rd0=1@N080X23`00<0d51h0?n0003oP0001`3o
P000103@D7P0X23`0?n0003@D7PA0:0Pl0060;Ph]03oP000j6Pl0?n0003@D7P0j6Pl103oP0000`2X
R3`0oooo0?ooo`090?ooo`002P3oool03000o`00LB4507d70@1Z0@40G04105X10P1N0@40J08206P1
0`1_0@D0P@4808`23080R`4;01@0U@4=09l3402P0Q00V@8;0901202=0@L0SP4809<22P2E0@T0X`@<
0;853P2f10l0^0@<0;@4302b0``0/`D?0;443`2C2A@0:P8909VMY080gN7R03@0gN7S0=Nd]`2/9bl0
cADL0;<E6`1SATh0f=gP0=cRh`3QhnL0g^3S0>7CeP2_<C/0aa8H09HB6`1D>D00emgP0=[Mh03Hfmh0
em_N0=SKg`2_T9L0V0dI0:D53`2Q10d0W`8<09h22`2M0@X0V`4;09P12`2H0Pd0T@<?09454@2D0P/0
T`4:09@12@2D0PT0T`4709021`2H0@T0VP8909P12P2I0@/0T08:07h1101n0`H0NP8607`3201[0P@0
H@8206L20P1R2@@08J@12@3oool00`00o`00oh000?n0000N0?n000050=1@N03oP000oh000?n0003X
J3`00`3oP0000`3XJ3`0oh000?n000020?n000050=1@N03oP000oh000?n0003XJ3`01@3oP0000`2h
>;@0oh000?n0000L0?n0000306RX?03oool0oooo00H0oooo3000o`00C@1cFQh0L50n07EBA`1dDT`0
K4i?06e>DP1[CE@0JD]F06e@G020FFL0SF=`09AaNP2GNX<0Vgj709n2R`2RPhX0XXZ?06a`U0048H80
1RR3086G^P2RZJd0bm;E0;Jk``2a^/80_lO>0=KLh`3Gh^P0bm[Y0=SWl03Um_d0Q/7T0:KNn02`hOD0
co7k0=k^mP3Vk_@0jo3d0>ccmP3Vk_D0h^cc0=WWk`3EiN`0e>?[0=KSj`3Fh^/0e>;[0=;Pj@3@gnT0
dn;[0;cAi`21[=`0W/OZ06ZA^02Y`=L0YKW80;C5d`33e>40/<?@0:fnbP2GZ;<0UZF]09RU[@2FXZ`0
QIJN07J9T01fRi40KXF907J=S`1hS900Mh^?07>7R`1JL7@0GgAe06EhNP1QM7@0>g`e00P0oooo3000
o`000`3@D7P0oh000?n000060?n000030;Ph]02P8?00X23`00X0X23`00@0oh000:0Pl02h>;@0^3Rd
0P3@D7P01@2h>;@0j6Pl0>QX?02h>;@0X23`0080d51h00<0j6Pl0?n0003oP0001`3oP0020=1@N080
^3Rd4`2P8?00103@D7P0X23`0:0Pl03@D7P40?n000030=1@N03oool0oooo00T0oooo000:0?ooo`1H
003o001d7P<0P0H206/10@1O0@40G04105h20P1X0P<0I04106h110210PP0R04:08d1302A0Pd0U`4;
09l22`2L0P`0T`4:08l12P2>0PX0S`4809<12@2F0P/0V@8;0:d43@2e10h0]@<<0;@43@2b10d0/@H<
0:d33@2R1a80E`H=05mKHP3Kh><0fmoQ0=kRi@3SfM`0^6U_0<DK8P3;5Q`0GQDN0;c0a`3Mi>D0gn?T
0>3Si03Th^D0^VM_0<LD6`2g4AX0DQ@K0<O<d@3Kgn40f]gP0=SKg`3IgMl0a[Zo08hL:@2S1A40X`@?
0:813`2O0@/0W04909T22P2J0@X0V@8:09@01`2E0@X0U04;09@1202E0@L0T`4609421`250@D0T`89
09L11`2G0@P0V04;09<220220@D0N04606D31P1H0@40J0@506<20`1X0@80I@X502j60PT0oooo00<0
0?l00?n0003oP0007P3oP0001P3@D7P0oh000?n0003oP000j6Pl0=1@N0<0oh0000<0d51h0?n0003o
P0000P3oP0001@3@D7P0oh000?n0003oP000d51h00@0oh0000<0d51h0?n0003oP000703oP0000`20
`000oooo0?ooo`060?ooo``00?l004d0G7XE071==P1fDd@0MEA=06]>C@1YC4h0J4]B0614C`1VBeP0
PEe[08YTK`2AKgH0UgN309IjQP27L7`0Ugb50::;U@18E8H012:900P^Q029V[H0d];F0;jla03;c=80
f=WN0=cNi@3Ni>h0hn_c0>_an@32fN/0]=G`0;;Ml03@m_l0bo3m08O9iP30iOL0io7h0>can03UkO@0
gNS_0=WVkP3Gi^d0eN?[0=7QjP3@hNT0d>3X0=3Oj@3@g^P0cmkW0=;Qj@32dn80HXJg05R4^02X`md0
/<WO0;74e02/_/`0VJZg0:^lb02[_LH0Y;O10:6a^P2EY:T0S9bS08>GWP1mT9L0Igj106IoP@1jSi80
Lh^>06j7R01^QXL0KhJ806UlO@1SMGD0H7Ec04iQAP080?ooo``00?l000<0X23`0?n0003oP0001P3o
P0000`2P8?00d51h0>QX?0090:0Pl0030=1@N02P8?00d51h00<0d51h00X0j6Pl0?n0002h>;@0X23`
0=1@N03oP000d51h0:0Pl02h>;@0oh000P3XJ3`30?n000040>QX?03@D7P0oh000=1@N080X23`00<0
^3Rd0=1@N02P8?003`2P8?00103oP000d51h0:0Pl02P8?020?n000050=1@N03oP000oh000?n0003X
J3`02`3oool000X0oooo05P00?l007TP0`241`80K`4106D20`1L0@80GP4206T2101W0@40K0020881
2@2:00`0S`8=09022`2F0@/0X0@=09X2302A0@T0T@4:09002@2A0@L0U`4909`33@2I0Pd0X@890;85
3P2b0`X0/@8;0:l4302]10/0Z`<;0:@4302341P0AC4j0<kCf@3KhN40gn;T0=oOg`3M/[H0^bH^0=<F
6`2241L0LVMa0=oTi@3Pi>H0hNGV0>7Ti@3;UI`0aQ/V0<PB701Z2Q80ZJnd0=_Ph`3IgN00em_N0=WN
h03Bc]80TCA00:D54P2U0`l0X`<>09d12P2K00X0V@4:09D12P2E00P0U@0709@12P2C00L0U0060940
1P2A0@D0T@4609011`2B0@P0T`0709<11P2G0@P0U@4708`21P1e0@<0M0<705l00@1P0@80J`4306/2
0P1W3@P0<8T52@3oool00`00o`00oh000?n0000N0?n00080d51h0`3oP0001@2P8?00oh000?n0003o
P000X23`00P0oh0000<0d51h0?n0003oP0000P3oP0000`3@D7P0oh000?n0000L0?n000030830003o
ool0oooo00H0oooo3000o`00;`1TP1L0KT`e079D@`1bET`0JTm>06M:C@1WBe40J4eF06mBF`22HF`0
Qf=a08m^N02DLgh0U7N307IQK@25KgT0Xi6O02i1Q`029i@03CR;0;2kd`3AaLT0fMGI0=cLhP3Df=h0
g=oY0=kSj`3Tjo<0g>K_0=SVl`3VnOl0[mOd03f=b`1U/=l0anki0;OGk03Gi>d0e^?/0=KSj`3Dh^P0
d^?X0=GTj`3Ch^T0dN7X0<oQj03>h>P0c^3W0080cmoX01`0cmoY0=;Pk02ec^@0K9S>096gg`1/T[D0
[<7D0;O:e`2od=d0^/gK0:Be`@2P/Kh0X;6j09:U[026UIh0O8jE07F9T01VOX80HGQl0724R@1cRXh0
K8>70727RP1dQhd0Kh>506EjN01QN7L0DeY?203oool<003o00030:0Pl03oP000oh0000H0oh0000<0
d51h0:0Pl02P8?000P2P8?000`3@D7P0^3Rd0:0Pl0040:0Pl00;0;Ph]03@D7P0oh000>QX?02P8?00
j6Pl0?n0003@D7P0^3Rd0>QX?02h>;@00P2P8?000`3XJ3`0X23`0>QX?0020=1@N0L0oh0000<0j6Pl
0;Ph]02h>;@04@2P8?000`3@D7P0oh000;Ph]0020:0Pl0030;Ph]02P8?00oh0000<0oh002`3oool0
00X0oooo01800?l007TS10262@80M@4106H10@1O0@40I04306`11@1]0P@0LP4608@22`2:0@d0S08=
08h1302D0P`0VP<=09D12`2B00X209<12`1409@22`2H0P`0W@8=09d33P2P0P/0[0@>0;843@2`0``0
[PH>0:L32P2V0PP0Z0@;09L<500k4QX0^l;:0=kRi03Oh^<0gn;R0>SEf034CEH0gA/M0;<J8@157bP0
emSK0>;UiP3TiNL0h^GW0=foa02o92h0e1@J09@A6@2>R8l0g>?U0=cQh`3Ig^00f=gP0=[JgP2MF680
Z0TF0:P33`2U0`h0W`4:09`12`2K0@T0U`4:09X1302H0@X0U@0;09812@2B0@L0TP4609811`2@0@D0
T@4808d3202?0PT0UP8:09H12@2C0PP0R08407`21@210`L0M@4206T20`1[0P@0K@8206D6100bR0D9
0?ooo`03003o003oP000oh0001l0oh0000<0d51h0?n0003oP0000P3oP0001@3XJ3`0oh000?n0003o
P000j6Pl00<0oh0000D0d51h0?n0003oP000oh000>QX?0050?n000030=1@N03oP000oh0001/0oh00
00<0P<000?ooo`3oool01P3oool<003o000U03nV2`1bCSD0M5I407EGB`1/D4X0J4i?07=PHP2VUYX0
NUiW08ASK@29IG40TFmh09EeO`2FMh80TW5j0:J2S02[VjP093f=00<`Y005<Hd0YKGB0=?>eP3Gf=h0
e]WO0>3Tj03Sinh0h>S_0=[TkP3Mi_00gN[h07BMc@2>`NX0TLG^07J]h01j/>00UkkK0=GSj`030=CR
jP80dn;Z02<0cn3[0<cRk@39hnh0an;^0<KRl@35hO<0_mkd0;SKmP2bf?L0P[KW01YP`P1a[NT0RK[X
09K3k`1kY]H0OZKG082We02<[m@0XKoP08f/b025X;H0RJ2b08FMZ01hTIT0J7n406f5QP1XPX80LhZ=
06n4RP1aQX`0M8V=07J;S@1[P7l0HWMg05IME0080?ooo``00?l000<0D91h0?n0003oP000103oP000
0`3@D7P0oh000>QX?0040:0Pl0030;Ph]02P8?00X23`00D0X23`00D0d51h0>QX?03oP000oh000>QX
?0020;Ph]0030=1@N02P8?00X23`00@0X23`00<0d51h0>QX?03XJ3`00P3oP0000`3XJ3`0^3Rd0;Ph
]0020=1@N0030;Ph]02P8?00X23`0140X23`00@0d51h0?n0003oP000d51h0`2P8?00103@D7P0oh00
0?n0003oP00;0?ooo`002P3oool0F000o`00ObH708X8101l0P<0J`4206@10`1Q0@80J08406h21@1`
0@D0N`48084130230@T0S04<09<2302B0@`0S`8;09412@2B00X0TP8909422@2F0P`0VP8<09/2302Q
0Pd0YP4<0:l33@2`10d0[0D=0:P22@2X0@P0/0@>0:h95@1P1a80TYBO0=oTi`3PiND0h^KV0>STi03R
XZD0h3do0=m7C@28=d40bl;60>KYj@3VjN/0inW[0>kTi`3JH6L0kRL[0<`P8`21GVD0gnGX0=kTi`3L
h><0fmoR0=[Nh@2lTiX0Za0L0;H54@2`1140Z@8>0:<13@2O0@/0W04:09/02P2J0@X0V@8;09H22P2E
00T0T`4809811`2A0@L0T@4808X21`2<0@T0V`8<09T12P2@0@H0Q08607H110220PH0M04306X3101Z
0@80K@4106H40P0cR0D90?ooo`03003o003oP000oh0001l0oh0000<0^3Rd0?n0003oP0000P3oP000
1@3XJ3`0oh000?n0003oP000d51h00@0oh0000@0j6Pl0?n0003oP000d51h1@3oP0000`3@D7P0oh00
0?n0000K0?n000030830003oool0oooo00H0oooo3000o`00C@0c_PT0ME4d07AEA`1dE4T0LE9;06U@
C`1hJVh0/jZd07UOK022H6d0RVMc09=`N`2GN8@0XH6<0:N0S02aS9P0[::b01TfRP02<:X01SVO09Va
eP3Dd]X0d]GJ0=WMi@3EfN@0e=cV0<_Hi038e=l0c]gZ08fW``2/anD0EXBk07R]g@1DSLP0L:cQ0<SS
m03Ei>d0f^K]0=gXk`3Gjo80`NOh09kIn020c_P0IKkg04bXl@17W^l0>XcY031hhP0[J]P09E[;02AD
b00VC<<0:4:n02/o/@0^?Jh0;cb/02/eY00Y<j009C:O028`V`0P<IL06S6A01`gT`0Q@9L0:T^J035C
TP0jFHP0Bfb;06F5U`1dSYP0LHR@07>:SP1[PXH0L8N:07J;SP1]PhD0GF9N00P0oooo3000o`000`1@
T7P0d51h0?n000030?n000040=1@N02P8?00^3Rd0=1@N0`0X23`0`3@D7P00`2P8?00^3Rd0:0Pl007
0:0Pl0030;Ph]03oP000oh000080oh00802P8?001@3XJ3`0^3Rd0:0Pl03XJ3`0oh0000/0oooo000:
0?ooo`0C003o0024:0H0S@P207d20P1/0@80H`8205h10@1U0P@0J04206`11@1j0PX0O@4;07d02027
0@X0S`8<08h13@2<0@/0S@8;09012P0209022P1309@12P2I0P/0W@8<0:@23P2R00/0Y`@<0;873P2h
20h0_0T?0<<:4P383AD0ba<I0;8M9P2=KWT0jng`0>KZk03Xj^`0kNg_0?C^kP3li^H0oo7b0?ofm`3o
o?d0moSi0?Gfm`3cm?H0lo;d0?J/[`3jCTT0mD8k08i1B`3]k_<0hnOX0>;Ui`3PhnH0gn;V0=o6c@2g
82h0b`/H0<D7502l1Q00/`<=0:/23@2T0@/0WP4:09/1202M0P`0V`4;09X12P2I0@P0UP4;09812@2A
0@L0U04909X2302M0Pl0V`4;09H11`2@0PT0Q04608021@1`0@<0I`8307420P1/0@40H0<103]o2P09
0?ooo`03003o003oP000oh0001l0oh0000<0d51h0?n0003oP0003P3oP0000`3@D7P0oh000?n00003
0?n000030=1@N03oP000oh0001/0oh0000<0Z8Pl0?ooo`3oool01P3oool<003o001=02CE1`1eD2h0
LeM507IFB01bDdX0JU1>06I>D@1dF640NUYW08IQKP2=J7H0VWN40::1S02/RiH0/8nI0;FRZ@2l^<T0
842D00<a[007>ZT0NIG50<W;e@37b]@0a/_E0<_Ag036cMT0/[o80<gIh`2Z^LH0YKcB09jme`1hWLD0
SKSH0;KTo019/>L0I/Wg08gInP2]i_/0T]Ke05Vkl@0VY_4039Ob00F@mP05Q_L0>V_P08M=/`2P@i/0
[SR50;X]K`2n8f00^aUF0;`GC02i6DD0]1Q20;8F@02^7TP0Z18j0:4E?02M33L0X0Td09L>>@2=54L0
QAE?07LGD`1T5Eh0DQMS03/DI00W66/04am^01lkO00aD8D0BFZ>06=nSP1UO840IWeo07Z?U@1TM6D0
203oool<003o0003052@N03@D7P0oh0000D0oh0000<0j6Pl0;Ph]02P8?00402P8?000`2h>;@0X23`
0:0Pl0020:0Pl0030=1@N02P8?00X23`0080X23`0P3@D7P<0:0Pl0050;Ph]03@D7P0d51h0=1@N02h
>;@01@3@D7P00`2h>;@0X23`0:0Pl0090:0Pl0040=1@N03oP000X23`0;Ph]0/0oooo000:0?ooo`1H
003o00249PL0S@P307T10P1Z0@40I04106410P1P0@40I04106l10P1h0@P0N@0907d12P250@X0S04<
08d23P290@X0R@4908T0202>0PX0S`4909X12`2O0@`0Y@8=0:/2302]0`d0[08;0;`8403>41H0gQLJ
0>DJ7P3[8B@0lbX^0?0f?02gF6/0o_On0>o_lP3_l?<0lO;f0??dmP3emoL0nocl0?_mo03loOd0n_[k
0?Kgm`3dm?H0mOCe0?JUZ`3jDD/0n44i0:4kA@3dl?H0hnOX0>CVj@3Ri>L0hNCW0>cKh`30=D80d@lJ
0=4<6@391a<0a@LB0;X43P2`0P`0YP4:09l01`2R0@X0XP<=0:023@2M0@/0V@4:09<0202A0@P0U`4:
09/12`2L0@d0VP4;09P1202C0@P0PP8607821@1_0P80I`4306`10P1/0@40G`8104aA30T0oooo00<0
0?l00?n0003oP0007`3oP0000`3@D7P0oh000?n0000;0?n000030=1@N03oP000oh0000H0oh0000<0
d51h0?n0003oP0006`3oP0000`3@D7P0oooo0?ooo`060?ooo``00?l004d02_H207Q>:01gET<0N5M9
07AFC`1/DTl0JU1C071BF01kFF@0RV9_09UcO`2NOHT0YHJC0:V?V`2bVjP0ak2l0;fZ_@0[?hl00RBJ
00DZVP1]Rkl0][S30<;4b`2m`/P0`<G?0;k5c035cML0/lGD0:G7gP2XeOD0TL[]072kl@1<[oD09Y?]
01BDlP0<Snh04J;^032/j@1G_>`0I/Gb04S3n00R/_T039cj012;n@25D;H0jB==0>dI;`3W52D0fPlM
0=H<703;1QX0aPHH0<]8D`3WZ;00YTMJ0=NKZP2iJG/0k;c60:@^AP2Z11@0^U5K0=:Y]@3;WZ`0`HZJ
0:I7G02G1A`0T@XO08@B;P1a33D0FQ1704<AE00W5Eh052=U031>LP1JMgl0JGf204f:B0080?ooo``0
0?l000<0:<Pl0=1@N03oP0001@3oP0000`3XJ3`0X23`0:0Pl00;0:0Pl0050;Ph]02P8?00X23`0=1@
N02h>;@00`2P8?000`2h>;@0X23`0:0Pl0060:0Pl0030;Ph]02P8?00X23`00@0X23`00<0j6Pl0?n0
003oP0000`3oP0002@3XJ3`0X23`0;Ph]02P8?00^3Rd0:0Pl03@D7P0oh000=1@N0020:0Pl0040;Ph
]03XJ3`0oh000?n00080d51h1@2P8?000`3@D7P0j6Pl0=1@N00;0?ooo`002P3oool0F000o`00S2T;
08`80P1d0P40I`4106<10@1U0@<0IP4306/10`1c0@D0N`8:07P12@1h0@X0Q`4=08`23P280@X0R`89
08d12@2@0@/0U@8;09T22@2V0PP0[`@90;X73@342@l0b0/A0<P:4P3@3QL0fa8J0>`N8`3f8bD0oBX]
0?d/<P3m=S`0iCY<0=a_R`3gd^00n?;h0?Wbn@3glOH0no;g0?cfn@3knOX0o?_m0?cgn@3llo<0oNk_
0?[@e03cKFl0nTTo0?]0=`2Q:S80cLO@0>7WjP3PhnL0gn;T0=kRi03Rf=l0^Sm>0<hA7P3=3QL0bPdE
0<D:4P2o2180^@LB0;033`2Z0Pd0Y`4=0:P23@2Y0`h0YP8>09l2302J0@/0UP4:09L12`2N0Pd0X08=
09l23@2L0P/0UP4808@21`1T0@<0KP@506P20`1`0@80K04205/10016BP@90?ooo`03003o003oP000
oh0001l0oh0000<0j6Pl0:0Pl02h>;@02P3oP0000`3@D7P0j6Pl0?n000020?n000030:0Pl03oP000
oh000080oh000P3@D7PL0?n000030=1@N03oool0oooo00H0oooo3@00o`00C01kDRH0MUI207UJBP1j
FeD0LeID07AHF`1lGV@0OemW08]XM@2EMWl0VX>=0:29UP2WSY`0/96Q0<:HZ@37WK80:Rij008HP@03
7X<0CVBG0<34bP2m_lL0^/?=0<?Di@2/a^L0MjOQ04fCiP0ILN802V_Y00UVi`04P?L00XWk00FBo00<
X_`0:K_k02ninP1=]O<0Gjc]03n:h`0WLn40<F3H04ACbP1H@kH0W2Mj0=@@<`3G31`0c@PE0<H55@37
1QD0aPHD0<@550306bh0hjZg0:IfR`3I]lP0^H^P0=BcaP2H6S/0Z08D0:Y;F`2]TjL0SEQg08iTO`2g
TJ@0R`PP0:55C`2URi40ZXJ>09eIJP202R@0P`HR068;=P0I4U4052mQ04mYMP0cXbl80?ooo`d00?l0
00<0d51h0?n0003oP0001@3oP00<0:0Pl0030;Ph]02P8?00X23`01H0X23`1P3oP0000`3XJ3`0X23`
0:0Pl0030:0Pl0030=1@N03oP000d51h00@0X23`00P0oh000=1@N03@D7P0^3Rd0=1@N03oP000j6Pl
0;Ph]080X23`00<0^3Rd0:R8?03oool02P3oool000X0oooo05P00?l0080T1P271`40LP4106P10@1Y
0@80IP4206D10P1/0P@0M04707h12`1f0@D0M`4708X1302>0@`0R`0809812@2L0Ph0X04>0:T33@2b
10d0_@H>0<H93@3@3A00fA8@0=D=3`3;1Ph0b`LA0<l:4`3G3AH0l1/P0?/V:03m;2d0oS8_0?df>03j
>T00le9Q0?AcQ`3fMhX0m7N50?J1RP3iV:D0nKK80?o3f03iZ[P0mhV@0?YnOP3lJVH0oUA<0?m7@@3n
?S/0^2Tc0:jFXP3UjNh0gnCW0=kRi@3Jgn80hMkS0;MDH`364b40b0lI0<H>5`3021D0^PDC0;H44@2b
10h0Z`4:0:T1302/0@l0[P<>0:X13@2T0@X0X04<0901202E0PP0X@4=0:H23`2Y1A40YPL@09X22P2:
0@H0M`8506d2101_0PD0N08306h10P1R0@00BTX42@3oool00`00o`00oh000?n0000Q0?n000050=1@
N02P8?00X23`0;Ph]03@D7P0102P8?000`3@D7P0j6Pl0?n000040?n000030:0Pl03oP000oh0000<0
oh0000<0d51h0?n0003oP0006P3oP0000`3@D7P0oooo0?ooo`060?ooo`d00?l004`0JWTR07=F?@1k
G4`0OEiD07aMF`1nHF@0P6EX089WK@29KgX0Tgj909R6T02KQi<0YHbJ0:V=V`2_SY`0]9>V024TK@01
5G`00Q^0055VW`2T[l@0Sj[E066CfP0VJ<h025?=00=Ef`03G>P00fSf00Icn`08OO/01ggh00Mim@0;
Mo405W?Y01U?a@0kBkl0JTJe08LlXP2G=Y<0WS6:09/`QP2<<XL0NCbD07diS`2l8Ed0haHZ0>@D6`3N
3aX0g@dG0=d>6@3I2aL0e0hN0=ATM@3:ZkP0gl7@0<2EZP3=WK@0Y1<a0;<44`2/<D40ajNf0<2]_@33
^<H0_9jb094:9@2F<3d0^k_00:bf_`2WUZ@0LAL]08L34P250a80>@do00<CE`0E;5409j/Z203oool=
003o00030:0Pl03oP000oh0000D0oh009@2P8?000`3XJ3`0oh000?n000040?n000030=1@N02P8?00
X23`0080X23`00<0d51h0?n0003XJ3`0102P8?000`3@D7P0oh000:0Pl0020:0Pl0<0oh000`2P8?00
0`20`000oooo0?ooo`090?ooo`002P3oool0F000o`00Ob8408L80P1d0@80J@4106L10P1S0@80I@42
06h11@1h0@H0Q08908<120250@T0S`8;09L53`2D0@T0W@<<0:@2302Z0`h0/P@>0;@3302k0`X0`0@:
0<P52@3D3Pd0e0d>0</73P391Pl0cPTC0=8=5P3]6RD0o2P/0?/Z:`3n<2d0oS4`0?da;`3n=c/0nca5
0?e1BP3i?TD0n4A90?A6D`3^Bf40kTeX0?58FP3d@DT0n4930?Ll>`3g<c@0m2X/0?<Y;@2_7RX0GT5C
0=GIhP3Mh^@0g>7T0=[Nh@3Mg>40Y59Q0;LA802m31P0`PhK0;T65@2d11@0/P@?0;433P2]0Pd0ZP8=
0:X13P2/0@`0ZP4<0:D02P2Q0P`0QP4408l12@2O0@/0Y@4?0:d85P2b51d0X0H=090220200PL0I`01
06X10P1g0@80K@4206810@19BP@90?ooo`03003o003oP000oh0002L0oh000P2P8?000`3@D7P0oh00
0?n000060?n000040=1@N03oP000oh000?n00080d51h703oP0000`3@D7P0oooo0?ooo`060?ooo`d0
0?l000`0JXLT085NB022HDh0QVEG08IUH026JFT0PFQY08M`M02:Lgd0TWZ809MkS02IO8d209n1T00n
0;6?W02hU:X08BYh00<TT`04:Y`0546Y01M=^007BLP00dS>00ADgP05En8015OT00MFi@0:Cmd06TcB
03A0^`1B=ZH0IC6H07LaT02>;hH0KAi`06HaQ@1aBIX0OVR^08J>`P1RWML0;ICY01F>l@0@R?D06gK`
07m;]03O8DL0jAHN0>0@6@3J2QP0e0XF0=885@3?2AL0_ba10>38d`3E`<l0dZVo0;1UQ@2Z32L0/`8@
0;PmB`3G^<D0a[K40<Bja`2gP9P0W@LQ09PY=`3>a<`0Zj^g0:jHY`1i6SH0RP<F07d230152S402A9D
00<DA00IW2480?ooo`d00?l000<0X23`0?n0003oP000103oP0000`3XJ3`0X23`0:0Pl00S0:0Pl003
0=1@N03oP000oh0000@0oh0000<0d51h0:0Pl02P8?000P2P8?000`3@D7P0oh000=1@N0040:0Pl080
oh000`2P8?00103@D7P0oh000?n0003@D7P20:0Pl0030830003oool0oooo00T0oooo000:0?ooo`1H
003o00259`D0Q0L107D10@1U0@40H04106<10@1Z0@<0M@8508011`280@T0R04:08d22P2Q3QP0/ATT
0:D74P2Y1@h0ZP<;0:X22P2`0PX0/@890;P42@2n10X0aPP=0<<:2`2j1PP0^@D;0;P53@2g10h0_0LB
0<D85@3O5b80iA/Q0>/Q9P3^9bT0kRTY0>/];@3V<380iSDf0>Hi>03U?ch0iTI40>=<B@3TDU80i55B
0>MGE`3SEU@0eDY70=e@C`3FBd`0ad5409/i@01=>4@0^l;70=_NhP3Ig^40f=_O0=WKh02AFVD0WAHS
0:@=5`2X2QD0Z0HC0:D24@2S0@h0X`8=0:<23P2S0@`0Z08<0:X13@2W0Ph0X@4;0:02302D0PT0UP4:
0:822P2T0@/0Y`8A0:X95`2Q2140S`@<07`31`1j10L0LP4307T20`1/0@80G`4004a=1`T0oooo00<0
0?l00?n0003oP000<P3oP0000`3@D7P0oh000?n000020?n000030=1@N03oP000oh0001X0oh0000<0
d51h0?ooo`3oool01P3oool=003o001<052T6@23HDT0QfEC08i]G`2>L6T0QVi[085XJ`1nHfl0RFmm
08Y^OP2<K7d0Sfal09]lR@2TRIL0ZY:W08Ao[@0E=ID00bjX008`[P01<kD013g300E4cP06BM802DC<
01Di_@0a<:/0DRNC070SO@218Fl0NRE`05/_O`1>?Y40?U2[02a^c`0KQNP069;_03b_mP1T^_@0E:O_
01V4l004M_@00Fkb001UkP05FN@0<cff0;DJE03I2QX0e0PD0=H95@3B21<0d0HC0</@702l@4`0h/[D
0;nR]@3;V:l0[5Eb0:dC:`2`1140a6Mc0<2Z^036^/P0_JZk0;AROP2V1ad0[U9K0<Jna`2l_<T0c;k>
08@VA`2B11T0QP8806<45P0d3cT02a<l01:B5`P0oooo3@00o`000`1hF;@0oh000?n000040?n00003
0=1@N02P8?00X23`02@0X23`1P3oP0000`3XJ3`0X23`0:0Pl0020:0Pl0030=1@N03oP000d51h00@0
X23`00<0oh000=1@N02P8?000`2P8?030?n00080X23`00<0P<000?ooo`3oool02@3oool000X0oooo
05P00?l008<T1@201P80L`8106D10P1M0@40HP810701101l0@@0Q@4808P11`2900L0T`<=0:/;602X
1a<0YP<>0:T33P2b1100/P<>0;@33@2h1@h0/@<:0;<53P2]0`X0X08709T0102H0@H0UP4609@11`2H
0@/0WP8=0:<54P292A<0/5II0=bASP3ZYZ80kkJd0?7:b@3cd<l0m]OD0?CKf@3cgMX0lN7L0?7Rg`3b
i><0l^GU0?7Sh`3/h=`0k>3O0>_Oh03Vfm/0gMKE0=GGe`3Fg=h0fmoS0=[Nh@3Hg>00f]gP0;Za/@2_
Shl0[7mn0:MZK@2TDeT0TA8L09/2302H0@X0U@4:09L1302M0P`0X08>09h13@2K0@/0VP4:09/12P2N
0@X0Y@4;0:H13P2W0Q40W04>08X22@1h0PL0L`@807H4201b0`D0OP<507820P1R0040C3L22@3oool0
0`00o`00oh000?n0000N0?n000050>QX?03oP000oh000?n0003XJ3`0503oP0000`3XJ3`0oh000?n0
00020=1@N1P0oh0000<0d51h0?ooo`3oool01P3oool=003o001<04V`4`27HDH0T6YE09MfHP2FOg80
SWUf081ZK@1lHf`0N5iY07mRK`26IW@0Sfil08ajT@1SJIT09T>G00L_W@04=;8013Nk00Dj`003;k<0
2S:_01`/X`18:Y@0K1Yd088HH`1f6F80Eb=d03LfT`0ND[`04FKM00efl@0<OoH02X?i00Mnm`02L_H0
0V[b005Xl@02J?400fga00=^l@04L_4017[b00=om@04OoH0877U0:XlRP3a7BT0la`P0?8I7P3Z4a/0
jA<O0=`a?03g_/`0hL3E0>:neP3Q_M<0l;SB0;T_C02l1QP0`dUP0=c3e038_Lh0d<GF0;5LNP2S2Ah0
^g^20;jlaP2j^<H0`IVd09XH?@2U1QP0U@8:05@68@0H2C408AL^00SF1`P0oooo3@00o`000`1@T7P0
d51h0?n000040?n00080j6Pl9@2P8?060?n000D0X23`00<0d51h0?n0002h>;@0102P8?000`3oP000
d51h0:0Pl0030:0Pl080oh0000@0j6Pl0:0Pl03XJ3`0:<Pl2`3oool000X0oooo05P00?l0084V1P1k
1@40L`4206810P1C0000G@4207<1101o00@0Q`4708X11@2=00P0V@<>0:P5402T0`h0XP8>0:/44@2_
1100/0<=0;453P2[1@`0WP890:44302K0@P0TP480980202>0@D0R@4308T01P2B0@`0V`8>09d85P1O
1A@0RGj90>SZjP3Yj^X0jng^0>WZk03Zjnd0k^oa0?CdmP3`l?80kNo_0>k^l03`k_40l_7b0?7bl`3/
k>d0j^[]0>_[k`3WjN`0i>SY0>7UiP3Oi>L0fn7T0=_OhP3LhN@0gMoR0=[MgP3HgMd0e]_K0=CGe`3?
a/P0Rc8m09l23@2I0@/0T`4709D02@2I0P/0VP0909L02P2I0@X0UP0909H12@2L0@X0Y`8>0:l55@2]
1aD0V`4:08d1201f0@@0N@<606d3201@0000M`8607D10P1U0@00GPX32@3oool00`00o`00oh000?n0
000N0?n000030=1@N03oP000oh0003@0oh00203oool=003o001<02CG202:Hd00UGAJ09f3K`2WUHX0
SGUg081WJ@1eG640M5UT07iUK`1nJgd0EE9o01T^O004:9@00RVR008YY005:j/03BVS01hPSP0i5GD0
Ha9N07XBE01_6V40D2n902@fWP0@A;X02ECB00QNh`04GN@00ekW005Ij000F^H00F;[005Ul@02LOD0
17ce016;l`0lYo00J<3d07cAn01ZeOT0@L[g01nio00?Z?h04I7j07UM_@3Y9440k1PU0><B8`3K42D0
eA4V0<T@;@327TT0^1Y>0;8GB`2]64T0ZaA40:/<<02/1R40Z0XX0:<WD@2X?VX0[d9/0:8;;02P11H0
`6j20;jM]03>_Ll0/6F30:L=:02]1a80VP@?04H=>`054e806APe003o00P0oooo3@00o`00101@T7P0
^3Rd0=1@N03XJ3`50?n000030>QX?02P8?00X23`01X0X23`00<0^3Rd0=1@N02h>;@01@2P8?001P3@
D7P0oh000?n0003oP000j6Pl0=1@N0D0X23`00<0^3Rd0=1@N03@D7P00`2P8?000`3@D7P0oh000;Ph
]0030:0Pl0<0oh0000@0^3Rd0:0Pl03@D7P00?l02`3oool000X0oooo02/00?l007dU1P1i1040L`41
06L20`1G0040H`4207T110220@H0R@4708h11`2E0PP0V@<;0:H84@2_4QP0/1TP0:L;5P2T0a00XP<=
09`22P2F0PX0R`0709@11`2E0@H0U`4909H02@2F0@T0UP4609T12@2T10h0[PDA0;L<5`2M5RD0R6Ee
0>k_l`3]ko80mOGh0?ShnP3in?X0n_Wk0?kmo`3ooOl0o_co0080o__o0P3mnOd0:@3kmO/0n_Ck0?Wb
nP3ilo/0mNkg0??Zl`3_iO40iMk[0>?Ok@3Kf^H0em[T0=OKhP3Gf^80emcQ0=CJg`3Dd]P0VdYI0:X4
4P2T0Pd0W00:09h1302O0Pd0W@4<09/13@2H0@/0U@0809H12P2K0@`0Y`HC0;PF8P2i6280X0D?0903
2`1h0@D0M@<706d31@1U0`D0O0<707X10P1Y0@40HP/300T0oooo00<00?l00?n0003oP0007P3oP000
0`3@D7P0oh000?n0000=0?n000030=1@N03XJ3`0d51h00P0d51h00@0oh000>QX?03@D7P0d51h603o
P0080?ooo`d00?l004`02oH308eT=P2KOf@0XXio0:fRW@2EQ8<0OFAT07aSI@1iHfl0FEAc01`XJ@03
6GH00R6<008RU`0589D06A^804XFL`1f4EH0N@Y106D?BP0k5fL072R<00`cZ`08A<X014cH0097dP01
B=<00T[H005Ch002H>/00F[a00=gn005QOX01YSm00bXoP0V^oX0Em3k06k;mP1O_?@0?Z[b01>Bl`06
ROL00h;l009en@03K?H06UgR06PmW`1i<X40JS:405/`S01@=9L0ACBK03leW`0h<Z80<RnM02h^V00]
:I80;RJ;02lPP@0b77L0=aM/04<FJ@1A5V40GA5A06/=?`1i33T0Q0li09h`EP2U83l0Z`PM0:/5402@
1QP0<1=@00@HJ00?6T@00?l0203oool=003o000402S8?02P8?00X23`0>QX?0@0oh0000<0j6Pl0:0P
l02P8?006@2P8?000`2h>;@0d51h0:0Pl00I0:0Pl080^3Rd0P2P8?00102h>;@0oh000?n0003oP002
0:0Pl0030=1@N000o`00oooo00X0oooo000:0?ooo`09003o001k8@D0N0<107T20P1i0P<0L04107D1
10200@D0Q@450080S08800P0S`4908l22@2I1140W`XG0:@D8@2J21H0U@8<09@22`80SP4903@0U@48
0:02202Z0`T0]`T=0<0?402l20d0^`H@0;`53`2o2180``XE0<T>6P365B40YBe70=fI^`3OV[d0jYo1
0?2U`P3aYKl0lZJk0?6Y]@3^[[T0k;C20>Z``P3XXK00ji:O0>b4T03^N8L0kVf20>mYO`3]IWX0k5]d
0>iMM`3XEG40ge=c0=A@M@3=EgT0bF:10<E[RP2mKHX0_GNB0;n6X`36TZh0/dML0;@54P2_0`d0Z@4:
0:T22`2W0Pd0Y08=0:423@2M0@/0V`4:0P2J0@/03@2R1140Z`/I0:/?6`2H0`h0OP0707L42P1i0PP0
M`8507D210270PD0P04207410@1W2@802@3oool00`00o`00oh000?n0000N0?n000030=1@N02P8?00
X23`00X0X23`1`3@D7P00`2h>;@0X23`0:0Pl0070:0Pl0030=1@N03oP000oh0001H0oh00203oool>
003o001;099X<`2FO640WHb30;bf]`2<NW/0QFi/07m^L@1EE7<01Q=J008EL`026X000Q^700TGQ@0]
4Fl0LPiA08`=@@1L2DT09@aM010JO`05;:0012b[00De^005A<h00TCA0011c002D=/00EgZ00A`mP03
OO`01hco00NDo`08V_l019Sm00:Bn`04SoT018Wi00B5n@03O?/00GOk005en`02KoX00F[f005TlP01
F^P00UWU00UDf009CLh01dW<00E5b@03@LD01DK900E3aP04@LH00co1008j^`02=KD00S2]00<]Y002
:Id00bJH00DVVP0699D02B>@00hMPP0G6GD0;1=R05<>B`223S<0W0/S0:465P2321h07aAG00<OLP0;
7Dh00?l000P0oooo3P00o`020:0Pl0030?n0003@D7P0oh000080oh00?@2P8?030?n000<0X23`00<0
0?l00?ooo`3oool02@3oool000X0oooo05P00?l007LQ0`1g1040P@4108`10`270@40P04208@21P27
0@D0R08708L11`230PP0O@4607h12`230a00X18O0:8>6`2I1100U`4:09X12@2X0`d0/@<>0;P63`2k
1Ph0_0L90<L@3P2n1@T0]`890;L23@2f0P`0_@@@0<H;5P392aH0e1DT0=`O<`3Q93T0jBm60?M8FP3k
EEd0nf5Q0?ehK`3jS8T0mifW0?JQ/`3gUJ40mgYi0?]UGP3lD4X0o4A30?a0?@3j>cT0mc0a0?L/;@3c
8bL0k1hU0>DH8@3O5R80eaHV0=0B903:3b40`PhN0;T=8`2c32@0]0LJ0;L4402^0@`0Z`4;0:X12P2Z
0@/0Z08;0:P23@2V0@X0XP4:09h12P2M0@`0X08@0:L85@2[3ad0W0DA08812@1Q0P@0I08506h21P1j
0PD0R@8408<10P1g0@40K@/32@3oool00`00o`00oh000?n0000O0?n000030>QX?03@D7P0d51h0080
d51h0`3oP0030:0Pl100oh0000<0j6Pl0=1@N03oP000603oP0080?ooo`h00?l001l0IYHR09=cF@2E
PWX0[JBR08n0O02<PH80FEem00/MIP015Fh00QIg00@DM@0C3F00@`Y<074<@`1J3Dh0;aI^00lJP`07
8Y<00b:J008UX004;k000Sc300AAf`02DM`00e[U00E^m`04L_`01G_n00Ano@03N?`00GGk00800WOk
02X00WWl005fnP01LoX00Voj009VmP02I?<00VGa009Sk002H^T015gP00EIfP06F]@02EK:00aC``0B
D;/05U2c01aB[`0REJ/0:5JU02eJY@0]Fj@0:eRN02YDV@0XD9809db>02E8R`0P@hL063j7018hR00=
<8H01RJ200@SQ006888031em01lLL@0i5Eh0GA=9068>>00B4e/00b=g010RE000o`080?ooo`h00?l0
00H0X23`0=1@N03oP000d51h0?n0003@D7Po0:0Pl080^3Rd0`2P8?000`00o`00oooo0?ooo`090?oo
o`002P3oool0F000o`00N2P707T4002:0P<0U08209P10`2@0@@0Q@8508821@210PP0P@8707`11P1k
00H0N`8907X33@2S7BX0X`lK09`3402O0`l0XP8;0:d22`2^00T0[`490;<12`2l1`X0cQPD0<TC5@2m
2180_0PD0;T64@2f1100^PLB0;h74@372aH0a@XF0<@=6`2n2QT0bADQ0=`R;P3Y:SD0mCLn0?Pn@P3h
@4H0n3i90?Dg?P3j>S/0nSLd0?/];P3m;2/0nBPZ0>lP8`3Y7Ql0haXM0=dF7@3B41T0c`lH0<L=5`2m
2QL0_0PD0;X74`2d0a00/@8A0:d1302^0P`0/0@?0:P2302V0@`0Y`8;0:T33`2X0@`0YP4;0:D12P2Q
0PX0W`8909h12@2P0@d0XP4A0:434`2J0Q00S`0;08042P1U0P<0H`4307<210260P<0PP4207P10@1_
3P890?ooo`03003o003oP000oh0005D0oh00203oool>003o001;02SJ3@2>JdL0SgEY0:BIU02BU:40
=D=b00/NK@047H0011Mi00h<G@0h2T<0D0L]03X8=`0I4FD02B>B00<VW`018Y/00B2I008SW`01:JL0
0SRi00A>eP05G^T0167^00AVl`02J?L00V?c009Rl`02IOD00V;b005Ol001Gnh00V7]009SkP02Hnd0
16K[00ETi`09H=d04V7C01eWc00^Kl<0?GFi04aj/@1HP:/0IHBW07:;Y01gSZ80NhfM082DWP23UZ40
P9BL08JDV@28UYd0Q9BK08JGW@22TiL0MhR=07N9S`1kRi40LH:706^2Q`1/Q8P0KH:;065gR01@Igl0
@UUl02Y6N@0E=7P02Rak00XZP`0>9h8012J400<[Q00J:5<00?l000P0oooo3P00o`001@1@T7P0^3Rd
0?n0003oP000^3Rd00H0X23`00<0d51h0;Ph]02P8?009@2P8?000`2h>;@0X23`0:0Pl0050:0Pl080
^3Rd00<0d51h0;Ph]02P8?002@2P8?000`2h>;@00?l00?ooo`0:0?ooo`002P3oool0F000o`00NRX;
07l50@2@0@80U`8209d41P2I10L0P@8307H00`1j0P@0O@4507h11`260PX0SP@>09074P2=2180T0@>
09<12P2J0@X0YP8:0;432@2c10/0^PTA0;443@2/10/0Z0@80:<32@2M0@T0V`8:09X12@2L0@`0W`4>
0:@13P2[1140/@LE0;<85P2d21H0^`dI0<XE903P82`0m2le0?]3?P3iB440n4I00?Q5?@3h@cX0nCde
0?Xb;@3k<2`0mRXY0?HX:@3Y7B00i1XQ0=lI8`3@4Q`0bQ4K0<8=5`2g21<0/`HA0:l5402Y0Pd0Y`8=
0:<12`2T0@/0X@4=09/12P2J00T0V`4909l23@2S0@h0X@8>09`22P2>0@D0U`8809h12@2O0@X0W`4>
09h3402G0@/0TP4808/2201e0P<0LP4307L1101m0P<0O04207H20@1_4P490?ooo`03003o003oP000
oh0005D0oh00203oool?003o000`09Z4B@2:K5X0T8ZA03<jM0196EX0JAA@02LBJ00]3E/0D@Pa03`6
<@0@1TD01AMb008TTP02:J800RZV008^[`04=KL00SNn00E2a`02@<@00T;90098d`02CMP00UGR00=F
iP02F>@00USS009Ih`03F=l00eKJ00IJf`0;G]<06FG903=ea@1=PK`0Ihji07bF]@2=X;00Tj:]09NT
Z`2O[Zh0Y;6c0::^[`2P[J/0XJZZ0:F][P2[/k40[[Nf0P2e_Kl0602i_[l0^;bn0;Zm_`2g^[/0^;bi
0;Ni^`2c]kT0/KBg0:nb]@2Y[[00X:RX09nYZP2NZJT0Uj>S08jKW027UiP0KX>805icOP1:I7d084Ak
00PcR@06;X005f/b003o00P0oooo3`00o`000`2P8?00oh000=1@N0060:0Pl0030;Ph]02P8?00X23`
01`0X23`00P0d51h0:0Pl02P8?00d51h0:0Pl02h>;@0d51h0>QX?0H0d51h00<0oh000;Ph]02P8?00
0`2P8?030;Ph]080X23`00@0^3Rd0=1@N03@D7P0^3Rd102P8?000`00o`00oooo0?ooo`090?ooo`00
2P3oool02P00o`00QSHE08D70P2J0`@0U`@508L820295aT0M`8407800P1i0@@207l11`1<08811P29
0@P0RP4:08L11`280PL0T@4709`22`2X0Pd0/0D?09l2302F0@P0T@4908h12@2?00T0S04908X1202;
00P0S`4909P12@2U0`d0[P@@0;H84`302aH0d1HO0=dP9P3X:c80j2li0?=4A`3kKVL0o9N80?V_Y@3j
^[P0n[Ne0?ZUVP3nSG/0oVEI0?mBB`3nB4@0oT910?dj?03k<3D0n2/`0?0W;03V82H0ga`S0=DD7P38
3AP0_0PD0;L54@2e1@l0[@8=0:P13P2Q0@d0W@4909/0202H0@L0UP4909P12`2I0@`0UP490941202E
0@/0V04:09T12P2E0@X0T`4:08h1102;0@80S08508@11@1n0@D0N`4407D10P1c0P80KP<106hH0`T0
oooo00<00?l00?n0003oP0009P3oP0000`3XJ3`0oh000?n000020?n000030>QX?03oP000oh0002L0
oh00203oool?003o001:05?<902<KET0@cmS06LJB`2S2b80[0LF08D7;01K2CD08`U300LBI`025WH0
0R6<004XW@03;jL00c>a008g^P01=[T00cVo008k_`03>[/00SFe004j^`02A<L00e3E00=BeP06E=00
3EW7029T`@12MKX0EX2h06Z;]`26W;@0TZ:^0:Nc]`2c_K`0_<?20;Rn`@39cl/0eMSH0=OKf`3JgMl0
dM;G0<S9c`32_lL0^;6h0:jUZP2PV9/0UXf>08^1Q@24NGl0P75e07eaK`1lK6/0OFeZ07IZI01gJVL0
MVYU07A[I@1fKFP0MVeY07E_J@1jM6h0OgYg08V5P@2DU900Si:@08N?RP21RhL0M8>0069eMP14GF/0
7cYE00n^4`00o`080?ooo`l00?l000L0N5Rd0>QX?02P8?00X23`0=1@N03oP000d51h01X0X23`00@0
^3Rd0>QX?03XJ3`0^3Rd103oP0040=1@N0030>QX?03oP000d51h00<0d51h3P3oP0000`3XJ3`0oh00
0?n000020?n00080d51h00<0J:Pl003o003oool02P3oool000X0oooo05P00?l009A770222`40XPL8
08d30`2D8B<0S1/R07D2101j0@<0N00207h11@1i0080O@4408D120260@T0R0<9094>4`2F2a@0V08?
0:034@2K0@h0SP4908T01P2<0PX0SP0709D01`2H00L0W0480:412P2T0PX0[P<<0<4:503<3aT0fATQ
0>/U;03`:Bl0mc8i0?Lf@P3f>DP0nDIA0?]QIP3jOGd0m8F?0?B4V03aMh/0l6Id0?AHFP3f@T40nCPh
0?`i>@3k=3H0nBdb0?/]<P3f9b`0lB<Z0>PM9`3T6bH0g1DQ0=HD803<3QX0b@`J0<H95P2o1a<0]P<@
0;013P2Z0@`0Y@0909l01`2M0PP0W`8=09/1302G00L0U@4908`22`2C10l0W0<E09@1402@0@X0RP44
08L00P2<0@@0S04508<1101m0@80NP430741001e30<0KQ/32@3oool00`00o`00X23`0?n0000W0?n0
00@0X23`:P3oP0080?ooo`l00?l003L03OT607Y^C`1>7TP0Z14R0;8<4`2a2A40T`HM024?C0035f/0
0Qmm004LP0029YD00bbU008/Z@01:j/00S6c008_]P03=[/00SJi00<j^003>[L00cni00Q5^00PF[H0
BGbm07BG_02N/<80/kg60;W1a02h_l40^l740<;7a`3@eM@0h>7T0=gMh`3Dd=T0`kc90;>/^@2OUjD0
QX6?07IdO@1_Kg<0Jf]_06EWJ`1[K6H0Mg1W07MaI01hLV@0NG5R07U_HP1hKV40Ng=R07Q`GP1kL600
MfmL0080MViK0140MVmL07I^GP1cKU`0K6YI06eZFP1/IeP0J69E06=KD@1UG4h0IV5D06YVF01/Jel0
JfmT05aWG@17FTh07j4H003o00080?ooo`l00?l000@0:<Pl0=1@N02P8?00j6Pl0`3oP00D0:0Pl004
0;Ph]03@D7P0d51h0=1@N080j6Pl00D0oh000>QX?03@D7P0d51h0;Ph]0020:0Pl0030=1@N03XJ3`0
d51h01d0oh0000<0T71h003o003oool02P3oool000X0oooo05P00?l004VV1P259@d0U`H508@20P1l
0`D0QP@807P10`2=0`D0Q@4308H21@2<0PP0QP<707l11P260`d0V14N0:@Q;`2K5R<0U0HD09813@2B
0@X0TP8909@11`2M0PX0ZPD=0;D93`2m4180^0X?0;863`2_1Ph0[0<;0;87402k2A@0^`LB0<495P34
31L0a``H0<d@7P3@41h0ga/V0?4W<@3f=S`0nD960?Q1BP3f>D80n3Pl0?Ld<P3k<R`0nRXS0?/[9`3i
:2L0mR8U0?DP8`3]6Qd0iQDK0=dB6@3C3aP0b``H0<<8502o1Q<0_0@A0;X43`2g0Pd0]P<>0;D23P2b
0P`0[P<;0:T12@2W0@T0YP8=0:@23@2O0P/0V04908D220290a00W`LK09`6602E0Ph0S@4708L01@29
0PD0S08508H10P210P80O`8207D40@1h5PX0CE@12@3oool00`00o`00X23`0>QX?01D0?n000030=1@
N03oool0oooo00H0oooo4000o`00B@22NDl0OQTd0:hJ7@3QQ8L0]d9<0:P:6`1C5e8022B7008XTP02
:YL00RRJ008VX0029Z400RZV008][P02<;<00C6`00<d[P09>JL0:EBW0621]P2J[LD0`lc@0<oDd@3E
em<0g=kL0>3RhP3MgN40d/oI0<K3cP2]Zk@0T8jI085nR021OhP0Q8B;08^?T`27SY00OHB606AaL@1P
Kfl0GVm_05e/K`1OK6d0GVQO06EYG@1cLf@0N79O07MaG@1fKEd0MVmJ07M`F`1jKel0N71O07I_G01e
Ke`0LF]E07=^F@1gLF00MVmP07A]H01aJU/0KVMF06m[F@1[IUD0JF=>06MUD`1GFTX0BDe204M:@01J
GTd0FUm?04UH=`05l`80203oool@003o0080d51h00@0oh000=1@N03XJ3`0oh003`2P8?000`2h>;@0
d51h0?n000030?n000080>QX?03@D7P0d51h0=1@N02h>;@0d51h0:0Pl02h>;@30=1@N240oh0000<0
j6Pl02S8?03oool02P3oool000X0oooo05P00?l001O_1P1d;0X0P`H207X10P1d0@80Q0@607T2102P
1PX0ZPH:0:43202K10T0RP8707l21`260`l0U0PH0:0I9P2J4Ad0T08>08l22P2J0P/0WP870:821`2W
0`T0Y08:0:832@2J0PH0T@4409001P2>0@@0TP4509`22P2T0@`0[`@@0;/53`372Q80dQ0G0>8K803X
8B@0m3<`0?]7@03gEe00m6MP0?ImN@3fQH<0mgei0?Y]HP3lFTd0oE0o0?i;@03nAS/0oChc0?hj<03k
<R/0nBLV0?DR803Z6AX0fQ0H0=0>6@372Q@0a0XC0;`63`2h0`d0]@<=0;412`2/0@P0ZP480:X12P2X
0@/0Z04<0:/23@2X0@/0XP4909/12@2G0P`0W@<C09X24P2H0Pl0S`4:08@21`1_0@<0O`4508H11@28
0@80QP8307T70`1Y4P80;Yd02@3oool00`00o`00D91h0=1@N00Y0?n000030=1@N03oP000oh0002P0
oh0000<0J:Pl0?ooo`3oool01P3oool@003o001906nP9@2D7QX0^EeM0=FV[`3?S9T0Ya4N09/::00g
76l012JE008VV@029i/00RJP008YXP02:9h012^P00X`W@0P@9T0CVFK08NBZ`2Y[[H0`L750<g:c03@
cm40b/W?0;Nb^P2QUIl0QW^4079/LP1YIfd0J6]_06Q`K`1aNWL0JW=^06Y^J01ZJf40JFYM06aZGP1`
K5h0KFaN06YWF`1JGEL0@dm<04AAD01@GE/0GFQM06a/H01cKEh0LfmL07M_G`1eKUX0MFmI07I_FP1g
Ked0MFiJ07A]E`1gKET0MFeK07A^G`1jMVL0MVeP071WE`1^JEP0L6UF06eWE`1ZIE00J6QI05=DCP0c
>cH0;S/a04E>?P1FEdD0FeY301KC30080?oooa000?l000L0T71h0?n0003XJ3`0X23`0;Ph]03oP000
j6Pl00h0X23`00<0d51h0>QX?03@D7P00P2h>;@30=1@N2/0oh0000<0D91h0?ooo`3oool02@3oool0
00X0oooo0P00o`00EP1KIPL0O0T108020P1_0000M`@507820P2U20/0[P<80:h63@2J0@L0QP4607d2
202610l0T@XG09<>602<0`/0S@4909022`2D0@L0V`0709l0102R00D0X00509T0102E0@80V@8309d2
1@2L00D0X@880;L530372aD0e10H0>DI703^7R00n2TX0?hg=@3oB4<0oeYA0?miL@3oWih0ol[?0?oO
jP3og>T0omCN0?nXYP3oMfh0oVEI0?eGB`3nEDH0oTdn0?i3>03n>C00oBdY0?h[9P3k9240k1/O0>4F
8@3E3aT0da0J0<`<5P331Q40`0PD0;P43P2b0PT0[@0;0:d12`2[0@X0ZP490:d12@2/00T0Y@070:80
1@2O0@P0V`4;09L12P2C0@/0S08708H11`1c0PD0O04408@0102;0@@0S08307d70P1]5@003nD12@3o
ool2003o00030=1@N03oP000oh0002@0oh0000<0d51h0:0Pl02P8?000P2P8?000`3@D7P0oh000?n0
000V0?n00003052@N03oool0oooo00H0oooo4@00o`00B01iKA<0aXR80>;3c03O]L<0ZbXl0;865021
44004af5008VV@029i`00RFI00@TT`0J=8P0Ae2506eYR028Nhd0ThN?09bDU`2RWj@0Y9jR08n8RP1i
Kg80Kf=T07IXH022MfX0M79Y065[J01HJFT0DV5R05iRFP1VIeX0MWAW08n=O`2[Zil0a/?30<:n_`2b
Z:@0WHf509J2M02:N6T0OW9Q06mXF01CF4/0CUYB06EXH01gMV/0MG9T07M_GP1dKEP0LVaE07E[E`1f
JEL0MFYF07E/E@1eJeP0MfiJ079ZE`1dK5d0N6eP07Y]GP1fKel0LVaM079[G`1WI5D0EeU@0494>P0o
ASX0A55204aHC`1PIeX0FEQ101OE3PP0oooo4@00o`001`2h>;@0j6Pl0:0Pl02P8?00j6Pl0?n0002h
>;@0302P8?00102h>;@0d51h0=1@N03XJ3`;0?n000030>QX?03@D7P0j6Pl0280oh0000<0D91h0?oo
o`3oool02@3oool000X0oooo0P00o`00EP0h_PT0N@l108`5101g0`<0Ka8B07<61@2X30d0Y`860:P2
2@2S10`0P`8506D1101m0P/0P`L?08@53@250@H0Q00508H11P2=0@H0Y`8;0;D43@2l1@`0aP/@0;X5
302k2`d0`@h@0;d83@2l2140_`lH0<T<4`3F4AP0gQ<I0>LJ7`3[7240n2LX0?db;`3o?SL0o4@o0?a;
C`3iDUd0mEa[0?ITN03cFVd0m5MV0?]IG@3kCT`0oTi:0?a6@P3nACh0o3/d0?hg<03m<B/0nR@R0?DO
703a6QX0iADK0=H?6P3@3A/0b@/H0;`:5P2f1a@0^`HC0;X54@2g0`d0]P8=0;T33P2m1A00_`D>0<D:
4@2k1@h0ZP480:@11`2P0PH0VP4609L01`2C0@H0S@4408X110220@D0P`4408@110270@@0RP<507l:
101_6@000?l02@3oool2003o0003052@N03oP000oh0002@0oh0000<0j6Pl0=1@N03@D7P00P3@D7P0
0`3XJ3`0oh000?n0000V0?n00003003o003oool0oooo00H0oooo4@00o`00B00Ej`L0bI:>0=bc`031
Ig/0]@lM0;X93`2M3RX08aah008TT`049Hh05Rio04I:MP1aI7@0Ofie089bM@28Mg`0QW]n07QaL@1]
HUd0L69D07U]E`1nL5T0P75H089bF`1bJed0EeeI03]<B@0oD4P0GFAH085nL@2ET8D0ViNB09B?S028
Ph<0Qh6208>0O@1oNWH0LG5X05iLD01OEdH0LV1407]SA@1bJ540C5A904]FD01SJ5/0N7Q[085mK01g
LUd0MVeF07Q]EP1eJeH0M6UD07E/F01hL5h0M6eI07I^F`1cK5T0MfaM07UaHP1gLV80MG=W06UXG`1N
FDl0DTm205EEA01GFd/0EV1B05IQE`1UK6@0Hem;01OD2`P0oooo4@00o`00100Xb3`0d51h0:0Pl02h
>;@20?n000030=1@N02P8?00X23`00<0X23`0P3@D7P0103oP000j6Pl0=1@N03XJ3`20?n000040=1@
N03XJ3`0j6Pl0>QX?0T0oh000P3@D7P60?n000030=1@N03oP000oh0001/0oh0000<0D91h0?ooo`3o
ool02@3oool000X0oooo0P00o`00EP0<m`@0P20509L=102D20X0V3a0084=3`2Q10L0Y@870:L21`2a
1Pd0XPD:07d21@1j0@D0O04308821P270@L0RP8708/11P2F0@P0[`@=0;d63P3<2Q80b`TB0;T32`2^
0`X0Y`890:<0202P0PX0W`<;0:d64@2f0`l0_PL@0</:503:10l0k1`O0?XV903i:2<0nbTS0?TW8`3j
:2P0nR/Y0?`^:`3l;b/0nbh/0?DU:03g;Rl0oCLd0?`c<03k<300o2l]0?PY9P3b8B40ka`O0?0N803]
6Qd0hQ@I0<P84`2m1Q@0Y0@@0;0O;@2`9SD0WP<>0:`23@2_0P`0^0<>0<0640392Q80d@hD0=<>4P38
2Q80/@8;0:H2202M0PD0V@4409L1102E0PD0S`8509<21@2@0@@0R`4208H10`210@@0P0<507`A1@16
LP000?l02@3oool2003o000502S8?03oP000oh000?n0003XJ3`0C`3oP0000`2P8?000?l00?ooo`07
0?oooa800?l004L0^YEe0>2L[02e:SH0ba<C0;4@7@1N75L03RF600lZO00e?VT0Fe=Q06aNHP1cIVD0
MVeX071WG`1ZHEH0Kf9A07UZDP25M5P0RWQJ08QeF@20LET0PG5E081aDP1cJE40DU93061SEP1`L680
N7EW07QdJ01hNFd0Q8Mm07EmM`1YMFh0I71Y061ZH@1VJEl0HVMJ061QE@1OG500NFeE085WA`1hGch0
LFeH04M?B01:E4/0HfMG07EcI01oOF`0NW9M07Q]F01eKET0N6aG07I/E01dKET0MFeF07Q^F@1gKU/0
NW1P07QeIP1fM6T0KFeU05aME`1LF4`0JF9C06UUE`1WJEh0G6EL05mWH01SIel0Iea201cF2@080?oo
oa800?l000<0^3Rd0:0Pl03XJ3`00P3oP0001@2h>;@0X23`0:0Pl02h>;@0d51h00H0oh0000P0d51h
0;Ph]02P8?00X23`0?n0003@D7P0X23`0>QX?100oh000P2P8?000`3XJ3`0oh000?n0000H0?n00003
0>QX?01@T7P0oooo00X0oooo000:0?ooo`<00?l005D0RCT>09XG202D10<0TAPE09491P2I0P80X043
0:/2202i1P/0^PH;0;L83@2S10P0TP4509@2202H0@T0V`<;09H2202I0PT0Y0<:0:d32P301`l0a`XA
0<09402`1`/0X04709L01`2C0@L0T@460:<32@2g20d0dAHF0>8O6P3V8ad0jbTR0>L/9P3V=2/0h3D[
0=Xl<@3@@CL0ddPn0=1;@P3@CdD0c4e50<I9@@30BSl0ae160<U?AP2nA3`0^T0l0;Hk=P2a<S00]34`
0;8Y9`2g9B@0^b0P0;LH6P2a4aP0TPlC0:Hb>P2<2A@0W`T?0;883P2l2A00`@TA0<493`341a00c``E
0=4>4`372a80[`<<0:012@2G0@H0U@4709L11`2E0PL0OP4309822@2C0@H0S04208T10@240@<0NP@4
07HJ1`0Lb@000?l000T0oooo0`00o`000`3@D7P0oh000?n0001@0?n00003052@N000o`00oooo00L0
oooo4P00o`00A`1^Wb/0]UeM0;X[;0336R40JBYS01<[P00U=VP0CT]E05eED`1SFeH0IemH06YQC`1_
HDD0MfE6085_CP27Le<0R79C08UdE@27M580Qg=A089cFP1nL5H0PgAG07YZC@1iJdl0NfiF079XDP1I
F4`0@55=04YTI@1AIf`0@EIH051KD`1UIEH0NGQU096AO`2NW8d0TXV107eaH@1oKE@0OfY<07mXAP1g
Hd80Lg1N055HC`1^Kf<0LfiN07A]F01`JED0LfYF07ecH01iJeH0MVA907=YD@1fK5P0OW9T07adJ01h
M6T0KViT05mQFP1KGET0H6AH075_HP1gMVT0LG9U06Q_I01WL6T0IVeS06MRDP1aIbd02_L400P0oooo
4P00o`00102@L7P0oh000?n0003oP0020:0Pl0030;Ph]03XJ3`0oh0000<0oh000P3@D7P60:0Pl005
0>QX?02h>;@0X23`0;Ph]03@D7P01@3oP000103XJ3`0oh000?n0003oP0020>QX?0@0oh000P2P8?00
0`2h>;@0oh000?n000070?n000030>QX?03oP000oh0000h0oh0000<0^3Rd02S8?03oool02P3oool0
00X0oooo0`00o`00D`1MI@80SQD408/20@260@40U0@309/10P2U0@D0/@<70<@=3`301``0bPd@0<L=
3P2X0@@0WP4709H01`2C00L0T@4809D12@2_1a00^0L@0<4;4P332a40_`L=0<8=4@2l3a40[PdA0:8=
3`2T5a@0]bPQ0;d_9@33?C00b4m00<ILC036JUX0a7U]0<>8N`33T8<0`j2A0;fUUP32ZYd0a:jS0<Jd
Z033/jH0_ZnQ0;R]X02_YY/0/:FI0:VPU02OUH/0Vi2509b=Q@2FQ7/0VH1f09MiK`2AK5l0U69B099F
A`24D4@0V7Ea05lX90208a`0UaLC0:PE502]4100_1<D0<H?4P3>3aH0cPhD0<P=502g1`l0X@4;09P1
2`2D0@T0U`4709D11P2=0@H0U@8909011P2=0@<0R@4208<10@1g1P80KQl500800?l02@3oool3003o
00030=1@N03oP000oh000280oh000P3@D7P/0?n000800?l0203ooolB003o000o00Wd0@2CK2d0/cTd
090cGP0S=X@0?D5H05M;@01SFT/0JF1B06eRC01aGd80NF8l089ZAP28Kdh0Qg9D08MgF`25MEH0RGAE
08YeEP27LE00QFm?089`D01oKDd0PFa?08=/BP1oKTh0KfI?05YIB01NIEP0KGYa07n:Q`2AUi40X9nI
09jLV02?T8`0Q8R108b9Q`1kN700P7EU08MgI@2AP6T0SG]P07YR>@1cHC/0KVYG06]SD`1fJ4/0MF=3
07ESBP1aHd/0N71J07acH021LEX0NViH07I/F@1]IE80If5C05QMD@1EGUH0G6IN06acIP1fNfh0O7ic
0080MGM]00H0LWI[06e`IP1_JUX0KFXd01[S2000o`080?oooa800?l000H0:<Pl0=1@N03oP000^3Rd
0:0Pl03@D7P40?n000030=1@N02P8?00X23`00d0X23`1P3oP0020>QX?0H0oh0000P0d51h0;Ph]02P
8?00X23`0>QX?03oP000d51h0;Ph]1@0oh0000<0^3Rd02S8?000o`002`3oool000X0oooo0`00o`00
D`1=V@P0O1X308<20P2?1@<0W0H30:@20P2/10H0/P<40<TA4@301`X0bPd>0<h>3P342Pd0/`L:09h4
2`2I2A80W@/B0:@7402`2100/0T?0:`=3`2X51<0X1`J0:0[9@2S@3@0XDa209mIC02OJUd0XgIZ0::1
MP2PRWh0XI:70:2GS@2SW9@0Yj>N0:b/YP2d]k40`LJn0<g@b03HfM80emO@0=WJe03HfM80dmG>0<cA
bP32bL<0^L2h0;Fm]`2U[Z/0WjZW09RPW`2@V9D0S96<08R>R024RH<0OX1g07emL@1jOG00MGU^07Qd
J01oLF80OfEG08=JC@21BSd0Sd8g09da:P2T8b40[Q/K0;HD5P2^2Q00/`/F0:D54P2H0@d0V04909L2
202D0@L0TP4509411@2B0`@0S04208H20`1i2P@0B6@100800?l02@3oool3003o000307QH]03oP000
oh0001l0oh0000<0j6Pl0?n0003oP000303oP0000`3@D7P0^3Rd0>QX?00N0?n000030=1@N000o`00
0?l000P0oooo5000o`00@`1jFaH0G4Aj03hlE@1VDSD0KUTk07=UB01aHdL0N6Q707e[BP23LE40QWAF
08MfF@2;N5/0RgYK08QfF@26L540RW=@08I]BP25KTD0Q6i407m[B021LE@0QW9?081ZAP1lJT`0NfU<
085^E02BPGH0VXfA07adM`1gLVd0OgIW07M`G`2IUHP0[:BL09B:O@22MF<0QgUV08QoKP2JU900RW]Y
089/B@1`Gch0MVU>07]T?P1kHcd0LUm107IWC01mLV40OW9R07e]E`1aHdX0J5m6061PCP1JHeP0FVUS
06AdK`1cOgP0NH1g07Z0N01jOWP0Mgad07IhKP1aL6<0LVYG07Qa>`0Ki0T00P00o`080?oooa@00?l0
00@0d51h0:0Pl02h>;@0j6Pl0`3@D7PA0:0Pl0<0d51h00<0j6Pl0=1@N03XJ3`02P3oP000103XJ3`0
X23`0;Ph]03XJ3`20:0Pl080d51h4@3oP000102h>;@0:<Pl003o0000o`0;0?ooo`002P3oool3003o
001C01G]1P1g;Pd0Q@`409/8102X1@<0/@P60;861@2m2PX0_@X<0;/52@3830h0ca0@0=0@4P3@4QH0
`1PI0:XO8@2T9bP0V2LW09<k=P2ACDL0SF5E095gJ`2BPGD0T8Ij08f:OP2;Rgh0Shj408j?R02CUI80
UYRH09ZQX02V[j`0/K^g0;c5a03=dmH0fMkP0>CYk03_l?<0m??h0?Kdn03el_H0m?3f0?3^l`3]j_00
j^O/0>CQiP3RgN40h=WL0=??d03>cL`0a<K10;no_030_KT0^kNc0;:b[P2XZ:D0W9jJ09RKU@2@ShX0
RHZ208:6O01mPWX0Mgie07MnLP1iO700MgEY07U`J01mJV00P5I?07m0>`2G=S<0Yb0T0:T?5`2V2100
V@8709021P280@<0S04309420`2=0@<0Q`8207`?100FeP000P00o`090?ooo`<00?l000<0:<Pl0=1@
N03oP0006P3oP0020=1@N0<0oh0000<0j6Pl0?n0003oP000103oP0070=1@N0030>QX?03oP000oh00
01l0oh0000<0D91h003o0000o`00203ooolD003o001202SI3`1K?S@0HDL]07aR>P1nId<0KV96075Y
C`1mJTT0P6]8089^D024M5/0PWAJ08UiGP2;NE`0QW=E08QaCP24K4<0QV]608E/@`24JCh0Q6Tl07US
>025LDl0SWAF08Y_CP25JD<0QF]3089Z@P1lJDd0B4m507Z4PP2KU8P0RGUU08elI02@P6X0T7mY08em
J028NfL0Qge^08Z1M@2<OFd0O6Q907]X@P1kJT`0P7=H08IhG`1oMEl0PGMR07mhIP20MfH0NW=Q079b
H`1]MF/0LWah07N3P@1fPWl0M8>207Z7Q@1nQX@0PXF007eoN@1mNg40NgAU07i[DP1XSbd05>h70`00
o`080?oooa@00?l000<0D91h0?n0003XJ3`00P2P8?001`3@D7P0oh000:0Pl02P8?00^3Rd0>QX?03@
D7P0402P8?001@3@D7P0oh000>QX?03XJ3`0oh000080^3Rd00<0d51h0?n0003oP0000`3oP0000`2h
>;@0X23`0:0Pl0020=1@N140oh0000<0d51h0:0Pl00Xb3`00`00o`0;0?ooo`002P3oool4003o001A
09176P2F7P/0Y`d40;@:1`2k2`X0_0`90;/91`2`0P<0^`D90<`>4@3=4180ba<D0<@I6`2/;2L0U4Do
095SG@2AO7<0RXEi08^9P@27Rgl0Rhf308b<PP2?ShH0TYB>09NKT`2JWYP0XjNR0;2f]@33b<X0`/W=
0<G9c`30aLd0^[c40:ZY/@2PWJT0W9VW09RDW`2DRYP0UXRF09V;V02ER9H0VhnK09B6S`2CQHX0T8:4
09F3PP2?O7/0Sgml0926P@2?R880ThR308j0N`2BPW`0TXIn09b>QP2OTH`0[9fF0;:QV`2bXYT0Zj2E
0:>OTP2IUHX0Ti2608V9OP21QW/0OXAn07IoN01dNG80MWE^07I]I@1oEe<0R3@`094Q7P2J4a@0SPH9
08X110280@40R04208X10@240P40Na4200<00?l02@3oool4003o00030=1@N03oP000oh0001P0oh00
00<0d51h0?n0002P8?003P2P8?000`3@D7P0oh000?n0000R0?n000<00?l0203ooolE003o000o06E2
4P1jGS80NfDm05U>=P1OGe00JVYE07ETA01jHSd0OVM307e/D023MEX0PWEJ08IeF@24KDd0OfY1089]
A025Kd/0QFi608I]@025K3d0QVTj07mT>P20Jdd0QG5D08]eD`22Ich0Nf0`07QT?01jNFD0ZZZU09B7
P02WSG80Zhm_0::=L`2]U7/0T89a08^3M`24Og80OWIV08=dG@28N5/0SGmQ08^0IP2=QWD0RXAc08^4
L@2KTGl0W9N;09nNU@2KW9L0TYJG08nGV@2<UYL0SYRJ08fDU@26TY00PHb;0826Q01mOWX0NgM]07i_
E01hOCP0=lPE00D00?l0203ooolE003o00040;Ph]02P8?00X23`0>QX?080oh0000D0^3Rd0:0Pl02P
8?00X23`0=1@N00A0:0Pl0040>QX?03oP000j6Pl0;Ph]0<0X23`00D0j6Pl0?n0003oP000oh000>QX
?0030:0Pl080oh000P3XJ3`20?n000050>QX?03@D7P0^3Rd0;Ph]02P8?000P3XJ3`0103oP000j6Pl
0?n0003oP0020=1@N003052@N000o`000?l000<00?l02`3oool000X0oooo1000o`00D@1KM`P0Ral4
0:`D1P3350/0bQTA0<HC3@303P`0`14A0<4=3@2n3a00/AlL0:He<02LDd/0T7=[08Z2N@27R7l0QXYo
08Z>Q@2<T8L0SY6809>DS@2DUXl0VY^G09ZLV@2FVYL0VIfK09fPV`2FUI40THj;08n<R@2?RX@0TXf7
09F?Q`2CRh80ThR109B:P02BQWT0U8Ig09B5MP2DQWT0VHf109fAQ`2JS7d0V8Yi09Z<NP2JRgL0VHag
09Z=O02PUXH0XIV909Z>N`2EQ780S7]V08YjHP2:NF40SGYV08]hH`2=Mf80S7AN08igH@2BOFT0VXEc
09b8N@2KS7h0WI:809ZBS02CT8H0R8Un0864O01jOGX0M79_075WH01_FE00Kcdg07LK6P2A4A<0T0H7
08810P240@40P0@106L`1003003o00T0oooo1000o`000`3@D7P0oh000?n0000H0?n000<0d51h1P3o
P000103XJ3`0d51h0=1@N03XJ3`20?n000030>QX?03@D7P0d51h0080d51h00<0j6Pl0=1@N03@D7P0
0P3@D7P00`3XJ3`0d51h0=1@N0040=1@N1D0oh0000@0j6Pl003o0000o`000?l0203ooolD003o000n
013Z0P1gE240QfPj06EK>P16AST0@D/n05iYG01`Kel0MV]D07Y^D`1kKeH0OW1I085dF`23Ke@0PFe:
08A^AP25Kdd0QG=@08QbCP27K440QV/m08M[?@25J3/0OFLo07m]B022LU00SWMD081U>01jHSD0M6I8
081kK@2@Pfl0b:J80<FUR`2cWHP0[I=n08IdI021M6@0OW5K08IiGP26O6<0QgeV09N@N@2@S7P0R89f
0:FTUP2n_[40_kZa0;Zg/`2j^[P0/[Bd0:V]/02TYj/0X:JY09RRY@2CW9d0QHj=07j5Q@1jOWT0O7Q]
081[A`1=^Q/7003o00P0oooo5000o`00101@T7P0X23`0:0Pl03@D7P80?n000030=1@N02P8?00X23`
00h0X23`00<0d51h0?n0003@D7P0102P8?030?n00080d51h0P2P8?000`3@D7P0oh000?n000040?n0
00H0X23`103oP0000`3@D7P0X23`003o0006003o00/0oooo000:0?ooo`@00?l001d0AZD807TX0P2O
7PT0a20E0<DO5P355Q00^14=0:dQ7@2N9ah0Sd`o08I`IP28PGT0QXR108>=Q@2:U8/0SIR?08fCR`2:
SHH0Q8Ej08F4O028R7l0RHIm08f7O@2CSWl0UI:409VERP2HUHP0VIB309B=NP0209^CP00b09R@OP2F
T7/0W9B209^EP`2OUXH0WIB209ZAO@2JT7/0Uhih09fBOP2JSWd0V8Yg09fBO`2MUH80WYR40:2IQP2Q
VHP0Xif=09fEP`2EQVl0SgaT08ekHP2>OF40S7]O08YjH027N5l0QWMN08AcF@24LET0Qg5I08ehG02E
P6L0WHej09F8MP2APFl0SWiZ0921K@2=PW00SXMi08N3NP1mO7D0LG5]06QZI@1RETl0ISlf07@S6`20
2@T0O@8107h:0`1=C@<3003o00T0oooo1000o`000`1@T7P0oh000?n0000D0?n000060=1@N03oP000
oh000?n0003XJ3`0d51h0P2h>;@01@3@D7P0X23`0;Ph]02P8?00d51h00@0X23`00D0^3Rd0=1@N03@
D7P0d51h0;Ph]0020:0Pl080d51h00<0^3Rd0:0Pl02P8?00102P8?001@2h>;@0d51h0=1@N03XJ3`0
oh000080X23`00@0d51h0>QX?03oP000d51h3@3oP000103@D7P00?l0003o0000o`080?oooa@00?l0
03d08=8308MQ:P1nId00HfAB05=LDP1:EDX0BUI;069ZH`1nP7@0NGUW07I`G`1hLeh0OG=N07e`F01o
Ke80Q71A08UeE`29MeT0QWEF08McD027Ld`0R7A=08QdD029MU<0RGQI08MgF@2:NUh0TX9T08inF`23
Ldh0P79F07]_E@2COfH0UXA`0965LP2OTGd0WI5l09^AO@2FSg/0U8mn0:2PSP2^[Yd0]k^/0<77^`38
c<T0alc:0<?8aP35a/H0a<G60;g0`@2h_[h0];bl0:bb]P2RZ:`0TIRL08J<SP1kP7d0NGYd07i_F@1X
TSL09]d?00P00?l0203ooolD003o0003052@N02P8?00X23`00X0oh0000<0j6Pl0;Ph]02P8?003P2P
8?020=1@N0030:0Pl03XJ3`0d51h00<0d51h00<0j6Pl0?n0002P8?000`3XJ3`30?n00080j6Pl0`3@
D7P30:0Pl0060=1@N03oP000oh000>QX?02h>;@0D91h2000o`0;0?ooo`002P3oool4003o001A01G/
1020>`L0U2lI0:hR7P3XKF`0/aXD09XQ5`2HFdh0P6MG075cIP1oPW`0QXR208V=QP2=TX/0RXn708:7
O01nOW<0QhAg08b8M02BRgT0UXio09RBP02FT7h0V99n09:=N@2DSWh0ShYj09JBO`2IU800W9B209^C
P@2GT7l0UY1k09jEP`2MUH<0X9V809fDP`2RV8H0WYN40:>MS02TWHd0Y9f:0::JQ`2PVHH0WIV609nJ
R02QVXX0WYZ=09nLSP2MVHT0THMd08YlI`26NV<0PgiV08B2K024P6l0PX5a08F6N@2>SX00Ti6309:>
O02HTW`0UXih09R=NP2HRgL0Vheh09R;L`2EQV`0RWUQ08IdGP28NFH0THQh08^7N@1iNW00IVQR05iM
F01LBd00Ib0I084?2P1n4`P0:hD100<00?l02@3oool4003o0003052@N02P8?00oh0000l0oh0000D0
X23`0?n0003oP000X23`0=1@N0020:0Pl080oh0000X0d51h0:0Pl02P8?00d51h0?n0002P8?00d51h
0:0Pl03@D7P0oh002@2P8?000`3@D7P0oh000?n000040?n000030:0Pl03@D7P0oh0000@0oh0000@0
d51h0:0Pl02P8?00d51h1@2P8?0;0?n0000408300000o`000?l0003o00P0oooo5000o`004`0TeP@0
SVT`07a`EP1/LfX0IgEY06EbJ01OK6<0GfYU061^J`1hQ800NX9j08>8O@25QWX0PhAd08N4L`28Pfl0
RhE`0929M@2@S7H00P2ET7P09P2?RW40ShU`09FAN02ITg`0V8ii09N=N02CRgD0Thec09:>L`2GT7L0
W9R20:FQS@2g]:<0aLFg0=ODcP3NfMD0h=kJ0>_[i`3fmo<0oOkk0?7clP3UjNX0g>7R0=WKg`3Dfmd0
dmWK0=7If`3>d]P0`/O<0;c4aP2[]KP0WZNZ09FJW027QXH0OGA^07]gC`1EXbX04nd82P00o`080?oo
oa@00?l000<0D91h0:0Pl03@D7P0303oP0000`3XJ3`0d51h0=1@N0080:0Pl080^3Rd1@2P8?020=1@
N0d0oh0000<0d51h0:0Pl03@D7P00`2P8?001@3@D7P0oh000=1@N02@L7P0:<Pl00X00?l02`3oool0
00X0oooo1@00o`00D026VRl0Xf=>0:Da;P33AD@0WC8V08AIB01cJUd0Kg9U07MnL027R7h0QhMm08:1
MP28PWH0R89d08f:MP2FTGh0VYB109ZDP02JTgl0VY>009VBOP2GTWd0VYB109R@O@2JTh40Ui1m09^F
Q02JTh00W9B209fGQ02HUH40ViR509bHQ@2IUH@0ViR609nJR@2QVX/0WYV:09jLS@2MVhd0WIb>09nN
S`2XY9L0YJBF0:JTV02VYIT0Y:FL0:2UV@2PYI/0WZ:H09JLT02HWi80W:JI09bTV@2>UHd0Q8n807V5
PP1iQH<0OHN40828PP27RGd0THal09R?O02OTW`0X91k09fAN@2MTGX0VXag09R9L@2BPV/0Sh1[08j1
KP26OFd0Oga`07AbJ@1PGUD0ET0e05lQ4`1S5PL07Z@10`00o`090?ooo`D00?l000<0X23`0>QX?03o
P0002`3oP0000`3@D7P0^3Rd0:0Pl0020:0Pl0030;Ph]02P8?00X23`0080X23`00D0d51h0;Ph]02h
>;@0X23`0=1@N0050:0Pl0050;Ph]03XJ3`0j6Pl0=1@N03XJ3`00P3oP0030=1@N0L0oh0000<0j6Pl
0=1@N03oP000203oP0000`3@D7P0X23`0:0Pl0040:0Pl0030;Ph]03XJ3`0oh0000L0oh0000@0J:Pl
003o0000o`000?l0203ooolD003o000S00_f0P2AIRX0O7MP07B1N01_OGP0MX5n07^4Q01oS8`0Ohf=
08B@S`24THh0QiFC08ZGU`2NZJH0Z[>]0;Vn]P2k`KL0_l:i0;Zo/`32b;/0`<Jl0<76^P2k`;<0`LJk
0<[?``3;cl<0cLo20=?Gb`3Lh=<0i>GI0>c/i03emNl0o?ch0?koo@3no_d00P3no_h0503oool0o_kn
0?kooP3no_l0oOgm0?gnoP3no_h0oOkm0?;cmP3Tin/0e]WN0<G;d02k`<@0/KBi0:FXZ`2DTXh0QWMU
05^I<`0hbQP02oL43000o`080?oooa@00?l000<0:<Pl0:0Pl03@D7P01@3oP0020>QX?0040?n0003@
D7P0d51h0=1@N0@0oh000P3XJ3`0103oP000j6Pl0=1@N03XJ3`20?n000040=1@N03XJ3`0d51h0>QX
?140oh0000<0j6Pl0;Ph]02P8?000P2P8?001@3@D7P0j6Pl0=1@N01@T7P0:<Pl00`00?l02`3oool0
00X0oooo1P00o`005P2KMdP0SS<U0917=P1hGTh0KFiO07AgIP1kOfd0Ogm^08IoK02;Pfh0UH]h09F9
M02ISW/0UHmi09B?N@2JTh40ViF409jGQP2PVXT0WiZ90:2KS02NVhd20:2MSP0X09jKSP2QWi@0Y:6G
0:VVV`2^ZIl0XZ6F09fOU02NWi<0VI^A09bOU`2KXIX0Xj^T0;:i/@2f_KD0/kZe0:jf/02/]J/0[[B_
0:fd[P2]]Jl0WjNS096HUP29TY40OHR406mmN01aOWH0P8Z009fPUP2][:00WYf?08b7N01jMF@0MFaN
06YSE`1GGE<0JW9[07n0M@2@QgL0WI9m0:6CO080WY5k00d0V8]d09V<M02OTG/0V8]e09F<N`1iM6D0
HV9C06YWE`1nMfD0JF1@05E5<`1@9A@04/<100<00?l02@3oool6003o00030=1@N03oP000oh0000D0
oh0000<0j6Pl0=1@N03@D7P00P3@D7P20:0Pl080d51h0P2h>;@0103@D7P0j6Pl0?n0003@D7P20>QX
?080oh0000L0j6Pl0?n0003oP000oh000=1@N03oP000j6Pl00@0oh0000<0j6Pl0?n0003oP0001@3o
P0000`3@D7P0oh000?n0000=0?n000P0X23`203oP000101@T7P00?l0003o0000o`080?oooaD00?l0
0140C;@D07m/C01dOG80N8R0086?S02:UID0TYjO09>RXP2JZ:L0XZj]0:Jb]02JZ:/0ZkRi0<3;b`3B
g=`0gnKU0>?[jP020>S_kP090>O^k@3Zlo40j?3_0>kcl`3cn?L0loKf0?Gin03io?`0o?gm0080oOkn
01L0oOgm0?clo03lo?d0o?cm0?_ko03hnOT0n_Wi0?SinP3inOT0o?ck0?knoP3moOd0n__k0??dm@3[
k^l0i>SZ0=[Jg030_l00[:BO0:6>O01QXSl0@/8P01K`2P0?003o00P0oooo5@00o`000`1hF;@0d51h
0?n000020?n000030>QX?02P8?00X23`0080^3Rd0P2P8?000`2h>;@0oh000?n0000P0?n000060;Ph
]03oP000^3Rd0=1@N01@T7P0:<Pl3`00o`0;0?ooo`002P3oool6003o001306g1=P1dECX0K5e807I[
FP1nNFH0NgQT06m/F`25Of`0UHYc09R=MP2GSGT0Vi>009N@O@2MU880WIR609^FR02NVY00WIV?0:6M
U02TX9D0Yj:G0:RTU`2WXiH0ZJJJ0:ZWX02b[JP0][:_0<g8b03>al`0][Ff09fRXP29TYH0Ohb=07j<
S`1jRX/0NXb:08RET02HXId0XjVW0:V`[02]/jh0/kNc0<35`@38cLT0a/_90<W>cP34b/P0^Kbk0:n_
[02KWIL0XZ6N0<6k`033^l00]Z^W09f=O02IP6H0VGUJ095`C`1oIdP0IU]706EOC028OFP0WY5j09nB
N@2NT7T0W91i09bAO00209Z?N@0909F;N02;R7d0I6QR03e:?`10BS`0EUA1081dG01iJU<0G40Y00@0
0?l02@3oool6003o000507QH]03XJ3`0oh000?n0003XJ3`00P3oP0000`3XJ3`0X23`0:0Pl0030:0P
l080d51h00<0j6Pl0?n0003oP0002@3oP0001@3XJ3`0d51h0=1@N03@D7P0^3Rd00@0d51h0P3oP000
0`3@D7P0oh000?n000060?n000060=1@N03XJ3`0oh000?n0003@D7P0j6Pl0P3oP0030:0Pl0040;Ph
]03oP000oh000>QX?0L0X23`00<0j6Pl0?n0003oP0000`3oP0000`3XJ3`0oh000?n00004003o00P0
oooo5P00o`009@1IWa`0OFmB07f3N@26TXd0RiZI09VWY`2O[Jh0[k^m0;[5a`33c<h0`/_<0<C=cP3;
eML0en3S0=[QiP3Hh^D0fNCX0=_Sj03Li>P0g>KX0=cVjP3Li^P0f>;T0=cTi`3Ni^P0h^GY0>7Vj@3T
in`0g^CW0>;VjP3TinT0j>c_0>gbl`3bmOH0moOi0?Ogn03emOH00P3fmoP02P3fm_L0n?Oj0?Kem@3]
inT0e/[:0;n/X@2>YfD0G;He02_P5P0<n0HB003o00P0oooo5P00o`001@1hF;@0d51h0?n0003oP000
d51h00<0X23`00<0d51h0?n0003oP0000`3oP0000`3@D7P0j6Pl0?n0000J0?n00080j6Pl00@0d51h
091`N01@T7P0:<Pl4P00o`0;0?ooo`002P3oool6003o001>03o>6P1]FSH0N6Y=089eG@1`Ie80JVAA
06QVEP20OFd0TXQe09bDOP2@RW@0UY1l09VEPP2DRg/0UXil09R=OP2LTH@0WYJ90:2MS`2MUHP0WYJ8
09fGQP2KUH@0VIB209ZBP@2JT840V8j309R>Q@2>R8D0Ngj105iXKP1?GfH0B5UK04mNF`1`NG@0Vj>L
0;g6_P3Fg=P0h^OW0>_]lP3Xj?00gM[R0<2k`P2[YJX0V9:G08=lO`1kKfd0OF]S085ZG024L5/0SG]T
09N4L`2QSh00XHmi0:6?L@2MR6H0UWiM08meD`2GMTh0Sg1:08M^B023KD/0Y9Em09jBN`2OTgl0VXij
09nGPP2KSgX0V8aj09:>PP1ZKF/0AU9>04EDAP1:EDD0D5A607EbF`24MEX0MUdn1000o`090?ooo`H0
0?l000<0D91h0:0Pl02P8?001@3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030?n0003@D7P0oh0000D0
oh0000<0X23`0?n0002P8?004@3oP0001@3@D7P0X23`0:0Pl02P8?00d51h00@0oh0000<0d51h0?n0
003oP0003`2P8?070?n000030=1@N02P8?00d51h00@00?l0203ooolG003o000D02c>3P1eOCX0R85`
0867P02AViP0XJ^Z0:Nc]@2a_<40^L?60;k7b`2la/X0`Lg?0<??dP35cm<0b=7D0<OAe@37d]<0a<o@
0<[Ge`3@f]`20<kHfP0F0=CKgP3Ih><0fn3S0=[Ph`3Mh^D0fnCU0=oUi@3QiNL0iNW[0>W[kP3/kO00
ko3a0?;bm03dloD0l^o`0>KNg@3Jb<<0c;6S09^_K@1Ha3X0A]<U00ch1QH00?l0203ooolG003o0003
052@N02h>;@0j6Pl0080oh0000<0^3Rd0:0Pl02P8?000P2P8?00103@D7P0oh000>QX?03XJ3`20=1@
N1L0oh000P3@D7P00`1XZ3`0D91h02S8?00F003o00/0oooo000:0?ooo`H00?l004h0CZDD07iW@@26
N5H0JV5504e;=P1CDd80GV5D07inL@2?QgD0VY5m08n:M@2CSW/0RX9_09:6LP2DQFl0T85Y09B4KP2E
RWL0TXej09J=O@2ESW`0Uhik09R?NP2GSg/0Vi5m09^CP02LTh00UXil07]mLP1GGEX0@Da804]FC@1f
O700Oge`09N?Q02TWIL0[:BT0:VQY02KTY<0SX6008IfL`2;Mf/0TGUU09InI@2NQVl0XHQ]0:67I@2L
OED0U7M@08YhG@2BQVd0V8]b0::HP`2WWXX0ViB209:>OP24PgD0MW=S08aaC@2PNDT0W7Q708]/A@2R
SgH0WHae09^9L`2CPFX0R7MM08AdF@1oMFH0JFm/04YGEP1:Ee00Cea?05=ND01KIEH0PhYk08V2J`28
KD/4003o00T0oooo1P00o`00101hF;@0X23`0:0Pl03XJ3`50?n000040:0Pl02h>;@0d51h0=1@N0<0
^3Rd00H0d51h0>QX?03@D7P0oh000>QX?02h>;@50:0Pl0030>QX?03oP000oh0000L0oh0000<0j6Pl
0=1@N03@D7P00P3XJ3`40=1@N0<0X23`0P3@D7P30:0Pl080d51h0P3oP0000`2h>;@0X23`0:0Pl005
0:0Pl0030=1@N02h>;@0oh0000H0oh0000<0j6Pl0:0Pl02P8?001000o`080?oooaT00?l002D0=lPD
062O<@2>NUT0UX]j0:FQVP2^/jh0/KRe0;Jn_@2f`L40]l310;o7bP33bld0`l[<0;k;c@30bl`0_lO:
0;k8b@34c/h0alo@0<O?d@39d=40c]CF0=;Gf03FfM/0fmcK0=WLf@3LgMX0f]GF0=C;bP3Fb/H0d/>j
0<fdXP2_]H<0T[UY06O2@`1AcB`09>XB01/00?l0203ooolI003o0003052@N02P8?00d51h0080j6Pl
0`3oP0001@3XJ3`0d51h0=1@N03oP000d51h0080oh0000<0d51h0>QX?03oP000303oP0001@3XJ3`0
d51h0=1@N03@D7P0N5Rd0080D91h6`00o`0;0?ooo`002P3oool6003o001>06Z=8P2<M540LFU=051?
=`1<CcX0Ce0o04mA@`1UIU`0QX9e09>;NP2ITX00V95n09jCOP2ERG80UhM^09V:L028MUd0UX=Y09f>
L`2GRFl0UHM[09J4IP2HPfH0V8AV09V5JP2LSGL0WXmj09b>NP22NfH0KFMB07E/E@1nLUH0TX1T09=m
G@2LPF00Y8YZ09J2IP2EQg80]jZI0<2dY`2PU800U8AW09V8I`2@RW00NGQZ08V3L@2APF<0XHAI09Aj
DP1OFdP0MGQ^08B2MP2LV8h0/J^Q09FAQP1mNFd0KFiN071ZDP2HNdh0YWe80:9kA`2INe40TGaP08eh
G02>Neh0SGmR08AjH`1kMfL0G6EM051OE@1AGU<0FFAG05eVF`1QKF40KGQ]086:P@2_[Ih0S71<1000
o`090?ooo`H00?l00P2P8?000`3@D7P0oh000?n000040?n00080d51h00<0^3Rd0:0Pl02P8?000P2P
8?000`3@D7P0^3Rd0:0Pl0080:0Pl0030;Ph]03XJ3`0d51h0080d51h00<0X23`0=1@N02P8?000P2P
8?00103@D7P0^3Rd0?n0002h>;@30:0Pl0030?n0003XJ3`0d51h0080X23`203oP0000`3XJ3`0X23`
0:0Pl0060:0Pl0030=1@N03oP000oh0000L0oh0000<0d51h0:0Pl000o`000`00o`080?oooa`00?l0
01`07nD;03S96@17^R/0Lim607BRCP2AWFT0ZIF00:bKRP2bXYP0]ZRN0;BZW`2g[Z<0]ZfT0;V/XP2i
Zj40^ZbR0;j^X`2o[Il0^jZH0;nYU@2`ZH00R[QY07fhF01EacX0F<De053<:@0`i1T09N/A8@00o`08
0?oooa`00?l00`1@T7P50=1@N080oh0000<0j6Pl0=1@N03@D7P00P3@D7P00`3oP000d51h0=1@N005
0=1@N0D0D91h8@00o`0;0?ooo`002P3oool6003o001>09id=`2;MUH0O7]Y04mDA01?E4<0CeA505=F
B01CEdX0HfEN07ioM02;RGX0UHik09fEP@2RUX@0TXI^09Z<LP2LS780U89Y09nBM`2RUWd0VXec09Z>
K`2LSG00WHa`09^9K02KRW80Vh]b09n@M`2APFD0SWQE08]`A02YS600]YI^0;6DK@2]Sf/0[8m^0:ZB
L`2RT7X0WY>309ZCPP2JTgl0Ui9k09:AO02UZ9P0WZ>G08J1L`24L5@0[XmT09elCP1hJ4`0J69D081a
G@2BQg40/Z^I09NCQ01mMfX0OW]X08YkG02LOTd0W7];0:R>IP2[W7l0ZIf90:nVUP2XXi<0Rh]n06ea
J01NIV40GFUQ05m[F`1NJEX0HFiO06IbJ01ZMfd0M7mf08B;Q@2JTh@0UgI91000o`090?ooo`H00?l0
0P2P8?090?n000030=1@N02P8?00d51h01P0X23`0P3oP0040:0Pl080oh000`2P8?030?n00080X23`
00<0d51h0?n0003oP000202P8?0<0?n000030:0Pl000o`000?l000800?l0c@3oool000X0oooo1P00
o`00CP1fVBd0RWYL07n0M01PIUX0EEa=055IB@1EGDh0EUe?05QND`1QIel0O7ig096?PP2HU8@0X9Z;
09nIQ`2OUX@0Y9b:0:FMRP2SW8T0Z:6A0:>KRP2PVXL0WYR50:2FQ@2NU7l0VY5n09ZBN`2KTgd0Vhif
09UoG02SQ5H0[iE[0:R>J02aT6X0ZHYV09^3I`2PQFT0TGi[08N6O02XZih0[:fP0;bl/@2`[Z<0THan
085nK028N5`0X8EN0:Z9F@2TOT/0XHAL09B0H`2VSW80]jFC0=[AcP2VWiX0O6iN08=dF02IQ680Yi9]
0;2RQ`2aZ9L0[:NK0:>QVP2:S8L0OH1i06YaIP1VKF@0J6iX06MaJ@1[LfT0K7M]06MeK01/NW@0L7]h
07b5P02=Rh80S7UP07JJ<@@00?l02@3oool6003o00030:0Pl02h>;@0oh0000T0oh000`3@D7P0102h
>;@0X23`0:0Pl02P8?050=1@N080^3Rd2`2P8?00103@D7P0oh000=1@N03@D7P20>QX?080oh0000<0
^3Rd0:0Pl02P8?00102P8?020=1@N0030?n0003XJ3`0d51h00<0X23`00<0d51h0>QX?03oP0003@3o
P0000`3@D7P0X23`003o0003003o0<d0oooo000:0?ooo`H00?l004h0Ij`V09J6J01lOVl0K7=X05mW
G01KHEP0EV1D05YREP1MIeT0GfYK06AWG`1ZK6H0N7Yc08j=QP2NVi<0W9Z@09^IS02MVH/0Wi^=09jI
RP2SWHh0Xij=0:bUU@2^YIT0[:>E0:RST`2^Zi/0Z::C0:VQT@2MSWP0TgYI09b4G@2NR680[hm]0:F8
J`2?O6D0V7eV0:67L`2ZWiP0al;10;6]Z@2WW9P0UhQk08inH`2BO5T0Wh=H0:jDK02/UFl0ZHmX0:ZD
K02XUG00YY=e0:FEO@2XVHH0Z9Mo0:JFOP2dYY<0]jbM0:bXW@2MWYP0SI2;08F9P`1eNW<0MWYc07Ek
LP1lQ7T0PHMo07j6OP1cP7X0L7mh07:1NP1]P7X0NHJ208:8P`2:RH00RGMN08b;?`0Fk`P4003o00T0
oooo1P00o`000`1hF;@0^3Rd0?n0000?0?n000070>QX?03oP000d51h0;Ph]02P8?00oh000>QX?002
0=1@N0030>QX?03@D7P0X23`00D0X23`0`3@D7P30?n00080j6Pl00<0d51h0:0Pl02P8?001P2P8?00
102h>;@0d51h0;Ph]02P8?020=1@N0030>QX?03oP000oh0000h0oh0000<0j6Pl0:0Pl00Xb3`01000
o`3=0?ooo`002P3oool6003o001<02WM3@2ORF@0O7QU075fJ01XLfP0HfiU05iZG`1MIeh0I6iQ06Q`
I01ZLFL0IfaS06Q_IP1YK6@0K6iW0861N`2HUHh0WifC0:VUW@2TXIL0Win>09^IQ`2IU8@0WIJ909VD
Q`2BSh40UY2309ZAQ02JTH40V91h09R<K@2IR640V8EO09R3H@2GQFP0QgMM095lH@2FP6D0VhYd09j?
O@2UU7l0ZIN00;BOP`2hYH80_jj=0;j`T@33^Ih0]J^F0;J]V@2h/9d0]JnK0;J^W`2`Z9L0_JnO0;Z[
VP2gZj00[:JN0::NV@2?SHT0QXZ40825O`22QH<0PXR00825O025Rh80SIF=08F;R01lQh<0MX9n07Z6
PP1mRH80O8Z508J@RP2;SHD0Q7UV08R7?PH00?l02@3oool6003o0003052@N02P8?00oh000140oh00
00<0X23`0=1@N03oP0001P3oP00:0:0Pl0030?n0002P8?00X23`00d0X23`503oP0000`2P8?000?l0
003o0004003o0<d0oooo000:0?ooo`L00?l004/0P94h099oHP1jMfH0NWmf075jM01YM6d0Hg1X06Mc
J@1YMF/0KgQ_06meJ@1dNfh0LWU/079eJ@1`M6`0LgM`07MhL021OgX0QhR208nBRP2LWI@0Y:BH0:VW
WP2]ZZ00/JnS0;2^X@2a[9h0ZJ>B0:n[UP2_ZiD0]:bJ0;J]U`2m]9h0`[^S0<BmY03;`jT0dlVb0=WA
_03NeL80hMW60=_D`03@ak@0cLJd0<g8^038a[D0a/Fe0<;1]031`;H0_;be0;Zj/@2h]Jh0^[2V0<2_
Y02cXi/0XiZD09^FT@2KV9<0UiVD09FIU02CUY<0TiJD08fDS@2;Th`0RY:;08NCS`22Shh0P8n<082?
R026T8/0Ri:<08jDS`2AShL0SGiW07Z??`0Rj0h01P00o`090?ooo`L00?l00P2P8?0F0?n000<0d51h
00@0^3Rd0:0Pl02P8?00d51h1@2P8?0;0=1@N1T0oh0000<0d51h0;Ph]00Xb3`01P00o`3=0?ooo`00
2P3oool7003o000@00_g101U[2H0ShMD09FBP`26Rh@0OhR207=oN01`Ng@0L7]e07B1N@1dOg80O89h
07f2N023Qgh0Qhb407IkLP80MG]c03L0M7ie07EnN@1iOWX0Ngml07Z0P020QhP0RiBD09JOX02MYZ@0
YZjX0:V_Z@2d^K<0^;fe0<K;_`3<d/L0eM_>0>;UfP3[kN@0lo;/0?[im@3lo?T0oOcj0?Wim@3emO00
lO?^0>_/j@3Sin40emoJ0<oIe@3=e]D0`<O90<?7a`33a<80b<Fn0<>n^030_KL0_;fh0;Ff/P2a/jh0
Yj^Y0:6YZ02KXZ80W::Q09BNW02DWYd0T9^I08fIUP2?ViL0T9bI08nIU@2@U8l0UiF;09B5LP1bVcd0
@M4L00P00?l02@3oool7003o000402S8?02P8?00X23`0>QX?1@0oh0000<0d51h0:0Pl03@D7P07P3o
P0000`3@D7P0X23`0:0Pl0020>QX?0030=1@N03XJ3`0oh0000D0oh0000<0j6Pl0:0Pl01@T7P02000
o`3=0?ooo`002P3oool9003o000Q01C_201jY4<0WX]^09^EQ@2>U8T0Qi6907R3OP1oSHL0PHb607n7
Q020RHH0Qi:<08^DSP2;TX`0RXn:08VAR`25T8X0TijJ08jGU029TY00OHN708JBTP2?W9/0SY^K096N
WP2LYjL0Z;6`0;Jo_`2oc<T0bmGC0=GNg@3TjnT0m_Wi0080o_kn00@0oOgn0?knoP3no_d0oOkm0P3n
o_h0703loOd0lOCd0>K/k03Tk>`0hNSY0=GMgP3Ggml0e]cL0=GGe`3@d/l0d=?A0<76a@2j`L40][fm
0:^c/`2W/:l0YZn]0::/Z`2NZJT0WJRX09bVY02GWI`0U9JE08j>R02:P6d0Oha=04Vj9`0[h1<:003o
00T0oooo2@00o`00100Xb3`0X23`0:0Pl03@D7P=0?n000040>QX?03oP000oh000?n00080d51h00<0
X23`0;Ph]02P8?000P3@D7PJ0?n000050;Ph]02P8?00d51h0?n0002h>;@00P2P8?001P2h>;@0d51h
0?n0003oP000j6Pl0;Ph]080D91h2P00o`3=0?ooo`002P3oool;003o000S02gQ4`29RD80WHme09ZJ
S027Rh00SIF=092IUP2?VYP0RIBB08bFT`2?ViT0T9^J092IV02IXYl0VZ>S09nYZ02BW9/0XJ^W08FC
SP2CXYh0YK2]0;Bn_@2g`[l0_LK50;Fl_03:d=80e]kQ0=WQh03PiNL0j>g^0??fm`3oooh0o_kn0?gm
oP3moOd00`3moOh06P3no_h0m_Kg0?;dm@3Zknl0jNk^0>O]k@3Mh^@0h>KX0=gQh`3Gg=`0c=7A0<[?
c`35bLX0`<G70;Fk_02h_Kd0/[Ng0:Z_/@2Z/;40Y:f^09jVY`2IVi`0SXEo08eiJ@2DMU@0E<0V3@00
o`090?ooo`/00?l00`2P8?0;0?n00080X23`00<0d51h0?n0003oP0001P3oP0000`3@D7P0oh000?n0
000H0?n000030=1@N02P8?00d51h00D0X23`0P3oP0020:0Pl0d00?l0c@3oool000X0oooo3@00o`00
?@0lcQ`0H;0k0:68I`2LSGP0WYV?09RITP2GViP0V9jL09ZTX`2;V9L0SING09fXY`2R[Jh0Xjf/07n;
R@2R[Z/0YkB_0:Fb[`2h`L80a<k@0<SAdP3Dg=h0dMSI0=_PhP3Ign40hNKX0>S]kP3]l?40n?Wj0?gm
o@3oool0oOgm0?knoP3mo_h0o_kn0?gmo@3oool0no_k0?Ggm`3_l_<0kO7c0>_`l@3QinP0hNKX0=_P
hP3CfMT0dMWF0<cAd@36bld0aL_:0;g2`P2i_L00];Vi0:n`/@2TXj<0V92:09R9N024T5X0Ek@a02KL
4`0Gl@/03P00o`090?ooo`d00?l000H0D91h07QH]02P8?00d51h0>QX?03oP0020>QX?0@0d51h00<0
X23`0;Ph]03oP0000`3oP0000`3XJ3`0oh000?n0000K0?n000050>QX?03oP000j6Pl0:0Pl02h>;@0
1@3@D7P00`1hF;@0D91h02S8?00>003o0<d0oooo000:0?oooa000?l003H0;N4D052m:@1jXDD0Vi1T
09n;M@2UUhX0Zj6G0:fXX@2^[Z/0[k:a0;6e/P2_]Jl0][bi0;No`02j`L@0_LG80<38b`38c]40cmSJ
0=7Jf`3Hgn00h>WX0>O]k`3/lO40m_Of0?kmo@3oool0o_kn0?kmo@3moOd0o_km0?knoP3no_d0o_kn
0?kno`3koO`0n?Wi0?Cem`3[k_00iNW[0>?Vj@3Lgn80f=cM0=3De@3:c</0_;fk0:n/Z@2[Xi`0YYF6
08JSH@1nZ4h0GKTe02_Q5`0Jl`dB003o00T0oooo4000o`02052@N0030:0Pl02h>;@0d51h0080d51h
00@0oh000>QX?03@D7P0j6Pl0P3oP0020;Ph]080d51h7@3oP0020=1@N0040:0Pl03@D7P0X23`07QH
]080D91h4P00o`3=0?ooo`002P3ooolD003o000N01Sa2`1C_RH0ZH5A0::0GP2YT7X0/Yn>0;^YW@35
]jl0b[fl0<Jo_`2o_;h0a<?50<G6a03=clh0dMOF0=[Qg`3MhN80i^g/0>_^k`3em_H0n__k0?gmo@3n
ood0o_kn0?kmo@3moOd0o_kn0?kooP3no_d0oOkn0P3moOh03@3fm_T0mOKi0>c[k`3Xi^T0gMWM0<k8
b@2m/Z/0/:6E0:RBO`2WR6@0PZE705c7<P0dj1X05`00o`090?oooa@00?l000<0D91h0:0Pl02P8?00
0`2P8?030?n000030=1@N02P8?00d51h01`0oh0000D0d51h0:0Pl02P8?00X23`052@N00G003o0<d0
oooo000:0?oooaP00?l002H0;N4E05g6;@1:b2H0PKA;08j`FP2:/5l0S[QZ09bjO035[iP0a;2O0<Vi
[@3=`KL0d<O20=K=b@3FcL/0hm[H0>_Sh03[hn80jnCT0>cTh`3]i>80l>KT0>kThP3Yg]`0h]GA0=c>
a`3Lbl40e/:f0=2iZ03;/I/0Tl1c08niJ02>]El0OkI>05c8<`0]haT0<nLL01_d3AX00?l02@3ooolH
003o00<0D91h0P2P8?070=1@N0d0oh001`3@D7P00`2h>;@0X23`052@N002052@N00302S8?000o`00
0?l001P00?l0c@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {177.5, 0}} -> {-0.107233, -0.0446483, \
0.0105626, 0.0105626}, {{10.125, 98.1875}, {173.25, 4.1875}} -> {-17.1322, \
-6.21784, 1.692, 1.692}, {{107, 195.062}, {173.25, 4.1875}} -> {-181.044, \
-6.21784, 1.692, 1.692}, {{203.875, 291.938}, {173.25, 4.1875}} -> {-393.575, \
-30.3891, 1.93047, 1.93047}, {{300.75, 388.812}, {173.25, 4.1875}} -> \
{-580.589, -30.3891, 1.93047, 1.93047}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Coke\>", "\<Coke Light\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.00658473 [
[.27273 -0.0125 -14 -12 ]
[.27273 -0.0125 14 0 ]
[.72727 -0.0125 -32 -12 ]
[.72727 -0.0125 32 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14641 -12 -4.5 ]
[-0.0125 .14641 0 4.5 ]
[-0.0125 .2781 -12 -4.5 ]
[-0.0125 .2781 0 4.5 ]
[-0.0125 .4098 -12 -4.5 ]
[-0.0125 .4098 0 4.5 ]
[-0.0125 .54149 -12 -4.5 ]
[-0.0125 .54149 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -14 0 ]
[.27273 .63053 14 12 ]
[.72727 .63053 -32 0 ]
[.72727 .63053 32 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -93 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14641 m
.00625 .14641 L
s
[(20)] -0.0125 .14641 1 0 Mshowa
0 .2781 m
.00625 .2781 L
s
[(40)] -0.0125 .2781 1 0 Mshowa
0 .4098 m
.00625 .4098 L
s
[(60)] -0.0125 .4098 1 0 Mshowa
0 .54149 m
.00625 .54149 L
s
[(80)] -0.0125 .54149 1 0 Mshowa
.125 Mabswid
0 .04764 m
.00375 .04764 L
s
0 .08056 m
.00375 .08056 L
s
0 .11349 m
.00375 .11349 L
s
0 .17933 m
.00375 .17933 L
s
0 .21226 m
.00375 .21226 L
s
0 .24518 m
.00375 .24518 L
s
0 .31103 m
.00375 .31103 L
s
0 .34395 m
.00375 .34395 L
s
0 .37688 m
.00375 .37688 L
s
0 .44272 m
.00375 .44272 L
s
0 .47565 m
.00375 .47565 L
s
0 .50857 m
.00375 .50857 L
s
0 .57442 m
.00375 .57442 L
s
0 .60734 m
.00375 .60734 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14641 m
1 .14641 L
s
.99375 .2781 m
1 .2781 L
s
.99375 .4098 m
1 .4098 L
s
.99375 .54149 m
1 .54149 L
s
.125 Mabswid
.99625 .04764 m
1 .04764 L
s
.99625 .08056 m
1 .08056 L
s
.99625 .11349 m
1 .11349 L
s
.99625 .17933 m
1 .17933 L
s
.99625 .21226 m
1 .21226 L
s
.99625 .24518 m
1 .24518 L
s
.99625 .31103 m
1 .31103 L
s
.99625 .34395 m
1 .34395 L
s
.99625 .37688 m
1 .37688 L
s
.99625 .44272 m
1 .44272 L
s
.99625 .47565 m
1 .47565 L
s
.99625 .50857 m
1 .50857 L
s
.99625 .57442 m
1 .57442 L
s
.99625 .60734 m
1 .60734 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .32784 L
.72727 .32784 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .32784 L
.72727 .32784 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .08458 L
.45455 .08458 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .08458 L
.45455 .08458 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .36006 L
.90909 .36006 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .36006 L
.90909 .36006 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00ooooool/ooooo`?o0000H_ooool00?oooooo;oooool00ol0003ooooo
ooooo`1Oooooo`00Moooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0007Oooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0
0008ooooo`Go000000?oooooo`000?l000000ol00002ooooo`Co000000?oooooo`000?l000001?l0
0002ooooo`;o0000E_ooool007Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`1gooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
Doooool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00003ooooo`Go0000M?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000?ooooo1Ol00008ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000F?oo
ool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000007Cooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Hooooo`00MOoo
ool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o0000
MOooool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o
00002Oooool00ol0003oooooooooo`02ooooo`?o00001?ooool5o`000004ooooool0003o0000o`00
00;ooooo1?l0001Fooooo`00M_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
07cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`00Moooool3o`00
00Oooooo0_l0001oooooo`?o00001oooool2o`00013ooooo0ol00005ooooo`03o`000?oooooooooo
00Oooooo0_l00005ooooo`03o`000?oooooooooo05Kooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000Rooooool00000
G000000Cooooo`008_ooool00`00003oooooooooo`1Looooo`03o`000?oooooooooo09[ooooo00<0
0000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`006_ooool2o`0000Kooooo00<00000
ooooooooool0G?ooool00ol0003oooooooooo`2Jooooo`0300000?oooooooooo05_ooooo00<00000
ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`3o
oooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooo
oooooooo00001Ooooooo000005`000004oooool001Wooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Iooooo`04o`000?oooooooooo
o`0000Gooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`006_ooool2o`00
00Kooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`<000007Oooool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`<000007Oooool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07?ooool0
0ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`0o000001oo
oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0
oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`
oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<0
0000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00k
oj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooo
ooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo
0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo0003
00000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00
??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oo
oooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool0
0`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`00
0`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo
05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo0`00000Mooooo`0300000?ooO`3oogl003co
ogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_o
X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003ooooo
ooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0
oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000l
oomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oooo
ooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
00000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo0003
00000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`004_ooool5o`0000?ooooo0_l00006ooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Cooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Gooooo0`00000Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool06oooool3
000001?ooooo000Eooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1K
ooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Booooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??oo
O`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Cooooo`?o00001?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo
000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooo
oooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo0`00000Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07?ooool00ol00000
0000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo
000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oooooooo
ool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Fooo
ool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3o
ogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00
003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003co
ogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_o
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool3000001gooooo
00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo
000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooooooo
o`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Koooo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?oo
O`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP
8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??oo
O`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3o
ogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00
003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01go
oooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003co
ogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`<000007Oooool00`00003oogl0oomo
000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo
000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooo
oooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
003oogl0oomo000loomo000300000?oooooooooo05_ooooo00<00000oomo0?ooO`00??ooO`000`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo05_o
oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool001Cooooo0ol00003ooooo`;o00001_ooool00`00003ooooo
ooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0
oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
0oooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`004_ooool5o`0000;ooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`004_ooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooo`0000Gooooo0`00000Mooooo`0300000?ooO`3oogl003coogl000<00000oooooooo
ool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool06oooool3000001?ooooo000Cooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo
00001Oooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oooooooo
ool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`005?ooool2o`0000?ooooo00Co0000oooooooooooo
00001Oooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oooooooo
ool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`005Oooool00ol0003oooooooooo`02ooooo`;o0000
1_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP
8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl0
03coogl000<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0Foooool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
ooooooooool0Foooool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool3000001gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0P
l?nP8?00>onP8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`03
00000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`03
00000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00
??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00
>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?oo
O`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`00
0`00003oooooooooo`1Kooooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`1Kooooo`0300000?ooO`3oogl0
03coogl000<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003o
ooooooooo`1Koooood000000?OnP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<0
0000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000l
oomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool3000001gooooo00<00000oomo0?oo
O`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3oX23`03_oX23`00<00000oooooooo
ool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00003oX23`oj0Pl00koj0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo09[ooooo00<00000oj0Pl?nP8?00>onP
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`2Jooooo`0300000?nP8?3o
X23`03_oX23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0V_ooool00`00
003oX23`oj0Pl00koj0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo09[o
oooo00<00000oj0Pl?nP8?00>onP8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooo
ooooo`2Jooooocl000007oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000oooooooo
ool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_oo
ool3000001gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3gooooo`03o`000000
003ooooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`00
0`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003o
ooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooooooo
o`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hoooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?oo
O`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Cooooo`?o0000
1?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?oooooooooo0?Sooooo00<00000ooooooooool04Oooool001;ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`00003o
ogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool001;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo0`00000Moooo
o`0300000?ooO`3oogl003coogl000<00000ooooooooool0m_ooool3000001?ooooo000Booooo`Co
00000oooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Booooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Moooo
o`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aoooo
o`004oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00<00000oooo
ooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000oooo
ooooool04Oooool001Cooooo0_l00004ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`03
00000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl0
03coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003ooooooooo
o`0Aooooo`008_ooool3000001gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3g
ooooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo
0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00
??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`00
0`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003o
ooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooooooo
o`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Roooo
o`<000007Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Oooooo00?o00000000
0?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo0003
00000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oo
oooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool0
0`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo
0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003o
ogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo
000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo0`00000Mooooo`03
00000?ooO`3oogl003coogl000<00000ooooooooool0moooool00ol000000000ooooo`0Booooo`00
8_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0
n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?oo
O`3oogl003coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl0
03coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl0
00<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000
ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`004oooool3o`0000Cooooo0_l00006oooo
o`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hoooo
o`0300000?oooooooooo017ooooo000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`00
0`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Booooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<0
0000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000C
ooooo`?o00000oooool01?l0003oooooooooool00005ooooo`<000007Oooool00`00003oogl0oomo
000loomo000300000?oooooooooo0?Kooooo0`00000Cooooo`004_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000
0?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`004_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00`00003o
ooooooooo`0Mooooo`0300000?ooO`3oogl003coogl000<00000ooooooooool0n?ooool00`00003o
ooooooooo`0Aooooo`004oooool3o`0000Cooooo0_l00006ooooo`0300000?oooooooooo01gooooo
00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003ooooooooo
o`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hoooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?oo
O`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`030000
0?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000oomo0?ooO`00??oo
O`000`00003oooooooooo`3hooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<00000oomo0?ooO`00??ooO`000`00003oooooooooo`3hooooo`0300000?oooooo
oooo017ooooo000Rooooo`<000007Oooool00`00003oogl0oomo000loomo000300000?oooooooooo
0?Oooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`00003o
ogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo
000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo
000300000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo00030000
0?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`00003oogl0oomo000loomo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool07Oooool00`00003oogl0oomo000loomo000300000?oooooo
oooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooooom00000
0?[ooooo00<00000ooooooooool04Oooool002;ooooo0`00003ooooooeOooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool0oooooomHooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo05cooooo00<00000ooooooooool0V_ooool00`00003ooooooooo
o`1Kooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<00000
ooooooooool0V_ooool00`00003oooooooooo`1Kooooo`0300000?oooooooooo017ooooo000Roooo
ool00000G000000Cooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00ooooool/ooooo`?o0000H_ooool00?oooooo;oooool00ol0003ooooo
ooooo`1Oooooo`00Moooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0007Oooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0
0008ooooo`Go000000?oooooo`000?l000000ol00002ooooo`Co000000?oooooo`000?l000001?l0
0002ooooo`;o0000E_ooool007Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`1gooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
Doooool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00003ooooo`Go0000M?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000?ooooo1Ol00008ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000F?oo
ool007Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000007Cooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Hooooo`00MOoo
ool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o0000
MOooool00ol0003oooooooooo`04ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`?o
00002Oooool00ol0003oooooooooo`02ooooo`?o00001?ooool5o`000004ooooool0003o0000o`00
00;ooooo1?l0001Fooooo`00M_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
07cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`00Moooool3o`00
00Oooooo0_l0001oooooo`?o00001oooool2o`00013ooooo0ol00005ooooo`03o`000?oooooooooo
00Oooooo0_l00005ooooo`03o`000?oooooooooo05Kooooo003ooooooi7ooooo003ooooooi7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -9.40778, \
0.00636706, 0.439519}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2d mixture-of-Gaussians classification (GB plane)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(which = {2, 3};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Show[gobj1, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Show[gobj2, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[g1, g2, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{g1, g2}], \ imSize, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.86275 .04706 Mdot
.71765 .09412 Mdot
.4902 .29804 Mdot
.43137 .22745 Mdot
.52549 .36471 Mdot
.72157 .10588 Mdot
.40784 .27843 Mdot
.42745 .31765 Mdot
.72157 .10588 Mdot
.25098 .17255 Mdot
.05098 .03137 Mdot
.48235 .31373 Mdot
.49412 .32157 Mdot
.07451 .0549 Mdot
.24706 .24314 Mdot
.42745 .19216 Mdot
.07059 .01569 Mdot
.08235 .05882 Mdot
.06275 .07059 Mdot
.43137 .2 Mdot
.01569 .00392 Mdot
.08235 .07059 Mdot
.02745 .02745 Mdot
.49804 .32941 Mdot
.01569 0 Mdot
.03529 .04706 Mdot
.02745 .02353 Mdot
.83137 .8 Mdot
.39216 .28235 Mdot
.01569 .02353 Mdot
.16863 .13725 Mdot
.01176 .01569 Mdot
.45882 .25882 Mdot
.01961 .02353 Mdot
.02745 .04314 Mdot
.03529 .03529 Mdot
.80392 .79216 Mdot
.40392 .27059 Mdot
.00784 .02353 Mdot
.0549 .03922 Mdot
.03529 .03137 Mdot
.65098 .61961 Mdot
.06667 .02745 Mdot
.02745 .03529 Mdot
.07059 .0549 Mdot
.04314 .04314 Mdot
.74118 .72157 Mdot
.0549 .02353 Mdot
.01569 .01961 Mdot
.06667 .05098 Mdot
.03922 .03529 Mdot
.82353 .80392 Mdot
.18039 .08627 Mdot
.01569 .02353 Mdot
.06275 .05098 Mdot
.51373 .46275 Mdot
.73725 .71373 Mdot
.84706 .04706 Mdot
.01569 .02353 Mdot
.03922 .03529 Mdot
.7451 .69412 Mdot
.02353 .01961 Mdot
.81176 .82353 Mdot
.01176 .02353 Mdot
.02745 .03529 Mdot
.11765 .09412 Mdot
.87451 .84706 Mdot
.84314 .82353 Mdot
.32941 .06275 Mdot
.01961 .01569 Mdot
.03922 .05098 Mdot
.90196 .89804 Mdot
.06275 .06275 Mdot
.83529 .84706 Mdot
0 0 Mdot
.02353 .02353 Mdot
.07059 .05098 Mdot
.89804 .90588 Mdot
.05882 .07843 Mdot
.81176 .82745 Mdot
.00784 .01176 Mdot
.01569 .02353 Mdot
.76078 .70196 Mdot
.90196 .90588 Mdot
.83137 .83529 Mdot
.62353 .59216 Mdot
0 .01176 Mdot
.02353 .03137 Mdot
.8902 .87843 Mdot
.88235 .88235 Mdot
.68235 .65098 Mdot
.6 .51765 Mdot
.01961 .01961 Mdot
.02745 .03529 Mdot
.8902 .87843 Mdot
.88235 .88627 Mdot
.67059 .62353 Mdot
.54902 .48627 Mdot
.05098 .05098 Mdot
.02353 .02745 Mdot
.89804 .89412 Mdot
.88235 .88235 Mdot
.11373 .10196 Mdot
.75686 .72549 Mdot
.0549 .03529 Mdot
.02353 .02745 Mdot
.8902 .87843 Mdot
.87451 .88627 Mdot
.01961 .03137 Mdot
.81569 .83137 Mdot
.08627 .03922 Mdot
.02353 .02745 Mdot
.86667 .86667 Mdot
.87843 .88235 Mdot
.04314 .04314 Mdot
.81569 .82745 Mdot
.00784 .00784 Mdot
.01176 .01176 Mdot
.75294 .67059 Mdot
.82745 .81961 Mdot
.85098 .84706 Mdot
.78431 .77255 Mdot
.00392 .01176 Mdot
.0549 .04706 Mdot
.07059 .06667 Mdot
.87451 .86275 Mdot
.86667 .86667 Mdot
.75294 .71373 Mdot
.14902 .08235 Mdot
.04314 .03137 Mdot
.02745 .03922 Mdot
.88627 .87843 Mdot
.05882 .06667 Mdot
.06275 .06667 Mdot
.83137 .84314 Mdot
.03529 .03529 Mdot
.05098 .04314 Mdot
.85098 .83137 Mdot
.07451 .07843 Mdot
.8549 .8549 Mdot
.80784 .79608 Mdot
.09412 0 Mdot
.04314 .03529 Mdot
.02745 .03137 Mdot
.78824 .78431 Mdot
.03922 .04314 Mdot
.02745 .03137 Mdot
.77255 .78431 Mdot
.02353 .02353 Mdot
.0549 .03922 Mdot
.84314 .83529 Mdot
.05098 .05882 Mdot
.84706 .84706 Mdot
.70196 .67059 Mdot
.1098 .00784 Mdot
.04314 .04314 Mdot
.02745 .02353 Mdot
.18824 .18824 Mdot
.03529 .03137 Mdot
.03922 .03922 Mdot
.81961 .83137 Mdot
.02353 .03137 Mdot
.05098 .03922 Mdot
.85098 .84706 Mdot
.07059 .05882 Mdot
.82745 .80392 Mdot
.72941 .69412 Mdot
.28627 .18824 Mdot
.03922 .03922 Mdot
.07843 .05882 Mdot
.0902 .0902 Mdot
.03922 .04314 Mdot
.19216 .1451 Mdot
.81569 .82745 Mdot
.00784 .01569 Mdot
.05098 .04314 Mdot
.83922 .83922 Mdot
.07843 .06667 Mdot
.00392 .00784 Mdot
.33725 .32549 Mdot
.47843 .47059 Mdot
.01569 .02353 Mdot
.06275 .04314 Mdot
.41961 .41961 Mdot
.03137 .02353 Mdot
.84314 .84314 Mdot
.62353 .60784 Mdot
.14118 .13333 Mdot
.04706 .04314 Mdot
.74118 .7098 Mdot
.07059 .05882 Mdot
.03922 .03137 Mdot
.15686 .13333 Mdot
.75294 .76471 Mdot
.00392 .01176 Mdot
.05882 .03922 Mdot
.85098 .8549 Mdot
.66275 .60784 Mdot
.00784 .00392 Mdot
.17647 .18431 Mdot
.29412 .27451 Mdot
.01176 .02745 Mdot
.07059 .05098 Mdot
.0549 .05882 Mdot
.84706 .8 Mdot
.61961 .58431 Mdot
.65882 .64314 Mdot
.62745 .63529 Mdot
.04314 .03529 Mdot
.88627 .88627 Mdot
.08235 .03922 Mdot
.04314 .04314 Mdot
.06667 .0549 Mdot
.77255 .78039 Mdot
.00784 .02353 Mdot
.04706 .03529 Mdot
.6549 .62353 Mdot
.88627 .87451 Mdot
.00784 .01569 Mdot
.22353 .21176 Mdot
.45098 .44314 Mdot
.00784 .02745 Mdot
.07059 .0549 Mdot
.05098 .0549 Mdot
.87843 .88235 Mdot
.77647 .75686 Mdot
.66275 .64314 Mdot
.48235 .50196 Mdot
.03922 .04314 Mdot
.88235 .89412 Mdot
.85098 .81569 Mdot
.23922 .19608 Mdot
.03529 .04706 Mdot
.80784 .81961 Mdot
.00392 .00392 Mdot
.04706 .03922 Mdot
.12157 .09412 Mdot
.87843 .86667 Mdot
.02353 .02745 Mdot
.01569 .02745 Mdot
.60784 .61569 Mdot
.00392 .02745 Mdot
.07451 .05882 Mdot
.11373 .09412 Mdot
.87451 .87059 Mdot
.83529 .83137 Mdot
.68627 .67451 Mdot
.75294 .72549 Mdot
.04706 .06275 Mdot
.88235 .8902 Mdot
.88235 .86275 Mdot
.52941 .48627 Mdot
.04706 .04706 Mdot
.83529 .84314 Mdot
.00784 .01961 Mdot
.04706 .04706 Mdot
.07843 .05882 Mdot
.88235 .87843 Mdot
.02353 .02353 Mdot
.04706 .05098 Mdot
.57647 .58039 Mdot
.00784 .01176 Mdot
.0902 .06275 Mdot
.25882 .20784 Mdot
.80784 .77647 Mdot
.81176 .80392 Mdot
.23137 .21961 Mdot
.6549 .27059 Mdot
.03137 .0549 Mdot
.85882 .86667 Mdot
.86667 .86275 Mdot
.23529 .21961 Mdot
0 .00392 Mdot
.82353 .83529 Mdot
.01176 .01569 Mdot
.05882 .07059 Mdot
.05882 .04706 Mdot
.19608 .18431 Mdot
.02353 .02353 Mdot
.02353 .02745 Mdot
.83137 .86667 Mdot
0 0 Mdot
.05098 .03529 Mdot
.17647 .1451 Mdot
.08235 .03922 Mdot
.55686 .47451 Mdot
.03529 .05098 Mdot
.21176 .22353 Mdot
.01176 .01176 Mdot
.87843 .8902 Mdot
.85098 .85098 Mdot
.71373 .68627 Mdot
.03922 .03529 Mdot
.61961 .61176 Mdot
.36863 .35686 Mdot
.03529 .04706 Mdot
.06275 .04314 Mdot
.10588 .08627 Mdot
.03922 .05098 Mdot
0 .01176 Mdot
.81961 .83529 Mdot
.01176 .00784 Mdot
.04314 .04706 Mdot
.08627 .06667 Mdot
.07059 .03922 Mdot
.03137 .02353 Mdot
.02353 .02745 Mdot
.7451 .76863 Mdot
.00392 .00392 Mdot
.5451 .49412 Mdot
.84314 .83922 Mdot
.82353 .82353 Mdot
.80392 .79216 Mdot
.01961 .01569 Mdot
.34118 .24706 Mdot
.00784 .02353 Mdot
.22353 .2 Mdot
.85882 .83922 Mdot
.04706 .0549 Mdot
.00392 .01961 Mdot
.63137 .61569 Mdot
.28627 .31373 Mdot
.03137 .04314 Mdot
.04314 .04314 Mdot
.17255 .11373 Mdot
.02745 .03529 Mdot
.00784 .01176 Mdot
.77255 .80392 Mdot
0 0 Mdot
.06275 .04706 Mdot
.84314 .82745 Mdot
.86275 .85098 Mdot
.50588 .44314 Mdot
.03137 .03529 Mdot
.56471 .6 Mdot
.00392 0 Mdot
.87843 .8902 Mdot
.14118 .11373 Mdot
.04314 .03137 Mdot
.03137 .03137 Mdot
.03529 .04314 Mdot
.73725 .14118 Mdot
0 .01961 Mdot
.61569 .55686 Mdot
.87059 .84706 Mdot
.07451 .07843 Mdot
.00392 .01176 Mdot
.60392 .60392 Mdot
.00392 .00392 Mdot
.03529 .03922 Mdot
.4 .31373 Mdot
.73333 .72157 Mdot
.03137 .02745 Mdot
.00392 .01176 Mdot
.83137 .8549 Mdot
.00392 .00392 Mdot
.68235 .65098 Mdot
.2902 .24706 Mdot
.81569 .77647 Mdot
.81569 .81176 Mdot
.01961 .02353 Mdot
.53333 .5451 Mdot
.00392 .00392 Mdot
.13333 .08235 Mdot
.76471 .71765 Mdot
.8549 .85098 Mdot
.00784 .02353 Mdot
.02745 .03922 Mdot
.36863 .37647 Mdot
.01176 .03137 Mdot
.84314 .83922 Mdot
.82353 .79216 Mdot
.07843 .06275 Mdot
.01569 .03137 Mdot
.6549 .65882 Mdot
.00392 .00392 Mdot
.05098 .04314 Mdot
.80392 .78431 Mdot
.86667 .86275 Mdot
.45098 .36863 Mdot
.00392 .01961 Mdot
.78431 .82745 Mdot
.00392 .00392 Mdot
.8 .80784 Mdot
.84314 .85098 Mdot
.85882 .85882 Mdot
.09412 .06275 Mdot
.01569 .02353 Mdot
.59216 .56078 Mdot
0 0 Mdot
.80784 .81569 Mdot
.78431 .72157 Mdot
.85098 .8549 Mdot
.00784 .01961 Mdot
.0549 .07451 Mdot
.11765 .11765 Mdot
.01176 .03137 Mdot
.04706 .04314 Mdot
.90196 .9098 Mdot
.05098 .0549 Mdot
.00392 .00784 Mdot
.69804 .70588 Mdot
0 0 Mdot
.04706 .03922 Mdot
.08627 .07451 Mdot
.86275 .85882 Mdot
.82745 .82745 Mdot
0 .01961 Mdot
.78431 .82353 Mdot
0 .00392 Mdot
.18824 .18039 Mdot
.08235 .05098 Mdot
.8 .78824 Mdot
.01961 .02745 Mdot
.02353 .03922 Mdot
.68627 .05882 Mdot
.01569 .02745 Mdot
.05882 .04706 Mdot
.8902 .8902 Mdot
.82745 .83137 Mdot
.00784 .01961 Mdot
.04314 .04706 Mdot
0 0 Mdot
.01176 .01961 Mdot
.05098 .0549 Mdot
.77647 .79216 Mdot
.20392 .1451 Mdot
.00392 .01569 Mdot
.78431 .81569 Mdot
.00392 .00392 Mdot
.05882 .03529 Mdot
.08235 .06667 Mdot
.09412 .08235 Mdot
.80392 .81176 Mdot
.00392 .01569 Mdot
.49412 .52549 Mdot
.00392 .01569 Mdot
.03137 .03137 Mdot
.8549 .8549 Mdot
.84314 .81961 Mdot
.00784 .01961 Mdot
.03529 .04706 Mdot
.4 .36471 Mdot
.03922 .03922 Mdot
.04706 .04706 Mdot
.38431 .4 Mdot
.06667 .05882 Mdot
.00392 .01176 Mdot
.55294 .51765 Mdot
0 .00392 Mdot
.00784 .01961 Mdot
.05098 .04314 Mdot
.08235 .07059 Mdot
.82353 .80392 Mdot
.00784 .02353 Mdot
.82745 .85882 Mdot
.00392 .01961 Mdot
.04314 .03529 Mdot
.85098 .8549 Mdot
.27451 .22353 Mdot
.37647 .35686 Mdot
.00784 .02353 Mdot
.4 .39608 Mdot
0 .01176 Mdot
.05098 .04314 Mdot
.23922 .23529 Mdot
.19608 .18824 Mdot
.00392 .01176 Mdot
.04706 .05098 Mdot
.08627 .08627 Mdot
.03137 .04706 Mdot
.03922 .04706 Mdot
.08235 .0549 Mdot
.0549 .0549 Mdot
.00392 .00784 Mdot
.41961 .40392 Mdot
0 .00392 Mdot
.01176 .01569 Mdot
.82745 .80392 Mdot
.07451 .04706 Mdot
.81176 .82353 Mdot
0 .01569 Mdot
.74902 .78039 Mdot
.00392 .01961 Mdot
.0549 .04706 Mdot
.36078 .35686 Mdot
.77255 .75686 Mdot
.22745 .19608 Mdot
.03922 .04706 Mdot
.67843 .07451 Mdot
.36471 .36863 Mdot
.04706 .05098 Mdot
.15294 .12941 Mdot
.42353 .38824 Mdot
.00392 .01176 Mdot
.05882 .06275 Mdot
.00784 .00392 Mdot
.01569 .01961 Mdot
.25882 .21176 Mdot
.04706 .02353 Mdot
.51373 .47059 Mdot
.00392 .01569 Mdot
.63137 .63529 Mdot
.01176 .02745 Mdot
.01961 .02353 Mdot
.77647 .77255 Mdot
.87843 .87843 Mdot
.81961 .82745 Mdot
.00784 .02353 Mdot
.64706 .67843 Mdot
0 .00784 Mdot
.03529 .03922 Mdot
.84706 .85098 Mdot
.84706 .85098 Mdot
.63922 .62353 Mdot
.05098 .05098 Mdot
.70588 .74902 Mdot
.01176 .04314 Mdot
.01569 .01961 Mdot
.08235 .06275 Mdot
.47843 .47059 Mdot
.00392 .01176 Mdot
.16078 .15686 Mdot
.01176 .01569 Mdot
.01569 .02745 Mdot
.83529 .81176 Mdot
.85882 .86275 Mdot
.83529 .83529 Mdot
.00392 .01569 Mdot
.66275 .68235 Mdot
.00392 .00784 Mdot
.01569 .02745 Mdot
.82353 .80392 Mdot
.85882 .8549 Mdot
.81961 .83137 Mdot
.00392 .00784 Mdot
.33333 .3451 Mdot
.00784 .01176 Mdot
.01961 .01961 Mdot
.16863 .11765 Mdot
.84706 .85098 Mdot
.0902 .08627 Mdot
.06667 .07451 Mdot
.7098 .74902 Mdot
.01569 .01961 Mdot
.03137 .04314 Mdot
.86275 .86667 Mdot
.07059 .07059 Mdot
0 .00392 Mdot
.04706 .0549 Mdot
.00392 .00392 Mdot
.01176 .01961 Mdot
.13333 .13333 Mdot
.84706 .8549 Mdot
.76471 .74902 Mdot
.00392 .00784 Mdot
.6902 .7098 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.16078 .17255 Mdot
.22745 .24314 Mdot
.83137 .83529 Mdot
.00392 .00392 Mdot
.51373 .53725 Mdot
.00392 .01176 Mdot
.01569 .02353 Mdot
.79216 .76078 Mdot
.84706 .86275 Mdot
.04314 .03529 Mdot
.02353 .04706 Mdot
.45098 .43137 Mdot
.01176 .02353 Mdot
.02353 .03922 Mdot
.85098 .85098 Mdot
.04314 .03137 Mdot
.00392 .00392 Mdot
.04706 .05882 Mdot
.00392 .00784 Mdot
.01961 .02745 Mdot
.03529 .03922 Mdot
.21176 .23137 Mdot
.04314 .05882 Mdot
.01176 .01569 Mdot
.07451 .0902 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.08235 .0902 Mdot
.65882 .61569 Mdot
.82353 .82353 Mdot
.00392 .00784 Mdot
.76863 .82353 Mdot
.00392 .00392 Mdot
.01569 .02745 Mdot
.83529 .84706 Mdot
.84706 .84706 Mdot
.5098 .5098 Mdot
.70196 .70196 Mdot
.60784 .0549 Mdot
.00784 .01569 Mdot
.03529 .05882 Mdot
.7451 .75686 Mdot
.84706 .84706 Mdot
.00392 .01176 Mdot
.03137 .0549 Mdot
.08235 .1098 Mdot
.01176 .03922 Mdot
.03529 .04314 Mdot
.09804 .06667 Mdot
.07059 .07843 Mdot
0 .00392 Mdot
.03529 .06275 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.06275 .04706 Mdot
.86667 .87451 Mdot
.05882 .05882 Mdot
.00392 .00392 Mdot
.76471 .80392 Mdot
0 0 Mdot
.00784 .02745 Mdot
.84314 .85098 Mdot
.85098 .86275 Mdot
.81569 .81569 Mdot
.00392 .00784 Mdot
.50588 .53333 Mdot
.00784 .02353 Mdot
.01569 .02745 Mdot
.12941 .12941 Mdot
.83529 .84314 Mdot
.01961 .02745 Mdot
0 .01176 Mdot
.36078 .4 Mdot
.00784 .03529 Mdot
.02745 .03137 Mdot
.8549 .83529 Mdot
.07843 .09804 Mdot
.00784 .01569 Mdot
.01569 .04314 Mdot
.00392 0 Mdot
.01176 .03529 Mdot
.51373 .46667 Mdot
.86667 .87059 Mdot
.04314 .06275 Mdot
.00392 .01176 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .01569 Mdot
.84314 .8549 Mdot
.37647 .39608 Mdot
.05882 .06667 Mdot
.00392 .00784 Mdot
.81569 .87059 Mdot
.00784 .01176 Mdot
.00784 .03137 Mdot
.67843 .64706 Mdot
.85098 .85882 Mdot
.81176 .81176 Mdot
0 .01176 Mdot
.41176 .05098 Mdot
.00784 .02353 Mdot
.03529 .04314 Mdot
.8549 .86275 Mdot
.06667 .07059 Mdot
.00392 .01176 Mdot
.01569 .05098 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.06667 .04314 Mdot
.68235 .69804 Mdot
.03137 .05098 Mdot
.00392 .01176 Mdot
.02745 .05098 Mdot
0 .00392 Mdot
.01176 .02745 Mdot
.83137 .83922 Mdot
.61176 .58824 Mdot
.02745 .05882 Mdot
.00392 .01961 Mdot
.79608 .82353 Mdot
.00784 .00784 Mdot
.00392 .02745 Mdot
.84706 .84314 Mdot
.49412 .51373 Mdot
.03529 .05098 Mdot
.00392 .01961 Mdot
.41961 .42353 Mdot
0 .01176 Mdot
.02353 .03529 Mdot
.83922 .85098 Mdot
.06275 .07451 Mdot
.55294 .55686 Mdot
.00392 .02353 Mdot
.00784 .00784 Mdot
.00392 .02353 Mdot
.03922 .03529 Mdot
.14118 .12941 Mdot
.04706 .06667 Mdot
.00392 .01569 Mdot
.00784 .03922 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.69804 .67843 Mdot
.85882 .8549 Mdot
.07059 .08235 Mdot
.00392 .00784 Mdot
.03922 .0549 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.84706 .86275 Mdot
.08627 .10196 Mdot
.03529 .0549 Mdot
0 .00392 Mdot
.52157 .56863 Mdot
.00392 .00784 Mdot
.02353 .02745 Mdot
.14118 .15686 Mdot
.02353 .02353 Mdot
.02745 .04314 Mdot
0 .02353 Mdot
.01176 0 Mdot
.00392 .01569 Mdot
.03922 .04706 Mdot
.08627 .0902 Mdot
.6 .57255 Mdot
.01569 .03529 Mdot
.01961 .03922 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.15294 .13725 Mdot
.25882 .28627 Mdot
.79608 .77647 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.00392 .01176 Mdot
.00392 .01961 Mdot
.56471 .59608 Mdot
.0549 .04706 Mdot
.76471 .75294 Mdot
.00392 .00392 Mdot
.56863 .59216 Mdot
.00392 .00392 Mdot
.02745 .04314 Mdot
.21961 .21569 Mdot
.85098 .85882 Mdot
.06275 .05098 Mdot
.00392 .01176 Mdot
.28235 .26667 Mdot
.00784 .01569 Mdot
.04314 .05882 Mdot
.07059 .08627 Mdot
.83922 .8549 Mdot
.01176 .02745 Mdot
.01176 .03137 Mdot
.00392 0 Mdot
.00392 .01961 Mdot
.04706 .06667 Mdot
.01176 .01176 Mdot
.83137 .84706 Mdot
0 .00784 Mdot
.00392 .03529 Mdot
.00784 .00392 Mdot
.00392 .00784 Mdot
.05882 .04314 Mdot
.87843 .86667 Mdot
.83922 .83922 Mdot
0 .01176 Mdot
.04706 .05098 Mdot
.00392 .00784 Mdot
.00784 .02745 Mdot
.84706 .8549 Mdot
.85882 .87059 Mdot
.81569 .82745 Mdot
0 .00392 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.02353 .03922 Mdot
.10588 .11765 Mdot
.8549 .86667 Mdot
.34902 .32941 Mdot
0 .01176 Mdot
.00392 .00784 Mdot
.00392 .00784 Mdot
.04314 .05098 Mdot
.82745 .81961 Mdot
.83529 .84314 Mdot
0 .01569 Mdot
.00392 .02745 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.54902 .54118 Mdot
.87843 .8902 Mdot
.82353 .84314 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.00392 .00392 Mdot
.00784 .02353 Mdot
.85098 .86275 Mdot
.87451 .87843 Mdot
.83137 .84314 Mdot
.00392 .01569 Mdot
.53725 .54902 Mdot
0 0 Mdot
.01176 .03137 Mdot
.34902 .31765 Mdot
.72941 .76471 Mdot
.81961 .82745 Mdot
.00392 .03137 Mdot
.55294 .03137 Mdot
.00392 .01569 Mdot
.03137 .04706 Mdot
.87059 .88235 Mdot
.11765 .13725 Mdot
.10588 .11373 Mdot
.02353 .05098 Mdot
.01569 .00784 Mdot
.00784 .01961 Mdot
.04314 .06667 Mdot
.8902 .90588 Mdot
.03137 .05098 Mdot
.01176 .01961 Mdot
.00392 .02745 Mdot
0 0 Mdot
.00784 .00392 Mdot
.0549 .07059 Mdot
.86667 .87843 Mdot
.36863 .33725 Mdot
.02353 .03922 Mdot
.00392 .02745 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.50196 .52157 Mdot
.66275 .70588 Mdot
.09412 .1098 Mdot
.00392 .02745 Mdot
0 .01569 Mdot
.01176 .00784 Mdot
.00392 .00784 Mdot
.38039 .36078 Mdot
.11373 .13333 Mdot
.03529 .04706 Mdot
.01176 .04314 Mdot
.56078 .56863 Mdot
0 .00392 Mdot
.00784 .02745 Mdot
.90196 .90588 Mdot
.42745 .41961 Mdot
.64314 .63137 Mdot
.00784 .03137 Mdot
.12549 .11765 Mdot
.00784 .01569 Mdot
.01961 .03529 Mdot
.8902 .89804 Mdot
.87059 .87059 Mdot
.83137 .83137 Mdot
.01961 .03922 Mdot
.56078 .02353 Mdot
.00392 .01569 Mdot
.03137 .0549 Mdot
.88235 .89412 Mdot
.85098 .85882 Mdot
.08235 .09804 Mdot
0 .00392 Mdot
.00784 .00392 Mdot
0 0 Mdot
.03529 .0549 Mdot
.27451 .31765 Mdot
.6902 .7098 Mdot
.00784 .04314 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.0902 .10588 Mdot
.07451 .09412 Mdot
.03922 .0549 Mdot
.00392 .03529 Mdot
.01176 .03529 Mdot
0 .00392 Mdot
.00784 .01569 Mdot
.84706 .85098 Mdot
.14902 .14118 Mdot
.03137 .05098 Mdot
.00784 .04314 Mdot
.00392 .02745 Mdot
0 .00392 Mdot
0 .00784 Mdot
.85882 .87059 Mdot
.86275 .87843 Mdot
.37647 .34902 Mdot
.00392 .03137 Mdot
.23529 .25098 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.87451 .88235 Mdot
.85098 .86275 Mdot
.81961 .84314 Mdot
.00392 .02745 Mdot
.4 .40784 Mdot
.00392 .01176 Mdot
0 .00784 Mdot
.27059 .31373 Mdot
.64706 .6902 Mdot
.07451 .10196 Mdot
.01569 .04314 Mdot
.05098 .01961 Mdot
.00784 .01176 Mdot
.00784 .03922 Mdot
.08235 .08235 Mdot
.05882 .09412 Mdot
.01569 .03922 Mdot
.02353 .04314 Mdot
.03529 0 Mdot
.00392 .01176 Mdot
.01961 .02353 Mdot
.07843 .08627 Mdot
.06667 .09412 Mdot
0 .01961 Mdot
.03922 .06275 Mdot
.00392 .00392 Mdot
0 .02353 Mdot
.83137 .83922 Mdot
.50196 .5098 Mdot
.38824 .38039 Mdot
.00392 .01961 Mdot
.02353 .05098 Mdot
.00392 .00392 Mdot
.02745 .04706 Mdot
.83922 .8549 Mdot
.86667 .87059 Mdot
.85098 .86275 Mdot
.00392 .01961 Mdot
.00392 .03137 Mdot
.00784 .00784 Mdot
.01569 .03137 Mdot
.64314 .67059 Mdot
.7098 .72549 Mdot
.22745 .27451 Mdot
.00784 .03137 Mdot
.02353 .03922 Mdot
.01176 .01176 Mdot
.00392 .01176 Mdot
.06667 .08235 Mdot
.01569 .03137 Mdot
.02353 .03529 Mdot
.00784 .02745 Mdot
.34902 .35294 Mdot
0 0 Mdot
.00392 .01569 Mdot
.07059 .08235 Mdot
.44314 .42353 Mdot
.21961 .20784 Mdot
.00392 .03137 Mdot
.00392 .00392 Mdot
.00392 .00392 Mdot
.03137 .03137 Mdot
.08235 .10196 Mdot
.83529 .84314 Mdot
.01569 .01176 Mdot
.01176 .03137 Mdot
.59216 .01176 Mdot
.01176 .03922 Mdot
.81961 .81961 Mdot
.04706 .07451 Mdot
.82353 .8549 Mdot
.02745 .05882 Mdot
.03529 .04706 Mdot
0 .00392 Mdot
.00784 .03922 Mdot
.82745 .83922 Mdot
.05882 .07451 Mdot
.40784 .41961 Mdot
.00392 .03529 Mdot
.04314 .06667 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18824 .21569 Mdot
.22353 .27059 Mdot
.85098 .85882 Mdot
.00392 .02353 Mdot
.00392 .03529 Mdot
.00392 .00392 Mdot
.00784 .03529 Mdot
.01176 .02353 Mdot
.36471 .41176 Mdot
.84706 .85098 Mdot
.01176 .02745 Mdot
.00784 .01961 Mdot
.01176 .00784 Mdot
.01569 .02745 Mdot
.76471 .73333 Mdot
.12157 .17647 Mdot
.83137 .84314 Mdot
.00392 .02745 Mdot
.38431 .38824 Mdot
.00392 .00392 Mdot
.06275 .06667 Mdot
.86275 .88235 Mdot
.03137 .05098 Mdot
.83922 .84706 Mdot
.01176 .03137 Mdot
0 0 Mdot
.00784 .02353 Mdot
.80784 .79608 Mdot
.8549 .87059 Mdot
.72941 .71765 Mdot
.84314 .8549 Mdot
.01569 .03922 Mdot
.03922 .01569 Mdot
.28627 .3098 Mdot
.81961 .82745 Mdot
.6549 .66667 Mdot
.85098 .8549 Mdot
.67059 .6902 Mdot
.01961 .04314 Mdot
.00392 .00392 Mdot
.03529 .06275 Mdot
.11373 .11765 Mdot
.06667 .07451 Mdot
.85098 .85882 Mdot
.01961 .05098 Mdot
.01961 .03529 Mdot
.1098 .11373 Mdot
.00392 .02745 Mdot
.76078 .75686 Mdot
.06667 .08627 Mdot
.80784 .83922 Mdot
0 .02745 Mdot
.00784 .03529 Mdot
.00392 .00392 Mdot
.01176 .04314 Mdot
.51373 .55294 Mdot
.06275 .07843 Mdot
.1098 .15686 Mdot
.01176 .03529 Mdot
0 .02353 Mdot
.00392 .00784 Mdot
.01961 .03529 Mdot
.05882 .07843 Mdot
.62745 .61961 Mdot
.06667 .09804 Mdot
0 .01569 Mdot
.45098 .46275 Mdot
0 .00392 Mdot
.31765 .30196 Mdot
.36863 .36078 Mdot
.87059 .87843 Mdot
.76471 .76078 Mdot
0 .01569 Mdot
.00392 .00392 Mdot
0 .00784 Mdot
.83137 .83922 Mdot
.86275 .87843 Mdot
.86667 .87059 Mdot
.79608 .81569 Mdot
.00392 .01569 Mdot
0 .00784 Mdot
.00392 .01961 Mdot
.08627 .07059 Mdot
.08627 .10588 Mdot
.40784 .45882 Mdot
.03137 .0549 Mdot
.00392 .01569 Mdot
.12157 .03137 Mdot
.00784 .02353 Mdot
.83137 .83529 Mdot
.06275 .08627 Mdot
.09412 .12157 Mdot
.00784 .02745 Mdot
.00784 .03137 Mdot
.00392 .00392 Mdot
.02353 .04314 Mdot
.07059 .09412 Mdot
.07843 .0902 Mdot
.06275 .07451 Mdot
.00784 .03529 Mdot
.00392 .03137 Mdot
.00392 0 Mdot
.00784 .02353 Mdot
.01176 .01961 Mdot
.3098 .3098 Mdot
.20784 .18824 Mdot
.00392 .02745 Mdot
.00784 .03529 Mdot
0 .00392 Mdot
.01176 .03529 Mdot
.62745 .61176 Mdot
.85882 .86667 Mdot
.84314 .82745 Mdot
.00784 .04314 Mdot
.03137 .03922 Mdot
0 0 Mdot
.01961 .03922 Mdot
.85098 .86275 Mdot
.8549 .87451 Mdot
.7098 .75294 Mdot
.00392 .02353 Mdot
.10196 .11373 Mdot
.00784 .00784 Mdot
.41569 .42353 Mdot
.19608 .24314 Mdot
.14902 .2 Mdot
.06667 .10588 Mdot
0 .00784 Mdot
0 0 Mdot
.00392 .01176 Mdot
.81569 .81961 Mdot
.0549 .06275 Mdot
.05098 .07451 Mdot
.05098 .07843 Mdot
0 .01569 Mdot
0 .00392 Mdot
.00392 .00784 Mdot
.76471 .76863 Mdot
.0549 .06667 Mdot
.12157 .12549 Mdot
0 .00784 Mdot
.00392 .01176 Mdot
.01569 .01569 Mdot
.00392 .01569 Mdot
.82745 .83529 Mdot
.0549 .05882 Mdot
.73725 .73333 Mdot
0 .00784 Mdot
0 .01176 Mdot
.00392 .00392 Mdot
.00392 .01961 Mdot
.80392 .79216 Mdot
.03529 .0549 Mdot
.86667 .87059 Mdot
.00392 .01569 Mdot
.00392 .02353 Mdot
.16078 .03137 Mdot
0 .01961 Mdot
.81176 .83529 Mdot
.0549 .07843 Mdot
.84314 .84706 Mdot
.03137 .05098 Mdot
.00392 .03137 Mdot
.00784 0 Mdot
.00784 .03137 Mdot
.16471 .20392 Mdot
.0549 .07451 Mdot
.74118 .7451 Mdot
.01176 .03529 Mdot
.00392 .02353 Mdot
.00392 0 Mdot
.01176 .03922 Mdot
.03529 .06667 Mdot
.06667 .09804 Mdot
.82353 .82353 Mdot
0 .01569 Mdot
.00392 .03137 Mdot
0 0 Mdot
.01176 .04314 Mdot
.03137 .05882 Mdot
.07059 .11765 Mdot
.85098 .8549 Mdot
0 .01569 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .02745 Mdot
.05098 .07451 Mdot
.05882 .10196 Mdot
.8549 .86275 Mdot
.00392 .02745 Mdot
.07843 .08235 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.04314 .06275 Mdot
.06275 .08235 Mdot
.85882 .86667 Mdot
.00784 .02745 Mdot
0 .00392 Mdot
.00784 .01176 Mdot
.31373 .3098 Mdot
.04706 .05882 Mdot
.24706 .2549 Mdot
.85882 .86667 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
0 .00392 Mdot
.83137 .83137 Mdot
.04706 .06667 Mdot
.86667 .87059 Mdot
.8549 .86275 Mdot
.01176 .03137 Mdot
.01176 .01961 Mdot
.00392 .01176 Mdot
.82353 .82745 Mdot
.05098 .07059 Mdot
.87059 .87451 Mdot
.8549 .86275 Mdot
.01569 .03529 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.80392 .80392 Mdot
.05882 .07059 Mdot
.87059 .87843 Mdot
.8549 .86275 Mdot
.00784 .03137 Mdot
0 0 Mdot
0 .01961 Mdot
.14118 .14118 Mdot
.05098 .06667 Mdot
.87059 .87843 Mdot
.63922 .66275 Mdot
.01176 .04314 Mdot
.12157 .00784 Mdot
.00392 .02745 Mdot
.03922 .0549 Mdot
.07451 .10196 Mdot
.76471 .79608 Mdot
.03922 .06667 Mdot
.02745 .0549 Mdot
.23529 .22353 Mdot
.00392 .03922 Mdot
.05882 .07843 Mdot
.4 .39608 Mdot
.11373 .16471 Mdot
.01176 .02745 Mdot
.05882 .07843 Mdot
.01176 .01176 Mdot
.00784 .03922 Mdot
.0549 .07451 Mdot
.85882 .86275 Mdot
.04706 .07451 Mdot
.01569 .02745 Mdot
.21961 .22745 Mdot
.0549 .05098 Mdot
.00784 .04314 Mdot
.03922 .0549 Mdot
.87451 .8902 Mdot
.07059 .08235 Mdot
.00784 .02745 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.01569 .04706 Mdot
.04706 .06275 Mdot
.86667 .87843 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.33333 .35686 Mdot
0 0 Mdot
.00784 .03529 Mdot
.03922 .0549 Mdot
.87451 .88235 Mdot
.37255 .36078 Mdot
.00392 .01961 Mdot
.30588 .32157 Mdot
.00784 .00392 Mdot
.01176 .03922 Mdot
.04314 .05882 Mdot
.87059 .88235 Mdot
.78431 .76863 Mdot
.00784 .03529 Mdot
.01176 .03529 Mdot
0 0 Mdot
.00784 .03922 Mdot
.04314 .05882 Mdot
.6902 .72549 Mdot
.85098 .85098 Mdot
.01176 .03529 Mdot
.01961 .04706 Mdot
0 0 Mdot
.01961 .04314 Mdot
.03922 .05882 Mdot
.11373 .13725 Mdot
.83529 .84314 Mdot
.00784 .03137 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
.01176 .02745 Mdot
.06275 .09412 Mdot
.72157 .71373 Mdot
.83922 .84706 Mdot
.01961 .03137 Mdot
.00392 .01569 Mdot
0 0 Mdot
.01176 .02745 Mdot
.06275 .06667 Mdot
.86667 .87451 Mdot
.83922 .84706 Mdot
.02353 .03922 Mdot
.01176 .02745 Mdot
.00784 .01569 Mdot
.02353 .05098 Mdot
.72549 .71373 Mdot
.72549 .76078 Mdot
.83922 .84706 Mdot
.01961 .04706 Mdot
.00392 .00784 Mdot
.00392 .01176 Mdot
.03137 .05098 Mdot
.86275 .87059 Mdot
.17255 .21961 Mdot
.84314 .86275 Mdot
.01176 .04314 Mdot
.01176 .01569 Mdot
.00392 .01176 Mdot
.02745 .05882 Mdot
.85882 .87451 Mdot
.01961 .03529 Mdot
.72941 .74902 Mdot
.00784 .03529 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.04314 .07843 Mdot
.86275 .87059 Mdot
.65882 .65882 Mdot
.75294 .76078 Mdot
.00392 .02353 Mdot
.00392 .00784 Mdot
0 .01176 Mdot
.05882 .0902 Mdot
.84706 .87059 Mdot
.87843 .87843 Mdot
.83529 .83922 Mdot
.00784 .02745 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.08627 .12157 Mdot
.30588 .37255 Mdot
.87059 .87451 Mdot
.83922 .84706 Mdot
.01569 .03137 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18039 .20784 Mdot
.06275 .1098 Mdot
.86667 .87451 Mdot
.56078 .59216 Mdot
.16078 .16471 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.34902 .36078 Mdot
.08235 .10588 Mdot
.84706 .8549 Mdot
.67059 .68235 Mdot
.76471 .76863 Mdot
.01569 .00392 Mdot
0 .01176 Mdot
.47059 .49412 Mdot
.11373 .11373 Mdot
.82353 .85098 Mdot
.82745 .83137 Mdot
.5098 .52941 Mdot
.76078 .00392 Mdot
.00392 .01961 Mdot
.24314 .27843 Mdot
.56863 .56863 Mdot
.4902 .5451 Mdot
.82353 .83137 Mdot
.25882 .2902 Mdot
.52157 .00392 Mdot
.00392 .02353 Mdot
.09412 .12941 Mdot
.74118 .73725 Mdot
.14902 .21569 Mdot
.81961 .83137 Mdot
.11373 .14118 Mdot
.51765 .00392 Mdot
.03137 .05098 Mdot
.06667 .09804 Mdot
.86275 .86667 Mdot
.10196 .14902 Mdot
.81961 .83137 Mdot
.12941 .1451 Mdot
.52549 .01569 Mdot
.00784 .02353 Mdot
.01961 .03922 Mdot
.85882 .87451 Mdot
.01569 .03137 Mdot
.82353 .83137 Mdot
.32157 .33725 Mdot
.52157 .01176 Mdot
.00784 .01961 Mdot
.04314 .04314 Mdot
.79608 .83137 Mdot
.0902 .09412 Mdot
.82353 .82745 Mdot
.5451 .56471 Mdot
.52157 .01176 Mdot
.00784 .02745 Mdot
.31373 .3098 Mdot
.43137 .49412 Mdot
.61176 .61176 Mdot
.82353 .82745 Mdot
.67059 .68627 Mdot
.51765 .00392 Mdot
.00392 .02353 Mdot
.62353 .61961 Mdot
.1451 .20392 Mdot
.77647 .77647 Mdot
.81569 .83137 Mdot
.75686 .76078 Mdot
.52549 .00784 Mdot
0 .01961 Mdot
.79608 .79608 Mdot
.0902 .12941 Mdot
.86275 .86667 Mdot
.76471 .79608 Mdot
.75686 .75294 Mdot
.52157 .00784 Mdot
.00392 .03137 Mdot
.81569 .81569 Mdot
.08235 .10196 Mdot
.87843 .88235 Mdot
.53333 .57647 Mdot
.7451 .7451 Mdot
.51373 .00392 Mdot
.00784 .03137 Mdot
.81961 .82353 Mdot
.1098 .11373 Mdot
.89804 .89804 Mdot
.23922 .30196 Mdot
.74118 .74118 Mdot
.50588 .00392 Mdot
.00392 .01961 Mdot
.81961 .82353 Mdot
.17647 .15686 Mdot
.91765 .92157 Mdot
.09412 .16078 Mdot
.76078 .76471 Mdot
.5098 .00784 Mdot
.00392 .02353 Mdot
.83137 .83529 Mdot
.25098 .21569 Mdot
.93333 .93725 Mdot
.04706 .10196 Mdot
.74902 .75294 Mdot
.51765 .00784 Mdot
.00392 .02353 Mdot
.82745 .83529 Mdot
.28627 .25098 Mdot
.94902 .95686 Mdot
.03529 .06667 Mdot
.7098 .71765 Mdot
.51373 .00784 Mdot
.00392 .02745 Mdot
.80784 .82353 Mdot
.2549 .23137 Mdot
.93725 .95294 Mdot
.05098 .06667 Mdot
.73725 .7451 Mdot
.51765 .00784 Mdot
.00392 .02745 Mdot
.71765 .74118 Mdot
.29412 .27451 Mdot
.93725 .95686 Mdot
.05882 .08235 Mdot
.74902 .76471 Mdot
.5098 .00392 Mdot
.00392 .01961 Mdot
.53333 .56471 Mdot
.27451 .25882 Mdot
.89412 .95294 Mdot
.05098 .07843 Mdot
.67059 .6902 Mdot
.5098 .00392 Mdot
.00392 .02353 Mdot
.30196 .3098 Mdot
.21176 .19608 Mdot
.40392 .5098 Mdot
.05882 .07451 Mdot
.59216 .6 Mdot
.5098 0 Mdot
.00784 .03137 Mdot
.18431 .17647 Mdot
.12549 .12941 Mdot
.1451 .21961 Mdot
.06667 .03922 Mdot
.76471 .77647 Mdot
.50196 0 Mdot
.01569 .04706 Mdot
.30196 .29412 Mdot
.07059 .0902 Mdot
.08627 .11373 Mdot
.10588 .00392 Mdot
.79216 .81569 Mdot
.50588 0 Mdot
.01961 .04706 Mdot
.6902 .6902 Mdot
.06275 .07843 Mdot
.08235 .09804 Mdot
.34118 .1098 Mdot
.67059 .70196 Mdot
.01569 .00392 Mdot
.14118 .15686 Mdot
.78824 .79216 Mdot
.08235 .08235 Mdot
.09804 .09804 Mdot
.47843 .18431 Mdot
.72941 .7451 Mdot
.01961 .00392 Mdot
.10588 .13333 Mdot
.82353 .82745 Mdot
.14118 .13333 Mdot
.14118 .11373 Mdot
.28627 .04706 Mdot
.68235 .6902 Mdot
.01961 .00784 Mdot
.03529 .07059 Mdot
.76471 .80392 Mdot
.20784 .18039 Mdot
.22353 .16471 Mdot
.10588 .00392 Mdot
.64706 .65882 Mdot
.01569 .00392 Mdot
.03529 .0549 Mdot
.43529 .50196 Mdot
.28627 .23922 Mdot
.32941 .26275 Mdot
.0549 .01176 Mdot
.60784 .61569 Mdot
.01569 0 Mdot
.39216 .39608 Mdot
.12157 .18824 Mdot
.28627 .25098 Mdot
.60392 .58039 Mdot
.04314 .03529 Mdot
.58824 .6 Mdot
.02745 .00784 Mdot
.25882 .27451 Mdot
.07843 .10588 Mdot
.21569 .18824 Mdot
.63137 .64706 Mdot
.04706 .05882 Mdot
.59608 .61961 Mdot
.01961 .00392 Mdot
.3098 .33725 Mdot
.1098 .1098 Mdot
.24706 .20784 Mdot
.64706 .67059 Mdot
.04314 .07843 Mdot
.58039 .60784 Mdot
.01961 .00392 Mdot
.05098 .07843 Mdot
.14902 .13725 Mdot
.24706 .21569 Mdot
.75294 .77647 Mdot
.03529 .07451 Mdot
.55294 .57647 Mdot
.01569 .00392 Mdot
0 .02745 Mdot
.12549 .12941 Mdot
.15294 .14902 Mdot
.70588 .75294 Mdot
.05098 .07451 Mdot
.56863 .58431 Mdot
.01569 .00392 Mdot
.00784 .03137 Mdot
.10588 .12549 Mdot
.10196 .11373 Mdot
.49804 .55294 Mdot
.06667 .07843 Mdot
.6549 .67451 Mdot
.02353 .00784 Mdot
.00784 .03529 Mdot
.03529 .0549 Mdot
.09804 .1098 Mdot
.58039 .63529 Mdot
.05882 .06667 Mdot
.66667 .69412 Mdot
.01569 .00392 Mdot
.01176 .03922 Mdot
.00392 .00784 Mdot
.1098 .1098 Mdot
.45882 .52941 Mdot
.06275 .07059 Mdot
.60784 .63529 Mdot
.01176 .00392 Mdot
0 .01176 Mdot
.1098 .11765 Mdot
.14118 .13725 Mdot
.21961 .25882 Mdot
.07843 .0902 Mdot
.66667 .68235 Mdot
.01961 0 Mdot
.00784 .01176 Mdot
.33725 .3451 Mdot
.21569 .19216 Mdot
.31373 .31373 Mdot
.26667 .27451 Mdot
.80784 .82353 Mdot
.03137 .00784 Mdot
.00392 .02353 Mdot
.59216 .59608 Mdot
.2902 .2549 Mdot
.31765 .32549 Mdot
.58431 .58824 Mdot
.7451 .78824 Mdot
.01961 0 Mdot
.01961 .03922 Mdot
.76863 .77255 Mdot
.23529 .21569 Mdot
.19216 .21176 Mdot
.77255 .77255 Mdot
.63529 .68627 Mdot
.04314 .00392 Mdot
.10588 .13333 Mdot
.81569 .81961 Mdot
.18039 .15294 Mdot
.12157 .12941 Mdot
.79608 .8 Mdot
.65098 .67451 Mdot
.0549 .00392 Mdot
.01961 .05098 Mdot
.82353 .83529 Mdot
.18824 .16078 Mdot
.18824 .18039 Mdot
.81569 .82353 Mdot
.6902 .71373 Mdot
.06667 .00392 Mdot
0 .02353 Mdot
.37255 .41176 Mdot
.28235 .22745 Mdot
.24706 .23529 Mdot
.81961 .82745 Mdot
.53725 .58431 Mdot
.46275 .06667 Mdot
.00392 .02353 Mdot
.08627 .12549 Mdot
.38431 .32941 Mdot
.27451 .26275 Mdot
.81569 .82353 Mdot
.03529 .09804 Mdot
.12157 .00392 Mdot
.00392 .02745 Mdot
.08627 .0902 Mdot
.33725 .30196 Mdot
.23922 .23529 Mdot
.80784 .82745 Mdot
.02353 .06275 Mdot
.01176 .00392 Mdot
.02353 .04314 Mdot
.11373 .11373 Mdot
.29412 .28627 Mdot
.28627 .04314 Mdot
.0902 .13725 Mdot
.08627 .14118 Mdot
0 0 Mdot
.00784 .02745 Mdot
.07451 .09804 Mdot
.2549 .23529 Mdot
.67843 .05098 Mdot
.60392 .61569 Mdot
.00392 .03137 Mdot
.03922 .03529 Mdot
.01569 .03529 Mdot
.11373 .10588 Mdot
.23529 .2 Mdot
.12549 .01176 Mdot
.83529 .86667 Mdot
.01176 .03922 Mdot
0 0 Mdot
.04314 .0549 Mdot
.16078 .12549 Mdot
.21176 .17647 Mdot
.02353 .0549 Mdot
.87843 .90588 Mdot
.01176 .01961 Mdot
.00784 .00392 Mdot
.07451 .09412 Mdot
.19216 .16863 Mdot
.24706 .2 Mdot
.68235 .67843 Mdot
.90196 .93725 Mdot
.04706 .03529 Mdot
.00392 .01569 Mdot
.04706 .05098 Mdot
.67059 .6902 Mdot
.34902 .27843 Mdot
.80784 .81961 Mdot
.81961 .85882 Mdot
.37647 .00392 Mdot
.00392 .02745 Mdot
.1451 .12549 Mdot
.53725 .49412 Mdot
.46667 .37255 Mdot
.07843 .10588 Mdot
.07843 .10588 Mdot
.01569 .00784 Mdot
.03922 .0549 Mdot
.52157 .45882 Mdot
.57647 .55294 Mdot
.5098 .4549 Mdot
.78039 .81569 Mdot
.05882 .07059 Mdot
.00392 .00784 Mdot
.12549 .1098 Mdot
.73333 .69804 Mdot
.65882 .64706 Mdot
.5098 .47451 Mdot
.77647 .82745 Mdot
.02745 .03922 Mdot
.00392 .00392 Mdot
.34118 .2902 Mdot
.80784 .79608 Mdot
.84706 .85882 Mdot
.4902 .47451 Mdot
.83137 .87451 Mdot
.00392 0 Mdot
.10588 .12549 Mdot
.55294 .52941 Mdot
.89412 .92549 Mdot
.83529 .85098 Mdot
.4902 .47843 Mdot
.74902 .80392 Mdot
.23922 .07059 Mdot
.16471 .15294 Mdot
.64706 .65882 Mdot
.44314 .46275 Mdot
.52941 .53333 Mdot
.47843 .46275 Mdot
.05882 .10196 Mdot
.01569 .01176 Mdot
.52157 .50588 Mdot
.43137 .41569 Mdot
.43922 .38824 Mdot
.56471 .55686 Mdot
.46275 .43922 Mdot
.01569 .00784 Mdot
.01961 .02353 Mdot
.51373 .49804 Mdot
.45098 .37647 Mdot
.47059 .41569 Mdot
.4902 .43137 Mdot
.43922 .44706 Mdot
.67059 .06275 Mdot
.4902 .47843 Mdot
.46667 .39216 Mdot
.46667 .38824 Mdot
.59608 .60392 Mdot
.4902 .42745 Mdot
.06667 .07843 Mdot
.03529 .01961 Mdot
.4 .33725 Mdot
.4549 .36471 Mdot
.47843 .42353 Mdot
.4549 .38039 Mdot
.58039 .5451 Mdot
.08627 .05098 Mdot
.43529 .40392 Mdot
.45098 .36471 Mdot
.44706 .36863 Mdot
.46275 .39216 Mdot
.38431 .28627 Mdot
.45882 .45882 Mdot
.08627 .04314 Mdot
.47059 .37255 Mdot
.44706 .37255 Mdot
.46275 .4 Mdot
.47059 .36471 Mdot
.44706 .34902 Mdot
.09412 .07843 Mdot
.43137 .39216 Mdot
.48235 .38431 Mdot
.45098 .36863 Mdot
.45882 .38431 Mdot
.42353 .32549 Mdot
.45882 .38039 Mdot
.09412 .04314 Mdot
.45098 .34902 Mdot
.47451 .38824 Mdot
.46667 .4 Mdot
.41961 .30588 Mdot
.47059 .38824 Mdot
.38039 .36078 Mdot
.40392 .3451 Mdot
.46667 .38039 Mdot
.45882 .39608 Mdot
.47059 .40392 Mdot
.45098 .3451 Mdot
.40392 .2902 Mdot
.31765 .21569 Mdot
.46667 .36471 Mdot
.46667 .36471 Mdot
.58824 .55294 Mdot
.42353 .3098 Mdot
.45882 .34902 Mdot
.38824 .38824 Mdot
.43922 .33725 Mdot
.45882 .35686 Mdot
.47843 .43529 Mdot
.46275 .43137 Mdot
.46667 .37647 Mdot
.41569 .30588 Mdot
.41176 .29804 Mdot
.45098 .35294 Mdot
.48627 .41569 Mdot
.23922 .21961 Mdot
.42745 .33333 Mdot
.4549 .37255 Mdot
.28627 .21961 Mdot
.47451 .37255 Mdot
.47059 .37255 Mdot
.35294 .32941 Mdot
.42353 .38039 Mdot
.4549 .36471 Mdot
.31765 .24706 Mdot
.38039 .27843 Mdot
.46667 .35294 Mdot
.2902 .25882 Mdot
.58824 .5451 Mdot
.46275 .35294 Mdot
.45098 .3451 Mdot
.27059 .02745 Mdot
.46667 .36078 Mdot
.42745 .36863 Mdot
.55294 .56863 Mdot
.44706 .34902 Mdot
.45098 .3451 Mdot
.2902 .21569 Mdot
.42745 .36078 Mdot
.46275 .35686 Mdot
.40392 .32941 Mdot
.59608 .54118 Mdot
.44314 .34902 Mdot
.43137 .37255 Mdot
.42353 .32941 Mdot
.47059 .34902 Mdot
.30196 .2549 Mdot
.68235 .62353 Mdot
.47451 .38039 Mdot
.46667 .38824 Mdot
.38824 .25098 Mdot
.43922 .35294 Mdot
.32941 .2902 Mdot
.40392 .25882 Mdot
.40392 .2549 Mdot
.46667 .37255 Mdot
.31373 .25098 Mdot
.41569 .35294 Mdot
.49804 .4 Mdot
.44314 .23922 Mdot
.48235 .38431 Mdot
.48627 .37255 Mdot
.41961 .3451 Mdot
.69804 .04706 Mdot
.38431 .27451 Mdot
.40392 .29412 Mdot
.4 .32941 Mdot
.43529 .30196 Mdot
.43922 .33725 Mdot
.40784 .36863 Mdot
.4902 .44706 Mdot
.51373 .41569 Mdot
.47843 .30196 Mdot
.36471 .27451 Mdot
.50196 .38824 Mdot
.39216 .32157 Mdot
.52157 .47843 Mdot
.43529 .33725 Mdot
.47059 .3098 Mdot
.32157 .28627 Mdot
.5098 .38431 Mdot
.37647 .30588 Mdot
.42353 .17255 Mdot
.52549 .48627 Mdot
.41176 .27451 Mdot
.67843 .63529 Mdot
.50196 .39608 Mdot
.37255 .28627 Mdot
.46667 .42745 Mdot
.58431 .57255 Mdot
.43137 .23922 Mdot
.48627 .34902 Mdot
.52941 .38431 Mdot
.41569 .3098 Mdot
.47451 .45882 Mdot
.60784 .6 Mdot
.50196 .44706 Mdot
.61961 .55294 Mdot
.58039 .40784 Mdot
.45098 .33725 Mdot
.49412 .46275 Mdot
.61176 .59216 Mdot
.56471 .52157 Mdot
.47843 .41961 Mdot
.65882 .47843 Mdot
.47843 .38039 Mdot
.52549 .50196 Mdot
.60392 .57647 Mdot
.60392 .57647 Mdot
.48235 .38431 Mdot
.78431 .65098 Mdot
.56471 .50588 Mdot
.53333 .52941 Mdot
.52941 .50196 Mdot
.63137 .60784 Mdot
.49804 .35294 Mdot
.83922 .77647 Mdot
.6 .56078 Mdot
.53725 .52549 Mdot
.65098 .64314 Mdot
.62745 .60784 Mdot
.56078 .50196 Mdot
.88235 .83922 Mdot
.64706 .58824 Mdot
.50588 .47843 Mdot
.68627 .68235 Mdot
.67843 .67843 Mdot
.99608 .95294 Mdot
.83137 .83137 Mdot
.60784 .59216 Mdot
.74902 .12157 Mdot
.6902 .6902 Mdot
.8 .80392 Mdot
.99216 .99216 Mdot
.7098 .6902 Mdot
.54118 .53333 Mdot
.72157 .71373 Mdot
.72157 .71765 Mdot
.99608 .99608 Mdot
.81176 .81176 Mdot
.62745 .61176 Mdot
.69804 .6902 Mdot
.73725 .73725 Mdot
.95294 .96078 Mdot
.92549 .92157 Mdot
.65882 .65098 Mdot
.67059 .64706 Mdot
.76863 .76078 Mdot
.94118 .93725 Mdot
.92549 .92549 Mdot
.61569 .6 Mdot
.76863 .76471 Mdot
.83922 .83922 Mdot
.99216 .99216 Mdot
.84314 .8549 Mdot
.88627 .08235 Mdot
.80392 .8 Mdot
.95294 .95686 Mdot
.94902 .95294 Mdot
.41176 .26275 Mdot
.81569 .81569 Mdot
.9451 .94118 Mdot
.94118 .95294 Mdot
.76078 .15294 Mdot
.82353 .82745 Mdot
.99216 .98824 Mdot
.72549 .72157 Mdot
.6 .52157 Mdot
.97647 .98824 Mdot
.6 .57255 Mdot
.56078 .44706 Mdot
.72549 .70196 Mdot
.81961 .21176 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.78431 .20392 Mdot
.43529 .38824 Mdot
.7451 .68235 Mdot
.75686 .73333 Mdot
.63529 .54118 Mdot
.43137 .44314 Mdot
.72157 .68235 Mdot
.7098 .63529 Mdot
.75294 .75686 Mdot
.79216 .78431 Mdot
.71765 .62745 Mdot
.83137 .80784 Mdot
.81569 .83137 Mdot
.58824 .43922 Mdot
.68627 .61176 Mdot
.63137 .63922 Mdot
.81961 .82745 Mdot
.63529 .51373 Mdot
.66275 .60392 Mdot
.74902 .75294 Mdot
.8 .80784 Mdot
.62353 .48235 Mdot
.76471 .66667 Mdot
.83137 .81569 Mdot
.81176 .83137 Mdot
.83529 .05098 Mdot
.60392 .5451 Mdot
.75686 .72941 Mdot
.30588 .43137 Mdot
.79608 .81176 Mdot
.63922 .51373 Mdot
.80784 .72549 Mdot
.7098 .68627 Mdot
.83137 .83922 Mdot
.74902 .77255 Mdot
.73333 .63137 Mdot
.80784 .72941 Mdot
.73333 .70588 Mdot
.81569 .82353 Mdot
.52549 .21569 Mdot
.73725 .64706 Mdot
.78431 .70588 Mdot
.72941 .72549 Mdot
.81569 .8549 Mdot
.82745 .05098 Mdot
.7451 .66275 Mdot
.79216 .7098 Mdot
.83137 .81176 Mdot
.82353 .84706 Mdot
.49804 .54118 Mdot
.71765 .61961 Mdot
.81569 .81961 Mdot
.80784 .76863 Mdot
.83922 .85098 Mdot
.79608 .81569 Mdot
.65882 .57647 Mdot
.75686 .64706 Mdot
.76471 .71765 Mdot
.73725 .77255 Mdot
.78039 .80392 Mdot
.59216 .45882 Mdot
.7098 .61569 Mdot
.79608 .70196 Mdot
.70588 .67843 Mdot
.83922 .86667 Mdot
.75686 .81569 Mdot
.68627 .6 Mdot
.7451 .63137 Mdot
.75686 .68627 Mdot
.44706 .52157 Mdot
.79216 .82353 Mdot
.56078 .41176 Mdot
.67843 .58431 Mdot
.76471 .67451 Mdot
.84706 .81176 Mdot
.22353 .36863 Mdot
.81176 .83922 Mdot
.61176 .49804 Mdot
.7098 .60392 Mdot
.78824 .69412 Mdot
.77647 .74902 Mdot
.83137 .8549 Mdot
.73725 .76078 Mdot
.58039 .5098 Mdot
.43922 .39608 Mdot
.76078 .66667 Mdot
.77647 .75686 Mdot
.83529 .85882 Mdot
.57647 .62353 Mdot
.14118 .09412 Mdot
.57647 .53333 Mdot
.75294 .6549 Mdot
.76863 .74118 Mdot
.83137 .8549 Mdot
.34902 .4 Mdot
.15294 .08235 Mdot
.62353 .54118 Mdot
.76471 .66667 Mdot
.69412 .67059 Mdot
.83529 .86667 Mdot
.26275 .3451 Mdot
.26275 .17647 Mdot
.61176 .53725 Mdot
.77647 .68235 Mdot
.82353 .8 Mdot
.83922 .84706 Mdot
.79216 .84314 Mdot
.61569 .51373 Mdot
.65882 .53333 Mdot
.76078 .65882 Mdot
.70588 .64314 Mdot
.5098 .48627 Mdot
.77647 .75294 Mdot
.56863 .47843 Mdot
.63922 .5098 Mdot
.7451 .63922 Mdot
.70588 .61569 Mdot
.38824 .37255 Mdot
.81176 .83529 Mdot
.44314 .32941 Mdot
.61961 .50196 Mdot
.41569 .4 Mdot
.74902 .65882 Mdot
.64314 .61569 Mdot
.64314 .66667 Mdot
.46667 .5098 Mdot
.61176 .50196 Mdot
.61569 .43922 Mdot
.76863 .67059 Mdot
.75686 .6902 Mdot
.02745 .03922 Mdot
.72941 .58431 Mdot
.51765 .44314 Mdot
.61569 .46667 Mdot
.72549 .61961 Mdot
.73725 .63529 Mdot
.03529 .04314 Mdot
.80392 .82745 Mdot
.5451 .55686 Mdot
.62353 .51765 Mdot
.61176 .43922 Mdot
.76863 .68235 Mdot
.64314 .57255 Mdot
.01961 .02353 Mdot
.79216 .71765 Mdot
.56471 .48627 Mdot
.6 .44314 Mdot
.7098 .57647 Mdot
.73333 .63137 Mdot
.01961 .03137 Mdot
.24314 .25882 Mdot
.66275 .68235 Mdot
.58824 .47451 Mdot
.61176 .41569 Mdot
.76078 .68627 Mdot
.61961 .57255 Mdot
.01961 .02745 Mdot
.59608 .03922 Mdot
.73333 .75686 Mdot
.59608 .4549 Mdot
.6549 .50196 Mdot
.46667 .43137 Mdot
.02745 .03922 Mdot
.02353 .03137 Mdot
.27843 .31765 Mdot
.59608 .53333 Mdot
.57255 .37647 Mdot
.72157 .60392 Mdot
.71765 .63137 Mdot
.03137 .03922 Mdot
.58824 .59216 Mdot
.82745 .05098 Mdot
.58039 .48235 Mdot
.62745 .43922 Mdot
.49412 .45882 Mdot
.07451 .0549 Mdot
.30588 .40392 Mdot
.59216 .19608 Mdot
.77647 .80784 Mdot
.6 .47843 Mdot
.65098 .49412 Mdot
.5451 .51373 Mdot
.04314 .05098 Mdot
.28627 .42353 Mdot
.62745 .01176 Mdot
.82353 .83529 Mdot
.58824 .43137 Mdot
.68235 .54902 Mdot
.76471 .68235 Mdot
.11373 .11765 Mdot
.28235 .33725 Mdot
.43922 .38824 Mdot
.56863 .51765 Mdot
.56863 .37647 Mdot
.72549 .61961 Mdot
.61176 .57647 Mdot
.23529 .38431 Mdot
.02353 .03922 Mdot
.53725 .52941 Mdot
.58824 .53725 Mdot
.59216 .40392 Mdot
.76078 .66275 Mdot
.06667 .06667 Mdot
.81961 .82353 Mdot
.67059 .71373 Mdot
.7451 .76471 Mdot
.57255 .48627 Mdot
.63529 .47451 Mdot
.78824 .70196 Mdot
.05882 .05098 Mdot
.68235 .68627 Mdot
.59216 .08235 Mdot
.77255 .81569 Mdot
.59608 .50588 Mdot
.66667 .55686 Mdot
.78824 .72157 Mdot
.34118 .39216 Mdot
.74902 .79216 Mdot
.50196 .02353 Mdot
.57647 .60784 Mdot
.58039 .47451 Mdot
.6902 .57647 Mdot
.77647 .69804 Mdot
.24314 .41961 Mdot
.27843 .38431 Mdot
.46275 .03922 Mdot
.66275 .67843 Mdot
.57647 .46275 Mdot
.69804 .59216 Mdot
.76078 .68235 Mdot
.61961 .58039 Mdot
.79608 .85882 Mdot
.39216 .01569 Mdot
.81569 .84706 Mdot
.56471 .42353 Mdot
.70588 .61176 Mdot
.25882 .23137 Mdot
.4549 .41961 Mdot
.81961 .8549 Mdot
.43922 .04706 Mdot
.69412 .70196 Mdot
.56471 .38824 Mdot
.7098 .61176 Mdot
.08235 .06667 Mdot
.04314 .05098 Mdot
.82353 .85882 Mdot
.37255 .02745 Mdot
.55294 .54118 Mdot
.55686 .39608 Mdot
.72157 .62745 Mdot
.0902 .05882 Mdot
.02353 .04314 Mdot
.82745 .8549 Mdot
.30196 .00392 Mdot
.56471 .54118 Mdot
.56863 .41569 Mdot
.71373 .62745 Mdot
.09412 .05882 Mdot
.02353 .03529 Mdot
.74118 .77255 Mdot
.38431 .01569 Mdot
.56863 .54902 Mdot
.56471 .41176 Mdot
.72941 .64314 Mdot
.30196 .29804 Mdot
.02745 .03529 Mdot
.37647 .42353 Mdot
.51765 .05882 Mdot
.58431 .56078 Mdot
.59216 .4549 Mdot
.74118 .65882 Mdot
.27059 .46275 Mdot
.11765 .12549 Mdot
.07843 .12157 Mdot
.49412 .06275 Mdot
.58431 .56078 Mdot
.6 .46275 Mdot
.73725 .6549 Mdot
.30196 .49804 Mdot
.34902 .43922 Mdot
.07059 .11373 Mdot
.44706 .02353 Mdot
.59216 .56078 Mdot
.62353 .49804 Mdot
.72941 .64706 Mdot
.58431 .69804 Mdot
.16863 .36471 Mdot
.06275 .1098 Mdot
.47451 .02353 Mdot
.58431 .55686 Mdot
.62745 .50588 Mdot
.72549 .64706 Mdot
.74118 .76471 Mdot
.41176 .53333 Mdot
.07059 .10196 Mdot
.43137 .00784 Mdot
.58824 .56863 Mdot
.61961 .5098 Mdot
.72941 .63529 Mdot
.7451 .7098 Mdot
.77255 .78039 Mdot
.06667 .08627 Mdot
.47451 .03137 Mdot
.54902 .53333 Mdot
.63529 .52549 Mdot
.72549 .63137 Mdot
.72941 .67451 Mdot
.62353 .58431 Mdot
.07451 .09804 Mdot
.55686 .08235 Mdot
.53333 .51373 Mdot
.62745 .52549 Mdot
.72157 .63529 Mdot
.67451 .62353 Mdot
.50196 .45882 Mdot
.06667 .09804 Mdot
.57255 .15686 Mdot
.52941 .50196 Mdot
.63922 .54118 Mdot
.73333 .64314 Mdot
.26275 .24314 Mdot
.16863 .15294 Mdot
.0549 .08235 Mdot
.58039 .2902 Mdot
.50588 .47843 Mdot
.63922 .55294 Mdot
.72549 .63529 Mdot
.11765 .10196 Mdot
.0549 .06275 Mdot
.0549 .08235 Mdot
.65882 .50588 Mdot
.50588 .48235 Mdot
.63922 .54902 Mdot
.72549 .63137 Mdot
.10196 .08235 Mdot
.05882 .05098 Mdot
.0549 .08235 Mdot
.63529 .58039 Mdot
.49804 .47451 Mdot
.64314 .5451 Mdot
.73333 .65098 Mdot
.1098 .0902 Mdot
.22353 .21176 Mdot
.04706 .06667 Mdot
.5451 .53333 Mdot
.48627 .46667 Mdot
.63529 .54118 Mdot
.73333 .64314 Mdot
.23529 .23529 Mdot
.18824 .25882 Mdot
.03922 .06275 Mdot
.72549 .73725 Mdot
.46275 .46275 Mdot
.61569 .52941 Mdot
.72157 .62745 Mdot
.30588 .3098 Mdot
.31373 .34118 Mdot
.06667 .0902 Mdot
.56863 .60784 Mdot
.69412 .70196 Mdot
.61569 .54118 Mdot
.7098 .61569 Mdot
.47059 .50196 Mdot
.04706 .04314 Mdot
.31373 .34118 Mdot
.41961 .50196 Mdot
.76471 .78039 Mdot
.62745 .56078 Mdot
.71765 .63137 Mdot
.47059 .56863 Mdot
.04706 .05882 Mdot
.35686 .42745 Mdot
.73333 .81176 Mdot
.76078 .78431 Mdot
.65098 .58039 Mdot
.70196 .60784 Mdot
.3098 .45882 Mdot
.07843 .07843 Mdot
.4549 .52549 Mdot
.47451 .58039 Mdot
.65098 .66667 Mdot
.64706 .58431 Mdot
.70196 .61961 Mdot
.66275 .70588 Mdot
.17647 .16471 Mdot
.63137 .6902 Mdot
.79608 .87451 Mdot
.51765 .52549 Mdot
.6549 .59216 Mdot
.6902 .61569 Mdot
.77255 .72549 Mdot
.27451 .25882 Mdot
.41961 .49412 Mdot
.79216 .84706 Mdot
.5098 .51765 Mdot
.64314 .6 Mdot
.68235 .59608 Mdot
.78039 .7098 Mdot
.3098 .30588 Mdot
.03922 .07843 Mdot
.77647 .83137 Mdot
.45882 .47059 Mdot
.6549 .60784 Mdot
.67451 .58824 Mdot
.78039 .71373 Mdot
.30196 .30196 Mdot
.01176 .02745 Mdot
.80392 .84314 Mdot
.42353 .45098 Mdot
.65098 .61569 Mdot
.67843 .58824 Mdot
.78431 .72157 Mdot
.30196 .30588 Mdot
.01569 .03529 Mdot
.79216 .83922 Mdot
.46275 .50588 Mdot
.63922 .60784 Mdot
.66275 .57647 Mdot
.78824 .72157 Mdot
.62353 .6 Mdot
.38824 .42353 Mdot
.79608 .85098 Mdot
.6549 .7098 Mdot
.63137 .59216 Mdot
.6549 .56078 Mdot
.76078 .69412 Mdot
.68627 .64706 Mdot
.65098 .66275 Mdot
.79216 .82353 Mdot
.54902 .55294 Mdot
.61176 .56471 Mdot
.64314 .55294 Mdot
.75686 .6902 Mdot
.72549 .67451 Mdot
.63137 .60392 Mdot
.79608 .83137 Mdot
.56078 .40784 Mdot
.56863 .52549 Mdot
.64314 .54902 Mdot
.75294 .67059 Mdot
.7098 .67059 Mdot
.60392 .54902 Mdot
.80392 .8549 Mdot
.26667 .21961 Mdot
.56471 .53725 Mdot
.63922 .54118 Mdot
.74118 .66667 Mdot
.71765 .69412 Mdot
.61176 .56078 Mdot
.7451 .80784 Mdot
.16863 .21176 Mdot
.56471 .55294 Mdot
.61569 .52157 Mdot
.73725 .67843 Mdot
.73333 .69804 Mdot
.61961 .56863 Mdot
.2549 .32549 Mdot
.59216 .63137 Mdot
.56078 .56078 Mdot
.61569 .52941 Mdot
.73725 .67843 Mdot
.72941 .69412 Mdot
.63529 .59608 Mdot
.02353 .05882 Mdot
.63922 .65882 Mdot
.69412 .71373 Mdot
.62745 .54902 Mdot
.73725 .66275 Mdot
.72941 .69804 Mdot
.61176 .57647 Mdot
.00784 .02745 Mdot
.48627 .51373 Mdot
.42745 .44706 Mdot
.62353 .56078 Mdot
.72549 .6549 Mdot
.75686 .73333 Mdot
.12941 .1451 Mdot
.26667 .29804 Mdot
.52941 .60784 Mdot
.65098 .67451 Mdot
.60784 .55686 Mdot
.70196 .63922 Mdot
.76471 .72941 Mdot
.0549 .06275 Mdot
.59216 .59608 Mdot
.76863 .83529 Mdot
.30196 .33333 Mdot
.62353 .58824 Mdot
.69804 .63922 Mdot
.74902 .71373 Mdot
.04706 .05882 Mdot
.04314 .05098 Mdot
.78824 .84706 Mdot
.45098 .49804 Mdot
.64314 .61176 Mdot
.67451 .60392 Mdot
.75686 .71373 Mdot
.07843 .09412 Mdot
.01569 .03137 Mdot
.77647 .83529 Mdot
.55686 .59216 Mdot
.61176 .6 Mdot
.65882 .59216 Mdot
.74902 .70588 Mdot
.28235 .27451 Mdot
.00784 .02353 Mdot
.79216 .84314 Mdot
.58039 .63137 Mdot
.61961 .59608 Mdot
.65882 .57647 Mdot
.73725 .69804 Mdot
.68627 .66667 Mdot
.01569 .03922 Mdot
.69412 .7098 Mdot
.66275 .60392 Mdot
.6 .58039 Mdot
.64706 .56078 Mdot
.72941 .68627 Mdot
.72549 .69804 Mdot
.01569 .03529 Mdot
.01961 .06275 Mdot
.21176 .12941 Mdot
.58824 .58431 Mdot
.63529 .53725 Mdot
.7451 .6902 Mdot
.72941 .69804 Mdot
.02353 .04706 Mdot
.00392 .04314 Mdot
.08235 .18431 Mdot
.55686 .56471 Mdot
.61961 .53333 Mdot
.72941 .66275 Mdot
.75294 .72549 Mdot
.03922 .0549 Mdot
.00392 .04706 Mdot
.1098 .2 Mdot
.81961 .8549 Mdot
.60784 .54118 Mdot
.68627 .61176 Mdot
.75686 .72941 Mdot
.02745 .05098 Mdot
.44706 .49412 Mdot
.65882 .70196 Mdot
.35294 .38824 Mdot
.58039 .54118 Mdot
.63922 .55686 Mdot
.76078 .73333 Mdot
.03137 .04706 Mdot
.43529 .53333 Mdot
.29804 .40392 Mdot
.6902 .72549 Mdot
.56078 .52549 Mdot
.61961 .51765 Mdot
.76863 .75294 Mdot
.04314 .0549 Mdot
.03529 .07843 Mdot
.78039 .85098 Mdot
.34902 .37255 Mdot
.59216 .55294 Mdot
.59608 .49412 Mdot
.59216 .58824 Mdot
.05098 .07451 Mdot
.01569 .03529 Mdot
.77255 .84314 Mdot
.48627 .52157 Mdot
.58431 .5451 Mdot
.61176 .50588 Mdot
.66667 .64706 Mdot
.11373 .14118 Mdot
.00784 .03137 Mdot
.77647 .86275 Mdot
.73725 .78824 Mdot
.58824 .56863 Mdot
.60784 .50196 Mdot
.71373 .67059 Mdot
.62745 .63529 Mdot
.00392 .03529 Mdot
.4549 .62353 Mdot
.59216 .53725 Mdot
.55686 .55294 Mdot
.59608 .48235 Mdot
.63922 .58431 Mdot
.70588 .68235 Mdot
.01176 .03529 Mdot
.08235 .32549 Mdot
.32941 .30588 Mdot
.56863 .55294 Mdot
.57255 .48235 Mdot
.62353 .56471 Mdot
.70588 .69804 Mdot
.03137 .05098 Mdot
.04706 .25882 Mdot
.30196 .29804 Mdot
.54118 .55294 Mdot
.58431 .4902 Mdot
.63922 .57255 Mdot
.72941 .71373 Mdot
.02745 .03529 Mdot
.47843 .5451 Mdot
.39216 .37647 Mdot
.48627 .50196 Mdot
.55686 .48627 Mdot
.60392 .51765 Mdot
.75686 .73725 Mdot
.02745 .04314 Mdot
.72941 .79216 Mdot
.48627 .4902 Mdot
.40392 .43922 Mdot
.55294 .50196 Mdot
.58824 .48627 Mdot
.75686 .74118 Mdot
.03529 .04706 Mdot
.56078 .7451 Mdot
.73725 .76863 Mdot
.33333 .38824 Mdot
.53725 .49412 Mdot
.57647 .44314 Mdot
.77647 .75294 Mdot
.03137 .04706 Mdot
.1451 .37647 Mdot
.40392 .49412 Mdot
.45882 .51765 Mdot
.53333 .50588 Mdot
.56471 .43529 Mdot
.75294 .73725 Mdot
.04706 .05882 Mdot
.31765 .45098 Mdot
.39608 .47843 Mdot
.73725 .78824 Mdot
.55294 .53725 Mdot
.56471 .44706 Mdot
.74118 .71765 Mdot
.03529 .04314 Mdot
.3098 .37647 Mdot
.78039 .83529 Mdot
.75686 .82353 Mdot
.53725 .5098 Mdot
.54902 .43529 Mdot
.63137 .58431 Mdot
.1098 .13333 Mdot
.1451 .18039 Mdot
.37255 .4549 Mdot
.64706 .58431 Mdot
.56471 .54902 Mdot
.54118 .42745 Mdot
.61176 .55294 Mdot
.72157 .70588 Mdot
.03922 .06667 Mdot
.42745 .47451 Mdot
.23922 .27451 Mdot
.53725 .53333 Mdot
.52941 .41961 Mdot
.60392 .53333 Mdot
.72549 .72549 Mdot
.10588 .14118 Mdot
.81176 .86275 Mdot
.36078 .36471 Mdot
.47843 .4902 Mdot
.54118 .45098 Mdot
.59216 .51765 Mdot
.73725 .73725 Mdot
.62745 .6549 Mdot
.64314 .73333 Mdot
.2549 .34118 Mdot
.12157 .14902 Mdot
.54902 .49804 Mdot
.63137 .57255 Mdot
.7451 .74118 Mdot
.58431 .62745 Mdot
.31373 .40392 Mdot
.43529 .49804 Mdot
.33333 .36471 Mdot
.55686 .52941 Mdot
.58824 .50588 Mdot
.74902 .7451 Mdot
.12941 .16863 Mdot
.56078 .58431 Mdot
.12549 .29804 Mdot
.18431 .18431 Mdot
.54118 .52157 Mdot
.59216 .50196 Mdot
.74902 .74902 Mdot
.12157 .18039 Mdot
.37647 .40392 Mdot
.63529 .68235 Mdot
.11373 .12157 Mdot
.49412 .48627 Mdot
.6 .50196 Mdot
.58039 .57647 Mdot
.1451 .21176 Mdot
.13333 .17255 Mdot
.43922 .52157 Mdot
.22353 .21569 Mdot
.49804 .4902 Mdot
.55294 .45882 Mdot
.56471 .53725 Mdot
.64706 .66667 Mdot
.10588 .12941 Mdot
.78824 .83137 Mdot
.70588 .08235 Mdot
.5098 .50196 Mdot
.56863 .46667 Mdot
.66667 .62353 Mdot
.71373 .70196 Mdot
.14902 .18431 Mdot
.11373 .18039 Mdot
.07059 .18824 Mdot
.48235 .48627 Mdot
.54902 .45098 Mdot
.67059 .62745 Mdot
.72941 .73333 Mdot
.12549 .16863 Mdot
.00784 .04706 Mdot
.04706 .19608 Mdot
.47451 .4902 Mdot
.54118 .4549 Mdot
.68627 .65882 Mdot
.73333 .72157 Mdot
.15294 .18431 Mdot
.00392 .03137 Mdot
.07843 .20784 Mdot
.43137 .43922 Mdot
.52941 .48235 Mdot
.65882 .63529 Mdot
.7451 .74902 Mdot
.20392 .2549 Mdot
.00784 .02745 Mdot
.39608 .42745 Mdot
.21176 .23529 Mdot
.50588 .47059 Mdot
.64706 .61176 Mdot
.72157 .71765 Mdot
.35686 .47451 Mdot
.00784 .04706 Mdot
.46275 .45882 Mdot
.08627 .09804 Mdot
.43922 .41569 Mdot
.63922 .6 Mdot
.71765 .7098 Mdot
.23922 .39216 Mdot
.00784 .04314 Mdot
.47059 .48235 Mdot
.20784 .22745 Mdot
.42745 .41569 Mdot
.61176 .56471 Mdot
.71765 .71373 Mdot
.28627 .43137 Mdot
.02353 .04314 Mdot
.44706 .48627 Mdot
.19608 .18039 Mdot
.44314 .41961 Mdot
.61176 .56078 Mdot
.72157 .72941 Mdot
.67451 .68627 Mdot
.04314 .06667 Mdot
.18039 .22745 Mdot
.31373 .26275 Mdot
.47451 .46275 Mdot
.59216 .52549 Mdot
.70588 .71765 Mdot
.71373 .70588 Mdot
.06275 .10196 Mdot
.00392 .03529 Mdot
.31373 .33725 Mdot
.42353 .43529 Mdot
.54902 .48627 Mdot
.7098 .7098 Mdot
.6902 .67843 Mdot
.07059 .10588 Mdot
.16078 .20392 Mdot
.34118 .37255 Mdot
.40392 .4 Mdot
.56863 .49412 Mdot
.67059 .65098 Mdot
.71373 .72157 Mdot
.03137 .05882 Mdot
.5098 .53725 Mdot
.40392 .4 Mdot
.34902 .35686 Mdot
.54902 .48627 Mdot
.68627 .6549 Mdot
.7098 .7098 Mdot
.01961 .03922 Mdot
.03137 .07451 Mdot
.1098 .18431 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.69412 .66667 Mdot
.68627 .69412 Mdot
.02353 .05098 Mdot
.00392 .04314 Mdot
.44314 .43922 Mdot
.30196 .31765 Mdot
.4549 .43922 Mdot
.66275 .63529 Mdot
.72941 .73333 Mdot
.00784 .03529 Mdot
.00392 .02745 Mdot
.47843 .47451 Mdot
.12157 .11373 Mdot
.43922 .43137 Mdot
.63922 .59608 Mdot
.71373 .72157 Mdot
.03529 .05882 Mdot
.00784 .03529 Mdot
.6 .6902 Mdot
.3451 .31765 Mdot
.4549 .44706 Mdot
.61961 .55294 Mdot
.70196 .6902 Mdot
.03922 .06667 Mdot
.04314 .08627 Mdot
.04706 .09412 Mdot
.27843 .32157 Mdot
.38431 .38824 Mdot
.6 .53725 Mdot
.58824 .56078 Mdot
.34902 .38431 Mdot
.56471 .57647 Mdot
.42745 .49804 Mdot
.0549 .23529 Mdot
.31765 .33333 Mdot
.55294 .50196 Mdot
.54902 .49412 Mdot
.68235 .69804 Mdot
.59216 .62353 Mdot
.80392 .90588 Mdot
.08627 .20392 Mdot
.27451 .29412 Mdot
.52549 .49412 Mdot
.61569 .58824 Mdot
.66275 .67451 Mdot
.4902 .62353 Mdot
.18824 .4 Mdot
.43922 .43529 Mdot
.27451 .27451 Mdot
.50196 .47451 Mdot
.66275 .62745 Mdot
.69804 .72157 Mdot
.18824 .46275 Mdot
.12941 .39216 Mdot
.47451 .46667 Mdot
.39608 .38824 Mdot
.44314 .43529 Mdot
.61961 .57647 Mdot
.70588 .70588 Mdot
.33333 .48627 Mdot
.12941 .36471 Mdot
.48627 .4902 Mdot
.37647 .37647 Mdot
.44314 .43922 Mdot
.57255 .50196 Mdot
.69804 .69804 Mdot
.07059 .0902 Mdot
.18039 .22745 Mdot
.74902 .80784 Mdot
.27843 .3098 Mdot
.38431 .38039 Mdot
.52157 .43529 Mdot
.61961 .60392 Mdot
.02353 .04706 Mdot
.32941 .34902 Mdot
.15686 .3451 Mdot
.40392 .42353 Mdot
.29804 .3098 Mdot
.46275 .4 Mdot
.6549 .64314 Mdot
.06275 .09412 Mdot
.58039 .58039 Mdot
.10196 .13725 Mdot
.41569 .39608 Mdot
.12549 .14118 Mdot
.45098 .43137 Mdot
.6549 .63137 Mdot
.65882 .66275 Mdot
.12549 .19608 Mdot
.03137 .0549 Mdot
.44706 .43137 Mdot
.28235 .29412 Mdot
.4549 .44314 Mdot
.55294 .49804 Mdot
.66667 .6549 Mdot
.07843 .12941 Mdot
.03529 .07059 Mdot
.46275 .46275 Mdot
.38824 .38824 Mdot
.49804 .4902 Mdot
.57255 .5098 Mdot
.68627 .69412 Mdot
.38824 .51765 Mdot
.26667 .32157 Mdot
.48627 .48627 Mdot
.26275 .27451 Mdot
.41961 .42353 Mdot
.47843 .37647 Mdot
.65098 .66275 Mdot
.22353 .48235 Mdot
.67843 .69412 Mdot
.03137 .07843 Mdot
.07451 .23529 Mdot
.35294 .37255 Mdot
.4902 .39608 Mdot
.71373 .71765 Mdot
.24314 .33333 Mdot
.48235 .58431 Mdot
.00392 .03922 Mdot
.0549 .23529 Mdot
.3098 .33725 Mdot
.43529 .38039 Mdot
.67451 .65882 Mdot
.05098 .07843 Mdot
.04314 .08627 Mdot
.00784 .05882 Mdot
.06667 .2902 Mdot
.22353 .23137 Mdot
.39608 .38824 Mdot
.53725 .50196 Mdot
.5098 .5451 Mdot
.56863 .63922 Mdot
.03529 .09412 Mdot
.0902 .28627 Mdot
.31765 .30196 Mdot
.47059 .47843 Mdot
.58039 .53333 Mdot
.69412 .70588 Mdot
.32157 .54118 Mdot
.42745 .48627 Mdot
.31373 .36078 Mdot
.4 .31373 Mdot
.47843 .48627 Mdot
.56471 .50588 Mdot
.7098 .72157 Mdot
.32941 .50588 Mdot
.77647 .84314 Mdot
.00392 .03529 Mdot
.40784 .39216 Mdot
.37647 .38824 Mdot
.52941 .47059 Mdot
.6902 .70588 Mdot
.06667 .08627 Mdot
.63529 .66667 Mdot
.10588 .13725 Mdot
.42353 .41569 Mdot
.30588 .32549 Mdot
.43529 .38824 Mdot
.59216 .57647 Mdot
.20784 .22745 Mdot
.15294 .39216 Mdot
.0902 .13725 Mdot
.09804 .23137 Mdot
.26667 .27059 Mdot
.38039 .33333 Mdot
.82745 .82353 Mdot
.07059 .0902 Mdot
.27451 .35686 Mdot
.02353 .04706 Mdot
.45098 .47059 Mdot
.22745 .21569 Mdot
.44706 .44706 Mdot
.51373 .4902 Mdot
.65882 .66275 Mdot
.03922 .07451 Mdot
.00392 .03137 Mdot
.17255 .3451 Mdot
.29804 .28235 Mdot
.46275 .47059 Mdot
.59608 .54118 Mdot
.70588 .71373 Mdot
.07451 .12157 Mdot
.01961 .0549 Mdot
.06275 .31373 Mdot
.18431 .27451 Mdot
.43137 .46667 Mdot
.52549 .47059 Mdot
.68235 .6902 Mdot
.1098 .19216 Mdot
.64314 .71765 Mdot
.0549 .10588 Mdot
.0549 .25882 Mdot
.33725 .37647 Mdot
.5098 .45098 Mdot
.66275 .66667 Mdot
.03922 .06667 Mdot
.49804 .54902 Mdot
.71373 .73725 Mdot
.12941 .23922 Mdot
.27451 .27843 Mdot
.41961 .4 Mdot
.53725 .52941 Mdot
.08235 .12941 Mdot
.71373 .73725 Mdot
.04314 .07843 Mdot
.18431 .30196 Mdot
.08627 .08235 Mdot
.41569 .40784 Mdot
.5451 .52941 Mdot
.70588 .71373 Mdot
.65882 .72549 Mdot
.16078 .31373 Mdot
.41569 .4902 Mdot
.30196 .27843 Mdot
.38039 .4 Mdot
.57647 .5451 Mdot
.69804 .71373 Mdot
.34118 .53333 Mdot
.01961 .05882 Mdot
.2 .37647 Mdot
.27059 .30588 Mdot
.03529 .06667 Mdot
.51373 .45882 Mdot
.63137 .63529 Mdot
.43137 .62745 Mdot
.55294 .59608 Mdot
.21961 .31373 Mdot
.21569 .28235 Mdot
.13725 .17255 Mdot
.4549 .42353 Mdot
.54118 .52549 Mdot
.06275 .1098 Mdot
.6 .62745 Mdot
.0549 .07451 Mdot
.44314 .43529 Mdot
.25098 .25882 Mdot
.41176 .41176 Mdot
.50588 .48235 Mdot
.29412 .32941 Mdot
.6 .62353 Mdot
.02353 .0549 Mdot
.48235 .47843 Mdot
.28235 .26275 Mdot
.38431 .40392 Mdot
.55686 .53725 Mdot
.6902 .69804 Mdot
.71765 .73333 Mdot
.03529 .07843 Mdot
.44314 .46275 Mdot
.12941 .01569 Mdot
.30588 .32941 Mdot
.58431 .55294 Mdot
.6902 .70588 Mdot
.66275 .67451 Mdot
.61961 .67059 Mdot
.29412 .30588 Mdot
.11765 .17647 Mdot
.31373 .35686 Mdot
.52157 .47451 Mdot
.5098 .5098 Mdot
.23137 .39608 Mdot
.6549 .7451 Mdot
.02745 .07451 Mdot
.37647 .37255 Mdot
.26275 .28627 Mdot
.44706 .42353 Mdot
.50196 .47843 Mdot
.05098 .07059 Mdot
.63137 .68235 Mdot
.00392 .03529 Mdot
.46667 .46275 Mdot
.06667 .06667 Mdot
.40784 .42353 Mdot
.46275 .4549 Mdot
.66275 .68627 Mdot
.66275 .67843 Mdot
.11373 .17647 Mdot
.43529 .43137 Mdot
.09804 .01569 Mdot
.2902 .3098 Mdot
.49412 .4549 Mdot
.65098 .66275 Mdot
.64314 .67059 Mdot
.5098 .59216 Mdot
0 .02745 Mdot
.05882 .17255 Mdot
.27451 .31765 Mdot
.55294 .51765 Mdot
.50196 .50588 Mdot
.35294 .46667 Mdot
.80784 .8549 Mdot
.00392 .03137 Mdot
.04706 .2 Mdot
.28235 .32157 Mdot
.50588 .47843 Mdot
.4902 .48235 Mdot
.03529 .05098 Mdot
.64706 .77255 Mdot
.00392 .02745 Mdot
.11765 .24706 Mdot
.27059 .2902 Mdot
.44706 .43922 Mdot
.43529 .43922 Mdot
.31765 .35686 Mdot
.72941 .81961 Mdot
0 .03137 Mdot
.42745 .41176 Mdot
.21961 .19216 Mdot
.33725 .34902 Mdot
.33725 .33333 Mdot
.63137 .64706 Mdot
.67843 .70196 Mdot
0 .03137 Mdot
.02745 .0549 Mdot
.6549 .12157 Mdot
.24706 .28235 Mdot
.49412 .44314 Mdot
.56471 .57255 Mdot
.06667 .13333 Mdot
.00392 .03529 Mdot
.26275 .34118 Mdot
.35294 .34118 Mdot
.27059 .3098 Mdot
.51765 .49412 Mdot
.4902 .48235 Mdot
.03922 .07059 Mdot
.02353 .08235 Mdot
.21176 .40784 Mdot
.03529 .21961 Mdot
.10196 .13333 Mdot
.44706 .45098 Mdot
.47059 .45098 Mdot
.65098 .67451 Mdot
.62353 .68627 Mdot
.11373 .16863 Mdot
.42353 .45098 Mdot
.39608 .38824 Mdot
.39216 .41569 Mdot
.50196 .4902 Mdot
.57255 .59608 Mdot
.65882 .68235 Mdot
.40784 .44706 Mdot
.13725 .25882 Mdot
.80784 .03529 Mdot
.27451 .30588 Mdot
.45098 .41961 Mdot
.56471 .56471 Mdot
.03529 .06275 Mdot
.07451 .12157 Mdot
.00392 .02353 Mdot
.36863 .35294 Mdot
.27451 .30588 Mdot
.52549 .50588 Mdot
.83922 .87451 Mdot
.04706 .07451 Mdot
.00784 .04706 Mdot
.05882 .12941 Mdot
.21176 .26275 Mdot
.2 .20784 Mdot
.40784 .40392 Mdot
.49804 .47451 Mdot
.61569 .63529 Mdot
.00392 .03922 Mdot
.36078 .52941 Mdot
.40392 .39216 Mdot
.12941 .13725 Mdot
.39608 .41961 Mdot
.50588 .48627 Mdot
.56471 .58039 Mdot
.06275 .11373 Mdot
.16471 .23922 Mdot
.06667 .07059 Mdot
.63529 .03137 Mdot
.28627 .31765 Mdot
.47451 .43137 Mdot
.59216 .60392 Mdot
.04706 .07451 Mdot
.20784 .31373 Mdot
.00784 .03137 Mdot
.38824 .35686 Mdot
.2549 .28235 Mdot
.46275 .43529 Mdot
.53333 .53333 Mdot
.26667 .29412 Mdot
.19216 .43529 Mdot
.00392 .04706 Mdot
.40392 .38039 Mdot
.16471 .17255 Mdot
.33725 .32157 Mdot
.53333 .52941 Mdot
.74902 .76863 Mdot
.2549 .36078 Mdot
.00392 .03137 Mdot
.40784 .39216 Mdot
.32941 .30588 Mdot
.37647 .4 Mdot
.47451 .46275 Mdot
.53725 .55294 Mdot
.03922 .06667 Mdot
.31373 .48627 Mdot
.06667 .09804 Mdot
.64706 .1098 Mdot
.04314 .0902 Mdot
.45098 .42745 Mdot
.57647 .58824 Mdot
.09412 .14118 Mdot
.13333 .18824 Mdot
.30196 .37647 Mdot
.36863 .3451 Mdot
.24314 .2902 Mdot
.49804 .47451 Mdot
.51373 .50588 Mdot
.77647 .79216 Mdot
.11765 .22353 Mdot
.24706 .36078 Mdot
.41176 .38039 Mdot
.24706 .2549 Mdot
.42745 .41961 Mdot
.4902 .48235 Mdot
.61961 .65098 Mdot
.46667 .61176 Mdot
.02353 .05098 Mdot
.41176 .39216 Mdot
.27451 .23922 Mdot
.33333 .34118 Mdot
.48627 .46667 Mdot
.76863 .78431 Mdot
.13333 .16471 Mdot
.00784 .04314 Mdot
.18431 .20392 Mdot
.62353 .00784 Mdot
.24706 .27843 Mdot
.47843 .45098 Mdot
.60392 .62353 Mdot
.0549 .08627 Mdot
.54118 .65882 Mdot
0 .02745 Mdot
.38824 .36078 Mdot
.04706 .06275 Mdot
.51373 .50196 Mdot
.46667 .46275 Mdot
.42353 .47451 Mdot
.29412 .40392 Mdot
.12941 .18824 Mdot
.41176 .4 Mdot
.26667 .26275 Mdot
.42353 .43529 Mdot
.46275 .45098 Mdot
.63137 .66667 Mdot
.29412 .34118 Mdot
.08627 .3098 Mdot
.38824 .37255 Mdot
.15294 .12157 Mdot
.27843 .31765 Mdot
.46667 .45882 Mdot
.78039 .78824 Mdot
.02353 .07059 Mdot
.00392 .04314 Mdot
.00392 .01176 Mdot
.32157 .28627 Mdot
.30196 .32157 Mdot
.54902 .53333 Mdot
.38431 .43922 Mdot
.07451 .11765 Mdot
.83529 .87843 Mdot
0 .01569 Mdot
.4 .36471 Mdot
.22745 .2549 Mdot
.46667 .46275 Mdot
.47843 .48235 Mdot
.27451 .3451 Mdot
.28627 .52157 Mdot
.00392 .03529 Mdot
.40392 .37647 Mdot
.23137 .19608 Mdot
.41176 .42745 Mdot
.47843 .47451 Mdot
.80784 .84314 Mdot
.15686 .21961 Mdot
.00784 .0549 Mdot
.33333 .37647 Mdot
.08627 0 Mdot
.35294 .38824 Mdot
.48627 .45882 Mdot
.58431 .60392 Mdot
.0549 .10196 Mdot
.16078 .21569 Mdot
.00784 .02745 Mdot
.37647 .36078 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.50588 .55686 Mdot
.21569 .38431 Mdot
.82353 .87059 Mdot
.21176 .31373 Mdot
.4 .38039 Mdot
.25098 .2549 Mdot
.30196 .31373 Mdot
.49412 .4902 Mdot
.6902 .72549 Mdot
.8549 .91765 Mdot
.01569 .05098 Mdot
.41176 .39608 Mdot
.08627 .05098 Mdot
.37255 .38824 Mdot
.82353 .83137 Mdot
.77255 .80392 Mdot
.02745 .07059 Mdot
.00784 .04314 Mdot
.08627 .23529 Mdot
.33333 .26667 Mdot
.12157 .14902 Mdot
.54902 .5098 Mdot
.52549 .54118 Mdot
.48235 .52157 Mdot
.81569 .85098 Mdot
.01569 .04706 Mdot
.38039 .35686 Mdot
.13333 .16471 Mdot
.42353 .42353 Mdot
.18431 .35294 Mdot
.31373 .33725 Mdot
.83529 .87059 Mdot
.60784 .72941 Mdot
.40784 .39608 Mdot
.28235 .2549 Mdot
.40392 .41961 Mdot
.47059 .45882 Mdot
.84706 .88627 Mdot
.23137 .44314 Mdot
.17255 .35686 Mdot
.41176 .38824 Mdot
.25098 .0549 Mdot
.41176 .43137 Mdot
.49804 .50588 Mdot
.56078 .58824 Mdot
.06667 .09412 Mdot
.18824 .24706 Mdot
.37255 .4549 Mdot
.38039 .3451 Mdot
.28627 .30196 Mdot
.4902 .47451 Mdot
.72941 .74902 Mdot
.30196 .55294 Mdot
.82745 .86275 Mdot
.53725 .59216 Mdot
.40392 .38039 Mdot
.08235 .10196 Mdot
.16078 .18431 Mdot
.10588 .32941 Mdot
.69412 .79608 Mdot
.83529 .86667 Mdot
.58824 .65882 Mdot
.40784 .38824 Mdot
.26667 .19608 Mdot
.3451 .38824 Mdot
.47059 .48235 Mdot
.82353 .84706 Mdot
.16863 .4 Mdot
.61569 .72941 Mdot
.42745 .42353 Mdot
.37255 .32941 Mdot
.37647 .41569 Mdot
.56863 .5451 Mdot
.68627 .71373 Mdot
.05098 .0902 Mdot
.82353 .85882 Mdot
.57647 .60392 Mdot
.38431 .36471 Mdot
.33333 .36471 Mdot
.39216 .38431 Mdot
.48627 .4902 Mdot
.23529 .47843 Mdot
.83529 .87451 Mdot
.7451 .79608 Mdot
.41569 .39608 Mdot
.04706 .01176 Mdot
.22353 .24314 Mdot
.45882 .47451 Mdot
.8549 .88235 Mdot
.84706 .87843 Mdot
.65882 .76078 Mdot
.43137 .42353 Mdot
.36078 .30588 Mdot
.14118 .18431 Mdot
.57255 .55294 Mdot
.60784 .64706 Mdot
.20784 .47059 Mdot
.82745 .86667 Mdot
.49412 .51765 Mdot
.39216 .37255 Mdot
.3098 .35686 Mdot
.46275 .44314 Mdot
.56863 .58431 Mdot
.12157 .2 Mdot
.83137 .86275 Mdot
.62353 .66275 Mdot
.41176 .40784 Mdot
.21569 .18039 Mdot
.47451 .49804 Mdot
.21176 .44314 Mdot
.84706 .8902 Mdot
.8549 .88627 Mdot
.37255 .48235 Mdot
.41961 .41569 Mdot
.1451 .02745 Mdot
.40392 .43137 Mdot
.62353 .61176 Mdot
.67059 .69412 Mdot
.8549 .88627 Mdot
.81961 .85882 Mdot
.53725 .55294 Mdot
.39608 .36078 Mdot
.18431 .21176 Mdot
.53333 .52549 Mdot
.84314 .86275 Mdot
.72157 .91373 Mdot
.83922 .87059 Mdot
.78431 .82353 Mdot
.41569 .38824 Mdot
.25882 .26667 Mdot
.43529 .45098 Mdot
.58431 .61176 Mdot
.83137 .87843 Mdot
.8549 .88235 Mdot
.56078 .63137 Mdot
.43137 .41176 Mdot
.15294 .07451 Mdot
.40784 .43922 Mdot
.53333 .63922 Mdot
.69412 .73333 Mdot
.8549 .88627 Mdot
.83137 .87451 Mdot
.55686 .57647 Mdot
.37255 .3451 Mdot
.36471 .40392 Mdot
.50588 .49412 Mdot
.61176 .63529 Mdot
.72157 .8549 Mdot
.8549 .88235 Mdot
.65882 .69412 Mdot
.40784 .39216 Mdot
.13333 .12157 Mdot
.33333 .3451 Mdot
.61569 .64706 Mdot
.78824 .9098 Mdot
.85882 .88627 Mdot
.5451 .64706 Mdot
.45882 .43529 Mdot
.13725 .0902 Mdot
.20784 .25098 Mdot
.12941 .46667 Mdot
.98039 1 Mdot
.87451 .90196 Mdot
.83922 .90196 Mdot
.58824 .61176 Mdot
.39216 .35686 Mdot
.35686 .4 Mdot
.56863 .57255 Mdot
.84706 .86667 Mdot
.91765 .9451 Mdot
.85098 .89804 Mdot
.79608 .81961 Mdot
.41176 .39216 Mdot
.32941 .35294 Mdot
.4549 .45098 Mdot
.76471 .81569 Mdot
.91373 .9451 Mdot
.86275 .89804 Mdot
.64706 .72157 Mdot
.47451 .46667 Mdot
.1098 .06275 Mdot
.29412 .30588 Mdot
.14902 .52157 Mdot
1 1 Mdot
.88235 .91373 Mdot
.77255 .86275 Mdot
.68235 .69804 Mdot
.40392 .36471 Mdot
.29804 .32941 Mdot
.56078 .56078 Mdot
.94902 .96471 Mdot
.91373 .95294 Mdot
.83922 .88235 Mdot
.76471 .8 Mdot
.44314 .42745 Mdot
.32549 .34118 Mdot
.50196 .50588 Mdot
.87451 .89804 Mdot
.92157 .98824 Mdot
.84706 .88627 Mdot
.35686 .4902 Mdot
.4902 .49412 Mdot
.18431 .11765 Mdot
.19216 .22353 Mdot
.23529 .63922 Mdot
.9451 .95686 Mdot
.84706 .8902 Mdot
.81569 .87059 Mdot
.62353 .64706 Mdot
.42353 .38824 Mdot
.31373 .34118 Mdot
.64706 .6549 Mdot
.99608 1 Mdot
.87451 .9098 Mdot
.82745 .87451 Mdot
.4902 .52941 Mdot
.46667 .46275 Mdot
.11373 .12157 Mdot
.57255 .59216 Mdot
.88235 .91373 Mdot
.89412 .98824 Mdot
.83137 .87843 Mdot
.43137 .54902 Mdot
.46275 .46667 Mdot
.23529 .12549 Mdot
.22353 .23922 Mdot
.30588 .69804 Mdot
.52157 .6549 Mdot
.85098 .8902 Mdot
.82353 .8902 Mdot
.53333 .5451 Mdot
.44706 .42745 Mdot
.06275 .1098 Mdot
.76863 .77647 Mdot
.76863 .82745 Mdot
.86667 .90196 Mdot
.83137 .97647 Mdot
.58039 .6549 Mdot
.43922 .43137 Mdot
.18039 .18039 Mdot
.64314 .65098 Mdot
.80784 .85098 Mdot
.81176 .92549 Mdot
.64706 .92941 Mdot
.33333 .63529 Mdot
.50588 .52157 Mdot
.23529 .12941 Mdot
.15294 .22353 Mdot
.23922 .61176 Mdot
.84706 .89412 Mdot
.62353 .9098 Mdot
.18039 .60392 Mdot
.34902 .5451 Mdot
.60784 .61961 Mdot
.22745 .25098 Mdot
.69804 .72157 Mdot
.8549 .88627 Mdot
.74902 .9451 Mdot
.17255 .5098 Mdot
.09804 .41176 Mdot
.42745 .40784 Mdot
.13333 .13333 Mdot
.63922 .6549 Mdot
.85098 .87843 Mdot
.71765 .94118 Mdot
.43137 .91373 Mdot
.04706 .18039 Mdot
.14902 .38824 Mdot
.12549 .02745 Mdot
.23922 .25882 Mdot
.15686 .41176 Mdot
.7098 .93725 Mdot
.66667 1 Mdot
.03137 .08627 Mdot
.03922 .18039 Mdot
.60392 .62353 Mdot
.37647 .41569 Mdot
.62745 .65098 Mdot
.56471 .87843 Mdot
.85882 1 Mdot
.03137 .09412 Mdot
.02745 .08235 Mdot
.34118 .47059 Mdot
.25882 .26275 Mdot
.60392 .62745 Mdot
.59608 .86275 Mdot
.83529 .99216 Mdot
.06667 .20392 Mdot
.32157 .38039 Mdot
.03922 .16078 Mdot
.04706 .03137 Mdot
.53333 .57255 Mdot
.54118 .78824 Mdot
.6 .99608 Mdot
.15686 .48235 Mdot
.53725 .55686 Mdot
0 .02353 Mdot
.37647 .32549 Mdot
.47451 .5098 Mdot
.62745 .74118 Mdot
.4902 .98039 Mdot
.18431 .44706 Mdot
.41961 .52157 Mdot
.57647 .59608 Mdot
.21961 .45882 Mdot
.27843 .28235 Mdot
.64706 .67843 Mdot
.45098 .97255 Mdot
.21569 .47843 Mdot
.06275 .10588 Mdot
.57255 .62745 Mdot
.01176 .05882 Mdot
.20392 .17647 Mdot
.58431 .60392 Mdot
.28235 .84314 Mdot
.27451 .52549 Mdot
.31765 .67843 Mdot
.58039 .64706 Mdot
.13725 .17647 Mdot
.22353 .17647 Mdot
.47451 .50196 Mdot
.21176 .73333 Mdot
.28235 .54118 Mdot
.57255 .99608 Mdot
.6 .67059 Mdot
0 .01176 Mdot
.69412 .07451 Mdot
.4 .43922 Mdot
.21961 .69412 Mdot
.22745 .4902 Mdot
.54902 .94902 Mdot
.34902 .4549 Mdot
.31373 .36863 Mdot
.06667 .18039 Mdot
.37647 .40392 Mdot
.2 .65882 Mdot
.18824 .45098 Mdot
.5098 .93333 Mdot
.05882 .09804 Mdot
.21176 .2902 Mdot
.59608 .63137 Mdot
.43137 .43529 Mdot
.16863 .61176 Mdot
.11373 .52157 Mdot
.44314 .93333 Mdot
.11765 .26667 Mdot
.10588 .20392 Mdot
.42745 .45882 Mdot
.4 .33333 Mdot
.18039 .58039 Mdot
.17647 .45882 Mdot
.4 .92157 Mdot
.46667 .95294 Mdot
.04314 .09804 Mdot
.47451 .4902 Mdot
.31373 .21176 Mdot
.14118 .47451 Mdot
.03922 .30588 Mdot
.37255 .8902 Mdot
.66275 .99608 Mdot
.05882 .1098 Mdot
.00392 .04706 Mdot
.55686 .0902 Mdot
.17647 .38824 Mdot
.13333 .33725 Mdot
.33725 .83529 Mdot
.88627 1 Mdot
.05098 .12549 Mdot
.00392 .03137 Mdot
.1451 .23922 Mdot
.40392 .47843 Mdot
.10196 .29804 Mdot
.28627 .79216 Mdot
.87451 .98039 Mdot
.06667 .14902 Mdot
.01961 .06275 Mdot
.42353 .50196 Mdot
.38431 .40392 Mdot
.10196 .25882 Mdot
.19216 .7098 Mdot
.64706 .89412 Mdot
.14118 .38824 Mdot
.06275 .18824 Mdot
.02745 .10588 Mdot
.38824 .39608 Mdot
.12157 .34902 Mdot
.23137 .76863 Mdot
.5451 .96078 Mdot
.2549 .68627 Mdot
.12549 .41176 Mdot
.01961 .06275 Mdot
.38431 .36863 Mdot
.11765 .43529 Mdot
.22745 .79216 Mdot
.48235 .97255 Mdot
.27843 .76078 Mdot
.17647 .58431 Mdot
.03137 .05882 Mdot
.36471 .3098 Mdot
.09412 .41961 Mdot
.41569 .95294 Mdot
.41569 .93333 Mdot
.31373 .76863 Mdot
.19608 .62353 Mdot
.03137 .14118 Mdot
.35294 .25882 Mdot
.09412 .41961 Mdot
.25882 .81961 Mdot
.37647 .88627 Mdot
.31765 .72549 Mdot
.24706 .53333 Mdot
.09412 .40392 Mdot
.34902 .24706 Mdot
.10588 .45098 Mdot
.23529 .78039 Mdot
.36078 .86667 Mdot
.38431 .61176 Mdot
.4902 .57647 Mdot
.13333 .47451 Mdot
.34118 .23137 Mdot
.11765 .4902 Mdot
.22353 .74902 Mdot
.34118 .83137 Mdot
.52157 .57647 Mdot
.7098 .7098 Mdot
.18824 .39608 Mdot
.3451 .17255 Mdot
.13725 .51765 Mdot
.26275 .78431 Mdot
.3451 .76863 Mdot
.59608 .60392 Mdot
.77255 .77255 Mdot
.35294 .4 Mdot
.34118 .12157 Mdot
.15294 .5451 Mdot
.23137 .73333 Mdot
.41176 .62745 Mdot
.67059 .67451 Mdot
.78431 .80784 Mdot
.38039 .37255 Mdot
.23529 .07451 Mdot
.14902 .55686 Mdot
.21176 .71373 Mdot
.55294 .57255 Mdot
.87843 .88235 Mdot
.49412 .52549 Mdot
.36471 .34902 Mdot
.07451 .12941 Mdot
.16078 .58039 Mdot
.14118 .61569 Mdot
.59608 .59216 Mdot
.56471 .58824 Mdot
.41961 .37647 Mdot
.34902 .31765 Mdot
.07843 .21569 Mdot
.16078 .58824 Mdot
.21961 .51765 Mdot
.78824 .78824 Mdot
.45098 .40392 Mdot
.39608 .2902 Mdot
.34118 .29804 Mdot
.03529 .0902 Mdot
.14902 .59216 Mdot
.52157 .53333 Mdot
.54902 .58039 Mdot
.41176 .30588 Mdot
.38039 .28627 Mdot
.32549 .28627 Mdot
.09804 .36863 Mdot
.18824 .62353 Mdot
.60784 .6 Mdot
.43922 .37255 Mdot
.36471 .24314 Mdot
.39608 .3098 Mdot
.30588 .25098 Mdot
.13333 .52157 Mdot
.28235 .52549 Mdot
.60784 .63137 Mdot
.39216 .2902 Mdot
.37255 .25882 Mdot
.38431 .28627 Mdot
.27843 .20392 Mdot
.09412 .47843 Mdot
.56078 .57647 Mdot
.36078 .27843 Mdot
.38824 .26275 Mdot
.36078 .2549 Mdot
.36863 .25882 Mdot
.1451 .03529 Mdot
.12941 .53333 Mdot
.76078 .74902 Mdot
.40392 .28627 Mdot
.37255 .25098 Mdot
.39608 .29412 Mdot
.35686 .25098 Mdot
.07843 .15686 Mdot
.17647 .43137 Mdot
.39608 .38039 Mdot
.41569 .31765 Mdot
.36863 .25098 Mdot
.38039 .2902 Mdot
.33725 .27843 Mdot
.12549 .45098 Mdot
.56863 .56471 Mdot
.46275 .38431 Mdot
.43922 .33333 Mdot
.37255 .25098 Mdot
.37647 .27451 Mdot
.27843 .2 Mdot
.11765 .49412 Mdot
.68627 .69412 Mdot
.52157 .46275 Mdot
.41961 .32941 Mdot
.35686 .23529 Mdot
.41569 .33333 Mdot
.33725 .24314 Mdot
.15294 .42353 Mdot
.52549 .4549 Mdot
.55686 .49412 Mdot
.39216 .31373 Mdot
.36078 .27451 Mdot
.36863 .28627 Mdot
.14118 .02745 Mdot
.65098 .64314 Mdot
.57255 .59608 Mdot
.45098 .39608 Mdot
.40784 .34902 Mdot
.41569 .38039 Mdot
.34902 .30588 Mdot
.16471 .52549 Mdot
.35686 .31373 Mdot
.42745 .39216 Mdot
.52157 .48235 Mdot
.34118 .32157 Mdot
.37255 .32157 Mdot
.41961 .36471 Mdot
.25098 .43137 Mdot
.39608 .28627 Mdot
.41569 .31765 Mdot
.23137 .21569 Mdot
.27059 .24314 Mdot
.44706 .38431 Mdot
.38431 .29804 Mdot
.55686 .54902 Mdot
.38431 .2549 Mdot
.47059 .41961 Mdot
.33333 .30588 Mdot
.22353 .18039 Mdot
.34118 .30588 Mdot
.26667 .61961 Mdot
.40392 .3098 Mdot
.40392 .2902 Mdot
.43137 .4 Mdot
.39216 .33333 Mdot
.41176 .36078 Mdot
.44314 .40784 Mdot
.45098 .42745 Mdot
.41176 .27451 Mdot
.39608 .33333 Mdot
.51373 .47059 Mdot
.43922 .33333 Mdot
.37647 .32157 Mdot
.6549 .04706 Mdot
.40392 .28627 Mdot
.4 .25882 Mdot
.7098 .69412 Mdot
.41961 .26667 Mdot
.39608 .30588 Mdot
.50196 .46667 Mdot
.38824 .31765 Mdot
.41176 .2902 Mdot
.40392 .31373 Mdot
.5098 .43922 Mdot
.38039 .26275 Mdot
.42353 .4 Mdot
.35686 .17647 Mdot
.40784 .28235 Mdot
.39216 .27451 Mdot
.44314 .39216 Mdot
.37255 .25098 Mdot
.42353 .32549 Mdot
.54902 .52549 Mdot
.30588 .16863 Mdot
.40392 .27059 Mdot
.78431 .76471 Mdot
.3451 .33333 Mdot
.43137 .38039 Mdot
.59608 .59216 Mdot
.3098 .18824 Mdot
.41569 .29804 Mdot
.4 .21961 Mdot
.4549 .40392 Mdot
.48235 .43922 Mdot
.62353 .61569 Mdot
.38431 .27843 Mdot
.34118 .1451 Mdot
.36863 .19608 Mdot
.45882 .38824 Mdot
.44706 .37255 Mdot
.52157 .46667 Mdot
.59608 .59608 Mdot
.35686 .27843 Mdot
.43922 .33725 Mdot
.38039 .23529 Mdot
.63137 .64314 Mdot
.48627 .41176 Mdot
.71373 .71765 Mdot
.23922 .16471 Mdot
.41569 .28627 Mdot
.46275 .36078 Mdot
.6 .57255 Mdot
.53725 .52157 Mdot
.78824 .79608 Mdot
.37255 .19216 Mdot
.40784 .29412 Mdot
.44706 .32157 Mdot
.53725 .42353 Mdot
.64706 .63922 Mdot
.8902 .89412 Mdot
.33725 .07843 Mdot
.41569 .32941 Mdot
.45882 .3451 Mdot
.45882 .29804 Mdot
.59608 .48627 Mdot
.92157 .93725 Mdot
.35686 .0902 Mdot
.39608 .33333 Mdot
.46275 .36863 Mdot
.56078 .42745 Mdot
.8902 .81569 Mdot
.85882 .8902 Mdot
.3451 .19608 Mdot
.38824 .32157 Mdot
.4549 .37647 Mdot
.63137 .55294 Mdot
.99608 .98824 Mdot
.81569 .84706 Mdot
.34902 .30196 Mdot
.4902 .43922 Mdot
.52941 .45098 Mdot
.88235 .84706 Mdot
.99216 .99608 Mdot
.73725 .74118 Mdot
.43137 .38824 Mdot
.47843 .42745 Mdot
.61176 .56078 Mdot
.99216 .99216 Mdot
.87451 .89412 Mdot
.35686 .16471 Mdot
.42745 .36078 Mdot
.57647 .55294 Mdot
.99608 .99216 Mdot
.89412 .9098 Mdot
.76863 .78039 Mdot
.47451 .43137 Mdot
.59608 .58431 Mdot
1 .99216 Mdot
.97255 .98039 Mdot
.82353 .82745 Mdot
.45098 .41569 Mdot
.57647 .55294 Mdot
.92157 .92157 Mdot
.97647 .98039 Mdot
.83529 .84314 Mdot
.43137 .38824 Mdot
.60784 .59216 Mdot
.90196 .90588 Mdot
.92157 .92941 Mdot
.83137 .84706 Mdot
.46275 .43137 Mdot
.67059 .66275 Mdot
.98824 .99216 Mdot
.93333 .92941 Mdot
.52549 .44314 Mdot
.53725 .51373 Mdot
.89804 .90588 Mdot
.96078 .96078 Mdot
.85098 .8549 Mdot
.48235 .43922 Mdot
.7451 .7451 Mdot
.96863 .96471 Mdot
.8902 .8902 Mdot
.38824 .2549 Mdot
.72549 .72549 Mdot
.93333 .93725 Mdot
.90196 .9098 Mdot
.4902 .41569 Mdot
.83529 .83922 Mdot
.91765 .92941 Mdot
.77255 .18824 Mdot
.6902 .68627 Mdot
.94118 .94118 Mdot
.78039 .20784 Mdot
.69804 .67451 Mdot
.65882 .59608 Mdot
.49804 .32157 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`002P3oool4oomo00<0oooo00Googl00?ooooooO`00oooooomo0006
0?ooo`04oomo003oool0oooooomo02d0oooo00?oogl00?ooo`3oool0503oool4oomo02X0oooo00?o
ogl00?ooo`3oool0:@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo00?o
X23`0?ooo`3oool0N`3oool00ol00000oooo0?ooo`090?ooo`002P3oool6oomo00<0oooo00?oogl0
0?ooo`3oool01`3oool01?ooO`00oooooomo0?ooO`140?ooo`Coogl02`3oool00oooO`00oooo0?oo
o`170?ooo`03o`00003oool0oooo00l0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?oo
o`120?ooo`03oj0Pl03oool0oooo0200oooo0_nP8?120?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`Coogl00P3oool00oooO`00oooo0?ooo`030?ooo`03oomo003oool0oooo04l0oooo00?oogl0
0?ooo`3oool0D`3oool00ol00000oooo0?ooo`0?0?ooo`03oj0Pl03oool0oooo00h0oooo00?oX23`
0?ooo`3oool00`3oool00onP8?00oooo0?ooo`0[0?ooo`;oX23`K@3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool7oomo00030?ooooooO`3oogl005X0oooo00?oogl00?ooo`3oool0C@3oool00ol0
0000oooo0?ooo`0?0?ooo`;oX23`00<0oooooj0Pl03oool0B`3oool00onP8?00oooo0?ooo`020?oo
o`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0E`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool6oomo00D0oooo00?oogl00?ooo`3oool08P3oool00oooO`00oooo0?ooo`210?ooo`03
o`00003oool0oooo00l0oooo1?nP8?0B0?ooo`03oj0Pl03oool0oooo00;oX23`:03oool00onP8?00
oooo0?ooo`1^0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`_oogl02P3oool00oooO`00oooo
0?ooo`040?ooo`03oomo003oool0oooo04@0oooo00?oogl00?ooo`3oool0CP3oool00ol00000oooo
0?ooo`0?0?ooo`KoX23`0P3oool00onP8?00oooo0?ooo`0?0?ooo`03oj0Pl03oool0oooo03P0oooo
00?oX23`0?ooo`3oool06P3oool00onP8?00oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo0200oooo
00?o00000?ooo`3oool02@3oool000X0oooo1oooO`000`3oooooogl0oomo0003oomo00030?oooooo
O`3oogl00:@0oooo00?o00000?ooo`3oool03`3oool00onP8?00oooo0?ooo`03oj0Pl4d0oooo00?o
X23`0?ooo`3oool05@3oool00onP8?00oooo0?ooo`160?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`03o`000?ooO`3oogl000Koogl000<0oooooomo0?ooO`000`3oool2oomo0280oooo00?oogl0
0?ooo`3oool0OP3oool00ol00000oooo0?ooo`0?0?ooo`;oX23`0P3oool3oj0Pl0030?oooonP8?00
oooo0:X0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooooooO`003OooO`0S0?oo
o`03oomo003oool0oooo01<0oooo00?oogl00?ooo`3oool0;P3oool01?ooO`00oooo0?ooooooO`0J
0?ooo`04oomo003oool0oooooomo01P0oooo00?o00000?ooo`3oool03`3oool2oj0Pl0030?oooonP
8?3oX23`00;oX23`00@0oooooj0Pl03oooooX23`103oool00onP8?00oooo0?ooo`0m0?ooo`03oj0P
l03oool0oooo02@0oooo00?oX23`0?ooo`3oool0703oool2oj0Pl1d0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo1_ooO`000`3oooooogl0oomo0002oomo05h0oooo
00?oogl00?ooo`3oool0A03oool00ol00000oooo0?ooo`0?0?ooo`03o`000?nP8?00oooo00?oX23`
00<0oooooj0Pl?nP8?00103oool00onP8?00oooo0?ooo`0M0?ooo`03oj0Pl03oool0oooo08@0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo2oooO`000`3oooooogl0
0?ooo`0Y0?ooo`03oomo003oool0oooo03X0oooo00Coogl00?ooo`3oooooogl0>03oool00ol00000
oooo0?ooo`0?0?ooo`03o`000?nP8?3oX23`00KoX23`00<0oooooj0Pl03oool0103oool2oj0Pl080
oooo00?oX23`0?ooo`3oool0@P3oool01OnP8?00oooo0?ooo`3oooooX23`05H0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00?o00000?ooo`3oool00`3oool:oomo00030?ooooooO`00oooo0400
oooo00?oogl00?ooo`3oool0GP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00<0
oooo0onP8?030?ooo`04oj0Pl03oool0oooooj0Pl:@0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00?o00000?ooo`3oool00`3oool00oooO`00oooooomo0004oomo00030?ooooooO`3oogl001X0
oooo00?oogl00?ooo`3oool0Q`3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
o`CoX23`00D0oooooj0Pl03oool0oooooj0Pl02W0?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`03o`00003oool0oooo00<0oooo2?ooO`000`3oooooogl0oomo001Y0?ooo`03oomo003oool0oooo
03L0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`020?ooo`KoX23`0`3oool00onP
8?00oooo0?ooo`0:0?ooo`03oj0Pl03oool0oooo00`0oooo00?oX23`0?ooo`3oool0403oool00onP
8?00oooo0?ooo`0m0?ooo`03oj0Pl03oool0oooo03@0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00?o00000?ooo`3oool01`3oool5oomo00030?ooooooO`00oooo00D0oooo00Coogl00?ooo`3o
ooooogl0Q03oool00oooO`00oooo0?ooo`0B0?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo0_nP8?040?ooo`03oj0Pl03oool0oooo0080oooo00CoX23`0?ooo`3oooooX23`203o
ool00onP8?00oooo0?ooo`160?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?ooo`3oool04P3o
ool00onP8?00oooo0?ooo`0b0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0
oooo00L0oooo1oooO`000`3oooooogl00?ooo`0<0?ooo`03oomo003oool0oooo0940oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`020?ooo`;oX23`00H0oooooj0Pl?nP8?3oX23`0?oo
oonP8?070?ooo`05oj0Pl03oool0oooo0?oooonP8?009`3oool00onP8?00oooo0?ooo`0Q0?ooo`03
oj0Pl03oool0oooo04d0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0
1`3oool4oomo0080oooo00Coogl00?ooo`3oool0oooo0_ooO`1[0?ooo`03oomo003oool0oooo0300
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`020?ooo`;oX23`00@0oooooj0Pl03o
ool0oooo0_nP8?000`3oooooX23`0?ooo`090?ooo`03oj0Pl03oool0oooo09P0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00?o00000?ooo`3oool00`3oool01?ooO`00oooooomo003oool2oomo
00060?ooooooO`3oogl0oomo003oooooogl00P3oool00oooO`00oooo0?ooo`2M0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool01@3oool00onP8?00oooooj0Pl003oj0Pl0030?oooonP
8?00oooo00@0oooo00?oX23`0?ooo`3oool0W03oool00ol00000oooo0?ooo`090?ooo`002P3oool0
0ol00000oooo0?ooo`080?ooo`03oomo003oooooogl000?oogl00`3oool00oooO`00oooo0?ooo`1Z
0?ooo`03oomo003oool0oooo0300oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`02
0?ooo`03oj0Pl03oool0oooo0080oooo0onP8?2W0?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`03o`00003oool0oooo00P0oooo00Googl00?ooo`3oooooogl00?ooo`02oomo00050?ooooooO`00
oooo0?ooooooO`009P3oool00oooO`00oooo0?ooo`1d0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool01`3oool2oj0Pl6P0oooo00?oX23`0?ooo`3oool0?@3oool00ol00000oooo0?oo
o`090?ooo`002P3oool00ol00000oooo0?ooo`090?ooo`04oomo003oool0oooooomo0080oooo1Ooo
O`020?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool0T`3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo00P0oooo0onP8?060?ooo`03oj0Pl03oooooX23`00X0oooo00?o
X23`0?ooo`3oool0T03oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0<
0?ooo`;oogl0M@3oool00oooO`00oooo0?ooo`0[0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool02P3oool2oj0Pl0D0oooo00GoX23`0?ooo`3oool0oooooj0Pl0020?ooo`03oj0Pl03o
ool0oooo01l0oooo00?oX23`0?ooo`3oool0=P3oool00onP8?00oooo0?ooo`0k0?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo00`0oooo0_ooO`00103oooooogl00?ooo`3o
ool3oomo00030?ooooooO`00oooo00;oogl0U`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo00H0oooo0_nP8?020?ooo`?oX23`0`3oool00onP8?00oooooj0Pl00@0?ooo`05oj0Pl03o
ool0oooo0?oooonP8?00R@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`0?0?ooo`03oomo003oooooogl00080oooo00?oogl00?ooooooO`000P3oool00oooO`00oooo0?oo
o`2E0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool02@3oool00onP8?00oooo0?oo
o`030?ooo`03oj0Pl03oooooX23`00<0oooo00?oX23`0?ooo`3oool0V@3oool00ol00000oooo0?oo
o`090?ooo`002P3oool00ol00000oooo0?ooo`0=0?ooo`04oomo003oool0oooo0?ooo`;oogl00`3o
ool3oomo0080oooo00?oogl00?ooo`3oool0T`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo00d0oooo00CoX23`0?oooonP8?3oX23`0`3oool00onP8?00oooo0?ooo`2J0?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo00`0oooo00?oogl00?ooo`3oool00P3o
ool01OooO`00oooo0?ooooooO`00oooo00;oogl0103oool01_ooO`00oooo0?ooooooO`00oooooomo
05l0oooo00?oogl00?ooo`3oool0;@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
0080oooo00?oX23`0?ooo`3oool02@3oool01OnP8?00oooooj0Pl?nP8?00oooo00;oX23`9@3oool0
0onP8?00oooo0?ooo`1d0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo
00l0oooo00?oogl00?ooo`3oool01P3oool00oooO`00oooo0?ooo`2F0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool02@3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo
09/0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0403oool00oooO`00
oooo0?ooo`030?ooo`03oomo003oool0oooo00;oogl000<0oooooomo0?ooO`00I`3oool00oooO`00
oooo0?ooo`0Y0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool02`3oool00onP8?00
oooo0?ooo`0=0?ooo`03oj0Pl03oool0oooo04H0oooo00?oX23`0?ooo`3oool0BP3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0=0?ooo`03oomo003oool0oooo00h0oooo
00?oogl00?ooo`3oool0T03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00@0oooo
00?oX23`0?ooo`3oool0ZP3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`0A0?ooo`03oomo003oool0oooo00D0oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?oo
o`030?ooo`03oomo003oool0oooo08T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`0A0?ooo`03oj0Pl03oooooX23`00;oX23`1`3oool00onP8?00oooo0?ooo`080?ooo`03oj0Pl03o
ool0oooo00T0oooo00?oX23`0?ooo`3oool01P3oool00onP8?00oooo0?ooo`1a0?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo01T0oooo00?oogl00?ooo`3oool03P3oool0
0oooO`00oooo0?ooo`0L0?ooo`03oomo003oool0oooo06D0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00/0oooo00?oX23`0?ooo`3oool00P3oool0
0onP8?00oooo0?ooo`0N0?ooo`03oj0Pl03oool0oooo07<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00?o00000?ooo`3oool04P3oool00oooO`00oooo0?ooo`090?ooo`05oomo003oool0oooo
0?ooooooO`00SP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0140oooo0_nP8?02
0?ooo`03oj0Pl03oool0oooo00T0oooo00GoX23`0?ooo`3oool0oooooj0Pl0060?ooo`03oj0Pl03o
ool0oooo00h0oooo00?oX23`0?ooo`3oool0L@3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
0ol00000oooo0?ooo`0L0?ooo`07oomo003oooooogl00?ooooooO`00oooooomo000_0?ooo`03oomo
003oool0oooo05`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`040?ooo`;oX23`
0`3oool01?nP8?00oooo0?oooonP8?040?ooo`03oj0Pl03oooooX23`0080oooo0onP8?00103ooooo
X23`0?ooo`3oool2oj0Pl0030?oooonP8?00oooo0080oooo0_nP8?2;0?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`03o`00003oool0oooo0180oooo00?oogl00?ooo`3oool02@3oool01?ooO`00
oooooomo003oool2oomo00`0oooo00?oogl00?ooo`3oool0OP3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo00P0oooo0_nP8?0:0?ooo`;oX23`7`3oool00onP8?00oooo0?ooo`1@0?oo
o`03oj0Pl03oool0oooo02H0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3o
ool08P3oool2oomo00040?ooooooO`00oooooomo0240oooo00?oogl00?ooo`3oool0I@3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00D0oooo00?oX23`0?ooo`3oool02@3oool00onP
8?00oooooj0Pl00@0?ooo`03oj0Pl03oooooX23`00H0oooo00?oX23`0?ooo`3oool02`3oool01?nP
8?00oooo0?ooo`3oool2oj0Pl2H0oooo00?oX23`0?ooo`3oool0A`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool00ol00000oooo0?ooo`0G0?ooo`03oomo003oool0oooo00/0oooo00Googl00?oo
ooooO`00oooooomo000P0?ooo`03oomo003oool0oooo06@0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`050?ooo`03oj0Pl03oool0oooo00T0oooo00?oX23`0?oooonP8?006`3oool0
0onP8?00oooo0?ooo`1o0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo
01H0oooo00Googl00?ooo`3oool0oooooomo002F0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool02@3oool01?nP8?00oooo0?oooonP8?030?ooo`03oj0Pl03oool0oooo00L0oooo00Go
X23`0?ooo`3oool0oooooj0Pl00@0?ooo`03oj0Pl03oool0oooo05P0oooo00?oX23`0?ooo`3oool0
903oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0M0?ooo`03oomo003o
ooooogl000@0oooo0_ooO`030?ooo`03oomo003oooooogl006@0oooo00?oogl00?ooo`3oool07P3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00/0oooo00?oX23`0?ooo`3oool02@3o
ool01OnP8?00oooo0?ooo`3oooooX23`0080oooo00CoX23`0?ooo`3oooooX23`0`3oool00onP8?00
oooo0?ooo`0=0?ooo`03oj0Pl03oool0oooo0540oooo00?oX23`0?ooo`3oool09@3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0G0?ooo`03oomo003oool0oooo00@0oooo
00?oogl00?ooo`3oool00`3oool01OooO`00oooo0?ooooooO`00oooo00;oogl01P3oool00oooO`00
oooo0?ooo`020?ooo`03oomo003oool0oooo07P0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0;0?ooo`03oj0Pl03oool0oooo00`0oooo00?oX23`0?ooo`3oool0203oool2oj0Pl3@0
oooo00?oX23`0?ooo`3oool0D`3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo
0?ooo`0F0?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool0103oool01?ooO`00oooo
0?ooo`3oool2oomo00H0oooo00?oogl00?ooooooO`00P03oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo00<0oooo00?oX23`0?ooo`3oool0303oool00onP8?00oooo0?ooo`030?ooo`;o
X23`1@3oool00onP8?00oooo0?ooo`0;0?ooo`03oj0Pl03oool0oooo01D0oooo00?oX23`0?ooo`3o
ool0J@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0T0?ooo`03oomo
003oool0oooo00P0oooo00?oogl00?ooo`3oool0603oool00oooO`00oooo0?ooo`1T0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool07@3oool00onP8?00oooo0?ooo`020?ooo`03oj0P
l03oool0oooo08`0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool08P3o
ool00oooO`00oooo0?ooo`050?ooo`03oomo003oool0oooo08@0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`070?ooo`08oj0Pl03oool0oooooj0Pl03oooooX23`0?oooonP8?0D0?oo
o`05oj0Pl03oooooX23`0?oooonP8?000`3oool00onP8?00oooo0?ooo`0<0?ooo`04oj0Pl03oool0
oooooj0Pl0<0oooo00?oX23`0?ooo`3oool0K@3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
0ol00000oooo0?ooo`0W0?ooo`04oomo003oooooogl0oomo00D0oooo00?oogl00?ooo`3oool05`3o
ool00oooO`00oooooomo001T0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0503o
ool01?nP8?00oooo0?oooonP8?020?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?ooo`3oool0
1P3oool00onP8?00oooo0?ooo`200?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003o
ool0oooo0200oooo00?oogl00?ooo`3oool00P3oool01OooO`00oooo0?ooo`3oooooogl008L0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0U0?ooo`03oj0Pl03oool0oooo00@0oooo
00?oX23`0?oooonP8?002`3oool01OnP8?00oooo0?ooo`3oooooX23`0780oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00?o00000?ooo`3oool09`3oool00oooO`00oooo0?ooo`060?ooo`;oogl0
0`3oool2oomo00<0oooo00?oogl00?ooo`3oool01@3oool00oooO`00oooo0?ooo`1/0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool04P3oool00onP8?00oooo0?ooo`0:0?ooo`04oj0P
l03oool0oooooj0Pl0<0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooo0?ooo`050?ooo`;o
X23`00<0oooooj0Pl?nP8?00L03oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo
0?ooo`0Y0?ooo`03oomo003oool0oooo00D0oooo00?oogl00?ooooooO`004@3oool00oooO`00oooo
0?ooo`1Y0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool08@3oool00onP8?00oooo
0?ooo`020?ooo`03oj0Pl03oool0oooo00;oX23`1@3oool00onP8?00oooo0?ooo`0;0?ooo`04oj0P
l03oool0oooo0?ooo`;oX23`K@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo
0?ooo`0T0?ooo`03oomo003oool0oooo00L0oooo00Coogl00?ooo`3oooooogl01P3oool00oooO`00
oooo0?ooo`0:0?ooo`;oogl0203oool00oooO`00oooo0?ooo`1O0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool01@3oool00onP8?00oooooj0Pl0070?ooo`03oj0Pl03oool0oooo00<0
oooo00?oX23`0?ooo`3oool01`3oool01OnP8?00oooo0?ooo`3oooooX23`00@0oooo1?nP8?001@3o
ooooX23`oj0Pl03oooooX23`00@0oooo00?oX23`0?ooo`3oool0103oool00onP8?00oooo0?ooo`03
oj0Pl0040?oooonP8?00oooooj0Pl6/0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o0000
0?ooo`3oool0;`3oool00oooO`00oooo0?ooo`1o0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool04P3oool00onP8?00oooo0?ooo`0F0?ooo`03oj0Pl03oool0oooo00/0oooo00?oX23`
0?ooo`3oool0303oool00onP8?00oooo0?ooo`1V0?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`03o`00003oool0oooo02D0oooo00?oogl00?ooo`3oool07@3oool00oooO`00oooo0?ooo`0Z0?oo
o`03oomo003oool0oooo03`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0]0?oo
o`03oj0Pl03oool0oooo01H0oooo00?oX23`0?ooo`3oool0J03oool00ol00000oooo0?ooo`090?oo
o`002P3oool00ol00000oooo0?ooo`0U0?ooo`04oomo003oool0oooooomo0080oooo0_ooO`040?oo
o`03oomo003oool0oooo00L0oooo00Coogl00?ooo`3oooooogl00P3oool2oomo00<0oooo00?oogl0
0?ooo`3oool0J03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01h0oooo00?oX23`
0?ooo`3oool01`3oool2oj0Pl080oooo00GoX23`0?oooonP8?00oooooj0Pl0020?ooo`03oj0Pl03o
ool0oooo00@0oooo00?oX23`0?ooo`3oool00_nP8?020?ooo`?oX23`0`3oool00onP8?00oooo0?oo
o`1W0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo04<0oooo00?oogl0
0?ooo`3oool0J`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02@0oooo00?oX23`
0?ooo`3oool00P3oool00onP8?00oooooj0Pl0030?ooo`04oj0Pl03oool0oooooj0Pl1<0oooo00?o
X23`0?ooo`3oool0J03oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0[
0?ooo`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool00P3oool01OooO`00oooooomo003o
ooooogl000@0oooo00Coogl00?ooo`3oooooogl00P3oool00oooO`00oooo0?ooo`1Y0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool02@3oool01OnP8?00oooo0?ooo`3oooooX23`01D0
oooo00?oX23`0?ooo`3oool00`3oool01_nP8?00oooo0?oooonP8?00oooooj0Pl0P0oooo00?oX23`
0?ooo`3oool01@3oool00onP8?00oooooj0Pl003oj0Pl0040?oooonP8?3oX23`oj0Pl1`0oooo00?o
X23`0?ooo`3oool0B@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0c
0?ooo`03oomo003oool0oooo00l0oooo00?oogl00?ooo`3oool0J@3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo02d0oooo0_nP8?000`3oooooX23`0?ooo`0B0?ooo`03oj0Pl03ooooo
X23`06X0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0AP3oool00ooo
O`00oooo0?ooo`0<0?ooo`03oomo003oool0oooo05T0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0?0?ooo`05oj0Pl03oool0oooo0?oooonP8?006@3oool00onP8?00oooo0?ooo`03
0?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`03
0?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool0G`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool00ol00000oooo0?ooo`0W0?ooo`03oomo003oool0oooo00`0oooo00Coogl00?oo
o`3oooooogl01P3oool00oooO`00oooo0?ooo`040?ooo`;oogl00P3oool00oooO`00oooo0?ooo`04
0?ooo`03oomo003oool0oooo05`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`04
0?ooo`03oj0Pl03oool0oooo01L0oooo00?oX23`0?ooo`3oool03@3oool01?nP8?00oooooj0Pl03o
ool2oj0Pl0040?oooonP8?3oX23`0?ooo`?oX23`00@0oooooj0Pl03oooooX23`1@3oool01?nP8?00
oooo0?oooonP8?1Y0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0300
oooo00?oogl00?ooo`3oool00oooO`0A0?ooo`03oomo003oooooogl000L0oooo00?oogl00?ooo`3o
ool0G@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00`0oooo00?oX23`0?ooo`3o
ool07`3oool2oj0Pl0050?oooonP8?3oX23`0?oooonP8?002@3oool00onP8?00oooo0?ooo`030?oo
o`03oj0Pl03oooooX23`06X0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3o
ool0;@3oool2oomo00030?ooooooO`00oooo00<0oooo00?oogl00?ooo`3oool00`3oool00oooO`00
oooo0?ooo`060?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool01`3oool00oooO`00
oooo0?ooo`1K0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0203oool00onP8?00
oooo0?ooo`0?0?ooo`03oj0Pl03oool0oooo00D0oooo0onP8?090?ooo`?oX23`0P3oool00onP8?00
oooo0?ooo`050?ooo`?oX23`1@3oool01_nP8?00oooooj0Pl?nP8?00oooooj0Pl6P0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0<`3oool00oooO`00oooo0?ooo`0=0?oo
o`03oomo003oool0oooo00l0oooo00?oogl00?ooo`3oool0F@3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo02d0oooo00GoX23`0?oooonP8?3oX23`0?ooo`02oj0Pl0H0oooo00?oX23`
0?ooo`3oool00`3oool2oj0Pl0030?oooonP8?00oooo00P0oooo00?oX23`0?ooo`3oool01P3oool0
0onP8?00oooo0?ooo`1H0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo
03H0oooo00Googl00?ooo`3oooooogl00?ooo`02oomo00D0oooo00Coogl00?ooooooO`3oogl00`3o
ool00oooO`00oooo0?ooo`0:0?ooo`03oomo003oool0oooo05P0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0<0?ooo`05oj0Pl03oool0oooo0?oooonP8?006P3oool00onP8?00oooo
0?ooo`040?ooo`03oj0Pl03oooooX23`00/0oooo0_nP8?060?ooo`;oX23`0`3oool00onP8?00oooo
0?ooo`1Q0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo04T0oooo00?o
ogl00?ooo`3oool0I@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02T0oooo00?o
X23`0?ooo`3oool01`3oool01?nP8?00oooo0?oooonP8?030?ooo`;oX23`1@3oool00onP8?00oooo
oj0Pl002oj0Pl080oooo00GoX23`0?ooo`3oool0oooooj0Pl01T0?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`03o`00003oool0oooo03@0oooo00?oogl00?ooooooO`00203oool00oooO`00oooo
0?ooo`020?ooo`03oomo003oool0oooo00@0oooo00Coogl00?ooo`3oooooogl0HP3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0oooo00?oX23`0?ooo`3oool0603oool00onP8?00
oooo0?ooo`020?ooo`03oj0Pl03oool0oooo01@0oooo00?oX23`0?ooo`3oool0HP3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0h0?ooo`;oogl02`3oool01?ooO`00oooo
0?ooooooO`050?ooo`03oomo003oool0oooo0600oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0I0?ooo`04oj0Pl03oool0oooooj0Pl0h0oooo0_nP8?000`3oooooX23`0?ooo`020?oo
o`08oj0Pl03oool0oooooj0Pl03oooooX23`0?oooonP8?020?ooo`03oj0Pl03oool0oooo00?oX23`
3@3oool00onP8?00oooo0?ooo`1O0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003o
ool0oooo0400oooo00?oogl00?ooo`3oool02@3oool4oomo00050?ooooooO`00oooo0?ooooooO`00
G03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01<0oooo00?oX23`0?ooo`3oool0
8P3oool00onP8?00oooooj0Pl0030?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3oool0
J03oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0h0?ooo`07oomo003o
ool0oooooomo003oooooogl00?ooo`02oomo00H0oooo00Googl00?ooo`3oool0oooooomo00020?oo
o`?oogl01@3oool00oooO`00oooo0?ooo`1H0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0703oool00onP8?00oooooj0Pl00?0?ooo`03oj0Pl03oool0oooo00@0oooo0_nP8?000`3o
ooooX23`0?ooo`020?ooo`08oj0Pl03oool0oooooj0Pl03oooooX23`0?oooonP8?1]0?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo03/0oooo00Ooogl00?ooo`3oool0oooo
oomo003oooooogl000L0oooo00?oogl00?ooo`3oool0103oool00oooO`00oooo0?ooo`1N0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0:@3oool00onP8?00oooooj0Pl0090?ooo`03
oj0Pl03oool0oooo00T0oooo00CoX23`0?oooonP8?3oX23`0P3oool01?nP8?00oooo0?oooonP8?05
0?ooo`03oj0Pl03oool0oooo05h0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?oo
o`3oool0A03oool00oooO`00oooo0?ooo`070?ooo`04oomo003oooooogl0oomo00T0oooo00?oogl0
0?ooo`3oool0D`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01@0oooo00?oX23`
0?ooo`3oool0103oool00onP8?00oooo0?ooo`0K0?ooo`03oj0Pl03oool0oooo0080oooo00GoX23`
0?ooo`3oool0oooooj0Pl0020?ooo`;oX23`00<0oooooj0Pl03oool0I`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool00ol00000oooo0?ooo`0c0?ooo`03oomo003oool0oooo00P0oooo00?oogl0
0?ooo`3oool01@3oool00oooO`00oooo0?ooo`02oomo0080oooo0_ooO`001P3oooooogl0oomo0?oo
O`00oooooomo05`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0>0?ooo`03oj0P
l03oool0oooo01@0oooo00?oX23`0?ooo`3oool03@3oool00onP8?00oooo0?ooo`020?ooo`03oj0P
l03oooooX23`00@0oooo0onP8?080?ooo`;oX23`0P3oool00onP8?00oooo0?ooo`1N0?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo03l0oooo00?oogl00?ooo`3oool0303o
ool00oooO`00oooooomo001P0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05`3o
ool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00l0oooo00?oX23`0?oooonP8?000`3o
ool2oj0Pl0H0oooo00?oX23`0?oooonP8?000P3oool00onP8?00oooooj0Pl0060?ooo`05oj0Pl03o
ool0oooo0?oooonP8?003`3oool2oj0Pl4`0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o
00000?ooo`3oool0@P3oool00oooO`00oooo0?ooo`040?ooo`03oomo003oool0oooo0080oooo0ooo
O`000`3oooooogl0oomo00040?ooo`05oomo003oool0oooo0?ooooooO`00E03oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo02@0oooo00CoX23`0?ooo`3oooooX23`1`3oool00onP8?00
oooo0?ooo`050?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool00`3oool7oj0Pl005
0?oooonP8?3oX23`0?oooonP8?000P3oool00onP8?00oooo0?ooo`1N0?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`03o`00003oool0oooo0480oooo00?oogl00?ooo`3oool0103oool00oooO`00
oooooomo00040?ooo`?oogl0103oool00oooO`00oooo0?ooo`1G0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool05P3oool00onP8?00oooooj0Pl0040?ooo`03oj0Pl03oool0oooo01T0
oooo00CoX23`0?oooonP8?3oX23`0`3oool5oj0Pl0030?oooonP8?3oX23`00GoX23`0P3oool00onP
8?00oooo0?ooo`0A0?ooo`03oj0Pl03oool0oooo04/0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00?o00000?ooo`3oool0@03oool00oooO`00oooo0?ooo`02oomo00D0oooo00?oogl00?ooo`3o
ool00P3oool2oomo00H0oooo00?oogl00?ooo`3oool0E`3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo01@0oooo00GoX23`0?ooo`3oool0oooooj0Pl0060?ooo`03oj0Pl03oool0oooo
00@0oooo00?oX23`0?oooonP8?004@3oool00onP8?00oooo0?ooo`060?ooo`03oj0Pl03oool0oooo
00?oX23`00<0oooooj0Pl03oool00onP8?060?ooo`03oj0Pl03oool0oooo00T0oooo00?oX23`0?oo
o`3oool0C@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`0m0?ooo`03
oomo003oool0oooo0080oooo00?oogl00?ooo`3oool02`3oool00oooO`00oooo0?ooo`030?ooo`03
oomo003oool0oooo05P0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0K0?ooo`05
oj0Pl03oool0oooo0?oooonP8?00703oool2oj0Pl0<0oooo00?oX23`0?ooo`3oool00P3oool5oj0P
l0D0oooo00?oX23`0?ooo`3oool0GP3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`180?ooo`04oomo003oool0oooooomo00D0oooo00?oogl00?ooo`3oool0G@3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00h0oooo00?oX23`0?ooo`3oool08@3oool01?nP
8?00oooooj0Pl?nP8?080?ooo`03oj0Pl03oool0oooo00;oX23`0`3oool00onP8?00oooo0?ooo`05
0?ooo`;oX23`5`3oool00onP8?00oooo0?ooo`170?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`03o`00003oool0oooo03h0oooo0_ooO`040?ooo`03oomo003oool0oooo01h0oooo00?oogl00?oo
o`3oool0B@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00h0oooo00?oX23`0?oo
o`3oool00P3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo00L0oooo00?oX23`0?oo
o`3oool08@3oool2oj0Pl0050?oooonP8?00oooo0?oooonP8?001P3oool00onP8?00oooo0?ooo`0;
0?ooo`;oX23`C@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`1:0?oo
o`03oomo003oool0oooo00@0oooo00Coogl00?ooo`3oooooogl0103oool00oooO`00oooo0?ooo`1E
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0@@3oool00onP8?00oooooj0Pl004
0?ooo`?oX23`00@0oooooj0Pl03oooooX23`1P3oool00onP8?00oooo0?ooo`0;0?ooo`03oj0Pl03o
ool0oooo00D0oooo00?oX23`0?ooo`3oool0@`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
0ol00000oooo0?ooo`160?ooo`Coogl00P3oool00oooO`00oooo0?ooo`030?ooo`03oomo003oool0
oooo05`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0>0?ooo`03oj0Pl03oool0
oooo00L0oooo00?oX23`0?ooo`3oool03P3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0
oooo00h0oooo00OoX23`0?oooonP8?3oX23`0?oooonP8?00oooo00?oX23`0P3oool3oj0Pl080oooo
00?oX23`0?ooo`3oool01`3oool00onP8?00oooooj0Pl0040?ooo`03oj0Pl03oool0oooo04/0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0D03oool00oooO`00oooo0?oo
o`020?ooo`03oomo003oool0oooo05T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`0m0?ooo`03oj0Pl03oool0oooo00@0oooo00CoX23`0?ooo`3oooooX23`1@3oool2oj0Pl0@0oooo
00?oX23`0?ooo`3oool0203oool01OnP8?00oooo0?ooo`3oooooX23`04h0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00?o00000?ooo`3oool0CP3oool00oooO`00oooooomo00040?ooo`03oomo
003oool0oooo05T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0M0?ooo`03oj0P
l03oool0oooo00X0oooo00?oX23`0?ooo`3oool00`3oool01OnP8?00oooo0?ooo`3oooooX23`0140
oooo0_nP8?030?ooo`CoX23`00@0oooooj0Pl?nP8?3oX23`503oool00onP8?00oooo0?ooo`170?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0500oooo00?oogl00?oooooo
O`00GP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0180oooo00?oX23`0?ooo`3o
ool02P3oool00onP8?00oooo0?ooo`0J0?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?ooo`3o
ool00_nP8?020?ooo`GoX23`00<0oooooj0Pl?nP8?000`3oool2oj0Pl0<0oooo00?oX23`0?oooonP
8?00103oool01?nP8?00oooo0?oooonP8?030?ooo`04oj0Pl03oool0oooo0?ooo`;oX23`00<0oooo
oj0Pl03oool0@@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`1>0?oo
o`03oomo003oool0oooo00H0oooo00?oogl00?ooo`3oool0E`3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo02<0oooo00CoX23`0?ooo`3oooooX23`8`3oool00onP8?00oooo0?ooo`02
0?ooo`;oX23`1@3oool01?nP8?00oooo0?ooo`3oool2oj0Pl0T0oooo00GoX23`0?ooo`3oool0oooo
oj0Pl0170?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo04/0oooo00?o
ogl00?ooo`3oool01`3oool00oooO`00oooooomo00090?ooo`03oomo003oool0oooo04d0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0@0?ooo`04oj0Pl03oool0oooooj0Pl0X0oooo
0_nP8?0F0?ooo`03oj0Pl03oool0oooo00d0oooo00?oX23`0?ooo`3oool00onP8?000`3oooooX23`
0?ooo`02oj0Pl0030?oooonP8?3oX23`00D0oooo00SoX23`0?ooo`3oooooX23`0?oooonP8?00oooo
oj0Pl080oooo00?oX23`0?ooo`3oool0B`3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol0
0000oooo0?ooo`1H0?ooo`03oomo003oool0oooo05H0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0l0?ooo`05oj0Pl03oool0oooo0?oooonP8?003`3oool00onP8?00oooo0?ooo`03
0?ooo`03oj0Pl03oool0oooo0080oooo00CoX23`0?ooo`3oooooX23`203oool2oj0Pl4P0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0AP3oool00oooO`00oooo0?ooo`03
0?ooo`04oomo003oooooogl0oomo0080oooo00Coogl00?ooo`3oooooogl00`3oool2oomo05H0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0M0?ooo`03oj0Pl03oooooX23`00@0oooo
00?oX23`0?ooo`3oool01`3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0oooo0180oooo
00CoX23`0?ooo`3oooooX23`0P3oool3oj0Pl0030?oooonP8?00oooo00;oX23`00@0oooooj0Pl03o
ooooX23`103oool00onP8?00oooo0?ooo`020?ooo`05oj0Pl03oooooX23`0?oooonP8?00A`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`1I0?ooo`03oomo003oool0oooo
05D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0D0?ooo`03oj0Pl03oool0oooo
02D0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooo0?ooo`030?ooo`05oj0Pl03oooooX23`
0?oooonP8?000P3oool01OnP8?00oooo0?ooo`3oooooX23`00L0oooo00?oX23`0?ooo`3oool01P3o
ool00onP8?00oooo0?ooo`120?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0
oooo0580oooo00?oogl00?ooo`3oool0103oool00oooO`00oooo0?ooo`1E0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool08P3oool00onP8?00oooo0?ooo`0E0?ooo`03oj0Pl03oool0
oooo0140oooo0onP8?070?ooo`;oX23`00<0oooooj0Pl?nP8?00E03oool00ol00000oooo0?ooo`09
0?ooo`002P3oool00ol00000oooo0?ooo`1E0?ooo`06oomo003oooooogl0oomo003oooooogl01P3o
ool00oooO`00oooo0?ooo`0?0?ooo`03oomo003oool0oooo03/0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo00@0oooo0_nP8?0=0?ooo`04oj0Pl03o
ool0oooooj0Pl1D0oooo00?oX23`0?ooo`3oool0103oool00onP8?00oooooj0Pl0020?ooo`;oX23`
103oool00onP8?00oooo0?ooo`07oj0Pl080oooo00?oX23`0?ooo`3oool01@3oool01onP8?00oooo
oj0Pl03oooooX23`0?oooonP8?001@3oool00onP8?00oooo0?ooo`0o0?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0I0?ooo`03oj0Pl03oool0oooo00T0oooo00?oX23`0?ooo`3oool0603oool00onP8?00
oooo0?ooo`0?0?ooo`;oX23`00D0oooooj0Pl03oool0oooooj0Pl0020?ooo`;oX23`1`3oool2oj0P
l080oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`110?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`03o`00003oool0oooo05/0oooo0_ooO`020?ooo`03oomo003oool0oooo04l0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0B0?ooo`03oj0Pl03oool0oooo0140
oooo00?oX23`0?ooo`3oool0303oool01OnP8?00oooo0?ooo`3oooooX23`00<0oooo00?oX23`0?oo
o`3oool0203oool00onP8?00oooooj0Pl0020?ooo`03oj0Pl03oool0oooo0080oooo0onP8?000`3o
ooooX23`oj0Pl002oj0Pl0H0oooo0_nP8?00103oooooX23`oj0Pl03oool3oj0Pl4P0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0BP3oool00oooO`00oooo0?ooo`040?oo
o`03oomo003oool0oooo00T0oooo00?oogl00?ooooooO`00D@3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo0180oooo00?oX23`0?ooo`3oool0<@3oool00onP8?00oooooj0Pl0040?oo
o`03oj0Pl03oool0oooo00D0oooo00GoX23`0?ooo`3oooooX23`0?ooo`02oj0Pl080oooo00KoX23`
0?oooonP8?3oX23`0?oooonP8?040?ooo`03oj0Pl03oool0oooo00L0oooo00?oX23`0?ooo`3oool0
?03oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`1B0?ooo`03oomo003o
ool0oooo00@0oooo00?oogl00?ooo`3oool0E@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo03<0oooo00?oX23`0?ooo`3oool0503oool2oj0Pl080oooo00GoX23`0?ooo`3oool0oooo
oj0Pl00=0?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?oooonP8?00@`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`1;0?ooo`03oomo003oool0oooo00D0oooo00?o
ogl00?ooo`3oool0103oool3oomo00@0oooo0_ooO`1>0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0>03oool00onP8?00oooo0?ooo`0=0?ooo`;oX23`1P3oool01_nP8?00oooooj0P
l03oooooX23`0?ooo`;oX23`00<0oooooj0Pl?nP8?001?nP8?00103oooooX23`0?ooo`3oool2oj0P
l080oooo1_nP8?000`3oooooX23`0?ooo`030?ooo`03oj0Pl03oool0oooo03/0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00?o00000?ooo`3oool0A@3oool00oooO`00oooo0?ooo`0?0?ooo`;o
ogl0F03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01`0oooo00?oX23`0?ooo`3o
ool0<P3oool2oj0Pl0H0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooooj0Pl0030?ooo`;o
X23`1P3oool01OnP8?00oooo0?ooo`3oooooX23`0400oooo00?o00000?ooo`3oool02@3oool000X0
oooo00?o00000?ooo`3oool0E@3oool00oooO`00oooo0?ooo`080?ooo`03oomo003oool0oooo00D0
oooo00?oogl00?ooo`3oool0AP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0
oooo00?oX23`0?ooo`3oool0303oool00onP8?00oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo00T0
oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooooj0Pl0020?ooo`04oj0Pl03oool0oooo0?oo
o`CoX23`0P3oool01OnP8?00oooo0?ooo`3oooooX23`0080oooo00GoX23`0?oooonP8?3oX23`0?oo
o`02oj0Pl400oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0E`3oool0
0oooO`00oooo0?ooo`080?ooo`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool0AP3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0140oooo00GoX23`0?ooo`3oool0oooooj0P
l0020?ooo`03oj0Pl03oool0oooo01D0oooo00?oX23`0?ooo`3oool05@3oool01?nP8?00oooo0?oo
o`3oool2oj0Pl0H0oooo00GoX23`0?ooo`3oool0oooooj0Pl0050?ooo`03oj0Pl03oool0oooo00/0
oooo00?oX23`0?ooo`3oool0@P3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo
0?ooo`1?0?ooo`03oomo003oool0oooo00<0oooo00Coogl00?ooo`3oooooogl00`3oool2oomo0080
oooo00?oogl00?ooo`3oool0CP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01X0
oooo00?oX23`0?ooo`3oool04@3oool00onP8?00oooooj0Pl00=0?ooo`03oj0Pl03oool0oooo00h0
oooo00?oX23`0?ooo`3oool00`3oool2oj0Pl0<0oooo00?oX23`0?ooo`3oool01onP8?030?ooo`03
oj0Pl03oool0oooo0080oooo00CoX23`0?oooonP8?3oX23`@@3oool00ol00000oooo0?ooo`090?oo
o`002P3oool00ol00000oooo0?ooo`1G0?ooo`03oomo003oool0oooo0080oooo00?oogl00?oooooo
O`00DP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01@0oooo00?oX23`0?ooo`3o
ool04P3oool00onP8?00oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo00X0oooo00GoX23`0?ooo`3o
ool0oooooj0Pl00?0?ooo`03oj0Pl03oooooX23`00?oX23`103oool02?nP8?00oooo0?oooonP8?00
oooooj0Pl03oooooX23`1P3oool00onP8?00oooo0?ooo`0k0?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`03o`00003oool0oooo05T0oooo00?oogl00?ooo`3oool0E@3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo05T0oooo00?oX23`0?ooo`3oool0103oool2oj0Pl0030?oooonP
8?00oooo0080oooo00GoX23`0?oooonP8?00oooooj0Pl0030?ooo`03oj0Pl03oool0oooo03l0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0E@3oool00oooO`00oooo0?oo
o`040?ooo`04oomo003oool0oooooomo00D0oooo0_ooO`000`3oooooogl00?ooo`170?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0603oool00onP8?00oooo0?ooo`0E0?ooo`03oj0P
l03oool0oooo00@0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`0D0?ooo`04oj0P
l03oool0oooooj0Pl080oooo00GoX23`0?oooonP8?00oooooj0Pl0020?ooo`05oj0Pl03oool0oooo
oj0Pl03oool00_nP8?001@3oooooX23`0?oooonP8?00oooo00;oX23`00@0oooooj0Pl?nP8?3oX23`
?`3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`1M0?ooo`03oomo003o
ool0oooo0540oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1:0?ooo`03oj0Pl03o
ool0oooo00T0oooo00?oX23`0?ooo`3oool0203oool00onP8?00oooooj0Pl0060?ooo`06oj0Pl03o
ool0oooo0?oooonP8?00oooo0_nP8?060?ooo`03oj0Pl03oool0oooo03H0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00?o00000?ooo`3oool0EP3oool01?ooO`00oooo0?ooooooO`060?ooo`07
oomo003oooooogl00?ooooooO`00oooooomo00040?ooo`;oogl0A03oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo01P0oooo00?oX23`0?ooo`3oool0603oool00onP8?00oooo0?ooo`0R
0?ooo`03oj0Pl03oool0oooo00<0oooo1?nP8?000`3oooooX23`oj0Pl003oj0Pl080oooo0onP8?02
0?ooo`?oX23`0`3oool00onP8?00oooo0?ooo`0i0?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`03o`00003oool0oooo06L0oooo0_ooO`180?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0HP3oool01?nP8?00oooo0?ooo`3oool2oj0Pl0<0oooo00CoX23`0?oooonP8?3oX23`0P3o
ool00onP8?00oooooj0Pl00m0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0
oooo05`0oooo00Coogl00?ooo`3oooooogl0D@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo0640oooo00?oX23`0?oooonP8?001`3oool00onP8?00oooooj0Pl0130?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo05X0oooo00?oogl00?ooo`3oool00`3oool2
oomo00070?ooooooO`00oooo0?ooooooO`00oooooomo00180?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0DP3oool00onP8?00oooo0?ooo`080?ooo`04oj0Pl03oool0oooooj0Pl080
oooo00OoX23`0?ooo`3oool0oooooj0Pl03oooooX23`0080oooo00?oX23`0?ooo`3oool00onP8?0o
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo05`0oooo00Googl00?oo
o`3oool0oooooomo00080?ooo`03oomo003oool0oooo04D0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`1E0?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?ooo`3oool00`3oool3
oj0Pl0040?oooonP8?00oooooj0Pl0<0oooo0_nP8?060?ooo`;oX23`103oool01OnP8?00oooo0?oo
o`3oooooX23`03<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0G@3o
ool00oooO`00oooo0?ooo`030?ooo`;oogl0103oool01?ooO`00oooo0?ooooooO`140?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool06P3oool01?nP8?00oooo0?oooonP8?0d0?ooo`03
oj0Pl03oooooX23`00/0oooo00OoX23`0?oooonP8?3oX23`0?oooonP8?00oooo00?oX23`0P3oool2
oj0Pl0030?oooonP8?3oX23`00;oX23`103oool00onP8?00oooo0?ooo`060?ooo`03oj0Pl03oool0
oooo02h0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0IP3oool00ooo
O`00oooo0?ooo`020?ooo`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool0?@3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01X0oooo00?oX23`0?ooo`3oool0A@3oool2oj0P
l0040?oooonP8?00oooooj0Pl0@0oooo0_nP8?080?ooo`;oX23`>@3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool00ol00000oooo0?ooo`1Q0?ooo`?oogl00`3oool00oooO`00oooo0?ooo`02oomo
00030?ooooooO`00oooo0480oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0H0?oo
o`03oj0Pl03oool0oooo03h0oooo00?oX23`0?ooo`3oool00P3oool01?nP8?00oooooj0Pl?nP8?02
0?ooo`;oX23`00L0oooooj0Pl?nP8?00oooooj0Pl03oooooX23`0080oooo0_nP8?020?ooo`03oj0P
l03oool0oooo0080oooo00CoX23`0?ooo`3oooooX23`=@3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool00ol00000oooo0?ooo`1R0?ooo`04oomo003oool0oooo0?ooo`;oogl00P3oool2oomo04D0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1Z0?ooo`;oX23`00@0oooooj0Pl03o
ool0oooo0_nP8?060?ooo`03oj0Pl03oool0oooo03H0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00?o00000?ooo`3oool0J03oool2oomo04L0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0M0?ooo`03oj0Pl03oool0oooo04D0oooo1?nP8?030?ooo`04oj0Pl03oool0oooooj0P
l0@0oooo00?oX23`0?oooonP8?001P3oool00onP8?00oooooj0Pl00a0?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`03o`00003oool0oooo06D0oooo00?oogl00?ooo`3oool00`3oool4oomo00D0
oooo00?oogl00?ooo`3oool0>P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01/0
oooo00?oX23`0?ooo`3oool02P3oool00onP8?00oooo0?ooo`0G0?ooo`03oj0Pl03oool0oooo00`0
oooo00?oX23`0?ooo`3oool0203oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oooooX23`00;o
X23`1@3oool00onP8?00oooo0?ooo`02oj0Pl0030?oooonP8?00oooo00<0oooo00?oX23`0?ooo`3o
ool00onP8?0c0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo06T0oooo
0_ooO`030?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool0>`3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo01H0oooo00?oX23`0?ooo`3oool0E03oool01?nP8?00oooo
0?ooo`3oool2oj0Pl0H0oooo00?oX23`0?ooo`3oool00_nP8?0c0?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`03o`00003oool0oooo06P0oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo
oomo00020?ooo`06oomo003oool0oooooomo003oooooogl0>@3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo01l0oooo0_nP8?0<0?ooo`03oj0Pl03oool0oooo01l0oooo00?oX23`0?oo
o`3oool00`3oool00onP8?00oooo0?ooo`0=0?ooo`04oj0Pl03oooooX23`0?ooo`;oX23`2P3oool2
oj0Pl0@0oooo00?oX23`0?ooo`3oool00_nP8?0a0?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`170?oo
o`04oj0Pl03oool0oooooj0Pl1T0oooo00?oX23`0?oooonP8?000P3oool2oj0Pl0T0oooo00?oX23`
0?oooonP8?001P3oool3oj0Pl340oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?oo
o`3oool0L03oool00oooO`00oooo0?ooo`0n0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0HP3oool01OnP8?00oooo0?oooonP8?00oooo00;oX23`00<0oooooj0Pl03oool01`3oool0
0onP8?00oooo0?ooo`080?ooo`;oX23`00@0oooooj0Pl03oooooX23`;@3oool00ol00000oooo0?oo
o`090?ooo`002P3oool00ol00000oooo0?ooo`1U0?ooo`03oomo003oool0oooo0080oooo00?oogl0
0?ooo`3oool00_ooO`080?ooo`03oomo003oool0oooo03L0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`0W0?ooo`03oj0Pl03oool0oooo00l0oooo00?oX23`0?ooo`3oool08@3oool0
0onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo00D0oooo0_nP8?001P3oooooX23`oj0Pl03o
ooooX23`0?ooo`;oX23`1P3oool01?nP8?00oooooj0Pl03oool2oj0Pl0030?oooonP8?3oX23`02d0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0LP3oool3oomo03`0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1_0?ooo`03oj0Pl03oool0oooo00;oX23`
203oool01?nP8?00oooo0?ooo`3oool2oj0Pl2l0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00?o00000?ooo`3oool0KP3oool00oooO`00oooo0?ooo`020?ooo`05oomo003oooooogl00?oooooo
O`004P3oool00oooO`00oooo0?ooo`0T0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0G`3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?oooonP
8?000onP8?000`3oooooX23`0?ooo`020?ooo`;oX23`00<0oooooj0Pl03oool01@3oool4oj0Pl080
oooo00?oX23`0?ooo`3oool0:@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo
0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0F`3oool00onP8?00oooo
0?ooo`070?ooo`03oj0Pl03oool0oooo00H0oooo00CoX23`0?oooonP8?3oX23`0`3oool01?nP8?00
oooo0?oooonP8?060?ooo`06oj0Pl03oool0oooooj0Pl03oooooX23`;03oool00ol00000oooo0?oo
o`090?ooo`002P3oool00ol00000oooo0?ooo`1a0?ooo`?oogl0?@3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo0240oooo00?oX23`0?ooo`3oool0>P3oool00onP8?00oooo0?ooo`06
0?ooo`03oj0Pl03oool0oooo00H0oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooooj0Pl009
0?ooo`05oj0Pl03oooooX23`0?oooonP8?00:P3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
0ol00000oooo0?ooo`1_0?ooo`04oomo003oool0oooooomo03h0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`1]0?ooo`04oj0Pl03oooooX23`0?ooo`CoX23`00H0oooooj0Pl03ooooo
X23`0?oooonP8?050?ooo`04oj0Pl03oooooX23`oj0Pl080oooo0_nP8?0Y0?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`03o`00003oool0oooo0700oooo0_ooO`090?ooo`03oomo003oool0oooo
00H0oooo00?oogl00?ooo`3oool0:P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
06T0oooo00CoX23`0?ooo`3oooooX23`103oool00onP8?00oooo0?ooo`060?ooo`04oj0Pl03oool0
oooooj0Pl0H0oooo00CoX23`0?ooo`3oooooX23`:@3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool00ol00000oooo0?ooo`1a0?ooo`;oogl0103oool2oomo00030?ooooooO`00oooo03D0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0f0?ooo`03oj0Pl03oool0oooo03P0oooo0_nP
8?00103oooooX23`0?oooonP8?020?ooo`04oj0Pl03oooooX23`oj0Pl080oooo0_nP8?000`3ooooo
X23`0?ooo`030?ooo`03oj0Pl03oool0oooo02L0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00?o00000?ooo`3oool0M03oool2oomo0080oooo00?oogl00?ooo`3oool0=P3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo06l0oooo00CoX23`0?ooo`3oool0oooo0_nP8?070?ooo`04
oj0Pl03oool0oooooj0Pl0<0oooo00?oX23`0?ooo`3oool00_nP8?000`3oooooX23`0?ooo`0V0?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo06l0oooo00?oogl00?oooooo
O`000`3oool01?ooO`00oooooomo003oool2oomo00030?ooooooO`3oogl003<0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0[0?ooo`03oj0Pl03oool0oooo03/0oooo00OoX23`0?oo
o`3oool0oooooj0Pl03oooooX23`00@0oooo00CoX23`0?oooonP8?00oooo0_nP8?00103oooooX23`
0?oooonP8?020?ooo`05oj0Pl03oool0oooooj0Pl03oool00_nP8?0Z0?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`03o`00003oool0oooo07@0oooo00?oogl00?ooo`3oool02@3oool01?ooO`00
oooo0?ooooooO`0]0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0903oool00onP
8?00oooo0?ooo`1<0?ooo`03oj0Pl03oool0oooo00?oX23`103oool2oj0Pl0030?oooonP8?00oooo
00@0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`0S0?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`03o`00003oool0oooo07L0oooo00?oogl00?ooo`3oool01P3oool00oooO`00
oooo0?ooo`0^0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0=03oool00onP8?00
oooo0?ooo`0_0?ooo`03oj0Pl03oool0oooo00l0oooo0_nP8?000`3oooooX23`oj0Pl0020?ooo`Co
X23`1P3oool00onP8?00oooo0?ooo`0U0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00
003oool0oooo07@0oooo0_ooO`040?ooo`;oogl00`3oool00oooO`00oooo0?ooo`030?ooo`03oomo
003oool0oooo02T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1c0?ooo`;oX23`
0P3oool01OnP8?00oooooj0Pl?nP8?00oooo00;oX23`00@0oooooj0Pl03oooooX23`0P3oool00onP
8?00oooo0?ooo`030?ooo`?oX23`903oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`1i0?ooo`03oomo003oool0oooo00H0oooo00?oogl00?ooo`3oool0;03oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo01l0oooo00?oX23`0?ooo`3oool0D@3oool00onP8?00
oooo0?ooo`040?ooo`03oj0Pl03oool0oooo00;oX23`103oool00onP8?00oooo0?ooo`030?ooo`03
oj0Pl03oooooX23`02D0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0
N@3oool01OooO`00oooo0?ooooooO`00oooo00Coogl00P3oool00oooO`00oooooomo000Z0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool08`3oool00onP8?00oooo0?ooo`1;0?ooo`03
oj0Pl03oool0oooo0080oooo00CoX23`0?oooonP8?00oooo1onP8?000`3oooooX23`0?ooo`02oj0P
l0060?oooonP8?00oooooj0Pl03oooooX23`9@3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
0ol00000oooo0?ooo`1o0?ooo`;oogl000<0oooooomo003oool01P3oool00oooO`00oooo0?ooo`0T
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0L@3oool00onP8?00oooo0?ooo`07
0?ooo`03oj0Pl03oooooX23`00<0oooo00?oX23`0?ooo`3oool01P3oool2oj0Pl2D0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0N@3oool01?ooO`00oooo0?ooooooO`07
0?ooo`;oogl0:`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03H0oooo00?oX23`
0?ooo`3oool0>P3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo00<0oooo0_nP8?03
0?ooo`05oj0Pl03oool0oooo0?oooonP8?001@3oool00onP8?00oooo0?ooo`0P0?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0840oooo00?oogl00?ooo`3oool00P3oool0
0oooO`00oooo0?ooo`0X0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool08`3oool0
1?nP8?00oooo0?oooonP8?130?ooo`03oj0Pl03oooooX23`00@0oooo00?oX23`0?ooo`3oool01P3o
ool01?nP8?00oooo0?ooo`3oool3oj0Pl0@0oooo0onP8?060?ooo`03oj0Pl03oool0oooo0200oooo
00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0P@3oool2oomo02h0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1m0?ooo`03oj0Pl03oooooX23`0080oooo00Co
X23`0?oooonP8?3oX23`:`3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`1n0?ooo`03oomo003oooooogl000?oogl0;@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo0680oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03o
ool0oooo00`0oooo1?nP8?000`3oooooX23`0?ooo`0X0?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`03o`00003oool0oooo07/0oooo0_ooO`030?ooo`03oomo003oool0oooo00<0oooo00?oogl0
0?ooo`3oool0:03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02D0oooo00?oX23`
0?ooo`3oool0F03oool00onP8?00oooo0?ooo`02oj0Pl0050?oooonP8?00oooo0?oooonP8?009`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`1k0?ooo`;oogl01P3oool0
0oooO`00oooooomo0003oomo02P0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`21
0?ooo`04oj0Pl03oool0oooooj0Pl080oooo00?oX23`0?oooonP8?009`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool00ol00000oooo0?ooo`1o0?ooo`03oomo003oool0oooo0080oooo1?ooO`03
0?ooo`03oomo003oool0oooo02<0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0_
0?ooo`03oj0Pl03oool0oooo0440oooo00?oX23`0?ooo`3oool0303oool00onP8?00oooo0?ooo`0/
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0800oooo00?oogl00?oo
o`3oool00oooO`000`3oooooogl00?ooo`0X0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0PP3oool2oj0Pl0H0oooo00?oX23`0?ooo`3oool0903oool00ol00000oooo0?ooo`090?oo
o`002P3oool00ol00000oooo0?ooo`230?ooo`03oomo003oool0oooo00?oogl000<0oooooomo003o
ool09@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02H0oooo00?oX23`0?ooo`3o
ool0303oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo03<0oooo00?oX23`0?ooo`3o
ool03P3oool00onP8?00oooooj0Pl0030?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?ooo`3o
ool0803oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`240?ooo`05oomo
003oooooogl00?ooooooO`000`3oool01?ooO`00oooooomo0?ooO`030?ooo`03oomo003oool0oooo
01/0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`270?ooo`03oj0Pl03oool0oooo
02L0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0P`3oool01OooO`00
oooo0?ooo`3oooooogl00080oooo00Coogl00?ooo`3oooooogl08`3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo02L0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`1G
0?ooo`?oX23`0P3oool00onP8?00oooo0?ooo`0S0?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`03o`00003oool0oooo08<0oooo00?oogl00?ooo`3oool01P3oool00oooO`00oooo0?ooo`0R0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0GP3oool00onP8?00oooo0?ooo`0Q0?oo
o`03oj0Pl03oool0oooo00@0oooo00?oX23`0?oooonP8?009@3oool00ol00000oooo0?ooo`090?oo
o`002P3oool00ol00000oooo0?ooo`280?ooo`03oomo003oooooogl00080oooo00Googl00?ooo`3o
ool0oooooomo000O0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool09P3oool00onP
8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo04d0oooo00GoX23`0?ooo`3oool0oooooj0Pl004
0?ooo`03oj0Pl03oool0oooo02D0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?oo
o`3oool0QP3oool00oooO`00oooo0?ooo`030?ooo`?oogl00`3oool01?ooO`00oooo0?ooooooO`0K
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0NP3oool00onP8?00oooo0?ooo`06
0?ooo`05oj0Pl03oool0oooo0?oooonP8?000`3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03o
ool0oooo01d0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0P`3oool0
0oooO`00oooo0?ooo`02oomo00@0oooo0_ooO`00103oooooogl00?ooooooO`0O0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0R03oool2oj0Pl2L0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00?o00000?ooo`3oool0S03oool2oomo00030?ooooooO`00oooo0080oooo00?oogl0
0?ooo`3oool06`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0840oooo00CoX23`
0?oooonP8?3oX23`103oool2oj0Pl0030?oooonP8?3oX23`00D0oooo00?oX23`0?oooonP8?006`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`290?ooo`Coogl000<0oooo
oomo0?ooO`001P3oool00oooO`00oooo0?ooo`0H0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0Q@3oool01?nP8?00oooooj0Pl?nP8?030?ooo`03oj0Pl03oool0oooo00@0oooo00?o
X23`0?ooo`3oool01`3oool00onP8?00oooo0?ooo`0A0?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`03o`00003oool0oooo08L0oooo00Ooogl00?ooo`3oooooogl00?ooooooO`00oooo00Coogl0
0P3oool00oooO`00oooo0?ooo`0J0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
:`3oool00onP8?00oooo0?ooo`1B0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0
0P3oool3oj0Pl0<0oooo00?oX23`0?oooonP8?007P3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool00ol00000oooo0?ooo`280?ooo`03oomo003oooooogl000<0oooo1?ooO`020?ooo`03oomo003o
ool0oooo01X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`270?ooo`03oj0Pl03o
ool0oooo00@0oooo00CoX23`0?oooonP8?3oX23`7`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool00ol00000oooo0?ooo`2<0?ooo`03oomo003oool0oooo00Googl00P3oool00oooO`00oooo0?oo
o`0H0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0>P3oool00onP8?00oooo0?oo
o`1<0?ooo`04oj0Pl03oooooX23`oj0Pl080oooo0onP8?0O0?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`03o`00003oool0oooo08h0oooo1oooO`000`3oooooogl0oomo00030?ooo`03oomo003o
ool0oooo01<0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0j0?ooo`03oj0Pl03o
ool0oooo04X0oooo00GoX23`0?oooonP8?00oooooj0Pl0030?ooo`05oj0Pl03oooooX23`0?oooonP
8?007@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2@0?ooo`Koogl0
6`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0300oooo00?oX23`0?ooo`3oool0
E@3oool2oj0Pl0050?oooonP8?00oooo0?oooonP8?00103oool00onP8?00oooo0?ooo`0K0?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0940oooo1_ooO`00103oooooogl0
oomo0?ooO`0F0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0R@3oool01onP8?00
oooooj0Pl?nP8?00oooooj0Pl03oool00_nP8?000`3oooooX23`oj0Pl0070?ooo`03oj0Pl03oool0
oooo0180oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0T@3oool7oomo
01T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1o0?ooo`03oj0Pl03oool0oooo
00`0oooo00CoX23`0?oooonP8?00oooo0_nP8?020?ooo`03oj0Pl03oool0oooo01P0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0T03oool2oomo00<0oooo1?ooO`0H0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0S03oool01?nP8?00oooo0?ooo`3oool2
oj0Pl0030?oooonP8?00oooo01`0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?oo
o`3oool0TP3oool7oomo00030?ooooooO`3oogl001D0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0n0?ooo`03oj0Pl03oool0oooo02L0oooo00?oX23`0?ooo`3oool07@3oool2oj0P
l0D0oooo00?oX23`0?ooo`3oool01?nP8?0K0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03
o`00003oool0oooo08l0oooo00?oogl00?ooo`3oool00`3oool6oomo01H0oooo00?o00000?ooo`3o
ool03`3oool00ol00000oooo0?ooo`2@0?ooo`;oX23`00<0oooooj0Pl?nP8?00703oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2B0?ooo`04oomo003oool0oooo0?ooo`So
ogl04`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo06<0oooo00?oX23`0?ooo`3o
ool09P3oool00onP8?00oooo0?ooo`030?ooo`GoX23`6P3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool00ol00000oooo0?ooo`2H0?ooo`Coogl05@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo09@0oooo00CoX23`0?ooo`3oooooX23`0`3oool00onP8?00oooo0?ooo`0C0?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo09X0oooo1?ooO`0C0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0@03oool2oj0Pl4l0oooo00CoX23`0?ooo`3oool0
oooo0onP8?050?ooo`03oj0Pl03oool0oooo0140oooo00?o00000?ooo`3oool02@3oool000X0oooo
00?o00000?ooo`3oool0V`3oool01?ooO`00oooo0?ooooooO`0B0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0L@3oool00onP8?00oooo0?ooo`0Q0?ooo`03oj0Pl03oool0oooo0080
oooo00CoX23`0?ooo`3oooooX23`4`3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`2M0?ooo`?oogl04@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo09H0
oooo00GoX23`0?oooonP8?00oooooj0Pl00F0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03
o`00003oool0oooo09/0oooo00?oogl00?ooooooO`000_ooO`0A0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0SP3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo0080
oooo0_nP8?040?ooo`03oj0Pl03oool0oooo00l0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00?o00000?ooo`3oool0W`3oool00oooO`00oooo0?ooo`0?0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0K@3oool00onP8?00oooo0?ooo`0K0?ooo`03oj0Pl03oool0oooo00`0oooo
00CoX23`0?ooo`3oool0oooo0_nP8?0A0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00
003oool0oooo0;40oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1:0?ooo`03oj0P
l03oool0oooo0380oooo00?oX23`0?ooo`3oool05@3oool00onP8?00oooo0?ooo`020?ooo`03oj0P
l03oool0oooo0180oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0XP3o
ool2oomo00d0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`150?ooo`03oj0Pl03o
ool0oooo05/0oooo00?oX23`0?ooo`3oool02`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
0ol00000oooo0?ooo`2M0?ooo`03oomo003oool0oooo00<0oooo00?oogl00?ooo`3oool02`3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo08l0oooo00?oX23`0?ooo`3oool07`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0B03oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oool0oooo
00T0oooo00?oX23`0?ooo`3oool05@3oool00onP8?00oooo0?ooo`0^0?ooo`;oX23`00<0oooooj0P
l03oool02P3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2O0?ooo`03
oomo003oool0oooo0080oooo00?oogl00?ooooooO`002P3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo07d0oooo00?oX23`0?ooo`3oool08`3oool00onP8?00oooooj0Pl00;0?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0:L0oooo00?oogl00?ooo`3oool0
1`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo07h0oooo00?oX23`0?ooo`3oool0
0`3oool00onP8?00oooo0?ooo`0J0?ooo`;oX23`0`3oool00onP8?00oooo0?ooo`080?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`1P0?ooo`03oj0Pl03oool0oooo04h0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00?o00000?ooo`3oool0W@3oool00oooO`00oooo0?ooo`050?ooo`Coogl01`3oool0
0oooO`3o00000?ooo`0@0?ooo`03o`00003oool0oooo04P0oooo00?oX23`0?ooo`3oool01P3oool0
0onP8?00oooo0?ooo`1=0?ooo`03oj0Pl03oool0oooo00d0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00?o00000?ooo`3oool0Z03oool00oooO`00oooo0?ooo`060?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0G`3oool00onP8?00oooo0?ooo`150?ooo`04oj0Pl03oool0oooo
oj0Pl0H0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0:P0oooo00CoX23`0?ooo`3oooooX23`1@3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0CP3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo
05X0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo09<0oooo00?oX23`0?ooo`3oool06`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0E@3oool00onP8?00oooo0?ooo`120?ooo`03oj0Pl03oool0oooo00l0oooo
0_nP8?030?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`03o`00003oool0oooo0:`0oooo00Ko
ogl00?ooo`3oooooogl00?ooool0000A0?ooo`03o`00003oool0oooo09h0oooo00?oX23`0?ooo`3o
ool00P3oool00onP8?00oooo0?ooo`0:0?ooo`03oj0Pl?l00000oooo00X0oooo000:0?ooo`03o`00
003oool0oooo0:l0oooo00?oogl00?ooool000004@3oool00ol00000oooo0?ooo`2C0?ooo`03oj0P
l03oool0oooo01T0oooo0_nP8?000ol00000oooo0?ooo`090?ooo`002P3ooonco`000003oomo0?l0
0000oooo0100ooooIol000000onP8?3o0000o`000002o`000003oj0Pl?l0003o000000So00000_nP
8?0Qo`000003oj0Pl?l0003o000000;o000000?oX23`o`000?l000003_l000001OnP8?3o0000o`00
0?nP8?3o000000/0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-14.4237, \
-6.63736, 1.4157, 1.4157}, {{208.5, 388.938}, {184.875, 4.5}} -> {-295.249, \
-6.59083, 1.41521, 1.41521}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EM experiment #1: object 1 (Coke can)", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[
    \(\(d2d1 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ \((data1/255. )\))\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 3;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices (custom)", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ {{{ .1,  .1}, { .5,  .5}, { .9,  .9}}, \
\[IndentingNewLine]Table[DiagonalMatrix[{ .1,  .1}], {3}], {1. , 1. , 1. }/
            3. };\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[d2d1, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.7800000000000011`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsubsection"],

Cell[BoxData[{
    \(\(bad = Position[em, Indeterminate];\)\), "\[IndentingNewLine]", 
    \(\(If[Length[bad] > 0, 
        bad = \(bad // First\) // First];\)\ \), "\[IndentingNewLine]", 
    \(\(em\  = \ 
        If[NumberQ[bad] \[Equal] True, Take[em, {1, bad - 1}], 
          em];\)\), "\[IndentingNewLine]", 
    \(\(model1 = em // Last;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EMAllPlot[model1, g1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .0794 m
.03846 .0961 L
.03853 .09615 L
.05769 .11288 L
.06103 .11538 L
.07692 .12878 L
.08459 .13462 L
.09615 .1438 L
.10929 .15385 L
.11538 .15834 L
.13462 .17283 L
.13521 .17308 L
.15385 .18757 L
.16495 .19231 L
.17308 .20083 L
.19 .21154 L
.19231 .213 L
.21154 .22138 L
.22081 .23077 L
.23077 .23665 L
.25 .24574 L
.26304 .25 L
.26923 .25252 L
.27922 .25 L
.27687 .23077 L
.26923 .21806 L
.26375 .21154 L
.25 .19311 L
.24906 .19231 L
.23222 .17308 L
.23077 .17135 L
.21385 .15385 L
.21154 .15126 L
.19446 .13462 L
.19231 .13235 L
.17425 .11538 L
.17308 .11422 L
.15385 .09652 L
.15339 .09615 L
.13462 .07902 L
.13192 .07692 L
.11538 .0622 L
.10956 .05769 L
.09615 .04621 L
.08626 .03846 L
.07692 .02818 L
.06209 .01923 L
.01923 .01923 L
F
0 g
.01923 .0794 m
.03846 .0961 L
.03853 .09615 L
.05769 .11288 L
.06103 .11538 L
.07692 .12878 L
.08459 .13462 L
.09615 .1438 L
.10929 .15385 L
.11538 .15834 L
.13462 .17283 L
.13521 .17308 L
.15385 .18757 L
.16495 .19231 L
.17308 .20083 L
.19 .21154 L
.19231 .213 L
.21154 .22138 L
.22081 .23077 L
.23077 .23665 L
.25 .24574 L
.26304 .25 L
.26923 .25252 L
.27922 .25 L
.27687 .23077 L
.26923 .21806 L
.26375 .21154 L
.25 .19311 L
.24906 .19231 L
.23222 .17308 L
.23077 .17135 L
.21385 .15385 L
.21154 .15126 L
.19446 .13462 L
.19231 .13235 L
.17425 .11538 L
.17308 .11422 L
.15385 .09652 L
.15339 .09615 L
.13462 .07902 L
.13192 .07692 L
.11538 .0622 L
.10956 .05769 L
.09615 .04621 L
.08626 .03846 L
.07692 .02818 L
.06209 .01923 L
s
.2 g
.01923 .07131 m
.02653 .07692 L
.03846 .08831 L
.04825 .09615 L
.05769 .10445 L
.07162 .11538 L
.07692 .1198 L
.09613 .13462 L
.09615 .13463 L
.11538 .1501 L
.12318 .15385 L
.13462 .16444 L
.15074 .17308 L
.15385 .17736 L
.17308 .18906 L
.17741 .19231 L
.19231 .19847 L
.21154 .21119 L
.21241 .21154 L
.23077 .21808 L
.24136 .21154 L
.23208 .19231 L
.23077 .18928 L
.21559 .17308 L
.21154 .16419 L
.19767 .15385 L
.19231 .14657 L
.18351 .13462 L
.17308 .12931 L
.16388 .11538 L
.15385 .10549 L
.14318 .09615 L
.13462 .08801 L
.12147 .07692 L
.11538 .07139 L
.09879 .05769 L
.09615 .05542 L
.07692 .04058 L
.07465 .03846 L
.05769 .02567 L
.04808 .01923 L
.01923 .01923 L
F
0 g
.01923 .07131 m
.02653 .07692 L
.03846 .08831 L
.04825 .09615 L
.05769 .10445 L
.07162 .11538 L
.07692 .1198 L
.09613 .13462 L
.09615 .13463 L
.11538 .1501 L
.12318 .15385 L
.13462 .16444 L
.15074 .17308 L
.15385 .17736 L
.17308 .18906 L
.17741 .19231 L
.19231 .19847 L
.21154 .21119 L
.21241 .21154 L
.23077 .21808 L
.24136 .21154 L
.23208 .19231 L
.23077 .18928 L
.21559 .17308 L
.21154 .16419 L
.19767 .15385 L
.19231 .14657 L
.18351 .13462 L
.17308 .12931 L
.16388 .11538 L
.15385 .10549 L
.14318 .09615 L
.13462 .08801 L
.12147 .07692 L
.11538 .07139 L
.09879 .05769 L
.09615 .05542 L
.07692 .04058 L
.07465 .03846 L
.05769 .02567 L
.04808 .01923 L
s
.3 g
.01923 .06545 m
.03331 .07692 L
.03846 .0824 L
.05508 .09615 L
.05769 .09845 L
.07692 .11364 L
.07895 .11538 L
.09615 .12677 L
.10461 .13462 L
.11538 .14469 L
.13106 .15385 L
.13462 .15805 L
.15385 .17074 L
.15783 .17308 L
.17308 .18235 L
.19171 .19231 L
.19231 .19249 L
.21154 .19839 L
.21811 .19231 L
.21154 .17878 L
.20849 .17308 L
.19251 .15385 L
.19231 .15307 L
.17583 .13462 L
.17308 .13406 L
.15668 .11538 L
.15385 .11247 L
.1362 .09615 L
.13462 .09461 L
.11538 .07761 L
.11446 .07692 L
.09615 .06223 L
.09104 .05769 L
.07692 .04869 L
.06611 .03846 L
.05769 .03056 L
.04085 .01923 L
.01923 .01923 L
F
0 g
.01923 .06545 m
.03331 .07692 L
.03846 .0824 L
.05508 .09615 L
.05769 .09845 L
.07692 .11364 L
.07895 .11538 L
.09615 .12677 L
.10461 .13462 L
.11538 .14469 L
.13106 .15385 L
.13462 .15805 L
.15385 .17074 L
.15783 .17308 L
.17308 .18235 L
.19171 .19231 L
.19231 .19249 L
.21154 .19839 L
.21811 .19231 L
.21154 .17878 L
.20849 .17308 L
.19251 .15385 L
.19231 .15307 L
.17583 .13462 L
.17308 .13406 L
.15668 .11538 L
.15385 .11247 L
.1362 .09615 L
.13462 .09461 L
.11538 .07761 L
.11446 .07692 L
.09615 .06223 L
.09104 .05769 L
.07692 .04869 L
.06611 .03846 L
.05769 .03056 L
.04085 .01923 L
s
.4 g
.01923 .06024 m
.03808 .07692 L
.03846 .07738 L
.05769 .09491 L
.06047 .09615 L
.07692 .10882 L
.08472 .11538 L
.09615 .12174 L
.11025 .13462 L
.11538 .1399 L
.13462 .15281 L
.13626 .15385 L
.15385 .16568 L
.16742 .17308 L
.17308 .17672 L
.19231 .18253 L
.19881 .17308 L
.19231 .16298 L
.18642 .15385 L
.17308 .13847 L
.17121 .13462 L
.15385 .11808 L
.15125 .11538 L
.13462 .09931 L
.13064 .09615 L
.11538 .0816 L
.10864 .07692 L
.09615 .06729 L
.08524 .05769 L
.07692 .05351 L
.06107 .03846 L
.05769 .03447 L
.03846 .01961 L
.03823 .01923 L
.01923 .01923 L
F
0 g
.01923 .06024 m
.03808 .07692 L
.03846 .07738 L
.05769 .09491 L
.06047 .09615 L
.07692 .10882 L
.08472 .11538 L
.09615 .12174 L
.11025 .13462 L
.11538 .1399 L
.13462 .15281 L
.13626 .15385 L
.15385 .16568 L
.16742 .17308 L
.17308 .17672 L
.19231 .18253 L
.19881 .17308 L
.19231 .16298 L
.18642 .15385 L
.17308 .13847 L
.17121 .13462 L
.15385 .11808 L
.15125 .11538 L
.13462 .09931 L
.13064 .09615 L
.11538 .0816 L
.10864 .07692 L
.09615 .06729 L
.08524 .05769 L
.07692 .05351 L
.06107 .03846 L
.05769 .03447 L
.03846 .01961 L
.03823 .01923 L
s
.5 g
.01923 .05571 m
.02089 .05769 L
.03846 .07364 L
.04161 .07692 L
.05769 .09358 L
.06473 .09615 L
.07692 .10534 L
.08923 .11538 L
.09615 .11866 L
.1146 .13462 L
.11538 .13543 L
.13462 .14866 L
.1432 .15385 L
.15385 .1606 L
.17308 .16846 L
.17951 .15385 L
.17308 .14561 L
.16813 .13462 L
.15385 .12308 L
.14716 .11538 L
.13462 .10347 L
.12622 .09615 L
.11538 .08449 L
.10419 .07692 L
.09615 .07077 L
.08115 .05769 L
.07692 .05606 L
.05804 .03846 L
.05769 .03799 L
.03846 .02242 L
.03653 .01923 L
.01923 .01923 L
F
0 g
.01923 .05571 m
.02089 .05769 L
.03846 .07364 L
.04161 .07692 L
.05769 .09358 L
.06473 .09615 L
.07692 .10534 L
.08923 .11538 L
.09615 .11866 L
.1146 .13462 L
.11538 .13543 L
.13462 .14866 L
.1432 .15385 L
.15385 .1606 L
.17308 .16846 L
.17951 .15385 L
.17308 .14561 L
.16813 .13462 L
.15385 .12308 L
.14716 .11538 L
.13462 .10347 L
.12622 .09615 L
.11538 .08449 L
.10419 .07692 L
.09615 .07077 L
.08115 .05769 L
.07692 .05606 L
.05804 .03846 L
.05769 .03799 L
.03846 .02242 L
.03653 .01923 L
s
.6 g
.01923 .05159 m
.02449 .05769 L
.03846 .07007 L
.04469 .07692 L
.05769 .09227 L
.06849 .09615 L
.07692 .10252 L
.09327 .11538 L
.09615 .11663 L
.11538 .13159 L
.11989 .13462 L
.13462 .14447 L
.15176 .15385 L
.15385 .15498 L
.1702 .15385 L
.16272 .13462 L
.15385 .12851 L
.14316 .11538 L
.13462 .10769 L
.12239 .09615 L
.11538 .08745 L
.10056 .07692 L
.09615 .07343 L
.07798 .05769 L
.07692 .05735 L
.05769 .04136 L
.05379 .03846 L
.03846 .02555 L
.03207 .01923 L
.01923 .01923 L
F
0 g
.01923 .05159 m
.02449 .05769 L
.03846 .07007 L
.04469 .07692 L
.05769 .09227 L
.06849 .09615 L
.07692 .10252 L
.09327 .11538 L
.09615 .11663 L
.11538 .13159 L
.11989 .13462 L
.13462 .14447 L
.15176 .15385 L
.15385 .15498 L
.1702 .15385 L
.16272 .13462 L
.15385 .12851 L
.14316 .11538 L
.13462 .10769 L
.12239 .09615 L
.11538 .08745 L
.10056 .07692 L
.09615 .07343 L
.07798 .05769 L
.07692 .05735 L
.05769 .04136 L
.05379 .03846 L
.03846 .02555 L
.03207 .01923 L
s
.7 g
.01923 .04721 m
.02844 .05769 L
.03846 .06642 L
.04809 .07692 L
.05769 .08963 L
.07239 .09615 L
.07692 .09966 L
.09615 .11421 L
.09772 .11538 L
.11538 .1278 L
.12607 .13462 L
.13462 .13994 L
.15289 .13462 L
.13826 .11538 L
.13462 .11229 L
.11854 .09615 L
.11538 .09165 L
.09717 .07692 L
.09615 .07606 L
.07692 .05989 L
.07426 .05769 L
.05769 .04473 L
.04912 .03846 L
.03846 .02915 L
.02116 .01923 L
.01923 .01923 L
F
0 g
.01923 .04721 m
.02844 .05769 L
.03846 .06642 L
.04809 .07692 L
.05769 .08963 L
.07239 .09615 L
.07692 .09966 L
.09615 .11421 L
.09772 .11538 L
.11538 .1278 L
.12607 .13462 L
.13462 .13994 L
.15289 .13462 L
.13826 .11538 L
.13462 .11229 L
.11854 .09615 L
.11538 .09165 L
.09717 .07692 L
.09615 .07606 L
.07692 .05989 L
.07426 .05769 L
.05769 .04473 L
.04912 .03846 L
.03846 .02915 L
.02116 .01923 L
s
.8 g
.01923 .04203 m
.03291 .05769 L
.03846 .06248 L
.0526 .07692 L
.05769 .08429 L
.07692 .09607 L
.07702 .09615 L
.09615 .11042 L
.10297 .11538 L
.11538 .12371 L
.13218 .11538 L
.11538 .09755 L
.11414 .09615 L
.09615 .07976 L
.09316 .07692 L
.07692 .06343 L
.06994 .05769 L
.05769 .04824 L
.04392 .03846 L
.03846 .03353 L
.01923 .0225 L
F
0 g
.01923 .04203 m
.03291 .05769 L
.03846 .06248 L
.0526 .07692 L
.05769 .08429 L
.07692 .09607 L
.07702 .09615 L
.09615 .11042 L
.10297 .11538 L
.11538 .12371 L
.13218 .11538 L
.11538 .09755 L
.11414 .09615 L
.09615 .07976 L
.09316 .07692 L
.07692 .06343 L
.06994 .05769 L
.05769 .04824 L
.04392 .03846 L
.03846 .03353 L
.01923 .0225 L
s
.9 g
.03846 .03978 m
.05769 .05211 L
.06511 .05769 L
.07692 .06728 L
.08861 .07692 L
.09615 .0842 L
.10911 .09615 L
.11538 .10399 L
.12482 .11538 L
.11538 .1188 L
.10963 .11538 L
.09615 .10619 L
.08212 .09615 L
.07692 .09175 L
.05862 .07692 L
.05769 .07598 L
.03846 .05779 L
.03835 .05769 L
F
0 g
.03846 .03978 m
.05769 .05211 L
.06511 .05769 L
.07692 .06728 L
.08861 .07692 L
.09615 .0842 L
.10911 .09615 L
.11538 .10399 L
.12482 .11538 L
.11538 .1188 L
.10963 .11538 L
.09615 .10619 L
.08212 .09615 L
.07692 .09175 L
.05862 .07692 L
.05769 .07598 L
.03846 .05779 L
.03835 .05769 L
.03846 .03978 L
s
1 g
.05769 .05691 m
.05881 .05769 L
.07692 .0719 L
.08313 .07692 L
.09615 .09004 L
.10254 .09615 L
.09615 .10079 L
.08887 .09615 L
.07692 .08629 L
.06485 .07692 L
.05769 .0688 L
.04675 .05769 L
F
0 g
.05769 .05691 m
.05881 .05769 L
.07692 .0719 L
.08313 .07692 L
.09615 .09004 L
.10254 .09615 L
.09615 .10079 L
.08887 .09615 L
.07692 .08629 L
.06485 .07692 L
.05769 .0688 L
.04675 .05769 L
.05769 .05691 L
s
.1 g
.59615 .57444 m
.60016 .57692 L
.61538 .5859 L
.62792 .59615 L
.63462 .60103 L
.65084 .61538 L
.65385 .61684 L
.67203 .63462 L
.67308 .63566 L
.69226 .65385 L
.69231 .65391 L
.71154 .67263 L
.71201 .67308 L
.73077 .6919 L
.73119 .69231 L
.7499 .71154 L
.75 .71166 L
.76789 .73077 L
.76923 .73224 L
.78507 .75 L
.78846 .75358 L
.80498 .76923 L
.80769 .77578 L
.82273 .78846 L
.82692 .7934 L
.84006 .80769 L
.84615 .81503 L
.85688 .82692 L
.86538 .83737 L
.87308 .84615 L
.88462 .86063 L
.88861 .86538 L
.90362 .88462 L
.90385 .88493 L
.92088 .90385 L
.92308 .90938 L
.93333 .92308 L
.94231 .93612 L
.94569 .94231 L
.95656 .96154 L
.94231 .97128 L
.93186 .96154 L
.92308 .95556 L
.90752 .94231 L
.90385 .93947 L
.8857 .92308 L
.88462 .92266 L
.86538 .90417 L
.86502 .90385 L
.84615 .88574 L
.84494 .88462 L
.82692 .86672 L
.82553 .86538 L
.80769 .84719 L
.80664 .84615 L
.78846 .82721 L
.78818 .82692 L
.77043 .80769 L
.76923 .80645 L
.7536 .78846 L
.75 .78483 L
.73369 .76923 L
.73077 .76238 L
.71613 .75 L
.71154 .74448 L
.69903 .73077 L
.69231 .72253 L
.68251 .71154 L
.67308 .69977 L
.66665 .69231 L
.65385 .67597 L
.65147 .67308 L
.63627 .65385 L
.63462 .65148 L
.61921 .63462 L
.61538 .62599 L
.60747 .61538 L
.59615 .59674 L
.59582 .59615 L
.58998 .57692 L
F
0 g
.59615 .57444 m
.60016 .57692 L
.61538 .5859 L
.62792 .59615 L
.63462 .60103 L
.65084 .61538 L
.65385 .61684 L
.67203 .63462 L
.67308 .63566 L
.69226 .65385 L
.69231 .65391 L
.71154 .67263 L
.71201 .67308 L
.73077 .6919 L
.73119 .69231 L
.7499 .71154 L
.75 .71166 L
.76789 .73077 L
.76923 .73224 L
.78507 .75 L
.78846 .75358 L
.80498 .76923 L
.80769 .77578 L
.82273 .78846 L
.82692 .7934 L
.84006 .80769 L
.84615 .81503 L
.85688 .82692 L
.86538 .83737 L
.87308 .84615 L
.88462 .86063 L
.88861 .86538 L
.90362 .88462 L
.90385 .88493 L
.92088 .90385 L
.92308 .90938 L
.93333 .92308 L
.94231 .93612 L
.94569 .94231 L
.95656 .96154 L
.94231 .97128 L
.93186 .96154 L
.92308 .95556 L
.90752 .94231 L
.90385 .93947 L
.8857 .92308 L
.88462 .92266 L
.86538 .90417 L
.86502 .90385 L
.84615 .88574 L
Mistroke
.84494 .88462 L
.82692 .86672 L
.82553 .86538 L
.80769 .84719 L
.80664 .84615 L
.78846 .82721 L
.78818 .82692 L
.77043 .80769 L
.76923 .80645 L
.7536 .78846 L
.75 .78483 L
.73369 .76923 L
.73077 .76238 L
.71613 .75 L
.71154 .74448 L
.69903 .73077 L
.69231 .72253 L
.68251 .71154 L
.67308 .69977 L
.66665 .69231 L
.65385 .67597 L
.65147 .67308 L
.63627 .65385 L
.63462 .65148 L
.61921 .63462 L
.61538 .62599 L
.60747 .61538 L
.59615 .59674 L
.59582 .59615 L
.58998 .57692 L
.59615 .57444 L
Mfstroke
.2 g
.67308 .65095 m
.67506 .65385 L
.69231 .66712 L
.69809 .67308 L
.71154 .68616 L
.72576 .69231 L
.73077 .70585 L
.73916 .71154 L
.75 .72596 L
.75541 .73077 L
.76923 .74649 L
.77213 .75 L
.78846 .7673 L
.79457 .76923 L
.80769 .78806 L
.81183 .78846 L
.82692 .80602 L
.82843 .80769 L
.84474 .82692 L
.84615 .82865 L
.8609 .84615 L
.86538 .85197 L
.87636 .86538 L
.88462 .87689 L
.89062 .88462 L
.90192 .90385 L
.88462 .91203 L
.88115 .90385 L
.86538 .89483 L
.85818 .88462 L
.84615 .87473 L
.83719 .86538 L
.82692 .85459 L
.81348 .84615 L
.80769 .8343 L
.79927 .82692 L
.78846 .81368 L
.78314 .80769 L
.76923 .79269 L
.76672 .78846 L
.75 .77151 L
.74426 .76923 L
.73077 .7506 L
.7276 .75 L
.71164 .73077 L
.71154 .73065 L
.69558 .71154 L
.69231 .70728 L
.68016 .69231 L
.67308 .68242 L
.66584 .67308 L
.65395 .65385 L
F
0 g
.67308 .65095 m
.67506 .65385 L
.69231 .66712 L
.69809 .67308 L
.71154 .68616 L
.72576 .69231 L
.73077 .70585 L
.73916 .71154 L
.75 .72596 L
.75541 .73077 L
.76923 .74649 L
.77213 .75 L
.78846 .7673 L
.79457 .76923 L
.80769 .78806 L
.81183 .78846 L
.82692 .80602 L
.82843 .80769 L
.84474 .82692 L
.84615 .82865 L
.8609 .84615 L
.86538 .85197 L
.87636 .86538 L
.88462 .87689 L
.89062 .88462 L
.90192 .90385 L
.88462 .91203 L
.88115 .90385 L
.86538 .89483 L
.85818 .88462 L
.84615 .87473 L
.83719 .86538 L
.82692 .85459 L
.81348 .84615 L
.80769 .8343 L
.79927 .82692 L
.78846 .81368 L
.78314 .80769 L
.76923 .79269 L
.76672 .78846 L
.75 .77151 L
.74426 .76923 L
.73077 .7506 L
.7276 .75 L
.71164 .73077 L
.71154 .73065 L
.69558 .71154 L
.69231 .70728 L
.68016 .69231 L
.67308 .68242 L
Mistroke
.66584 .67308 L
.65395 .65385 L
.67308 .65095 L
Mfstroke
.3 g
.71154 .69852 m
.72699 .71154 L
.73077 .71452 L
.74785 .73077 L
.75 .73269 L
.76705 .75 L
.76923 .75212 L
.7853 .76923 L
.78846 .77252 L
.80286 .78846 L
.80769 .79383 L
.81978 .80769 L
.82692 .81619 L
.83594 .82692 L
.84615 .84012 L
.85094 .84615 L
.84615 .86115 L
.82826 .84615 L
.82692 .84509 L
.80779 .82692 L
.80769 .82683 L
.78887 .80769 L
.78846 .8073 L
.77086 .78846 L
.76923 .78677 L
.75352 .76923 L
.75 .76531 L
.73681 .75 L
.73077 .74278 L
.72083 .73077 L
.71154 .71865 L
.706 .71154 L
F
0 g
.71154 .69852 m
.72699 .71154 L
.73077 .71452 L
.74785 .73077 L
.75 .73269 L
.76705 .75 L
.76923 .75212 L
.7853 .76923 L
.78846 .77252 L
.80286 .78846 L
.80769 .79383 L
.81978 .80769 L
.82692 .81619 L
.83594 .82692 L
.84615 .84012 L
.85094 .84615 L
.84615 .86115 L
.82826 .84615 L
.82692 .84509 L
.80779 .82692 L
.80769 .82683 L
.78887 .80769 L
.78846 .8073 L
.77086 .78846 L
.76923 .78677 L
.75352 .76923 L
.75 .76531 L
.73681 .75 L
.73077 .74278 L
.72083 .73077 L
.71154 .71865 L
.706 .71154 L
.71154 .69852 L
s
.4 g
.75 .74682 m
.75344 .75 L
.76923 .76369 L
.77443 .76923 L
.78846 .78365 L
.79266 .78846 L
.80769 .80604 L
.809 .80769 L
.80769 .81206 L
.80299 .80769 L
.78846 .79523 L
.78222 .78846 L
.76923 .77507 L
.76427 .76923 L
.75 .75223 L
.74832 .75 L
F
0 g
.75 .74682 m
.75344 .75 L
.76923 .76369 L
.77443 .76923 L
.78846 .78365 L
.79266 .78846 L
.80769 .80604 L
.809 .80769 L
.80769 .81206 L
.80299 .80769 L
.78846 .79523 L
.78222 .78846 L
.76923 .77507 L
.76427 .76923 L
.75 .75223 L
.74832 .75 L
.75 .74682 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .52321 .66807 .51694 Mtetra
.663 .741 .908 r
.66807 .51694 .67349 .52321 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51642 .69076 .51011 Mtetra
.69076 .51011 .69612 .51642 .7075 .513 .70218 .50667 Mtetra
.70218 .50667 .7075 .513 .71893 .50958 .71364 .50322 Mtetra
.71364 .50322 .71893 .50958 .73041 .50614 .72515 .49975 Mtetra
.72515 .49975 .73041 .50614 .74193 .50269 .7367 .49628 Mtetra
.7367 .49628 .74193 .50269 .7535 .49922 .7483 .49279 Mtetra
.663 .742 .908 r
.7483 .49279 .7535 .49922 .76511 .49574 .75995 .48929 Mtetra
.75995 .48929 .76511 .49574 .77678 .49225 .77165 .48577 Mtetra
.77165 .48577 .77678 .49225 .78849 .48875 .78339 .48224 Mtetra
.663 .742 .909 r
.78339 .48224 .78849 .48875 .80024 .48523 .79519 .4787 Mtetra
.79519 .4787 .80024 .48523 .81205 .4817 .80703 .47515 Mtetra
.80703 .47515 .81205 .4817 .82391 .47815 .81892 .47158 Mtetra
.81892 .47158 .82391 .47815 .83581 .47459 .83086 .46799 Mtetra
.83086 .46799 .83581 .47459 .84776 .47102 .84285 .46439 Mtetra
.84285 .46439 .84776 .47102 .85977 .46743 .85488 .46077 Mtetra
.85488 .46077 .85977 .46743 .87182 .46382 .86697 .45714 Mtetra
.86697 .45714 .87182 .46382 .88392 .46019 .87911 .45349 Mtetra
.87911 .45349 .88392 .46019 .89607 .45655 .8913 .44982 Mtetra
.66 .741 .91 r
.8913 .44982 .89607 .45655 .90827 .45289 .90355 .44623 Mtetra
.61 .723 .925 r
.90355 .44623 .90827 .45289 .92054 .44932 .91603 .4441 Mtetra
.233 .571 .94 r
.91603 .4441 .92054 .44932 .93301 .447 .92932 .44802 Mtetra
.446 0 0 r
.92932 .44802 .93301 .447 .94614 .44926 .94284 .45279 Mtetra
0 0 0 r
.94284 .45279 .94614 .44926 .9593 .45101 .95455 .44292 Mtetra
.832 .768 .79 r
.95455 .44292 .9593 .45101 .9711 .44206 .96586 .43006 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .65131 .51405 Mtetra
.663 .741 .908 r
.65131 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .5072 Mtetra
.67397 .5072 .67939 .51353 .69076 .51011 .68537 .50375 Mtetra
.68537 .50375 .69076 .51011 .70218 .50667 .69682 .50028 Mtetra
.69682 .50028 .70218 .50667 .71364 .50322 .70831 .49681 Mtetra
.70831 .49681 .71364 .50322 .72515 .49975 .71985 .49332 Mtetra
.663 .742 .908 r
.71985 .49332 .72515 .49975 .7367 .49628 .73144 .48982 Mtetra
.73144 .48982 .7367 .49628 .7483 .49279 .74307 .48631 Mtetra
.74307 .48631 .7483 .49279 .75995 .48929 .75475 .48279 Mtetra
.663 .742 .909 r
.75475 .48279 .75995 .48929 .77165 .48577 .76649 .47925 Mtetra
.76649 .47925 .77165 .48577 .78339 .48224 .77826 .4757 Mtetra
.77826 .4757 .78339 .48224 .79519 .4787 .79009 .47213 Mtetra
.79009 .47213 .79519 .4787 .80703 .47515 .80197 .46855 Mtetra
.80197 .46855 .80703 .47515 .81892 .47158 .81389 .46496 Mtetra
.81389 .46496 .81892 .47158 .83086 .46799 .82587 .46135 Mtetra
.82587 .46135 .83086 .46799 .84285 .46439 .83789 .45772 Mtetra
.663 .743 .909 r
.83789 .45772 .84285 .46439 .85488 .46077 .84997 .45408 Mtetra
.84997 .45408 .85488 .46077 .86697 .45714 .86209 .45042 Mtetra
.86209 .45042 .86697 .45714 .87911 .45349 .87427 .44674 Mtetra
.66 .741 .91 r
.87427 .44674 .87911 .45349 .8913 .44982 .8865 .44314 Mtetra
.604 .72 .927 r
.8865 .44314 .8913 .44982 .90355 .44623 .89898 .44115 Mtetra
.092 .483 .896 r
.89898 .44115 .90355 .44623 .91603 .4441 .91242 .44677 Mtetra
.643 .111 0 r
.91242 .44677 .91603 .4441 .92932 .44802 .92636 .45543 Mtetra
0 0 0 r
.92636 .45543 .92932 .44802 .94284 .45279 .93806 .44512 Mtetra
.876 .785 .757 r
.93806 .44512 .94284 .45279 .95455 .44292 .94894 .4285 Mtetra
.704 .617 .758 r
.94894 .4285 .95455 .44292 .96586 .43006 .96096 .42079 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51116 Mtetra
.663 .741 .908 r
.63448 .51116 .64004 .51746 .65131 .51405 .64578 .50772 Mtetra
.64578 .50772 .65131 .51405 .66261 .51063 .65712 .50428 Mtetra
.65712 .50428 .66261 .51063 .67397 .5072 .6685 .50082 Mtetra
.6685 .50082 .67397 .5072 .68537 .50375 .67994 .49734 Mtetra
.67994 .49734 .68537 .50375 .69682 .50028 .69141 .49386 Mtetra
.69141 .49386 .69682 .50028 .70831 .49681 .70294 .49036 Mtetra
.663 .742 .908 r
.70294 .49036 .70831 .49681 .71985 .49332 .71451 .48685 Mtetra
.71451 .48685 .71985 .49332 .73144 .48982 .72613 .48333 Mtetra
.663 .742 .909 r
.72613 .48333 .73144 .48982 .74307 .48631 .7378 .47979 Mtetra
.7378 .47979 .74307 .48631 .75475 .48279 .74952 .47624 Mtetra
.74952 .47624 .75475 .48279 .76649 .47925 .76128 .47268 Mtetra
.76128 .47268 .76649 .47925 .77826 .4757 .7731 .46911 Mtetra
.7731 .46911 .77826 .4757 .79009 .47213 .78496 .46552 Mtetra
.78496 .46552 .79009 .47213 .80197 .46855 .79687 .46192 Mtetra
.663 .743 .909 r
.79687 .46192 .80197 .46855 .81389 .46496 .80883 .4583 Mtetra
.80883 .4583 .81389 .46496 .82587 .46135 .82084 .45467 Mtetra
.82084 .45467 .82587 .46135 .83789 .45772 .8329 .45102 Mtetra
.8329 .45102 .83789 .45772 .84997 .45408 .84501 .44734 Mtetra
.84501 .44734 .84997 .45408 .86209 .45042 .85717 .44365 Mtetra
.66 .742 .91 r
.85717 .44365 .86209 .45042 .87427 .44674 .86939 .44003 Mtetra
.6 .719 .928 r
.86939 .44003 .87427 .44674 .8865 .44314 .88185 .43812 Mtetra
0 .389 .837 r
.88185 .43812 .8865 .44314 .89898 .44115 .89542 .44535 Mtetra
.739 .259 .105 r
.89542 .44535 .89898 .44115 .91242 .44677 .90984 .45866 Mtetra
.231 0 .181 r
.90984 .45866 .91242 .44677 .92636 .45543 .92163 .44877 Mtetra
.92 .806 .717 r
.92163 .44877 .92636 .45543 .93806 .44512 .93202 .42761 Mtetra
.71 .594 .724 r
.93202 .42761 .93806 .44512 .94894 .4285 .9438 .41785 Mtetra
.67 .655 .826 r
.9438 .41785 .94894 .4285 .96096 .42079 .9563 .4134 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.663 .741 .908 r
.6176 .50825 .62323 .51458 .63448 .51116 .62888 .50481 Mtetra
.62888 .50481 .63448 .51116 .64578 .50772 .64021 .50135 Mtetra
.64021 .50135 .64578 .50772 .65712 .50428 .65158 .49788 Mtetra
.65158 .49788 .65712 .50428 .6685 .50082 .663 .49439 Mtetra
.663 .49439 .6685 .50082 .67994 .49734 .67446 .49089 Mtetra
.67446 .49089 .67994 .49734 .69141 .49386 .68597 .48738 Mtetra
.663 .742 .908 r
.68597 .48738 .69141 .49386 .70294 .49036 .69753 .48386 Mtetra
.69753 .48386 .70294 .49036 .71451 .48685 .70914 .48033 Mtetra
.663 .742 .909 r
.70914 .48033 .71451 .48685 .72613 .48333 .72079 .47679 Mtetra
.72079 .47679 .72613 .48333 .7378 .47979 .73249 .47323 Mtetra
.73249 .47323 .7378 .47979 .74952 .47624 .74424 .46966 Mtetra
.74424 .46966 .74952 .47624 .76128 .47268 .75604 .46608 Mtetra
.75604 .46608 .76128 .47268 .7731 .46911 .76789 .46249 Mtetra
.663 .743 .909 r
.76789 .46249 .7731 .46911 .78496 .46552 .77979 .45888 Mtetra
.663 .743 .91 r
.77979 .45888 .78496 .46552 .79687 .46192 .79173 .45525 Mtetra
.79173 .45525 .79687 .46192 .80883 .4583 .80373 .45161 Mtetra
.80373 .45161 .80883 .4583 .82084 .45467 .81578 .44795 Mtetra
.81578 .44795 .82084 .45467 .8329 .45102 .82787 .44426 Mtetra
.82787 .44426 .8329 .45102 .84501 .44734 .84002 .44056 Mtetra
.661 .742 .91 r
.84002 .44056 .84501 .44734 .85717 .44365 .85222 .43693 Mtetra
.599 .719 .928 r
.85222 .43693 .85717 .44365 .86939 .44003 .86466 .43501 Mtetra
0 .307 .777 r
.86466 .43501 .86939 .44003 .88185 .43812 .8783 .44357 Mtetra
.791 .346 .191 r
.8783 .44357 .88185 .43812 .89542 .44535 .89321 .46205 Mtetra
.371 .062 .304 r
.89321 .46205 .89542 .44535 .90984 .45866 .90523 .45377 Mtetra
.96 .83 .671 r
.90523 .45377 .90984 .45866 .92163 .44877 .91513 .42754 Mtetra
.716 .574 .694 r
.91513 .42754 .92163 .44877 .93202 .42761 .9266 .41505 Mtetra
.669 .624 .795 r
.9266 .41505 .93202 .42761 .9438 .41785 .93904 .41021 Mtetra
.665 .725 .894 r
.93904 .41021 .9438 .41785 .9563 .4134 .95164 .40629 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.663 .741 .908 r
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50534 Mtetra
.60066 .50534 .60637 .51168 .6176 .50825 .61193 .50188 Mtetra
.61193 .50188 .6176 .50825 .62888 .50481 .62324 .49841 Mtetra
.62324 .49841 .62888 .50481 .64021 .50135 .6346 .49492 Mtetra
.6346 .49492 .64021 .50135 .65158 .49788 .646 .49143 Mtetra
.646 .49143 .65158 .49788 .663 .49439 .65745 .48792 Mtetra
.65745 .48792 .663 .49439 .67446 .49089 .66894 .4844 Mtetra
.663 .742 .908 r
.66894 .4844 .67446 .49089 .68597 .48738 .68049 .48087 Mtetra
.663 .742 .909 r
.68049 .48087 .68597 .48738 .69753 .48386 .69208 .47733 Mtetra
.69208 .47733 .69753 .48386 .70914 .48033 .70372 .47377 Mtetra
.70372 .47377 .70914 .48033 .72079 .47679 .7154 .47021 Mtetra
.7154 .47021 .72079 .47679 .73249 .47323 .72714 .46663 Mtetra
.72714 .46663 .73249 .47323 .74424 .46966 .73893 .46304 Mtetra
.662 .742 .909 r
.73893 .46304 .74424 .46966 .75604 .46608 .75076 .45944 Mtetra
.662 .743 .91 r
.75076 .45944 .75604 .46608 .76789 .46249 .76264 .45582 Mtetra
.76264 .45582 .76789 .46249 .77979 .45888 .77457 .45219 Mtetra
.663 .743 .91 r
.77457 .45219 .77979 .45888 .79173 .45525 .78656 .44854 Mtetra
.78656 .44854 .79173 .45525 .80373 .45161 .79859 .44487 Mtetra
.79859 .44487 .80373 .45161 .81578 .44795 .81067 .44118 Mtetra
.81067 .44118 .81578 .44795 .82787 .44426 .82281 .43747 Mtetra
.661 .743 .911 r
.82281 .43747 .82787 .44426 .84002 .44056 .835 .43381 Mtetra
.601 .72 .928 r
.835 .43381 .84002 .44056 .85222 .43693 .84741 .43183 Mtetra
0 .252 .735 r
.84741 .43183 .85222 .43693 .86466 .43501 .86106 .44129 Mtetra
.824 .401 .238 r
.86106 .44129 .86466 .43501 .8783 .44357 .8764 .46504 Mtetra
.465 .165 .372 r
.8764 .46504 .8783 .44357 .89321 .46205 .8888 .4598 Mtetra
.989 .851 .613 r
.8888 .4598 .89321 .46205 .90523 .45377 .89824 .42837 Mtetra
.722 .56 .67 r
.89824 .42837 .90523 .45377 .91513 .42754 .90935 .41241 Mtetra
.667 .592 .762 r
.90935 .41241 .91513 .42754 .9266 .41505 .92171 .40702 Mtetra
.666 .715 .885 r
.92171 .40702 .9266 .41505 .93904 .41021 .9343 .40306 Mtetra
.665 .741 .907 r
.9343 .40306 .93904 .41021 .95164 .40629 .94695 .39914 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50587 Mtetra
.663 .741 .908 r
.57246 .50587 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50534 .59492 .49894 Mtetra
.59492 .49894 .60066 .50534 .61193 .50188 .60621 .49546 Mtetra
.60621 .49546 .61193 .50188 .62324 .49841 .61755 .49196 Mtetra
.61755 .49196 .62324 .49841 .6346 .49492 .62894 .48846 Mtetra
.62894 .48846 .6346 .49492 .646 .49143 .64038 .48494 Mtetra
.663 .742 .908 r
.64038 .48494 .646 .49143 .65745 .48792 .65186 .48141 Mtetra
.65186 .48141 .65745 .48792 .66894 .4844 .66339 .47786 Mtetra
.663 .742 .909 r
.66339 .47786 .66894 .4844 .68049 .48087 .67496 .47431 Mtetra
.67496 .47431 .68049 .48087 .69208 .47733 .68659 .47075 Mtetra
.68659 .47075 .69208 .47733 .70372 .47377 .69826 .46718 Mtetra
.662 .742 .909 r
.69826 .46718 .70372 .47377 .7154 .47021 .70998 .46359 Mtetra
.662 .742 .91 r
.70998 .46359 .7154 .47021 .72714 .46663 .72175 .46 Mtetra
.662 .743 .91 r
.72175 .46 .72714 .46663 .73893 .46304 .73357 .45639 Mtetra
.73357 .45639 .73893 .46304 .75076 .45944 .74544 .45277 Mtetra
.74544 .45277 .75076 .45944 .76264 .45582 .75736 .44913 Mtetra
.75736 .44913 .76264 .45582 .77457 .45219 .76933 .44547 Mtetra
.662 .744 .91 r
.76933 .44547 .77457 .45219 .78656 .44854 .78134 .4418 Mtetra
.663 .744 .91 r
.78134 .4418 .78656 .44854 .79859 .44487 .79341 .4381 Mtetra
.79341 .4381 .79859 .44487 .81067 .44118 .80553 .43438 Mtetra
.661 .743 .911 r
.80553 .43438 .81067 .44118 .82281 .43747 .81771 .4307 Mtetra
.606 .723 .927 r
.81771 .4307 .82281 .43747 .835 .43381 .83008 .42857 Mtetra
0 .231 .719 r
.83008 .42857 .835 .43381 .84741 .43183 .84369 .4384 Mtetra
.847 .438 .263 r
.84369 .4384 .84741 .43183 .86106 .44129 .85937 .46701 Mtetra
.535 .238 .41 r
.85937 .46701 .86106 .44129 .8764 .46504 .87226 .46632 Mtetra
.995 .863 .538 r
.87226 .46632 .8764 .46504 .8888 .4598 .88134 .43007 Mtetra
.73 .552 .651 r
.88134 .43007 .8888 .4598 .89824 .42837 .89205 .40999 Mtetra
.663 .563 .731 r
.89205 .40999 .89824 .42837 .90935 .41241 .90433 .40385 Mtetra
.666 .701 .873 r
.90433 .40385 .90935 .41241 .92171 .40702 .9169 .39982 Mtetra
.665 .741 .907 r
.9169 .39982 .92171 .40702 .9343 .40306 .92953 .39588 Mtetra
.665 .742 .908 r
.92953 .39588 .9343 .40306 .94695 .39914 .94222 .39193 Mtetra
.664 .741 .908 r
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50984 Mtetra
.53318 .50984 .53912 .51615 .55019 .51274 .54428 .5064 Mtetra
.54428 .5064 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.663 .741 .908 r
.55543 .50294 .5613 .50931 .57246 .50587 .56661 .49947 Mtetra
.56661 .49947 .57246 .50587 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49894 .58913 .4925 Mtetra
.58913 .4925 .59492 .49894 .60621 .49546 .60046 .48899 Mtetra
.60046 .48899 .60621 .49546 .61755 .49196 .61183 .48547 Mtetra
.61183 .48547 .61755 .49196 .62894 .48846 .62325 .48194 Mtetra
.663 .742 .908 r
.62325 .48194 .62894 .48846 .64038 .48494 .63471 .4784 Mtetra
.663 .742 .909 r
.63471 .4784 .64038 .48494 .65186 .48141 .64623 .47485 Mtetra
.64623 .47485 .65186 .48141 .66339 .47786 .65779 .47129 Mtetra
.65779 .47129 .66339 .47786 .67496 .47431 .6694 .46771 Mtetra
.662 .742 .909 r
.6694 .46771 .67496 .47431 .68659 .47075 .68105 .46413 Mtetra
.68105 .46413 .68659 .47075 .69826 .46718 .69276 .46054 Mtetra
.662 .743 .91 r
.69276 .46054 .69826 .46718 .70998 .46359 .70451 .45694 Mtetra
.70451 .45694 .70998 .46359 .72175 .46 .71632 .45333 Mtetra
.71632 .45333 .72175 .46 .73357 .45639 .72817 .4497 Mtetra
.662 .743 .911 r
.72817 .4497 .73357 .45639 .74544 .45277 .74008 .44606 Mtetra
.662 .744 .911 r
.74008 .44606 .74544 .45277 .75736 .44913 .75203 .4424 Mtetra
.75203 .4424 .75736 .44913 .76933 .44547 .76404 .43872 Mtetra
.76404 .43872 .76933 .44547 .78134 .4418 .77609 .43502 Mtetra
.663 .744 .911 r
.77609 .43502 .78134 .4418 .79341 .4381 .78819 .43129 Mtetra
.661 .744 .911 r
.78819 .43129 .79341 .4381 .80553 .43438 .80035 .42759 Mtetra
.613 .726 .926 r
.80035 .42759 .80553 .43438 .81771 .4307 .81269 .42527 Mtetra
0 .244 .732 r
.81269 .42527 .81771 .4307 .83008 .42857 .82619 .43488 Mtetra
.863 .461 .272 r
.82619 .43488 .83008 .42857 .84369 .4384 .84206 .46738 Mtetra
.59 .292 .431 r
.84206 .46738 .84369 .4384 .85937 .46701 .85552 .47253 Mtetra
.962 .851 .438 r
.85552 .47253 .85937 .46701 .87226 .46632 .8644 .4325 Mtetra
.738 .548 .636 r
.8644 .4325 .87226 .46632 .88134 .43007 .87471 .40781 Mtetra
.66 .538 .704 r
.87471 .40781 .88134 .43007 .89205 .40999 .88688 .40069 Mtetra
.666 .684 .858 r
.88688 .40069 .89205 .40999 .90433 .40385 .89943 .39659 Mtetra
.665 .74 .906 r
.89943 .39659 .90433 .40385 .9169 .39982 .91205 .39262 Mtetra
.665 .742 .908 r
.91205 .39262 .9169 .39982 .92953 .39588 .92473 .38865 Mtetra
.92473 .38865 .92953 .39588 .94222 .39193 .93746 .38466 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50984 .5272 .50347 Mtetra
.5272 .50347 .53318 .50984 .54428 .5064 .53833 .50001 Mtetra
.663 .741 .908 r
.53833 .50001 .54428 .5064 .55543 .50294 .5495 .49653 Mtetra
.5495 .49653 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48953 Mtetra
.57199 .48953 .57785 .49599 .58913 .4925 .5833 .48601 Mtetra
.5833 .48601 .58913 .4925 .60046 .48899 .59465 .48248 Mtetra
.59465 .48248 .60046 .48899 .61183 .48547 .60606 .47894 Mtetra
.663 .742 .908 r
.60606 .47894 .61183 .48547 .62325 .48194 .61751 .47539 Mtetra
.663 .742 .909 r
.61751 .47539 .62325 .48194 .63471 .4784 .62901 .47182 Mtetra
.62901 .47182 .63471 .4784 .64623 .47485 .64055 .46825 Mtetra
.64055 .46825 .64623 .47485 .65779 .47129 .65215 .46467 Mtetra
.662 .742 .909 r
.65215 .46467 .65779 .47129 .6694 .46771 .66379 .46108 Mtetra
.662 .742 .91 r
.66379 .46108 .6694 .46771 .68105 .46413 .67548 .45748 Mtetra
.662 .743 .91 r
.67548 .45748 .68105 .46413 .69276 .46054 .68722 .45387 Mtetra
.68722 .45387 .69276 .46054 .70451 .45694 .69901 .45025 Mtetra
.662 .743 .911 r
.69901 .45025 .70451 .45694 .71632 .45333 .71085 .44662 Mtetra
.662 .744 .911 r
.71085 .44662 .71632 .45333 .72817 .4497 .72274 .44298 Mtetra
.72274 .44298 .72817 .4497 .74008 .44606 .73468 .43932 Mtetra
.73468 .43932 .74008 .44606 .75203 .4424 .74667 .43563 Mtetra
.74667 .43563 .75203 .4424 .76404 .43872 .75871 .43193 Mtetra
.662 .745 .911 r
.75871 .43193 .76404 .43872 .77609 .43502 .7708 .4282 Mtetra
.661 .744 .912 r
.7708 .4282 .77609 .43502 .78819 .43129 .78294 .42448 Mtetra
.62 .729 .924 r
.78294 .42448 .78819 .43129 .80035 .42759 .79523 .42193 Mtetra
0 .29 .771 r
.79523 .42193 .80035 .42759 .81269 .42527 .80859 .43078 Mtetra
.875 .475 .269 r
.80859 .43078 .81269 .42527 .82619 .43488 .82447 .46574 Mtetra
.637 .334 .441 r
.82447 .46574 .82619 .43488 .84206 .46738 .83851 .47753 Mtetra
.871 .801 .312 r
.83851 .47753 .84206 .46738 .85552 .47253 .84738 .43534 Mtetra
.747 .548 .625 r
.84738 .43534 .85552 .47253 .8644 .4325 .85732 .40587 Mtetra
.658 .518 .681 r
.85732 .40587 .8644 .4325 .87471 .40781 .86937 .39756 Mtetra
.665 .664 .84 r
.86937 .39756 .87471 .40781 .88688 .40069 .8819 .39335 Mtetra
.665 .738 .904 r
.8819 .39335 .88688 .40069 .89943 .39659 .8945 .38936 Mtetra
.665 .743 .908 r
.8945 .38936 .89943 .39659 .91205 .39262 .90716 .38536 Mtetra
.665 .742 .908 r
.90716 .38536 .91205 .39262 .92473 .38865 .91988 .38135 Mtetra
.91988 .38135 .92473 .38865 .93746 .38466 .93265 .37733 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.663 .741 .908 r
.52117 .49706 .5272 .50347 .53833 .50001 .53233 .49357 Mtetra
.53233 .49357 .53833 .50001 .5495 .49653 .54353 .49007 Mtetra
.54353 .49007 .5495 .49653 .56072 .49303 .55478 .48655 Mtetra
.55478 .48655 .56072 .49303 .57199 .48953 .56608 .48302 Mtetra
.56608 .48302 .57199 .48953 .5833 .48601 .57742 .47948 Mtetra
.57742 .47948 .5833 .48601 .59465 .48248 .58881 .47592 Mtetra
.663 .742 .908 r
.58881 .47592 .59465 .48248 .60606 .47894 .60024 .47236 Mtetra
.663 .742 .909 r
.60024 .47236 .60606 .47894 .61751 .47539 .61173 .46879 Mtetra
.61173 .46879 .61751 .47539 .62901 .47182 .62326 .4652 Mtetra
.662 .742 .909 r
.62326 .4652 .62901 .47182 .64055 .46825 .63483 .46161 Mtetra
.63483 .46161 .64055 .46825 .65215 .46467 .64646 .45802 Mtetra
.662 .742 .91 r
.64646 .45802 .65215 .46467 .66379 .46108 .65814 .45441 Mtetra
.662 .743 .91 r
.65814 .45441 .66379 .46108 .67548 .45748 .66986 .4508 Mtetra
.661 .743 .911 r
.66986 .4508 .67548 .45748 .68722 .45387 .68164 .44717 Mtetra
.68164 .44717 .68722 .45387 .69901 .45025 .69346 .44354 Mtetra
.661 .744 .911 r
.69346 .44354 .69901 .45025 .71085 .44662 .70533 .43989 Mtetra
.661 .744 .912 r
.70533 .43989 .71085 .44662 .72274 .44298 .71726 .43623 Mtetra
.661 .745 .912 r
.71726 .43623 .72274 .44298 .73468 .43932 .72923 .43254 Mtetra
.662 .745 .912 r
.72923 .43254 .73468 .43932 .74667 .43563 .74126 .42884 Mtetra
.74126 .42884 .74667 .43563 .75871 .43193 .75334 .4251 Mtetra
.661 .745 .912 r
.75334 .4251 .75871 .43193 .7708 .4282 .76546 .42137 Mtetra
.628 .733 .923 r
.76546 .42137 .7708 .4282 .78294 .42448 .77772 .41859 Mtetra
0 .363 .826 r
.77772 .41859 .78294 .42448 .79523 .42193 .79089 .42621 Mtetra
.883 .481 .255 r
.79089 .42621 .79523 .42193 .80859 .43078 .80661 .4619 Mtetra
.677 .369 .444 r
.80661 .4619 .80859 .43078 .82447 .46574 .82115 .48041 Mtetra
.715 .702 .168 r
.82115 .48041 .82447 .46574 .83851 .47753 .83023 .43813 Mtetra
.757 .551 .617 r
.83023 .43813 .83851 .47753 .84738 .43534 .83988 .40414 Mtetra
.657 .503 .663 r
.83988 .40414 .84738 .43534 .85732 .40587 .8518 .39447 Mtetra
.663 .643 .82 r
.8518 .39447 .85732 .40587 .86937 .39756 .86431 .39012 Mtetra
.666 .736 .902 r
.86431 .39012 .86937 .39756 .8819 .39335 .8769 .38611 Mtetra
.666 .743 .908 r
.8769 .38611 .8819 .39335 .8945 .38936 .88954 .38208 Mtetra
.665 .743 .908 r
.88954 .38208 .8945 .38936 .90716 .38536 .90224 .37804 Mtetra
.665 .742 .908 r
.90224 .37804 .90716 .38536 .91988 .38135 .915 .37399 Mtetra
.915 .37399 .91988 .38135 .93265 .37733 .92781 .36993 Mtetra
.664 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50454 Mtetra
.4708 .50454 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .4976 Mtetra
.49286 .4976 .49899 .504 .51006 .50054 .50396 .49411 Mtetra
.663 .741 .908 r
.50396 .49411 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48709 Mtetra
.52629 .48709 .53233 .49357 .54353 .49007 .53752 .48356 Mtetra
.53752 .48356 .54353 .49007 .55478 .48655 .5488 .48002 Mtetra
.5488 .48002 .55478 .48655 .56608 .48302 .56013 .47646 Mtetra
.56013 .47646 .56608 .48302 .57742 .47948 .5715 .4729 Mtetra
.663 .742 .908 r
.5715 .4729 .57742 .47948 .58881 .47592 .58292 .46932 Mtetra
.663 .742 .909 r
.58292 .46932 .58881 .47592 .60024 .47236 .59438 .46574 Mtetra
.59438 .46574 .60024 .47236 .61173 .46879 .6059 .46215 Mtetra
.662 .742 .909 r
.6059 .46215 .61173 .46879 .62326 .4652 .61746 .45855 Mtetra
.662 .742 .91 r
.61746 .45855 .62326 .4652 .63483 .46161 .62907 .45494 Mtetra
.662 .743 .91 r
.62907 .45494 .63483 .46161 .64646 .45802 .64073 .45133 Mtetra
.661 .743 .91 r
.64073 .45133 .64646 .45802 .65814 .45441 .65244 .44771 Mtetra
.661 .743 .911 r
.65244 .44771 .65814 .45441 .66986 .4508 .6642 .44409 Mtetra
.661 .744 .911 r
.6642 .44409 .66986 .4508 .68164 .44717 .67601 .44045 Mtetra
.661 .744 .912 r
.67601 .44045 .68164 .44717 .69346 .44354 .68787 .4368 Mtetra
.661 .745 .912 r
.68787 .4368 .69346 .44354 .70533 .43989 .69978 .43314 Mtetra
.69978 .43314 .70533 .43989 .71726 .43623 .71174 .42945 Mtetra
.71174 .42945 .71726 .43623 .72923 .43254 .72375 .42574 Mtetra
.662 .746 .912 r
.72375 .42574 .72923 .43254 .74126 .42884 .73581 .42201 Mtetra
.661 .746 .913 r
.73581 .42201 .74126 .42884 .75334 .4251 .74793 .41826 Mtetra
.636 .736 .921 r
.74793 .41826 .75334 .4251 .76546 .42137 .76015 .41525 Mtetra
.077 .45 .881 r
.76015 .41525 .76546 .42137 .77772 .41859 .77312 .42134 Mtetra
.887 .477 .23 r
.77312 .42134 .77772 .41859 .79089 .42621 .78852 .45593 Mtetra
.712 .396 .441 r
.78852 .45593 .79089 .42621 .80661 .4619 .80342 .48045 Mtetra
0 0 0 r
.80342 .48045 .80661 .4619 .82115 .48041 .8129 .44034 Mtetra
.768 .557 .612 r
.8129 .44034 .82115 .48041 .83023 .43813 .82236 .40256 Mtetra
.657 .493 .65 r
.82236 .40256 .83023 .43813 .83988 .40414 .83417 .3914 Mtetra
.66 .621 .799 r
.83417 .3914 .83988 .40414 .8518 .39447 .84665 .3869 Mtetra
.666 .733 .9 r
.84665 .3869 .8518 .39447 .86431 .39012 .85922 .38285 Mtetra
.666 .743 .908 r
.85922 .38285 .86431 .39012 .8769 .38611 .87185 .3788 Mtetra
.87185 .3788 .8769 .38611 .88954 .38208 .88454 .37473 Mtetra
.666 .742 .907 r
.88454 .37473 .88954 .38208 .90224 .37804 .89728 .37066 Mtetra
.665 .742 .907 r
.89728 .37066 .90224 .37804 .915 .37399 .91007 .36657 Mtetra
.91007 .36657 .915 .37399 .92781 .36993 .92292 .36247 Mtetra
.664 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50454 .46457 .49813 Mtetra
.46457 .49813 .4708 .50454 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .4976 .48668 .49114 Mtetra
.663 .741 .908 r
.48668 .49114 .49286 .4976 .50396 .49411 .49781 .48763 Mtetra
.49781 .48763 .50396 .49411 .5151 .4906 .50898 .4841 Mtetra
.50898 .4841 .5151 .4906 .52629 .48709 .5202 .48056 Mtetra
.5202 .48056 .52629 .48709 .53752 .48356 .53146 .477 Mtetra
.53146 .477 .53752 .48356 .5488 .48002 .54277 .47344 Mtetra
.54277 .47344 .5488 .48002 .56013 .47646 .55413 .46986 Mtetra
.663 .742 .909 r
.55413 .46986 .56013 .47646 .5715 .4729 .56553 .46627 Mtetra
.56553 .46627 .5715 .4729 .58292 .46932 .57698 .46268 Mtetra
.662 .742 .909 r
.57698 .46268 .58292 .46932 .59438 .46574 .58848 .45908 Mtetra
.58848 .45908 .59438 .46574 .6059 .46215 .60003 .45547 Mtetra
.662 .742 .91 r
.60003 .45547 .6059 .46215 .61746 .45855 .61162 .45186 Mtetra
.661 .743 .91 r
.61162 .45186 .61746 .45855 .62907 .45494 .62327 .44824 Mtetra
.661 .743 .911 r
.62327 .44824 .62907 .45494 .64073 .45133 .63496 .44461 Mtetra
.63496 .44461 .64073 .45133 .65244 .44771 .6467 .44098 Mtetra
.661 .744 .912 r
.6467 .44098 .65244 .44771 .6642 .44409 .6585 .43735 Mtetra
.66 .744 .912 r
.6585 .43735 .6642 .44409 .67601 .44045 .67034 .4337 Mtetra
.66 .745 .913 r
.67034 .4337 .67601 .44045 .68787 .4368 .68224 .43003 Mtetra
.68224 .43003 .68787 .4368 .69978 .43314 .69418 .42635 Mtetra
.661 .746 .913 r
.69418 .42635 .69978 .43314 .71174 .42945 .70618 .42264 Mtetra
.70618 .42264 .71174 .42945 .72375 .42574 .71822 .41891 Mtetra
.71822 .41891 .72375 .42574 .73581 .42201 .73032 .41516 Mtetra
.642 .739 .919 r
.73032 .41516 .73581 .42201 .74793 .41826 .74251 .41195 Mtetra
.212 .534 .924 r
.74251 .41195 .74793 .41826 .76015 .41525 .7553 .41634 Mtetra
.884 .462 .188 r
.7553 .41634 .76015 .41525 .77312 .42134 .77026 .44821 Mtetra
.743 .418 .433 r
.77026 .44821 .77312 .42134 .78852 .45593 .78534 .47726 Mtetra
0 0 .09 r
.78534 .47726 .78852 .45593 .80342 .48045 .79535 .4414 Mtetra
.78 .566 .61 r
.79535 .4414 .80342 .48045 .8129 .44034 .80477 .40101 Mtetra
.658 .486 .641 r
.80477 .40101 .8129 .44034 .82236 .40256 .81648 .38837 Mtetra
.658 .601 .78 r
.81648 .38837 .82236 .40256 .83417 .3914 .82893 .38369 Mtetra
.667 .73 .897 r
.82893 .38369 .83417 .3914 .84665 .3869 .84149 .3796 Mtetra
.666 .743 .908 r
.84149 .3796 .84665 .3869 .85922 .38285 .8541 .37552 Mtetra
.8541 .37552 .85922 .38285 .87185 .3788 .86677 .37142 Mtetra
.666 .743 .907 r
.86677 .37142 .87185 .3788 .88454 .37473 .87949 .36732 Mtetra
.666 .742 .907 r
.87949 .36732 .88454 .37473 .89728 .37066 .89227 .3632 Mtetra
.665 .742 .907 r
.89227 .3632 .89728 .37066 .91007 .36657 .90511 .35908 Mtetra
.90511 .35908 .91007 .36657 .92292 .36247 .918 .35495 Mtetra
.664 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48817 Mtetra
.663 .741 .908 r
.46935 .48817 .4756 .49464 .48668 .49114 .48046 .48464 Mtetra
.48046 .48464 .48668 .49114 .49781 .48763 .49162 .4811 Mtetra
.49162 .4811 .49781 .48763 .50898 .4841 .50282 .47754 Mtetra
.50282 .47754 .50898 .4841 .5202 .48056 .51406 .47398 Mtetra
.51406 .47398 .5202 .48056 .53146 .477 .52536 .4704 Mtetra
.52536 .4704 .53146 .477 .54277 .47344 .5367 .46681 Mtetra
.663 .742 .909 r
.5367 .46681 .54277 .47344 .55413 .46986 .54809 .46322 Mtetra
.54809 .46322 .55413 .46986 .56553 .46627 .55952 .45961 Mtetra
.662 .742 .909 r
.55952 .45961 .56553 .46627 .57698 .46268 .571 .456 Mtetra
.571 .456 .57698 .46268 .58848 .45908 .58253 .45238 Mtetra
.662 .742 .91 r
.58253 .45238 .58848 .45908 .60003 .45547 .59411 .44876 Mtetra
.661 .743 .91 r
.59411 .44876 .60003 .45547 .61162 .45186 .60574 .44513 Mtetra
.661 .743 .911 r
.60574 .44513 .61162 .45186 .62327 .44824 .61742 .44151 Mtetra
.66 .743 .911 r
.61742 .44151 .62327 .44824 .63496 .44461 .62915 .43787 Mtetra
.66 .744 .912 r
.62915 .43787 .63496 .44461 .6467 .44098 .64092 .43423 Mtetra
.66 .745 .913 r
.64092 .43423 .6467 .44098 .6585 .43735 .65275 .43059 Mtetra
.65275 .43059 .6585 .43735 .67034 .4337 .66463 .42692 Mtetra
.66 .746 .913 r
.66463 .42692 .67034 .4337 .68224 .43003 .67656 .42324 Mtetra
.66 .746 .914 r
.67656 .42324 .68224 .43003 .69418 .42635 .68854 .41954 Mtetra
.661 .746 .914 r
.68854 .41954 .69418 .42635 .70618 .42264 .70057 .41581 Mtetra
.661 .747 .914 r
.70057 .41581 .70618 .42264 .71822 .41891 .71266 .41205 Mtetra
.648 .742 .918 r
.71266 .41205 .71822 .41891 .73032 .41516 .72482 .40867 Mtetra
.335 .604 .947 r
.72482 .40867 .73032 .41516 .74251 .41195 .73743 .41138 Mtetra
.871 .43 .122 r
.73743 .41138 .74251 .41195 .7553 .41634 .7519 .43925 Mtetra
.769 .434 .418 r
.7519 .43925 .7553 .41634 .77026 .44821 .76695 .47083 Mtetra
0 0 .173 r
.76695 .47083 .77026 .44821 .78534 .47726 .77756 .44081 Mtetra
.793 .578 .61 r
.77756 .44081 .78534 .47726 .79535 .4414 .78709 .39934 Mtetra
.66 .483 .634 r
.78709 .39934 .79535 .4414 .80477 .40101 .79872 .38537 Mtetra
.655 .584 .763 r
.79872 .38537 .80477 .40101 .81648 .38837 .81114 .38048 Mtetra
.667 .726 .893 r
.81114 .38048 .81648 .38837 .82893 .38369 .82369 .37636 Mtetra
.667 .743 .907 r
.82369 .37636 .82893 .38369 .84149 .3796 .83628 .37225 Mtetra
.83628 .37225 .84149 .3796 .8541 .37552 .84893 .36812 Mtetra
.666 .743 .907 r
.84893 .36812 .8541 .37552 .86677 .37142 .86164 .36398 Mtetra
.666 .742 .907 r
.86164 .36398 .86677 .37142 .87949 .36732 .8744 .35984 Mtetra
.8744 .35984 .87949 .36732 .89227 .3632 .88722 .35569 Mtetra
.665 .742 .907 r
.88722 .35569 .89227 .3632 .90511 .35908 .9001 .35153 Mtetra
.9001 .35153 .90511 .35908 .918 .35495 .91303 .34737 Mtetra
.664 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.663 .741 .908 r
.45196 .48518 .45829 .49168 .46935 .48817 .46305 .48164 Mtetra
.46305 .48164 .46935 .48817 .48046 .48464 .47419 .47809 Mtetra
.47419 .47809 .48046 .48464 .49162 .4811 .48538 .47452 Mtetra
.48538 .47452 .49162 .4811 .50282 .47754 .49661 .47094 Mtetra
.49661 .47094 .50282 .47754 .51406 .47398 .50788 .46735 Mtetra
.50788 .46735 .51406 .47398 .52536 .4704 .51921 .46375 Mtetra
.663 .742 .909 r
.51921 .46375 .52536 .4704 .5367 .46681 .53058 .46015 Mtetra
.53058 .46015 .5367 .46681 .54809 .46322 .542 .45653 Mtetra
.662 .742 .909 r
.542 .45653 .54809 .46322 .55952 .45961 .55346 .45291 Mtetra
.662 .742 .91 r
.55346 .45291 .55952 .45961 .571 .456 .56498 .44928 Mtetra
.56498 .44928 .571 .456 .58253 .45238 .57654 .44565 Mtetra
.661 .743 .911 r
.57654 .44565 .58253 .45238 .59411 .44876 .58815 .44202 Mtetra
.58815 .44202 .59411 .44876 .60574 .44513 .59981 .43838 Mtetra
.66 .744 .912 r
.59981 .43838 .60574 .44513 .61742 .44151 .61152 .43475 Mtetra
.61152 .43475 .61742 .44151 .62915 .43787 .62328 .43111 Mtetra
.659 .745 .913 r
.62328 .43111 .62915 .43787 .64092 .43423 .6351 .42746 Mtetra
.659 .745 .914 r
.6351 .42746 .64092 .43423 .65275 .43059 .64696 .4238 Mtetra
.659 .746 .914 r
.64696 .4238 .65275 .43059 .66463 .42692 .65887 .42013 Mtetra
.66 .746 .914 r
.65887 .42013 .66463 .42692 .67656 .42324 .67084 .41643 Mtetra
.66 .747 .914 r
.67084 .41643 .67656 .42324 .68854 .41954 .68286 .4127 Mtetra
.68286 .4127 .68854 .41954 .70057 .41581 .69492 .40894 Mtetra
.652 .744 .917 r
.69492 .40894 .70057 .41581 .71266 .41205 .70706 .40543 Mtetra
.435 .656 .953 r
.70706 .40543 .71266 .41205 .72482 .40867 .71953 .40658 Mtetra
.837 .369 .017 r
.71953 .40658 .72482 .40867 .73743 .41138 .7335 .42968 Mtetra
.792 .443 .396 r
.7335 .42968 .73743 .41138 .7519 .43925 .74834 .46158 Mtetra
.049 0 .224 r
.74834 .46158 .7519 .43925 .76695 .47083 .75953 .43826 Mtetra
.806 .593 .614 r
.75953 .43826 .76695 .47083 .77756 .44081 .76931 .39742 Mtetra
.663 .483 .631 r
.76931 .39742 .77756 .44081 .78709 .39934 .7809 .38238 Mtetra
.653 .571 .75 r
.7809 .38238 .78709 .39934 .79872 .38537 .79329 .37728 Mtetra
.667 .721 .889 r
.79329 .37728 .79872 .38537 .81114 .38048 .80582 .37312 Mtetra
.667 .743 .907 r
.80582 .37312 .81114 .38048 .82369 .37636 .8184 .36898 Mtetra
.667 .744 .907 r
.8184 .36898 .82369 .37636 .83628 .37225 .83104 .36482 Mtetra
.667 .743 .907 r
.83104 .36482 .83628 .37225 .84893 .36812 .84373 .36065 Mtetra
.84373 .36065 .84893 .36812 .86164 .36398 .85647 .35647 Mtetra
.666 .742 .907 r
.85647 .35647 .86164 .36398 .8744 .35984 .86928 .35229 Mtetra
.86928 .35229 .8744 .35984 .88722 .35569 .88214 .34811 Mtetra
.665 .742 .907 r
.88214 .34811 .88722 .35569 .9001 .35153 .89505 .34392 Mtetra
.89505 .34392 .9001 .35153 .91303 .34737 .90803 .33972 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.663 .741 .908 r
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47507 Mtetra
.4567 .47507 .46305 .48164 .47419 .47809 .46787 .47149 Mtetra
.46787 .47149 .47419 .47809 .48538 .47452 .47909 .4679 Mtetra
.47909 .4679 .48538 .47452 .49661 .47094 .49035 .4643 Mtetra
.49035 .4643 .49661 .47094 .50788 .46735 .50165 .46068 Mtetra
.663 .742 .909 r
.50165 .46068 .50788 .46735 .51921 .46375 .51301 .45706 Mtetra
.51301 .45706 .51921 .46375 .53058 .46015 .52441 .45344 Mtetra
.662 .742 .909 r
.52441 .45344 .53058 .46015 .542 .45653 .53586 .4498 Mtetra
.662 .742 .91 r
.53586 .4498 .542 .45653 .55346 .45291 .54736 .44617 Mtetra
.661 .742 .91 r
.54736 .44617 .55346 .45291 .56498 .44928 .5589 .44253 Mtetra
.661 .743 .911 r
.5589 .44253 .56498 .44928 .57654 .44565 .5705 .43889 Mtetra
.66 .743 .911 r
.5705 .43889 .57654 .44565 .58815 .44202 .58214 .43525 Mtetra
.66 .744 .912 r
.58214 .43525 .58815 .44202 .59981 .43838 .59384 .43161 Mtetra
.659 .744 .913 r
.59384 .43161 .59981 .43838 .61152 .43475 .60558 .42797 Mtetra
.659 .745 .913 r
.60558 .42797 .61152 .43475 .62328 .43111 .61738 .42432 Mtetra
.659 .745 .914 r
.61738 .42432 .62328 .43111 .6351 .42746 .62923 .42067 Mtetra
.659 .746 .915 r
.62923 .42067 .6351 .42746 .64696 .4238 .64112 .417 Mtetra
.659 .747 .915 r
.64112 .417 .64696 .4238 .65887 .42013 .65307 .41331 Mtetra
.65307 .41331 .65887 .42013 .67084 .41643 .66508 .40959 Mtetra
.66 .748 .915 r
.66508 .40959 .67084 .41643 .68286 .4127 .67713 .40583 Mtetra
.654 .746 .917 r
.67713 .40583 .68286 .4127 .69492 .40894 .68924 .40223 Mtetra
.509 .69 .95 r
.68924 .40223 .69492 .40894 .70706 .40543 .7016 .40203 Mtetra
.759 .256 0 r
.7016 .40203 .70706 .40543 .71953 .40658 .71511 .42009 Mtetra
.81 .444 .363 r
.71511 .42009 .71953 .40658 .7335 .42968 .72959 .45025 Mtetra
.177 0 .245 r
.72959 .45025 .7335 .42968 .74834 .46158 .7413 .43367 Mtetra
.819 .611 .621 r
.7413 .43367 .74834 .46158 .75953 .43826 .75141 .3951 Mtetra
.667 .486 .631 r
.75141 .3951 .75953 .43826 .76931 .39742 .76301 .37939 Mtetra
.651 .561 .74 r
.76301 .37939 .76931 .39742 .7809 .38238 .77538 .37409 Mtetra
.668 .717 .885 r
.77538 .37409 .7809 .38238 .79329 .37728 .78789 .36989 Mtetra
.668 .744 .907 r
.78789 .36989 .79329 .37728 .80582 .37312 .80045 .36571 Mtetra
.80045 .36571 .80582 .37312 .8184 .36898 .81307 .36152 Mtetra
.668 .743 .907 r
.81307 .36152 .8184 .36898 .83104 .36482 .82574 .35732 Mtetra
.667 .743 .907 r
.82574 .35732 .83104 .36482 .84373 .36065 .83847 .35311 Mtetra
.667 .742 .907 r
.83847 .35311 .84373 .36065 .85647 .35647 .85126 .34889 Mtetra
.666 .742 .907 r
.85126 .34889 .85647 .35647 .86928 .35229 .8641 .34468 Mtetra
.8641 .34468 .86928 .35229 .88214 .34811 .877 .34046 Mtetra
.665 .742 .907 r
.877 .34046 .88214 .34811 .89505 .34392 .88996 .33624 Mtetra
.665 .741 .907 r
.88996 .33624 .89505 .34392 .90803 .33972 .90298 .33201 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48627 Mtetra
.39501 .48627 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.663 .741 .908 r
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47204 Mtetra
.43916 .47204 .44558 .47863 .4567 .47507 .45031 .46845 Mtetra
.45031 .46845 .4567 .47507 .46787 .47149 .46151 .46484 Mtetra
.46151 .46484 .46787 .47149 .47909 .4679 .47275 .46123 Mtetra
.47275 .46123 .47909 .4679 .49035 .4643 .48404 .4576 Mtetra
.663 .742 .909 r
.48404 .4576 .49035 .4643 .50165 .46068 .49538 .45397 Mtetra
.49538 .45397 .50165 .46068 .51301 .45706 .50676 .45033 Mtetra
.662 .742 .909 r
.50676 .45033 .51301 .45706 .52441 .45344 .5182 .44669 Mtetra
.662 .742 .91 r
.5182 .44669 .52441 .45344 .53586 .4498 .52968 .44304 Mtetra
.661 .742 .91 r
.52968 .44304 .53586 .4498 .54736 .44617 .54121 .43939 Mtetra
.661 .743 .911 r
.54121 .43939 .54736 .44617 .5589 .44253 .55278 .43575 Mtetra
.66 .743 .912 r
.55278 .43575 .5589 .44253 .5705 .43889 .56441 .4321 Mtetra
.659 .744 .912 r
.56441 .4321 .5705 .43889 .58214 .43525 .57609 .42846 Mtetra
.659 .744 .913 r
.57609 .42846 .58214 .43525 .59384 .43161 .58782 .42482 Mtetra
.658 .745 .914 r
.58782 .42482 .59384 .43161 .60558 .42797 .5996 .42117 Mtetra
.658 .746 .915 r
.5996 .42117 .60558 .42797 .61738 .42432 .61143 .41752 Mtetra
.61143 .41752 .61738 .42432 .62923 .42067 .62331 .41386 Mtetra
.658 .747 .916 r
.62331 .41386 .62923 .42067 .64112 .417 .63524 .41017 Mtetra
.658 .748 .916 r
.63524 .41017 .64112 .417 .65307 .41331 .64723 .40646 Mtetra
.659 .748 .916 r
.64723 .40646 .65307 .41331 .66508 .40959 .65927 .40271 Mtetra
.656 .747 .917 r
.65927 .40271 .66508 .40959 .67713 .40583 .67136 .39904 Mtetra
.561 .713 .943 r
.67136 .39904 .67713 .40583 .68924 .40223 .68363 .39776 Mtetra
.586 .06 0 r
.68363 .39776 .68924 .40223 .7016 .40203 .69674 .41096 Mtetra
.823 .432 .313 r
.69674 .41096 .7016 .40203 .71511 .42009 .71081 .43775 Mtetra
.275 0 .239 r
.71081 .43775 .71511 .42009 .72959 .45025 .7229 .42723 Mtetra
.832 .632 .633 r
.7229 .42723 .72959 .45025 .7413 .43367 .73341 .39228 Mtetra
.671 .491 .633 r
.73341 .39228 .7413 .43367 .75141 .3951 .74504 .37638 Mtetra
.651 .556 .735 r
.74504 .37638 .75141 .3951 .76301 .37939 .7574 .37091 Mtetra
.668 .713 .882 r
.7574 .37091 .76301 .37939 .77538 .37409 .76989 .36667 Mtetra
.669 .744 .907 r
.76989 .36667 .77538 .37409 .78789 .36989 .78244 .36246 Mtetra
.668 .744 .907 r
.78244 .36246 .78789 .36989 .80045 .36571 .79504 .35823 Mtetra
.668 .743 .907 r
.79504 .35823 .80045 .36571 .81307 .36152 .8077 .35399 Mtetra
.668 .743 .906 r
.8077 .35399 .81307 .36152 .82574 .35732 .82041 .34974 Mtetra
.667 .742 .906 r
.82041 .34974 .82574 .35732 .83847 .35311 .83318 .3455 Mtetra
.83318 .3455 .83847 .35311 .85126 .34889 .84601 .34125 Mtetra
.666 .742 .907 r
.84601 .34125 .85126 .34889 .8641 .34468 .85889 .337 Mtetra
.85889 .337 .8641 .34468 .877 .34046 .87183 .33275 Mtetra
.665 .741 .907 r
.87183 .33275 .877 .34046 .88996 .33624 .88483 .32849 Mtetra
.88483 .32849 .88996 .33624 .90298 .33201 .89789 .32423 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48627 .38842 .47972 Mtetra
.38842 .47972 .39501 .48627 .40598 .48273 .39942 .47616 Mtetra
.663 .741 .908 r
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47259 Mtetra
.41046 .47259 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47204 .43268 .46539 Mtetra
.43268 .46539 .43916 .47204 .45031 .46845 .44386 .46178 Mtetra
.44386 .46178 .45031 .46845 .46151 .46484 .45509 .45815 Mtetra
.45509 .45815 .46151 .46484 .47275 .46123 .46637 .45451 Mtetra
.663 .742 .909 r
.46637 .45451 .47275 .46123 .48404 .4576 .47769 .45087 Mtetra
.662 .742 .909 r
.47769 .45087 .48404 .4576 .49538 .45397 .48905 .44721 Mtetra
.48905 .44721 .49538 .45397 .50676 .45033 .50047 .44356 Mtetra
.662 .742 .91 r
.50047 .44356 .50676 .45033 .5182 .44669 .51193 .4399 Mtetra
.661 .742 .91 r
.51193 .4399 .5182 .44669 .52968 .44304 .52344 .43624 Mtetra
.66 .743 .911 r
.52344 .43624 .52968 .44304 .54121 .43939 .53501 .43259 Mtetra
.66 .743 .912 r
.53501 .43259 .54121 .43939 .55278 .43575 .54662 .42894 Mtetra
.659 .744 .913 r
.54662 .42894 .55278 .43575 .56441 .4321 .55828 .42529 Mtetra
.658 .744 .913 r
.55828 .42529 .56441 .4321 .57609 .42846 .56999 .42165 Mtetra
.658 .745 .914 r
.56999 .42165 .57609 .42846 .58782 .42482 .58175 .41801 Mtetra
.657 .746 .915 r
.58175 .41801 .58782 .42482 .5996 .42117 .59356 .41436 Mtetra
.657 .747 .916 r
.59356 .41436 .5996 .42117 .61143 .41752 .60543 .4107 Mtetra
.60543 .4107 .61143 .41752 .62331 .41386 .61735 .40703 Mtetra
.658 .748 .917 r
.61735 .40703 .62331 .41386 .63524 .41017 .62932 .40332 Mtetra
.658 .749 .917 r
.62932 .40332 .63524 .41017 .64723 .40646 .64134 .39958 Mtetra
.657 .748 .917 r
.64134 .39958 .64723 .40646 .65927 .40271 .65341 .39587 Mtetra
.596 .727 .936 r
.65341 .39587 .65927 .40271 .67136 .39904 .66561 .39376 Mtetra
0 .216 .69 r
.66561 .39376 .67136 .39904 .68363 .39776 .6784 .40262 Mtetra
.824 .399 .233 r
.6784 .40262 .68363 .39776 .69674 .41096 .69204 .42497 Mtetra
.347 0 .201 r
.69204 .42497 .69674 .41096 .71081 .43775 .70438 .41934 Mtetra
.843 .657 .651 r
.70438 .41934 .71081 .43775 .7229 .42723 .7153 .38892 Mtetra
.677 .5 .639 r
.7153 .38892 .7229 .42723 .73341 .39228 .72701 .37333 Mtetra
.652 .555 .733 r
.72701 .37333 .73341 .39228 .74504 .37638 .73935 .36774 Mtetra
.668 .71 .879 r
.73935 .36774 .74504 .37638 .7574 .37091 .75182 .36346 Mtetra
.669 .744 .906 r
.75182 .36346 .7574 .37091 .76989 .36667 .76436 .35921 Mtetra
.669 .744 .907 r
.76436 .35921 .76989 .36667 .78244 .36246 .77694 .35495 Mtetra
.669 .744 .906 r
.77694 .35495 .78244 .36246 .79504 .35823 .78958 .35067 Mtetra
.669 .743 .906 r
.78958 .35067 .79504 .35823 .8077 .35399 .80228 .34638 Mtetra
.668 .743 .906 r
.80228 .34638 .8077 .35399 .82041 .34974 .81503 .3421 Mtetra
.667 .742 .906 r
.81503 .3421 .82041 .34974 .83318 .3455 .82784 .33781 Mtetra
.82784 .33781 .83318 .3455 .84601 .34125 .84071 .33353 Mtetra
.666 .742 .906 r
.84071 .33353 .84601 .34125 .85889 .337 .85363 .32925 Mtetra
.666 .741 .907 r
.85363 .32925 .85889 .337 .87183 .33275 .86662 .32497 Mtetra
.665 .741 .907 r
.86662 .32497 .87183 .33275 .88483 .32849 .87966 .32068 Mtetra
.87966 .32068 .88483 .32849 .89789 .32423 .89276 .31639 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.663 .741 .908 r
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46955 Mtetra
.39281 .46955 .39942 .47616 .41046 .47259 .40388 .46594 Mtetra
.40388 .46594 .41046 .47259 .42155 .46899 .415 .46233 Mtetra
.415 .46233 .42155 .46899 .43268 .46539 .42616 .4587 Mtetra
.42616 .4587 .43268 .46539 .44386 .46178 .43737 .45506 Mtetra
.43737 .45506 .44386 .46178 .45509 .45815 .44863 .45141 Mtetra
.663 .742 .909 r
.44863 .45141 .45509 .45815 .46637 .45451 .45993 .44775 Mtetra
.662 .742 .909 r
.45993 .44775 .46637 .45451 .47769 .45087 .47128 .44408 Mtetra
.47128 .44408 .47769 .45087 .48905 .44721 .48268 .44042 Mtetra
.662 .742 .91 r
.48268 .44042 .48905 .44721 .50047 .44356 .49413 .43675 Mtetra
.661 .742 .91 r
.49413 .43675 .50047 .44356 .51193 .4399 .50562 .43308 Mtetra
.66 .743 .911 r
.50562 .43308 .51193 .4399 .52344 .43624 .51716 .42942 Mtetra
.66 .743 .912 r
.51716 .42942 .52344 .43624 .53501 .43259 .52876 .42576 Mtetra
.659 .744 .913 r
.52876 .42576 .53501 .43259 .54662 .42894 .5404 .42211 Mtetra
.658 .744 .914 r
.5404 .42211 .54662 .42894 .55828 .42529 .55209 .41846 Mtetra
.657 .745 .915 r
.55209 .41846 .55828 .42529 .56999 .42165 .56384 .41482 Mtetra
.657 .746 .916 r
.56384 .41482 .56999 .42165 .58175 .41801 .57563 .41118 Mtetra
.657 .747 .916 r
.57563 .41118 .58175 .41801 .59356 .41436 .58748 .40753 Mtetra
.657 .747 .917 r
.58748 .40753 .59356 .41436 .60543 .4107 .59938 .40386 Mtetra
.657 .748 .917 r
.59938 .40386 .60543 .4107 .61735 .40703 .61134 .40017 Mtetra
.657 .749 .917 r
.61134 .40017 .61735 .40703 .62932 .40332 .62334 .39644 Mtetra
.657 .749 .918 r
.62334 .39644 .62932 .40332 .64134 .39958 .6354 .39271 Mtetra
.62 .736 .93 r
.6354 .39271 .64134 .39958 .65341 .39587 .64755 .38999 Mtetra
.068 .468 .887 r
.64755 .38999 .65341 .39587 .66561 .39376 .6601 .39522 Mtetra
.801 .327 .097 r
.6601 .39522 .66561 .39376 .6784 .40262 .67333 .41268 Mtetra
.388 0 .12 r
.67333 .41268 .6784 .40262 .69204 .42497 .68581 .41052 Mtetra
.851 .687 .677 r
.68581 .41052 .69204 .42497 .70438 .41934 .6971 .38504 Mtetra
.683 .512 .648 r
.6971 .38504 .70438 .41934 .7153 .38892 .7089 .37024 Mtetra
.653 .558 .735 r
.7089 .37024 .7153 .38892 .72701 .37333 .72123 .36457 Mtetra
.669 .707 .876 r
.72123 .36457 .72701 .37333 .73935 .36774 .73369 .36025 Mtetra
.67 .744 .906 r
.73369 .36025 .73935 .36774 .75182 .36346 .7462 .35597 Mtetra
.67 .745 .906 r
.7462 .35597 .75182 .36346 .76436 .35921 .75877 .35167 Mtetra
.67 .744 .906 r
.75877 .35167 .76436 .35921 .77694 .35495 .7714 .34735 Mtetra
.669 .743 .906 r
.7714 .34735 .77694 .35495 .78958 .35067 .78408 .34303 Mtetra
.78408 .34303 .78958 .35067 .80228 .34638 .79681 .3387 Mtetra
.668 .742 .906 r
.79681 .3387 .80228 .34638 .81503 .3421 .80961 .33438 Mtetra
.667 .742 .906 r
.80961 .33438 .81503 .3421 .82784 .33781 .82246 .33006 Mtetra
.82246 .33006 .82784 .33781 .84071 .33353 .83536 .32575 Mtetra
.666 .741 .906 r
.83536 .32575 .84071 .33353 .85363 .32925 .84833 .32144 Mtetra
.666 .741 .907 r
.84833 .32144 .85363 .32925 .86662 .32497 .86136 .31712 Mtetra
.665 .741 .907 r
.86136 .31712 .86662 .32497 .87966 .32068 .87445 .31281 Mtetra
.87445 .31281 .87966 .32068 .89276 .31639 .88759 .30849 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .4701 Mtetra
.663 .741 .908 r
.36408 .4701 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46955 .38615 .46288 Mtetra
.38615 .46288 .39281 .46955 .40388 .46594 .39725 .45925 Mtetra
.39725 .45925 .40388 .46594 .415 .46233 .40839 .45561 Mtetra
.40839 .45561 .415 .46233 .42616 .4587 .41959 .45196 Mtetra
.41959 .45196 .42616 .4587 .43737 .45506 .43083 .44829 Mtetra
.663 .742 .909 r
.43083 .44829 .43737 .45506 .44863 .45141 .44211 .44462 Mtetra
.662 .742 .909 r
.44211 .44462 .44863 .45141 .45993 .44775 .45345 .44094 Mtetra
.45345 .44094 .45993 .44775 .47128 .44408 .46483 .43726 Mtetra
.662 .742 .91 r
.46483 .43726 .47128 .44408 .48268 .44042 .47626 .43358 Mtetra
.661 .742 .91 r
.47626 .43358 .48268 .44042 .49413 .43675 .48773 .4299 Mtetra
.66 .743 .911 r
.48773 .4299 .49413 .43675 .50562 .43308 .49926 .42623 Mtetra
.659 .743 .912 r
.49926 .42623 .50562 .43308 .51716 .42942 .51083 .42256 Mtetra
.659 .744 .913 r
.51083 .42256 .51716 .42942 .52876 .42576 .52246 .41891 Mtetra
.658 .744 .914 r
.52246 .41891 .52876 .42576 .5404 .42211 .53413 .41526 Mtetra
.657 .745 .915 r
.53413 .41526 .5404 .42211 .55209 .41846 .54586 .41162 Mtetra
.656 .746 .916 r
.54586 .41162 .55209 .41846 .56384 .41482 .55764 .40798 Mtetra
.656 .747 .917 r
.55764 .40798 .56384 .41482 .57563 .41118 .56947 .40433 Mtetra
.656 .748 .917 r
.56947 .40433 .57563 .41118 .58748 .40753 .58135 .40068 Mtetra
.656 .748 .918 r
.58135 .40068 .58748 .40753 .59938 .40386 .59329 .39699 Mtetra
.657 .749 .918 r
.59329 .39699 .59938 .40386 .61134 .40017 .60528 .39328 Mtetra
.60528 .39328 .61134 .40017 .62334 .39644 .61732 .38954 Mtetra
.635 .742 .926 r
.61732 .38954 .62334 .39644 .6354 .39271 .62943 .38641 Mtetra
.323 .615 .954 r
.62943 .38641 .6354 .39271 .64755 .38999 .64181 .38877 Mtetra
.708 .171 0 r
.64181 .38877 .64755 .38999 .6601 .39522 .6547 .40145 Mtetra
.386 0 0 r
.6547 .40145 .6601 .39522 .67333 .41268 .66721 .40134 Mtetra
.854 .718 .713 r
.66721 .40134 .67333 .41268 .68581 .41052 .67882 .38073 Mtetra
.689 .527 .662 r
.67882 .38073 .68581 .41052 .6971 .38504 .69072 .36708 Mtetra
.656 .566 .742 r
.69072 .36708 .6971 .38504 .7089 .37024 .70304 .3614 Mtetra
.669 .707 .876 r
.70304 .3614 .7089 .37024 .72123 .36457 .71548 .35705 Mtetra
.67 .744 .906 r
.71548 .35705 .72123 .36457 .73369 .36025 .72799 .35273 Mtetra
.67 .745 .906 r
.72799 .35273 .73369 .36025 .7462 .35597 .74054 .34839 Mtetra
.67 .744 .906 r
.74054 .34839 .7462 .35597 .75877 .35167 .75315 .34404 Mtetra
.67 .743 .905 r
.75315 .34404 .75877 .35167 .7714 .34735 .76581 .33967 Mtetra
.669 .743 .905 r
.76581 .33967 .7714 .34735 .78408 .34303 .77853 .33531 Mtetra
.669 .742 .905 r
.77853 .33531 .78408 .34303 .79681 .3387 .7913 .33095 Mtetra
.668 .742 .905 r
.7913 .33095 .79681 .3387 .80961 .33438 .80414 .32659 Mtetra
.667 .742 .906 r
.80414 .32659 .80961 .33438 .82246 .33006 .81703 .32224 Mtetra
.667 .741 .906 r
.81703 .32224 .82246 .33006 .83536 .32575 .82998 .3179 Mtetra
.666 .741 .906 r
.82998 .3179 .83536 .32575 .84833 .32144 .84299 .31356 Mtetra
.665 .741 .907 r
.84299 .31356 .84833 .32144 .86136 .31712 .85606 .30921 Mtetra
.85606 .30921 .86136 .31712 .87445 .31281 .86919 .30487 Mtetra
.86919 .30487 .87445 .31281 .88759 .30849 .88238 .30052 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.663 .741 .908 r
.34633 .46705 .35312 .47368 .36408 .4701 .35732 .46343 Mtetra
.35732 .46343 .36408 .4701 .37509 .46649 .36835 .45981 Mtetra
.36835 .45981 .37509 .46649 .38615 .46288 .37944 .45616 Mtetra
.37944 .45616 .38615 .46288 .39725 .45925 .39057 .45251 Mtetra
.39057 .45251 .39725 .45925 .40839 .45561 .40174 .44884 Mtetra
.40174 .44884 .40839 .45561 .41959 .45196 .41296 .44517 Mtetra
.663 .742 .909 r
.41296 .44517 .41959 .45196 .43083 .44829 .42423 .44148 Mtetra
.662 .742 .909 r
.42423 .44148 .43083 .44829 .44211 .44462 .43555 .43779 Mtetra
.43555 .43779 .44211 .44462 .45345 .44094 .44691 .4341 Mtetra
.662 .742 .91 r
.44691 .4341 .45345 .44094 .46483 .43726 .45832 .4304 Mtetra
.661 .742 .91 r
.45832 .4304 .46483 .43726 .47626 .43358 .46978 .42671 Mtetra
.66 .743 .911 r
.46978 .42671 .47626 .43358 .48773 .4299 .48129 .42303 Mtetra
.659 .743 .912 r
.48129 .42303 .48773 .4299 .49926 .42623 .49285 .41935 Mtetra
.658 .744 .913 r
.49285 .41935 .49926 .42623 .51083 .42256 .50445 .41569 Mtetra
.657 .744 .914 r
.50445 .41569 .51083 .42256 .52246 .41891 .51611 .41204 Mtetra
.657 .745 .915 r
.51611 .41204 .52246 .41891 .53413 .41526 .52782 .40839 Mtetra
.656 .746 .916 r
.52782 .40839 .53413 .41526 .54586 .41162 .53958 .40476 Mtetra
.655 .747 .917 r
.53958 .40476 .54586 .41162 .55764 .40798 .55139 .40112 Mtetra
.655 .748 .918 r
.55139 .40112 .55764 .40798 .56947 .40433 .56326 .39747 Mtetra
.655 .748 .919 r
.56326 .39747 .56947 .40433 .58135 .40068 .57517 .3938 Mtetra
.656 .749 .919 r
.57517 .3938 .58135 .40068 .59329 .39699 .58714 .39009 Mtetra
.656 .75 .919 r
.58714 .39009 .59329 .39699 .60528 .39328 .59917 .38636 Mtetra
.644 .746 .923 r
.59917 .38636 .60528 .39328 .61732 .38954 .61125 .38296 Mtetra
.471 .685 .959 r
.61125 .38296 .61732 .38954 .62943 .38641 .62351 .38318 Mtetra
.448 0 0 r
.62351 .38318 .62943 .38641 .64181 .38877 .63613 .39157 Mtetra
.299 0 0 r
.63613 .39157 .64181 .38877 .6547 .40145 .64861 .39233 Mtetra
.846 .75 .756 r
.64861 .39233 .6547 .40145 .66721 .40134 .66047 .37612 Mtetra
.696 .547 .681 r
.66047 .37612 .66721 .40134 .67882 .38073 .67246 .36385 Mtetra
.659 .578 .752 r
.67246 .36385 .67882 .38073 .69072 .36708 .68478 .35823 Mtetra
.669 .707 .876 r
.68478 .35823 .69072 .36708 .70304 .3614 .69721 .35385 Mtetra
.671 .744 .905 r
.69721 .35385 .70304 .3614 .71548 .35705 .7097 .3495 Mtetra
.671 .745 .906 r
.7097 .3495 .71548 .35705 .72799 .35273 .72223 .34512 Mtetra
.671 .744 .905 r
.72223 .34512 .72799 .35273 .74054 .34839 .73483 .34073 Mtetra
.671 .743 .905 r
.73483 .34073 .74054 .34839 .75315 .34404 .74747 .33632 Mtetra
.67 .743 .905 r
.74747 .33632 .75315 .34404 .76581 .33967 .76017 .33191 Mtetra
.67 .742 .905 r
.76017 .33191 .76581 .33967 .77853 .33531 .77293 .32751 Mtetra
.669 .742 .905 r
.77293 .32751 .77853 .33531 .7913 .33095 .78575 .32312 Mtetra
.668 .742 .905 r
.78575 .32312 .7913 .33095 .80414 .32659 .79862 .31873 Mtetra
.667 .741 .906 r
.79862 .31873 .80414 .32659 .81703 .32224 .81155 .31435 Mtetra
.666 .741 .906 r
.81155 .31435 .81703 .32224 .82998 .3179 .82455 .30998 Mtetra
.82455 .30998 .82998 .3179 .84299 .31356 .8376 .30561 Mtetra
.665 .741 .907 r
.8376 .30561 .84299 .31356 .85606 .30921 .85071 .30124 Mtetra
.85071 .30124 .85606 .30921 .86919 .30487 .86388 .29686 Mtetra
.664 .741 .907 r
.86388 .29686 .86919 .30487 .88238 .30052 .87712 .29248 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.663 .741 .908 r
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45672 Mtetra
.3505 .45672 .35732 .46343 .36835 .45981 .36156 .45307 Mtetra
.36156 .45307 .36835 .45981 .37944 .45616 .37267 .4494 Mtetra
.37267 .4494 .37944 .45616 .39057 .45251 .38383 .44572 Mtetra
.38383 .44572 .39057 .45251 .40174 .44884 .39504 .44203 Mtetra
.663 .742 .909 r
.39504 .44203 .40174 .44884 .41296 .44517 .40629 .43833 Mtetra
.662 .742 .909 r
.40629 .43833 .41296 .44517 .42423 .44148 .41759 .43463 Mtetra
.41759 .43463 .42423 .44148 .43555 .43779 .42893 .43092 Mtetra
.662 .742 .91 r
.42893 .43092 .43555 .43779 .44691 .4341 .44032 .42721 Mtetra
.661 .742 .91 r
.44032 .42721 .44691 .4341 .45832 .4304 .45176 .42351 Mtetra
.66 .743 .911 r
.45176 .42351 .45832 .4304 .46978 .42671 .46325 .41981 Mtetra
.659 .743 .912 r
.46325 .41981 .46978 .42671 .48129 .42303 .47479 .41613 Mtetra
.658 .744 .913 r
.47479 .41613 .48129 .42303 .49285 .41935 .48638 .41245 Mtetra
.657 .744 .914 r
.48638 .41245 .49285 .41935 .50445 .41569 .49802 .40879 Mtetra
.656 .745 .915 r
.49802 .40879 .50445 .41569 .51611 .41204 .50971 .40515 Mtetra
.655 .746 .916 r
.50971 .40515 .51611 .41204 .52782 .40839 .52145 .40151 Mtetra
.655 .747 .918 r
.52145 .40151 .52782 .40839 .53958 .40476 .53325 .39788 Mtetra
.654 .748 .918 r
.53325 .39788 .53958 .40476 .55139 .40112 .54509 .39423 Mtetra
.654 .748 .919 r
.54509 .39423 .55139 .40112 .56326 .39747 .55699 .39058 Mtetra
.655 .749 .919 r
.55699 .39058 .56326 .39747 .57517 .3938 .56894 .38689 Mtetra
.655 .75 .919 r
.56894 .38689 .57517 .3938 .58714 .39009 .58095 .38316 Mtetra
.649 .748 .922 r
.58095 .38316 .58714 .39009 .59917 .38636 .59301 .3796 Mtetra
.553 .717 .949 r
.59301 .3796 .59917 .38636 .61125 .38296 .60519 .37831 Mtetra
0 .453 .853 r
.60519 .37831 .61125 .38296 .62351 .38318 .61762 .38311 Mtetra
.071 0 0 r
.61762 .38311 .62351 .38318 .63613 .39157 .63003 .38386 Mtetra
.827 .776 .804 r
.63003 .38386 .63613 .39157 .64861 .39233 .64206 .37136 Mtetra
.702 .571 .705 r
.64206 .37136 .64861 .39233 .66047 .37612 .65414 .36056 Mtetra
.663 .593 .767 r
.65414 .36056 .66047 .37612 .67246 .36385 .66645 .35504 Mtetra
.67 .709 .877 r
.66645 .35504 .67246 .36385 .68478 .35823 .67887 .35064 Mtetra
.671 .744 .905 r
.67887 .35064 .68478 .35823 .69721 .35385 .69134 .34626 Mtetra
.672 .745 .906 r
.69134 .34626 .69721 .35385 .7097 .3495 .70386 .34185 Mtetra
.672 .744 .905 r
.70386 .34185 .7097 .3495 .72223 .34512 .71643 .33742 Mtetra
.672 .743 .904 r
.71643 .33742 .72223 .34512 .73483 .34073 .72906 .33297 Mtetra
.671 .743 .904 r
.72906 .33297 .73483 .34073 .74747 .33632 .74175 .32852 Mtetra
.67 .742 .904 r
.74175 .32852 .74747 .33632 .76017 .33191 .75449 .32408 Mtetra
.669 .742 .904 r
.75449 .32408 .76017 .33191 .77293 .32751 .76729 .31964 Mtetra
.669 .741 .905 r
.76729 .31964 .77293 .32751 .78575 .32312 .78014 .31522 Mtetra
.668 .741 .905 r
.78014 .31522 .78575 .32312 .79862 .31873 .79306 .3108 Mtetra
.667 .741 .906 r
.79306 .3108 .79862 .31873 .81155 .31435 .80604 .3064 Mtetra
.666 .741 .906 r
.80604 .3064 .81155 .31435 .82455 .30998 .81907 .302 Mtetra
.81907 .302 .82455 .30998 .8376 .30561 .83217 .2976 Mtetra
.665 .741 .907 r
.83217 .2976 .8376 .30561 .85071 .30124 .84532 .2932 Mtetra
.84532 .2932 .85071 .30124 .86388 .29686 .85854 .28879 Mtetra
.664 .741 .907 r
.85854 .28879 .86388 .29686 .87712 .29248 .87181 .28438 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46455 Mtetra
.29971 .46455 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.663 .741 .908 r
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45672 .34363 .44996 Mtetra
.34363 .44996 .3505 .45672 .36156 .45307 .35472 .44628 Mtetra
.35472 .44628 .36156 .45307 .37267 .4494 .36586 .44258 Mtetra
.36586 .44258 .37267 .4494 .38383 .44572 .37705 .43888 Mtetra
.37705 .43888 .38383 .44572 .39504 .44203 .38828 .43517 Mtetra
.663 .742 .909 r
.38828 .43517 .39504 .44203 .40629 .43833 .39956 .43145 Mtetra
.662 .742 .909 r
.39956 .43145 .40629 .43833 .41759 .43463 .41089 .42773 Mtetra
.662 .742 .91 r
.41089 .42773 .41759 .43463 .42893 .43092 .42226 .42401 Mtetra
.661 .742 .91 r
.42226 .42401 .42893 .43092 .44032 .42721 .43368 .42029 Mtetra
.66 .743 .911 r
.43368 .42029 .44032 .42721 .45176 .42351 .44516 .41658 Mtetra
.659 .743 .912 r
.44516 .41658 .45176 .42351 .46325 .41981 .45668 .41288 Mtetra
.658 .744 .913 r
.45668 .41288 .46325 .41981 .47479 .41613 .46825 .4092 Mtetra
.657 .744 .914 r
.46825 .4092 .47479 .41613 .48638 .41245 .47987 .40553 Mtetra
.656 .745 .915 r
.47987 .40553 .48638 .41245 .49802 .40879 .49154 .40188 Mtetra
.655 .746 .917 r
.49154 .40188 .49802 .40879 .50971 .40515 .50326 .39824 Mtetra
.654 .747 .918 r
.50326 .39824 .50971 .40515 .52145 .40151 .51503 .39461 Mtetra
.653 .747 .919 r
.51503 .39461 .52145 .40151 .53325 .39788 .52686 .39097 Mtetra
.653 .748 .919 r
.52686 .39097 .53325 .39788 .54509 .39423 .53874 .38732 Mtetra
.654 .749 .92 r
.53874 .38732 .54509 .39423 .55699 .39058 .55068 .38365 Mtetra
.654 .75 .92 r
.55068 .38365 .55699 .39058 .56894 .38689 .56266 .37993 Mtetra
.652 .749 .921 r
.56266 .37993 .56894 .38689 .58095 .38316 .57471 .37628 Mtetra
.598 .733 .939 r
.57471 .37628 .58095 .38316 .59301 .3796 .58683 .37399 Mtetra
.301 .635 .964 r
.58683 .37399 .59301 .3796 .60519 .37831 .59912 .37597 Mtetra
.22 .705 .93 r
.59912 .37597 .60519 .37831 .61762 .38311 .61147 .37618 Mtetra
.795 .791 .849 r
.61147 .37618 .61762 .38311 .63003 .38386 .62359 .36658 Mtetra
.706 .599 .734 r
.62359 .36658 .63003 .38386 .64206 .37136 .63574 .35722 Mtetra
.667 .612 .784 r
.63574 .35722 .64206 .37136 .65414 .36056 .64805 .35185 Mtetra
.67 .713 .88 r
.64805 .35185 .65414 .36056 .66645 .35504 .66045 .34743 Mtetra
.672 .744 .905 r
.66045 .34743 .66645 .35504 .67887 .35064 .67291 .34303 Mtetra
.672 .745 .905 r
.67291 .34303 .67887 .35064 .69134 .34626 .68541 .33858 Mtetra
.672 .744 .904 r
.68541 .33858 .69134 .34626 .70386 .34185 .69797 .33411 Mtetra
.672 .743 .904 r
.69797 .33411 .70386 .34185 .71643 .33742 .71059 .32962 Mtetra
.71059 .32962 .71643 .33742 .72906 .33297 .72325 .32513 Mtetra
.671 .742 .904 r
.72325 .32513 .72906 .33297 .74175 .32852 .73598 .32064 Mtetra
.67 .742 .904 r
.73598 .32064 .74175 .32852 .75449 .32408 .74876 .31616 Mtetra
.669 .741 .904 r
.74876 .31616 .75449 .32408 .76729 .31964 .7616 .3117 Mtetra
.668 .741 .905 r
.7616 .3117 .76729 .31964 .78014 .31522 .7745 .30725 Mtetra
.667 .741 .905 r
.7745 .30725 .78014 .31522 .79306 .3108 .78745 .30281 Mtetra
.667 .741 .906 r
.78745 .30281 .79306 .3108 .80604 .3064 .80047 .29838 Mtetra
.666 .741 .906 r
.80047 .29838 .80604 .3064 .81907 .302 .81355 .29395 Mtetra
.665 .741 .907 r
.81355 .29395 .81907 .302 .83217 .2976 .82669 .28952 Mtetra
.82669 .28952 .83217 .2976 .84532 .2932 .83989 .28509 Mtetra
.664 .741 .907 r
.83989 .28509 .84532 .2932 .85854 .28879 .85315 .28066 Mtetra
.85315 .28066 .85854 .28879 .87181 .28438 .86647 .27621 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46455 .29268 .45784 Mtetra
.29268 .45784 .29971 .46455 .31062 .46092 .30361 .45419 Mtetra
.663 .741 .908 r
.30361 .45419 .31062 .46092 .32158 .45728 .3146 .45052 Mtetra
.3146 .45052 .32158 .45728 .33258 .45362 .32563 .44684 Mtetra
.32563 .44684 .33258 .45362 .34363 .44996 .3367 .44314 Mtetra
.3367 .44314 .34363 .44996 .35472 .44628 .34782 .43944 Mtetra
.34782 .43944 .35472 .44628 .36586 .44258 .35899 .43572 Mtetra
.35899 .43572 .36586 .44258 .37705 .43888 .37021 .43199 Mtetra
.663 .742 .909 r
.37021 .43199 .37705 .43888 .38828 .43517 .38147 .42826 Mtetra
.662 .742 .909 r
.38147 .42826 .38828 .43517 .39956 .43145 .39278 .42452 Mtetra
.662 .742 .91 r
.39278 .42452 .39956 .43145 .41089 .42773 .40414 .42079 Mtetra
.661 .742 .91 r
.40414 .42079 .41089 .42773 .42226 .42401 .41554 .41705 Mtetra
.66 .742 .911 r
.41554 .41705 .42226 .42401 .43368 .42029 .42699 .41333 Mtetra
.659 .743 .912 r
.42699 .41333 .43368 .42029 .44516 .41658 .43849 .40962 Mtetra
.658 .743 .913 r
.43849 .40962 .44516 .41658 .45668 .41288 .45005 .40593 Mtetra
.657 .744 .914 r
.45005 .40593 .45668 .41288 .46825 .4092 .46165 .40225 Mtetra
.656 .745 .915 r
.46165 .40225 .46825 .4092 .47987 .40553 .4733 .39859 Mtetra
.654 .746 .917 r
.4733 .39859 .47987 .40553 .49154 .40188 .485 .39495 Mtetra
.654 .746 .918 r
.485 .39495 .49154 .40188 .50326 .39824 .49676 .39131 Mtetra
.653 .747 .919 r
.49676 .39131 .50326 .39824 .51503 .39461 .50856 .38768 Mtetra
.653 .748 .92 r
.50856 .38768 .51503 .39461 .52686 .39097 .52043 .38404 Mtetra
.653 .749 .92 r
.52043 .38404 .52686 .39097 .53874 .38732 .53234 .38038 Mtetra
.654 .75 .92 r
.53234 .38038 .53874 .38732 .55068 .38365 .54431 .37667 Mtetra
.653 .75 .921 r
.54431 .37667 .55068 .38365 .56266 .37993 .55633 .37298 Mtetra
.624 .741 .931 r
.55633 .37298 .56266 .37993 .57471 .37628 .56842 .37004 Mtetra
.472 .703 .969 r
.56842 .37004 .57471 .37628 .58683 .37399 .58062 .36995 Mtetra
.418 .761 .995 r
.58062 .36995 .58683 .37399 .59912 .37597 .5929 .36936 Mtetra
.757 .794 .883 r
.5929 .36936 .59912 .37597 .61147 .37618 .60508 .3619 Mtetra
.708 .63 .768 r
.60508 .3619 .61147 .37618 .62359 .36658 .61727 .35384 Mtetra
.67 .634 .804 r
.61727 .35384 .62359 .36658 .63574 .35722 .62958 .34864 Mtetra
.67 .717 .883 r
.62958 .34864 .63574 .35722 .64805 .35185 .64197 .34421 Mtetra
.672 .744 .905 r
.64197 .34421 .64805 .35185 .66045 .34743 .6544 .33978 Mtetra
.673 .745 .905 r
.6544 .33978 .66045 .34743 .67291 .34303 .6669 .3353 Mtetra
.673 .744 .904 r
.6669 .3353 .67291 .34303 .68541 .33858 .67944 .33079 Mtetra
.673 .743 .903 r
.67944 .33079 .68541 .33858 .69797 .33411 .69204 .32626 Mtetra
.673 .742 .903 r
.69204 .32626 .69797 .33411 .71059 .32962 .70469 .32173 Mtetra
.672 .742 .903 r
.70469 .32173 .71059 .32962 .72325 .32513 .71739 .3172 Mtetra
.671 .741 .903 r
.71739 .3172 .72325 .32513 .73598 .32064 .73016 .31268 Mtetra
.67 .741 .904 r
.73016 .31268 .73598 .32064 .74876 .31616 .74298 .30818 Mtetra
.669 .741 .904 r
.74298 .30818 .74876 .31616 .7616 .3117 .75586 .30369 Mtetra
.668 .741 .905 r
.75586 .30369 .7616 .3117 .7745 .30725 .7688 .29921 Mtetra
.667 .741 .905 r
.7688 .29921 .7745 .30725 .78745 .30281 .7818 .29475 Mtetra
.666 .741 .906 r
.7818 .29475 .78745 .30281 .80047 .29838 .79486 .29029 Mtetra
.79486 .29029 .80047 .29838 .81355 .29395 .80798 .28584 Mtetra
.665 .741 .907 r
.80798 .28584 .81355 .29395 .82669 .28952 .82116 .28138 Mtetra
.82116 .28138 .82669 .28952 .83989 .28509 .8344 .27692 Mtetra
.664 .741 .907 r
.8344 .27692 .83989 .28509 .85315 .28066 .84771 .27245 Mtetra
.84771 .27245 .85315 .28066 .86647 .27621 .86107 .26797 Mtetra
.664 .741 .908 r
.25296 .46204 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.663 .741 .908 r
.28559 .45108 .29268 .45784 .30361 .45419 .29655 .4474 Mtetra
.29655 .4474 .30361 .45419 .3146 .45052 .30756 .44371 Mtetra
.30756 .44371 .3146 .45052 .32563 .44684 .31862 .44 Mtetra
.31862 .44 .32563 .44684 .3367 .44314 .32972 .43628 Mtetra
.32972 .43628 .3367 .44314 .34782 .43944 .34087 .43255 Mtetra
.34087 .43255 .34782 .43944 .35899 .43572 .35207 .4288 Mtetra
.663 .742 .909 r
.35207 .4288 .35899 .43572 .37021 .43199 .36331 .42506 Mtetra
.662 .742 .909 r
.36331 .42506 .37021 .43199 .38147 .42826 .37461 .42131 Mtetra
.662 .742 .91 r
.37461 .42131 .38147 .42826 .39278 .42452 .38594 .41755 Mtetra
.661 .742 .91 r
.38594 .41755 .39278 .42452 .40414 .42079 .39733 .41381 Mtetra
.66 .742 .911 r
.39733 .41381 .40414 .42079 .41554 .41705 .40876 .41007 Mtetra
.659 .743 .912 r
.40876 .41007 .41554 .41705 .42699 .41333 .42025 .40634 Mtetra
.658 .743 .913 r
.42025 .40634 .42699 .41333 .43849 .40962 .43178 .40264 Mtetra
.657 .744 .914 r
.43178 .40264 .43849 .40962 .45005 .40593 .44336 .39895 Mtetra
.655 .745 .915 r
.44336 .39895 .45005 .40593 .46165 .40225 .45499 .39528 Mtetra
.654 .745 .917 r
.45499 .39528 .46165 .40225 .4733 .39859 .46668 .39163 Mtetra
.653 .746 .918 r
.46668 .39163 .4733 .39859 .485 .39495 .47841 .38799 Mtetra
.652 .747 .919 r
.47841 .38799 .485 .39495 .49676 .39131 .4902 .38436 Mtetra
.652 .748 .92 r
.4902 .38436 .49676 .39131 .50856 .38768 .50204 .38073 Mtetra
.652 .749 .921 r
.50204 .38073 .50856 .38768 .52043 .38404 .51394 .37707 Mtetra
.653 .749 .921 r
.51394 .37707 .52043 .38404 .53234 .38038 .52588 .37338 Mtetra
.653 .75 .921 r
.52588 .37338 .53234 .38038 .54431 .37667 .53789 .36967 Mtetra
.638 .745 .926 r
.53789 .36967 .54431 .37667 .55633 .37298 .54995 .36635 Mtetra
.558 .728 .954 r
.54995 .36635 .55633 .37298 .56842 .37004 .56209 .36482 Mtetra
.522 .765 .985 r
.56209 .36482 .56842 .37004 .58062 .36995 .57431 .36339 Mtetra
.721 .787 .904 r
.57431 .36339 .58062 .36995 .5929 .36936 .58651 .35738 Mtetra
.707 .661 .803 r
.58651 .35738 .5929 .36936 .60508 .3619 .59873 .35043 Mtetra
.673 .656 .825 r
.59873 .35043 .60508 .3619 .61727 .35384 .61103 .3454 Mtetra
.671 .721 .887 r
.61103 .3454 .61727 .35384 .62958 .34864 .62341 .34097 Mtetra
.672 .744 .905 r
.62341 .34097 .62958 .34864 .64197 .34421 .63583 .33652 Mtetra
.673 .745 .905 r
.63583 .33652 .64197 .34421 .6544 .33978 .6483 .33201 Mtetra
.674 .744 .903 r
.6483 .33201 .6544 .33978 .6669 .3353 .66083 .32747 Mtetra
.674 .743 .903 r
.66083 .32747 .6669 .3353 .67944 .33079 .67341 .3229 Mtetra
.673 .742 .902 r
.67341 .3229 .67944 .33079 .69204 .32626 .68605 .31833 Mtetra
.68605 .31833 .69204 .32626 .70469 .32173 .69874 .31375 Mtetra
.672 .741 .903 r
.69874 .31375 .70469 .32173 .71739 .3172 .71149 .30919 Mtetra
.671 .741 .903 r
.71149 .30919 .71739 .3172 .73016 .31268 .72429 .30465 Mtetra
.67 .741 .904 r
.72429 .30465 .73016 .31268 .74298 .30818 .73715 .30012 Mtetra
.668 .741 .904 r
.73715 .30012 .74298 .30818 .75586 .30369 .75007 .29561 Mtetra
.668 .741 .905 r
.75007 .29561 .75586 .30369 .7688 .29921 .76306 .29111 Mtetra
.667 .741 .906 r
.76306 .29111 .7688 .29921 .7818 .29475 .7761 .28662 Mtetra
.666 .741 .906 r
.7761 .28662 .7818 .29475 .79486 .29029 .7892 .28214 Mtetra
.665 .741 .906 r
.7892 .28214 .79486 .29029 .80798 .28584 .80236 .27766 Mtetra
.665 .741 .907 r
.80236 .27766 .80798 .28584 .82116 .28138 .81559 .27318 Mtetra
.664 .741 .907 r
.81559 .27318 .82116 .28138 .8344 .27692 .82888 .26868 Mtetra
.82888 .26868 .8344 .27692 .84771 .27245 .84223 .26418 Mtetra
.664 .741 .908 r
.84223 .26418 .84771 .27245 .86107 .26797 .85564 .25966 Mtetra
.24574 .45531 .25296 .46204 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44797 Mtetra
.663 .741 .908 r
.2675 .44797 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .44371 .30047 .43684 Mtetra
.30047 .43684 .30756 .44371 .31862 .44 .31156 .43311 Mtetra
.31156 .43311 .31862 .44 .32972 .43628 .32269 .42936 Mtetra
.32269 .42936 .32972 .43628 .34087 .43255 .33387 .42561 Mtetra
.663 .742 .909 r
.33387 .42561 .34087 .43255 .35207 .4288 .34509 .42184 Mtetra
.662 .742 .909 r
.34509 .42184 .35207 .4288 .36331 .42506 .35637 .41808 Mtetra
.35637 .41808 .36331 .42506 .37461 .42131 .36769 .41431 Mtetra
.661 .742 .91 r
.36769 .41431 .37461 .42131 .38594 .41755 .37905 .41055 Mtetra
.66 .742 .911 r
.37905 .41055 .38594 .41755 .39733 .41381 .39047 .40679 Mtetra
.659 .743 .912 r
.39047 .40679 .39733 .41381 .40876 .41007 .40193 .40305 Mtetra
.658 .743 .913 r
.40193 .40305 .40876 .41007 .42025 .40634 .41345 .39933 Mtetra
.657 .744 .914 r
.41345 .39933 .42025 .40634 .43178 .40264 .42501 .39562 Mtetra
.655 .744 .915 r
.42501 .39562 .43178 .40264 .44336 .39895 .43662 .39194 Mtetra
.654 .745 .917 r
.43662 .39194 .44336 .39895 .45499 .39528 .44828 .38828 Mtetra
.653 .746 .918 r
.44828 .38828 .45499 .39528 .46668 .39163 .46 .38464 Mtetra
.652 .747 .919 r
.46 .38464 .46668 .39163 .47841 .38799 .47177 .38101 Mtetra
.651 .748 .92 r
.47177 .38101 .47841 .38799 .4902 .38436 .48359 .37738 Mtetra
.651 .748 .921 r
.48359 .37738 .4902 .38436 .50204 .38073 .49546 .37373 Mtetra
.652 .749 .921 r
.49546 .37373 .50204 .38073 .51394 .37707 .50739 .37004 Mtetra
.652 .75 .921 r
.50739 .37004 .51394 .37707 .52588 .37338 .51938 .36633 Mtetra
.645 .747 .924 r
.51938 .36633 .52588 .37338 .53789 .36967 .53142 .36279 Mtetra
.603 .739 .94 r
.53142 .36279 .53789 .36967 .54995 .36635 .54352 .36031 Mtetra
.578 .759 .964 r
.54352 .36031 .54995 .36635 .56209 .36482 .55569 .35814 Mtetra
.694 .777 .915 r
.55569 .35814 .56209 .36482 .57431 .36339 .56789 .35307 Mtetra
.701 .689 .835 r
.56789 .35307 .57431 .36339 .58651 .35738 .58012 .34699 Mtetra
.674 .678 .846 r
.58012 .34699 .58651 .35738 .59873 .35043 .59242 .34214 Mtetra
.67 .726 .891 r
.59242 .34214 .59873 .35043 .61103 .3454 .60477 .3377 Mtetra
.672 .744 .905 r
.60477 .3377 .61103 .3454 .62341 .34097 .61718 .33324 Mtetra
.673 .744 .904 r
.61718 .33324 .62341 .34097 .63583 .33652 .62964 .32871 Mtetra
.674 .744 .903 r
.62964 .32871 .63583 .33652 .6483 .33201 .64215 .32413 Mtetra
.674 .743 .902 r
.64215 .32413 .6483 .33201 .66083 .32747 .65472 .31953 Mtetra
.674 .742 .902 r
.65472 .31953 .66083 .32747 .67341 .3229 .66734 .31492 Mtetra
.673 .741 .902 r
.66734 .31492 .67341 .3229 .68605 .31833 .68001 .3103 Mtetra
.672 .741 .902 r
.68001 .3103 .68605 .31833 .69874 .31375 .69274 .3057 Mtetra
.671 .741 .902 r
.69274 .3057 .69874 .31375 .71149 .30919 .70553 .30111 Mtetra
.67 .74 .903 r
.70553 .30111 .71149 .30919 .72429 .30465 .71837 .29654 Mtetra
.669 .74 .904 r
.71837 .29654 .72429 .30465 .73715 .30012 .73128 .292 Mtetra
.668 .74 .904 r
.73128 .292 .73715 .30012 .75007 .29561 .74424 .28746 Mtetra
.667 .741 .905 r
.74424 .28746 .75007 .29561 .76306 .29111 .75726 .28295 Mtetra
.666 .741 .906 r
.75726 .28295 .76306 .29111 .7761 .28662 .77035 .27843 Mtetra
.77035 .27843 .7761 .28662 .7892 .28214 .7835 .27393 Mtetra
.665 .741 .907 r
.7835 .27393 .7892 .28214 .80236 .27766 .7967 .26942 Mtetra
.7967 .26942 .80236 .27766 .81559 .27318 .80997 .2649 Mtetra
.664 .741 .907 r
.80997 .2649 .81559 .27318 .82888 .26868 .8233 .26038 Mtetra
.8233 .26038 .82888 .26868 .84223 .26418 .8367 .25584 Mtetra
.664 .741 .908 r
.8367 .25584 .84223 .26418 .85564 .25966 .85015 .25129 Mtetra
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.663 .741 .908 r
.24934 .44484 .25659 .45164 .2675 .44797 .26027 .44113 Mtetra
.26027 .44113 .2675 .44797 .27844 .44427 .27124 .43741 Mtetra
.27124 .43741 .27844 .44427 .28944 .44056 .28226 .43368 Mtetra
.28226 .43368 .28944 .44056 .30047 .43684 .29333 .42993 Mtetra
.29333 .42993 .30047 .43684 .31156 .43311 .30444 .42617 Mtetra
.30444 .42617 .31156 .43311 .32269 .42936 .3156 .4224 Mtetra
.663 .741 .909 r
.3156 .4224 .32269 .42936 .33387 .42561 .32681 .41862 Mtetra
.662 .742 .909 r
.32681 .41862 .33387 .42561 .34509 .42184 .33806 .41484 Mtetra
.33806 .41484 .34509 .42184 .35637 .41808 .34936 .41105 Mtetra
.661 .742 .91 r
.34936 .41105 .35637 .41808 .36769 .41431 .36071 .40727 Mtetra
.66 .742 .911 r
.36071 .40727 .36769 .41431 .37905 .41055 .37211 .4035 Mtetra
.659 .743 .911 r
.37211 .4035 .37905 .41055 .39047 .40679 .38355 .39974 Mtetra
.658 .743 .913 r
.38355 .39974 .39047 .40679 .40193 .40305 .39505 .396 Mtetra
.657 .743 .914 r
.39505 .396 .40193 .40305 .41345 .39933 .40659 .39228 Mtetra
.655 .744 .915 r
.40659 .39228 .41345 .39933 .42501 .39562 .41818 .38858 Mtetra
.654 .745 .916 r
.41818 .38858 .42501 .39562 .43662 .39194 .42982 .38491 Mtetra
.653 .746 .918 r
.42982 .38491 .43662 .39194 .44828 .38828 .44152 .38126 Mtetra
.652 .746 .919 r
.44152 .38126 .44828 .38828 .46 .38464 .45327 .37762 Mtetra
.651 .747 .92 r
.45327 .37762 .46 .38464 .47177 .38101 .46507 .37399 Mtetra
.651 .748 .921 r
.46507 .37399 .47177 .38101 .48359 .37738 .47692 .37034 Mtetra
.651 .749 .921 r
.47692 .37034 .48359 .37738 .49546 .37373 .48883 .36667 Mtetra
.652 .749 .921 r
.48883 .36667 .49546 .37373 .50739 .37004 .50079 .36296 Mtetra
.649 .748 .922 r
.50079 .36296 .50739 .37004 .51938 .36633 .51281 .35931 Mtetra
.627 .744 .931 r
.51281 .35931 .51938 .36633 .53142 .36279 .52489 .35624 Mtetra
.61 .754 .947 r
.52489 .35624 .53142 .36279 .54352 .36031 .53702 .35348 Mtetra
.676 .768 .92 r
.53702 .35348 .54352 .36031 .55569 .35814 .54921 .34895 Mtetra
.693 .711 .862 r
.54921 .34895 .55569 .35814 .56789 .35307 .56144 .34354 Mtetra
.674 .697 .864 r
.56144 .34354 .56789 .35307 .58012 .34699 .57372 .33884 Mtetra
.67 .73 .895 r
.57372 .33884 .58012 .34699 .59242 .34214 .58607 .33441 Mtetra
.672 .744 .905 r
.58607 .33441 .59242 .34214 .60477 .3377 .59846 .32993 Mtetra
.673 .744 .904 r
.59846 .32993 .60477 .3377 .61718 .33324 .6109 .32538 Mtetra
.674 .743 .902 r
.6109 .32538 .61718 .33324 .62964 .32871 .6234 .32078 Mtetra
.675 .742 .902 r
.6234 .32078 .62964 .32871 .64215 .32413 .63595 .31615 Mtetra
.674 .741 .901 r
.63595 .31615 .64215 .32413 .65472 .31953 .64855 .31149 Mtetra
.64855 .31149 .65472 .31953 .66734 .31492 .66121 .30684 Mtetra
.673 .741 .901 r
.66121 .30684 .66734 .31492 .68001 .3103 .67392 .3022 Mtetra
.672 .74 .902 r
.67392 .3022 .68001 .3103 .69274 .3057 .68669 .29757 Mtetra
.671 .74 .902 r
.68669 .29757 .69274 .3057 .70553 .30111 .69952 .29296 Mtetra
.67 .74 .903 r
.69952 .29296 .70553 .30111 .71837 .29654 .71241 .28837 Mtetra
.669 .74 .904 r
.71241 .28837 .71837 .29654 .73128 .292 .72535 .28381 Mtetra
.667 .74 .905 r
.72535 .28381 .73128 .292 .74424 .28746 .73836 .27926 Mtetra
.667 .741 .905 r
.73836 .27926 .74424 .28746 .75726 .28295 .75143 .27472 Mtetra
.666 .741 .906 r
.75143 .27472 .75726 .28295 .77035 .27843 .76455 .27018 Mtetra
.665 .741 .906 r
.76455 .27018 .77035 .27843 .7835 .27393 .77774 .26565 Mtetra
.665 .741 .907 r
.77774 .26565 .7835 .27393 .7967 .26942 .79099 .26111 Mtetra
.664 .741 .907 r
.79099 .26111 .7967 .26942 .80997 .2649 .80431 .25656 Mtetra
.80431 .25656 .80997 .2649 .8233 .26038 .81768 .252 Mtetra
.664 .741 .908 r
.81768 .252 .8233 .26038 .8367 .25584 .83112 .24743 Mtetra
.83112 .24743 .8367 .25584 .85015 .25129 .84462 .24284 Mtetra
.663 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43425 Mtetra
.25299 .43425 .26027 .44113 .27124 .43741 .26399 .4305 Mtetra
.26399 .4305 .27124 .43741 .28226 .43368 .27504 .42674 Mtetra
.27504 .42674 .28226 .43368 .29333 .42993 .28613 .42296 Mtetra
.28613 .42296 .29333 .42993 .30444 .42617 .29727 .41918 Mtetra
.663 .741 .909 r
.29727 .41918 .30444 .42617 .3156 .4224 .30846 .41538 Mtetra
.662 .742 .909 r
.30846 .41538 .3156 .4224 .32681 .41862 .31969 .41158 Mtetra
.31969 .41158 .32681 .41862 .33806 .41484 .33098 .40778 Mtetra
.661 .742 .91 r
.33098 .40778 .33806 .41484 .34936 .41105 .34231 .40398 Mtetra
.66 .742 .91 r
.34231 .40398 .34936 .41105 .36071 .40727 .35368 .40019 Mtetra
.659 .742 .911 r
.35368 .40019 .36071 .40727 .37211 .4035 .36511 .39642 Mtetra
.658 .743 .912 r
.36511 .39642 .37211 .4035 .38355 .39974 .37658 .39266 Mtetra
.657 .743 .914 r
.37658 .39266 .38355 .39974 .39505 .396 .3881 .38892 Mtetra
.656 .744 .915 r
.3881 .38892 .39505 .396 .40659 .39228 .39968 .3852 Mtetra
.654 .745 .916 r
.39968 .3852 .40659 .39228 .41818 .38858 .4113 .38152 Mtetra
.653 .745 .918 r
.4113 .38152 .41818 .38858 .42982 .38491 .42297 .37785 Mtetra
.651 .746 .919 r
.42297 .37785 .42982 .38491 .44152 .38126 .4347 .37421 Mtetra
.651 .747 .92 r
.4347 .37421 .44152 .38126 .45327 .37762 .44648 .37057 Mtetra
.65 .748 .921 r
.44648 .37057 .45327 .37762 .46507 .37399 .45831 .36692 Mtetra
.45831 .36692 .46507 .37399 .47692 .37034 .4702 .36325 Mtetra
.651 .749 .921 r
.4702 .36325 .47692 .37034 .48883 .36667 .48214 .35954 Mtetra
.65 .748 .921 r
.48214 .35954 .48883 .36667 .50079 .36296 .49414 .35584 Mtetra
.639 .746 .926 r
.49414 .35584 .50079 .36296 .51281 .35931 .50619 .35242 Mtetra
.629 .751 .935 r
.50619 .35242 .51281 .35931 .52489 .35624 .5183 .34923 Mtetra
.666 .76 .92 r
.5183 .34923 .52489 .35624 .53702 .35348 .53047 .34501 Mtetra
.684 .726 .882 r
.53047 .34501 .53702 .35348 .54921 .34895 .54269 .34007 Mtetra
.672 .713 .878 r
.54269 .34007 .54921 .34895 .56144 .34354 .55496 .3355 Mtetra
.67 .734 .898 r
.55496 .3355 .56144 .34354 .57372 .33884 .56728 .33107 Mtetra
.672 .744 .905 r
.56728 .33107 .57372 .33884 .58607 .33441 .57966 .32659 Mtetra
.673 .744 .904 r
.57966 .32659 .58607 .33441 .59846 .32993 .59209 .32203 Mtetra
.674 .743 .902 r
.59209 .32203 .59846 .32993 .6109 .32538 .60457 .3174 Mtetra
.675 .742 .901 r
.60457 .3174 .6109 .32538 .6234 .32078 .61711 .31274 Mtetra
.675 .741 .9 r
.61711 .31274 .6234 .32078 .63595 .31615 .62969 .30806 Mtetra
.62969 .30806 .63595 .31615 .64855 .31149 .64233 .30337 Mtetra
.674 .74 .9 r
.64233 .30337 .64855 .31149 .66121 .30684 .65503 .29868 Mtetra
.673 .74 .901 r
.65503 .29868 .66121 .30684 .67392 .3022 .66778 .29401 Mtetra
.671 .74 .902 r
.66778 .29401 .67392 .3022 .68669 .29757 .68059 .28937 Mtetra
.67 .74 .902 r
.68059 .28937 .68669 .29757 .69952 .29296 .69346 .28474 Mtetra
.669 .74 .903 r
.69346 .28474 .69952 .29296 .71241 .28837 .70639 .28014 Mtetra
.668 .74 .904 r
.70639 .28014 .71241 .28837 .72535 .28381 .71938 .27556 Mtetra
.667 .74 .905 r
.71938 .27556 .72535 .28381 .73836 .27926 .73243 .27099 Mtetra
.666 .741 .906 r
.73243 .27099 .73836 .27926 .75143 .27472 .74554 .26642 Mtetra
.665 .741 .906 r
.74554 .26642 .75143 .27472 .76455 .27018 .75871 .26186 Mtetra
.665 .741 .907 r
.75871 .26186 .76455 .27018 .77774 .26565 .77194 .2573 Mtetra
.664 .741 .907 r
.77194 .2573 .77774 .26565 .79099 .26111 .78524 .25273 Mtetra
.78524 .25273 .79099 .26111 .80431 .25656 .79859 .24815 Mtetra
.79859 .24815 .80431 .25656 .81768 .252 .81201 .24356 Mtetra
.664 .741 .908 r
.81201 .24356 .81768 .252 .83112 .24743 .82549 .23895 Mtetra
.82549 .23895 .83112 .24743 .84462 .24284 .83904 .23432 Mtetra
.663 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43425 .24565 .42731 Mtetra
.24565 .42731 .25299 .43425 .26399 .4305 .25668 .42353 Mtetra
.25668 .42353 .26399 .4305 .27504 .42674 .26775 .41974 Mtetra
.26775 .41974 .27504 .42674 .28613 .42296 .27887 .41594 Mtetra
.27887 .41594 .28613 .42296 .29727 .41918 .29004 .41213 Mtetra
.662 .742 .909 r
.29004 .41213 .29727 .41918 .30846 .41538 .30126 .40832 Mtetra
.30126 .40832 .30846 .41538 .31969 .41158 .31252 .4045 Mtetra
.661 .742 .91 r
.31252 .4045 .31969 .41158 .33098 .40778 .32383 .40068 Mtetra
.32383 .40068 .33098 .40778 .34231 .40398 .33519 .39687 Mtetra
.66 .742 .911 r
.33519 .39687 .34231 .40398 .35368 .40019 .3466 .39308 Mtetra
.659 .743 .912 r
.3466 .39308 .35368 .40019 .36511 .39642 .35805 .3893 Mtetra
.657 .743 .913 r
.35805 .3893 .36511 .39642 .37658 .39266 .36955 .38554 Mtetra
.656 .744 .915 r
.36955 .38554 .37658 .39266 .3881 .38892 .3811 .3818 Mtetra
.654 .744 .916 r
.3811 .3818 .3881 .38892 .39968 .3852 .39271 .3781 Mtetra
.653 .745 .917 r
.39271 .3781 .39968 .3852 .4113 .38152 .40436 .37442 Mtetra
.651 .746 .919 r
.40436 .37442 .4113 .38152 .42297 .37785 .41606 .37076 Mtetra
.65 .746 .92 r
.41606 .37076 .42297 .37785 .4347 .37421 .42782 .36711 Mtetra
.65 .747 .921 r
.42782 .36711 .4347 .37421 .44648 .37057 .43963 .36346 Mtetra
.65 .748 .921 r
.43963 .36346 .44648 .37057 .45831 .36692 .4515 .35979 Mtetra
.4515 .35979 .45831 .36692 .4702 .36325 .46342 .35609 Mtetra
.651 .748 .921 r
.46342 .35609 .4702 .36325 .48214 .35954 .4754 .35236 Mtetra
.646 .747 .923 r
.4754 .35236 .48214 .35954 .49414 .35584 .48743 .34874 Mtetra
.64 .749 .927 r
.48743 .34874 .49414 .35584 .50619 .35242 .49952 .34526 Mtetra
.66 .755 .92 r
.49952 .34526 .50619 .35242 .5183 .34923 .51166 .34119 Mtetra
.676 .735 .895 r
.51166 .34119 .5183 .34923 .53047 .34501 .52387 .33658 Mtetra
.67 .724 .89 r
.52387 .33658 .53047 .34501 .54269 .34007 .53612 .33211 Mtetra
.669 .737 .901 r
.53612 .33211 .54269 .34007 .55496 .3355 .54843 .3277 Mtetra
.671 .743 .905 r
.54843 .3277 .55496 .3355 .56728 .33107 .56079 .32321 Mtetra
.673 .743 .903 r
.56079 .32321 .56728 .33107 .57966 .32659 .5732 .31864 Mtetra
.674 .742 .902 r
.5732 .31864 .57966 .32659 .59209 .32203 .58567 .314 Mtetra
.675 .741 .9 r
.58567 .314 .59209 .32203 .60457 .3174 .59819 .30931 Mtetra
.59819 .30931 .60457 .3174 .61711 .31274 .61076 .3046 Mtetra
.675 .74 .9 r
.61076 .3046 .61711 .31274 .62969 .30806 .62338 .29987 Mtetra
.674 .74 .9 r
.62338 .29987 .62969 .30806 .64233 .30337 .63606 .29515 Mtetra
.673 .739 .9 r
.63606 .29515 .64233 .30337 .65503 .29868 .6488 .29045 Mtetra
.672 .739 .901 r
.6488 .29045 .65503 .29868 .66778 .29401 .66159 .28576 Mtetra
.671 .74 .902 r
.66159 .28576 .66778 .29401 .68059 .28937 .67444 .2811 Mtetra
.67 .74 .903 r
.67444 .2811 .68059 .28937 .69346 .28474 .68735 .27646 Mtetra
.668 .74 .904 r
.68735 .27646 .69346 .28474 .70639 .28014 .70032 .27184 Mtetra
.667 .74 .905 r
.70032 .27184 .70639 .28014 .71938 .27556 .71335 .26724 Mtetra
.666 .74 .905 r
.71335 .26724 .71938 .27556 .73243 .27099 .72645 .26265 Mtetra
.666 .741 .906 r
.72645 .26265 .73243 .27099 .74554 .26642 .7396 .25807 Mtetra
.665 .741 .906 r
.7396 .25807 .74554 .26642 .75871 .26186 .75281 .25348 Mtetra
.665 .741 .907 r
.75281 .25348 .75871 .26186 .77194 .2573 .76609 .24889 Mtetra
.664 .741 .907 r
.76609 .24889 .77194 .2573 .78524 .25273 .77943 .24429 Mtetra
.77943 .24429 .78524 .25273 .79859 .24815 .79283 .23967 Mtetra
.664 .741 .908 r
.79283 .23967 .79859 .24815 .81201 .24356 .80629 .23504 Mtetra
.80629 .23504 .81201 .24356 .82549 .23895 .81982 .2304 Mtetra
.81982 .2304 .82549 .23895 .83904 .23432 .83341 .22573 Mtetra
.663 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .42411 Mtetra
.22724 .42411 .23467 .43107 .24565 .42731 .23825 .42032 Mtetra
.23825 .42032 .24565 .42731 .25668 .42353 .24931 .41651 Mtetra
.24931 .41651 .25668 .42353 .26775 .41974 .26041 .4127 Mtetra
.26041 .4127 .26775 .41974 .27887 .41594 .27156 .40887 Mtetra
.663 .741 .909 r
.27156 .40887 .27887 .41594 .29004 .41213 .28276 .40504 Mtetra
.662 .742 .909 r
.28276 .40504 .29004 .41213 .30126 .40832 .294 .40121 Mtetra
.294 .40121 .30126 .40832 .31252 .4045 .30529 .39737 Mtetra
.661 .742 .91 r
.30529 .39737 .31252 .4045 .32383 .40068 .31663 .39354 Mtetra
.66 .742 .911 r
.31663 .39354 .32383 .40068 .33519 .39687 .32802 .38972 Mtetra
.659 .743 .912 r
.32802 .38972 .33519 .39687 .3466 .39308 .33945 .38592 Mtetra
.657 .743 .913 r
.33945 .38592 .3466 .39308 .35805 .3893 .35093 .38214 Mtetra
.656 .743 .914 r
.35093 .38214 .35805 .3893 .36955 .38554 .36247 .37838 Mtetra
.654 .744 .916 r
.36247 .37838 .36955 .38554 .3811 .3818 .37405 .37466 Mtetra
.653 .745 .917 r
.37405 .37466 .3811 .3818 .39271 .3781 .38568 .37096 Mtetra
.651 .745 .918 r
.38568 .37096 .39271 .3781 .40436 .37442 .39736 .36728 Mtetra
.65 .746 .919 r
.39736 .36728 .40436 .37442 .41606 .37076 .4091 .36362 Mtetra
.65 .747 .92 r
.4091 .36362 .41606 .37076 .42782 .36711 .42089 .35996 Mtetra
.649 .747 .921 r
.42089 .35996 .42782 .36711 .43963 .36346 .43273 .35629 Mtetra
.65 .748 .921 r
.43273 .35629 .43963 .36346 .4515 .35979 .44463 .35258 Mtetra
.651 .748 .921 r
.44463 .35258 .4515 .35979 .46342 .35609 .45659 .34884 Mtetra
.649 .747 .921 r
.45659 .34884 .46342 .35609 .4754 .35236 .4686 .34513 Mtetra
.646 .748 .923 r
.4686 .34513 .4754 .35236 .48743 .34874 .48066 .34147 Mtetra
.658 .751 .919 r
.48066 .34147 .48743 .34874 .49952 .34526 .49279 .33746 Mtetra
.67 .741 .903 r
.49279 .33746 .49952 .34526 .51166 .34119 .50497 .33306 Mtetra
.668 .732 .898 r
.50497 .33306 .51166 .34119 .52387 .33658 .51721 .32867 Mtetra
.668 .739 .903 r
.51721 .32867 .52387 .33658 .53612 .33211 .5295 .32428 Mtetra
.671 .743 .905 r
.5295 .32428 .53612 .33211 .54843 .3277 .54185 .31979 Mtetra
.673 .743 .903 r
.54185 .31979 .54843 .3277 .56079 .32321 .55424 .31522 Mtetra
.674 .742 .901 r
.55424 .31522 .56079 .32321 .5732 .31864 .56669 .31056 Mtetra
.675 .741 .9 r
.56669 .31056 .5732 .31864 .58567 .314 .5792 .30586 Mtetra
.675 .74 .899 r
.5792 .30586 .58567 .314 .59819 .30931 .59175 .30112 Mtetra
.675 .739 .899 r
.59175 .30112 .59819 .30931 .61076 .3046 .60436 .29636 Mtetra
.60436 .29636 .61076 .3046 .62338 .29987 .61702 .29161 Mtetra
.674 .739 .9 r
.61702 .29161 .62338 .29987 .63606 .29515 .62974 .28686 Mtetra
.673 .739 .9 r
.62974 .28686 .63606 .29515 .6488 .29045 .64252 .28214 Mtetra
.671 .739 .901 r
.64252 .28214 .6488 .29045 .66159 .28576 .65535 .27744 Mtetra
.67 .739 .902 r
.65535 .27744 .66159 .28576 .67444 .2811 .66824 .27277 Mtetra
.669 .74 .903 r
.66824 .27277 .67444 .2811 .68735 .27646 .6812 .26812 Mtetra
.668 .74 .904 r
.6812 .26812 .68735 .27646 .70032 .27184 .69421 .26349 Mtetra
.667 .74 .905 r
.69421 .26349 .70032 .27184 .71335 .26724 .70728 .25887 Mtetra
.666 .74 .906 r
.70728 .25887 .71335 .26724 .72645 .26265 .72041 .25426 Mtetra
.665 .741 .906 r
.72041 .25426 .72645 .26265 .7396 .25807 .73361 .24964 Mtetra
.665 .741 .907 r
.73361 .24964 .7396 .25807 .75281 .25348 .74687 .24503 Mtetra
.664 .741 .907 r
.74687 .24503 .75281 .25348 .76609 .24889 .76019 .24041 Mtetra
.76019 .24041 .76609 .24889 .77943 .24429 .77357 .23577 Mtetra
.664 .741 .908 r
.77357 .23577 .77943 .24429 .79283 .23967 .78702 .23112 Mtetra
.78702 .23112 .79283 .23967 .80629 .23504 .80053 .22646 Mtetra
.80053 .22646 .80629 .23504 .81982 .2304 .8141 .22177 Mtetra
.8141 .22177 .81982 .2304 .83341 .22573 .82774 .21707 Mtetra
.663 .741 .908 r
.20877 .4209 .21628 .42788 .22724 .42411 .21976 .41709 Mtetra
.21976 .41709 .22724 .42411 .23825 .42032 .2308 .41327 Mtetra
.2308 .41327 .23825 .42032 .24931 .41651 .24188 .40944 Mtetra
.24188 .40944 .24931 .41651 .26041 .4127 .25301 .4056 Mtetra
.663 .741 .909 r
.25301 .4056 .26041 .4127 .27156 .40887 .26419 .40175 Mtetra
.662 .742 .909 r
.26419 .40175 .27156 .40887 .28276 .40504 .27541 .3979 Mtetra
.27541 .3979 .28276 .40504 .294 .40121 .28668 .39405 Mtetra
.661 .742 .91 r
.28668 .39405 .294 .40121 .30529 .39737 .298 .3902 Mtetra
.66 .742 .911 r
.298 .3902 .30529 .39737 .31663 .39354 .30937 .38636 Mtetra
.659 .742 .912 r
.30937 .38636 .31663 .39354 .32802 .38972 .32078 .38253 Mtetra
.658 .743 .913 r
.32078 .38253 .32802 .38972 .33945 .38592 .33225 .37873 Mtetra
.656 .743 .914 r
.33225 .37873 .33945 .38592 .35093 .38214 .34376 .37495 Mtetra
.655 .744 .915 r
.34376 .37495 .35093 .38214 .36247 .37838 .35532 .37119 Mtetra
.653 .744 .916 r
.35532 .37119 .36247 .37838 .37405 .37466 .36693 .36747 Mtetra
.652 .745 .918 r
.36693 .36747 .37405 .37466 .38568 .37096 .37859 .36377 Mtetra
.65 .745 .919 r
.37859 .36377 .38568 .37096 .39736 .36728 .39031 .36009 Mtetra
.65 .746 .92 r
.39031 .36009 .39736 .36728 .4091 .36362 .40207 .35642 Mtetra
.649 .747 .921 r
.40207 .35642 .4091 .36362 .42089 .35996 .41389 .35274 Mtetra
.41389 .35274 .42089 .35996 .43273 .35629 .42577 .34903 Mtetra
.65 .747 .92 r
.42577 .34903 .43273 .35629 .44463 .35258 .43771 .34529 Mtetra
.43771 .34529 .44463 .35258 .45659 .34884 .44969 .34152 Mtetra
.65 .747 .921 r
.44969 .34152 .45659 .34884 .4686 .34513 .46174 .33776 Mtetra
.656 .748 .918 r
.46174 .33776 .4686 .34513 .48066 .34147 .47385 .33378 Mtetra
.665 .743 .908 r
.47385 .33378 .48066 .34147 .49279 .33746 .48601 .32951 Mtetra
.666 .737 .903 r
.48601 .32951 .49279 .33746 .50497 .33306 .49823 .32519 Mtetra
.667 .74 .905 r
.49823 .32519 .50497 .33306 .51721 .32867 .5105 .3208 Mtetra
.67 .743 .905 r
.5105 .3208 .51721 .32867 .5295 .32428 .52283 .31632 Mtetra
.672 .742 .903 r
.52283 .31632 .5295 .32428 .54185 .31979 .53521 .31175 Mtetra
.674 .741 .901 r
.53521 .31175 .54185 .31979 .55424 .31522 .54764 .30709 Mtetra
.675 .74 .9 r
.54764 .30709 .55424 .31522 .56669 .31056 .56013 .30237 Mtetra
.676 .739 .899 r
.56013 .30237 .56669 .31056 .5792 .30586 .57267 .2976 Mtetra
.676 .739 .898 r
.57267 .2976 .5792 .30586 .59175 .30112 .58526 .29282 Mtetra
.675 .739 .898 r
.58526 .29282 .59175 .30112 .60436 .29636 .59791 .28804 Mtetra
.674 .739 .899 r
.59791 .28804 .60436 .29636 .61702 .29161 .61061 .28326 Mtetra
.673 .739 .9 r
.61061 .28326 .61702 .29161 .62974 .28686 .62337 .27851 Mtetra
.672 .739 .901 r
.62337 .27851 .62974 .28686 .64252 .28214 .63618 .27377 Mtetra
.671 .739 .902 r
.63618 .27377 .64252 .28214 .65535 .27744 .64906 .26907 Mtetra
.669 .739 .903 r
.64906 .26907 .65535 .27744 .66824 .27277 .66199 .26438 Mtetra
.668 .74 .904 r
.66199 .26438 .66824 .27277 .6812 .26812 .67499 .25972 Mtetra
.667 .74 .905 r
.67499 .25972 .6812 .26812 .69421 .26349 .68804 .25507 Mtetra
.666 .74 .905 r
.68804 .25507 .69421 .26349 .70728 .25887 .70116 .25043 Mtetra
.665 .74 .906 r
.70116 .25043 .70728 .25887 .72041 .25426 .71433 .24579 Mtetra
.665 .741 .907 r
.71433 .24579 .72041 .25426 .73361 .24964 .72757 .24116 Mtetra
.72757 .24116 .73361 .24964 .74687 .24503 .74087 .23651 Mtetra
.664 .741 .907 r
.74087 .23651 .74687 .24503 .76019 .24041 .75424 .23186 Mtetra
.75424 .23186 .76019 .24041 .77357 .23577 .76766 .22719 Mtetra
.664 .741 .908 r
.76766 .22719 .77357 .23577 .78702 .23112 .78115 .2225 Mtetra
.78115 .2225 .78702 .23112 .80053 .22646 .79471 .21779 Mtetra
.79471 .21779 .80053 .22646 .8141 .22177 .80833 .21307 Mtetra
.80833 .21307 .8141 .22177 .82774 .21707 .82201 .20832 Mtetra
.663 .741 .908 r
.2012 .41385 .20877 .4209 .21976 .41709 .21222 .41002 Mtetra
.21222 .41002 .21976 .41709 .2308 .41327 .22328 .40617 Mtetra
.22328 .40617 .2308 .41327 .24188 .40944 .23439 .40232 Mtetra
.663 .741 .909 r
.23439 .40232 .24188 .40944 .25301 .4056 .24555 .39845 Mtetra
.662 .742 .909 r
.24555 .39845 .25301 .4056 .26419 .40175 .25676 .39458 Mtetra
.25676 .39458 .26419 .40175 .27541 .3979 .26801 .39071 Mtetra
.661 .742 .91 r
.26801 .39071 .27541 .3979 .28668 .39405 .27931 .38684 Mtetra
.66 .742 .91 r
.27931 .38684 .28668 .39405 .298 .3902 .29066 .38298 Mtetra
.659 .742 .911 r
.29066 .38298 .298 .3902 .30937 .38636 .30205 .37913 Mtetra
.658 .743 .912 r
.30205 .37913 .30937 .38636 .32078 .38253 .31349 .3753 Mtetra
.657 .743 .913 r
.31349 .3753 .32078 .38253 .33225 .37873 .32498 .37149 Mtetra
.655 .743 .915 r
.32498 .37149 .33225 .37873 .34376 .37495 .33652 .36771 Mtetra
.654 .744 .916 r
.33652 .36771 .34376 .37495 .35532 .37119 .34811 .36396 Mtetra
.652 .744 .917 r
.34811 .36396 .35532 .37119 .36693 .36747 .35975 .36024 Mtetra
.651 .745 .919 r
.35975 .36024 .36693 .36747 .37859 .36377 .37145 .35654 Mtetra
.65 .745 .92 r
.37145 .35654 .37859 .36377 .39031 .36009 .38319 .35285 Mtetra
.649 .746 .92 r
.38319 .35285 .39031 .36009 .40207 .35642 .39499 .34915 Mtetra
.39499 .34915 .40207 .35642 .41389 .35274 .40684 .34544 Mtetra
.65 .746 .92 r
.40684 .34544 .41389 .35274 .42577 .34903 .41876 .34169 Mtetra
.651 .746 .92 r
.41876 .34169 .42577 .34903 .43771 .34529 .43072 .3379 Mtetra
.651 .746 .919 r
.43072 .3379 .43771 .34529 .44969 .34152 .44275 .33408 Mtetra
.656 .747 .917 r
.44275 .33408 .44969 .34152 .46174 .33776 .45483 .33011 Mtetra
.662 .744 .911 r
.45483 .33011 .46174 .33776 .47385 .33378 .46697 .32592 Mtetra
.665 .74 .906 r
.46697 .32592 .47385 .33378 .48601 .32951 .47917 .32164 Mtetra
.666 .741 .906 r
.47917 .32164 .48601 .32951 .49823 .32519 .49143 .31728 Mtetra
.669 .742 .905 r
.49143 .31728 .49823 .32519 .5105 .3208 .50373 .3128 Mtetra
.672 .741 .903 r
.50373 .3128 .5105 .3208 .52283 .31632 .5161 .30823 Mtetra
.673 .74 .901 r
.5161 .30823 .52283 .31632 .53521 .31175 .52851 .30357 Mtetra
.675 .739 .899 r
.52851 .30357 .53521 .31175 .54764 .30709 .54098 .29884 Mtetra
.675 .739 .898 r
.54098 .29884 .54764 .30709 .56013 .30237 .55351 .29406 Mtetra
.676 .738 .898 r
.55351 .29406 .56013 .30237 .57267 .2976 .56608 .28926 Mtetra
.675 .738 .898 r
.56608 .28926 .57267 .2976 .58526 .29282 .57871 .28444 Mtetra
.674 .738 .898 r
.57871 .28444 .58526 .29282 .59791 .28804 .5914 .27964 Mtetra
.673 .738 .899 r
.5914 .27964 .59791 .28804 .61061 .28326 .60414 .27485 Mtetra
.672 .738 .9 r
.60414 .27485 .61061 .28326 .62337 .27851 .61694 .27009 Mtetra
.671 .739 .901 r
.61694 .27009 .62337 .27851 .63618 .27377 .6298 .26535 Mtetra
.67 .739 .902 r
.6298 .26535 .63618 .27377 .64906 .26907 .64271 .26063 Mtetra
.668 .739 .903 r
.64271 .26063 .64906 .26907 .66199 .26438 .65569 .25594 Mtetra
.667 .74 .904 r
.65569 .25594 .66199 .26438 .67499 .25972 .66872 .25126 Mtetra
.666 .74 .905 r
.66872 .25126 .67499 .25972 .68804 .25507 .68182 .24659 Mtetra
.666 .74 .906 r
.68182 .24659 .68804 .25507 .70116 .25043 .69498 .24193 Mtetra
.665 .741 .906 r
.69498 .24193 .70116 .25043 .71433 .24579 .7082 .23727 Mtetra
.665 .741 .907 r
.7082 .23727 .71433 .24579 .72757 .24116 .72148 .2326 Mtetra
.664 .741 .907 r
.72148 .2326 .72757 .24116 .74087 .23651 .73483 .22792 Mtetra
.73483 .22792 .74087 .23651 .75424 .23186 .74823 .22323 Mtetra
.664 .741 .908 r
.74823 .22323 .75424 .23186 .76766 .22719 .76171 .21853 Mtetra
.76171 .21853 .76766 .22719 .78115 .2225 .77524 .2138 Mtetra
.77524 .2138 .78115 .2225 .79471 .21779 .78884 .20906 Mtetra
.78884 .20906 .79471 .21779 .80833 .21307 .80251 .20429 Mtetra
.80251 .20429 .80833 .21307 .82201 .20832 .81624 .19951 Mtetra
.663 .741 .908 r
.19358 .40676 .2012 .41385 .21222 .41002 .20462 .40289 Mtetra
.20462 .40289 .21222 .41002 .22328 .40617 .21571 .39902 Mtetra
.21571 .39902 .22328 .40617 .23439 .40232 .22685 .39514 Mtetra
.663 .741 .909 r
.22685 .39514 .23439 .40232 .24555 .39845 .23803 .39125 Mtetra
.662 .742 .909 r
.23803 .39125 .24555 .39845 .25676 .39458 .24927 .38736 Mtetra
.661 .742 .91 r
.24927 .38736 .25676 .39458 .26801 .39071 .26055 .38347 Mtetra
.26055 .38347 .26801 .39071 .27931 .38684 .27187 .37958 Mtetra
.66 .742 .911 r
.27187 .37958 .27931 .38684 .29066 .38298 .28325 .37571 Mtetra
.659 .742 .912 r
.28325 .37571 .29066 .38298 .30205 .37913 .29467 .37185 Mtetra
.657 .743 .913 r
.29467 .37185 .30205 .37913 .31349 .3753 .30614 .36802 Mtetra
.656 .743 .914 r
.30614 .36802 .31349 .3753 .32498 .37149 .31766 .36421 Mtetra
.654 .744 .915 r
.31766 .36421 .32498 .37149 .33652 .36771 .32923 .36044 Mtetra
.653 .744 .917 r
.32923 .36044 .33652 .36771 .34811 .36396 .34085 .35668 Mtetra
.651 .744 .918 r
.34085 .35668 .34811 .36396 .35975 .36024 .35252 .35296 Mtetra
.65 .745 .919 r
.35252 .35296 .35975 .36024 .37145 .35654 .36424 .34924 Mtetra
.649 .745 .92 r
.36424 .34924 .37145 .35654 .38319 .35285 .37602 .34553 Mtetra
.649 .746 .92 r
.37602 .34553 .38319 .35285 .39499 .34915 .38785 .3418 Mtetra
.65 .746 .92 r
.38785 .3418 .39499 .34915 .40684 .34544 .39974 .33804 Mtetra
.651 .746 .919 r
.39974 .33804 .40684 .34544 .41876 .34169 .41168 .33424 Mtetra
.651 .745 .918 r
.41168 .33424 .41876 .34169 .43072 .3379 .42368 .3304 Mtetra
.655 .746 .917 r
.42368 .3304 .43072 .3379 .44275 .33408 .43574 .32644 Mtetra
.66 .745 .913 r
.43574 .32644 .44275 .33408 .45483 .33011 .44787 .3223 Mtetra
.663 .742 .908 r
.44787 .3223 .45483 .33011 .46697 .32592 .46004 .31804 Mtetra
.666 .741 .907 r
.46004 .31804 .46697 .32592 .47917 .32164 .47228 .31369 Mtetra
.668 .741 .905 r
.47228 .31369 .47917 .32164 .49143 .31728 .48457 .30923 Mtetra
.671 .741 .903 r
.48457 .30923 .49143 .31728 .50373 .3128 .49691 .30466 Mtetra
.673 .74 .901 r
.49691 .30466 .50373 .3128 .5161 .30823 .50931 .3 Mtetra
.674 .739 .899 r
.50931 .3 .5161 .30823 .52851 .30357 .52177 .29526 Mtetra
.675 .738 .898 r
.52177 .29526 .52851 .30357 .54098 .29884 .53427 .29048 Mtetra
.676 .738 .897 r
.53427 .29048 .54098 .29884 .55351 .29406 .54683 .28566 Mtetra
.675 .737 .897 r
.54683 .28566 .55351 .29406 .56608 .28926 .55945 .28082 Mtetra
.675 .737 .898 r
.55945 .28082 .56608 .28926 .57871 .28444 .57212 .27599 Mtetra
.674 .738 .898 r
.57212 .27599 .57871 .28444 .5914 .27964 .58484 .27117 Mtetra
.673 .738 .899 r
.58484 .27117 .5914 .27964 .60414 .27485 .59762 .26638 Mtetra
.671 .738 .901 r
.59762 .26638 .60414 .27485 .61694 .27009 .61046 .26161 Mtetra
.67 .739 .902 r
.61046 .26161 .61694 .27009 .6298 .26535 .62336 .25686 Mtetra
.669 .739 .903 r
.62336 .25686 .6298 .26535 .64271 .26063 .63631 .25214 Mtetra
.668 .739 .904 r
.63631 .25214 .64271 .26063 .65569 .25594 .64933 .24743 Mtetra
.667 .74 .905 r
.64933 .24743 .65569 .25594 .66872 .25126 .66241 .24274 Mtetra
.666 .74 .906 r
.66241 .24274 .66872 .25126 .68182 .24659 .67555 .23805 Mtetra
.665 .74 .906 r
.67555 .23805 .68182 .24659 .69498 .24193 .68875 .23337 Mtetra
.665 .741 .907 r
.68875 .23337 .69498 .24193 .7082 .23727 .70201 .22868 Mtetra
.664 .741 .907 r
.70201 .22868 .7082 .23727 .72148 .2326 .71534 .22398 Mtetra
.71534 .22398 .72148 .2326 .73483 .22792 .72873 .21927 Mtetra
.664 .741 .908 r
.72873 .21927 .73483 .22792 .74823 .22323 .74218 .21454 Mtetra
.74218 .21454 .74823 .22323 .76171 .21853 .7557 .2098 Mtetra
.7557 .2098 .76171 .21853 .77524 .2138 .76928 .20503 Mtetra
.76928 .20503 .77524 .2138 .78884 .20906 .78292 .20025 Mtetra
.78292 .20025 .78884 .20906 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81624 .19951 .81041 .19061 Mtetra
.663 .741 .908 r
.18589 .3996 .19358 .40676 .20462 .40289 .19696 .39572 Mtetra
.19696 .39572 .20462 .40289 .21571 .39902 .20808 .39182 Mtetra
.663 .741 .909 r
.20808 .39182 .21571 .39902 .22685 .39514 .21924 .38791 Mtetra
.662 .742 .909 r
.21924 .38791 .22685 .39514 .23803 .39125 .23045 .384 Mtetra
.23045 .384 .23803 .39125 .24927 .38736 .24171 .38009 Mtetra
.661 .742 .91 r
.24171 .38009 .24927 .38736 .26055 .38347 .25302 .37618 Mtetra
.66 .742 .911 r
.25302 .37618 .26055 .38347 .27187 .37958 .26438 .37228 Mtetra
.659 .742 .911 r
.26438 .37228 .27187 .37958 .28325 .37571 .27578 .3684 Mtetra
.658 .742 .912 r
.27578 .3684 .28325 .37571 .29467 .37185 .28723 .36454 Mtetra
.656 .743 .914 r
.28723 .36454 .29467 .37185 .30614 .36802 .29873 .3607 Mtetra
.655 .743 .915 r
.29873 .3607 .30614 .36802 .31766 .36421 .31028 .35689 Mtetra
.653 .744 .916 r
.31028 .35689 .31766 .36421 .32923 .36044 .32187 .35311 Mtetra
.652 .744 .917 r
.32187 .35311 .32923 .36044 .34085 .35668 .33352 .34935 Mtetra
.65 .744 .918 r
.33352 .34935 .34085 .35668 .35252 .35296 .34522 .34561 Mtetra
.65 .745 .919 r
.34522 .34561 .35252 .35296 .36424 .34924 .35698 .34187 Mtetra
.649 .745 .919 r
.35698 .34187 .36424 .34924 .37602 .34553 .36878 .33813 Mtetra
.36878 .33813 .37602 .34553 .38785 .3418 .38065 .33436 Mtetra
.65 .745 .919 r
.38065 .33436 .38785 .3418 .39974 .33804 .39257 .33056 Mtetra
.651 .745 .919 r
.39257 .33056 .39974 .33804 .41168 .33424 .40455 .32672 Mtetra
.654 .746 .917 r
.40455 .32672 .41168 .33424 .42368 .3304 .41659 .32277 Mtetra
.659 .745 .914 r
.41659 .32277 .42368 .3304 .43574 .32644 .42869 .31864 Mtetra
.663 .743 .91 r
.42869 .31864 .43574 .32644 .44787 .3223 .44084 .31439 Mtetra
.665 .741 .907 r
.44084 .31439 .44787 .3223 .46004 .31804 .45306 .31004 Mtetra
.667 .741 .905 r
.45306 .31004 .46004 .31804 .47228 .31369 .46533 .30559 Mtetra
.67 .74 .903 r
.46533 .30559 .47228 .31369 .48457 .30923 .47765 .30103 Mtetra
.672 .739 .9 r
.47765 .30103 .48457 .30923 .49691 .30466 .49004 .29638 Mtetra
.674 .738 .899 r
.49004 .29638 .49691 .30466 .50931 .3 .50247 .29165 Mtetra
.675 .737 .898 r
.50247 .29165 .50931 .3 .52177 .29526 .51496 .28685 Mtetra
.675 .737 .897 r
.51496 .28685 .52177 .29526 .53427 .29048 .5275 .28202 Mtetra
.5275 .28202 .53427 .29048 .54683 .28566 .5401 .27717 Mtetra
.5401 .27717 .54683 .28566 .55945 .28082 .55275 .27232 Mtetra
.674 .737 .898 r
.55275 .27232 .55945 .28082 .57212 .27599 .56546 .26747 Mtetra
.673 .737 .899 r
.56546 .26747 .57212 .27599 .58484 .27117 .57823 .26265 Mtetra
.672 .738 .9 r
.57823 .26265 .58484 .27117 .59762 .26638 .59105 .25785 Mtetra
.67 .738 .901 r
.59105 .25785 .59762 .26638 .61046 .26161 .60392 .25308 Mtetra
.669 .739 .902 r
.60392 .25308 .61046 .26161 .62336 .25686 .61686 .24832 Mtetra
.668 .739 .903 r
.61686 .24832 .62336 .25686 .63631 .25214 .62986 .24359 Mtetra
.667 .74 .904 r
.62986 .24359 .63631 .25214 .64933 .24743 .64292 .23887 Mtetra
.666 .74 .905 r
.64292 .23887 .64933 .24743 .66241 .24274 .65604 .23416 Mtetra
.665 .74 .906 r
.65604 .23416 .66241 .24274 .67555 .23805 .66922 .22945 Mtetra
.665 .741 .907 r
.66922 .22945 .67555 .23805 .68875 .23337 .68246 .22474 Mtetra
.664 .741 .907 r
.68246 .22474 .68875 .23337 .70201 .22868 .69577 .22002 Mtetra
.69577 .22002 .70201 .22868 .71534 .22398 .70914 .21528 Mtetra
.70914 .21528 .71534 .22398 .72873 .21927 .72257 .21054 Mtetra
.664 .741 .908 r
.72257 .21054 .72873 .21927 .74218 .21454 .73607 .20577 Mtetra
.73607 .20577 .74218 .21454 .7557 .2098 .74963 .20099 Mtetra
.74963 .20099 .7557 .2098 .76928 .20503 .76326 .19619 Mtetra
.76326 .19619 .76928 .20503 .78292 .20025 .77695 .19136 Mtetra
.77695 .19136 .78292 .20025 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.663 .741 .908 r
.17814 .3924 .18589 .3996 .19696 .39572 .18924 .38848 Mtetra
.663 .741 .909 r
.18924 .38848 .19696 .39572 .20808 .39182 .20038 .38456 Mtetra
.662 .741 .909 r
.20038 .38456 .20808 .39182 .21924 .38791 .21157 .38063 Mtetra
.662 .742 .909 r
.21157 .38063 .21924 .38791 .23045 .384 .22281 .37669 Mtetra
.661 .742 .91 r
.22281 .37669 .23045 .384 .24171 .38009 .2341 .37276 Mtetra
.66 .742 .91 r
.2341 .37276 .24171 .38009 .25302 .37618 .24544 .36884 Mtetra
.659 .742 .911 r
.24544 .36884 .25302 .37618 .26438 .37228 .25682 .36493 Mtetra
.658 .742 .912 r
.25682 .36493 .26438 .37228 .27578 .3684 .26825 .36104 Mtetra
.657 .743 .913 r
.26825 .36104 .27578 .3684 .28723 .36454 .27973 .35717 Mtetra
.655 .743 .914 r
.27973 .35717 .28723 .36454 .29873 .3607 .29125 .35333 Mtetra
.654 .743 .915 r
.29125 .35333 .29873 .3607 .31028 .35689 .30283 .34951 Mtetra
.652 .744 .917 r
.30283 .34951 .31028 .35689 .32187 .35311 .31446 .34572 Mtetra
.651 .744 .918 r
.31446 .34572 .32187 .35311 .33352 .34935 .32613 .34195 Mtetra
.65 .744 .918 r
.32613 .34195 .33352 .34935 .34522 .34561 .33787 .33819 Mtetra
.649 .744 .919 r
.33787 .33819 .34522 .34561 .35698 .34187 .34965 .33442 Mtetra
.34965 .33442 .35698 .34187 .36878 .33813 .36149 .33065 Mtetra
.648 .744 .919 r
.36149 .33065 .36878 .33813 .38065 .33436 .37339 .32688 Mtetra
.648 .745 .92 r
.37339 .32688 .38065 .33436 .39257 .33056 .38534 .3231 Mtetra
.653 .748 .919 r
.38534 .3231 .39257 .33056 .40455 .32672 .39736 .31915 Mtetra
.66 .748 .915 r
.39736 .31915 .40455 .32672 .41659 .32277 .40943 .31499 Mtetra
.663 .744 .91 r
.40943 .31499 .41659 .32277 .42869 .31864 .42157 .31069 Mtetra
.665 .741 .907 r
.42157 .31069 .42869 .31864 .44084 .31439 .43377 .30634 Mtetra
.667 .74 .905 r
.43377 .30634 .44084 .31439 .45306 .31004 .44602 .3019 Mtetra
.669 .739 .903 r
.44602 .3019 .45306 .31004 .46533 .30559 .45832 .29735 Mtetra
.671 .738 .9 r
.45832 .29735 .46533 .30559 .47765 .30103 .47069 .29271 Mtetra
.673 .737 .899 r
.47069 .29271 .47765 .30103 .49004 .29638 .4831 .28798 Mtetra
.674 .737 .897 r
.4831 .28798 .49004 .29638 .50247 .29165 .49557 .28318 Mtetra
.675 .736 .897 r
.49557 .28318 .50247 .29165 .51496 .28685 .5081 .27835 Mtetra
.675 .736 .896 r
.5081 .27835 .51496 .28685 .5275 .28202 .52068 .27348 Mtetra
.675 .736 .897 r
.52068 .27348 .5275 .28202 .5401 .27717 .53332 .26861 Mtetra
.674 .737 .897 r
.53332 .26861 .5401 .27717 .55275 .27232 .54601 .26375 Mtetra
.673 .737 .898 r
.54601 .26375 .55275 .27232 .56546 .26747 .55875 .2589 Mtetra
.672 .737 .9 r
.55875 .2589 .56546 .26747 .57823 .26265 .57155 .25407 Mtetra
.671 .738 .901 r
.57155 .25407 .57823 .26265 .59105 .25785 .58442 .24927 Mtetra
.669 .738 .902 r
.58442 .24927 .59105 .25785 .60392 .25308 .59733 .24449 Mtetra
.668 .739 .903 r
.59733 .24449 .60392 .25308 .61686 .24832 .61031 .23973 Mtetra
.667 .739 .904 r
.61031 .23973 .61686 .24832 .62986 .24359 .62335 .23499 Mtetra
.666 .74 .905 r
.62335 .23499 .62986 .24359 .64292 .23887 .63645 .23025 Mtetra
.666 .74 .906 r
.63645 .23025 .64292 .23887 .65604 .23416 .64962 .22552 Mtetra
.665 .74 .906 r
.64962 .22552 .65604 .23416 .66922 .22945 .66284 .22078 Mtetra
.665 .741 .907 r
.66284 .22078 .66922 .22945 .68246 .22474 .67613 .21604 Mtetra
.664 .741 .907 r
.67613 .21604 .68246 .22474 .69577 .22002 .68948 .21129 Mtetra
.68948 .21129 .69577 .22002 .70914 .21528 .70289 .20652 Mtetra
.664 .741 .908 r
.70289 .20652 .70914 .21528 .72257 .21054 .71637 .20173 Mtetra
.71637 .20173 .72257 .21054 .73607 .20577 .72991 .19693 Mtetra
.72991 .19693 .73607 .20577 .74963 .20099 .74352 .19211 Mtetra
.74352 .19211 .74963 .20099 .76326 .19619 .75719 .18726 Mtetra
.75719 .18726 .76326 .19619 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.663 .741 .908 r
.17033 .38514 .17814 .3924 .18924 .38848 .18145 .38119 Mtetra
.663 .741 .909 r
.18145 .38119 .18924 .38848 .20038 .38456 .19262 .37724 Mtetra
.662 .742 .909 r
.19262 .37724 .20038 .38456 .21157 .38063 .20384 .37329 Mtetra
.661 .742 .909 r
.20384 .37329 .21157 .38063 .22281 .37669 .21511 .36934 Mtetra
.661 .742 .91 r
.21511 .36934 .22281 .37669 .2341 .37276 .22643 .36539 Mtetra
.66 .742 .911 r
.22643 .36539 .2341 .37276 .24544 .36884 .23779 .36145 Mtetra
.659 .742 .912 r
.23779 .36145 .24544 .36884 .25682 .36493 .2492 .35753 Mtetra
.657 .742 .913 r
.2492 .35753 .25682 .36493 .26825 .36104 .26066 .35363 Mtetra
.656 .743 .914 r
.26066 .35363 .26825 .36104 .27973 .35717 .27216 .34975 Mtetra
.654 .743 .915 r
.27216 .34975 .27973 .35717 .29125 .35333 .28372 .3459 Mtetra
.653 .743 .916 r
.28372 .3459 .29125 .35333 .30283 .34951 .29532 .34208 Mtetra
.652 .743 .917 r
.29532 .34208 .30283 .34951 .31446 .34572 .30698 .33827 Mtetra
.651 .744 .918 r
.30698 .33827 .31446 .34572 .32613 .34195 .31869 .33448 Mtetra
.65 .744 .918 r
.31869 .33448 .32613 .34195 .33787 .33819 .33045 .33069 Mtetra
.648 .743 .919 r
.33045 .33069 .33787 .33819 .34965 .33442 .34226 .32694 Mtetra
.644 .744 .922 r
.34226 .32694 .34965 .33442 .36149 .33065 .35413 .32328 Mtetra
.643 .747 .925 r
.35413 .32328 .36149 .33065 .37339 .32688 .36605 .31963 Mtetra
.652 .755 .925 r
.36605 .31963 .37339 .32688 .38534 .3231 .37804 .31568 Mtetra
.664 .755 .918 r
.37804 .31568 .38534 .3231 .39736 .31915 .39011 .31138 Mtetra
.667 .746 .91 r
.39011 .31138 .39736 .31915 .40943 .31499 .40223 .30697 Mtetra
.665 .74 .906 r
.40223 .30697 .40943 .31499 .42157 .31069 .4144 .30259 Mtetra
.666 .739 .904 r
.4144 .30259 .42157 .31069 .43377 .30634 .42663 .29815 Mtetra
.668 .738 .903 r
.42663 .29815 .43377 .30634 .44602 .3019 .43892 .29362 Mtetra
.671 .738 .9 r
.43892 .29362 .44602 .3019 .45832 .29735 .45126 .28898 Mtetra
.672 .737 .899 r
.45126 .28898 .45832 .29735 .47069 .29271 .46366 .28426 Mtetra
.674 .736 .897 r
.46366 .28426 .47069 .29271 .4831 .28798 .47611 .27947 Mtetra
.675 .736 .897 r
.47611 .27947 .4831 .28798 .49557 .28318 .48862 .27463 Mtetra
.675 .736 .896 r
.48862 .27463 .49557 .28318 .5081 .27835 .50118 .26976 Mtetra
.50118 .26976 .5081 .27835 .52068 .27348 .5138 .26488 Mtetra
.674 .736 .897 r
.5138 .26488 .52068 .27348 .53332 .26861 .52647 .25999 Mtetra
.673 .736 .898 r
.52647 .25999 .53332 .26861 .54601 .26375 .5392 .25512 Mtetra
.672 .737 .899 r
.5392 .25512 .54601 .26375 .55875 .2589 .55199 .25028 Mtetra
.671 .738 .9 r
.55199 .25028 .55875 .2589 .57155 .25407 .56483 .24545 Mtetra
.669 .738 .902 r
.56483 .24545 .57155 .25407 .58442 .24927 .57773 .24064 Mtetra
.668 .739 .903 r
.57773 .24064 .58442 .24927 .59733 .24449 .59069 .23586 Mtetra
.667 .739 .904 r
.59069 .23586 .59733 .24449 .61031 .23973 .60371 .23109 Mtetra
.666 .74 .905 r
.60371 .23109 .61031 .23973 .62335 .23499 .61679 .22633 Mtetra
.666 .74 .906 r
.61679 .22633 .62335 .23499 .63645 .23025 .62993 .22157 Mtetra
.665 .74 .906 r
.62993 .22157 .63645 .23025 .64962 .22552 .64314 .21681 Mtetra
.665 .741 .907 r
.64314 .21681 .64962 .22552 .66284 .22078 .6564 .21205 Mtetra
.664 .741 .907 r
.6564 .21205 .66284 .22078 .67613 .21604 .66973 .20727 Mtetra
.66973 .20727 .67613 .21604 .68948 .21129 .68313 .20248 Mtetra
.664 .741 .908 r
.68313 .20248 .68948 .21129 .70289 .20652 .69659 .19768 Mtetra
.69659 .19768 .70289 .20652 .71637 .20173 .71011 .19285 Mtetra
.71011 .19285 .71637 .20173 .72991 .19693 .72369 .18801 Mtetra
.72369 .18801 .72991 .19693 .74352 .19211 .73735 .18315 Mtetra
.73735 .18315 .74352 .19211 .75719 .18726 .75106 .17826 Mtetra
.75106 .17826 .75719 .18726 .77093 .18239 .76485 .17335 Mtetra
.76485 .17335 .77093 .18239 .78473 .1775 .7787 .16841 Mtetra
.7787 .16841 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
.663 .741 .909 r
.16245 .37782 .17033 .38514 .18145 .38119 .17361 .37385 Mtetra
.662 .741 .909 r
.17361 .37385 .18145 .38119 .19262 .37724 .18481 .36988 Mtetra
.662 .742 .909 r
.18481 .36988 .19262 .37724 .20384 .37329 .19605 .3659 Mtetra
.661 .742 .91 r
.19605 .3659 .20384 .37329 .21511 .36934 .20735 .36193 Mtetra
.66 .742 .91 r
.20735 .36193 .21511 .36934 .22643 .36539 .21869 .35796 Mtetra
.659 .742 .911 r
.21869 .35796 .22643 .36539 .23779 .36145 .23008 .35401 Mtetra
.658 .742 .912 r
.23008 .35401 .23779 .36145 .2492 .35753 .24151 .35008 Mtetra
.657 .742 .913 r
.24151 .35008 .2492 .35753 .26066 .35363 .253 .34617 Mtetra
.655 .743 .914 r
.253 .34617 .26066 .35363 .27216 .34975 .26453 .34228 Mtetra
.654 .743 .915 r
.26453 .34228 .27216 .34975 .28372 .3459 .27612 .33842 Mtetra
.652 .743 .916 r
.27612 .33842 .28372 .3459 .29532 .34208 .28775 .33457 Mtetra
.651 .743 .917 r
.28775 .33457 .29532 .34208 .30698 .33827 .29944 .33075 Mtetra
.649 .743 .918 r
.29944 .33075 .30698 .33827 .31869 .33448 .31118 .32695 Mtetra
.644 .742 .921 r
.31118 .32695 .31869 .33448 .33045 .33069 .32296 .32329 Mtetra
.632 .743 .928 r
.32296 .32329 .33045 .33069 .34226 .32694 .33478 .31992 Mtetra
.629 .755 .937 r
.33478 .31992 .34226 .32694 .35413 .32328 .34666 .31657 Mtetra
.653 .772 .936 r
.34666 .31657 .35413 .32328 .36605 .31963 .35864 .31257 Mtetra
.676 .769 .921 r
.35864 .31257 .36605 .31963 .37804 .31568 .3707 .3079 Mtetra
.674 .749 .907 r
.3707 .3079 .37804 .31568 .39011 .31138 .38281 .30324 Mtetra
.667 .738 .903 r
.38281 .30324 .39011 .31138 .40223 .30697 .39497 .29878 Mtetra
.665 .737 .904 r
.39497 .29878 .40223 .30697 .4144 .30259 .40717 .29435 Mtetra
.667 .738 .903 r
.40717 .29435 .4144 .30259 .42663 .29815 .41944 .28983 Mtetra
.67 .737 .901 r
.41944 .28983 .42663 .29815 .43892 .29362 .43176 .28521 Mtetra
.672 .736 .899 r
.43176 .28521 .43892 .29362 .45126 .28898 .44414 .2805 Mtetra
.673 .736 .897 r
.44414 .2805 .45126 .28898 .46366 .28426 .45658 .27571 Mtetra
.674 .735 .896 r
.45658 .27571 .46366 .28426 .47611 .27947 .46907 .27087 Mtetra
.46907 .27087 .47611 .27947 .48862 .27463 .48161 .266 Mtetra
.48161 .266 .48862 .27463 .50118 .26976 .49421 .2611 Mtetra
.674 .736 .897 r
.49421 .2611 .50118 .26976 .5138 .26488 .50686 .25621 Mtetra
.673 .736 .898 r
.50686 .25621 .5138 .26488 .52647 .25999 .51957 .25132 Mtetra
.672 .737 .899 r
.51957 .25132 .52647 .25999 .5392 .25512 .53234 .24645 Mtetra
.671 .737 .9 r
.53234 .24645 .5392 .25512 .55199 .25028 .54516 .2416 Mtetra
.67 .738 .901 r
.54516 .2416 .55199 .25028 .56483 .24545 .55805 .23677 Mtetra
.668 .738 .903 r
.55805 .23677 .56483 .24545 .57773 .24064 .57099 .23196 Mtetra
.667 .739 .904 r
.57099 .23196 .57773 .24064 .59069 .23586 .58399 .22717 Mtetra
.667 .74 .905 r
.58399 .22717 .59069 .23586 .60371 .23109 .59705 .22238 Mtetra
.666 .74 .905 r
.59705 .22238 .60371 .23109 .61679 .22633 .61017 .2176 Mtetra
.665 .74 .906 r
.61017 .2176 .61679 .22633 .62993 .22157 .62336 .21282 Mtetra
.665 .741 .907 r
.62336 .21282 .62993 .22157 .64314 .21681 .6366 .20804 Mtetra
.664 .741 .907 r
.6366 .20804 .64314 .21681 .6564 .21205 .64991 .20324 Mtetra
.64991 .20324 .6564 .21205 .66973 .20727 .66329 .19843 Mtetra
.66329 .19843 .66973 .20727 .68313 .20248 .67672 .19361 Mtetra
.664 .741 .908 r
.67672 .19361 .68313 .20248 .69659 .19768 .69023 .18876 Mtetra
.69023 .18876 .69659 .19768 .71011 .19285 .70379 .1839 Mtetra
.70379 .1839 .71011 .19285 .72369 .18801 .71742 .17901 Mtetra
.71742 .17901 .72369 .18801 .73735 .18315 .73112 .17411 Mtetra
.73112 .17411 .73735 .18315 .75106 .17826 .74489 .16917 Mtetra
.74489 .16917 .75106 .17826 .76485 .17335 .75872 .16422 Mtetra
.75872 .16422 .76485 .17335 .7787 .16841 .77261 .15924 Mtetra
.77261 .15924 .7787 .16841 .79262 .16346 .78658 .15424 Mtetra
.662 .741 .909 r
.15452 .37044 .16245 .37782 .17361 .37385 .1657 .36645 Mtetra
.662 .742 .909 r
.1657 .36645 .17361 .37385 .18481 .36988 .17692 .36245 Mtetra
.661 .742 .91 r
.17692 .36245 .18481 .36988 .19605 .3659 .18819 .35846 Mtetra
.18819 .35846 .19605 .3659 .20735 .36193 .19952 .35447 Mtetra
.66 .742 .911 r
.19952 .35447 .20735 .36193 .21869 .35796 .21088 .35048 Mtetra
.659 .742 .912 r
.21088 .35048 .21869 .35796 .23008 .35401 .2223 .34652 Mtetra
.657 .742 .912 r
.2223 .34652 .23008 .35401 .24151 .35008 .23377 .34257 Mtetra
.656 .742 .913 r
.23377 .34257 .24151 .35008 .253 .34617 .24528 .33865 Mtetra
.655 .743 .914 r
.24528 .33865 .253 .34617 .26453 .34228 .25684 .33474 Mtetra
.653 .743 .915 r
.25684 .33474 .26453 .34228 .27612 .33842 .26846 .33086 Mtetra
.652 .743 .916 r
.26846 .33086 .27612 .33842 .28775 .33457 .28012 .327 Mtetra
.648 .742 .918 r
.28012 .327 .28775 .33457 .29944 .33075 .29183 .32324 Mtetra
.633 .74 .925 r
.29183 .32324 .29944 .33075 .31118 .32695 .30357 .31985 Mtetra
.602 .743 .944 r
.30357 .31985 .31118 .32695 .32296 .32329 .31532 .31716 Mtetra
.595 .773 .965 r
.31532 .31716 .32296 .32329 .33478 .31992 .32713 .31441 Mtetra
.658 .812 .957 r
.32713 .31441 .33478 .31992 .34666 .31657 .33911 .31013 Mtetra
.701 .794 .922 r
.33911 .31013 .34666 .31657 .35864 .31257 .3512 .30468 Mtetra
.688 .751 .899 r
.3512 .30468 .35864 .31257 .3707 .3079 .36332 .29952 Mtetra
.67 .733 .898 r
.36332 .29952 .3707 .3079 .38281 .30324 .37546 .29493 Mtetra
.665 .735 .902 r
.37546 .29493 .38281 .30324 .39497 .29878 .38764 .29049 Mtetra
.666 .737 .903 r
.38764 .29049 .39497 .29878 .40717 .29435 .39989 .28598 Mtetra
.669 .736 .901 r
.39989 .28598 .40717 .29435 .41944 .28983 .41219 .28138 Mtetra
.671 .736 .899 r
.41219 .28138 .41944 .28983 .43176 .28521 .42455 .27668 Mtetra
.672 .735 .898 r
.42455 .27668 .43176 .28521 .44414 .2805 .43696 .2719 Mtetra
.673 .735 .897 r
.43696 .2719 .44414 .2805 .45658 .27571 .44944 .26707 Mtetra
.674 .735 .896 r
.44944 .26707 .45658 .27571 .46907 .27087 .46196 .26219 Mtetra
.46196 .26219 .46907 .27087 .48161 .266 .47454 .2573 Mtetra
.673 .735 .897 r
.47454 .2573 .48161 .266 .49421 .2611 .48718 .25239 Mtetra
.673 .736 .898 r
.48718 .25239 .49421 .2611 .50686 .25621 .49987 .24749 Mtetra
.672 .736 .899 r
.49987 .24749 .50686 .25621 .51957 .25132 .51262 .2426 Mtetra
.671 .737 .9 r
.51262 .2426 .51957 .25132 .53234 .24645 .52542 .23773 Mtetra
.67 .738 .901 r
.52542 .23773 .53234 .24645 .54516 .2416 .53828 .23288 Mtetra
.669 .738 .902 r
.53828 .23288 .54516 .2416 .55805 .23677 .55121 .22805 Mtetra
.668 .739 .903 r
.55121 .22805 .55805 .23677 .57099 .23196 .56419 .22323 Mtetra
.667 .739 .904 r
.56419 .22323 .57099 .23196 .58399 .22717 .57723 .21843 Mtetra
.666 .74 .905 r
.57723 .21843 .58399 .22717 .59705 .22238 .59033 .21362 Mtetra
.665 .74 .906 r
.59033 .21362 .59705 .22238 .61017 .2176 .60349 .20882 Mtetra
.60349 .20882 .61017 .2176 .62336 .21282 .61672 .20401 Mtetra
.664 .741 .907 r
.61672 .20401 .62336 .21282 .6366 .20804 .63001 .1992 Mtetra
.63001 .1992 .6366 .20804 .64991 .20324 .64336 .19437 Mtetra
.64336 .19437 .64991 .20324 .66329 .19843 .65678 .18952 Mtetra
.664 .741 .908 r
.65678 .18952 .66329 .19843 .67672 .19361 .67026 .18465 Mtetra
.67026 .18465 .67672 .19361 .69023 .18876 .68381 .17977 Mtetra
.68381 .17977 .69023 .18876 .70379 .1839 .69742 .17486 Mtetra
.69742 .17486 .70379 .1839 .71742 .17901 .7111 .16994 Mtetra
.7111 .16994 .71742 .17901 .73112 .17411 .72484 .16499 Mtetra
.72484 .16499 .73112 .17411 .74489 .16917 .73865 .16001 Mtetra
.73865 .16001 .74489 .16917 .75872 .16422 .75253 .15501 Mtetra
.75253 .15501 .75872 .16422 .77261 .15924 .76647 .14999 Mtetra
.76647 .14999 .77261 .15924 .78658 .15424 .78049 .14494 Mtetra
.662 .741 .909 r
.14652 .36301 .15452 .37044 .1657 .36645 .15772 .35899 Mtetra
.662 .742 .909 r
.15772 .35899 .1657 .36645 .17692 .36245 .16897 .35497 Mtetra
.661 .742 .91 r
.16897 .35497 .17692 .36245 .18819 .35846 .18027 .35096 Mtetra
.66 .742 .91 r
.18027 .35096 .18819 .35846 .19952 .35447 .19162 .34695 Mtetra
.659 .742 .911 r
.19162 .34695 .19952 .35447 .21088 .35048 .20302 .34295 Mtetra
.658 .742 .912 r
.20302 .34295 .21088 .35048 .2223 .34652 .21446 .33897 Mtetra
.657 .742 .913 r
.21446 .33897 .2223 .34652 .23377 .34257 .22595 .335 Mtetra
.655 .742 .914 r
.22595 .335 .23377 .34257 .24528 .33865 .2375 .33106 Mtetra
.654 .742 .915 r
.2375 .33106 .24528 .33865 .25684 .33474 .24909 .32714 Mtetra
.652 .742 .916 r
.24909 .32714 .25684 .33474 .26846 .33086 .26073 .32326 Mtetra
.643 .741 .92 r
.26073 .32326 .26846 .33086 .28012 .327 .2724 .31962 Mtetra
.604 .736 .938 r
.2724 .31962 .28012 .327 .29183 .32324 .28406 .31691 Mtetra
.514 .737 .975 r
.28406 .31691 .29183 .32324 .30357 .31985 .29567 .31567 Mtetra
.488 .8 .999 r
.29567 .31567 .30357 .31985 .31532 .31716 .3074 .31391 Mtetra
.67 .888 .978 r
.3074 .31391 .31532 .31716 .32713 .31441 .31941 .30884 Mtetra
.747 .827 .914 r
.31941 .30884 .32713 .31441 .33911 .31013 .33159 .30185 Mtetra
.709 .747 .882 r
.33159 .30185 .33911 .31013 .3512 .30468 .34375 .29585 Mtetra
.674 .724 .887 r
.34375 .29585 .3512 .30468 .36332 .29952 .35588 .29104 Mtetra
.665 .731 .899 r
.35588 .29104 .36332 .29952 .37546 .29493 .36804 .28659 Mtetra
.665 .736 .902 r
.36804 .28659 .37546 .29493 .38764 .29049 .38027 .28209 Mtetra
.668 .736 .901 r
.38027 .28209 .38764 .29049 .39989 .28598 .39254 .2775 Mtetra
.67 .735 .899 r
.39254 .2775 .39989 .28598 .41219 .28138 .40488 .27281 Mtetra
.671 .735 .898 r
.40488 .27281 .41219 .28138 .42455 .27668 .41728 .26805 Mtetra
.672 .735 .897 r
.41728 .26805 .42455 .27668 .43696 .2719 .42973 .26322 Mtetra
.673 .734 .896 r
.42973 .26322 .43696 .2719 .44944 .26707 .44224 .25835 Mtetra
.673 .735 .896 r
.44224 .25835 .44944 .26707 .46196 .26219 .4548 .25345 Mtetra
.673 .735 .897 r
.4548 .25345 .46196 .26219 .47454 .2573 .46741 .24854 Mtetra
.46741 .24854 .47454 .2573 .48718 .25239 .48009 .24363 Mtetra
.672 .736 .898 r
.48009 .24363 .48718 .25239 .49987 .24749 .49281 .23873 Mtetra
.671 .737 .9 r
.49281 .23873 .49987 .24749 .51262 .2426 .5056 .23384 Mtetra
.67 .737 .901 r
.5056 .23384 .51262 .2426 .52542 .23773 .51844 .22897 Mtetra
.669 .738 .902 r
.51844 .22897 .52542 .23773 .53828 .23288 .53135 .22412 Mtetra
.668 .739 .903 r
.53135 .22412 .53828 .23288 .55121 .22805 .54431 .21928 Mtetra
.667 .739 .904 r
.54431 .21928 .55121 .22805 .56419 .22323 .55733 .21445 Mtetra
.666 .74 .905 r
.55733 .21445 .56419 .22323 .57723 .21843 .57041 .20963 Mtetra
.665 .74 .906 r
.57041 .20963 .57723 .21843 .59033 .21362 .58355 .2048 Mtetra
.58355 .2048 .59033 .21362 .60349 .20882 .59676 .19997 Mtetra
.664 .741 .907 r
.59676 .19997 .60349 .20882 .61672 .20401 .61003 .19513 Mtetra
.61003 .19513 .61672 .20401 .63001 .1992 .62336 .19028 Mtetra
.62336 .19028 .63001 .1992 .64336 .19437 .63676 .18541 Mtetra
.664 .741 .908 r
.63676 .18541 .64336 .19437 .65678 .18952 .65022 .18053 Mtetra
.65022 .18053 .65678 .18952 .67026 .18465 .66374 .17562 Mtetra
.66374 .17562 .67026 .18465 .68381 .17977 .67734 .1707 Mtetra
.67734 .1707 .68381 .17977 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16994 .70472 .16078 Mtetra
.70472 .16078 .7111 .16994 .72484 .16499 .7185 .15578 Mtetra
.7185 .15578 .72484 .16499 .73865 .16001 .73236 .15077 Mtetra
.73236 .15077 .73865 .16001 .75253 .15501 .74629 .14572 Mtetra
.74629 .14572 .75253 .15501 .76647 .14999 .76028 .14065 Mtetra
.76028 .14065 .76647 .14999 .78049 .14494 .77434 .13556 Mtetra
.662 .741 .909 r
.13845 .35553 .14652 .36301 .15772 .35899 .14968 .35148 Mtetra
.661 .742 .91 r
.14968 .35148 .15772 .35899 .16897 .35497 .16096 .34744 Mtetra
.16096 .34744 .16897 .35497 .18027 .35096 .17229 .3434 Mtetra
.66 .742 .911 r
.17229 .3434 .18027 .35096 .19162 .34695 .18366 .33937 Mtetra
.659 .742 .911 r
.18366 .33937 .19162 .34695 .20302 .34295 .19509 .33535 Mtetra
.657 .742 .912 r
.19509 .33535 .20302 .34295 .21446 .33897 .20656 .33135 Mtetra
.656 .742 .913 r
.20656 .33135 .21446 .33897 .22595 .335 .21808 .32737 Mtetra
.655 .742 .914 r
.21808 .32737 .22595 .335 .2375 .33106 .22965 .32341 Mtetra
.651 .741 .916 r
.22965 .32341 .2375 .33106 .24909 .32714 .24126 .31954 Mtetra
.629 .737 .925 r
.24126 .31954 .24909 .32714 .26073 .32326 .25288 .31625 Mtetra
.524 .719 .962 r
.25288 .31625 .26073 .32326 .2724 .31962 .26438 .31503 Mtetra
.193 .634 .945 r
.26438 .31503 .2724 .31962 .28406 .31691 .27574 .31653 Mtetra
.075 .636 .773 r
.27574 .31653 .28406 .31691 .29567 .31567 .28734 .31618 Mtetra
.663 .967 .919 r
.28734 .31618 .29567 .31567 .3074 .31391 .29949 .30923 Mtetra
.81 .854 .882 r
.29949 .30923 .3074 .31391 .31941 .30884 .31186 .29952 Mtetra
.73 .729 .849 r
.31186 .29952 .31941 .30884 .33159 .30185 .3241 .29221 Mtetra
.678 .707 .87 r
.3241 .29221 .33159 .30185 .34375 .29585 .33623 .28712 Mtetra
.664 .725 .895 r
.33623 .28712 .34375 .29585 .35588 .29104 .34837 .28264 Mtetra
.665 .735 .902 r
.34837 .28264 .35588 .29104 .36804 .28659 .36057 .27815 Mtetra
.667 .736 .901 r
.36057 .27815 .36804 .28659 .38027 .28209 .37283 .27357 Mtetra
.669 .735 .9 r
.37283 .27357 .38027 .28209 .39254 .2775 .38514 .2689 Mtetra
.67 .735 .898 r
.38514 .2689 .39254 .2775 .40488 .27281 .39752 .26415 Mtetra
.672 .734 .897 r
.39752 .26415 .40488 .27281 .41728 .26805 .40995 .25933 Mtetra
.40995 .25933 .41728 .26805 .42973 .26322 .42243 .25447 Mtetra
.673 .734 .896 r
.42243 .25447 .42973 .26322 .44224 .25835 .43497 .24957 Mtetra
.673 .735 .897 r
.43497 .24957 .44224 .25835 .4548 .25345 .44757 .24466 Mtetra
.672 .735 .897 r
.44757 .24466 .4548 .25345 .46741 .24854 .46023 .23974 Mtetra
.671 .736 .898 r
.46023 .23974 .46741 .24854 .48009 .24363 .47293 .23483 Mtetra
.671 .736 .899 r
.47293 .23483 .48009 .24363 .49281 .23873 .4857 .22993 Mtetra
.67 .737 .901 r
.4857 .22993 .49281 .23873 .5056 .23384 .49852 .22504 Mtetra
.669 .738 .902 r
.49852 .22504 .5056 .23384 .51844 .22897 .51141 .22017 Mtetra
.668 .738 .903 r
.51141 .22017 .51844 .22897 .53135 .22412 .52435 .21531 Mtetra
.667 .739 .904 r
.52435 .21531 .53135 .22412 .54431 .21928 .53735 .21046 Mtetra
.666 .74 .905 r
.53735 .21046 .54431 .21928 .55733 .21445 .55041 .20561 Mtetra
.665 .74 .906 r
.55041 .20561 .55733 .21445 .57041 .20963 .56353 .20076 Mtetra
.56353 .20076 .57041 .20963 .58355 .2048 .57672 .19591 Mtetra
.665 .741 .907 r
.57672 .19591 .58355 .2048 .59676 .19997 .58997 .19105 Mtetra
.664 .741 .907 r
.58997 .19105 .59676 .19997 .61003 .19513 .60328 .18618 Mtetra
.60328 .18618 .61003 .19513 .62336 .19028 .61665 .18129 Mtetra
.664 .741 .908 r
.61665 .18129 .62336 .19028 .63676 .18541 .63009 .17639 Mtetra
.63009 .17639 .63676 .18541 .65022 .18053 .6436 .17146 Mtetra
.6436 .17146 .65022 .18053 .66374 .17562 .65717 .16652 Mtetra
.65717 .16652 .66374 .17562 .67734 .1707 .6708 .16155 Mtetra
.6708 .16155 .67734 .1707 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15077 .72601 .14144 Mtetra
.72601 .14144 .73236 .15077 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14065 .75403 .13123 Mtetra
.75403 .13123 .76028 .14065 .77434 .13556 .76814 .12609 Mtetra
.662 .742 .909 r
.13031 .34798 .13845 .35553 .14968 .35148 .14157 .34391 Mtetra
.661 .742 .91 r
.14157 .34391 .14968 .35148 .16096 .34744 .15288 .33985 Mtetra
.66 .742 .91 r
.15288 .33985 .16096 .34744 .17229 .3434 .16423 .33579 Mtetra
.659 .742 .911 r
.16423 .33579 .17229 .3434 .18366 .33937 .17564 .33173 Mtetra
.658 .742 .912 r
.17564 .33173 .18366 .33937 .19509 .33535 .18709 .3277 Mtetra
.657 .742 .912 r
.18709 .3277 .19509 .33535 .20656 .33135 .19859 .32368 Mtetra
.655 .742 .913 r
.19859 .32368 .20656 .33135 .21808 .32737 .21014 .31968 Mtetra
.648 .74 .917 r
.21014 .31968 .21808 .32737 .22965 .32341 .22172 .31589 Mtetra
.594 .729 .938 r
.22172 .31589 .22965 .32341 .24126 .31954 .23323 .31339 Mtetra
.261 .623 .959 r
.23323 .31339 .24126 .31954 .25288 .31625 .24443 .31511 Mtetra
.527 0 0 r
.24443 .31511 .25288 .31625 .26438 .31503 .25534 .32131 Mtetra
.401 0 0 r
.25534 .32131 .26438 .31503 .27574 .31653 .26679 .32252 Mtetra
.596 .915 .67 r
.26679 .32252 .27574 .31653 .28734 .31618 .27927 .31176 Mtetra
.867 .845 .82 r
.27927 .31176 .28734 .31618 .29949 .30923 .292 .29772 Mtetra
.744 .692 .802 r
.292 .29772 .29949 .30923 .31186 .29952 .30437 .28861 Mtetra
.68 .682 .845 r
.30437 .28861 .31186 .29952 .3241 .29221 .3165 .28317 Mtetra
.664 .718 .889 r
.3165 .28317 .3241 .29221 .33623 .28712 .32863 .27865 Mtetra
.664 .734 .902 r
.32863 .27865 .33623 .28712 .34837 .28264 .3408 .27417 Mtetra
.666 .735 .902 r
.3408 .27417 .34837 .28264 .36057 .27815 .35304 .2696 Mtetra
.668 .735 .9 r
.35304 .2696 .36057 .27815 .37283 .27357 .36533 .26495 Mtetra
.67 .734 .899 r
.36533 .26495 .37283 .27357 .38514 .2689 .37768 .26021 Mtetra
.671 .734 .898 r
.37768 .26021 .38514 .2689 .39752 .26415 .39009 .2554 Mtetra
.672 .734 .897 r
.39009 .2554 .39752 .26415 .40995 .25933 .40255 .25055 Mtetra
.40255 .25055 .40995 .25933 .42243 .25447 .41508 .24566 Mtetra
.41508 .24566 .42243 .25447 .43497 .24957 .42765 .24074 Mtetra
.672 .735 .898 r
.42765 .24074 .43497 .24957 .44757 .24466 .44029 .23582 Mtetra
.671 .736 .898 r
.44029 .23582 .44757 .24466 .46023 .23974 .45298 .2309 Mtetra
.67 .736 .899 r
.45298 .2309 .46023 .23974 .47293 .23483 .46572 .22598 Mtetra
.67 .737 .901 r
.46572 .22598 .47293 .23483 .4857 .22993 .47852 .22108 Mtetra
.669 .738 .902 r
.47852 .22108 .4857 .22993 .49852 .22504 .49139 .21619 Mtetra
.668 .738 .903 r
.49139 .21619 .49852 .22504 .51141 .22017 .50431 .21131 Mtetra
.667 .739 .904 r
.50431 .21131 .51141 .22017 .52435 .21531 .51729 .20644 Mtetra
.666 .739 .905 r
.51729 .20644 .52435 .21531 .53735 .21046 .53033 .20158 Mtetra
.665 .74 .906 r
.53033 .20158 .53735 .21046 .55041 .20561 .54343 .19671 Mtetra
.54343 .19671 .55041 .20561 .56353 .20076 .5566 .19184 Mtetra
.665 .741 .907 r
.5566 .19184 .56353 .20076 .57672 .19591 .56982 .18696 Mtetra
.664 .741 .907 r
.56982 .18696 .57672 .19591 .58997 .19105 .58311 .18206 Mtetra
.58311 .18206 .58997 .19105 .60328 .18618 .59647 .17715 Mtetra
.664 .741 .908 r
.59647 .17715 .60328 .18618 .61665 .18129 .60989 .17223 Mtetra
.60989 .17223 .61665 .18129 .63009 .17639 .62337 .16728 Mtetra
.62337 .16728 .63009 .17639 .6436 .17146 .63692 .16232 Mtetra
.63692 .16232 .6436 .17146 .65717 .16652 .65053 .15733 Mtetra
.65053 .15733 .65717 .16652 .6708 .16155 .66421 .15231 Mtetra
.66421 .15231 .6708 .16155 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.661 .742 .909 r
.12211 .34038 .13031 .34798 .14157 .34391 .1334 .33628 Mtetra
.661 .742 .91 r
.1334 .33628 .14157 .34391 .15288 .33985 .14473 .33219 Mtetra
.66 .742 .91 r
.14473 .33219 .15288 .33985 .16423 .33579 .15612 .32811 Mtetra
.659 .742 .911 r
.15612 .32811 .16423 .33579 .17564 .33173 .16755 .32403 Mtetra
.658 .742 .912 r
.16755 .32403 .17564 .33173 .18709 .3277 .17902 .31998 Mtetra
.655 .741 .913 r
.17902 .31998 .18709 .3277 .19859 .32368 .19055 .31596 Mtetra
.639 .738 .92 r
.19055 .31596 .19859 .32368 .21014 .31968 .20208 .31239 Mtetra
.505 .704 .96 r
.20208 .31239 .21014 .31968 .22172 .31589 .2134 .31151 Mtetra
.448 0 0 r
.2134 .31151 .22172 .31589 .23323 .31339 .22404 .31844 Mtetra
.746 .307 .21 r
.22404 .31844 .23323 .31339 .24443 .31511 .23422 .33185 Mtetra
.505 .116 .236 r
.23422 .33185 .24443 .31511 .25534 .32131 .24558 .33405 Mtetra
.585 .823 .441 r
.24558 .33405 .25534 .32131 .26679 .32252 .25871 .31652 Mtetra
.89 .794 .748 r
.25871 .31652 .26679 .32252 .27927 .31176 .27201 .29632 Mtetra
.741 .641 .748 r
.27201 .29632 .27927 .31176 .292 .29772 .28456 .285 Mtetra
.678 .65 .815 r
.28456 .285 .292 .29772 .30437 .28861 .29671 .27918 Mtetra
.663 .709 .882 r
.29671 .27918 .30437 .28861 .3165 .28317 .30881 .27463 Mtetra
.663 .733 .901 r
.30881 .27463 .3165 .28317 .32863 .27865 .32096 .27016 Mtetra
.665 .735 .902 r
.32096 .27016 .32863 .27865 .3408 .27417 .33317 .2656 Mtetra
.667 .735 .901 r
.33317 .2656 .3408 .27417 .35304 .2696 .34544 .26095 Mtetra
.669 .734 .899 r
.34544 .26095 .35304 .2696 .36533 .26495 .35777 .25623 Mtetra
.67 .734 .898 r
.35777 .25623 .36533 .26495 .37768 .26021 .37016 .25144 Mtetra
.671 .734 .897 r
.37016 .25144 .37768 .26021 .39009 .2554 .3826 .24659 Mtetra
.3826 .24659 .39009 .2554 .40255 .25055 .3951 .2417 Mtetra
.3951 .2417 .40255 .25055 .41508 .24566 .40766 .23679 Mtetra
.671 .735 .898 r
.40766 .23679 .41508 .24566 .42765 .24074 .42027 .23187 Mtetra
.671 .735 .899 r
.42027 .23187 .42765 .24074 .44029 .23582 .43294 .22694 Mtetra
.67 .736 .9 r
.43294 .22694 .44029 .23582 .45298 .2309 .44566 .22202 Mtetra
.669 .737 .901 r
.44566 .22202 .45298 .2309 .46572 .22598 .45845 .2171 Mtetra
.668 .737 .902 r
.45845 .2171 .46572 .22598 .47852 .22108 .47129 .2122 Mtetra
.668 .738 .903 r
.47129 .2122 .47852 .22108 .49139 .21619 .48419 .2073 Mtetra
.667 .739 .904 r
.48419 .2073 .49139 .21619 .50431 .21131 .49715 .20241 Mtetra
.666 .739 .905 r
.49715 .20241 .50431 .21131 .51729 .20644 .51017 .19752 Mtetra
.665 .74 .906 r
.51017 .19752 .51729 .20644 .53033 .20158 .52325 .19264 Mtetra
.52325 .19264 .53033 .20158 .54343 .19671 .53639 .18774 Mtetra
.665 .74 .907 r
.53639 .18774 .54343 .19671 .5566 .19184 .5496 .18284 Mtetra
.664 .741 .907 r
.5496 .18284 .5566 .19184 .56982 .18696 .56287 .17793 Mtetra
.56287 .17793 .56982 .18696 .58311 .18206 .5762 .173 Mtetra
.5762 .173 .58311 .18206 .59647 .17715 .5896 .16805 Mtetra
.664 .741 .908 r
.5896 .16805 .59647 .17715 .60989 .17223 .60306 .16309 Mtetra
.60306 .16309 .60989 .17223 .62337 .16728 .61659 .1581 Mtetra
.61659 .1581 .62337 .16728 .63692 .16232 .63018 .15309 Mtetra
.63018 .15309 .63692 .16232 .65053 .15733 .64384 .14805 Mtetra
.64384 .14805 .65053 .15733 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.661 .741 .91 r
.11385 .33271 .12211 .34038 .1334 .33628 .12516 .32859 Mtetra
.66 .742 .91 r
.12516 .32859 .1334 .33628 .14473 .33219 .13652 .32448 Mtetra
.659 .742 .911 r
.13652 .32448 .14473 .33219 .15612 .32811 .14793 .32037 Mtetra
.658 .742 .911 r
.14793 .32037 .15612 .32811 .16755 .32403 .15939 .31627 Mtetra
.655 .741 .913 r
.15939 .31627 .16755 .32403 .17902 .31998 .17088 .31227 Mtetra
.62 .733 .928 r
.17088 .31227 .17902 .31998 .19055 .31596 .18233 .30917 Mtetra
.248 .597 .951 r
.18233 .30917 .19055 .31596 .20208 .31239 .1933 .31122 Mtetra
.809 .34 .11 r
.1933 .31122 .20208 .31239 .2134 .31151 .203 .32656 Mtetra
.764 .407 .378 r
.203 .32656 .2134 .31151 .22404 .31844 .21212 .3498 Mtetra
.502 .174 .342 r
.21212 .3498 .22404 .31844 .23422 .33185 .22357 .35112 Mtetra
.716 .836 .393 r
.22357 .35112 .23422 .33185 .24558 .33405 .2378 .32302 Mtetra
.875 .721 .687 r
.2378 .32302 .24558 .33405 .25871 .31652 .2519 .29501 Mtetra
.726 .587 .699 r
.2519 .29501 .25871 .31652 .27201 .29632 .26468 .28131 Mtetra
.671 .615 .784 r
.26468 .28131 .27201 .29632 .28456 .285 .27684 .27516 Mtetra
.662 .7 .875 r
.27684 .27516 .28456 .285 .29671 .27918 .28892 .27059 Mtetra
.662 .732 .901 r
.28892 .27059 .29671 .27918 .30881 .27463 .30105 .26611 Mtetra
.664 .735 .903 r
.30105 .26611 .30881 .27463 .32096 .27016 .31323 .26156 Mtetra
.666 .735 .901 r
.31323 .26156 .32096 .27016 .33317 .2656 .32548 .25693 Mtetra
.668 .734 .9 r
.32548 .25693 .33317 .2656 .34544 .26095 .33778 .25221 Mtetra
.669 .734 .899 r
.33778 .25221 .34544 .26095 .35777 .25623 .35015 .24743 Mtetra
.67 .734 .898 r
.35015 .24743 .35777 .25623 .37016 .25144 .36257 .2426 Mtetra
.671 .734 .898 r
.36257 .2426 .37016 .25144 .3826 .24659 .37505 .23772 Mtetra
.37505 .23772 .3826 .24659 .3951 .2417 .38758 .23281 Mtetra
.671 .735 .898 r
.38758 .23281 .3951 .2417 .40766 .23679 .40017 .22789 Mtetra
.67 .735 .899 r
.40017 .22789 .40766 .23679 .42027 .23187 .41282 .22296 Mtetra
.67 .736 .9 r
.41282 .22296 .42027 .23187 .43294 .22694 .42553 .21802 Mtetra
.669 .737 .901 r
.42553 .21802 .43294 .22694 .44566 .22202 .43829 .2131 Mtetra
.668 .737 .902 r
.43829 .2131 .44566 .22202 .45845 .2171 .45111 .20818 Mtetra
.668 .738 .903 r
.45111 .20818 .45845 .2171 .47129 .2122 .46399 .20327 Mtetra
.667 .739 .904 r
.46399 .20327 .47129 .2122 .48419 .2073 .47692 .19836 Mtetra
.666 .739 .905 r
.47692 .19836 .48419 .2073 .49715 .20241 .48992 .19345 Mtetra
.665 .74 .905 r
.48992 .19345 .49715 .20241 .51017 .19752 .50298 .18855 Mtetra
.665 .74 .906 r
.50298 .18855 .51017 .19752 .52325 .19264 .5161 .18363 Mtetra
.665 .74 .907 r
.5161 .18363 .52325 .19264 .53639 .18774 .52929 .17871 Mtetra
.664 .741 .907 r
.52929 .17871 .53639 .18774 .5496 .18284 .54254 .17378 Mtetra
.54254 .17378 .5496 .18284 .56287 .17793 .55585 .16883 Mtetra
.55585 .16883 .56287 .17793 .5762 .173 .56922 .16386 Mtetra
.664 .741 .908 r
.56922 .16386 .5762 .173 .5896 .16805 .58266 .15887 Mtetra
.58266 .15887 .5896 .16805 .60306 .16309 .59617 .15386 Mtetra
.59617 .15386 .60306 .16309 .61659 .1581 .60974 .14883 Mtetra
.60974 .14883 .61659 .1581 .63018 .15309 .62338 .14378 Mtetra
.62338 .14378 .63018 .15309 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.661 .741 .91 r
.10551 .32498 .11385 .33271 .12516 .32859 .11685 .32084 Mtetra
.66 .741 .91 r
.11685 .32084 .12516 .32859 .13652 .32448 .12824 .3167 Mtetra
.659 .741 .911 r
.12824 .3167 .13652 .32448 .14793 .32037 .13967 .31257 Mtetra
.652 .74 .914 r
.13967 .31257 .14793 .32037 .15939 .31627 .15114 .30862 Mtetra
.579 .723 .941 r
.15114 .30862 .15939 .31627 .17088 .31227 .16245 .30642 Mtetra
0 .173 .608 r
.16245 .30642 .17088 .31227 .18233 .30917 .17281 .31328 Mtetra
.852 .476 .338 r
.17281 .31328 .18233 .30917 .1933 .31122 .18106 .34081 Mtetra
.755 .435 .444 r
.18106 .34081 .1933 .31122 .203 .32656 .18881 .37575 Mtetra
.463 .168 .379 r
.18881 .37575 .203 .32656 .21212 .3498 .20076 .37261 Mtetra
.903 .888 .466 r
.20076 .37261 .21212 .3498 .22357 .35112 .21663 .32999 Mtetra
.84 .648 .643 r
.21663 .32999 .22357 .35112 .2378 .32302 .23172 .29332 Mtetra
.704 .538 .661 r
.23172 .29332 .2378 .32302 .2519 .29501 .24473 .27749 Mtetra
.662 .583 .756 r
.24473 .27749 .2519 .29501 .26468 .28131 .2569 .2711 Mtetra
.661 .693 .869 r
.2569 .2711 .26468 .28131 .27684 .27516 .26896 .26652 Mtetra
.662 .731 .901 r
.26896 .26652 .27684 .27516 .28892 .27059 .28106 .26204 Mtetra
.664 .735 .903 r
.28106 .26204 .28892 .27059 .30105 .26611 .29322 .2575 Mtetra
.665 .735 .902 r
.29322 .2575 .30105 .26611 .31323 .26156 .30544 .25287 Mtetra
.667 .734 .9 r
.30544 .25287 .31323 .26156 .32548 .25693 .31772 .24817 Mtetra
.668 .734 .899 r
.31772 .24817 .32548 .25693 .33778 .25221 .33006 .2434 Mtetra
.669 .734 .898 r
.33006 .2434 .33778 .25221 .35015 .24743 .34246 .23857 Mtetra
.67 .734 .898 r
.34246 .23857 .35015 .24743 .36257 .2426 .35492 .2337 Mtetra
.35492 .2337 .36257 .2426 .37505 .23772 .36743 .2288 Mtetra
.67 .735 .898 r
.36743 .2288 .37505 .23772 .38758 .23281 .38 .22388 Mtetra
.67 .735 .899 r
.38 .22388 .38758 .23281 .40017 .22789 .39262 .21894 Mtetra
.669 .736 .9 r
.39262 .21894 .40017 .22789 .41282 .22296 .40531 .21401 Mtetra
.669 .737 .901 r
.40531 .21401 .41282 .22296 .42553 .21802 .41805 .20907 Mtetra
.668 .737 .902 r
.41805 .20907 .42553 .21802 .43829 .2131 .43085 .20414 Mtetra
.667 .738 .903 r
.43085 .20414 .43829 .2131 .45111 .20818 .4437 .19921 Mtetra
.667 .739 .904 r
.4437 .19921 .45111 .20818 .46399 .20327 .45662 .19429 Mtetra
.666 .739 .905 r
.45662 .19429 .46399 .20327 .47692 .19836 .4696 .18936 Mtetra
.665 .74 .905 r
.4696 .18936 .47692 .19836 .48992 .19345 .48264 .18444 Mtetra
.665 .74 .906 r
.48264 .18444 .48992 .19345 .50298 .18855 .49574 .1795 Mtetra
.665 .74 .907 r
.49574 .1795 .50298 .18855 .5161 .18363 .5089 .17456 Mtetra
.664 .741 .907 r
.5089 .17456 .5161 .18363 .52929 .17871 .52212 .16961 Mtetra
.52212 .16961 .52929 .17871 .54254 .17378 .53541 .16464 Mtetra
.53541 .16464 .54254 .17378 .55585 .16883 .54877 .15965 Mtetra
.664 .741 .908 r
.54877 .15965 .55585 .16883 .56922 .16386 .56218 .15464 Mtetra
.56218 .15464 .56922 .16386 .58266 .15887 .57567 .14961 Mtetra
.57567 .14961 .58266 .15887 .59617 .15386 .58922 .14456 Mtetra
.58922 .14456 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.661 .741 .91 r
.09711 .31719 .10551 .32498 .11685 .32084 .10847 .31302 Mtetra
.659 .741 .911 r
.10847 .31302 .11685 .32084 .12824 .3167 .11989 .30887 Mtetra
.647 .739 .916 r
.11989 .30887 .12824 .3167 .13967 .31257 .13131 .30505 Mtetra
.492 .695 .959 r
.13131 .30505 .13967 .31257 .15114 .30862 .1424 .30435 Mtetra
.795 .299 0 r
.1424 .30435 .15114 .30862 .16245 .30642 .15182 .31832 Mtetra
.85 .519 .426 r
.15182 .31832 .16245 .30642 .17281 .31328 .15805 .36166 Mtetra
.738 .438 .473 r
.15805 .36166 .17281 .31328 .18106 .34081 .1643 .40827 Mtetra
.394 .122 .378 r
.1643 .40827 .18106 .34081 .18881 .37575 .17738 .39556 Mtetra
.995 .866 .546 r
.17738 .39556 .18881 .37575 .20076 .37261 .19539 .33556 Mtetra
.799 .586 .614 r
.19539 .33556 .20076 .37261 .21663 .32999 .21151 .2908 Mtetra
.682 .499 .633 r
.21151 .2908 .21663 .32999 .23172 .29332 .22472 .27349 Mtetra
.652 .558 .736 r
.22472 .27349 .23172 .29332 .24473 .27749 .23689 .26702 Mtetra
.659 .687 .865 r
.23689 .26702 .24473 .27749 .2569 .2711 .24892 .26244 Mtetra
.661 .731 .901 r
.24892 .26244 .2569 .2711 .26896 .26652 .26099 .25796 Mtetra
.663 .735 .904 r
.26099 .25796 .26896 .26652 .28106 .26204 .27313 .25341 Mtetra
.665 .735 .902 r
.27313 .25341 .28106 .26204 .29322 .2575 .28533 .24879 Mtetra
.666 .735 .901 r
.28533 .24879 .29322 .2575 .30544 .25287 .29758 .2441 Mtetra
.667 .734 .9 r
.29758 .2441 .30544 .25287 .31772 .24817 .3099 .23934 Mtetra
.668 .734 .899 r
.3099 .23934 .31772 .24817 .33006 .2434 .32227 .23452 Mtetra
.669 .734 .899 r
.32227 .23452 .33006 .2434 .34246 .23857 .33471 .22966 Mtetra
.33471 .22966 .34246 .23857 .35492 .2337 .3472 .22476 Mtetra
.67 .735 .899 r
.3472 .22476 .35492 .2337 .36743 .2288 .35974 .21984 Mtetra
.669 .735 .899 r
.35974 .21984 .36743 .2288 .38 .22388 .37235 .21491 Mtetra
.669 .736 .9 r
.37235 .21491 .38 .22388 .39262 .21894 .38501 .20997 Mtetra
.668 .737 .901 r
.38501 .20997 .39262 .21894 .40531 .21401 .39773 .20502 Mtetra
.668 .737 .902 r
.39773 .20502 .40531 .21401 .41805 .20907 .4105 .20008 Mtetra
.667 .738 .903 r
.4105 .20008 .41805 .20907 .43085 .20414 .42334 .19514 Mtetra
.667 .739 .904 r
.42334 .19514 .43085 .20414 .4437 .19921 .43623 .1902 Mtetra
.666 .739 .905 r
.43623 .1902 .4437 .19921 .45662 .19429 .44919 .18525 Mtetra
.665 .74 .905 r
.44919 .18525 .45662 .19429 .4696 .18936 .46221 .18031 Mtetra
.665 .74 .906 r
.46221 .18031 .4696 .18936 .48264 .18444 .47528 .17536 Mtetra
.665 .74 .907 r
.47528 .17536 .48264 .18444 .49574 .1795 .48842 .1704 Mtetra
.664 .741 .907 r
.48842 .1704 .49574 .1795 .5089 .17456 .50163 .16542 Mtetra
.50163 .16542 .5089 .17456 .52212 .16961 .51489 .16043 Mtetra
.51489 .16043 .52212 .16961 .53541 .16464 .52823 .15542 Mtetra
.664 .741 .908 r
.52823 .15542 .53541 .16464 .54877 .15965 .54162 .15039 Mtetra
.54162 .15039 .54877 .15965 .56218 .15464 .55508 .14534 Mtetra
.55508 .14534 .56218 .15464 .57567 .14961 .56861 .14027 Mtetra
.56861 .14027 .57567 .14961 .58922 .14456 .5822 .13517 Mtetra
.5822 .13517 .58922 .14456 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.659 .741 .91 r
.08863 .30934 .09711 .31719 .10847 .31302 .10002 .30517 Mtetra
.637 .736 .92 r
.10002 .30517 .10847 .31302 .11989 .30887 .11138 .3016 Mtetra
.302 .615 .956 r
.11138 .3016 .11989 .30887 .13131 .30505 .12213 .30315 Mtetra
.876 .471 .253 r
.12213 .30315 .13131 .30505 .1424 .30435 .13025 .32651 Mtetra
.841 .532 .466 r
.13025 .32651 .1424 .30435 .15182 .31832 .13398 .38789 Mtetra
.718 .429 .487 r
.13398 .38789 .15182 .31832 .15805 .36166 .13895 .44322 Mtetra
.279 .029 .345 r
.13895 .44322 .15805 .36166 .1643 .40827 .15393 .41538 Mtetra
.974 .78 .581 r
.15393 .41538 .1643 .40827 .17738 .39556 .17432 .33776 Mtetra
.759 .536 .594 r
.17432 .33776 .17738 .39556 .19539 .33556 .19133 .28709 Mtetra
.661 .469 .614 r
.19133 .28709 .19539 .33556 .21151 .2908 .20466 .26929 Mtetra
.643 .541 .723 r
.20466 .26929 .21151 .2908 .22472 .27349 .2168 .26292 Mtetra
.658 .686 .865 r
.2168 .26292 .22472 .27349 .23689 .26702 .2288 .25835 Mtetra
.661 .732 .902 r
.2288 .25835 .23689 .26702 .24892 .26244 .24086 .25386 Mtetra
.663 .736 .904 r
.24086 .25386 .24892 .26244 .26099 .25796 .25297 .24931 Mtetra
.664 .735 .903 r
.25297 .24931 .26099 .25796 .27313 .25341 .26514 .24469 Mtetra
.665 .735 .902 r
.26514 .24469 .27313 .25341 .28533 .24879 .27737 .24 Mtetra
.667 .735 .901 r
.27737 .24 .28533 .24879 .29758 .2441 .28966 .23525 Mtetra
.668 .734 .9 r
.28966 .23525 .29758 .2441 .3099 .23934 .30201 .23044 Mtetra
.668 .734 .899 r
.30201 .23044 .3099 .23934 .32227 .23452 .31442 .22559 Mtetra
.669 .735 .899 r
.31442 .22559 .32227 .23452 .33471 .22966 .32689 .2207 Mtetra
.32689 .2207 .33471 .22966 .3472 .22476 .33941 .21578 Mtetra
.669 .736 .9 r
.33941 .21578 .3472 .22476 .35974 .21984 .35199 .21085 Mtetra
.669 .736 .901 r
.35199 .21085 .35974 .21984 .37235 .21491 .36463 .2059 Mtetra
.668 .737 .901 r
.36463 .2059 .37235 .21491 .38501 .20997 .37733 .20095 Mtetra
.668 .737 .902 r
.37733 .20095 .38501 .20997 .39773 .20502 .39008 .196 Mtetra
.667 .738 .903 r
.39008 .196 .39773 .20502 .4105 .20008 .40289 .19104 Mtetra
.666 .739 .904 r
.40289 .19104 .4105 .20008 .42334 .19514 .41577 .18609 Mtetra
.666 .739 .905 r
.41577 .18609 .42334 .19514 .43623 .1902 .4287 .18113 Mtetra
.665 .74 .905 r
.4287 .18113 .43623 .1902 .44919 .18525 .44169 .17616 Mtetra
.665 .74 .906 r
.44169 .17616 .44919 .18525 .46221 .18031 .45475 .17119 Mtetra
.665 .74 .907 r
.45475 .17119 .46221 .18031 .47528 .17536 .46787 .16621 Mtetra
.664 .741 .907 r
.46787 .16621 .47528 .17536 .48842 .1704 .48105 .16122 Mtetra
.48105 .16122 .48842 .1704 .50163 .16542 .49429 .15621 Mtetra
.49429 .15621 .50163 .16542 .51489 .16043 .5076 .15118 Mtetra
.664 .741 .908 r
.5076 .15118 .51489 .16043 .52823 .15542 .52097 .14613 Mtetra
.52097 .14613 .52823 .15542 .54162 .15039 .53441 .14105 Mtetra
.53441 .14105 .54162 .15039 .55508 .14534 .54792 .13596 Mtetra
.54792 .13596 .55508 .14534 .56861 .14027 .56149 .13084 Mtetra
.56149 .13084 .56861 .14027 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.621 .733 .926 r
.08008 .30148 .08863 .30934 .10002 .30517 .09135 .2983 Mtetra
0 .396 .827 r
.09135 .2983 .10002 .30517 .11138 .3016 .10164 .30285 Mtetra
.886 .53 .366 r
.10164 .30285 .11138 .3016 .12213 .30315 .1081 .33722 Mtetra
.831 .534 .487 r
.1081 .33722 .12213 .30315 .13025 .32651 .10919 .41603 Mtetra
.695 .412 .491 r
.10919 .41603 .13025 .32651 .13398 .38789 .11352 .47394 Mtetra
.068 0 .253 r
.11352 .47394 .13398 .38789 .13895 .44322 .13107 .42698 Mtetra
.913 .689 .586 r
.13107 .42698 .13895 .44322 .15393 .41538 .15365 .33514 Mtetra
.724 .496 .58 r
.15365 .33514 .15393 .41538 .17432 .33776 .17122 .28213 Mtetra
.642 .446 .602 r
.17122 .28213 .17432 .33776 .19133 .28709 .18454 .26495 Mtetra
.637 .533 .719 r
.18454 .26495 .19133 .28709 .20466 .26929 .19664 .25881 Mtetra
.658 .688 .867 r
.19664 .25881 .20466 .26929 .2168 .26292 .20862 .25425 Mtetra
.661 .733 .903 r
.20862 .25425 .2168 .26292 .2288 .25835 .22064 .24975 Mtetra
.662 .736 .905 r
.22064 .24975 .2288 .25835 .24086 .25386 .23273 .2452 Mtetra
.664 .736 .903 r
.23273 .2452 .24086 .25386 .25297 .24931 .24487 .24057 Mtetra
.665 .735 .902 r
.24487 .24057 .25297 .24931 .26514 .24469 .25708 .23589 Mtetra
.666 .735 .901 r
.25708 .23589 .26514 .24469 .27737 .24 .26934 .23114 Mtetra
.667 .735 .901 r
.26934 .23114 .27737 .24 .28966 .23525 .28167 .22634 Mtetra
.668 .735 .9 r
.28167 .22634 .28966 .23525 .30201 .23044 .29405 .22149 Mtetra
.29405 .22149 .30201 .23044 .31442 .22559 .3065 .21661 Mtetra
.3065 .21661 .31442 .22559 .32689 .2207 .319 .21169 Mtetra
.668 .736 .9 r
.319 .21169 .32689 .2207 .33941 .21578 .33155 .20676 Mtetra
.668 .736 .901 r
.33155 .20676 .33941 .21578 .35199 .21085 .34417 .20181 Mtetra
.668 .737 .902 r
.34417 .20181 .35199 .21085 .36463 .2059 .35684 .19685 Mtetra
.667 .737 .902 r
.35684 .19685 .36463 .2059 .37733 .20095 .36958 .19189 Mtetra
.667 .738 .903 r
.36958 .19189 .37733 .20095 .39008 .196 .38237 .18692 Mtetra
.666 .739 .904 r
.38237 .18692 .39008 .196 .40289 .19104 .39522 .18196 Mtetra
.666 .739 .905 r
.39522 .18196 .40289 .19104 .41577 .18609 .40813 .17698 Mtetra
.665 .74 .905 r
.40813 .17698 .41577 .18609 .4287 .18113 .4211 .172 Mtetra
.665 .74 .906 r
.4211 .172 .4287 .18113 .44169 .17616 .43413 .16701 Mtetra
.665 .74 .907 r
.43413 .16701 .44169 .17616 .45475 .17119 .44722 .16201 Mtetra
.664 .741 .907 r
.44722 .16201 .45475 .17119 .46787 .16621 .46038 .15699 Mtetra
.46038 .15699 .46787 .16621 .48105 .16122 .4736 .15196 Mtetra
.4736 .15196 .48105 .16122 .49429 .15621 .48689 .14691 Mtetra
.664 .741 .908 r
.48689 .14691 .49429 .15621 .5076 .15118 .50024 .14184 Mtetra
.50024 .14184 .5076 .15118 .52097 .14613 .51366 .13675 Mtetra
.51366 .13675 .52097 .14613 .53441 .14105 .52714 .13163 Mtetra
.52714 .13163 .53441 .14105 .54792 .13596 .54069 .12649 Mtetra
.54069 .12649 .54792 .13596 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.51 0 0 r
.07122 .29515 .08008 .30148 .09135 .2983 .08091 .30327 Mtetra
.883 .553 .419 r
.08091 .30327 .09135 .2983 .10164 .30285 .08558 .34871 Mtetra
.819 .529 .498 r
.08558 .34871 .10164 .30285 .1081 .33722 .08436 .44065 Mtetra
.667 .387 .488 r
.08436 .44065 .1081 .33722 .10919 .41603 .0891 .49293 Mtetra
0 0 .022 r
.0891 .49293 .10919 .41603 .11352 .47394 .10946 .4266 Mtetra
.851 .615 .582 r
.10946 .4266 .11352 .47394 .13107 .42698 .13353 .32737 Mtetra
.694 .464 .57 r
.13353 .32737 .13107 .42698 .15365 .33514 .15116 .27614 Mtetra
.628 .431 .597 r
.15116 .27614 .15365 .33514 .17122 .28213 .16435 .26052 Mtetra
.634 .535 .725 r
.16435 .26052 .17122 .28213 .18454 .26495 .1764 .2547 Mtetra
.658 .694 .873 r
.1764 .2547 .18454 .26495 .19664 .25881 .18835 .25015 Mtetra
.661 .734 .904 r
.18835 .25015 .19664 .25881 .20862 .25425 .20035 .24564 Mtetra
.662 .736 .905 r
.20035 .24564 .20862 .25425 .22064 .24975 .21241 .24107 Mtetra
.663 .736 .904 r
.21241 .24107 .22064 .24975 .23273 .2452 .22453 .23645 Mtetra
.664 .736 .903 r
.22453 .23645 .23273 .2452 .24487 .24057 .23671 .23176 Mtetra
.665 .735 .902 r
.23671 .23176 .24487 .24057 .25708 .23589 .24895 .22702 Mtetra
.666 .735 .901 r
.24895 .22702 .25708 .23589 .26934 .23114 .26125 .22222 Mtetra
.667 .735 .901 r
.26125 .22222 .26934 .23114 .28167 .22634 .27361 .21738 Mtetra
.27361 .21738 .28167 .22634 .29405 .22149 .28603 .2125 Mtetra
.668 .736 .901 r
.28603 .2125 .29405 .22149 .3065 .21661 .2985 .20759 Mtetra
.2985 .20759 .3065 .21661 .319 .21169 .31104 .20265 Mtetra
.31104 .20265 .319 .21169 .33155 .20676 .32363 .1977 Mtetra
.667 .737 .902 r
.32363 .1977 .33155 .20676 .34417 .20181 .33628 .19274 Mtetra
.667 .738 .903 r
.33628 .19274 .34417 .20181 .35684 .19685 .34899 .18777 Mtetra
.667 .738 .904 r
.34899 .18777 .35684 .19685 .36958 .19189 .36175 .18279 Mtetra
.666 .739 .904 r
.36175 .18279 .36958 .19189 .38237 .18692 .37458 .17781 Mtetra
.666 .739 .905 r
.37458 .17781 .38237 .18692 .39522 .18196 .38747 .17282 Mtetra
.665 .74 .906 r
.38747 .17282 .39522 .18196 .40813 .17698 .40042 .16782 Mtetra
.40042 .16782 .40813 .17698 .4211 .172 .41343 .16281 Mtetra
.665 .74 .907 r
.41343 .16281 .4211 .172 .43413 .16701 .4265 .15779 Mtetra
.664 .741 .907 r
.4265 .15779 .43413 .16701 .44722 .16201 .43963 .15275 Mtetra
.43963 .15275 .44722 .16201 .46038 .15699 .45283 .1477 Mtetra
.45283 .1477 .46038 .15699 .4736 .15196 .46609 .14263 Mtetra
.664 .741 .908 r
.46609 .14263 .4736 .15196 .48689 .14691 .47942 .13754 Mtetra
.47942 .13754 .48689 .14691 .50024 .14184 .49281 .13243 Mtetra
.49281 .13243 .50024 .14184 .51366 .13675 .50627 .12729 Mtetra
.50627 .12729 .51366 .13675 .52714 .13163 .5198 .12213 Mtetra
.5198 .12213 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10124 Mtetra
.57457 .10124 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.877 .561 .446 r
.06003 .30389 .07122 .29515 .08091 .30327 .06302 .35842 Mtetra
.808 .52 .502 r
.06302 .35842 .08091 .30327 .08558 .34871 .06044 .45563 Mtetra
.631 .353 .478 r
.06044 .45563 .08558 .34871 .08436 .44065 .0667 .49444 Mtetra
.89 .838 .374 r
.0667 .49444 .08436 .44065 .0891 .49293 .08946 .41332 Mtetra
.798 .558 .575 r
.08946 .41332 .0891 .49293 .10946 .4266 .11393 .31536 Mtetra
.669 .439 .564 r
.11393 .31536 .10946 .4266 .13353 .32737 .13113 .26955 Mtetra
.616 .423 .598 r
.13113 .26955 .13353 .32737 .15116 .27614 .14409 .25607 Mtetra
.634 .547 .739 r
.14409 .25607 .15116 .27614 .16435 .26052 .15608 .25059 Mtetra
.658 .703 .88 r
.15608 .25059 .16435 .26052 .1764 .2547 .168 .24605 Mtetra
.661 .735 .905 r
.168 .24605 .1764 .2547 .18835 .25015 .17998 .24152 Mtetra
.662 .737 .906 r
.17998 .24152 .18835 .25015 .20035 .24564 .19201 .23695 Mtetra
.663 .736 .905 r
.19201 .23695 .20035 .24564 .21241 .24107 .20411 .23231 Mtetra
.664 .736 .904 r
.20411 .23231 .21241 .24107 .22453 .23645 .21626 .22762 Mtetra
.665 .736 .903 r
.21626 .22762 .22453 .23645 .23671 .23176 .22848 .22288 Mtetra
.666 .736 .902 r
.22848 .22288 .23671 .23176 .24895 .22702 .24075 .21809 Mtetra
.24075 .21809 .24895 .22702 .26125 .22222 .25308 .21325 Mtetra
.667 .736 .901 r
.25308 .21325 .26125 .22222 .27361 .21738 .26548 .20837 Mtetra
.26548 .20837 .27361 .21738 .28603 .2125 .27793 .20346 Mtetra
.667 .736 .902 r
.27793 .20346 .28603 .2125 .2985 .20759 .29044 .19852 Mtetra
.667 .737 .902 r
.29044 .19852 .2985 .20759 .31104 .20265 .30301 .19357 Mtetra
.30301 .19357 .31104 .20265 .32363 .1977 .31563 .1886 Mtetra
.667 .738 .903 r
.31563 .1886 .32363 .1977 .33628 .19274 .32832 .18362 Mtetra
.666 .738 .904 r
.32832 .18362 .33628 .19274 .34899 .18777 .34106 .17863 Mtetra
.666 .739 .904 r
.34106 .17863 .34899 .18777 .36175 .18279 .35386 .17364 Mtetra
.665 .739 .905 r
.35386 .17364 .36175 .18279 .37458 .17781 .36673 .16863 Mtetra
.665 .74 .906 r
.36673 .16863 .37458 .17781 .38747 .17282 .37965 .16362 Mtetra
.37965 .16362 .38747 .17282 .40042 .16782 .39264 .15859 Mtetra
.664 .74 .907 r
.39264 .15859 .40042 .16782 .41343 .16281 .40569 .15355 Mtetra
.664 .741 .907 r
.40569 .15355 .41343 .16281 .4265 .15779 .4188 .1485 Mtetra
.4188 .1485 .4265 .15779 .43963 .15275 .43197 .14342 Mtetra
.43197 .14342 .43963 .15275 .45283 .1477 .44521 .13833 Mtetra
.664 .741 .908 r
.44521 .13833 .45283 .1477 .46609 .14263 .45852 .13322 Mtetra
.45852 .13322 .46609 .14263 .47942 .13754 .47188 .12808 Mtetra
.47188 .12808 .47942 .13754 .49281 .13243 .48532 .12293 Mtetra
.48532 .12293 .49281 .13243 .50627 .12729 .49882 .11774 Mtetra
.49882 .11774 .50627 .12729 .5198 .12213 .51239 .11254 Mtetra
.51239 .11254 .5198 .12213 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10124 .56734 .09145 Mtetra
.56734 .09145 .57457 .10124 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.795 .508 .502 r
.04091 .36351 .06003 .30389 .06302 .35842 .0383 .45635 Mtetra
.582 .303 .458 r
.0383 .45635 .06302 .35842 .06044 .45563 .04687 .47705 Mtetra
.992 .815 .567 r
.04687 .47705 .06044 .45563 .0667 .49444 .07098 .38949 Mtetra
.754 .514 .569 r
.07098 .38949 .0667 .49444 .08946 .41332 .09469 .3009 Mtetra
.648 .421 .561 r
.09469 .3009 .08946 .41332 .11393 .31536 .11107 .26285 Mtetra
.609 .423 .605 r
.11107 .26285 .11393 .31536 .13113 .26955 .12376 .25167 Mtetra
.637 .57 .762 r
.12376 .25167 .13113 .26955 .14409 .25607 .13568 .24649 Mtetra
.659 .712 .887 r
.13568 .24649 .14409 .25607 .15608 .25059 .14758 .24195 Mtetra
.661 .736 .906 r
.14758 .24195 .15608 .25059 .168 .24605 .15953 .23741 Mtetra
.662 .737 .906 r
.15953 .23741 .168 .24605 .17998 .24152 .17154 .23282 Mtetra
.663 .737 .905 r
.17154 .23282 .17998 .24152 .19201 .23695 .1836 .22817 Mtetra
.664 .737 .904 r
.1836 .22817 .19201 .23695 .20411 .23231 .19573 .22348 Mtetra
.664 .736 .903 r
.19573 .22348 .20411 .23231 .21626 .22762 .20792 .21873 Mtetra
.665 .736 .903 r
.20792 .21873 .21626 .22762 .22848 .22288 .22017 .21394 Mtetra
.666 .736 .902 r
.22017 .21394 .22848 .22288 .24075 .21809 .23248 .2091 Mtetra
.23248 .2091 .24075 .21809 .25308 .21325 .24485 .20422 Mtetra
.667 .736 .902 r
.24485 .20422 .25308 .21325 .26548 .20837 .25727 .19931 Mtetra
.667 .737 .902 r
.25727 .19931 .26548 .20837 .27793 .20346 .26976 .19438 Mtetra
.26976 .19438 .27793 .20346 .29044 .19852 .2823 .18942 Mtetra
.667 .737 .903 r
.2823 .18942 .29044 .19852 .30301 .19357 .2949 .18444 Mtetra
.666 .738 .903 r
.2949 .18444 .30301 .19357 .31563 .1886 .30756 .17946 Mtetra
.666 .738 .904 r
.30756 .17946 .31563 .1886 .32832 .18362 .32028 .17446 Mtetra
.666 .739 .905 r
.32028 .17446 .32832 .18362 .34106 .17863 .33306 .16945 Mtetra
.665 .739 .905 r
.33306 .16945 .34106 .17863 .35386 .17364 .3459 .16443 Mtetra
.665 .74 .906 r
.3459 .16443 .35386 .17364 .36673 .16863 .3588 .1594 Mtetra
.3588 .1594 .36673 .16863 .37965 .16362 .37176 .15435 Mtetra
.664 .74 .907 r
.37176 .15435 .37965 .16362 .39264 .15859 .38479 .14929 Mtetra
.664 .741 .907 r
.38479 .14929 .39264 .15859 .40569 .15355 .39788 .14422 Mtetra
.39788 .14422 .40569 .15355 .4188 .1485 .41103 .13913 Mtetra
.41103 .13913 .4188 .1485 .43197 .14342 .42424 .13401 Mtetra
.664 .741 .908 r
.42424 .13401 .43197 .14342 .44521 .13833 .43752 .12888 Mtetra
.43752 .12888 .44521 .13833 .45852 .13322 .45087 .12372 Mtetra
.45087 .12372 .45852 .13322 .47188 .12808 .46428 .11854 Mtetra
.46428 .11854 .47188 .12808 .48532 .12293 .47776 .11334 Mtetra
.47776 .11334 .48532 .12293 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11254 .50491 .10286 Mtetra
.50491 .10286 .51239 .11254 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.503 .219 .415 r
.0184 .44161 .04091 .36351 .0383 .45635 .02948 .44427 Mtetra
.915 .701 .598 r
.02948 .44427 .0383 .45635 .04687 .47705 .05357 .35971 Mtetra
.718 .481 .565 r
.05357 .35971 .04687 .47705 .07098 .38949 .07558 .286 Mtetra
.631 .408 .562 r
.07558 .286 .07098 .38949 .09469 .3009 .09093 .25643 Mtetra
.606 .433 .621 r
.09093 .25643 .09469 .3009 .11107 .26285 .10333 .24735 Mtetra
.643 .601 .792 r
.10333 .24735 .11107 .26285 .12376 .25167 .1152 .24241 Mtetra
.66 .72 .894 r
.1152 .24241 .12376 .25167 .13568 .24649 .12707 .23786 Mtetra
.661 .737 .906 r
.12707 .23786 .13568 .24649 .14758 .24195 .139 .2333 Mtetra
.662 .738 .906 r
.139 .2333 .14758 .24195 .15953 .23741 .15098 .22869 Mtetra
.663 .737 .905 r
.15098 .22869 .15953 .23741 .17154 .23282 .16302 .22403 Mtetra
.16302 .22403 .17154 .23282 .1836 .22817 .17513 .21933 Mtetra
.664 .737 .904 r
.17513 .21933 .1836 .22817 .19573 .22348 .18729 .21458 Mtetra
.665 .737 .903 r
.18729 .21458 .19573 .22348 .20792 .21873 .19951 .20978 Mtetra
.665 .736 .903 r
.19951 .20978 .20792 .21873 .22017 .21394 .21179 .20494 Mtetra
.666 .736 .903 r
.21179 .20494 .22017 .21394 .23248 .2091 .22413 .20006 Mtetra
.666 .737 .903 r
.22413 .20006 .23248 .2091 .24485 .20422 .23653 .19515 Mtetra
.23653 .19515 .24485 .20422 .25727 .19931 .24899 .19021 Mtetra
.24899 .19021 .25727 .19931 .26976 .19438 .26151 .18525 Mtetra
.666 .738 .903 r
.26151 .18525 .26976 .19438 .2823 .18942 .27409 .18027 Mtetra
.666 .738 .904 r
.27409 .18027 .2823 .18942 .2949 .18444 .28672 .17527 Mtetra
.666 .739 .904 r
.28672 .17527 .2949 .18444 .30756 .17946 .29942 .17026 Mtetra
.665 .739 .905 r
.29942 .17026 .30756 .17946 .32028 .17446 .31217 .16524 Mtetra
.31217 .16524 .32028 .17446 .33306 .16945 .32499 .16021 Mtetra
.665 .74 .906 r
.32499 .16021 .33306 .16945 .3459 .16443 .33787 .15516 Mtetra
.33787 .15516 .3459 .16443 .3588 .1594 .3508 .1501 Mtetra
.664 .74 .907 r
.3508 .1501 .3588 .1594 .37176 .15435 .3638 .14502 Mtetra
.664 .741 .907 r
.3638 .14502 .37176 .15435 .38479 .14929 .37687 .13993 Mtetra
.37687 .13993 .38479 .14929 .39788 .14422 .39 .13481 Mtetra
.39 .13481 .39788 .14422 .41103 .13913 .40319 .12968 Mtetra
.664 .741 .908 r
.40319 .12968 .41103 .13913 .42424 .13401 .41644 .12452 Mtetra
.41644 .12452 .42424 .13401 .43752 .12888 .42976 .11935 Mtetra
.42976 .11935 .43752 .12888 .45087 .12372 .44315 .11415 Mtetra
.44315 .11415 .45087 .12372 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47012 .10367 Mtetra
.47012 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .08241 Mtetra
.52489 .08241 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.841 .617 .598 r
.01373 .40296 .0184 .44161 .02948 .44427 .03657 .32904 Mtetra
.689 .455 .563 r
.03657 .32904 .02948 .44427 .05357 .35971 .05636 .27227 Mtetra
.618 .403 .568 r
.05636 .27227 .05357 .35971 .07558 .286 .07066 .25052 Mtetra
.609 .455 .648 r
.07066 .25052 .07558 .286 .09093 .25643 .08282 .24312 Mtetra
.649 .636 .823 r
.08282 .24312 .09093 .25643 .10333 .24735 .09464 .23834 Mtetra
.66 .727 .899 r
.09464 .23834 .10333 .24735 .1152 .24241 .10649 .23378 Mtetra
.661 .738 .907 r
.10649 .23378 .1152 .24241 .12707 .23786 .11838 .22919 Mtetra
.662 .738 .907 r
.11838 .22919 .12707 .23786 .139 .2333 .13034 .22456 Mtetra
.662 .738 .906 r
.13034 .22456 .139 .2333 .15098 .22869 .14236 .21989 Mtetra
.663 .737 .905 r
.14236 .21989 .15098 .22869 .16302 .22403 .15444 .21518 Mtetra
.664 .737 .905 r
.15444 .21518 .16302 .22403 .17513 .21933 .16657 .21042 Mtetra
.664 .737 .904 r
.16657 .21042 .17513 .21933 .18729 .21458 .17877 .20561 Mtetra
.665 .737 .904 r
.17877 .20561 .18729 .21458 .19951 .20978 .19102 .20077 Mtetra
.665 .737 .903 r
.19102 .20077 .19951 .20978 .21179 .20494 .20334 .19589 Mtetra
.666 .737 .903 r
.20334 .19589 .21179 .20494 .22413 .20006 .21571 .19097 Mtetra
.21571 .19097 .22413 .20006 .23653 .19515 .22815 .18603 Mtetra
.666 .738 .903 r
.22815 .18603 .23653 .19515 .24899 .19021 .24064 .18106 Mtetra
.666 .738 .904 r
.24064 .18106 .24899 .19021 .26151 .18525 .25319 .17608 Mtetra
.25319 .17608 .26151 .18525 .27409 .18027 .2658 .17107 Mtetra
.666 .739 .905 r
.2658 .17107 .27409 .18027 .28672 .17527 .27847 .16605 Mtetra
.665 .739 .905 r
.27847 .16605 .28672 .17527 .29942 .17026 .2912 .16102 Mtetra
.665 .74 .906 r
.2912 .16102 .29942 .17026 .31217 .16524 .30399 .15597 Mtetra
.30399 .15597 .31217 .16524 .32499 .16021 .31684 .1509 Mtetra
.31684 .1509 .32499 .16021 .33787 .15516 .32976 .14582 Mtetra
.664 .74 .907 r
.32976 .14582 .33787 .15516 .3508 .1501 .34273 .14073 Mtetra
.664 .741 .907 r
.34273 .14073 .3508 .1501 .3638 .14502 .35577 .13561 Mtetra
.35577 .13561 .3638 .14502 .37687 .13993 .36888 .13048 Mtetra
.36888 .13048 .37687 .13993 .39 .13481 .38204 .12533 Mtetra
.664 .741 .908 r
.38204 .12533 .39 .13481 .40319 .12968 .39527 .12015 Mtetra
.39527 .12015 .40319 .12968 .41644 .12452 .40857 .11495 Mtetra
.40857 .11495 .41644 .12452 .42976 .11935 .42193 .10973 Mtetra
.42193 .10973 .42976 .11935 .44315 .11415 .43536 .10448 Mtetra
.43536 .10448 .44315 .11415 .4566 .10892 .44886 .09921 Mtetra
.44886 .09921 .4566 .10892 .47012 .10367 .46242 .09391 Mtetra
.46242 .09391 .47012 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.005 w
.0098 .04003 m
.03211 .0614 L
.0356 .06457 L
.0614 .08675 L
.06196 .0872 L
.0872 .10703 L
.09531 .113 L
.113 .12526 L
.13597 .1388 L
.1388 .14016 L
.15431 .1388 L
.1388 .11582 L
.13633 .113 L
.113 .08908 L
.11103 .0872 L
.0872 .06567 L
.08223 .0614 L
.0614 .04431 L
.05018 .0356 L
.0356 .02485 L
.012 .0098 L
s
.2936 .17872 m
.3194 .17619 L
.3452 .18124 L
.36981 .1904 L
.371 .19092 L
.3968 .20389 L
.41751 .2162 L
.4226 .21976 L
.4484 .2381 L
.45356 .242 L
.4742 .25875 L
.48475 .2678 L
.5 .28171 L
.51245 .2936 L
.5258 .30708 L
.5375 .3194 L
.5516 .33507 L
.56034 .3452 L
.5774 .36614 L
.58118 .371 L
.60022 .3968 L
.6032 .40103 L
.61747 .4226 L
.629 .44165 L
.63278 .4484 L
.6462 .4742 L
.6548 .49329 L
.65728 .5 L
.66585 .5258 L
.67092 .5516 L
.67082 .5774 L
.65905 .6032 L
.6548 .60686 L
.629 .61632 L
.6032 .61431 L
.5774 .60662 L
.5674 .6032 L
.5516 .59517 L
.5258 .58057 L
.52059 .5774 L
.5 .56344 L
.48387 .5516 L
.4742 .54387 L
.45265 .5258 L
.4484 .52198 L
.42486 .5 L
.4226 .49777 L
.39968 .4742 L
.3968 .47108 L
.37671 .4484 L
Mistroke
.371 .4416 L
.35573 .4226 L
.3452 .40869 L
.33664 .3968 L
.31941 .371 L
.3194 .37099 L
.30389 .3452 L
.2936 .32594 L
.29048 .3194 L
.27915 .2936 L
.27058 .2678 L
.2678 .25602 L
.26546 .242 L
.26547 .2162 L
.2678 .20628 L
.27333 .1904 L
.2936 .17872 L
Mfstroke
.7064 .69028 m
.72532 .7064 L
.7322 .71269 L
.75256 .7322 L
.758 .73759 L
.77799 .758 L
.7838 .76409 L
.80216 .7838 L
.8096 .79198 L
.82523 .8096 L
.8354 .82139 L
.84712 .8354 L
.8612 .85301 L
.86742 .8612 L
.8612 .88022 L
.8397 .8612 L
.8354 .85716 L
.81307 .8354 L
.8096 .8319 L
.78802 .8096 L
.7838 .80512 L
.76415 .7838 L
.758 .77694 L
.74139 .758 L
.7322 .74718 L
.71988 .7322 L
.7064 .71491 L
.70018 .7064 L
.7064 .69028 L
s
0 g
.03 w
.0669 .06997 Mdot
.46804 .39622 Mdot
.78637 .78733 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.86275 .04706 Mdot
.71765 .09412 Mdot
.4902 .29804 Mdot
.43137 .22745 Mdot
.52549 .36471 Mdot
.72157 .10588 Mdot
.40784 .27843 Mdot
.42745 .31765 Mdot
.72157 .10588 Mdot
.25098 .17255 Mdot
.05098 .03137 Mdot
.48235 .31373 Mdot
.49412 .32157 Mdot
.07451 .0549 Mdot
.24706 .24314 Mdot
.42745 .19216 Mdot
.07059 .01569 Mdot
.08235 .05882 Mdot
.06275 .07059 Mdot
.43137 .2 Mdot
.01569 .00392 Mdot
.08235 .07059 Mdot
.02745 .02745 Mdot
.49804 .32941 Mdot
.01569 0 Mdot
.03529 .04706 Mdot
.02745 .02353 Mdot
.83137 .8 Mdot
.39216 .28235 Mdot
.01569 .02353 Mdot
.16863 .13725 Mdot
.01176 .01569 Mdot
.45882 .25882 Mdot
.01961 .02353 Mdot
.02745 .04314 Mdot
.03529 .03529 Mdot
.80392 .79216 Mdot
.40392 .27059 Mdot
.00784 .02353 Mdot
.0549 .03922 Mdot
.03529 .03137 Mdot
.65098 .61961 Mdot
.06667 .02745 Mdot
.02745 .03529 Mdot
.07059 .0549 Mdot
.04314 .04314 Mdot
.74118 .72157 Mdot
.0549 .02353 Mdot
.01569 .01961 Mdot
.06667 .05098 Mdot
.03922 .03529 Mdot
.82353 .80392 Mdot
.18039 .08627 Mdot
.01569 .02353 Mdot
.06275 .05098 Mdot
.51373 .46275 Mdot
.73725 .71373 Mdot
.84706 .04706 Mdot
.01569 .02353 Mdot
.03922 .03529 Mdot
.7451 .69412 Mdot
.02353 .01961 Mdot
.81176 .82353 Mdot
.01176 .02353 Mdot
.02745 .03529 Mdot
.11765 .09412 Mdot
.87451 .84706 Mdot
.84314 .82353 Mdot
.32941 .06275 Mdot
.01961 .01569 Mdot
.03922 .05098 Mdot
.90196 .89804 Mdot
.06275 .06275 Mdot
.83529 .84706 Mdot
0 0 Mdot
.02353 .02353 Mdot
.07059 .05098 Mdot
.89804 .90588 Mdot
.05882 .07843 Mdot
.81176 .82745 Mdot
.00784 .01176 Mdot
.01569 .02353 Mdot
.76078 .70196 Mdot
.90196 .90588 Mdot
.83137 .83529 Mdot
.62353 .59216 Mdot
0 .01176 Mdot
.02353 .03137 Mdot
.8902 .87843 Mdot
.88235 .88235 Mdot
.68235 .65098 Mdot
.6 .51765 Mdot
.01961 .01961 Mdot
.02745 .03529 Mdot
.8902 .87843 Mdot
.88235 .88627 Mdot
.67059 .62353 Mdot
.54902 .48627 Mdot
.05098 .05098 Mdot
.02353 .02745 Mdot
.89804 .89412 Mdot
.88235 .88235 Mdot
.11373 .10196 Mdot
.75686 .72549 Mdot
.0549 .03529 Mdot
.02353 .02745 Mdot
.8902 .87843 Mdot
.87451 .88627 Mdot
.01961 .03137 Mdot
.81569 .83137 Mdot
.08627 .03922 Mdot
.02353 .02745 Mdot
.86667 .86667 Mdot
.87843 .88235 Mdot
.04314 .04314 Mdot
.81569 .82745 Mdot
.00784 .00784 Mdot
.01176 .01176 Mdot
.75294 .67059 Mdot
.82745 .81961 Mdot
.85098 .84706 Mdot
.78431 .77255 Mdot
.00392 .01176 Mdot
.0549 .04706 Mdot
.07059 .06667 Mdot
.87451 .86275 Mdot
.86667 .86667 Mdot
.75294 .71373 Mdot
.14902 .08235 Mdot
.04314 .03137 Mdot
.02745 .03922 Mdot
.88627 .87843 Mdot
.05882 .06667 Mdot
.06275 .06667 Mdot
.83137 .84314 Mdot
.03529 .03529 Mdot
.05098 .04314 Mdot
.85098 .83137 Mdot
.07451 .07843 Mdot
.8549 .8549 Mdot
.80784 .79608 Mdot
.09412 0 Mdot
.04314 .03529 Mdot
.02745 .03137 Mdot
.78824 .78431 Mdot
.03922 .04314 Mdot
.02745 .03137 Mdot
.77255 .78431 Mdot
.02353 .02353 Mdot
.0549 .03922 Mdot
.84314 .83529 Mdot
.05098 .05882 Mdot
.84706 .84706 Mdot
.70196 .67059 Mdot
.1098 .00784 Mdot
.04314 .04314 Mdot
.02745 .02353 Mdot
.18824 .18824 Mdot
.03529 .03137 Mdot
.03922 .03922 Mdot
.81961 .83137 Mdot
.02353 .03137 Mdot
.05098 .03922 Mdot
.85098 .84706 Mdot
.07059 .05882 Mdot
.82745 .80392 Mdot
.72941 .69412 Mdot
.28627 .18824 Mdot
.03922 .03922 Mdot
.07843 .05882 Mdot
.0902 .0902 Mdot
.03922 .04314 Mdot
.19216 .1451 Mdot
.81569 .82745 Mdot
.00784 .01569 Mdot
.05098 .04314 Mdot
.83922 .83922 Mdot
.07843 .06667 Mdot
.00392 .00784 Mdot
.33725 .32549 Mdot
.47843 .47059 Mdot
.01569 .02353 Mdot
.06275 .04314 Mdot
.41961 .41961 Mdot
.03137 .02353 Mdot
.84314 .84314 Mdot
.62353 .60784 Mdot
.14118 .13333 Mdot
.04706 .04314 Mdot
.74118 .7098 Mdot
.07059 .05882 Mdot
.03922 .03137 Mdot
.15686 .13333 Mdot
.75294 .76471 Mdot
.00392 .01176 Mdot
.05882 .03922 Mdot
.85098 .8549 Mdot
.66275 .60784 Mdot
.00784 .00392 Mdot
.17647 .18431 Mdot
.29412 .27451 Mdot
.01176 .02745 Mdot
.07059 .05098 Mdot
.0549 .05882 Mdot
.84706 .8 Mdot
.61961 .58431 Mdot
.65882 .64314 Mdot
.62745 .63529 Mdot
.04314 .03529 Mdot
.88627 .88627 Mdot
.08235 .03922 Mdot
.04314 .04314 Mdot
.06667 .0549 Mdot
.77255 .78039 Mdot
.00784 .02353 Mdot
.04706 .03529 Mdot
.6549 .62353 Mdot
.88627 .87451 Mdot
.00784 .01569 Mdot
.22353 .21176 Mdot
.45098 .44314 Mdot
.00784 .02745 Mdot
.07059 .0549 Mdot
.05098 .0549 Mdot
.87843 .88235 Mdot
.77647 .75686 Mdot
.66275 .64314 Mdot
.48235 .50196 Mdot
.03922 .04314 Mdot
.88235 .89412 Mdot
.85098 .81569 Mdot
.23922 .19608 Mdot
.03529 .04706 Mdot
.80784 .81961 Mdot
.00392 .00392 Mdot
.04706 .03922 Mdot
.12157 .09412 Mdot
.87843 .86667 Mdot
.02353 .02745 Mdot
.01569 .02745 Mdot
.60784 .61569 Mdot
.00392 .02745 Mdot
.07451 .05882 Mdot
.11373 .09412 Mdot
.87451 .87059 Mdot
.83529 .83137 Mdot
.68627 .67451 Mdot
.75294 .72549 Mdot
.04706 .06275 Mdot
.88235 .8902 Mdot
.88235 .86275 Mdot
.52941 .48627 Mdot
.04706 .04706 Mdot
.83529 .84314 Mdot
.00784 .01961 Mdot
.04706 .04706 Mdot
.07843 .05882 Mdot
.88235 .87843 Mdot
.02353 .02353 Mdot
.04706 .05098 Mdot
.57647 .58039 Mdot
.00784 .01176 Mdot
.0902 .06275 Mdot
.25882 .20784 Mdot
.80784 .77647 Mdot
.81176 .80392 Mdot
.23137 .21961 Mdot
.6549 .27059 Mdot
.03137 .0549 Mdot
.85882 .86667 Mdot
.86667 .86275 Mdot
.23529 .21961 Mdot
0 .00392 Mdot
.82353 .83529 Mdot
.01176 .01569 Mdot
.05882 .07059 Mdot
.05882 .04706 Mdot
.19608 .18431 Mdot
.02353 .02353 Mdot
.02353 .02745 Mdot
.83137 .86667 Mdot
0 0 Mdot
.05098 .03529 Mdot
.17647 .1451 Mdot
.08235 .03922 Mdot
.55686 .47451 Mdot
.03529 .05098 Mdot
.21176 .22353 Mdot
.01176 .01176 Mdot
.87843 .8902 Mdot
.85098 .85098 Mdot
.71373 .68627 Mdot
.03922 .03529 Mdot
.61961 .61176 Mdot
.36863 .35686 Mdot
.03529 .04706 Mdot
.06275 .04314 Mdot
.10588 .08627 Mdot
.03922 .05098 Mdot
0 .01176 Mdot
.81961 .83529 Mdot
.01176 .00784 Mdot
.04314 .04706 Mdot
.08627 .06667 Mdot
.07059 .03922 Mdot
.03137 .02353 Mdot
.02353 .02745 Mdot
.7451 .76863 Mdot
.00392 .00392 Mdot
.5451 .49412 Mdot
.84314 .83922 Mdot
.82353 .82353 Mdot
.80392 .79216 Mdot
.01961 .01569 Mdot
.34118 .24706 Mdot
.00784 .02353 Mdot
.22353 .2 Mdot
.85882 .83922 Mdot
.04706 .0549 Mdot
.00392 .01961 Mdot
.63137 .61569 Mdot
.28627 .31373 Mdot
.03137 .04314 Mdot
.04314 .04314 Mdot
.17255 .11373 Mdot
.02745 .03529 Mdot
.00784 .01176 Mdot
.77255 .80392 Mdot
0 0 Mdot
.06275 .04706 Mdot
.84314 .82745 Mdot
.86275 .85098 Mdot
.50588 .44314 Mdot
.03137 .03529 Mdot
.56471 .6 Mdot
.00392 0 Mdot
.87843 .8902 Mdot
.14118 .11373 Mdot
.04314 .03137 Mdot
.03137 .03137 Mdot
.03529 .04314 Mdot
.73725 .14118 Mdot
0 .01961 Mdot
.61569 .55686 Mdot
.87059 .84706 Mdot
.07451 .07843 Mdot
.00392 .01176 Mdot
.60392 .60392 Mdot
.00392 .00392 Mdot
.03529 .03922 Mdot
.4 .31373 Mdot
.73333 .72157 Mdot
.03137 .02745 Mdot
.00392 .01176 Mdot
.83137 .8549 Mdot
.00392 .00392 Mdot
.68235 .65098 Mdot
.2902 .24706 Mdot
.81569 .77647 Mdot
.81569 .81176 Mdot
.01961 .02353 Mdot
.53333 .5451 Mdot
.00392 .00392 Mdot
.13333 .08235 Mdot
.76471 .71765 Mdot
.8549 .85098 Mdot
.00784 .02353 Mdot
.02745 .03922 Mdot
.36863 .37647 Mdot
.01176 .03137 Mdot
.84314 .83922 Mdot
.82353 .79216 Mdot
.07843 .06275 Mdot
.01569 .03137 Mdot
.6549 .65882 Mdot
.00392 .00392 Mdot
.05098 .04314 Mdot
.80392 .78431 Mdot
.86667 .86275 Mdot
.45098 .36863 Mdot
.00392 .01961 Mdot
.78431 .82745 Mdot
.00392 .00392 Mdot
.8 .80784 Mdot
.84314 .85098 Mdot
.85882 .85882 Mdot
.09412 .06275 Mdot
.01569 .02353 Mdot
.59216 .56078 Mdot
0 0 Mdot
.80784 .81569 Mdot
.78431 .72157 Mdot
.85098 .8549 Mdot
.00784 .01961 Mdot
.0549 .07451 Mdot
.11765 .11765 Mdot
.01176 .03137 Mdot
.04706 .04314 Mdot
.90196 .9098 Mdot
.05098 .0549 Mdot
.00392 .00784 Mdot
.69804 .70588 Mdot
0 0 Mdot
.04706 .03922 Mdot
.08627 .07451 Mdot
.86275 .85882 Mdot
.82745 .82745 Mdot
0 .01961 Mdot
.78431 .82353 Mdot
0 .00392 Mdot
.18824 .18039 Mdot
.08235 .05098 Mdot
.8 .78824 Mdot
.01961 .02745 Mdot
.02353 .03922 Mdot
.68627 .05882 Mdot
.01569 .02745 Mdot
.05882 .04706 Mdot
.8902 .8902 Mdot
.82745 .83137 Mdot
.00784 .01961 Mdot
.04314 .04706 Mdot
0 0 Mdot
.01176 .01961 Mdot
.05098 .0549 Mdot
.77647 .79216 Mdot
.20392 .1451 Mdot
.00392 .01569 Mdot
.78431 .81569 Mdot
.00392 .00392 Mdot
.05882 .03529 Mdot
.08235 .06667 Mdot
.09412 .08235 Mdot
.80392 .81176 Mdot
.00392 .01569 Mdot
.49412 .52549 Mdot
.00392 .01569 Mdot
.03137 .03137 Mdot
.8549 .8549 Mdot
.84314 .81961 Mdot
.00784 .01961 Mdot
.03529 .04706 Mdot
.4 .36471 Mdot
.03922 .03922 Mdot
.04706 .04706 Mdot
.38431 .4 Mdot
.06667 .05882 Mdot
.00392 .01176 Mdot
.55294 .51765 Mdot
0 .00392 Mdot
.00784 .01961 Mdot
.05098 .04314 Mdot
.08235 .07059 Mdot
.82353 .80392 Mdot
.00784 .02353 Mdot
.82745 .85882 Mdot
.00392 .01961 Mdot
.04314 .03529 Mdot
.85098 .8549 Mdot
.27451 .22353 Mdot
.37647 .35686 Mdot
.00784 .02353 Mdot
.4 .39608 Mdot
0 .01176 Mdot
.05098 .04314 Mdot
.23922 .23529 Mdot
.19608 .18824 Mdot
.00392 .01176 Mdot
.04706 .05098 Mdot
.08627 .08627 Mdot
.03137 .04706 Mdot
.03922 .04706 Mdot
.08235 .0549 Mdot
.0549 .0549 Mdot
.00392 .00784 Mdot
.41961 .40392 Mdot
0 .00392 Mdot
.01176 .01569 Mdot
.82745 .80392 Mdot
.07451 .04706 Mdot
.81176 .82353 Mdot
0 .01569 Mdot
.74902 .78039 Mdot
.00392 .01961 Mdot
.0549 .04706 Mdot
.36078 .35686 Mdot
.77255 .75686 Mdot
.22745 .19608 Mdot
.03922 .04706 Mdot
.67843 .07451 Mdot
.36471 .36863 Mdot
.04706 .05098 Mdot
.15294 .12941 Mdot
.42353 .38824 Mdot
.00392 .01176 Mdot
.05882 .06275 Mdot
.00784 .00392 Mdot
.01569 .01961 Mdot
.25882 .21176 Mdot
.04706 .02353 Mdot
.51373 .47059 Mdot
.00392 .01569 Mdot
.63137 .63529 Mdot
.01176 .02745 Mdot
.01961 .02353 Mdot
.77647 .77255 Mdot
.87843 .87843 Mdot
.81961 .82745 Mdot
.00784 .02353 Mdot
.64706 .67843 Mdot
0 .00784 Mdot
.03529 .03922 Mdot
.84706 .85098 Mdot
.84706 .85098 Mdot
.63922 .62353 Mdot
.05098 .05098 Mdot
.70588 .74902 Mdot
.01176 .04314 Mdot
.01569 .01961 Mdot
.08235 .06275 Mdot
.47843 .47059 Mdot
.00392 .01176 Mdot
.16078 .15686 Mdot
.01176 .01569 Mdot
.01569 .02745 Mdot
.83529 .81176 Mdot
.85882 .86275 Mdot
.83529 .83529 Mdot
.00392 .01569 Mdot
.66275 .68235 Mdot
.00392 .00784 Mdot
.01569 .02745 Mdot
.82353 .80392 Mdot
.85882 .8549 Mdot
.81961 .83137 Mdot
.00392 .00784 Mdot
.33333 .3451 Mdot
.00784 .01176 Mdot
.01961 .01961 Mdot
.16863 .11765 Mdot
.84706 .85098 Mdot
.0902 .08627 Mdot
.06667 .07451 Mdot
.7098 .74902 Mdot
.01569 .01961 Mdot
.03137 .04314 Mdot
.86275 .86667 Mdot
.07059 .07059 Mdot
0 .00392 Mdot
.04706 .0549 Mdot
.00392 .00392 Mdot
.01176 .01961 Mdot
.13333 .13333 Mdot
.84706 .8549 Mdot
.76471 .74902 Mdot
.00392 .00784 Mdot
.6902 .7098 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.16078 .17255 Mdot
.22745 .24314 Mdot
.83137 .83529 Mdot
.00392 .00392 Mdot
.51373 .53725 Mdot
.00392 .01176 Mdot
.01569 .02353 Mdot
.79216 .76078 Mdot
.84706 .86275 Mdot
.04314 .03529 Mdot
.02353 .04706 Mdot
.45098 .43137 Mdot
.01176 .02353 Mdot
.02353 .03922 Mdot
.85098 .85098 Mdot
.04314 .03137 Mdot
.00392 .00392 Mdot
.04706 .05882 Mdot
.00392 .00784 Mdot
.01961 .02745 Mdot
.03529 .03922 Mdot
.21176 .23137 Mdot
.04314 .05882 Mdot
.01176 .01569 Mdot
.07451 .0902 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.08235 .0902 Mdot
.65882 .61569 Mdot
.82353 .82353 Mdot
.00392 .00784 Mdot
.76863 .82353 Mdot
.00392 .00392 Mdot
.01569 .02745 Mdot
.83529 .84706 Mdot
.84706 .84706 Mdot
.5098 .5098 Mdot
.70196 .70196 Mdot
.60784 .0549 Mdot
.00784 .01569 Mdot
.03529 .05882 Mdot
.7451 .75686 Mdot
.84706 .84706 Mdot
.00392 .01176 Mdot
.03137 .0549 Mdot
.08235 .1098 Mdot
.01176 .03922 Mdot
.03529 .04314 Mdot
.09804 .06667 Mdot
.07059 .07843 Mdot
0 .00392 Mdot
.03529 .06275 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.06275 .04706 Mdot
.86667 .87451 Mdot
.05882 .05882 Mdot
.00392 .00392 Mdot
.76471 .80392 Mdot
0 0 Mdot
.00784 .02745 Mdot
.84314 .85098 Mdot
.85098 .86275 Mdot
.81569 .81569 Mdot
.00392 .00784 Mdot
.50588 .53333 Mdot
.00784 .02353 Mdot
.01569 .02745 Mdot
.12941 .12941 Mdot
.83529 .84314 Mdot
.01961 .02745 Mdot
0 .01176 Mdot
.36078 .4 Mdot
.00784 .03529 Mdot
.02745 .03137 Mdot
.8549 .83529 Mdot
.07843 .09804 Mdot
.00784 .01569 Mdot
.01569 .04314 Mdot
.00392 0 Mdot
.01176 .03529 Mdot
.51373 .46667 Mdot
.86667 .87059 Mdot
.04314 .06275 Mdot
.00392 .01176 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .01569 Mdot
.84314 .8549 Mdot
.37647 .39608 Mdot
.05882 .06667 Mdot
.00392 .00784 Mdot
.81569 .87059 Mdot
.00784 .01176 Mdot
.00784 .03137 Mdot
.67843 .64706 Mdot
.85098 .85882 Mdot
.81176 .81176 Mdot
0 .01176 Mdot
.41176 .05098 Mdot
.00784 .02353 Mdot
.03529 .04314 Mdot
.8549 .86275 Mdot
.06667 .07059 Mdot
.00392 .01176 Mdot
.01569 .05098 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.06667 .04314 Mdot
.68235 .69804 Mdot
.03137 .05098 Mdot
.00392 .01176 Mdot
.02745 .05098 Mdot
0 .00392 Mdot
.01176 .02745 Mdot
.83137 .83922 Mdot
.61176 .58824 Mdot
.02745 .05882 Mdot
.00392 .01961 Mdot
.79608 .82353 Mdot
.00784 .00784 Mdot
.00392 .02745 Mdot
.84706 .84314 Mdot
.49412 .51373 Mdot
.03529 .05098 Mdot
.00392 .01961 Mdot
.41961 .42353 Mdot
0 .01176 Mdot
.02353 .03529 Mdot
.83922 .85098 Mdot
.06275 .07451 Mdot
.55294 .55686 Mdot
.00392 .02353 Mdot
.00784 .00784 Mdot
.00392 .02353 Mdot
.03922 .03529 Mdot
.14118 .12941 Mdot
.04706 .06667 Mdot
.00392 .01569 Mdot
.00784 .03922 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.69804 .67843 Mdot
.85882 .8549 Mdot
.07059 .08235 Mdot
.00392 .00784 Mdot
.03922 .0549 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.84706 .86275 Mdot
.08627 .10196 Mdot
.03529 .0549 Mdot
0 .00392 Mdot
.52157 .56863 Mdot
.00392 .00784 Mdot
.02353 .02745 Mdot
.14118 .15686 Mdot
.02353 .02353 Mdot
.02745 .04314 Mdot
0 .02353 Mdot
.01176 0 Mdot
.00392 .01569 Mdot
.03922 .04706 Mdot
.08627 .0902 Mdot
.6 .57255 Mdot
.01569 .03529 Mdot
.01961 .03922 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.15294 .13725 Mdot
.25882 .28627 Mdot
.79608 .77647 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.00392 .01176 Mdot
.00392 .01961 Mdot
.56471 .59608 Mdot
.0549 .04706 Mdot
.76471 .75294 Mdot
.00392 .00392 Mdot
.56863 .59216 Mdot
.00392 .00392 Mdot
.02745 .04314 Mdot
.21961 .21569 Mdot
.85098 .85882 Mdot
.06275 .05098 Mdot
.00392 .01176 Mdot
.28235 .26667 Mdot
.00784 .01569 Mdot
.04314 .05882 Mdot
.07059 .08627 Mdot
.83922 .8549 Mdot
.01176 .02745 Mdot
.01176 .03137 Mdot
.00392 0 Mdot
.00392 .01961 Mdot
.04706 .06667 Mdot
.01176 .01176 Mdot
.83137 .84706 Mdot
0 .00784 Mdot
.00392 .03529 Mdot
.00784 .00392 Mdot
.00392 .00784 Mdot
.05882 .04314 Mdot
.87843 .86667 Mdot
.83922 .83922 Mdot
0 .01176 Mdot
.04706 .05098 Mdot
.00392 .00784 Mdot
.00784 .02745 Mdot
.84706 .8549 Mdot
.85882 .87059 Mdot
.81569 .82745 Mdot
0 .00392 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.02353 .03922 Mdot
.10588 .11765 Mdot
.8549 .86667 Mdot
.34902 .32941 Mdot
0 .01176 Mdot
.00392 .00784 Mdot
.00392 .00784 Mdot
.04314 .05098 Mdot
.82745 .81961 Mdot
.83529 .84314 Mdot
0 .01569 Mdot
.00392 .02745 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.54902 .54118 Mdot
.87843 .8902 Mdot
.82353 .84314 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.00392 .00392 Mdot
.00784 .02353 Mdot
.85098 .86275 Mdot
.87451 .87843 Mdot
.83137 .84314 Mdot
.00392 .01569 Mdot
.53725 .54902 Mdot
0 0 Mdot
.01176 .03137 Mdot
.34902 .31765 Mdot
.72941 .76471 Mdot
.81961 .82745 Mdot
.00392 .03137 Mdot
.55294 .03137 Mdot
.00392 .01569 Mdot
.03137 .04706 Mdot
.87059 .88235 Mdot
.11765 .13725 Mdot
.10588 .11373 Mdot
.02353 .05098 Mdot
.01569 .00784 Mdot
.00784 .01961 Mdot
.04314 .06667 Mdot
.8902 .90588 Mdot
.03137 .05098 Mdot
.01176 .01961 Mdot
.00392 .02745 Mdot
0 0 Mdot
.00784 .00392 Mdot
.0549 .07059 Mdot
.86667 .87843 Mdot
.36863 .33725 Mdot
.02353 .03922 Mdot
.00392 .02745 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.50196 .52157 Mdot
.66275 .70588 Mdot
.09412 .1098 Mdot
.00392 .02745 Mdot
0 .01569 Mdot
.01176 .00784 Mdot
.00392 .00784 Mdot
.38039 .36078 Mdot
.11373 .13333 Mdot
.03529 .04706 Mdot
.01176 .04314 Mdot
.56078 .56863 Mdot
0 .00392 Mdot
.00784 .02745 Mdot
.90196 .90588 Mdot
.42745 .41961 Mdot
.64314 .63137 Mdot
.00784 .03137 Mdot
.12549 .11765 Mdot
.00784 .01569 Mdot
.01961 .03529 Mdot
.8902 .89804 Mdot
.87059 .87059 Mdot
.83137 .83137 Mdot
.01961 .03922 Mdot
.56078 .02353 Mdot
.00392 .01569 Mdot
.03137 .0549 Mdot
.88235 .89412 Mdot
.85098 .85882 Mdot
.08235 .09804 Mdot
0 .00392 Mdot
.00784 .00392 Mdot
0 0 Mdot
.03529 .0549 Mdot
.27451 .31765 Mdot
.6902 .7098 Mdot
.00784 .04314 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.0902 .10588 Mdot
.07451 .09412 Mdot
.03922 .0549 Mdot
.00392 .03529 Mdot
.01176 .03529 Mdot
0 .00392 Mdot
.00784 .01569 Mdot
.84706 .85098 Mdot
.14902 .14118 Mdot
.03137 .05098 Mdot
.00784 .04314 Mdot
.00392 .02745 Mdot
0 .00392 Mdot
0 .00784 Mdot
.85882 .87059 Mdot
.86275 .87843 Mdot
.37647 .34902 Mdot
.00392 .03137 Mdot
.23529 .25098 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.87451 .88235 Mdot
.85098 .86275 Mdot
.81961 .84314 Mdot
.00392 .02745 Mdot
.4 .40784 Mdot
.00392 .01176 Mdot
0 .00784 Mdot
.27059 .31373 Mdot
.64706 .6902 Mdot
.07451 .10196 Mdot
.01569 .04314 Mdot
.05098 .01961 Mdot
.00784 .01176 Mdot
.00784 .03922 Mdot
.08235 .08235 Mdot
.05882 .09412 Mdot
.01569 .03922 Mdot
.02353 .04314 Mdot
.03529 0 Mdot
.00392 .01176 Mdot
.01961 .02353 Mdot
.07843 .08627 Mdot
.06667 .09412 Mdot
0 .01961 Mdot
.03922 .06275 Mdot
.00392 .00392 Mdot
0 .02353 Mdot
.83137 .83922 Mdot
.50196 .5098 Mdot
.38824 .38039 Mdot
.00392 .01961 Mdot
.02353 .05098 Mdot
.00392 .00392 Mdot
.02745 .04706 Mdot
.83922 .8549 Mdot
.86667 .87059 Mdot
.85098 .86275 Mdot
.00392 .01961 Mdot
.00392 .03137 Mdot
.00784 .00784 Mdot
.01569 .03137 Mdot
.64314 .67059 Mdot
.7098 .72549 Mdot
.22745 .27451 Mdot
.00784 .03137 Mdot
.02353 .03922 Mdot
.01176 .01176 Mdot
.00392 .01176 Mdot
.06667 .08235 Mdot
.01569 .03137 Mdot
.02353 .03529 Mdot
.00784 .02745 Mdot
.34902 .35294 Mdot
0 0 Mdot
.00392 .01569 Mdot
.07059 .08235 Mdot
.44314 .42353 Mdot
.21961 .20784 Mdot
.00392 .03137 Mdot
.00392 .00392 Mdot
.00392 .00392 Mdot
.03137 .03137 Mdot
.08235 .10196 Mdot
.83529 .84314 Mdot
.01569 .01176 Mdot
.01176 .03137 Mdot
.59216 .01176 Mdot
.01176 .03922 Mdot
.81961 .81961 Mdot
.04706 .07451 Mdot
.82353 .8549 Mdot
.02745 .05882 Mdot
.03529 .04706 Mdot
0 .00392 Mdot
.00784 .03922 Mdot
.82745 .83922 Mdot
.05882 .07451 Mdot
.40784 .41961 Mdot
.00392 .03529 Mdot
.04314 .06667 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18824 .21569 Mdot
.22353 .27059 Mdot
.85098 .85882 Mdot
.00392 .02353 Mdot
.00392 .03529 Mdot
.00392 .00392 Mdot
.00784 .03529 Mdot
.01176 .02353 Mdot
.36471 .41176 Mdot
.84706 .85098 Mdot
.01176 .02745 Mdot
.00784 .01961 Mdot
.01176 .00784 Mdot
.01569 .02745 Mdot
.76471 .73333 Mdot
.12157 .17647 Mdot
.83137 .84314 Mdot
.00392 .02745 Mdot
.38431 .38824 Mdot
.00392 .00392 Mdot
.06275 .06667 Mdot
.86275 .88235 Mdot
.03137 .05098 Mdot
.83922 .84706 Mdot
.01176 .03137 Mdot
0 0 Mdot
.00784 .02353 Mdot
.80784 .79608 Mdot
.8549 .87059 Mdot
.72941 .71765 Mdot
.84314 .8549 Mdot
.01569 .03922 Mdot
.03922 .01569 Mdot
.28627 .3098 Mdot
.81961 .82745 Mdot
.6549 .66667 Mdot
.85098 .8549 Mdot
.67059 .6902 Mdot
.01961 .04314 Mdot
.00392 .00392 Mdot
.03529 .06275 Mdot
.11373 .11765 Mdot
.06667 .07451 Mdot
.85098 .85882 Mdot
.01961 .05098 Mdot
.01961 .03529 Mdot
.1098 .11373 Mdot
.00392 .02745 Mdot
.76078 .75686 Mdot
.06667 .08627 Mdot
.80784 .83922 Mdot
0 .02745 Mdot
.00784 .03529 Mdot
.00392 .00392 Mdot
.01176 .04314 Mdot
.51373 .55294 Mdot
.06275 .07843 Mdot
.1098 .15686 Mdot
.01176 .03529 Mdot
0 .02353 Mdot
.00392 .00784 Mdot
.01961 .03529 Mdot
.05882 .07843 Mdot
.62745 .61961 Mdot
.06667 .09804 Mdot
0 .01569 Mdot
.45098 .46275 Mdot
0 .00392 Mdot
.31765 .30196 Mdot
.36863 .36078 Mdot
.87059 .87843 Mdot
.76471 .76078 Mdot
0 .01569 Mdot
.00392 .00392 Mdot
0 .00784 Mdot
.83137 .83922 Mdot
.86275 .87843 Mdot
.86667 .87059 Mdot
.79608 .81569 Mdot
.00392 .01569 Mdot
0 .00784 Mdot
.00392 .01961 Mdot
.08627 .07059 Mdot
.08627 .10588 Mdot
.40784 .45882 Mdot
.03137 .0549 Mdot
.00392 .01569 Mdot
.12157 .03137 Mdot
.00784 .02353 Mdot
.83137 .83529 Mdot
.06275 .08627 Mdot
.09412 .12157 Mdot
.00784 .02745 Mdot
.00784 .03137 Mdot
.00392 .00392 Mdot
.02353 .04314 Mdot
.07059 .09412 Mdot
.07843 .0902 Mdot
.06275 .07451 Mdot
.00784 .03529 Mdot
.00392 .03137 Mdot
.00392 0 Mdot
.00784 .02353 Mdot
.01176 .01961 Mdot
.3098 .3098 Mdot
.20784 .18824 Mdot
.00392 .02745 Mdot
.00784 .03529 Mdot
0 .00392 Mdot
.01176 .03529 Mdot
.62745 .61176 Mdot
.85882 .86667 Mdot
.84314 .82745 Mdot
.00784 .04314 Mdot
.03137 .03922 Mdot
0 0 Mdot
.01961 .03922 Mdot
.85098 .86275 Mdot
.8549 .87451 Mdot
.7098 .75294 Mdot
.00392 .02353 Mdot
.10196 .11373 Mdot
.00784 .00784 Mdot
.41569 .42353 Mdot
.19608 .24314 Mdot
.14902 .2 Mdot
.06667 .10588 Mdot
0 .00784 Mdot
0 0 Mdot
.00392 .01176 Mdot
.81569 .81961 Mdot
.0549 .06275 Mdot
.05098 .07451 Mdot
.05098 .07843 Mdot
0 .01569 Mdot
0 .00392 Mdot
.00392 .00784 Mdot
.76471 .76863 Mdot
.0549 .06667 Mdot
.12157 .12549 Mdot
0 .00784 Mdot
.00392 .01176 Mdot
.01569 .01569 Mdot
.00392 .01569 Mdot
.82745 .83529 Mdot
.0549 .05882 Mdot
.73725 .73333 Mdot
0 .00784 Mdot
0 .01176 Mdot
.00392 .00392 Mdot
.00392 .01961 Mdot
.80392 .79216 Mdot
.03529 .0549 Mdot
.86667 .87059 Mdot
.00392 .01569 Mdot
.00392 .02353 Mdot
.16078 .03137 Mdot
0 .01961 Mdot
.81176 .83529 Mdot
.0549 .07843 Mdot
.84314 .84706 Mdot
.03137 .05098 Mdot
.00392 .03137 Mdot
.00784 0 Mdot
.00784 .03137 Mdot
.16471 .20392 Mdot
.0549 .07451 Mdot
.74118 .7451 Mdot
.01176 .03529 Mdot
.00392 .02353 Mdot
.00392 0 Mdot
.01176 .03922 Mdot
.03529 .06667 Mdot
.06667 .09804 Mdot
.82353 .82353 Mdot
0 .01569 Mdot
.00392 .03137 Mdot
0 0 Mdot
.01176 .04314 Mdot
.03137 .05882 Mdot
.07059 .11765 Mdot
.85098 .8549 Mdot
0 .01569 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .02745 Mdot
.05098 .07451 Mdot
.05882 .10196 Mdot
.8549 .86275 Mdot
.00392 .02745 Mdot
.07843 .08235 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.04314 .06275 Mdot
.06275 .08235 Mdot
.85882 .86667 Mdot
.00784 .02745 Mdot
0 .00392 Mdot
.00784 .01176 Mdot
.31373 .3098 Mdot
.04706 .05882 Mdot
.24706 .2549 Mdot
.85882 .86667 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
0 .00392 Mdot
.83137 .83137 Mdot
.04706 .06667 Mdot
.86667 .87059 Mdot
.8549 .86275 Mdot
.01176 .03137 Mdot
.01176 .01961 Mdot
.00392 .01176 Mdot
.82353 .82745 Mdot
.05098 .07059 Mdot
.87059 .87451 Mdot
.8549 .86275 Mdot
.01569 .03529 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.80392 .80392 Mdot
.05882 .07059 Mdot
.87059 .87843 Mdot
.8549 .86275 Mdot
.00784 .03137 Mdot
0 0 Mdot
0 .01961 Mdot
.14118 .14118 Mdot
.05098 .06667 Mdot
.87059 .87843 Mdot
.63922 .66275 Mdot
.01176 .04314 Mdot
.12157 .00784 Mdot
.00392 .02745 Mdot
.03922 .0549 Mdot
.07451 .10196 Mdot
.76471 .79608 Mdot
.03922 .06667 Mdot
.02745 .0549 Mdot
.23529 .22353 Mdot
.00392 .03922 Mdot
.05882 .07843 Mdot
.4 .39608 Mdot
.11373 .16471 Mdot
.01176 .02745 Mdot
.05882 .07843 Mdot
.01176 .01176 Mdot
.00784 .03922 Mdot
.0549 .07451 Mdot
.85882 .86275 Mdot
.04706 .07451 Mdot
.01569 .02745 Mdot
.21961 .22745 Mdot
.0549 .05098 Mdot
.00784 .04314 Mdot
.03922 .0549 Mdot
.87451 .8902 Mdot
.07059 .08235 Mdot
.00784 .02745 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.01569 .04706 Mdot
.04706 .06275 Mdot
.86667 .87843 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.33333 .35686 Mdot
0 0 Mdot
.00784 .03529 Mdot
.03922 .0549 Mdot
.87451 .88235 Mdot
.37255 .36078 Mdot
.00392 .01961 Mdot
.30588 .32157 Mdot
.00784 .00392 Mdot
.01176 .03922 Mdot
.04314 .05882 Mdot
.87059 .88235 Mdot
.78431 .76863 Mdot
.00784 .03529 Mdot
.01176 .03529 Mdot
0 0 Mdot
.00784 .03922 Mdot
.04314 .05882 Mdot
.6902 .72549 Mdot
.85098 .85098 Mdot
.01176 .03529 Mdot
.01961 .04706 Mdot
0 0 Mdot
.01961 .04314 Mdot
.03922 .05882 Mdot
.11373 .13725 Mdot
.83529 .84314 Mdot
.00784 .03137 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
.01176 .02745 Mdot
.06275 .09412 Mdot
.72157 .71373 Mdot
.83922 .84706 Mdot
.01961 .03137 Mdot
.00392 .01569 Mdot
0 0 Mdot
.01176 .02745 Mdot
.06275 .06667 Mdot
.86667 .87451 Mdot
.83922 .84706 Mdot
.02353 .03922 Mdot
.01176 .02745 Mdot
.00784 .01569 Mdot
.02353 .05098 Mdot
.72549 .71373 Mdot
.72549 .76078 Mdot
.83922 .84706 Mdot
.01961 .04706 Mdot
.00392 .00784 Mdot
.00392 .01176 Mdot
.03137 .05098 Mdot
.86275 .87059 Mdot
.17255 .21961 Mdot
.84314 .86275 Mdot
.01176 .04314 Mdot
.01176 .01569 Mdot
.00392 .01176 Mdot
.02745 .05882 Mdot
.85882 .87451 Mdot
.01961 .03529 Mdot
.72941 .74902 Mdot
.00784 .03529 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.04314 .07843 Mdot
.86275 .87059 Mdot
.65882 .65882 Mdot
.75294 .76078 Mdot
.00392 .02353 Mdot
.00392 .00784 Mdot
0 .01176 Mdot
.05882 .0902 Mdot
.84706 .87059 Mdot
.87843 .87843 Mdot
.83529 .83922 Mdot
.00784 .02745 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.08627 .12157 Mdot
.30588 .37255 Mdot
.87059 .87451 Mdot
.83922 .84706 Mdot
.01569 .03137 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18039 .20784 Mdot
.06275 .1098 Mdot
.86667 .87451 Mdot
.56078 .59216 Mdot
.16078 .16471 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.34902 .36078 Mdot
.08235 .10588 Mdot
.84706 .8549 Mdot
.67059 .68235 Mdot
.76471 .76863 Mdot
.01569 .00392 Mdot
0 .01176 Mdot
.47059 .49412 Mdot
.11373 .11373 Mdot
.82353 .85098 Mdot
.82745 .83137 Mdot
.5098 .52941 Mdot
.76078 .00392 Mdot
.00392 .01961 Mdot
.24314 .27843 Mdot
.56863 .56863 Mdot
.4902 .5451 Mdot
.82353 .83137 Mdot
.25882 .2902 Mdot
.52157 .00392 Mdot
.00392 .02353 Mdot
.09412 .12941 Mdot
.74118 .73725 Mdot
.14902 .21569 Mdot
.81961 .83137 Mdot
.11373 .14118 Mdot
.51765 .00392 Mdot
.03137 .05098 Mdot
.06667 .09804 Mdot
.86275 .86667 Mdot
.10196 .14902 Mdot
.81961 .83137 Mdot
.12941 .1451 Mdot
.52549 .01569 Mdot
.00784 .02353 Mdot
.01961 .03922 Mdot
.85882 .87451 Mdot
.01569 .03137 Mdot
.82353 .83137 Mdot
.32157 .33725 Mdot
.52157 .01176 Mdot
.00784 .01961 Mdot
.04314 .04314 Mdot
.79608 .83137 Mdot
.0902 .09412 Mdot
.82353 .82745 Mdot
.5451 .56471 Mdot
.52157 .01176 Mdot
.00784 .02745 Mdot
.31373 .3098 Mdot
.43137 .49412 Mdot
.61176 .61176 Mdot
.82353 .82745 Mdot
.67059 .68627 Mdot
.51765 .00392 Mdot
.00392 .02353 Mdot
.62353 .61961 Mdot
.1451 .20392 Mdot
.77647 .77647 Mdot
.81569 .83137 Mdot
.75686 .76078 Mdot
.52549 .00784 Mdot
0 .01961 Mdot
.79608 .79608 Mdot
.0902 .12941 Mdot
.86275 .86667 Mdot
.76471 .79608 Mdot
.75686 .75294 Mdot
.52157 .00784 Mdot
.00392 .03137 Mdot
.81569 .81569 Mdot
.08235 .10196 Mdot
.87843 .88235 Mdot
.53333 .57647 Mdot
.7451 .7451 Mdot
.51373 .00392 Mdot
.00784 .03137 Mdot
.81961 .82353 Mdot
.1098 .11373 Mdot
.89804 .89804 Mdot
.23922 .30196 Mdot
.74118 .74118 Mdot
.50588 .00392 Mdot
.00392 .01961 Mdot
.81961 .82353 Mdot
.17647 .15686 Mdot
.91765 .92157 Mdot
.09412 .16078 Mdot
.76078 .76471 Mdot
.5098 .00784 Mdot
.00392 .02353 Mdot
.83137 .83529 Mdot
.25098 .21569 Mdot
.93333 .93725 Mdot
.04706 .10196 Mdot
.74902 .75294 Mdot
.51765 .00784 Mdot
.00392 .02353 Mdot
.82745 .83529 Mdot
.28627 .25098 Mdot
.94902 .95686 Mdot
.03529 .06667 Mdot
.7098 .71765 Mdot
.51373 .00784 Mdot
.00392 .02745 Mdot
.80784 .82353 Mdot
.2549 .23137 Mdot
.93725 .95294 Mdot
.05098 .06667 Mdot
.73725 .7451 Mdot
.51765 .00784 Mdot
.00392 .02745 Mdot
.71765 .74118 Mdot
.29412 .27451 Mdot
.93725 .95686 Mdot
.05882 .08235 Mdot
.74902 .76471 Mdot
.5098 .00392 Mdot
.00392 .01961 Mdot
.53333 .56471 Mdot
.27451 .25882 Mdot
.89412 .95294 Mdot
.05098 .07843 Mdot
.67059 .6902 Mdot
.5098 .00392 Mdot
.00392 .02353 Mdot
.30196 .3098 Mdot
.21176 .19608 Mdot
.40392 .5098 Mdot
.05882 .07451 Mdot
.59216 .6 Mdot
.5098 0 Mdot
.00784 .03137 Mdot
.18431 .17647 Mdot
.12549 .12941 Mdot
.1451 .21961 Mdot
.06667 .03922 Mdot
.76471 .77647 Mdot
.50196 0 Mdot
.01569 .04706 Mdot
.30196 .29412 Mdot
.07059 .0902 Mdot
.08627 .11373 Mdot
.10588 .00392 Mdot
.79216 .81569 Mdot
.50588 0 Mdot
.01961 .04706 Mdot
.6902 .6902 Mdot
.06275 .07843 Mdot
.08235 .09804 Mdot
.34118 .1098 Mdot
.67059 .70196 Mdot
.01569 .00392 Mdot
.14118 .15686 Mdot
.78824 .79216 Mdot
.08235 .08235 Mdot
.09804 .09804 Mdot
.47843 .18431 Mdot
.72941 .7451 Mdot
.01961 .00392 Mdot
.10588 .13333 Mdot
.82353 .82745 Mdot
.14118 .13333 Mdot
.14118 .11373 Mdot
.28627 .04706 Mdot
.68235 .6902 Mdot
.01961 .00784 Mdot
.03529 .07059 Mdot
.76471 .80392 Mdot
.20784 .18039 Mdot
.22353 .16471 Mdot
.10588 .00392 Mdot
.64706 .65882 Mdot
.01569 .00392 Mdot
.03529 .0549 Mdot
.43529 .50196 Mdot
.28627 .23922 Mdot
.32941 .26275 Mdot
.0549 .01176 Mdot
.60784 .61569 Mdot
.01569 0 Mdot
.39216 .39608 Mdot
.12157 .18824 Mdot
.28627 .25098 Mdot
.60392 .58039 Mdot
.04314 .03529 Mdot
.58824 .6 Mdot
.02745 .00784 Mdot
.25882 .27451 Mdot
.07843 .10588 Mdot
.21569 .18824 Mdot
.63137 .64706 Mdot
.04706 .05882 Mdot
.59608 .61961 Mdot
.01961 .00392 Mdot
.3098 .33725 Mdot
.1098 .1098 Mdot
.24706 .20784 Mdot
.64706 .67059 Mdot
.04314 .07843 Mdot
.58039 .60784 Mdot
.01961 .00392 Mdot
.05098 .07843 Mdot
.14902 .13725 Mdot
.24706 .21569 Mdot
.75294 .77647 Mdot
.03529 .07451 Mdot
.55294 .57647 Mdot
.01569 .00392 Mdot
0 .02745 Mdot
.12549 .12941 Mdot
.15294 .14902 Mdot
.70588 .75294 Mdot
.05098 .07451 Mdot
.56863 .58431 Mdot
.01569 .00392 Mdot
.00784 .03137 Mdot
.10588 .12549 Mdot
.10196 .11373 Mdot
.49804 .55294 Mdot
.06667 .07843 Mdot
.6549 .67451 Mdot
.02353 .00784 Mdot
.00784 .03529 Mdot
.03529 .0549 Mdot
.09804 .1098 Mdot
.58039 .63529 Mdot
.05882 .06667 Mdot
.66667 .69412 Mdot
.01569 .00392 Mdot
.01176 .03922 Mdot
.00392 .00784 Mdot
.1098 .1098 Mdot
.45882 .52941 Mdot
.06275 .07059 Mdot
.60784 .63529 Mdot
.01176 .00392 Mdot
0 .01176 Mdot
.1098 .11765 Mdot
.14118 .13725 Mdot
.21961 .25882 Mdot
.07843 .0902 Mdot
.66667 .68235 Mdot
.01961 0 Mdot
.00784 .01176 Mdot
.33725 .3451 Mdot
.21569 .19216 Mdot
.31373 .31373 Mdot
.26667 .27451 Mdot
.80784 .82353 Mdot
.03137 .00784 Mdot
.00392 .02353 Mdot
.59216 .59608 Mdot
.2902 .2549 Mdot
.31765 .32549 Mdot
.58431 .58824 Mdot
.7451 .78824 Mdot
.01961 0 Mdot
.01961 .03922 Mdot
.76863 .77255 Mdot
.23529 .21569 Mdot
.19216 .21176 Mdot
.77255 .77255 Mdot
.63529 .68627 Mdot
.04314 .00392 Mdot
.10588 .13333 Mdot
.81569 .81961 Mdot
.18039 .15294 Mdot
.12157 .12941 Mdot
.79608 .8 Mdot
.65098 .67451 Mdot
.0549 .00392 Mdot
.01961 .05098 Mdot
.82353 .83529 Mdot
.18824 .16078 Mdot
.18824 .18039 Mdot
.81569 .82353 Mdot
.6902 .71373 Mdot
.06667 .00392 Mdot
0 .02353 Mdot
.37255 .41176 Mdot
.28235 .22745 Mdot
.24706 .23529 Mdot
.81961 .82745 Mdot
.53725 .58431 Mdot
.46275 .06667 Mdot
.00392 .02353 Mdot
.08627 .12549 Mdot
.38431 .32941 Mdot
.27451 .26275 Mdot
.81569 .82353 Mdot
.03529 .09804 Mdot
.12157 .00392 Mdot
.00392 .02745 Mdot
.08627 .0902 Mdot
.33725 .30196 Mdot
.23922 .23529 Mdot
.80784 .82745 Mdot
.02353 .06275 Mdot
.01176 .00392 Mdot
.02353 .04314 Mdot
.11373 .11373 Mdot
.29412 .28627 Mdot
.28627 .04314 Mdot
.0902 .13725 Mdot
.08627 .14118 Mdot
0 0 Mdot
.00784 .02745 Mdot
.07451 .09804 Mdot
.2549 .23529 Mdot
.67843 .05098 Mdot
.60392 .61569 Mdot
.00392 .03137 Mdot
.03922 .03529 Mdot
.01569 .03529 Mdot
.11373 .10588 Mdot
.23529 .2 Mdot
.12549 .01176 Mdot
.83529 .86667 Mdot
.01176 .03922 Mdot
0 0 Mdot
.04314 .0549 Mdot
.16078 .12549 Mdot
.21176 .17647 Mdot
.02353 .0549 Mdot
.87843 .90588 Mdot
.01176 .01961 Mdot
.00784 .00392 Mdot
.07451 .09412 Mdot
.19216 .16863 Mdot
.24706 .2 Mdot
.68235 .67843 Mdot
.90196 .93725 Mdot
.04706 .03529 Mdot
.00392 .01569 Mdot
.04706 .05098 Mdot
.67059 .6902 Mdot
.34902 .27843 Mdot
.80784 .81961 Mdot
.81961 .85882 Mdot
.37647 .00392 Mdot
.00392 .02745 Mdot
.1451 .12549 Mdot
.53725 .49412 Mdot
.46667 .37255 Mdot
.07843 .10588 Mdot
.07843 .10588 Mdot
.01569 .00784 Mdot
.03922 .0549 Mdot
.52157 .45882 Mdot
.57647 .55294 Mdot
.5098 .4549 Mdot
.78039 .81569 Mdot
.05882 .07059 Mdot
.00392 .00784 Mdot
.12549 .1098 Mdot
.73333 .69804 Mdot
.65882 .64706 Mdot
.5098 .47451 Mdot
.77647 .82745 Mdot
.02745 .03922 Mdot
.00392 .00392 Mdot
.34118 .2902 Mdot
.80784 .79608 Mdot
.84706 .85882 Mdot
.4902 .47451 Mdot
.83137 .87451 Mdot
.00392 0 Mdot
.10588 .12549 Mdot
.55294 .52941 Mdot
.89412 .92549 Mdot
.83529 .85098 Mdot
.4902 .47843 Mdot
.74902 .80392 Mdot
.23922 .07059 Mdot
.16471 .15294 Mdot
.64706 .65882 Mdot
.44314 .46275 Mdot
.52941 .53333 Mdot
.47843 .46275 Mdot
.05882 .10196 Mdot
.01569 .01176 Mdot
.52157 .50588 Mdot
.43137 .41569 Mdot
.43922 .38824 Mdot
.56471 .55686 Mdot
.46275 .43922 Mdot
.01569 .00784 Mdot
.01961 .02353 Mdot
.51373 .49804 Mdot
.45098 .37647 Mdot
.47059 .41569 Mdot
.4902 .43137 Mdot
.43922 .44706 Mdot
.67059 .06275 Mdot
.4902 .47843 Mdot
.46667 .39216 Mdot
.46667 .38824 Mdot
.59608 .60392 Mdot
.4902 .42745 Mdot
.06667 .07843 Mdot
.03529 .01961 Mdot
.4 .33725 Mdot
.4549 .36471 Mdot
.47843 .42353 Mdot
.4549 .38039 Mdot
.58039 .5451 Mdot
.08627 .05098 Mdot
.43529 .40392 Mdot
.45098 .36471 Mdot
.44706 .36863 Mdot
.46275 .39216 Mdot
.38431 .28627 Mdot
.45882 .45882 Mdot
.08627 .04314 Mdot
.47059 .37255 Mdot
.44706 .37255 Mdot
.46275 .4 Mdot
.47059 .36471 Mdot
.44706 .34902 Mdot
.09412 .07843 Mdot
.43137 .39216 Mdot
.48235 .38431 Mdot
.45098 .36863 Mdot
.45882 .38431 Mdot
.42353 .32549 Mdot
.45882 .38039 Mdot
.09412 .04314 Mdot
.45098 .34902 Mdot
.47451 .38824 Mdot
.46667 .4 Mdot
.41961 .30588 Mdot
.47059 .38824 Mdot
.38039 .36078 Mdot
.40392 .3451 Mdot
.46667 .38039 Mdot
.45882 .39608 Mdot
.47059 .40392 Mdot
.45098 .3451 Mdot
.40392 .2902 Mdot
.31765 .21569 Mdot
.46667 .36471 Mdot
.46667 .36471 Mdot
.58824 .55294 Mdot
.42353 .3098 Mdot
.45882 .34902 Mdot
.38824 .38824 Mdot
.43922 .33725 Mdot
.45882 .35686 Mdot
.47843 .43529 Mdot
.46275 .43137 Mdot
.46667 .37647 Mdot
.41569 .30588 Mdot
.41176 .29804 Mdot
.45098 .35294 Mdot
.48627 .41569 Mdot
.23922 .21961 Mdot
.42745 .33333 Mdot
.4549 .37255 Mdot
.28627 .21961 Mdot
.47451 .37255 Mdot
.47059 .37255 Mdot
.35294 .32941 Mdot
.42353 .38039 Mdot
.4549 .36471 Mdot
.31765 .24706 Mdot
.38039 .27843 Mdot
.46667 .35294 Mdot
.2902 .25882 Mdot
.58824 .5451 Mdot
.46275 .35294 Mdot
.45098 .3451 Mdot
.27059 .02745 Mdot
.46667 .36078 Mdot
.42745 .36863 Mdot
.55294 .56863 Mdot
.44706 .34902 Mdot
.45098 .3451 Mdot
.2902 .21569 Mdot
.42745 .36078 Mdot
.46275 .35686 Mdot
.40392 .32941 Mdot
.59608 .54118 Mdot
.44314 .34902 Mdot
.43137 .37255 Mdot
.42353 .32941 Mdot
.47059 .34902 Mdot
.30196 .2549 Mdot
.68235 .62353 Mdot
.47451 .38039 Mdot
.46667 .38824 Mdot
.38824 .25098 Mdot
.43922 .35294 Mdot
.32941 .2902 Mdot
.40392 .25882 Mdot
.40392 .2549 Mdot
.46667 .37255 Mdot
.31373 .25098 Mdot
.41569 .35294 Mdot
.49804 .4 Mdot
.44314 .23922 Mdot
.48235 .38431 Mdot
.48627 .37255 Mdot
.41961 .3451 Mdot
.69804 .04706 Mdot
.38431 .27451 Mdot
.40392 .29412 Mdot
.4 .32941 Mdot
.43529 .30196 Mdot
.43922 .33725 Mdot
.40784 .36863 Mdot
.4902 .44706 Mdot
.51373 .41569 Mdot
.47843 .30196 Mdot
.36471 .27451 Mdot
.50196 .38824 Mdot
.39216 .32157 Mdot
.52157 .47843 Mdot
.43529 .33725 Mdot
.47059 .3098 Mdot
.32157 .28627 Mdot
.5098 .38431 Mdot
.37647 .30588 Mdot
.42353 .17255 Mdot
.52549 .48627 Mdot
.41176 .27451 Mdot
.67843 .63529 Mdot
.50196 .39608 Mdot
.37255 .28627 Mdot
.46667 .42745 Mdot
.58431 .57255 Mdot
.43137 .23922 Mdot
.48627 .34902 Mdot
.52941 .38431 Mdot
.41569 .3098 Mdot
.47451 .45882 Mdot
.60784 .6 Mdot
.50196 .44706 Mdot
.61961 .55294 Mdot
.58039 .40784 Mdot
.45098 .33725 Mdot
.49412 .46275 Mdot
.61176 .59216 Mdot
.56471 .52157 Mdot
.47843 .41961 Mdot
.65882 .47843 Mdot
.47843 .38039 Mdot
.52549 .50196 Mdot
.60392 .57647 Mdot
.60392 .57647 Mdot
.48235 .38431 Mdot
.78431 .65098 Mdot
.56471 .50588 Mdot
.53333 .52941 Mdot
.52941 .50196 Mdot
.63137 .60784 Mdot
.49804 .35294 Mdot
.83922 .77647 Mdot
.6 .56078 Mdot
.53725 .52549 Mdot
.65098 .64314 Mdot
.62745 .60784 Mdot
.56078 .50196 Mdot
.88235 .83922 Mdot
.64706 .58824 Mdot
.50588 .47843 Mdot
.68627 .68235 Mdot
.67843 .67843 Mdot
.99608 .95294 Mdot
.83137 .83137 Mdot
.60784 .59216 Mdot
.74902 .12157 Mdot
.6902 .6902 Mdot
.8 .80392 Mdot
.99216 .99216 Mdot
.7098 .6902 Mdot
.54118 .53333 Mdot
.72157 .71373 Mdot
.72157 .71765 Mdot
.99608 .99608 Mdot
.81176 .81176 Mdot
.62745 .61176 Mdot
.69804 .6902 Mdot
.73725 .73725 Mdot
.95294 .96078 Mdot
.92549 .92157 Mdot
.65882 .65098 Mdot
.67059 .64706 Mdot
.76863 .76078 Mdot
.94118 .93725 Mdot
.92549 .92549 Mdot
.61569 .6 Mdot
.76863 .76471 Mdot
.83922 .83922 Mdot
.99216 .99216 Mdot
.84314 .8549 Mdot
.88627 .08235 Mdot
.80392 .8 Mdot
.95294 .95686 Mdot
.94902 .95294 Mdot
.41176 .26275 Mdot
.81569 .81569 Mdot
.9451 .94118 Mdot
.94118 .95294 Mdot
.76078 .15294 Mdot
.82353 .82745 Mdot
.99216 .98824 Mdot
.72549 .72157 Mdot
.6 .52157 Mdot
.97647 .98824 Mdot
.6 .57255 Mdot
.56078 .44706 Mdot
.72549 .70196 Mdot
.81961 .21176 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002@3ooonf
o`000=40oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0c`3oool000T0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`3?0?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooo`800000
1Ol0000300000:L0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo
0P3<c<`00`00003o0000o`000004o`00000301TI6@00003o00000:7o0000103oool00ol00000oooo
0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3oool30<c<c00300000?l0003o000000;o0000
00@0<c<co`00000I6AT00000XOl000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00
003oool0oooo0?ooo`<0c<c<0_l000001@00003o0000o`000?l00000<c<c00;o000000<00000o`00
0?l00000W_l000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`05o`00003oool0oooo0?oo
o`0000000P3<c<`01?l00000i^KVo`0000000003o`000080<c<c00?o000000000?l00000W_l00004
0?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`05o`00003oool0oooo0?ooo`0000000P3<c<`0
1Ol00000i^KV0>KVi_l00000000000Co000000<0<c<co`0000000000W_l000040?ooo`03o`00003o
ool0oooo0<l0oooo00090?ooo`08o`00003oool0oooo0?ooool0000000000<c<c?l000020>KViP;o
000000<00000o`000?l000000_l000000`0c<c?o00000000002Mo`0000@0oooo00?o00000?ooo`3o
ool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo1_l000000`3ooooo0000o`000007o`000003
00000?l0003o000009[o0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo
0?ooo`3oool4o`00000300000?l0003o00000080oooo0_l000000`00003o0000o`000003o`000003
01TI6@00003o000009Wo0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo
0?ooo`3oool5o`00000300000?l0003o00000080oooo0_l000000`00003o0000o`000003o`000003
01TI6@00003o000009So0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01Ol00000oooo
0?ooo`3oool06ATI00So00000P3oool8o`00000301TI6@00003o000009Oo0000103oool00ol00000
oooo0?ooo`3?0?ooo`002@3oool01_l00000oooo0?ooo`3oool0000001TI6@;o000000@0C4a<o`00
0?l0000000000_l000030?ooo`Oo000000<06ATI00000?l00000U_l000040?ooo`03o`00003oool0
oooo0<l0oooo00090?ooo`07o`00003oool0oooo0?ooool00000000001TI6@02o`00000404a<C?l0
003o0000000000;o00000`3oool00ol000000000o`000004o`00000301TI6@00003o000009Go0000
103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3oool2o`0000800000
0_l00000101<C4co0000o`0000000002o`000080oooo0_l000000`00003o0000o`000003o`000003
01TI6@00003o000009Co0000103oool00ol00000oooo0?ooo`2;0?ooo`;o0000@P3oool000T0oooo
00Co00000?ooo`3oool0oooo0ol00002000000Go000000<00000o`000?l000001?l000000`00003o
0000o`000004o`00000300000?l0003o000009;o0000103oool00ol00000oooo0?ooo`280?ooo`?o
000000<0ooooo`00003oool0@@3oool000T0oooo00Co00000?ooo`3oool0oooo1Ol000000`000000
6ATIo`000004o`000080000000Go00000>KViP3Vi^Ko000000000003o`00000404a<C?l0003o0000
000009?o0000103oool00ol00000oooo0?ooo`260?ooo`;o00000`3oool00onY_NSo0000o`000011
0?ooo`002@3oool01?l00000oooo0?ooo`3oool6o`0000030000000I6AWo000000Oo00000P3Vi^H0
0ol000000000o`000002o`00000404a<C?l0003o0000000009;o0000103oool00ol00000oooo0?oo
o`230?ooo`?o00000P3oool4ojVmj003o`00003ooooo00000400oooo00090?ooo`04o`00003oool0
oooo0?ooo`Oo00000P000006o`00000300000?l00000i^KV00;o000000<00000o`000?l000000_l0
00000`0c<c?o00000000002Ao`0000@0oooo00?o00000?ooo`3oool0P03oool3o`000080oooo1onY
_NP00ol00000ooooo`0000100?ooo`002@3oool01?l00000oooo0?ooo`3oool9o`00000300000?l0
003o000000Co000000<00000o`00000000000`2c/k<5o`0000806ATI00<00000o`000?l00000SOl0
00040?ooo`03o`00003oool0oooo07h0oooo0_l000030?ooo`WoZKgX00Co0000ojVmj03ooooo0000
?`3oool000T0oooo00Co00000?ooo`3oool0oooo2ol000000`0I6AWo000003<c<`03o`0000030000
0?l00000/k>c00<0/k>c1Ol0000201TI6@0300000?l0003o000008co0000103oool00ol00000oooo
0?ooo`1k0?ooo`?o00000P3oool<ojVmj005o`000?nY_NP0oooo0?ooool00000?P3oool000T0oooo
00Co00000?ooo`3oool0oooo2ol00002000000Oo00000P2c/k<3o`00000309VIVOl0003o000000;o
000000<06ATI00000?l00000S?l000040?ooo`03o`00003oool0oooo07T0oooo0_l000030?ooo`ko
ZKgX00Go0000ojVmj?nY_NP0ooooo`00000n0?ooo`002@3oool01?l00000oooo0?ooo`3oool=o`00
00030000000I6AWo000000Ko0000102IVIT4o`0000806ATI00<00000o`000?l00000R_l000040?oo
o`03o`00003oool0oooo07H0oooo0ol000020?oooa7oZKgX00Ko0000ojVmj?nY_NSoZKgX0?ooool0
000m0?ooo`002@3oool01?l00000oooo0?ooo`3oool>o`0000030000000I6AWo000000Go0000102I
VIT5o`0000806ATI00<00000o`000?l00000ROl000040?ooo`03o`00003oool0oooo07@0oooo0_l0
00020?oooaCoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol00000oooo0?ooo`0k0?ooo`002@3oool0
1?l00000oooo0?ooo`3oool?o`0000040000000I6AWo000003<c<`Go00000`2IVIT5o`0000806ATI
00<00000o`000?l00000R?l000040?ooo`03o`00003oool0oooo0740oooo0ol000020?oooaKoZKgX
00?o0000ojVmj?nY_NP00onY_NP00ol00000oooo0?ooo`0j0?ooo`002@3oool01?l00000oooo0?oo
o`3ooolAo`00000301TI6Ol00000<c<c00So000000<0Ogmoo`000?l000000_l0000201TI6H[o0000
103oool00ol00000oooo0?ooo`1^0?ooo`?o00000P3ooolIojVmj003o`000?nY_NSoZKgX00?oZKgX
00<0ooooo`00003oool0>P3oool000T0oooo00Co00000?ooo`3oool0oooo4Ol00002000000?o0000
00@0C4a<o`000?l0003o00000`1oOgl2o`00000304a<C?l0003o000000806ATI00<00000o`000?l0
0000Q_l000040?ooo`03o`00003oool0oooo06`0oooo0_l000030?oooacoZKgX00?o0000ojVmj?nY
_NP00onY_NP00ol00000oooo0?ooo`0i0?ooo`002@3oool01?l00000oooo0?ooo`3ooolCo`000003
00000?l0003o000000Go000000H0Ogmoo`00001VIVH0IVIVo`00001<C4`2o`0000806ATI00<00000
o`000?l00000QOl000040?ooo`03o`00003oool0oooo06T0oooo0ol000020?oooaooZKgX00?o0000
ojVmj?nY_NP00onY_NP00`3ooooo00000?ooo`0i0?ooo`002@3oool01?l00000oooo0?ooo`3ooolE
o`0000030000000I6AWo000000Co0000101VIVH01?l00000C4a<o`000?l0000201TI6@0300000?l0
003o000008Co0000103oool00ol00000oooo0?ooo`1W0?ooo`;o00000`3ooolQojVmj003o`000?nY
_NSoZKgX00CoZKgX00<0ooooo`00003oool0>03oool000T0oooo00Co00000?ooo`3oool0oooo5_l0
00000`0000006ATIo`000005o`000080IVIV00Oo000004a<C?l00000<c<co`00000I6AT0000008Ko
0000103oool00ol00000oooo0?ooo`1T0?ooo`?o00000P3ooolTojVmj003o`000?nY_NSoZKgX00Co
ZKgX00<0ooooo`00003oool0>03oool000T0oooo00Co00000?ooo`3oool0oooo5ol000000`000000
6ATI01TI6@03o`00000304a<C?l0003o00000080C4a<00Ko000003<c<`0c<c?o000001TI6@000025
o`0000@0oooo00?o00000?ooo`3oool0HP3oool2o`0000<0oooo9_nY_NP00ol0003oZKgXojVmj005
ojVmj0030?ooool00000oooo03L0oooo00090?ooo`04o`00003oool0oooo0?oooaSo00000P000000
0`0I6AWo000003<c<`02o`0000@0C4a<00Ko000003<c<`0c<c?o000001TI6@000024o`0000@0oooo
00?o00000?ooo`3oool0G`3oool3o`000080oooo:OnY_NP00ol0003oZKgXojVmj006ojVmj0030?oo
ool00000oooo03H0oooo00090?ooo`04o`00003oool0oooo0?oooa_o000000<06ATIo`000?l00000
1?l000001@1<C4co0000o`00000c<c?o000000806ATI00<00000o`000?l00000POl000040?ooo`03
o`00003oool0oooo05d0oooo0_l000030?ooob_oZKgX00?o0000ojVmj?nY_NP01onY_NP00ol00000
oooo0?ooo`0e0?ooo`002@3oool01?l00000oooo0?ooo`3ooolKo`00008000000P0I6AT2o`000003
03<c<ol00000<c<c0080<c<c00Go000001TI6@0I6AT06ATI00000022o`0000@0oooo00?o00000?oo
o`3oool0FP3oool3o`000080oooo;_nY_NP00ol0003oZKgXojVmj008ojVmj003o`00003oool0oooo
03@0oooo00090?ooo`04o`00003oool0oooo0?oooago000000D0000001TI6@0I6AT06ATIo`000005
03<c<`05o`00000I6AT06ATI01TI6@000000POl000040?ooo`03o`00003oool0oooo05L0oooo0ol0
00030?oooc3oZKgX00?o0000ojVmj?nY_NP02?nY_NP00`3ooooo00000?ooo`0d0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolOo`0000<06ATI0ol0000303<c<`05o`00000I6AT06ATI01TI6@000000
P?l000040?ooo`03o`00003oool0oooo05D0oooo0_l000030?oooc?oZKgX00?o0000ojVmj?nY_NP0
2OnY_NP00ol00000oooo0?ooo`0c0?ooo`002@3oool01?l00000oooo0?ooo`3ooolOo`0000<00000
0`0I6AT00ol00000<c<co`00000401TI6@0300000?l0003o000007ko0000103oool00ol00000oooo
0?ooo`1B0?ooo`?o00000`3oooleojVmj003o`000?nY_NSoZKgX00WoZKgX00<0ooooo`00003oool0
<`3oool000T0oooo00Co00000?ooo`3oool0oooo8_l000001@0000006ATI01TI6@0I6AWo000000H0
6ATI00<00000o`000?l00000OOl000040?ooo`03o`00003oool0oooo0500oooo0_l000040?ooocOo
ZKgX00?o0000ojVmj?nY_NP02_nY_NP00ol00000oooo0?ooo`0b0?ooo`002@3oool01?l00000oooo
0?ooo`3ooolSo`0000030000000I6AT06ATI00L06ATI00<00000o`000?l00000OOl000040?ooo`03
o`00003oool0oooo04d0oooo0ol000030?oooc[oZKgX00?o0000ojVmj?nY_NP02_nY_NP00`3ooooo
00000?ooo`0b0?ooo`002@3oool01?l00000oooo0?ooo`3ooolTo`0000800000200I6AT00`00003o
0000o`00001lo`0000@0oooo00?o00000?ooo`3oool0B`3oool2o`0000@0oooo??nY_NP00ol0003o
ZKgXojVmj00;ojVmj0030?ooool00000oooo0340oooo00090?ooo`04o`00003oool0oooo0?ooobKo
00000P00000601TI6@0300000?l0003o000007co0000103oool00ol00000oooo0?ooo`180?ooo`?o
00000`3oooloojVmj003o`000?nY_NSoZKgX00coZKgX00?o00000?ooo`3oool0<03oool000T0oooo
00Co00000?ooo`3oool0oooo:?l000000`0000006ATI01TI6@0401TI6@0300000?l0003o000007_o
0000103oool00ol00000oooo0?ooo`150?ooo`?o00000P3oool00onZ_NOoZKgXojVmj010ojVmj003
o`000?nY_NSoZKgX00coZKgX00<0ooooo`00003oool0<03oool000T0oooo00Co00000?ooo`3oool0
oooo:Ol0000300000004o`00000I6AT00000000007go0000103oool00ol00000oooo0?ooo`130?oo
o`;o00000P3oool5ojZmi`03ojVmj?nZ_NOoZ[gW03koZKgX00?o0000ojVmj?nY_NP03OnY_NP00`3o
oooo00000?ooo`0_0?ooo`002@3oool01?l00000oooo0?ooo`3oool]o`00000300000?l0003o0000
07go0000103oool00ol00000oooo0?ooo`100?ooo`?o00000P3oool;ojZmi`03ojVmj?nZ_NOoZ[gW
03[oZKgX00?o0000ojVmj?nY_NP03OnY_NP00`3ooooo00000?ooo`0_0?ooo`002@3oool01?l00000
oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0?P3oool2o`0000<0oooo4OnZ_NL00onY
_NSoZ[gWojZmi`04ojVmj0?oZ[gX00?oZKgXojZmj?nY_NP0;?nY_NP00ol0003oZKgXojVmj00>ojVm
j0030?ooool00000oooo02h0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol0
0000oooo0?ooo`0k0?ooo`?o00000P3ooolKojZmi`;oZ[gX00CoZ[gWojZmj?nZ_NSoZ[gX0_nY_NP0
0onZ_NSoZKgXojVmj00WojVmj003o`000?nY_NSoZKgX00ooZKgX00<0ooooo`00003oool0;@3oool0
00T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo03T0oooo0_l00003
0?ooo`;oZ[cW7onZ_NL00onZ_NSoZ[gWojZmi`03ojZmj003ojVmj?nZ_NSoZ[gX02GoZKgX00?o0000
ojVmj?nY_NP04?nY_NP00ol00000oooo0?ooo`0/0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]
o`0000@0oooo00?o00000?ooo`3oool0=P3oool3o`0000<0oooo1OnZ_>L00onZ_NOoZ[cWojZli`04
ojZmi`;oZ[cW0_nZ_NL00onZ_>OoZ[gWojZmi`0DojZmi`03ojZmj?nZ_NOoZ[gW00?oZ[gX00?oZKgX
ojZmj?nZ_NP00_nY_NP00onZ_NSoZKgXojVmj00LojVmj003o`000?nY_NSoZKgX017oZKgX00?o0000
0?ooo`3oool0:`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0
oooo03<0oooo0ol000040?oooaCoZ[cW00?oZ[gWojZlionZ_>L06OnZ_NL00onZ_NSoZ[gWojZmi`03
ojZmj003ojVmj?nZ_NSoZ[gX01[oZKgX00?o0000ojVmj?nY_NP04OnY_NP00ol00000oooo0?ooo`0[
0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0<@3oool2
o`0000@0oooo2_nZ_>L2ojZliPCoZ[cW0_nZ_>H9ojZli`03ojZmionZ_>OoZ[cW01WoZ[gW00?oZ[gX
ojZmionZ_NP00onZ_NP00onY_NSoZ[gXojVmj00GojVmj003o`000?nY_NSoZKgX017oZKgX00?o0000
0?ooo`3oool0:P3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0
oooo02h0oooo0ol000040?ooo`[oZ[cW1OnZ_>H00onZ_>OoZ[cVojZliP03ojZliP03ojZlionZ_>Ko
Z[cW00CoZ[cW0_nZ_>H3ojZli`03ojZmionZ_>OoZ[cW00;oZ[gW00?oZ[cWojZmionZ_NL04onZ_NL2
ojZmj0;oZ[gW0_nZ_NP2ojVmj0;oZ[gX4onY_NP00ol0003oZKgXojVmj00BojVmj003o`00003oool0
oooo02T0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0/
0?ooo`;o00000`3oool<ojZli`coZ[cV00CoZkcVojZli_nZ_>KoZ[cV0_nZ_>L2oj^liP03ojZli_n[
_>KoZkcV00?oZkcV00?oZ[cWoj^li_n[_>H00onZ_>L00onZ_NOoZ[cWojZli`0IojZmi`03ojZmj?nZ
_NOoZKgX01;oZKgX00?o0000ojVmj?nY_NP04_nY_NP00ol00000oooo0?ooo`0Y0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0:@3oool3o`000080oooo0_nY
_>L:ojZli`coZ[cV1On[_>H00onZ_>KoZkcVoj^liP0=oj^liP03ojZlion[_>KoZ[cW00?oZ[cW00?o
Z[gWoj^lionZ_NL06?nZ_NL2ojVmj003ojZmionY_NSoZKgX00goZKgX00?o0000ojVmj?nY_NP04onY
_NP00ol00000oooo0?ooo`0X0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o
00000?ooo`3oool09`3oool2o`0000<0oooo1OnY_>L7ojZli`coZ[cV6_n[_>H2ojZli`;oZkcV0_n[
_>L2ojZmi`;oZkcW00?oZ[gWoj^lion[_>L05OnZ_NL00onY_NSoZ[gXojZmj002ojVmj003ojZmj?nY
_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP05?nY_NP00ol00000oooo0?ooo`0W0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0903oool3o`0000<0oooo1onY
_>L7ojZli`coZ[cV8_n[_>H00on[_>OoZkcVoj^li`03oj^li`03ojZmion[_>OoZ[gW01;oZ[gW00?o
Z[gXojZmionZ_NL00onZ_NP00onY_NSoZ[gXojVmj004ojVmj003o`000?nY_NSoZKgX01CoZKgX00?o
00000?ooo`3oool09`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003o
ool0oooo0280oooo0_l000040?ooo`[oZKcW0_nZ_>L2ojVli`?oZ[cW2_nZ_>HVoj^liP;oZkcW00Go
ZkcVoj^lion[_>OoZkcWojZmi`03oj^mia;oZ[gW00?oZ[gXojZmionZ_NP00_nZ_NP4ojVmj003o`00
0?nY_NSoZKgX01GoZKgX00?o00000?ooo`3oool09P3oool000T0oooo00Co00000?ooo`3oool0oooo
[Ol000040?ooo`03o`00003oool0oooo01l0oooo0ol000040?ooo`;oZKcX3onY_>L3ojZli`SoZ[cV
1On[_>H00on[^nKoZkcVoj^liP03oj^liP;oZk_V1?n[_>H2oj^li@03oj^li_n[_>GoZkcU01GoZkcV
00?oZkcWoj^li_n[_>H00_n[_NL01?n[_>KoZkgWoj^mion[_NLBojZmi`CoZ[gX00?oZKgXojZmj?l0
00005onY_NP00`3ooooo00000?ooo`0V0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0
oooo00?o00000?ooo`3oool0703oool3o`000080oooo0_nX^^H4ojVlj17oZKcW00?oZ[cWojVlionZ
_>H02?nZ_>H2oj^liPCoZk_V0_n[_>H3oj^kiPGoZk_U00?oZkcUoj^kiOn[_>D00on[_>D00on[_>Ko
ZkcUoj^liP04oj^liP;oZkcU4_n[_>H00on[_NOoZkcWoj^li`0BojZmi`;oZ[gX00CoZ[gWojZmj?nZ
_NSo00000_nY_NP00onZ_NSoZKgXojVmj00CojVmj003o`00003oool0oooo02D0oooo00090?ooo`04
o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0J0?ooo`;o00000`3oool2ojJR
dP?oZ;[V00?oZKcXojRhi?nX^>@05?nY_>L:ojZliP03oj^ki_nZ^nKoZk_V00CoZk_V2_n[^nD2oj^l
i@04oj^kiOn[_>GoZkcUoj^li@;oZkcV0_n/_>D00on[_>Go[;cUojbli@03oj^li@03oj^li_n/_>Go
ZkcV00_oZkcV1?n[_>L01?nZ_NOoZkgWoj^mionZ_NL2oj^mi`ooZ[gW00?oZ[gXo`000?nZ_NP00onZ
_NP00onY_NSoZ[gXojZmj00BojVmj003o`00003oool0oooo02@0oooo00090?ooo`04o`00003oool0
oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0G0?ooo`?o00000`3oool00onKM:GoYZ;BojJR
dP02ojJRdP03ojRji_nTVL[oZ;ST00?oZ;ST00?oZKcWojRfhonX]^<04_nY_>L00onZ_>KoZKcWojZl
iP05ojZliP?oZ[_V0on[^nH?oj^ki@04oj^liOn/^nGo[;_Uojbki@Ko[;cU00?oZkcUojbliOn/_>D0
0_n/_>D2oj^liP03ojbli_n[_>KoZkcV00OoZkcV0_n[_>L2oj^liP03oj^mion[_>KoZkgW00?oZkgW
00?oZ[gWoj^mionZ_NL02onZ_NL2o`000003ojZmionZ_NSoZ[gX00CoZ[gX4_nY_NP00`3ooooo0000
0?ooo`0T0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0
5P3oool2o`0000@0oooo0onKM:D2ojJRdP04oi]^W_nTVL[oY9W:ojBIbP;oZ;ST0_nSTL<00onX]^?o
XXbmoj:<_@03ojRch@03ojVlionX/MooZ;7O00?oZK_W00?oZKcWojVkionY_>L02?nY_>L6ojZliP?o
Z[_V0on[^nH01?n[^nGoZk_Voj^ki_n[^nH7oj^ki@Oo[;_U3On/_>D2ojbliP06oj^li_n/_>Ko[;cV
ojbli_n[_>Ko[;cV2On[_>H2oj^mi`05oj^mi_n[_NOoZkgWoj^mionZ_NL00on[_NL4ojZmi`?o0000
00CoZ[gWo`000?nZ_NOoZ[gW0_nZ_NP01?nZ_NOoZ[gXojZmj?nZ_NP2ojVmj003ojZmj?nY_NSoZKgX
00goZKgX00?o00000?ooo`3oool08`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?oo
o`03o`00003oool0oooo01H0oooo00?o00000?ooool000000`3oool3oi]dY@04ojJRd_nKKYkoVfjN
oi]^WP;oY9W:1?nSTL<4oj:<_@03ojRchOnRR;WoZ;7O00?oZ;7O00?oZK_WojR`gOnY^nL00_nY^nL2
ojVli`03ojVki_nY_>OoZKcW00CoZKcW1onZ_>H2ojZkiPKoZk_V1_n[^nD9ojbki@oo[;cU0_n/_>H0
1On/_>Go[;cVojbli_n/_>KoZkcV00;o[;cV1_n[_>H3oj^miPKoZkgW00CoZ[gWo`000?l0003o0000
1OnZ_NL00ol0003oZ[gWojZmi`03ojZmi`03ojZmj?nZ_NOoZ[gW00?oZ[gX3onY_NP00ol00000oooo
0?ooo`0R0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0
5P3oool01_l00000oooo0?ooool00000oooooiiWT@?oVgBU1?nKKYh00onTVL[oVfbJoi]/VP03oj>A
``CoXXbm0onRR;T2ojRag`05oj>8^?nX/=goZ;3MojR`gOnY^nL00onX[md2ojVkiP04ojVlionY^nKo
ZK_VojVkiP;oZKcW00?oZ[cVojVlionY_>L00_nZ_>H01?nY_>OoZ[cVojZli_nZ_>H2oj^kiP05ojZl
i_n[^nKoZk_Voj^ki_n[^nD00_n[^nH3oj^ki@Wo[;_U4_n/_>D00on/_>Ko[;cUojbliP03ojbliP03
oj^li_n/_>Ko[;cV00?oZkcV0on[_NH00on[_NOoZkgVoj^mi`03o`000003ojZmion[_NOoZ[gW00Ko
Z[gW00?o0000ojZmionZ_NL01OnZ_NL4ojZmj003ojVmj?nZ_NSoZKgX00_oZKgX00?o00000?ooo`3o
ool08P3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo01H0
oooo00Co00000?ooo`3oool0oooo0onNIi42oi]dY@CoVfjN1?nKK9X00onSTL?oWFbIoie/V@02oj:<
_@04oj1^V?nRR;WoXXRioj:8^@CoXhRh00?oZ;3MojB:^OnTR[T01_nX[md2ojVkiP05ojVag_nY^nKo
ZK_VojVki_nY_>L00_nY^nH3ojVli`KoZ[cV00?oZk_Voj^li_n[^nH00on[^nH00on[^nGoZkcUoj^l
i@04ojbki@;o[;cU00?o[;_UojbliOn/_>D05?n/_>D6ojbliPCoZkcV0_n[_NH3o`0000KoZkgW0_nZ
_NL2oj^mi`?oZ[gW00?o0000ojZmionZ_NL01OnZ_NL2ojZmj004ojZmionZ_NSoZ[gXojZmj0;oZKgX
00?oZ[gXojVmj?nY_NP01onY_NP00ol00000oooo0?ooo`0Q0?ooo`002@3oool01?l00000oooo0?oo
o`3ooon]o`0000@0oooo00?o00000?ooo`3oool05@3oool01?l00000oooo0?ooo`3oool4oiiWT@03
oi]dYOnQJ8ooVfjN00?oVfjN1?nKK9X3oie/V@04oj:<_OnPKYSoX6jHoj1^V0;oXXRi00CoY7:Joj>8
^?nSR;SoXhRh1?nTR[T01?nX[mgoYXjlojJ>_?nX[md2ojVE`@?oZK7N00?oZK_VojVcgonY/ml00onY
^nH00onY_>OoZK_VojZliP06ojZliP;oZkcV0_n[^nH2oj^liP03oj^liOn[_>KoZkcV00?oZkcU6on/
_>D00on/_>Ko[;cUojbliP02ojbliP;oZkcV0ol00005oj^miP03oj^mion[_NKoZkgW00GoZkgW0onZ
_NL00ol0003oZ[gWojZmi`09ojZmi`KoZ[gX2OnY_NP00ol00000oooo0?ooo`0P0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool05@3oool01?l00000oooo0?oo
o`3oool4oiiWT@03oi]dYOnQJ8ooVfjN00;oVfjN00?oYF^?oi]/V_nKK9X00_nKK9X3oie/V@CoX6jH
00?oXXRiojAbV_nTLYX00onSR;P4ojB:^@?oYXjl1?nYUL400onY/MkoZig8ojVcg`03ojVcg`03ojVk
i_nY]N7oZKGQ00;oZK_V0_nZ_>H2ojVkiPKoZ[cV1_n[_>H00on[_>GoZkcVojbli@0Mojbli@04ojbl
i_l0003o0000o`0000;o[;cV00?oZkgVojbmi_n/_NH01_n[_NH6oj^mi`04ojZmion[_NOoZkgWo`00
00_oZ[gW00?oZ[gXojZmionZ_NP00onZ_NP00onY_NSoZ[gXojVmj005ojVmj003o`00003oool0oooo
0200oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0E0?oo
o`04o`00003oool0oooo0?ooo`CoWVNA00?oVgBUoj5XSonQJ8l00_nKKYh01OnUJhooVfbJoi]/V_nK
K9[oZg2@00?oWFbI1?nPKYP4ojAbVP03oj>8^?nYN9goZGRM00;oY8Zi0_n^Oj82ojJ>_004okB9ZOnY
UL7oZIG1ojVE`@?oZig80_nY/ml2ojfVd003ojVehOn^[]So[ZkH00?oZKOS00?oZK_VojViiOnZ_>H0
1OnZ_>H9oj^liP04ojbliOn/_>Ko[;cVojbliQOo[;cU0ol000000on/_>Ko[;gVojbmiP05ojbmiPOo
ZkgV2?n[_NL00onZ_NOo0000ojZmi`0<ojZmi`KoZ[gX1_nY_NP00ol00000oooo0?ooo`0O0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool05@3oool01?l00000
oooo0?oooon`M904oiiWT@?oXFR?00CoVfjNojE[SonUJhooYF^?0_nKK9X01?n[L93oWFbIoie/VOna
MY44oj1^V0CoY7:J0onYN9d01OnTR[Wo[WnRojioX_n^Oj;oYXjl00?o]8VY00?oZIG1okVF/_niU[80
0_n[WLP01?nmY;oo[JK@ojfVd?n]Y]04ojj^f003ojVghon]]=koZKWU00;oZKWU0_nZ_>H2ojZkiP;o
Z[cV00CoZkcVojZlionZ_>OoZ[cW1On[_>H2ojbliP05oj^li_n/_>Ko[;cVojbli_n/_>D00_n/_>H:
ojbli@;o[KcU00?o[;cUojfliOl000000_l00002ojbli@03ojbmiOn/_NKo[;gV00Oo[;gV0_n[_NH2
ojbmiPKoZkgV1On[_NL00onZ_NOo0000oj^mi`0<ojZmi`KoZ[gX00?oZKgXojZmj?nY_NP00onY_NP0
0ol00000oooo0?ooo`0N0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o0000
0?ooo`3oool05@3oool01?l00000oooo0?oooon`M904oiiWT@?oXFR?00CoVfjNojE[SonUJhooYF^?
0_nKK9X01?n[L93oWFbIoie/VOnaMY44oj1^V0CoY7:J0onYN9d4ojioXPCo]8VY0oniU[801On[WLSo
_JBookfT_onmY;oo[JK@00;o_[7=0_n^[]P01Onj^]Wo[KCNojfdg_n]]=koZKWU00?o[;WS00?oZ[_V
oj^kiOnZ_>H00_nZ_>H6ojZli`03oj^li_n[_>OoZkcW00?oZkcV00?o[;cVoj^li_n/_>H00on/_>H0
0on/_>Go[;cVojbliP06ojbli@04ojfliOn/_NGo0000o`0000;o[KcU00?o[;cUojfmiOn/_ND00_n/
_ND<ojbmiPKoZkgV1_n[_NL01?l0003oZkgWoj^mionZ_NL2oj^mi`SoZ[gW2OnZ_NP3ojVmj003o`00
003oool0oooo01h0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo
0?ooo`0E0?ooo`04o`00003oool0oooook1dT0CoWVNA0onQJ8l01OnKKYkoYF^?ojE[SonUJhooVfbJ
00;oZg2@0_nMK9T01OnaMY7oX6jHoj1^V?nPKYSo^GjD00?oY7:J00Co`XVHojUhWOnYN9goZGRM1?n^
Oj84okB9Z@?o^IJb1?nmY;l3okjac@05oloJhOnj^]Wo^[[IokZjfOn]]=h00one_n400on/^N?o/<3V
oj^ki@02oj^ki@03ojZli_nZ_>OoZ[cW00CoZ[cW00?oZ[gWoj^lion[_>L00_n[_>L00on[_>KoZkgW
oj^mi`02oj^liP;o[;cV0_n/_NH00on/_>Ko[;gVojbmiP03ojbmiP05ojbliOl0003o0000o`000?n/
_ND00_n]_>D2ojfmiP;o[KgU00?o[;gUojbmi_n/_NH03?n/_NH00on[_NKo[;gVojbmiP03oj^miPKo
ZkgW00?o0000oj^mion[_NL00_n[_NL9ojZmi`;oZ[gX0_nZ_NL5ojZmj0;oZKgX00?oZ[gXo`00003o
ool07P3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo01@0
oooo00?o00000?ooo`3oool00_n`M903oiiWT@04okMkT?nQJ8ooXFR?oj5XS`CoYF^?00CoVfbJoj]`
T?n[L93oWFbI0onaMY42oj1^V005okUnU?nTLY[oY7:JojAbV_o2RIP00_nYN9d01Oo<UYgo[WnRojio
X_n^Oj;oejFT00?o]8VY0_oO^:l2okVF/P06on?;_onmY;oo_JBookfT_ooMf=7o_[7=0oo?f^400onj
^]Wo_m?YokoCj@02okFoh@05ok?;k?n``>Ko/<3Vok30i_n[^nD00on/_nP3ojZli`CoZ[gW0_n[_>L2
ojZmi`03oj^mionZ_NOoZkgW00?oZkgW00?o[;gVoj^mion/_NH00on/_NH3o`0000;o[;gV00Go[;gU
ojbmi_n/_NKo[;gVojfmiP0EojbmiPCoZkgV1_n[_NL00ol0003oZkgWoj^mi`02oj^mi`coZ[gW2OnZ
_NP00ol00000oooo0?ooo`0L0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o
00000?ooo`3oool0503oool00ol00000oooo0?ooo`02ok1dT0?oWVNA00Co]g^@oj5XSonQJ8ooXFR?
1?nUJhl01?nKK9[oZg2@oj]`T?nMK9T3ok5fT@;oX6jH0_niOY@2ojAbVP03ol:9V?nYN9goZGRM00;o
c9JM0_n^Oj82omNUY0;o]8VY0_oO^:l01_niU[;ohl^oon?;_ooSbkoo_JBoomgHd@?oZOO[00Cocm[Q
oj_Sn_n[ho[o_m?Y0onXco@2ok?;k003ok30i_n]a>_o[LC[00;o[;oX00GoZL7[ojZnj?nZ_^SoZ[kX
ojZmi`02ojVnj0?oZ[gX00?oZ[gWojZmj?nZ_NL00_nZ_NL6oj^mi`?o000000?o[;gWojbmi_n/_NH0
7On/_NH2oj^miP03ojbmion[_NOoZkgW00GoZkgW00?o0000oj^mion[_NL00_n[_NL00onZ_NOoZkgW
oj^mi`09ojZmi`SoZ[gX00?o00000?ooo`3oool0703oool000T0oooo00Co00000?ooo`3oool0oooo
[Ol000040?ooo`03o`00003oool0oooo01@0oooo00?o00000?ooo`3oool00_n`M903oiiWT@04okMk
T?nQJ8ooXFR?oj5XS`CoYF^?0on[L9001OnMK9Wo/GJAok5fTOnaMY7oX6jH00?o^GjD00?oY7:Jol:9
V?o2RIP00_nYN9d2olbFW@05ojioX_oGYJCoejFTomNUY?ndRJT00ooO^:l00onEdW3ohl^oon?;_`02
oiZll0?oPkci0_mlc?l01_n[ho[oV<GgoiS5monHaOOoZ<odoj71k`?oYlG_00?o[LC[ojK1k?nV`N`0
0onY`N/00onZ_^SoZ;oZojVnj003ojVnj003ojZmj?nY_^SoZKkX00;oZ[gX00GoZ[gWojZmj?nZ_NSo
Z[gXoj^mi`03o`000004oj^mion/_NOo[;gWoj^ni`?o[;gW00?o[;gVojbnion/_NH06on/_NH2ojbm
i`KoZkgW00?o0000oj^mion[_NL01_n[_NL8ojZmi`WoZ[gX00?o00000?ooo`3oool06`3oool000T0
oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo01@0oooo00?o00000?oo
o`3oool00_n`M902oiiWT@;o]g^@0_nQJ8l00oo1Pi7oYF^?ojE[S`02ojE[S`?oZg2@1?naMY401OnP
KYSo^GjDokUnU?niOYCoY7:J00;o`XVH00GoZGRMolbFWOo<UYgoc9JMojioXP03omNUY005okB9ZOoO
^:oogkR_omnh[on6^?H00onT_N/2oiZll003oh>lnOnR_NcoX[g/00;oV[ka0_nHaOL2oj6nk@;oXL7_
00CoYlG_ojBok?nT_ncoY;o/0_nV`N`00onY`N_oYko[ojNoj`02ojRojP;oZKkX0_nX_^T00onY_^So
Z;kYojVmj002ojVmj004ojZmj?l0003o0000o`0000;oZ[gW00?oZkgWojZmionZ_NL00on[_^L00on/
_NOoZkkWoj^ni`02ojbni`;o[;gV0_n/_^L00on/_NKo[;kWojbniP03ojbniP03ojbmi_n/_^Ko[;gV
00?o[;gV0on/_^H7ojbmiPCo[;gW1_n[_NL00ol0003oZkgWoj^mi`06oj^mi`OoZ[gW2OnZ_NP00`3o
oooo00000?ooo`0K0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?oo
o`3oool0503oool00ol00000oooook1dT002ok1dT0;oWVNA0_ngNi02oj5XS`03ol63TOnUJhooYF^?
00;oYF^?0on[L904ok5fT@05oj1^V?niOYCo^GjDokUnU?nTLYX00_o2RIP01OnYN9goc9JMolbFWOo<
UYgo[WnR00?oejFT0ooO^:l3ojJmjP03ojBmjonV_^[oYKg[00;oYKg[00?oX[g/ojJnjonV_^/00onT
_N/00onQ_^goYKk[ojBnk002ojBnk0;oY;o/1?nU_^/00onW_n_oY[k[ojNnjP03ojNnjP03ojRnjOnW
_^[oZ;kY00;oZ;kY0ol00004ojZmi`;oZ[cW0onZ_NL01On[_^OoZkgWoj^mion[_^OoZkcV00CoZkkW
1On/_^L2ojbniP;o[;kW0_n/_^H00on/_NKo[;kWojbni`02ojbniPCo[;kW00?o[;gVojbnion/_NL0
1?n/_NL2ojbni`KoZkgW00?o0000oj^mion[_NL01On[_NL8ojZmi`WoZ[gX00?o00000?ooo`3oool0
6P3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo01@0oooo
00?o00000?oooon`M9000_n`M902oiiWT@;o]g^@0_nQJ8l01Oo1Pi7oYF^?ojE[SonUJhooc8jC00?o
Zg2@1?naMY44okUnU0?o`XVH00CoZGRMolbFWOo<UYgoc9JM1?oGYJ@00onW_NWogkR_ojNmjP02ojJm
jP;oYkkZ0_nV_^X01?nU_N_oY[kZojJnj_nV_^X2ojJnj`03ojBmjonV_^_oY[k[00;oYKk[00CoY;k/
ojJnjonV_^_oY[k[0onU_^/4ojJnj`;oYkkZ0_nV_^/01?nW_^[o0000o`000?l00002ojNojP;oZKkY
00CoZ[gWojZnj?nZ_^SoZ[cW0_n[_NL3oj^ki@03oj^mion[^N?oZkcV00;oZkcV0_n[_^L2oj^kiAKo
[;kW0_n/_NL4ojbni`?oZkkW0_n[_NL00on[_^Oo0000oj^mi`06oj^mi`WoZ[gW2?nZ_NP00`3ooooo
00000?ooo`0J0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3o
ool04`3oool00ol00000oooo0?ooo`03ok1dT004oiiWTOngNi3o]g^@okMkT0;oXFR?00Go`H>AojE[
SonUJhooYF^?olb>T`03oj]`T0Co/GJA1?niOY@3ol:9V0Coc9JM0ooGYJ@3ojNmj@?oYkkY0_nW_^X6
ojJnjQCoY[k[0ol00002ojJnj`;oYkoZ00KoY[o[ojNojonW_n_oYko[ojZnj?nX`>/4oj^mi`03oj^k
iOn]_>GoZkWS00;oZkWS00KoZkcVojbfh?n/]^3o[;KPoj^kiOn//]d3oj^ji@03ojbnion[^NCoZkWT
01Oo[;kW1_n[_^L01Ol0003oZkkWoj^nion[_NOoZkkW00?oZkgW1onZ_NL:ojZmj003o`00003oool0
oooo01T0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0C
0?ooo`03o`00003oooooeifI00?o/7B@00?oWVNAokMkT?ngNi000_nQJ8l2ol63T@?oYF^?00Coc8jC
oj]`T?n[L93ofIfD1?naMY44okUnU0?o`XVH0oo<UYd2onOSM`04omNUY?nX_NWoZ;gYojRmj@;oYkgY
0onW_^T2ojNnjP04ojJnj_nW_^[oYkkZojNnjP;oY[kZ4OnV_^/2o`0000CoY[k[1OnV_n/00onW_n_o
YKo/ojFok002ojS0j`;oZkgW0_nX`N/2ojfli@03oj^ihon_^N7o[kWQ00;o[;KP00Ko/KKLojbbgOn/
/]go[;;Moj^jiOn/[MP4oj^ii005ojbnion[^>?oZkSSojbnion[]n804?n/_^L8oj^ni`03o`000?n[
_^OoZkkW00;oZkkW00?oZkgWoj^nion[_^L01_nZ_NL;ojZmj003o`00003oool0oooo01P0oooo0009
0?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0C0?ooo`03o`00003o
ooooeifI00?o/7B@00?oWVNAokMkT?ngNi000_nQJ8l2ol63T@;oYF^?0_o<SY<2oj]`T003omVMU?na
MY7o/GJA00;o/GJA1?niOY@3ol:9V0?oc9JM0_nX_NT00ooGYJCoZ;gYojRmj@04ojRmj@?oYkkY1OnW
_^X3ojJnjP03ojJnjonV_^[oY[kZ00[oY[k[0ol00002ojJnj`[oY[o[0_nU_n`4oj>ok@03ojS1jonQ
`>ooZ/;[00;oZ/;[00?o[kWQojg4jon]a>/00ona]]`00on//]go/k3Eojb]f002ojb]f0;oZkWT0_n/
Ym<00on[^>?oZj;=oj^ghP02oj^ghP;o[;kW0_n[]^43ojbni`;oZkkW00?o[;kWoj^nion[_^L03?n[
_^L00ol0003oZkkWoj^ni`04oj^ni`GoZ[gW3OnZ_NP00ol00000oooo0?ooo`0G0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool04`3oool00ol00000ooooomNM
V@03ok1dT0?o]g^@0_nQJ8l2ol63T@;oYF^?0_o<SY<2oj]`T005omVMU?naMY7o/GJAok5fTOoY/9H0
0oniOY@00ooiaiCo`XVHol:9V002ookMR`;oc9JM2onX_NT2ojNnj@03ojNnj_nW_^WoYkkY00;oYkkZ
00CoY[kZojNnj_nW_^[oYkkZ0_nV_^X6ojJnj`?o00000onV_^/=ojJoj`;oYKo/0_nS_nd2oj>nk@;o
XL3_00?oZ/;[oic1l_nL`O800on]a>/00ona]]co/LKZok>`e@02ok>`e@03ojb]f?ndZLgo[:OC00;o
[:OC00Go]J74oj^RcOn[X/goZj;=oj^ghP02ojZLb0;oZkKQ00KoZIO4oj^eh?n[]N3oZkGPoj^nion[
]>0>oj^ni`03oj^nj?l0003oZkkW00;oZkkW00CoZkkXoj^nion[_^OoZkkW0_nZ_NL2ojZnj0goZ[gX
00?o00000?ooo`3oool05`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00
003oool0oooo01<0oooo00?o0000omNMVOoGWIT00on`M903okMkT0;oXFR?0_o1Pi42ojE[S`;oc8jC
0_n[L9001OoIWICo/GJAok5fTOnaMY7ojK2F00?o^GjD00?onLNDol:9V?o2RIP00_ongH/00oo<UYgo
ZKgXojRmj@02ojRmj0SoZ;gY0onX_^T2ojNnj@WoYkkZ00?oY[k[ojJnj_l000000_l00006ojJnja7o
Y[o[00?oXkk]ojJok?nV_n`00_nP_^h01?nL`O;oV[g`oiZml?nJ_O02oi?2mP;o/LKZ00?o/k3EokS9
iondZLd00_ndZLd01_n/Ym?o]J74okFQa?neXLCoZj;=okBI^`?oZYc81?nYUl@00on[]N3oZ9?0oj^d
h002oj^dh003oj^nion[]>3oZkCP00;oZkkW00?oZkCPoj^nion[_^L01?n[_^L3oj^nj003o`000?n[
_^SoZkkX00;oZkkX00?oZkkWoj^nj?n[_^P01_nZ_^P;ojZmj003o`00003oool0oooo01H0oooo0009
0?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0C0?ooo`03o`000?oG
WIWo/7B@00?o/7B@0ongNi000onQJ8oo`H>Aol63T@03ojE[S`;oc8jC0_n[L9001OoIWICo/GJAok5f
TOnaMY7ojK2F00?o^GjD00?onLNDol:9V?o2RIP00_ongH/01Oo<UYgoZKgXojVmj?nX_NSoZKgX00Wo
Z;gY00?oZ;kYojRmjOnX_NT00_nW_^T01?nW_^[oYkkYojNnjOnW_^T3ojNnjP?o000000?oY[kZojJn
jonV_^/01onV_^/AojJoj`03ojJok?nV_n_oYKo/00;oYKo/0_nJ_O001?nS_^goS[[dohjjm?n>^_@2
ohG3o0;o^<WW00?o]:W=ol7;h_o1bn800oneXL@3okBI^`03ojZLb?ncT[Co/i:d00?oZIO40onXTl00
1?n[]>3oYi2mojN@_On[]>02ojN>_0?oZkCP00GoZkkWoj^ehOn[]N7oZkkWoj^fh@04oj^nj003o`00
0?n[_^SoZkkX00?oZkkX2?nZ_^P;ojZmj003o`00003oool0oooo01D0oooo00090?ooo`04o`00003o
ool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0B0?ooo`03o`000?oGWIWoeifI00Co/7B@
0ongNi000onQJ8oo`H>Aol63T@02ojE[S`?oc8jC00?oZg2@omVMU?oIWI@00onaMY400ooY/9Ko^GjD
okUnU002ooW7U005ol:9V?ongH_oo]f;ookMRoo<UYd01OnY_NP01?nX_NWoZ;gXojRmj?nX_NP8ojRm
j@?oZ;kY00?oYkkYojRnjOl000000_l00006ojNnjP03ojJnjonW_^[oY[k[00SoY[k[4?nV_n/00onU
_ncoYko[ojNoj`03oj>nk@03ohjjm?nO_NkoWkg^00;oN;?h0_m[`_h3ol7;hP03okFQa?o;b]Wo]9Vk
00;o]9Vk1?ncT[@00onYUlCo/Xb^ok:<[P02ojRC`0?oYi2m1?nWS[`01On[]>3oYXjkojJ>^on[]N7o
YXjl00?oZkKQ0_n[_^P2oj^ghP03o`000?n[_^SoZkkX00goZ[kX2?nZ_NP00ol00000oooo0?ooo`0E
0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool04P3oool0
0ol0003oeifIomNMV@03ok1dT005onZcVOngNi3o]g^@okMkT?nQJ8l00_o1Pi42ojE[S`;oc8jC0_n[
L902omVMU0;o/GJA0_oY/9H2okUnU0;onLND00?o`XVHookMRonY_NP02OnY_NP00onX_NSoZKgXojVm
j008ojRmj@06ojRnjOl0003o0000o`000?nX_^WoYkkZ0_nW_^T8ojNnjP03ojJnjonW_^[oYkkZ00;o
Y[k[00KoYkk[ojJnjonV_^_oY[k[ojJojonV_^/;ojJoj`WoYko[00?oWkg^ojJojonV_n/00_nI^o03
odfRmP;o>;C^0_o;b]T2okBI^`Co/i:d0onbS:h00onXTl3o/8JYok26Z@02ojN@_@04ojj3YOnWS[co
YhjlojeoX`?oYXjk0onVS[`00on[]^7oYXnmojJ?_@02oj^ghP06ojNB_ol0003oZ[SSojZhhonZ_^So
Z[WT3?nZ_^P8ojZmj003o`00003oool0oooo01@0oooo00090?ooo`04o`00003oool0oooo0?ooojgo
0000103oool00ol00000oooo0?ooo`0B0?ooo`03o`000?oGWIWoeifI00?o/7B@00Goj[>IokMkT?ng
Ni3o]g^@oj5XS`02ol63T@;oYF^?0_o<SY<2oj]`T0;ofIfD0_naMY42onV`UP;o^GjD0_oiai@00oo2
RISoo]f;ojVmj00@ojVmj003ojRmjOnX_NSo000000;o000000?oZ;kYojRmjOnX_^T00_nX_^T00onW
_^WoZ;kYojRnj@03ojNnj@WoYkkZ0_nW_^/00onV_^_oYkk[ojNnj`02ojJnj`_oY[o[2OnW_n/00onV
_n_oYko[ojJok002ojJok0;oSKOb00GoY;k/ogR_mOmh[oGoN:oeokBI^`02om?6c@;o/i:d00Cof;o1
ok:<[_nbS:ko/Xb^0on`QZT01?nWT;go[X>Uojj3YOnWS[`3ojeoX`;oYXjk0onVS[`3ojJ?_@CoYi:o
00?o0000ojNE`onWUL<00_nZ^N@01OnZ_^SoZ[[UojZjiOnZ_^SoZ[_V00WoZ[kX1_nZ_NP00ol00000
oooo0?ooo`0C0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3o
ool04P3oool00ol0003oeifIomNMV@03ok1dT004onZcVOngNi3o]g^@okMkT0?o`H>A0_nUJhl2olb>
T`;oZg2@0_oIWI@2ok5fT@;ojK2F0_niOY@2ooW7U003ol:9V?nY_NSoZKgX013oZKgX0_l000000onX
_NSoZ;gYojRmj@03ojRmj@KoZ;kY00GoYkkYojRnjOnX_^WoYkkZojRnj@09ojNnjP03ojNnjonW_^[o
Ykk[00;oYkk[0_nV_n/00onW_^_oY[o[ojJoj`02ojJoj`ooYko[00CoY[o/ojNojonW_n_oYko[0_nT
_^`00omh[oGoX[g]oj:mk@02om?6c@04ok>B]?oH_l7of;o1omRo`@;o/Xb^0on`QZT3ojj3Y@Co[GnS
00?oYXjkoj]mX_n[OJ800_nVS[`01?nZO:7oYXnmojJ?_OnYNj42ojNB_`04ojQkX_nWUL?o0000ojNE
``?oZ9W700?oZ[[UojRNc?nXW/`00_nZ^nH2ojZnj0;oZ[cV1OnZ_^P5ojZmj003o`00003oool0oooo
01<0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0B0?oo
o`03o`000?oGWIWoeifI00;o/7B@00?oj[>IokMkT?ngNi000_ngNi03ol63T@05ojE[Soo<SY?oc8jC
olb>Ton[L9000ooIWI@2ok5fT@;ojK2F00Ko^GjDooW7U?oiaiConLNDookMR`3oool>ojVmj0?o0000
1?nY_NP00onX_NWoZKgXojVmj003ojRmj@03ojRnjOnX_NWoZ;kY00OoZ;kY0_nW_^X2ojRnj@OoYkkZ
00CoYkk[ojNnj_nW_^[oYkkZ0_nW_^/00onV_n_oYkk[ojNnj`0BojNoj`CoZ;o[00CoX[g]ojRojonX
_n_oW[c^1?oH_l400onbS:kof[NfomZg]P02ok26Z@?o[X>U1?n]Oj<3oj]mXP04ojJ>_?nZO:7oZWbQ
ojJ?_@;oZG^Q00OoYi:oojQkX_nXNj;oZ7^RojNE`ol0003oZ7bT00;oZ9W70onXW/`3ojVTd@;oZ[cV
00GoZZWGojZlionZ_>OoZ[cWojZnj002ojZmi`GoZ[gX00?o00000?ooo`3oool04P3oool000T0oooo
00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0180oooo00?o0000omNMVOoG
WIT00_n`M9000ooZ/iWo]g^@okMkT002okMkT0?o`H>A00GoYF^?olb>Too<SY?oc8jCoj]`T003omVM
U005ok5fTOoY/9KojK2FonV`U_niOY@00ooiai@20?ooo`_oZKgX0ol0000;ojVmj003ojRmjOnY_NSo
ZKgX00;oZ;gY00?oZ;kYojRmjOnX_NT02onX_^T00onW_^[oZ;kYojNnjP08ojNnjP03ojNnjonW_^[o
YkkZ013oYko[1?nX_n/2ojRojP04ojRojonX_n[oZ;oZojRojP?of;o100Go/Xb^omZg]_oJ]kKo/8JY
omV_[@02ojj3Y@;oejRV0on]Oj<3oj]mXP?oZWbQ0onYNj44ojQkXP04ojNE`ol0003oZ7bTojRIa`;o
Z7jV00?oZ9k<ojR0ZOnXP:T00_nYY=43ojZYe`;oZ[cW0_nZ[m/00onZ_NOoZ[?OojZmj004ojZmj003
o`00003oool0oooo0180oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000
oooo0?ooo`0A0?ooo`04omNMVOl0003oeifIomNMV@;o/7B@00Goj[>IokMkT?ngNi3o]g^@oog@T@03
ol63T@05ojE[Soo<SY?oc8jColb>Ton[L9000ooIWI@01OnaMY7ojK2FonV`U_oY/9Ko^GjD00;onLND
103oool7ojVmj0?o00004_nY_NP2ojRmj0CoZ;gY3?nX_^T2ojNnjP;oZ;kY00?oYkkZojRnjOnW_^X0
2?nW_^X00onW_n_oYkkZojNojP02ojNojP03ojNojonW_n[oYkoZ00;oYkoZ00?oYko[ojRoj_nX_nX0
2onX_nX01OnW_n[of[NfomZg]_oJ]kKo/8JY00;ofJn]00?o[X>UomNXY_oGZ:H00_n]Oj<01?oDXJ;o
ZgfRoj]mX_n[OJ83ojYlX@?oZG^Q1?nXNj82ojQlY004o`000?nXOZKoZ7jVojQnYP?oZ82Y00CoZJCA
ojR4[_nXQ:koZZWG0_nXRK@2ojZ_f`05ojV@^onZ/mooZ[?OojZcgonZ_NP00_nZ]n82ojZmj003o`00
003oool0oooo0140oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo
0?ooo`0A0?ooo`05o`000?oGWIWoeifIomNMVOn`M9000_oZ/iT3okMkT004oog@TOo1Pi7o`H>Aol63
T@Coc8jC00GoZg2@omVMU?oIWICofIfDok5fT@03onV`UP03ooW7U03oool0oooo00D0oooo0onY_NP3
o`0001WoZKgX00?oZ;gYojVmj?nX_NT00_nX_NT00onX_^WoZ;gYojRnj@0=ojRnj@03ojNnj_nX_^Wo
Z;kY00CoYkkZ0_nX_^X2ojNnjP03ojNoj_nW_^[oYkkZ00?oYkoZ4OnX_nX00ooJ]kKoZ;oZomV_[@02
omV_[@03ojj3YOoGZ:KoejRV00;o[GnS00Coe:6Roj]mX_n[OJ;oZgfR0onZO:401?o>UigoZG^QojUk
XOo;Ti`3ojQkXP?oZ7bT00?o0000ojQnY_nXOZH00onXP:T3ojR4[P?oZ8Vd1?nYT;/01OnZ/mooZYO3
ojZG`onZ]n80Zio;00<0Z[WT00?o00000?ooo`3oool0403oool000T0oooo00Co00000?ooo`3oool0
oooo[Ol000040?ooo`03o`00003oool0oooo0140oooo00Go0000omNMVOoGWIWoeifIok1dT002onZc
V@?o]g^@00CooM2Aol63TOo1Pi7o`H>A1?o<SY<01On[L93ofIfDomVMU?oIWICo/GJA00?ojK2F203o
ool3o`0001ooZKgX00?oZ;gYojVmj?nY_NP00_nX_NT00onX_^WoZ;gYojRmj@0AojRnj@03ojRnj_nX
_^WoZ;kY00;oZ;kZ00?oYkkZojRnj_nX_^X00_nX_^X00onX_n[oZ;kZojRnjP04ojRojP;oZ;kZ1_nX
_nX01OnX_^WoZ;oYojRojOnX_nWoH`0N00;ofJn]1?oGZ:H01?n]Oj?oe:6RomBQX_n[OJ82om6LWP03
ojYlXOo>UigocYNM00;oZG^Q00Cobi>LojQkX_nXNj;oZ7^R0onXO:@00onXOZKo0000ol6=W@03ojR0
Z@?oZ8B^0onXRK@01?njSJKoZI2kojV@^onYT;/3ojZG``<0Zio;00<0Z[WT0:^Wdol000004P3oool0
00T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0140oooo00Go0000
omNMVOoGWIWoeifIok1dT002onZcV@;o]g^@0_omd943ol63T@Coc8jC1?oIWI@4onV`UPD0oooo0ol0
00020?ooobKoZKgX00CoZ;gYojVmj?nY_NSoZKgX5OnX_^T00onX_^[oZ;kYojRnj@02ojRnj@03ojRn
j_nX_^WoZ;kY00CoZ;kZ0_nX_^T2ojRnjP03ojRoj_nX_^WoZ;kY00;oZ;kY0_nX_nT00onX_^WofJn]
ojVnj@04omNXYP?oe:6R00CoZgfRom6LW_oAW9koZWbQ0_o>Uid2ojUkX@03ol^CW?nXNj;oZ7^R00;o
ai2L00CoZ7bTolB>W?o4SYco00000_o1SId01?nXP:Wo_hbOokn<WonXQ:h2okb<XP03ojR9]?njSJKo
^XfV00?oZI2k00Ko^8n[ojZG``2gT[40]i:a0:^Ob`2eV;T30:^Wd`03o`00003oool0oooo00l0oooo
00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0A0?ooo`04o`00
0?oGWIWoeifIok1dT0?oj[>I0_ngNi02oog@T@?o`H>A1?o<SY<4omVMU0?ojK2F0`3oool3o`0000H0
oooo;?nY_NP00onX_^WoZKgXojRnj@0HojRnj@03ojRnj_nX_^WoZ;kY00koZ;kY00CoZKkYomNXY_oG
Z:KoejRV0ooDXJ801?n[OJ;odIbNom6LW_nZO:42oljGW@03ojUkXOo;Ticobi>L00;oZ7^R0_o7T9`0
1onXO:Coa8jLolB>W?nXOZKo0000ol6=WOnXP:T00_noS9l01?nXQ:ko_8bRokb<X_nXRK@3okZ=YP03
ojV@^onhSj_o^8n[00<0]i:a0`2eV;T0102[Ym<0]9g20;BM`_l0000@0?ooo`002@3oool01?l00000
oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool04@3oool01?l0003oeifIomNMVOn`M903
onZcV@;o]g^@0_omd942ol63T@03on?FGoo<SY?oc8jC00;oc8jC1?oIWI@00`3ooooojK2F0?ooo`03
o`0000X0oooo;_nY_NP01?nX_^WoZKgXojVmj?nX_^T2ojVmj2;oZ;kY0onY_^T00ooGZ:KoAP0momBQ
XP02omBQXP?odIbN1?o>Uid3ol^CW004ojQkX_o7T9coai2LojQlY0;oa8jL0_o1SId01?l0003oZ82Y
okn<WonoS9l3okb<XPCo^XfV0onhSj/30;NB/@<0]IRi0`2dWL800ol00000oooo0?ooo`0>0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool04@3oool01?l0003o
eifIomNMVOn`M903onZcV@04okMkT?omd97ooM2Aoog@T@;o`H>A00GohmIOolb>Too<SY?oc8jC0?oo
o`03omVMU080oooo0_l0000?0?oooc?oZKgX00?oZ;kYojVmj?nY_NP00onX_^T2ojVnj@OoZ;kY00?o
ZKkYojRnjOnX_^T01onX_^T2ojVnj@?oZ;kY2?nY_^T00om603goe:6RomBQXP03om6LWPCocYNM0oo;
Ti`3olN@W0?oa8jL0oo1SId01?l0003o_hbOokn<WooffG02okb<XP04ookLROnjSJKo^XfVokZ=YP;o
^8n[0P3ee:/00`2gT[40jljg0>_>]`020;FH^@040>38`@2dWL80e<C:o`000100oooo00090?ooo`04
o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`0@0?ooo`04o`00003oool0oooo
0?ooo`Coj[>I00Co]g^@oog@TOomd97ooM2A0_o1Pi401OoSeUooc8jColb>Too<SY<0oooo00;ofIfD
0ol0000B0?ooocSoZKgX00?oZKkYojVmj?nY_NP00_nY_^T00onX_^WoZKkYojVnj@03ojVnj@03ojRn
jOnY_^WoZKkY00?oZ;kY3onY_^T00om603goe:6RomBQXP03om6LWP04o``0>Oo>UigocYNMoljGW@?o
bi>L0oo7T9`3olB>W0?o`HfM00Co0000okn<WonoS9oom]U`0_nlS:800oong8Wo^XfVokZ=YP02oogI
W004okR?Z`3ee:/0mMB[0;NB/@80jljg00<0]IRi0>38`@3Pb<400P3Da<X00ol00000oooo0?ooo`0>
0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0403oool0
0ol00000oooo0?ooo`020?ooo`?oj[>I00?o]g^@oog@TOomd9400oo1Pi401?oSeUooc8jColb>Too<
SY<3o`000003omVMU03oool0oooo01<0oooo?OnY_NP00onY_^WoZKgXojVmj003ojVnj003ojVnjOnY
_^SoZKkX00?oZKkY0_nY_^P<ojVnj@07ojVnj?oDXJ;oZKkYobd0?_oAW9koZKkXo``0>@03oljGW@?o
bi>L0oo7T9`3olB>W007okNc:oo1SIgo`HfMomk=Col0003o_hbOooKIL002okb<XP03ookLROnjSJKo
^XfV00;ooMVL00?o^8n[0?GDZ`3ee:/00`3[c[L01`3oool0h<S10?ooo`3oool0e<C:0?ooool00000
3`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0100oooo
00?o00000?ooo`3oool00`3oool00ooZ/iWo]g^@oog@T@02oog@T@;o`H>A0_oSeUl3o`000080oooo
00?ofIfD0?ooo`3oool05@3ooom0ojVmj005ojVnj?nY_NSoZKgXojVnj?nY_NP01?nY_^P01OnY_NSo
ZKkXojVnj?nY_^SoZKkY00CoZKkX0_nY_^T4ojVnj003ojVnjOnY_^SodIbN00;oZKkX0_o>Uid01?l0
02cobi>Lol^CW?l001L3olN@W004o`000?o4SYcoa8jLokNc:`;o`HfM00?og/e?okn<Wol000000_of
fG03ookLR@05okZ=Y_omfIcooMVL0?ooo`3ee:/00P3oool00`3[c[L0oooo0?ooo`050?ooo`03o`00
003oool0oooo00d0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo
0?ooo`0@0?ooo`03o`00003oool0oooo00<0oooo00?oj[>IokMkT?omd9400_omd9401?o1Pi7o0000
o`000?l00002olb>T`<0oooo00?ofIfD0?ooo`3oool05P3ooom5ojVmj003ojVnj?nY_NSoZKgX00;o
ZKgX00GoZKkXojVmj?nY_NSoZKkXojVmj005ojVnj003ojVmj?nY_^SoZKkX00;oZKkX00SodIbNojVm
j?nY_^So300ioljGW@2Y_^So000/ol^CW0;o000G00?oai2Lo`000?l000000_o4SY`01_ng/b_o`HfM
ol6=WOoNcDoo_hbOo`0000;om]U`0_ong8T20?ooo`03oogIW03oool0oooo00/0oooo00?o00000?oo
o`3oool03@3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo
0100oooo00?o00000?ooo`3oool0103oool00ongNi3ooM2Ao`000002o`000003ol63T@3oool0oooo
00;oc8jC0`3oool00ooIWI@0oooo0?ooo`0G0?ooodooZKgX00?oZKkXojVmj?nY_NP00onY_NP01?nY
_^SoZKgXojVmj?nY_NP30:Vmj00=oljGW@2Y_^So000/ol^CW02Y_NSo000GolN@W02Y_NSo0000olB>
W02Y_NSo]k<[ol6=W@03omk=C`03ooKIL?l00000oooo0180oooo00?o00000?ooo`3oool03@3oool0
00T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0100oooo00?o0000
0?ooo`3oool00`3oool3o`0000040?ooooomd97o`H>Aon?FG`80oooo00?oc8jC0?ooo`3oool07@3o
oom@ojVmj0D0ZKgX00?oZKgX0:Vmj02Y_NP0202Y_NP01Ol001Ooai2L0:Vmj02Y_NSo00000080ZKgX
00?o]k<[0?ooo`3oool00`3oool00ol00000oooo0?ooo`0@0?ooo`03o`00003oool0oooo00d0oooo
00090?ooo`04o`00003oool0oooo0?ooofWo000000<00000o`000?l00000@Ol000040?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo0ol000050?ooo`05ol63T@3oool0oooo0?oo
ooo<SY<08@3ooom:ojVmj1X0ZKgX203oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
00d0oooo00090?ooo`04o`00003oool0oooo0?ooofOo000000@0000001TI6@0I6AT00000@_l00004
0?ooo`03o`00003oool0oooo00l0oooo1?l000080?ooo`05ol63T@3oool0oooo0?ooooo<SY<08P3o
oom7ojVmj1P0ZKgX303oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00d0oooo0009
0?ooo`04o`00003oool0oooo0?ooofOo000000@0000001TI6@0I6AT06ATI0P000010o`0000@0oooo
00?o00000?ooo`3oool03`3oool2o`0000X0oooo00?o`H>A0?ooo`3oool0903ooom3ojVmj1X0ZKgX
3`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00`0oooo00090?ooo`04o`00003o
ool0oooo0?ooofSo000000<0000001TI6@0I6AT00P0I6AT00`00003o0000o`00000mo`0000@0oooo
00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0_0?oood3oZKgX602Y_NPD0?ooo`03o`00
003oool0oooo00h0oooo00?o00000?ooo`3oool0303oool000T0oooo00Co00000?ooo`3oool0oooo
J?l000000`0000006ATI01TI6@0301TI6Coo0000103oool00ol00000oooo0?ooo`0B0?ooo`03o`00
003oool0oooo02l0oooo>onY_NPG0:Vmj1X0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo
0?ooo`0<0?ooo`002@3oool01?l00000oooo0?ooo`3ooomXo`0000030000000I6AT06ATI00@06ATI
0P00000lo`0000@0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0?ooo`0`0?ooocOoZKgX
5`2Y_NPL0?ooo`03o`00003oool0oooo00d0oooo00?o00000?ooo`3oool0303oool000T0oooo00Co
00000?ooo`3oool0ooooJOl000000`0000006ATI01TI6@0501TI6@0300000?l0003o000003Wo0000
103oool00ol00000oooo0?ooo`0D0?ooo`;o0000<@3ooolbojVmj1L0ZKgX8@3oool00ol00000oooo
0?ooo`0<0?ooo`03o`00003oool0oooo00`0oooo00090?ooo`04o`00003oool0oooo0?ooof[o0000
00<0000001TI6@0I6AT01@0I6ATko`0000@0oooo00?o00000?ooo`3oool05P3oool00ol00000oooo
0?ooo`0_0?ooobgoZKgX6@2Y_NPT0?ooo`03o`00003oool0oooo00/0oooo00?o00000?ooo`3oool0
303oool000T0oooo00Co00000?ooo`3oool0ooooJ_l000000`0000006ATI01TI6@0501TI6@800000
>Ol000040?ooo`03o`00003oool0oooo01L0oooo00?o00000?ooo`3oool0;`3ooolZojVmj1L0ZKgX
:@3oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00`0oooo00090?ooo`04o`00003o
ool0oooo0?ooof_o000000<0000001TI6@0I6AT01P0I6AT00`00003o0000o`00000fo`0000@0oooo
00?o00000?ooo`3oool0603oool00ol00000oooo0?ooo`0_0?ooobGoZKgX5`2Y_NP]0?ooo`03o`00
003oool0oooo00/0oooo00?o00000?ooo`3oool02`3oool000T0oooo00Co00000?ooo`3oool0oooo
Jol000000`0000006ATI01TI6@0701TI6@0300000?l0003o000003Go0000103oool00ol00000oooo
0?ooo`0I0?ooo`;o0000<03ooolPojVmj1T0ZKgX<03oool00ol00000oooo0?ooo`0:0?ooo`03o`00
003oool0oooo00/0oooo00090?ooo`04o`00003oool0oooo0?ooofco000000<0000001TI6@0I6AT0
1`0I6AT00`00003o0000o`00000do`0000@0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo
0?ooo`0^0?oooagoZKgX5`2Y_NPe0?ooo`03o`00003oool0oooo00T0oooo00?o00000?ooo`3oool0
2`3oool000T0oooo00Co00000?ooo`3oool0ooooKOl000000`0000006ATI01TI6@0701TI6@030000
0?l0003o000003?o0000103oool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo02h0oooo
6?nY_NPG0:Vmj3X0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`0;0?ooo`002@3o
ool01?l00000oooo0?ooo`3ooom^o`0000030000000I6AT06ATI00L06ATI00<00000o`000?l00000
<_l000040?ooo`03o`00003oool0oooo01d0oooo00?o00000?ooo`3oool0;P3ooolCojVmj1T0ZKgX
?03oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo00/0oooo00090?ooo`04o`00003o
ool0oooo0?ooofoo000000<0000001TI6@0I6AT01@00000201TI6@0300000?l0003o0000037o0000
103oool00ol00000oooo0?ooo`0N0?ooo`;o0000;`3oool@ojVmj1L0ZKgX@@3oool00ol00000oooo
0?ooo`070?ooo`03o`00003oool0oooo00/0oooo00090?ooo`04o`00003oool0oooo0?ooofoo0000
00@0000001TI6@0I6AT00000100c<c<0100000006ATI01TI6@00000bo`0000@0oooo00?o00000?oo
o`3oool0803oool00ol00000oooo0?ooo`0]0?ooo`_oZKgX5`2Y_NQ60?ooo`03o`00003oool0oooo
00L0oooo00?o00000?ooo`3oool02P3oool000T0oooo00Co00000?ooo`3oool0ooooL?l000001000
00006ATI01TI6@00000403<c<`040000000I6AT06ATI0000037o0000103oool00ol00000oooo0?oo
o`0Q0?ooo`03o`00003oool0oooo02h0oooo1OnY_NPI0:Vmj4T0oooo00?o00000?ooo`3oool01P3o
ool00ol00000oooo0?ooo`0:0?ooo`002@3oool01?l00000oooo0?ooo`3ooomao`0000030000000I
6AT0000000D0<c<c00Co000001TI6@0I6AT00000<?l000040?ooo`03o`00003oool0oooo0280oooo
00?o00000?ooo`3oool0;P3oool3ojVmj1H0ZKgXC@3oool00ol00000oooo0?ooo`060?ooo`03o`00
003oool0oooo00X0oooo00090?ooo`04o`00003oool0oooo0?ooog;o000000@0000001TI6@000000
0000100c<c<20000000301TI6@00003o000002ko0000103oool00ol00000oooo0?ooo`0S0?ooo`03
o`00003oool0oooo02h0oooo502Y_NQB0?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3o
ool02P3oool000T0oooo00Co00000?ooo`3oool0ooooLol00000100000006ATI01TI6@00000503<c
<`030000000I6AT0000002ko0000103oool00ol00000oooo0?ooo`0T0?ooo`;o0000;`3oool@0:Vm
j5H0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0:0?ooo`002@3oool01?l00000
oooo0?ooo`3ooomdo`0000030000000I6AT0000000H0<c<c0`00000]o`0000@0oooo00?o00000?oo
o`3oool09P3oool00ol00000oooo0?ooo`0]0?ooo`d0ZKgXF03oool00ol00000oooo0?ooo`040?oo
o`03o`00003oool0oooo00X0oooo00090?ooo`04o`00003oool0oooo0?ooogGo000000<0000001TI
6@0000001`0c<c<2000002co0000103oool00ol00000oooo0?ooo`0W0?ooo`03o`00003oool0oooo
02d0oooo202Y_NQM0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool02P3oool000T0
oooo00Co00000?ooo`3oool0ooooMOl000000`0000006ATI0000000503<c<`05o`00000c<c<00000
01TI6@000000:ol000040?ooo`03o`00003oool0oooo02P0oooo00?o00000?ooo`3oool0;@3oool3
0:Vmj680oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`090?ooo`002@3oool01?l0
0000oooo0?ooo`3ooomfo`0000030000000I6AT0000000@0<c<c00Ko000003<c<`0c<c<0000001TI
6@00000Zo`0000@0oooo00?o00000?ooo`3oool0:@3oool2o`0002d0oooo00?o00000?ooo`3oool0
H`3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo00T0oooo00090?ooo`04o`00003o
ool0oooo0?ooogKo000000@0000001TI6@0I6AT000000P0c<c<01?l00000C4a<o`00000c<c<20000
000301TI6@00003o000002So0000103oool00ol00000oooo0?ooo`0[0?ooo`03o`00003oool0oooo
02X0oooo00?o00000?ooo`3oool0H`3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo
00T0oooo00090?ooo`04o`00003oool0oooo0?ooogOo000000H0000001TI6@0I6AWo000003<c<ol0
000204a<C0;o000000@0<c<c0000000I6AT00000:?l000040?ooo`03o`00003oool0oooo02`0oooo
00?o00000?ooo`3oool0:@3oool00ol00000oooo0?ooo`1T0?ooo`05o`00003oool0oooo0?ooool0
00002`3oool000T0oooo00Co00000?ooo`3oool0ooooN?l000001P0000006ATI01TI6@000000<c<c
o`0000<0C4a<00Go000003<c<`0000006ATI0000000Wo`0000@0oooo00?o00000?ooo`3oool0;@3o
ool00ol00000oooo0?ooo`0X0?ooo`03o`00003oool0oooo06D0oooo00Co00000?ooo`3ooooo0000
2`3oool000T0oooo00Co00000?ooo`3oool0ooooNOl000001@0000006ATI01TI6@00003o000000@0
C4a<00Go000003<c<ol000006ATI0000000Vo`0000@0oooo00?o00000?ooo`3oool0;P3oool2o`00
02P0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00000;0?ooo`002@3oool01?l00000
oooo0?ooo`3ooomko`0000806ATI00<00000o`00001<C4`00`1<C4`01Ol00000<c<c0000000I6AT0
000002Go0000103oool00ol00000oooo0?ooo`0`0?ooo`03o`00003oool0oooo02D0oooo00?o0000
0?ooo`3oool0IP3oool00ol00000ooooo`00000;0?ooo`002@3oool01?l00000oooo0?ooo`3ooomk
o`0000050000000I6AT0000003<c<ol00000101<C4`01?l00000000001TI6@00000Uo`0000@0oooo
00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`0T0?ooo`03o`00003oool0oooo06L0oooo
00?o00000?ooool000002P3oool000T0oooo00Co00000?ooo`3oool0ooooO?l000001@0000006ATI
0000000c<c?o000000@0C4a<00Co00000000000I6AT000009?l000040?ooo`03o`00003oool0oooo
0380oooo00?o00000?ooo`3oool08`3oool00ol00000oooo0?ooo`1X0?ooo`;o00002P3oool000T0
oooo00Co00000?ooo`3oool0ooooOOl00000100000006ATI00000?l0000304a<C006o`00001<C4co
0000o`00000I6AT000008ol000040?ooo`03o`00003oool0oooo03<0oooo0_l0000S0?ooo`03o`00
003oool0oooo06L0oooo0ol0000:0?ooo`002@3oool01?l00000oooo0?ooo`3ooomoo`00000301TI
6@00003o000000Co000000H0C4a<o`00000000006ATIo`000000000Qo`0000@0oooo00?o00000?oo
o`3oool0=@3oool00ol00000oooo0?ooo`0P0?ooo`03o`00003oool0oooo06<0oooo1?l0000=0?oo
o`002@3oool01?l00000oooo0?ooo`3ooomoo`0000040000000I6AT0000003<c<`;o000000D0IVIV
o`00001<C4co00000000000201TI6@0300000?l0003o000001ko0000103oool00ol00000oooo0?oo
o`0f0?ooo`03o`00003oool0oooo01l0oooo00?o00000?ooo`3oool0H03oool3o`000140oooo0009
0?ooo`04o`00003oool0oooo0?oooh3o000000@0000001TI6@000000<c<c0_l000001@1VIVKo0000
04a<C?l00000000000806ATI00<00000o`000?l000007Ol000040?ooo`03o`00003oool0oooo03L0
oooo00?o00000?ooo`3oool07P3oool00ol00000oooo0?ooo`1L0?ooo`Co0000503oool000T0oooo
00Co00000?ooo`3oool0ooooP_l00000200I6AT00000o`00001<C4co000006IVI_l00000C4a<0_l0
00000`0000006ATIo`00000No`0000@0oooo00?o00000?ooo`3oool0>03oool2o`0001h0oooo00?o
00000?ooo`3oool0F03oool4o`0001P0oooo00090?ooo`04o`00003oool0oooo0?oooh;o000000d0
000001TI6Ol0003o000004a<C?l00000IVIVo`00001<C4co00000000000I6AT0000001ko0000103o
ool00ol00000oooo0?ooo`0j0?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0E03o
ool4o`0001`0oooo00090?ooo`04o`00003oool0oooo0?oooh?o000000<0000001TI6@0000000_l0
000206IVIP;o000000@0<c<c0000000I6AT000007Ol000040?ooo`03o`00003oool0oooo03/0oooo
00?o00000?ooo`3oool06P3oool00ol00000oooo0?ooo`1A0?ooo`?o0000803oool000T0oooo00Co
00000?ooo`3oool0ooooQ?l000000`0000006ATI00000002o`000080IVIV0_l00000100000006ATI
01TI6@00000Lo`0000@0oooo00?o00000?ooo`3oool0?03oool00ol00000oooo0?ooo`0I0?ooo`03
o`00003oool0oooo04d0oooo1?l0000S0?ooo`002@3oool01?l00000oooo0?ooo`3ooon5o`000080
6ATI1Ol000001@1<C4co0000o`00000000006ATI01co0000103oool00ol00000oooo0?ooo`0m0?oo
o`;o00006@3oool00ol00000oooo0?ooo`190?ooo`Co00009`3oool000T0oooo00Co00000?ooo`3o
ool0ooooQOl000001P0000006ATI01TI6@00003o000004a<C0;o000000H0C4a<o`00000c<c<00000
01TI6@00000Jo`0000@0oooo00?o00000?ooo`3oool0?`3oool00ol00000oooo0?ooo`0F0?ooo`03
o`00003oool0oooo04D0oooo1?l0000[0?ooo`002@3oool01?l00000oooo0?ooo`3ooon6o`000006
0000000I6AT06ATI00000?l00000C4a<0_l000001P1<C4co000003<c<`0000006ATI000001Wo0000
103oool00ol00000oooo0?ooo`100?ooo`03o`00003oool0oooo01@0oooo00?o00000?ooo`3oool0
@`3oool3o`0002l0oooo00090?ooo`04o`00003oool0oooo0?ooohOo000000H0000001TI6@0I6AT0
0000o`00001<C4`2o`00000504a<C?l00000<c<c0000000I6AT06Ol000040?ooo`03o`00003oool0
oooo0440oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0?ooo`0o0?ooo`Co0000<P3oool0
00T0oooo00Co00000?ooo`3oool0ooooR?l00000100000006ATI01TI6Ol0000204a<C005o`00001<
C4`0C4a<o`00000000000P0I6AT00`00003o0000o`00000Eo`0000@0oooo00?o00000?ooo`3oool0
@P3oool2o`0001<0oooo00?o00000?ooo`3oool0>`3oool4o`0003H0oooo00090?ooo`04o`00003o
ool0oooo0?ooohWo000000@0000001TI6@00003o00001@1<C4`01?l00000000001TI6@00000Go`00
00@0oooo00?o00000?ooo`3oool0A03oool00ol00000oooo0?ooo`0@0?ooo`03o`00003oool0oooo
03L0oooo1?l0000j0?ooo`002@3oool01?l00000oooo0?ooo`3ooon:o`0000040000000I6AT00000
o`0000@0C4a<00Go000003<c<`0000006ATI0000000Fo`0000@0oooo00?o00000?ooo`3oool0A@3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo1?l0000n0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooon;o`0000030000000I6AT0000000;o00000`1<C4`01?l00000<c<c0000
000I6ATFo`0000@0oooo00?o00000?ooo`3oool0AP3oool00ol00000oooo0?ooo`0>0?ooo`03o`00
003oool0oooo0300oooo0ol000120?ooo`002@3oool01?l00000oooo0?ooo`3ooon<o`0000050000
000I6AWo000003<c<ol000000`1<C4`01Ol00000<c<c0000000I6AT0000001Co0000103oool00ol0
0000oooo0?ooo`170?ooo`03o`00003oool0oooo00d0oooo00?o00000?ooo`3oool0;03oool4o`00
04D0oooo00090?ooo`04o`00003oool0oooo0?ooohgo00000P00000203<c<`09o`00001<C4`0C4a<
04a<C?l00000<c<c0000000I6AT0000001?o0000103oool00ol00000oooo0?ooo`180?ooo`;o0000
3@3oool00ol00000oooo0?ooo`0X0?ooo`Co0000B@3oool000T0oooo00Co00000?ooo`3oool0oooo
S_l000030000000303<c<ol00000C4a<0080C4a<00Go000003<c<ol000006ATI0000000Bo`0000@0
oooo00?o00000?ooo`3oool0BP3oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo02@0
oooo1?l0001=0?ooo`002@3oool01?l00000oooo0?ooo`3ooon>o`0000060000000I6AT06ATI0000
000c<c?o00000P1<C4`01Ol00000<c<c0000000I6AT0000001;o0000103oool00ol00000oooo0?oo
o`1;0?ooo`03o`00003oool0oooo00T0oooo00?o00000?ooo`3oool08@3oool3o`000540oooo0009
0?ooo`04o`00003oool0oooo0?ooohoo000000D0000001TI6@0I6AT0000003<c<`02o`000080<c<c
00@0000001TI6@0I6AT000004Ol000040?ooo`03o`00003oool0oooo04`0oooo00?o00000?ooo`3o
ool0203oool00ol00000oooo0?ooo`0M0?ooo`Co0000E03oool000T0oooo00Co00000?ooo`3oool0
ooooT?l000000`0000006ATI0000000203<c<`05o`00000c<c<0<c<c03<c<`0000000P0I6ATAo`00
00@0oooo00?o00000?ooo`3oool0C@3oool2o`0000P0oooo00?o00000?ooo`3oool06@3oool4o`00
05P0oooo00090?ooo`04o`00003oool0oooo0?oooi7o000000@00000o`000000000000001@0c<c<0
100000006ATI01TI6@00000?o`0000@0oooo00?o00000?ooo`3oool0C`3oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo01D0oooo1?l0001L0?ooo`002@3oool01?l00000oooo0?ooo`3o
oonCo`0000030000000I6AT0000000D0<c<c00<0000001TI6@0000003ol000040?ooo`03o`00003o
ool0oooo0500oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0B0?ooo`?o0000H03o
ool000T0oooo00Co00000?ooo`3oool0ooooU?l000000`0000006ATI0000000503<c<`03o`00000I
6AT0000000ko0000103oool00ol00000oooo0?ooo`1A0?ooo`03o`00003oool0oooo00<0oooo00?o
00000?ooo`3oool03P3oool4o`0006<0oooo00090?ooo`04o`00003oool0oooo0?oooiGo000000<0
000001TI6@0000001@0c<c<0100000006ATI00000000000<o`0000@0oooo00?o00000?ooo`3oool0
DP3oool2o`0000<0oooo00?o00000?ooo`3oool02P3oool4o`0006L0oooo00090?ooo`04o`00003o
ool0oooo0?oooiKo00000P00000503<c<`050000000I6AT06ATI01TI6@0000002ol000040?ooo`03
o`00003oool0oooo05@0oooo00Co00000?ooo`3ooooo0000203oool4o`0006/0oooo00090?ooo`04
o`00003oool0oooo0?oooiOo00001000000303<c<`050000000I6AT06ATI01TI6@0000002_l00004
0?ooo`03o`00003oool0oooo05D0oooo00?o00000?ooool000001@3oool3o`0006l0oooo00090?oo
o`04o`00003oool0oooo0?oooiSo000000@0000001TI6@0I6AT000000P0c<c<2000000<06ATI2_l0
00040?ooo`03o`00003oool0oooo05H0oooo0_l000000`3ooooo0000o`000002o`000780oooo0009
0?ooo`04o`00003oool0oooo0?oooiWo000000D0000001TI6@000000<c<c0000000501TI6@030000
0?l0003o000000Oo0000103oool00ol00000oooo0?ooo`1G0?ooo`;o0000MP3oool000T0oooo00Co
00000?ooo`3oool0ooooV_l000000`0000006ATI0000000601TI6@0300000?l0003o000000Oo0000
103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooonKo`0000030000
000I6AT06ATI00H06ATI00<00000o`000?l000001_l000040?ooo`03o`00003oool0oooo0<l0oooo
00090?ooo`04o`00003oool0oooo0?oooico000000<0000001TI6@0I6AT01P0I6AT00`00003o0000
o`000005o`0000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo
WOl000000`0000006ATI01TI6@0501TI6@0300000?l0003o000000Go0000103oool00ol00000oooo
0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooonNo`0000030000000I6AT06ATI00D06ATI
1ol000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?oooioo0000
00<00000o`00000I6AT01@0I6AT00`00003o0000o`000003o`0000@0oooo00?o00000?ooo`3oool0
c`3oool000T0oooo00Co00000?ooo`3oool0ooooXOl000000`0000006ATI01TI6@0301TI6@030000
0?l0003o000000?o0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?oo
o`3ooonRo`0000030000000I6AT06ATI00<06ATI00<00000o`000?l000000_l000040?ooo`03o`00
003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?oooj?o00000P00000301TI6@030000
0?l0003o000000;o0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?oo
o`3ooonUo`0000030000000I6AT06ATI008000000ol000040?ooo`03o`00003oool0oooo0<l0oooo
00090?ooo`04o`00003oool0oooo0?ooojGo000000<0000001TI6@0000001Ol000040?ooo`03o`00
003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooojKo000000<00000o`000?l00000
1?l000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000
103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003o
ool0oooo0<l0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0c`3oool0
00T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`3?0?ooo`002@3ooonfo`000=40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo00090?oookKo00004@3ooonfo`0000X0oooo00090?oo
o`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool40?mo0080oooo00L0ogl00?oo
o`3oO`00oooo0?mo003oool0ogl000@0oooo00<0ogl00?ooo`3oO`000P3oool00`3oO`00oooo0?oo
o`0[0?ooo`030?mo003oool0oooo01<0oooo1@3oO`0Z0?ooo`030?mo003oool0oooo02T0oooo00?o
00000?ooo`3oool0203oool000T0oooo00Co00000?ooool00?oo003o/@3oool00ol00000oooo0?oo
o`0?0?ooo`H0ogl03P3oool00`3oO`00oooo0?mo00150?ooo`@0ogl0E@3oool00ol00000oooo0?oo
o`080?ooo`002@3oool01?l00000oooo0?ooo`3oool2o`00ojl0oooo00?o00000?ooo`3oool03`3o
ool40?mo00<0oooo00@0ogl00?ooo`3oool0ogl00P3oool00`3oO`00oooo0?ooo`060?ooo`030?mo
003oool0oooo04D0oooo0P3oO`0;0?ooo`030?mo003oool0oooo04L0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool00`3oool00ol00?l0oooo0?ooo`2/0?ooo`03o`00003o
ool0oooo00l0oooo1@3oO`001@3oool0ogl00?ooo`3oool0ogl00:/0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool0103oool00ol00?l0oooo0?ooo`2[0?ooo`03o`00003o
ool0oooo00l0oooo1P3oO`020?ooo`030?mo003oool0ogl005X0oooo00<0ogl00?ooo`3oool0C@3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`050?ooo`03o`00o`3oool0
oooo0:X0oooo00?o00000?ooo`3oool03`3oool:0?mo0080oooo00<0ogl00?ooo`3oool01`3oool0
0`3oO`00oooo0?ooo`040?ooo`030?mo003oool0oooo0140oooo00<0ogl00?ooo`3oool0<03oool0
0`3oO`00oooo0?ooo`1>0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003ooooo003o
00H0oooo0_l00?nZ0?ooo`03o`00003oool0oooo00l0oooo2`3oO`2Z0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`04o`00003oool0ooooo`00o`L0oooo0_l00?nX0?ooo`03o`00003oool0oooo
00l0oooo3P3oO`00103oool0ogl00?ooo`3oO`0Q0?ooo`030?mo003oool0oooo07l0oooo00?o0000
0?ooo`3oool0203oool000T0oooo00Go00000?ooo`3oool0ooooo`00o`080?ooo`03o`00o`3oool0
oooo0:D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`060?mo00050?ooo`3oO`00
ogl00?ooo`3oO`009@3oool00`3oO`00oooo0?ooo`180?ooo`030?mo003oool0oooo01P0oooo00@0
ogl00?ooo`3oool0ogl0603oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`020?ooo`03o`00o`3oool0oooo00H0oooo00?o003o0?ooo`3oool0Y03oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo00/0ogl000<0oooo0?mo003oool0>@3oool00`3oO`00oooo0?oo
o`0Q0?ooo`030?mo003oool0oooo00T0oooo00<0ogl00?ooo`3oool0>03oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`030?ooo`03o`00o`3oool0oooo0080oooo0`000000
0`3ooooo003o0?ooo`2T0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool00P3oool6
0?mo00030?ooo`3oO`00ogl00080ogl0K03oool00`3oO`00oooo0?ooo`0f0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo00@0oooo00?o003o0?ooo`3oool01@0000000`3o
oooo003o0?ooo`2S0?ooo`03o`00003oool0oooo00l0oooo00Ko00000?ooo`3oool0oooo0?mo003o
ool30?mo00030?ooo`3oO`00ogl00080oooo103oO`0Y0?ooo`030?mo003oool0oooo03/0oooo00<0
ogl00?ooo`3oool0>@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`05
0?ooo`03o`00o`3oool0000000@000000P3oool00ol00?l0oooo0?ooo`2Q0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool00`3oool:0?mo00030?ooo`3oO`00oooo01P0oooo00<0ogl0
0?ooo`3oool09@3oool00`3oO`00oooo0?ooo`1O0?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo00H0oooo00?o003o0000000000000`0000030?ooo`03o`00o`3oool0oooo
0:00oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`030?ooo`030?mo003oool0ogl0
00@0ogl00P3oool00`3oO`00oooo0?ooo`1X0?ooo`030?mo003oool0oooo03P0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool01`3oool01?l00?l000000000000000050?oo
o`03o`00o`3oool0oooo09l0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`050?oo
o`P0ogl000<0oooo0?mo003oool01@3oool0103oO`00oooo0?ooo`3oO`240?ooo`030?mo003oool0
oooo0180oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0203oool2o`00
o`L0oooo0_l00?nO0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0203oool60?mo
0080oooo00<0ogl00?ooo`3oool02P3oool00`3oO`00oooo0?ooo`2B0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo00X0oooo00?o003o0?ooo`3oool01@3oool00ol00?l0
oooo0?ooo`2M0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool01`3oool00`3oO`00
oooo0?ooo`040?mo0:@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
2`3oool00ol00?l0oooo0?ooo`050?ooo`03o`00o`3oool0oooo09`0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`030?ooo`040?mo003oool0oooo0?ooo`P0ogl00P3oool30?mo06X0
oooo00<0ogl00?ooo`3oool0<@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`0<0?ooo`03o`00o`3oool0oooo00D0oooo00?o003o0?ooo`3oool0V`3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo00D0oooo00<0ogl00?ooo`3oO`000P3oool00`3oO`00oooo
0?mo00040?ooo`030?mo003oool0oooo09h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool03@3oool00ol00?l0oooo0?ooo`050?ooo`03o`00o`3oool0oooo09X0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`080?ooo`80ogl000<0oooo0?mo003oO`000P3o
O`020?ooo`030?mo003oool0ogl002H0oooo00<0ogl00?ooo`3oool0@P3oool00`3oO`00oooo0?oo
o`0`0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00h0oooo0_l00?l6
0?ooo`03o`00o`3oool0oooo09T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0<
0?ooo`030?mo003oool0oooo00<0ogl0103oool00`3oO`00oooo0?ooo`030?ooo`030?mo003oool0
oooo09<0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0403oool2o`00
o`@0oooo00?o003o0?ooo`3oool0V@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
00X0oooo00<0ogl00?ooo`3oool00`3oool40?mo00L0oooo00<0ogl00?ooo`3oool0U03oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0B0?ooo`;o003o0`3oool00ol00?l0
oooo0?ooo`2H0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0303oool01@3oO`00
oooo0?mo003oool0ogl00080oooo00D0ogl00?ooo`3oool0oooo0?mo00020?ooo`030?mo003oool0
oooo06L0oooo00<0ogl00?ooo`3oool0:`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`0D0?ooo`;o003o0P3oool00ol00?l0oooo0?ooo`2G0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool03@3oool20?mo00@0oooo0P3oO`00103oool0ogl00?ooo`3oO`2I
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01H0oooo00Co003o0?oo
ool00?oo003oV03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00d0oooo00<0ogl0
0?ooo`3oool00`3oO`020?ooo`80ogl000D0oooo0?mo003oO`00oooo0?mo002F0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01H0oooo0_l00?nJ0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0303oool00`3oO`00oooo0?ooo`020?ooo`030?mo003oool0
oooo0080oooo00<0ogl00?ooo`3oO`00J@3oool00`3oO`00oooo0?ooo`0]0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0?0?ooo`030?mo003oool0oooo0080oooo00D0ogl00?ooo`3oool0oooo0?mo0004
0?ooo`030?mo003oool0ogl00080oooo00<0ogl00?ooo`3oool0S@3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool06`3oool00`3oO`00oooo0?mo001X0?ooo`030?mo003oool0oooo02T0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo0140oooo00<0ogl00?ooo`3oool00P3oool01@3oO`00oooo0?ooo`3oool0ogl0
0080oooo00<0ogl00?ooo`3oool0TP3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool03P3oool0103oO`00
oooo0?ooo`3oO`080?ooo`030?mo003oool0oooo0080oooo00<0ogl00?ooo`3oool00`3oool00`3o
O`00oooo0?ooo`2:0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0O0?ooo`030?mo003oool0oooo0900
oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0<P3oool90000ogL0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0C0?ooo`030?mo003oool0oooo00@0oooo
00D0ogl00?ooo`3oool0oooo0?mo00040?ooo`030?mo003oool0oooo00@0oooo00<0ogl00?ooo`3o
ool0703oool00`3oO`00oooo0?ooo`1V0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo0340oooo00<0003o0?ooo`3oool01`3oool30000og@0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0O0?ooo`040?mo003oool0oooo0?mo08l0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0;0?ooo`80003o
LP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01d0oooo00@0ogl00?ooo`3oool0
ogl0<P3oool00`3oO`00oooo0?ooo`1L0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo02l0oooo00<0003o0?ooo`3oool03P3oool20000og00oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0C0?ooo`030?mo003oool0oooo00T0oooo0P3oO`00103oool0ogl0
0?ooo`3oO`0;0?ooo`030?mo003oool0oooo01L0oooo00<0ogl00?ooo`3oool0I@3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0100oooo
0`000?m]0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool08`3oool01P3oO`00oooo
0?ooo`3oO`00oooo0?mo08T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0;P3oool00`000?l0oooo0?ooo`0D0?ooo`80003oJ`3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo01L0oooo0P3oO`020?ooo`030?mo003oool0oooo00L0oooo00D0ogl00?ooo`3o
O`00oooo0?mo000Q0?ooo`030?mo003oool0oooo06@0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0F0?ooo`80003oJ@3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo01d0oooo00<0ogl00?ooo`3oool0103oool00`3oO`00
oooo0?ooo`020?ooo`040?mo003oool0oooo0?mo08D0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0I0?ooo`03o`00o`3oool0oooo06H0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0O0?ooo`030?mo003oool0oooo00<0
oooo00<0ogl00?ooo`3oool0103oool00`3oO`00oooo0?ooo`1R0?ooo`030?mo003oool0oooo01h0
oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0;@3oool00`000?l0oooo
0?ooo`0I0?ooo`80003oI`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01L0oooo
0P3oO`030?ooo`040?mo003oool0oooo0?mo00@0oooo00<0ogl00?ooo`3oool0103oO`050?ooo`80
ogl0103oool00`3oO`00oooo0?ooo`1i0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo02d0oooo00<0003o0?ooo`3oool06`3oool20000ofD0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0S0?ooo`050?mo003oool0oooo0?ooo`3oO`001P3oool00`3oO`00
oooo0?ooo`210?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02d0oooo
00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`1R0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool08`3oool20?mo00H0oooo00<0ogl00?ooo`3oool00P3oool00`3oO`00oooo
0?ooo`0H0?ooo`030?mo003oool0oooo06@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0N0?ooo`03o`00o`3oool0oooo0640oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0X0?ooo`80ogl000<0oooo0?mo003oool0Q@3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0]0?ooo`030000o`3oool0
oooo01l0oooo0P000?mQ0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0803oool0
0`3oO`00oooo0?ooo`030?ooo`040?mo003oool0oooo0?mo00H0oooo00<0ogl00?ooo`3oool0603o
ool00`3oO`00oooo0?mo001T0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo02d0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`1N0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0<@3oool00`3oO`00oooo0?ooo`020?ooo`050?mo003oool0
oooo0?ooo`3oO`00M`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0^
0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0G@3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo02L0oooo00<0ogl00?ooo`3oool01P3oool00`3oO`00oooo0?ooo`02
0?ooo`030?mo003oool0oooo00/0oooo00<0ogl00?ooo`3oool0K03oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`0^0?ooo`030000o`3oool0oooo0280oooo00<0003o0?oo
o`3oool0G03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02@0oooo00<0ogl00?oo
o`3oool00P3oool00`3oO`00oooo0?ooo`020?ooo`060?mo003oool0oooo0?mo003oool0ogl04P3o
ool00`3oO`00oooo0?ooo`070?ooo`030?mo003oool0oooo05l0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0
oooo05/0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0^0?ooo`030?mo003oool0
oooo00L0oooo00<0ogl00?ooo`3oool0303oool00`3oO`00oooo0?ooo`1X0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo02h0oooo00<0003o0?ooo`3oool0903oool00`00
0?l0oooo0?ooo`1J0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool09@3oool00`3o
O`00oooo0?ooo`080?ooo`030?mo003oool0oooo01<0oooo00<0ogl00?ooo`3oool0:P3oool00`3o
O`00oooo0?ooo`0l0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02h0
oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`1I0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool09P3oool00`3oO`00oooo0?ooo`030?ooo`80ogl0103oool00`3oO`00
oooo0?ooo`0:0?ooo`040?mo003oool0oooo0?mo00@0oooo00<0ogl00?ooo`3oool0J03oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0_0?ooo`030000o`3oool0oooo02D0
oooo0P000?mI0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0:@3oool00`3oO`00
oooo0?ooo`0@0?ooo`030?mo003oool0oooo0080oooo00<0ogl00?ooo`3oool00P3oool00`3oO`00
oooo0?ooo`1Y0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02l0oooo
00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`1F0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0;03oool00`3oO`00oooo0?ooo`030?ooo`030?mo003oool0oooo0080oooo
00<0ogl00?ooo`3oool01P3oool01@3oO`00oooo0?mo003oool0ogl006d0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0W0?ooo`030000
o`3oool0oooo05D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0/0?ooo`030?mo
003oool0oooo00T0oooo00<0ogl00?ooo`3oO`002`3oool00`3oO`00oooo0?ooo`1Y0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0300oooo00<0003o0?ooo`3oool09`3o
ool00`000?l0oooo0?ooo`1E0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0<`3o
ool00`3oO`00oooo0?ooo`0@0?ooo`80ogl03@3oool00`3oO`00oooo0?ooo`1J0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0340oooo00<0003o0?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`1D0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0:03oool0
0`3oO`00oooo0?ooo`0;0?ooo`050?mo003oool0oooo0?ooo`3oO`00403oool00`3oO`00oooo0?oo
o`050?ooo`030?mo003oool0oooo05`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo05<0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`110?ooo`030?mo003oool0oooo00@0oooo0P3oO`1X
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0340oooo00<0003o0?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`1B0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0;P3oool00`3oO`00oooo0?mo00020?ooo`030?mo003oool0ogl000l0oooo00<0ogl00?oo
o`3oool00P3oO`080?ooo`030?mo003oool0ogl005d0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0540
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0^0?ooo`030?mo003oool0oooo00/0
oooo00<0ogl00?ooo`3oool02`3oool00`3oO`00oooo0?ooo`1U0?ooo`03o`00003oool0oooo00P0
oooo00090?ooo`03o`00003oool0oooo0380oooo00?o003o0?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`1@0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0=03oool00`3oO`00oooo
0?mo00030?ooo`030?mo003oool0oooo00L0oooo00<0ogl00?ooo`3oool00P3oool00`3oO`00oooo
0?ooo`0:0?ooo`030?mo003oool0oooo05T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo04l0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0l0?ooo`80ogl0103oool00`3oO`00oooo0?oo
o`020?mo0080oooo00<0ogl00?ooo`3oool02`3oool00`3oO`00oooo0?ooo`1H0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03<0oooo00<0003o0?ooo`3oool0:`3oool0
0`000?l0oooo0?ooo`1>0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0=@3oool0
0`3oO`00oooo0?mo00070?ooo`030?mo003oool0oooo00<0oooo00<0ogl00?ooo`3oool00P3oool3
0?mo00030?ooo`3oO`00oooo0680oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo04h0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo03@0oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`1=0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0>@3oool20?mo00/0oooo00@0ogl00?ooo`3o
ool0ogl0103oool00`3oO`00oooo0?ooo`1Q0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo03@0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`1<0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0?03oool00`3oO`00oooo0?ooo`020?ooo`03
0?mo003oool0oooo00@0oooo00@0ogl00?ooo`3oool0oooo0`3oO`00103oool0ogl00?mo003oO`02
0?ooo`030?mo003oool0ogl005X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0=@3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo04/0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0i0?ooo`030?mo003oool0oooo0080oooo0P3oO`000`3o
ool0ogl00?ooo`0=0?ooo`030?mo003oool0oooo05l0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0/0?ooo`03o`00o`3oool0oooo04X0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0l0?ooo`030?mo003oool0oooo00<0
ogl00`3oool00`3oO`00oooo0?ooo`020?ooo`040?mo003oool0oooo0?ooo`80ogl000<0oooo0?mo
003oO`002@3oool00`3oO`00oooo0?ooo`1C0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo03L0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`190?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0?`3oool00`3oO`00oooo0?ooo`040?ooo`05
0?mo003oool0oooo0?ooo`3oO`000`3oool00`3oO`00oooo0?ooo`1Q0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo03L0oooo00<0003o0?ooo`3oool0;03oool00`000?l0
oooo0?ooo`190?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0=03oool00`3oO`00
oooo0?ooo`0D0?ooo`030?mo003oool0oooo0080ogl000<0oooo0?mo003oO`000P3oool00`3oO`00
oooo0?ooo`1J0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03P0oooo
00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`180?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0?`3oool01@3oO`00oooo0?ooo`3oool0ogl000D0oooo00<0ogl00?ooo`3o
ool00P3oool60?mo05h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
>@3oool00`000?l0oooo0?ooo`0E0?ooo`<00000503oool00`000?l0oooo0?ooo`170?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0D03oool01@3oO`00oooo0?ooo`3oool0ogl000@0
oooo00@0ogl00?ooo`3oool0ogl0E@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0i0?ooo`030000o`3oool0oooo01@0oooo1@00000D0?ooo`030000o`3oool0oooo04H0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`120?ooo`80ogl01@3oool0103oO`00
oooo0?mo003oO`030?ooo`<0ogl0103oool00`3oO`00oooo0?ooo`1H0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo03X0oooo00<0003o0?ooo`3oool04`3oool5000001D0
oooo00?o003o0?ooo`3oool0A@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0440
oooo00<0ogl00?ooo`3oool00P3oO`0:0?ooo`030?mo003oool0oooo00@0oooo00<0ogl00?ooo`3o
ool0F03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0k0?ooo`030000
o`3oool0oooo0180oooo1@00000E0?ooo`030000o`3oool0oooo04D0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0n0?ooo`050?mo003oool0oooo0?ooo`3oO`003@3oool20?mo00D0
oooo00<0ogl00?ooo`3oool0F03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`0l0?ooo`030000o`3oool0oooo0180oooo0`00000F0?ooo`030000o`3oool0oooo04D0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`150?ooo`070?mo003oool0oooo0?ooo`3o
O`00oooo0?mo00060?ooo`030?mo003oool0oooo0140oooo00<0ogl00?ooo`3oool0B@3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0l0?ooo`030000o`3oool0oooo02`0
oooo00<0003o0?ooo`3oool0A03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03l0
oooo0P3oO`1a0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03d0oooo
00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`130?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0AP3oool00`3oO`00oooo0?ooo`030?mo00H0oooo0P3oO`000`3oool0ogl0
0?ooo`030?ooo`030?mo003oool0oooo05D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo0480oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`180?ooo`80ogl00`3oool00`3oO`00oooo0?oo
o`030?ooo`030?mo003oool0oooo05`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo0480oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`1A0?ooo`050?mo003oool0oooo0?ooo`3oO`00G03o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0o0?ooo`030000o`3oool0
oooo02`0oooo00<0003o0?ooo`3oool0@@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo04h0oooo00<0ogl00?ooo`3oO`000P3oool00`3oO`00oooo0?mo001L0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0400oooo00<0003o0?ooo`3oool0;03oool00ol0
0?l0oooo0?ooo`100?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0D03oool00`3o
O`00oooo0?ooo`1O0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0440
oooo00?o003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`100?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0C03oool00`3oO`00oooo0?mo00060?ooo`040?mo003oool0ogl00?mo
00T0oooo00<0ogl00?ooo`3oool0C@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`120?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0@03oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo03l0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`160?ooo`030?mo003oool0oooo00L0oooo
00<0ogl00?ooo`3oO`001P3oool00`3oO`00oooo0?mo001F0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo04@0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?oo
o`0n0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0C@3oool20?mo00@0oooo00@0
ogl00?ooo`3oool0ogl00`3oool00`3oO`00oooo0?ooo`1E0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo04D0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?oo
o`0n0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0FP3oool00`3oO`00oooo0?oo
o`1E0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo04D0oooo00?o003o
0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0m0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0D`3oool00`3oO`00oooo0?mo00030?ooo`80ogl01P3oool00`3oO`00oooo0?ooo`1>
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo04H0oooo00<0003o0?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`0m0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0E@3oool0103oO`00oooo0?ooo`3oO`020?ooo`030?mo003oool0oooo01H0oooo00<0ogl0
0?ooo`3oool0>`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`170?oo
o`030000o`3oool0oooo02T0oooo00<0003o0?ooo`3oool0?03oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo05`0oooo00D0ogl00?ooo`3oool0oooo0?mo001A0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo04P0oooo00<0003o0?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`0l0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`190?ooo`030000o`3oool0oooo02L0
oooo00<0003o0?ooo`3oool0?03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo04/0
oooo00<0ogl00?ooo`3oool0103oool00`3oO`00oooo0?ooo`090?ooo`80ogl0DP3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1:0?ooo`03o`00o`3oool0oooo02L0oooo
00<0003o0?ooo`3oool0>`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo04/0oooo
00<0ogl00?ooo`3oool01@3oool20?mo00D0oooo00<0ogl00?ooo`3oO`001@3oool00`3oO`00oooo
0?ooo`1=0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo04/0oooo00<0
003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0k0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0F`3oool00`3oO`00oooo0?ooo`050?ooo`030?mo003oool0oooo04`0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0U
0?ooo`030000o`3oool0oooo03/0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`16
0?ooo`030?mo003oool0oooo00d0oooo0P3oO`000`3oool0ogl00?ooo`1G0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo04d0oooo00<0003o0?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`0j0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0H@3oool00`3o
O`00oooo0?ooo`050?ooo`030?mo003oool0oooo04H0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0CP3oool00`000?oo003o0000o`0T0?ooo`030000o`3oool0oooo03X0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1G0?ooo`030?mo003oool0oooo00T0
oooo00<0ogl00?ooo`3oool00`3oool00`3oO`00oooo0?ooo`160?ooo`03o`00003oool0oooo00P0
oooo00090?ooo`03o`00003oool0oooo0540oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo
0?ooo`0j0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0D03oool00`3oO`00oooo
0?ooo`030?ooo`040?mo003oool0oooo0?mo00<0oooo0P3oO`020?ooo`030?mo003oool0oooo04h0
oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0DP3oool00`000?l0oooo
0?ooo`0P0?ooo`030000o`3oool0oooo03X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`1H0?ooo`050?mo003oool0oooo0?ooo`3oO`000P3oool00`3oO`00oooo0?ooo`1@0?ooo`03
o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo05<0oooo00<0003o0?ooo`3oool0
803oool00`000?l0oooo0?ooo`0i0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
FP3oool00`3oO`00oooo0?ooo`030?ooo`030?mo003oool0oooo00D0oooo00<0ogl00?ooo`3oool0
A`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1D0?ooo`030000o`3o
ool0oooo01l0oooo00<0003o0?ooo`3oool0>@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo05D0oooo00<0ogl00?ooo`3oool01@3oool00`3oO`00oooo0?ooo`060?ooo`80ogl0BP3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1E0?ooo`030000o`3oool0
oooo01h0oooo00<0003o0?ooo`3oool0>@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo05L0oooo00@0ogl00?ooo`3oool0ogl00`3oool00`3oO`00oooo0?ooo`040?ooo`030?mo003o
ool0ogl000D0oooo00<0ogl00?ooo`3oool0@P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1F0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0>@3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0640oooo00<0ogl00?ooo`3oO`00203oool0
0`3oO`00oooo0?ooo`130?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
05L0oooo0P000?lM0?ooo`030000o`3oool0oooo03T0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`1X0?ooo`80ogl0B03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`1I0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0>@3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo05/0oooo00H0ogl00?ooo`3oO`00oooo0?mo003oool3
0?mo04h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0FP3oool00`00
0?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo03T0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`1V0?ooo`040?mo003oool0oooo0?mo04P0oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool0F`3oool00`000?oo003o0000o`0H0?ooo`030000o`3oool0oooo
03T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1M0?ooo`050?mo003oool0oooo
0?ooo`3oO`000`3oool00`3oO`00oooo0?ooo`020?ooo`030?mo003oool0oooo04D0oooo00?o0000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0GP3oool20000oaH0oooo00<0003o0?oo
o`3oool0>@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo05h0oooo00<0ogl00?oo
o`3oool00P3oool00`3oO`00oooo0?ooo`070?ooo`030?mo003oool0oooo0480oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo03X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1V0?ooo`03
0?mo003oool0oooo0080oooo00<0ogl00?ooo`3oool0103oool00`3oO`00oooo0?ooo`0m0?ooo`03
o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0640oooo0`000?lA0?ooo`030000
o`3oool0oooo03X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1R0?ooo`80ogl0
103oool01P3oO`00oooo0?ooo`3oO`00oooo0?mo04@0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0I03oool00`000?l0oooo0?ooo`0=0?ooo`03o`00o`3oool0oooo03/0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1S0?ooo`040?mo003oool0oooo0?oo
o`80ogl00P3oool20?mo04D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0I@3oool01?l00?l0003o0000o`000?l90?ooo`80003o?P3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo06H0oooo00D0ogl00?ooo`3oO`00oooo0?mo00020?ooo`<0ogl01@3oool0
0`3oO`00oooo0?ooo`0j0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
06T0oooo1@000?l20?ooo`80003o@03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
06/0oooo00@0ogl00?ooo`3oO`00ogl0@`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`1^0?ooo`80003o@P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
06X0oooo0P3oO`030?ooo`030?mo003oool0oooo0080oooo00<0ogl00?ooo`3oool0>`3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0J03oool00`3oO`00oooo0?ooo`020?ooo`80ogl000<0oooo0?mo003o
ool00P3oO`020?ooo`030?mo003oool0ogl003T0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;80oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo06H0oooo00<0ogl00?ooo`3oool00P3oool00`3oO`00oooo0?oo
o`020?mo00030?ooo`3oO`00oooo00@0oooo00<0ogl00?ooo`3oool0>03oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0K`3oool01@3oO`00oooo0?ooo`3oO`00
oooo00@0ogl0>P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0M03oool01@3oO`00oooo0?ooo`3oool0
ogl00140oooo00<0ogl00?ooo`3oool09@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0L03oool00`3oO`00oooo0?mo00020?mo03d0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo07<0oooo00<0ogl00?ooo`3oool0?03oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0L@3o
ool30?mo00D0oooo00@0ogl00?ooo`3oool0ogl0203oool00`3oO`00oooo0?ooo`0Z0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`1b0?ooo`030?mo003oool0oooo0080oooo0P3oO`020?ooo`030?mo003o
ool0oooo03@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo07D0oooo0P3oO`020?ooo`030?mo003oool0
oooo03H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0O@3oool00ol0
0?l0oooo0?ooo`0b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0L03oool00`3o
O`00oooo0?mo00030?ooo`070?mo003oool0ogl00?mo003oool0ogl00?ooo`020?mo03<0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0O@3oool2o`00oc<0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`1e0?ooo`030?mo003oool0oooo00T0oooo00<0ogl0
0?ooo`3oO`00;P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1l0?oo
o`04o`00o`3oool0ooooo`00oc80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1f
0?ooo`030?mo003oool0ogl000<0oooo00@0ogl00?ooo`3oool0oooo0P3oO`040?ooo`030?mo003o
ool0oooo02T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0O03oool0
1Ol00?l0oooo0?ooo`3ooooo003o0340oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`1e0?ooo`030?mo003oool0oooo00<0oooo00<0ogl00?ooo`3oool0=03oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1m0?ooo`04o`00o`3oool0oooo0?ooo`;o003o;`3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo07T0oooo00<0ogl00?ooo`3oool01`3o
ool00`3oO`00oooo0?ooo`0/0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07d0oooo00?o003o0?ooo`3oool00`3oool00ol00?l0oooo0?ooo`0/0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0N@3oool01P3oO`00oooo0?ooo`3oool0ogl00?ooo`@0ogl0
0P3oool00`3oO`00oooo0?mo000Z0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo07h0oooo00?o003o0?ooo`3oool00`3oool00ol00?l0oooo0?ooo`0[0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0P03oool20?mo00030?ooo`3oO`00oooo00D0oooo00<0
ogl00?ooo`3oool09@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1o
0?ooo`03o`00o`3oool0oooo00<0oooo00?o003o0?ooo`3oool0:P3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo07T0oooo00D0ogl00?ooo`3oool0oooo0?mo00070?ooo`80ogl0:`3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1o0?ooo`03o`00o`3oool0
oooo00@0oooo00?o003o0?ooo`3oool0:@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo0880oooo00<0ogl00?ooo`3oool00P3oool00`3oO`00oooo0?ooo`0X0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0800oooo00?o003o0?ooo`3oool0103oool00ol0
0?l0oooo0?ooo`0X0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0OP3oool0103o
O`00oooo0?ooo`3oool20?mo02h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0P@3oool00ol00?l0oooo0?ooo`040?ooo`03o`00o`3oool0oooo02L0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`210?ooo`<0ogl0;P3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`220?ooo`03o`00o`3oool0oooo00@0oooo00?o003o0?ooo`3o
ool09P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo07`0oooo0P3oO`030?ooo`03
0?mo003oool0oooo00<0oooo00<0ogl00?ooo`3oool0:03oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`230?ooo`03o`00o`3oool0oooo00@0oooo00?o003o0?ooo`3oool0
9@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo07`0oooo0P3oO`050?ooo`80ogl0
00<0oooo0?mo003oO`000P3oO`0X0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo08<0oooo00?o003o0?ooo`3oool01@3oool00ol00?l0oooo0?ooo`0T0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0P03oool00`3oO`00oooo0?ooo`020?ooo`@0ogl00`3o
ool00`3oO`00oooo0?ooo`0S0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo08@0oooo00?o003o0?ooo`3oool0103oool00ol00?l0oooo0?ooo`0T0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0P@3oool00`3oO`00oooo0?mo00050?mo00030?ooo`3oO`00
oooo02H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0Q@3oool00ol0
0?l0oooo0?ooo`040?ooo`03o`00o`3oool0oooo02<0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`280?ooo`<0ogl09`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`260?ooo`04o`00o`3oool0oooo0?ooo`<0000000?o003o0?ooo`3oool08P3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo08D0oooo00D0ogl00?ooo`3oO`00oooo0?mo0003
0?ooo`040?mo003oool0ogl00?mo00<0oooo00<0ogl00?ooo`3oool06`3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`270?ooo`03o`00o`3oool0000000@0000000?o003o
0?ooo`3oool08@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo08@0oooo00D0ogl0
0?ooo`3oool0oooo0?mo00020?ooo`040?mo003oool0oooo0?mo02<0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool0R03oool00ol00?l0000000000003000000030?ooool0
0?l0oooo0240oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`230?ooo`030?mo003o
ool0oooo00L0oooo00<0ogl00?ooo`3oool08P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`290?ooo`D000000P3oool00ol00?l0oooo0?ooo`0O0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0Q`3oool01P3oO`00oooo0?mo003oool0ogl00?ooo`<0ogl0
0P3oool00`3oO`00oooo0?ooo`0M0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo08X0oooo0`0000040?ooo`03o`00o`3oool0oooo01h0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`2=0?ooo`80ogl0103oool0103oO`00oooo0?ooo`3oO`0K0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08/0oooo0_l00?l50?ooo`03o`00o`3o
ool0oooo01d0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`240?ooo`030?mo003o
ool0oooo0080ogl0103oool30?mo0080oooo00<0ogl00?ooo`3oool07@3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2<0?ooo`03o`00o`3oool0oooo00<0oooo00?o003o
0?ooo`3oool07@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo08d0oooo103oO`03
0?ooo`030?mo003oool0oooo01/0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0S@3oool00ol00?l0oooo0?ooo`030?ooo`03o`00o`3oool0oooo01`0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`2:0?ooo`050?mo003oool0ogl00?mo003oool00P3oO`06
0?ooo`030?mo003oool0oooo01P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0SP3oool00ol00?l0oooo0?ooo`030?ooo`03o`00o`3oool0oooo01/0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`280?ooo`030?mo003oool0ogl00080oooo00<0ogl00?oo
o`3oO`000`3oO`020?ooo`030?mo003oool0oooo01X0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0S`3oool00ol00?l0oooo0?ooo`030?ooo`03o`00o`3oool0oooo01X0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`290?ooo`80ogl0103oool40?mo0080
oooo00<0ogl00?ooo`3oool06P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2@0?ooo`03o`00o`3oool0oooo00<0oooo00?o003o0?ooo`3oool06@3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo08d0oooo00<0ogl00?ooo`3oO`001P3oO`000`3oool0ogl0
0?ooo`0I0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0940oooo00?o
003o0?ooo`3oool00`3oool00ol00?l0oooo0?ooo`0H0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0S`3oool00`3oO`00oooo0?ooo`040?mo0080oooo00D0ogl00?ooo`3oool0oooo
0?mo000E0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0980oooo00?o
003o0?ooo`3oool00`3oool00ol00?l0oooo0?ooo`0G0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0T@3oool60?mo01/0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0T`3oool00ol00?l0oooo0?ooo`030?ooo`03o`00o`3oool0oooo01H0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`2B0?ooo`H0ogl000@0oooo0?mo003oO`00ogl05P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2D0?ooo`03o`00o`3oool0
oooo0080oooo00?o003o0?ooo`3oool05P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo0980oooo1`3oO`0I0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
09D0oooo0_l00?l30?ooo`03o`00o`3oool0oooo01D0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`2A0?ooo`80ogl00P3oool50?mo00030?ooo`3oO`00ogl001D0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0U`3oool01?l00?l0oooo0?ooool00?lG0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0T`3oool20?mo0080oooo0`3oO`000`3o
ool0ogl00?ooo`0E0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo09P0
oooo0_l00?lH0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0T03oool00`3oO`00
oooo0?ooo`030?ooo`H0ogl05P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2I0?ooo`03o`00o`3oool0oooo01H0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`2C0?ooo`040?mo003oool0oooo0?ooo`P0ogl04`3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
V@3oool40?mo01D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo09/0oooo103oO`0C0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`2L0?ooo`040?mo003oool0oooo0?mo0180oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo09h0oooo0`3oO`0A0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2K0?ooo`030?mo003oool0oooo
00<0ogl04@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0X03oool00`3oO`00oooo0?ooo`0?0?ooo`03
o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2S0?ooo`80ogl03@3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0WP3oool00`3oO`00oooo0?ooo`030?ooo`030?mo003oool0
oooo00/0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0:00
oooo00<0ogl00?ooo`3oool00P3oool00`3oO`00oooo0?mo000:0?ooo`03o`00003oool0oooo00P0
oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`2X0?ooo`030?mo003oool0oooo00L0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;80oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo09h0oooo00<0ogl00?ooo`3oool01@3oool40?mo00L0oooo00<0ogl0
o`00003oool02@3oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo0:T0oooo00<0ogl00?ooo`3oool01P3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0[@3oool01P3o
O`00oooo0?ooo`3oO`00ooooo`0000X0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`2`0?ooo`030?mo003ooooo000000X0oooo00090?oo
okKo00004@3ooondo`0000030?mo0?l00000oooo00T0oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-294.432, -294.52, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EM experiment #2: object 2 (Coke Light can)", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[
    \(\(d2d2 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ \((data2/255. )\))\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 3;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices (custom)", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ {{{ .1,  .1}, { .5,  .5}, { .9,  .9}}, \
\[IndentingNewLine]Table[DiagonalMatrix[{ .1,  .1}], {3}], {1. , 1. , 1. }/
            3. };\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[d2d2, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({6.560000000000002`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsubsection"],

Cell[BoxData[{
    \(\(bad = Position[em, Indeterminate];\)\), "\[IndentingNewLine]", 
    \(\(If[Length[bad] > 0, 
        bad = \(bad // First\) // First];\)\ \), "\[IndentingNewLine]", 
    \(\(em\  = \ 
        If[NumberQ[bad] \[Equal] True, Take[em, {1, bad - 1}], 
          em];\)\), "\[IndentingNewLine]", 
    \(\(model2 = em // Last;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EMAllPlot[model2, g2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.01923 .09306 m
.02267 .09615 L
.03846 .11294 L
.04092 .11538 L
.05769 .13272 L
.05961 .13462 L
.07692 .15246 L
.07834 .15385 L
.09615 .17217 L
.09708 .17308 L
.11538 .1919 L
.1158 .19231 L
.13447 .21154 L
.13462 .21169 L
.15301 .23077 L
.15385 .23163 L
.17142 .25 L
.17308 .25171 L
.18963 .26923 L
.19231 .272 L
.20751 .28846 L
.21154 .29267 L
.22484 .30769 L
.23077 .31404 L
.24102 .32692 L
.24896 .34615 L
.24743 .36538 L
.24422 .38462 L
.24423 .40385 L
.24718 .42308 L
.25 .43504 L
.25286 .44231 L
.26144 .46154 L
.26923 .47475 L
.2734 .48077 L
.28846 .49851 L
.28991 .5 L
.30769 .51483 L
.31381 .51923 L
.32692 .52583 L
.34615 .53228 L
.36538 .53428 L
.38462 .53193 L
.40385 .529 L
.42308 .53295 L
.43433 .53846 L
.44231 .54403 L
.45954 .55769 L
.46154 .55927 L
.48077 .57673 L
.48096 .57692 L
.5 .59511 L
.50097 .59615 L
.51923 .61438 L
.52013 .61538 L
.53846 .63421 L
.53881 .63462 L
.55723 .65385 L
.55769 .65416 L
.57549 .67308 L
.57692 .67409 L
.59367 .69231 L
.59615 .69413 L
.61183 .71154 L
.61538 .71425 L
.63002 .73077 L
.63462 .73439 L
.65055 .75 L
.65385 .75449 L
.66876 .76923 L
.67308 .77447 L
.68714 .78846 L
.69231 .79426 L
.70579 .80769 L
.71154 .8138 L
.72474 .82692 L
.73077 .83303 L
.74406 .84615 L
.75 .85191 L
.76382 .86538 L
.76923 .8704 L
.78408 .88462 L
.78846 .88848 L
.80497 .90385 L
.80769 .90611 L
.82667 .92308 L
.82692 .92327 L
.84615 .93917 L
.84983 .94231 L
.86538 .95415 L
.87472 .96154 L
.88462 .96847 L
.90373 .98077 L
.01923 .98077 L
F
.01923 .09306 m
.02267 .09615 L
.03846 .11294 L
.04092 .11538 L
.05769 .13272 L
.05961 .13462 L
.07692 .15246 L
.07834 .15385 L
.09615 .17217 L
.09708 .17308 L
.11538 .1919 L
.1158 .19231 L
.13447 .21154 L
.13462 .21169 L
.15301 .23077 L
.15385 .23163 L
.17142 .25 L
.17308 .25171 L
.18963 .26923 L
.19231 .272 L
.20751 .28846 L
.21154 .29267 L
.22484 .30769 L
.23077 .31404 L
.24102 .32692 L
.24896 .34615 L
.24743 .36538 L
.24422 .38462 L
.24423 .40385 L
.24718 .42308 L
.25 .43504 L
.25286 .44231 L
.26144 .46154 L
.26923 .47475 L
.2734 .48077 L
.28846 .49851 L
.28991 .5 L
.30769 .51483 L
.31381 .51923 L
.32692 .52583 L
.34615 .53228 L
.36538 .53428 L
.38462 .53193 L
.40385 .529 L
.42308 .53295 L
.43433 .53846 L
.44231 .54403 L
.45954 .55769 L
.46154 .55927 L
.48077 .57673 L
Mistroke
.48096 .57692 L
.5 .59511 L
.50097 .59615 L
.51923 .61438 L
.52013 .61538 L
.53846 .63421 L
.53881 .63462 L
.55723 .65385 L
.55769 .65416 L
.57549 .67308 L
.57692 .67409 L
.59367 .69231 L
.59615 .69413 L
.61183 .71154 L
.61538 .71425 L
.63002 .73077 L
.63462 .73439 L
.65055 .75 L
.65385 .75449 L
.66876 .76923 L
.67308 .77447 L
.68714 .78846 L
.69231 .79426 L
.70579 .80769 L
.71154 .8138 L
.72474 .82692 L
.73077 .83303 L
.74406 .84615 L
.75 .85191 L
.76382 .86538 L
.76923 .8704 L
.78408 .88462 L
.78846 .88848 L
.80497 .90385 L
.80769 .90611 L
.82667 .92308 L
.82692 .92327 L
.84615 .93917 L
.84983 .94231 L
.86538 .95415 L
.87472 .96154 L
.88462 .96847 L
.90373 .98077 L
Mfstroke
.2 g
.01923 .08076 m
.03497 .09615 L
.03846 .10109 L
.05225 .11538 L
.05769 .12113 L
.07087 .13462 L
.07692 .14095 L
.08968 .15385 L
.09615 .16056 L
.10865 .17308 L
.11538 .18 L
.12777 .19231 L
.13462 .1993 L
.14703 .21154 L
.15385 .21845 L
.16641 .23077 L
.17308 .23747 L
.18592 .25 L
.19231 .25636 L
.20556 .26923 L
.21154 .27513 L
.22533 .28846 L
.23077 .29377 L
.24525 .30769 L
.25 .31228 L
.2653 .32692 L
.26923 .33067 L
.2855 .34615 L
.28846 .34894 L
.30584 .36538 L
.30769 .36711 L
.32627 .38462 L
.32692 .38522 L
.34615 .40341 L
.34701 .40385 L
.36538 .42173 L
.36687 .42308 L
.38462 .44012 L
.38699 .44231 L
.40385 .45872 L
.40683 .46154 L
.42308 .47769 L
.42623 .48077 L
.44231 .49721 L
.44638 .5 L
.46154 .51675 L
.46393 .51923 L
.48077 .53833 L
.48089 .53846 L
.4979 .55769 L
.5 .55958 L
.51657 .57692 L
.51923 .58149 L
.53312 .59615 L
.53846 .6037 L
.54946 .61538 L
.55769 .62591 L
.56585 .63462 L
.57692 .64795 L
.58244 .65385 L
.59615 .66971 L
.5993 .67308 L
.61538 .69114 L
.61648 .69231 L
.63424 .71154 L
.63462 .71204 L
.65247 .73077 L
.65385 .73242 L
.67081 .75 L
.67308 .75252 L
.68941 .76923 L
.69231 .77229 L
.70836 .78846 L
.71154 .79166 L
.72777 .80769 L
.73077 .81057 L
.74776 .82692 L
.75 .82897 L
.76849 .84615 L
.76923 .84679 L
.78846 .86374 L
.79026 .86538 L
.80769 .8797 L
.81326 .88462 L
.82692 .89459 L
.83876 .90385 L
.84615 .90804 L
.86538 .9194 L
.87473 .92308 L
.88462 .92606 L
.89614 .92308 L
.89978 .90385 L
.89491 .88462 L
.88658 .86538 L
.88462 .86057 L
.87706 .84615 L
.86652 .82692 L
.86538 .82472 L
.85493 .80769 L
.84615 .79283 L
.84324 .78846 L
.83038 .76923 L
.82692 .76336 L
.81738 .75 L
.80769 .73516 L
.80445 .73077 L
.79045 .71154 L
.78846 .70823 L
.77609 .69231 L
.76923 .68213 L
.76206 .67308 L
.75 .65643 L
.74793 .65385 L
.73257 .63462 L
.73077 .63183 L
.71704 .61538 L
.71154 .6077 L
.70181 .59615 L
.69231 .58373 L
.68654 .57692 L
.67308 .56009 L
.67103 .55769 L
.65473 .53846 L
.65385 .53728 L
.63789 .51923 L
.63462 .51512 L
.62118 .5 L
.61538 .49308 L
.60438 .48077 L
.59615 .47129 L
.58735 .46154 L
.57692 .44989 L
.57 .44231 L
.55769 .42894 L
.55225 .42308 L
.53846 .4085 L
.53406 .40385 L
.51923 .38863 L
.51534 .38462 L
.5 .36938 L
.49602 .36538 L
.48077 .35081 L
.47596 .34615 L
.46154 .333 L
.45499 .32692 L
.44231 .31604 L
.43277 .30769 L
.42308 .30003 L
.40858 .28846 L
.40385 .28516 L
.38462 .27188 L
.38029 .26923 L
.36538 .26093 L
.34615 .25376 L
.32692 .25987 L
.30769 .26474 L
.28846 .2515 L
.28646 .25 L
.26923 .23585 L
.26302 .23077 L
.25 .21952 L
.24062 .21154 L
.23077 .20284 L
.21866 .19231 L
.21154 .18596 L
.19689 .17308 L
.19231 .16899 L
.17518 .15385 L
.17308 .15198 L
.15385 .1351 L
.15332 .13462 L
.13462 .11909 L
.13066 .11538 L
.11538 .10339 L
.10778 .09615 L
.09615 .0879 L
.08483 .07692 L
.07692 .06639 L
.06208 .05769 L
.05769 .04996 L
.04002 .03846 L
.03846 .03476 L
.02021 .01923 L
.01923 .01923 L
F
0 g
.01923 .08076 m
.03497 .09615 L
.03846 .10109 L
.05225 .11538 L
.05769 .12113 L
.07087 .13462 L
.07692 .14095 L
.08968 .15385 L
.09615 .16056 L
.10865 .17308 L
.11538 .18 L
.12777 .19231 L
.13462 .1993 L
.14703 .21154 L
.15385 .21845 L
.16641 .23077 L
.17308 .23747 L
.18592 .25 L
.19231 .25636 L
.20556 .26923 L
.21154 .27513 L
.22533 .28846 L
.23077 .29377 L
.24525 .30769 L
.25 .31228 L
.2653 .32692 L
.26923 .33067 L
.2855 .34615 L
.28846 .34894 L
.30584 .36538 L
.30769 .36711 L
.32627 .38462 L
.32692 .38522 L
.34615 .40341 L
.34701 .40385 L
.36538 .42173 L
.36687 .42308 L
.38462 .44012 L
.38699 .44231 L
.40385 .45872 L
.40683 .46154 L
.42308 .47769 L
.42623 .48077 L
.44231 .49721 L
.44638 .5 L
.46154 .51675 L
.46393 .51923 L
.48077 .53833 L
.48089 .53846 L
.4979 .55769 L
Mistroke
.5 .55958 L
.51657 .57692 L
.51923 .58149 L
.53312 .59615 L
.53846 .6037 L
.54946 .61538 L
.55769 .62591 L
.56585 .63462 L
.57692 .64795 L
.58244 .65385 L
.59615 .66971 L
.5993 .67308 L
.61538 .69114 L
.61648 .69231 L
.63424 .71154 L
.63462 .71204 L
.65247 .73077 L
.65385 .73242 L
.67081 .75 L
.67308 .75252 L
.68941 .76923 L
.69231 .77229 L
.70836 .78846 L
.71154 .79166 L
.72777 .80769 L
.73077 .81057 L
.74776 .82692 L
.75 .82897 L
.76849 .84615 L
.76923 .84679 L
.78846 .86374 L
.79026 .86538 L
.80769 .8797 L
.81326 .88462 L
.82692 .89459 L
.83876 .90385 L
.84615 .90804 L
.86538 .9194 L
.87473 .92308 L
.88462 .92606 L
.89614 .92308 L
.89978 .90385 L
.89491 .88462 L
.88658 .86538 L
.88462 .86057 L
.87706 .84615 L
.86652 .82692 L
.86538 .82472 L
.85493 .80769 L
.84615 .79283 L
Mistroke
.84324 .78846 L
.83038 .76923 L
.82692 .76336 L
.81738 .75 L
.80769 .73516 L
.80445 .73077 L
.79045 .71154 L
.78846 .70823 L
.77609 .69231 L
.76923 .68213 L
.76206 .67308 L
.75 .65643 L
.74793 .65385 L
.73257 .63462 L
.73077 .63183 L
.71704 .61538 L
.71154 .6077 L
.70181 .59615 L
.69231 .58373 L
.68654 .57692 L
.67308 .56009 L
.67103 .55769 L
.65473 .53846 L
.65385 .53728 L
.63789 .51923 L
.63462 .51512 L
.62118 .5 L
.61538 .49308 L
.60438 .48077 L
.59615 .47129 L
.58735 .46154 L
.57692 .44989 L
.57 .44231 L
.55769 .42894 L
.55225 .42308 L
.53846 .4085 L
.53406 .40385 L
.51923 .38863 L
.51534 .38462 L
.5 .36938 L
.49602 .36538 L
.48077 .35081 L
.47596 .34615 L
.46154 .333 L
.45499 .32692 L
.44231 .31604 L
.43277 .30769 L
.42308 .30003 L
.40858 .28846 L
.40385 .28516 L
Mistroke
.38462 .27188 L
.38029 .26923 L
.36538 .26093 L
.34615 .25376 L
.32692 .25987 L
.30769 .26474 L
.28846 .2515 L
.28646 .25 L
.26923 .23585 L
.26302 .23077 L
.25 .21952 L
.24062 .21154 L
.23077 .20284 L
.21866 .19231 L
.21154 .18596 L
.19689 .17308 L
.19231 .16899 L
.17518 .15385 L
.17308 .15198 L
.15385 .1351 L
.15332 .13462 L
.13462 .11909 L
.13066 .11538 L
.11538 .10339 L
.10778 .09615 L
.09615 .0879 L
.08483 .07692 L
.07692 .06639 L
.06208 .05769 L
.05769 .04996 L
.04002 .03846 L
.03846 .03476 L
.02021 .01923 L
Mfstroke
.3 g
.01923 .072 m
.02293 .07692 L
.03846 .09283 L
.04058 .09615 L
.05769 .11319 L
.05955 .11538 L
.07692 .1332 L
.07834 .13462 L
.09615 .15337 L
.09718 .15385 L
.11538 .1725 L
.11615 .17308 L
.13462 .19171 L
.13529 .19231 L
.15385 .2108 L
.15464 .21154 L
.17308 .22968 L
.17419 .23077 L
.19231 .24835 L
.19398 .25 L
.21154 .26676 L
.214 .26923 L
.23077 .28491 L
.23428 .28846 L
.25 .30278 L
.25483 .30769 L
.26923 .32037 L
.27565 .32692 L
.28846 .33769 L
.29672 .34615 L
.30769 .3548 L
.31799 .36538 L
.32692 .37725 L
.33934 .38462 L
.34615 .39501 L
.36057 .40385 L
.36538 .4127 L
.37684 .42308 L
.38462 .43044 L
.39753 .44231 L
.40385 .44836 L
.41787 .46154 L
.42308 .46662 L
.43769 .48077 L
.44231 .4854 L
.45954 .5 L
.46154 .50267 L
.47772 .51923 L
.48077 .52333 L
.49526 .53846 L
.5 .54466 L
.5122 .55769 L
.51923 .56658 L
.52872 .57692 L
.53846 .58888 L
.54505 .59615 L
.55769 .61128 L
.56139 .61538 L
.57692 .63354 L
.57789 .63462 L
.59505 .65385 L
.59615 .65527 L
.61244 .67308 L
.61538 .67662 L
.62993 .69231 L
.63462 .69766 L
.64767 .71154 L
.65385 .7183 L
.66576 .73077 L
.67308 .73848 L
.68429 .75 L
.69231 .75815 L
.70334 .76923 L
.71154 .77725 L
.72303 .78846 L
.73077 .7957 L
.74351 .80769 L
.75 .81344 L
.76509 .82692 L
.76923 .83033 L
.78846 .84615 L
.78846 .84616 L
.80769 .86051 L
.81519 .86538 L
.82692 .8727 L
.84615 .88035 L
.86194 .86538 L
.85851 .84615 L
.84937 .82692 L
.84615 .81902 L
.83971 .80769 L
.82869 .78846 L
.82692 .78524 L
.81689 .76923 L
.80769 .75436 L
.80471 .75 L
.79161 .73077 L
.78846 .72579 L
.77817 .71154 L
.76923 .69846 L
.76463 .69231 L
.75059 .67308 L
.75 .67217 L
.73567 .65385 L
.73077 .64696 L
.72088 .63462 L
.71154 .62223 L
.70595 .61538 L
.69231 .59804 L
.69075 .59615 L
.67475 .57692 L
.67308 .57473 L
.65845 .55769 L
.65385 .55197 L
.64208 .53846 L
.63462 .52956 L
.6255 .51923 L
.61538 .50758 L
.60859 .5 L
.59615 .48609 L
.5913 .48077 L
.57692 .46514 L
.57358 .46154 L
.55769 .44475 L
.55538 .44231 L
.53846 .42498 L
.53662 .42308 L
.51923 .40587 L
.51722 .40385 L
.5 .3875 L
.49705 .38462 L
.48077 .36996 L
.47591 .36538 L
.46154 .3534 L
.4534 .34615 L
.44231 .33803 L
.42776 .32692 L
.42308 .32429 L
.40385 .31291 L
.38926 .30769 L
.38462 .30667 L
.37878 .30769 L
.36538 .31281 L
.34615 .30865 L
.34469 .30769 L
.32692 .29435 L
.31938 .28846 L
.30769 .27864 L
.29647 .26923 L
.28846 .26218 L
.27445 .25 L
.26923 .2453 L
.25284 .23077 L
.25 .22818 L
.23142 .21154 L
.23077 .21095 L
.21154 .19391 L
.20975 .19231 L
.19231 .17715 L
.18786 .17308 L
.17308 .1606 L
.16583 .15385 L
.15385 .14422 L
.1437 .13462 L
.13462 .12793 L
.12157 .11538 L
.11538 .11155 L
.09964 .09615 L
.09615 .09475 L
.07821 .07692 L
.07692 .07393 L
.05769 .05804 L
.05726 .05769 L
.03846 .04198 L
.03768 .03846 L
.01923 .02514 L
F
0 g
.01923 .072 m
.02293 .07692 L
.03846 .09283 L
.04058 .09615 L
.05769 .11319 L
.05955 .11538 L
.07692 .1332 L
.07834 .13462 L
.09615 .15337 L
.09718 .15385 L
.11538 .1725 L
.11615 .17308 L
.13462 .19171 L
.13529 .19231 L
.15385 .2108 L
.15464 .21154 L
.17308 .22968 L
.17419 .23077 L
.19231 .24835 L
.19398 .25 L
.21154 .26676 L
.214 .26923 L
.23077 .28491 L
.23428 .28846 L
.25 .30278 L
.25483 .30769 L
.26923 .32037 L
.27565 .32692 L
.28846 .33769 L
.29672 .34615 L
.30769 .3548 L
.31799 .36538 L
.32692 .37725 L
.33934 .38462 L
.34615 .39501 L
.36057 .40385 L
.36538 .4127 L
.37684 .42308 L
.38462 .43044 L
.39753 .44231 L
.40385 .44836 L
.41787 .46154 L
.42308 .46662 L
.43769 .48077 L
.44231 .4854 L
.45954 .5 L
.46154 .50267 L
.47772 .51923 L
.48077 .52333 L
.49526 .53846 L
Mistroke
.5 .54466 L
.5122 .55769 L
.51923 .56658 L
.52872 .57692 L
.53846 .58888 L
.54505 .59615 L
.55769 .61128 L
.56139 .61538 L
.57692 .63354 L
.57789 .63462 L
.59505 .65385 L
.59615 .65527 L
.61244 .67308 L
.61538 .67662 L
.62993 .69231 L
.63462 .69766 L
.64767 .71154 L
.65385 .7183 L
.66576 .73077 L
.67308 .73848 L
.68429 .75 L
.69231 .75815 L
.70334 .76923 L
.71154 .77725 L
.72303 .78846 L
.73077 .7957 L
.74351 .80769 L
.75 .81344 L
.76509 .82692 L
.76923 .83033 L
.78846 .84615 L
.78846 .84616 L
.80769 .86051 L
.81519 .86538 L
.82692 .8727 L
.84615 .88035 L
.86194 .86538 L
.85851 .84615 L
.84937 .82692 L
.84615 .81902 L
.83971 .80769 L
.82869 .78846 L
.82692 .78524 L
.81689 .76923 L
.80769 .75436 L
.80471 .75 L
.79161 .73077 L
.78846 .72579 L
.77817 .71154 L
.76923 .69846 L
Mistroke
.76463 .69231 L
.75059 .67308 L
.75 .67217 L
.73567 .65385 L
.73077 .64696 L
.72088 .63462 L
.71154 .62223 L
.70595 .61538 L
.69231 .59804 L
.69075 .59615 L
.67475 .57692 L
.67308 .57473 L
.65845 .55769 L
.65385 .55197 L
.64208 .53846 L
.63462 .52956 L
.6255 .51923 L
.61538 .50758 L
.60859 .5 L
.59615 .48609 L
.5913 .48077 L
.57692 .46514 L
.57358 .46154 L
.55769 .44475 L
.55538 .44231 L
.53846 .42498 L
.53662 .42308 L
.51923 .40587 L
.51722 .40385 L
.5 .3875 L
.49705 .38462 L
.48077 .36996 L
.47591 .36538 L
.46154 .3534 L
.4534 .34615 L
.44231 .33803 L
.42776 .32692 L
.42308 .32429 L
.40385 .31291 L
.38926 .30769 L
.38462 .30667 L
.37878 .30769 L
.36538 .31281 L
.34615 .30865 L
.34469 .30769 L
.32692 .29435 L
.31938 .28846 L
.30769 .27864 L
.29647 .26923 L
.28846 .26218 L
Mistroke
.27445 .25 L
.26923 .2453 L
.25284 .23077 L
.25 .22818 L
.23142 .21154 L
.23077 .21095 L
.21154 .19391 L
.20975 .19231 L
.19231 .17715 L
.18786 .17308 L
.17308 .1606 L
.16583 .15385 L
.15385 .14422 L
.1437 .13462 L
.13462 .12793 L
.12157 .11538 L
.11538 .11155 L
.09964 .09615 L
.09615 .09475 L
.07821 .07692 L
.07692 .07393 L
.05769 .05804 L
.05726 .05769 L
.03846 .04198 L
.03768 .03846 L
.01923 .02514 L
Mfstroke
.4 g
.01923 .06367 m
.02956 .07692 L
.03846 .08579 L
.04439 .09615 L
.05769 .10695 L
.06385 .11538 L
.07692 .1275 L
.08313 .13462 L
.09615 .15165 L
.10235 .15385 L
.11538 .16881 L
.12162 .17308 L
.13462 .18696 L
.14102 .19231 L
.15385 .2054 L
.16059 .21154 L
.17308 .22384 L
.18037 .23077 L
.19231 .24215 L
.20036 .25 L
.21154 .26028 L
.22058 .26923 L
.23077 .2782 L
.24103 .28846 L
.25 .29591 L
.2617 .30769 L
.26923 .31345 L
.28253 .32692 L
.28846 .33091 L
.30344 .34615 L
.30769 .34843 L
.32429 .36538 L
.32692 .37098 L
.34488 .38462 L
.34615 .38836 L
.36503 .40385 L
.36538 .40567 L
.38462 .42304 L
.38464 .42308 L
.40385 .44131 L
.40531 .44231 L
.42308 .45913 L
.42597 .46154 L
.44231 .4773 L
.44611 .48077 L
.46154 .49612 L
.46554 .5 L
.48077 .51573 L
.48422 .51923 L
.5 .53613 L
.50221 .53846 L
.51923 .55723 L
.51966 .55769 L
.53718 .57692 L
.53846 .57861 L
.55429 .59615 L
.55769 .60041 L
.57111 .61538 L
.57692 .62239 L
.58789 .63462 L
.59615 .64427 L
.6048 .65385 L
.61538 .66584 L
.62199 .67308 L
.63462 .68698 L
.63955 .69231 L
.65385 .70761 L
.65755 .71154 L
.67308 .72766 L
.67606 .73077 L
.69231 .74708 L
.69516 .75 L
.71154 .76578 L
.71495 .76923 L
.73077 .78368 L
.73554 .78846 L
.75 .80062 L
.75715 .80769 L
.76923 .81634 L
.78162 .82692 L
.78846 .8303 L
.80769 .84314 L
.82692 .84439 L
.83261 .82692 L
.82692 .81312 L
.82484 .80769 L
.81614 .78846 L
.80769 .77124 L
.80552 .76923 L
.7937 .75 L
.78846 .7413 L
.78142 .73077 L
.76923 .71248 L
.76856 .71154 L
.75485 .69231 L
.75 .68524 L
.74093 .67308 L
.73077 .6591 L
.72672 .65385 L
.71204 .63462 L
.71154 .63392 L
.69666 .61538 L
.69231 .6097 L
.68116 .59615 L
.67308 .58604 L
.66541 .57692 L
.65385 .56297 L
.64932 .55769 L
.63462 .5405 L
.63284 .53846 L
.61585 .51923 L
.61538 .51869 L
.59835 .5 L
.59615 .49759 L
.58046 .48077 L
.57692 .47703 L
.56209 .46154 L
.55769 .45707 L
.54311 .44231 L
.53846 .4378 L
.52335 .42308 L
.51923 .4193 L
.50252 .40385 L
.5 .4017 L
.48077 .38521 L
.48062 .38462 L
.46154 .37019 L
.45452 .36538 L
.44231 .3573 L
.42308 .3487 L
.40385 .34995 L
.38462 .34766 L
.38203 .34615 L
.36538 .33465 L
.35513 .32692 L
.34615 .31958 L
.33184 .30769 L
.32692 .30339 L
.30981 .28846 L
.30769 .28654 L
.28846 .2693 L
.28836 .26923 L
.26923 .25173 L
.26703 .25 L
.25 .23438 L
.24573 .23077 L
.23077 .21719 L
.22438 .21154 L
.21154 .20013 L
.20294 .19231 L
.19231 .18321 L
.1814 .17308 L
.17308 .16635 L
.15983 .15385 L
.15385 .14947 L
.13831 .13462 L
.13462 .13236 L
.117 .11538 L
.11538 .11472 L
.09615 .09636 L
.09591 .09615 L
.07692 .08009 L
.07298 .07692 L
.05769 .06423 L
.04928 .05769 L
.03846 .04897 L
.02844 .03846 L
.01923 .03381 L
F
0 g
.01923 .06367 m
.02956 .07692 L
.03846 .08579 L
.04439 .09615 L
.05769 .10695 L
.06385 .11538 L
.07692 .1275 L
.08313 .13462 L
.09615 .15165 L
.10235 .15385 L
.11538 .16881 L
.12162 .17308 L
.13462 .18696 L
.14102 .19231 L
.15385 .2054 L
.16059 .21154 L
.17308 .22384 L
.18037 .23077 L
.19231 .24215 L
.20036 .25 L
.21154 .26028 L
.22058 .26923 L
.23077 .2782 L
.24103 .28846 L
.25 .29591 L
.2617 .30769 L
.26923 .31345 L
.28253 .32692 L
.28846 .33091 L
.30344 .34615 L
.30769 .34843 L
.32429 .36538 L
.32692 .37098 L
.34488 .38462 L
.34615 .38836 L
.36503 .40385 L
.36538 .40567 L
.38462 .42304 L
.38464 .42308 L
.40385 .44131 L
.40531 .44231 L
.42308 .45913 L
.42597 .46154 L
.44231 .4773 L
.44611 .48077 L
.46154 .49612 L
.46554 .5 L
.48077 .51573 L
.48422 .51923 L
.5 .53613 L
Mistroke
.50221 .53846 L
.51923 .55723 L
.51966 .55769 L
.53718 .57692 L
.53846 .57861 L
.55429 .59615 L
.55769 .60041 L
.57111 .61538 L
.57692 .62239 L
.58789 .63462 L
.59615 .64427 L
.6048 .65385 L
.61538 .66584 L
.62199 .67308 L
.63462 .68698 L
.63955 .69231 L
.65385 .70761 L
.65755 .71154 L
.67308 .72766 L
.67606 .73077 L
.69231 .74708 L
.69516 .75 L
.71154 .76578 L
.71495 .76923 L
.73077 .78368 L
.73554 .78846 L
.75 .80062 L
.75715 .80769 L
.76923 .81634 L
.78162 .82692 L
.78846 .8303 L
.80769 .84314 L
.82692 .84439 L
.83261 .82692 L
.82692 .81312 L
.82484 .80769 L
.81614 .78846 L
.80769 .77124 L
.80552 .76923 L
.7937 .75 L
.78846 .7413 L
.78142 .73077 L
.76923 .71248 L
.76856 .71154 L
.75485 .69231 L
.75 .68524 L
.74093 .67308 L
.73077 .6591 L
.72672 .65385 L
.71204 .63462 L
Mistroke
.71154 .63392 L
.69666 .61538 L
.69231 .6097 L
.68116 .59615 L
.67308 .58604 L
.66541 .57692 L
.65385 .56297 L
.64932 .55769 L
.63462 .5405 L
.63284 .53846 L
.61585 .51923 L
.61538 .51869 L
.59835 .5 L
.59615 .49759 L
.58046 .48077 L
.57692 .47703 L
.56209 .46154 L
.55769 .45707 L
.54311 .44231 L
.53846 .4378 L
.52335 .42308 L
.51923 .4193 L
.50252 .40385 L
.5 .4017 L
.48077 .38521 L
.48062 .38462 L
.46154 .37019 L
.45452 .36538 L
.44231 .3573 L
.42308 .3487 L
.40385 .34995 L
.38462 .34766 L
.38203 .34615 L
.36538 .33465 L
.35513 .32692 L
.34615 .31958 L
.33184 .30769 L
.32692 .30339 L
.30981 .28846 L
.30769 .28654 L
.28846 .2693 L
.28836 .26923 L
.26923 .25173 L
.26703 .25 L
.25 .23438 L
.24573 .23077 L
.23077 .21719 L
.22438 .21154 L
.21154 .20013 L
.20294 .19231 L
Mistroke
.19231 .18321 L
.1814 .17308 L
.17308 .16635 L
.15983 .15385 L
.15385 .14947 L
.13831 .13462 L
.13462 .13236 L
.117 .11538 L
.11538 .11472 L
.09615 .09636 L
.09591 .09615 L
.07692 .08009 L
.07298 .07692 L
.05769 .06423 L
.04928 .05769 L
.03846 .04897 L
.02844 .03846 L
.01923 .03381 L
Mfstroke
.5 g
.03846 .05725 m
.03909 .05769 L
.05769 .0708 L
.06543 .07692 L
.07692 .08579 L
.08949 .09615 L
.09615 .10153 L
.11255 .11538 L
.11538 .11774 L
.13462 .13449 L
.13485 .13462 L
.15385 .15243 L
.15597 .15385 L
.17308 .16994 L
.17715 .17308 L
.19231 .18723 L
.19835 .19231 L
.21154 .20442 L
.2195 .21154 L
.23077 .22161 L
.24058 .23077 L
.25 .23881 L
.26158 .25 L
.26923 .256 L
.28253 .26923 L
.28846 .2731 L
.30349 .28846 L
.30769 .28995 L
.32454 .30769 L
.32692 .30975 L
.34572 .32692 L
.34615 .32734 L
.36538 .34396 L
.36798 .34615 L
.38462 .35934 L
.39269 .36538 L
.40385 .37637 L
.42308 .38229 L
.44231 .38124 L
.45429 .38462 L
.46154 .38772 L
.48077 .39972 L
.48797 .40385 L
.5 .41452 L
.51123 .42308 L
.51923 .43103 L
.53214 .44231 L
.53846 .44878 L
.55196 .46154 L
.55769 .46751 L
.57097 .48077 L
.57692 .4871 L
.58929 .5 L
.59615 .50746 L
.60701 .51923 L
.61538 .52853 L
.62422 .53846 L
.63462 .55029 L
.64096 .55769 L
.65385 .57271 L
.65733 .57692 L
.67308 .59577 L
.67338 .59615 L
.68887 .61538 L
.69231 .61968 L
.70387 .63462 L
.71154 .64449 L
.71846 .65385 L
.73077 .67031 L
.7327 .67308 L
.74651 .69231 L
.75 .69715 L
.75957 .71154 L
.76923 .72625 L
.77192 .73077 L
.78412 .75 L
.78846 .75908 L
.7942 .76923 L
.80193 .78846 L
.80506 .80769 L
.78846 .81363 L
.77859 .80769 L
.76923 .80309 L
.75015 .78846 L
.75 .78836 L
.73077 .77251 L
.72672 .76923 L
.71154 .7553 L
.70563 .75 L
.69231 .73705 L
.68577 .73077 L
.67308 .71794 L
.66674 .71154 L
.65385 .69811 L
.64834 .69231 L
.63462 .67766 L
.63042 .67308 L
.61538 .6567 L
.61287 .65385 L
.59615 .63537 L
.59551 .63462 L
.57838 .61538 L
.57692 .61374 L
.56143 .59615 L
.55769 .59199 L
.54442 .57692 L
.53846 .57039 L
.52718 .55769 L
.51923 .54916 L
.50954 .53846 L
.5 .52853 L
.49135 .51923 L
.48077 .50861 L
.47248 .5 L
.46154 .48951 L
.45284 .48077 L
.44231 .47129 L
.43232 .46154 L
.42308 .45403 L
.41085 .44231 L
.40385 .43788 L
.38834 .42308 L
.38462 .41763 L
.36953 .40385 L
.36538 .40022 L
.3482 .38462 L
.34615 .38282 L
.32693 .36538 L
.32692 .36538 L
.30769 .34635 L
.30682 .34615 L
.28846 .3279 L
.28643 .32692 L
.26923 .30981 L
.26594 .30769 L
.25 .29189 L
.24546 .28846 L
.23077 .27397 L
.22508 .26923 L
.21154 .25599 L
.20487 .25 L
.19231 .23789 L
.18484 .23077 L
.17308 .21969 L
.165 .21154 L
.15385 .20145 L
.14535 .19231 L
.13462 .18329 L
.12588 .17308 L
.11538 .16551 L
.10659 .15385 L
.09615 .14868 L
.08751 .13462 L
.07692 .12171 L
.06883 .11538 L
.05769 .10029 L
.05128 .09615 L
.03846 .07747 L
.03793 .07692 L
.02306 .05769 L
F
0 g
.03846 .05725 m
.03909 .05769 L
.05769 .0708 L
.06543 .07692 L
.07692 .08579 L
.08949 .09615 L
.09615 .10153 L
.11255 .11538 L
.11538 .11774 L
.13462 .13449 L
.13485 .13462 L
.15385 .15243 L
.15597 .15385 L
.17308 .16994 L
.17715 .17308 L
.19231 .18723 L
.19835 .19231 L
.21154 .20442 L
.2195 .21154 L
.23077 .22161 L
.24058 .23077 L
.25 .23881 L
.26158 .25 L
.26923 .256 L
.28253 .26923 L
.28846 .2731 L
.30349 .28846 L
.30769 .28995 L
.32454 .30769 L
.32692 .30975 L
.34572 .32692 L
.34615 .32734 L
.36538 .34396 L
.36798 .34615 L
.38462 .35934 L
.39269 .36538 L
.40385 .37637 L
.42308 .38229 L
.44231 .38124 L
.45429 .38462 L
.46154 .38772 L
.48077 .39972 L
.48797 .40385 L
.5 .41452 L
.51123 .42308 L
.51923 .43103 L
.53214 .44231 L
.53846 .44878 L
.55196 .46154 L
.55769 .46751 L
Mistroke
.57097 .48077 L
.57692 .4871 L
.58929 .5 L
.59615 .50746 L
.60701 .51923 L
.61538 .52853 L
.62422 .53846 L
.63462 .55029 L
.64096 .55769 L
.65385 .57271 L
.65733 .57692 L
.67308 .59577 L
.67338 .59615 L
.68887 .61538 L
.69231 .61968 L
.70387 .63462 L
.71154 .64449 L
.71846 .65385 L
.73077 .67031 L
.7327 .67308 L
.74651 .69231 L
.75 .69715 L
.75957 .71154 L
.76923 .72625 L
.77192 .73077 L
.78412 .75 L
.78846 .75908 L
.7942 .76923 L
.80193 .78846 L
.80506 .80769 L
.78846 .81363 L
.77859 .80769 L
.76923 .80309 L
.75015 .78846 L
.75 .78836 L
.73077 .77251 L
.72672 .76923 L
.71154 .7553 L
.70563 .75 L
.69231 .73705 L
.68577 .73077 L
.67308 .71794 L
.66674 .71154 L
.65385 .69811 L
.64834 .69231 L
.63462 .67766 L
.63042 .67308 L
.61538 .6567 L
.61287 .65385 L
.59615 .63537 L
Mistroke
.59551 .63462 L
.57838 .61538 L
.57692 .61374 L
.56143 .59615 L
.55769 .59199 L
.54442 .57692 L
.53846 .57039 L
.52718 .55769 L
.51923 .54916 L
.50954 .53846 L
.5 .52853 L
.49135 .51923 L
.48077 .50861 L
.47248 .5 L
.46154 .48951 L
.45284 .48077 L
.44231 .47129 L
.43232 .46154 L
.42308 .45403 L
.41085 .44231 L
.40385 .43788 L
.38834 .42308 L
.38462 .41763 L
.36953 .40385 L
.36538 .40022 L
.3482 .38462 L
.34615 .38282 L
.32693 .36538 L
.32692 .36538 L
.30769 .34635 L
.30682 .34615 L
.28846 .3279 L
.28643 .32692 L
.26923 .30981 L
.26594 .30769 L
.25 .29189 L
.24546 .28846 L
.23077 .27397 L
.22508 .26923 L
.21154 .25599 L
.20487 .25 L
.19231 .23789 L
.18484 .23077 L
.17308 .21969 L
.165 .21154 L
.15385 .20145 L
.14535 .19231 L
.13462 .18329 L
.12588 .17308 L
.11538 .16551 L
Mistroke
.10659 .15385 L
.09615 .14868 L
.08751 .13462 L
.07692 .12171 L
.06883 .11538 L
.05769 .10029 L
.05128 .09615 L
.03846 .07747 L
.03793 .07692 L
.02306 .05769 L
.03846 .05725 L
Mfstroke
.96093 .98077 m
.95879 .96154 L
.95214 .94231 L
.94396 .92308 L
.94231 .91902 L
.93442 .90385 L
.92424 .88462 L
.92308 .88209 L
.91282 .86538 L
.90385 .84924 L
.90181 .84615 L
.88888 .82692 L
.88462 .81887 L
.87661 .80769 L
.86538 .78955 L
.86459 .78846 L
.85002 .76923 L
.84615 .762 L
.83676 .75 L
.82692 .7346 L
.82391 .73077 L
.80906 .71154 L
.80769 .70851 L
.7942 .69231 L
.78846 .68284 L
.78036 .67308 L
.76923 .657 L
.76663 .65385 L
.7522 .63462 L
.75 .63253 L
.73511 .61538 L
.73077 .60841 L
.72028 .59615 L
.71154 .5838 L
.70572 .57692 L
.69231 .55922 L
.69102 .55769 L
.6756 .53846 L
.67308 .53642 L
.65805 .51923 L
.65385 .5134 L
.64239 .5 L
.63462 .48988 L
.62692 .48077 L
.61538 .4663 L
.61138 .46154 L
.59615 .44294 L
.59562 .44231 L
.57856 .42308 L
.57692 .42126 L
.56166 .40385 L
.55769 .39939 L
.54486 .38462 L
.53846 .37744 L
.52794 .36538 L
.51923 .35577 L
.51069 .34615 L
.5 .33464 L
.49297 .32692 L
.48077 .31422 L
.47461 .30769 L
.46154 .29463 L
.45547 .28846 L
.44231 .27594 L
.43536 .26923 L
.42308 .25819 L
.41409 .25 L
.40385 .24138 L
.3914 .23077 L
.38462 .22549 L
.36684 .21154 L
.36538 .21051 L
.34615 .19706 L
.33925 .19231 L
.32692 .18497 L
.30769 .17441 L
.30489 .17308 L
.28846 .16648 L
.26923 .16244 L
.25 .16928 L
.24743 .17308 L
.23077 .18414 L
.21475 .17308 L
.21154 .17076 L
.19231 .15522 L
.19062 .15385 L
.17308 .13914 L
.16773 .13462 L
.15385 .12279 L
.14527 .11538 L
.13462 .10627 L
.12299 .09615 L
.11538 .08967 L
.10077 .07692 L
.09615 .07301 L
.07854 .05769 L
.07692 .05633 L
.05769 .03943 L
.05553 .03846 L
.03846 .02478 L
.03382 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.96093 .98077 m
.95879 .96154 L
.95214 .94231 L
.94396 .92308 L
.94231 .91902 L
.93442 .90385 L
.92424 .88462 L
.92308 .88209 L
.91282 .86538 L
.90385 .84924 L
.90181 .84615 L
.88888 .82692 L
.88462 .81887 L
.87661 .80769 L
.86538 .78955 L
.86459 .78846 L
.85002 .76923 L
.84615 .762 L
.83676 .75 L
.82692 .7346 L
.82391 .73077 L
.80906 .71154 L
.80769 .70851 L
.7942 .69231 L
.78846 .68284 L
.78036 .67308 L
.76923 .657 L
.76663 .65385 L
.7522 .63462 L
.75 .63253 L
.73511 .61538 L
.73077 .60841 L
.72028 .59615 L
.71154 .5838 L
.70572 .57692 L
.69231 .55922 L
.69102 .55769 L
.6756 .53846 L
.67308 .53642 L
.65805 .51923 L
.65385 .5134 L
.64239 .5 L
.63462 .48988 L
.62692 .48077 L
.61538 .4663 L
.61138 .46154 L
.59615 .44294 L
.59562 .44231 L
.57856 .42308 L
.57692 .42126 L
Mistroke
.56166 .40385 L
.55769 .39939 L
.54486 .38462 L
.53846 .37744 L
.52794 .36538 L
.51923 .35577 L
.51069 .34615 L
.5 .33464 L
.49297 .32692 L
.48077 .31422 L
.47461 .30769 L
.46154 .29463 L
.45547 .28846 L
.44231 .27594 L
.43536 .26923 L
.42308 .25819 L
.41409 .25 L
.40385 .24138 L
.3914 .23077 L
.38462 .22549 L
.36684 .21154 L
.36538 .21051 L
.34615 .19706 L
.33925 .19231 L
.32692 .18497 L
.30769 .17441 L
.30489 .17308 L
.28846 .16648 L
.26923 .16244 L
.25 .16928 L
.24743 .17308 L
.23077 .18414 L
.21475 .17308 L
.21154 .17076 L
.19231 .15522 L
.19062 .15385 L
.17308 .13914 L
.16773 .13462 L
.15385 .12279 L
.14527 .11538 L
.13462 .10627 L
.12299 .09615 L
.11538 .08967 L
.10077 .07692 L
.09615 .07301 L
.07854 .05769 L
.07692 .05633 L
.05769 .03943 L
.05553 .03846 L
.03846 .02478 L
Mistroke
.03382 .01923 L
Mfstroke
.6 g
.07692 .0923 m
.08192 .09615 L
.09615 .10703 L
.10636 .11538 L
.11538 .12269 L
.12952 .13462 L
.13462 .1389 L
.15195 .15385 L
.15385 .15549 L
.17308 .17263 L
.17368 .17308 L
.19231 .19028 L
.19476 .19231 L
.21154 .20775 L
.21576 .21154 L
.23077 .22511 L
.23669 .23077 L
.25 .24236 L
.25756 .25 L
.26923 .25942 L
.27839 .26923 L
.28846 .276 L
.29927 .28846 L
.30769 .29133 L
.32034 .30769 L
.32692 .3147 L
.34192 .32692 L
.34615 .33279 L
.36068 .34615 L
.36538 .35059 L
.38195 .36538 L
.38462 .36784 L
.40385 .38441 L
.40466 .38462 L
.42308 .39944 L
.434 .40385 L
.44231 .40857 L
.46154 .41071 L
.48077 .41621 L
.49246 .42308 L
.5 .4278 L
.51878 .44231 L
.51923 .44265 L
.53846 .45935 L
.54102 .46154 L
.55769 .4774 L
.56128 .48077 L
.57692 .49653 L
.58038 .5 L
.59615 .51658 L
.59866 .51923 L
.61538 .53745 L
.6163 .53846 L
.63341 .55769 L
.63462 .55911 L
.64995 .57692 L
.65385 .5816 L
.66592 .59615 L
.67308 .60496 L
.68138 .61538 L
.69231 .62926 L
.69637 .63462 L
.71098 .65385 L
.71154 .65457 L
.7251 .67308 L
.73077 .68094 L
.73836 .69231 L
.75 .71023 L
.75078 .71154 L
.76392 .73077 L
.76923 .74354 L
.77302 .75 L
.77968 .76923 L
.76923 .78483 L
.75 .77601 L
.74127 .76923 L
.73077 .76189 L
.71707 .75 L
.71154 .74551 L
.6938 .73077 L
.69231 .72782 L
.67492 .71154 L
.67308 .70914 L
.65615 .69231 L
.65385 .68962 L
.63787 .67308 L
.63462 .66941 L
.62005 .65385 L
.61538 .64862 L
.6026 .63462 L
.59615 .62741 L
.58538 .61538 L
.57692 .60596 L
.56824 .59615 L
.55769 .58447 L
.55104 .57692 L
.53846 .56317 L
.53361 .55769 L
.51923 .54226 L
.51582 .53846 L
.5 .52188 L
.49757 .51923 L
.48077 .50213 L
.47877 .5 L
.46154 .48312 L
.45926 .48077 L
.44231 .46503 L
.43885 .46154 L
.42308 .44812 L
.41717 .44231 L
.40385 .43297 L
.39357 .42308 L
.38462 .41227 L
.37534 .40385 L
.36538 .3952 L
.35366 .38462 L
.34615 .37808 L
.33207 .36538 L
.32692 .36086 L
.31068 .34615 L
.30769 .34349 L
.28952 .32692 L
.28846 .32596 L
.26923 .3079 L
.26886 .30769 L
.25 .28942 L
.24865 .28846 L
.23077 .27111 L
.22846 .26923 L
.21154 .25283 L
.20839 .25 L
.19231 .23451 L
.18847 .23077 L
.17308 .21611 L
.16874 .21154 L
.15385 .19759 L
.14926 .19231 L
.13462 .17891 L
.13008 .17308 L
.11538 .1599 L
.11136 .15385 L
.09615 .13968 L
.0935 .13462 L
.07731 .11538 L
.07692 .11489 L
.0625 .09615 L
F
0 g
.07692 .0923 m
.08192 .09615 L
.09615 .10703 L
.10636 .11538 L
.11538 .12269 L
.12952 .13462 L
.13462 .1389 L
.15195 .15385 L
.15385 .15549 L
.17308 .17263 L
.17368 .17308 L
.19231 .19028 L
.19476 .19231 L
.21154 .20775 L
.21576 .21154 L
.23077 .22511 L
.23669 .23077 L
.25 .24236 L
.25756 .25 L
.26923 .25942 L
.27839 .26923 L
.28846 .276 L
.29927 .28846 L
.30769 .29133 L
.32034 .30769 L
.32692 .3147 L
.34192 .32692 L
.34615 .33279 L
.36068 .34615 L
.36538 .35059 L
.38195 .36538 L
.38462 .36784 L
.40385 .38441 L
.40466 .38462 L
.42308 .39944 L
.434 .40385 L
.44231 .40857 L
.46154 .41071 L
.48077 .41621 L
.49246 .42308 L
.5 .4278 L
.51878 .44231 L
.51923 .44265 L
.53846 .45935 L
.54102 .46154 L
.55769 .4774 L
.56128 .48077 L
.57692 .49653 L
.58038 .5 L
.59615 .51658 L
Mistroke
.59866 .51923 L
.61538 .53745 L
.6163 .53846 L
.63341 .55769 L
.63462 .55911 L
.64995 .57692 L
.65385 .5816 L
.66592 .59615 L
.67308 .60496 L
.68138 .61538 L
.69231 .62926 L
.69637 .63462 L
.71098 .65385 L
.71154 .65457 L
.7251 .67308 L
.73077 .68094 L
.73836 .69231 L
.75 .71023 L
.75078 .71154 L
.76392 .73077 L
.76923 .74354 L
.77302 .75 L
.77968 .76923 L
.76923 .78483 L
.75 .77601 L
.74127 .76923 L
.73077 .76189 L
.71707 .75 L
.71154 .74551 L
.6938 .73077 L
.69231 .72782 L
.67492 .71154 L
.67308 .70914 L
.65615 .69231 L
.65385 .68962 L
.63787 .67308 L
.63462 .66941 L
.62005 .65385 L
.61538 .64862 L
.6026 .63462 L
.59615 .62741 L
.58538 .61538 L
.57692 .60596 L
.56824 .59615 L
.55769 .58447 L
.55104 .57692 L
.53846 .56317 L
.53361 .55769 L
.51923 .54226 L
.51582 .53846 L
Mistroke
.5 .52188 L
.49757 .51923 L
.48077 .50213 L
.47877 .5 L
.46154 .48312 L
.45926 .48077 L
.44231 .46503 L
.43885 .46154 L
.42308 .44812 L
.41717 .44231 L
.40385 .43297 L
.39357 .42308 L
.38462 .41227 L
.37534 .40385 L
.36538 .3952 L
.35366 .38462 L
.34615 .37808 L
.33207 .36538 L
.32692 .36086 L
.31068 .34615 L
.30769 .34349 L
.28952 .32692 L
.28846 .32596 L
.26923 .3079 L
.26886 .30769 L
.25 .28942 L
.24865 .28846 L
.23077 .27111 L
.22846 .26923 L
.21154 .25283 L
.20839 .25 L
.19231 .23451 L
.18847 .23077 L
.17308 .21611 L
.16874 .21154 L
.15385 .19759 L
.14926 .19231 L
.13462 .17891 L
.13008 .17308 L
.11538 .1599 L
.11136 .15385 L
.09615 .13968 L
.0935 .13462 L
.07731 .11538 L
.07692 .11489 L
.0625 .09615 L
.07692 .0923 L
Mfstroke
.7 g
.09615 .1139 m
.09817 .11538 L
.11538 .12826 L
.12324 .13462 L
.13462 .14385 L
.14648 .15385 L
.15385 .16009 L
.16887 .17308 L
.17308 .17676 L
.1907 .19231 L
.19231 .19376 L
.21154 .2111 L
.21203 .21154 L
.23077 .22866 L
.23295 .23077 L
.25 .2461 L
.25375 .25 L
.26923 .2633 L
.27451 .26923 L
.28846 .27992 L
.29533 .28846 L
.30769 .29493 L
.31645 .30769 L
.32692 .3197 L
.33849 .32692 L
.34615 .33827 L
.35451 .34615 L
.36538 .35673 L
.37473 .36538 L
.38462 .37489 L
.3955 .38462 L
.40385 .39242 L
.4175 .40385 L
.42308 .40874 L
.44231 .42297 L
.4425 .42308 L
.46154 .43203 L
.48077 .43826 L
.49642 .44231 L
.5 .4437 L
.51923 .45518 L
.53087 .46154 L
.53846 .47013 L
.5524 .48077 L
.55769 .48719 L
.57203 .5 L
.57692 .50572 L
.59076 .51923 L
.59615 .5254 L
.60872 .53846 L
.61538 .5461 L
.62597 .55769 L
.63462 .56777 L
.64257 .57692 L
.65385 .59042 L
.6586 .59615 L
.67308 .61411 L
.67408 .61538 L
.68943 .63462 L
.69231 .63837 L
.70384 .65385 L
.71154 .66458 L
.71725 .67308 L
.72978 .69231 L
.73077 .69387 L
.74492 .71154 L
.75 .7278 L
.75186 .73077 L
.75694 .75 L
.75 .75751 L
.73262 .75 L
.73077 .74889 L
.71154 .73502 L
.70422 .73077 L
.69231 .71854 L
.68335 .71154 L
.67308 .70052 L
.66398 .69231 L
.65385 .68142 L
.64533 .67308 L
.63462 .66149 L
.62721 .65385 L
.61538 .64094 L
.60948 .63462 L
.59615 .61995 L
.59201 .61538 L
.57692 .59871 L
.57464 .59615 L
.55769 .57743 L
.55725 .57692 L
.53927 .55769 L
.53846 .55623 L
.52102 .53846 L
.51923 .53527 L
.50226 .51923 L
.5 .51469 L
.48211 .5 L
.48077 .49465 L
.46694 .48077 L
.46154 .47534 L
.4471 .46154 L
.44231 .45693 L
.42611 .44231 L
.42308 .43952 L
.40391 .42308 L
.40385 .42302 L
.38462 .40643 L
.38174 .40385 L
.36538 .38986 L
.35951 .38462 L
.34615 .37315 L
.33746 .36538 L
.32692 .35623 L
.3157 .34615 L
.30769 .33909 L
.29426 .32692 L
.28846 .3217 L
.27317 .30769 L
.26923 .30407 L
.2524 .28846 L
.25 .28621 L
.23196 .26923 L
.23077 .26809 L
.21185 .25 L
.21154 .24969 L
.19231 .23097 L
.19211 .23077 L
.17308 .21194 L
.17271 .21154 L
.15385 .19246 L
.15372 .19231 L
.1353 .17308 L
.13462 .17231 L
.1176 .15385 L
.11538 .1512 L
.1011 .13462 L
.09615 .12777 L
.08772 .11538 L
F
0 g
.09615 .1139 m
.09817 .11538 L
.11538 .12826 L
.12324 .13462 L
.13462 .14385 L
.14648 .15385 L
.15385 .16009 L
.16887 .17308 L
.17308 .17676 L
.1907 .19231 L
.19231 .19376 L
.21154 .2111 L
.21203 .21154 L
.23077 .22866 L
.23295 .23077 L
.25 .2461 L
.25375 .25 L
.26923 .2633 L
.27451 .26923 L
.28846 .27992 L
.29533 .28846 L
.30769 .29493 L
.31645 .30769 L
.32692 .3197 L
.33849 .32692 L
.34615 .33827 L
.35451 .34615 L
.36538 .35673 L
.37473 .36538 L
.38462 .37489 L
.3955 .38462 L
.40385 .39242 L
.4175 .40385 L
.42308 .40874 L
.44231 .42297 L
.4425 .42308 L
.46154 .43203 L
.48077 .43826 L
.49642 .44231 L
.5 .4437 L
.51923 .45518 L
.53087 .46154 L
.53846 .47013 L
.5524 .48077 L
.55769 .48719 L
.57203 .5 L
.57692 .50572 L
.59076 .51923 L
.59615 .5254 L
.60872 .53846 L
Mistroke
.61538 .5461 L
.62597 .55769 L
.63462 .56777 L
.64257 .57692 L
.65385 .59042 L
.6586 .59615 L
.67308 .61411 L
.67408 .61538 L
.68943 .63462 L
.69231 .63837 L
.70384 .65385 L
.71154 .66458 L
.71725 .67308 L
.72978 .69231 L
.73077 .69387 L
.74492 .71154 L
.75 .7278 L
.75186 .73077 L
.75694 .75 L
.75 .75751 L
.73262 .75 L
.73077 .74889 L
.71154 .73502 L
.70422 .73077 L
.69231 .71854 L
.68335 .71154 L
.67308 .70052 L
.66398 .69231 L
.65385 .68142 L
.64533 .67308 L
.63462 .66149 L
.62721 .65385 L
.61538 .64094 L
.60948 .63462 L
.59615 .61995 L
.59201 .61538 L
.57692 .59871 L
.57464 .59615 L
.55769 .57743 L
.55725 .57692 L
.53927 .55769 L
.53846 .55623 L
.52102 .53846 L
.51923 .53527 L
.50226 .51923 L
.5 .51469 L
.48211 .5 L
.48077 .49465 L
.46694 .48077 L
.46154 .47534 L
Mistroke
.4471 .46154 L
.44231 .45693 L
.42611 .44231 L
.42308 .43952 L
.40391 .42308 L
.40385 .42302 L
.38462 .40643 L
.38174 .40385 L
.36538 .38986 L
.35951 .38462 L
.34615 .37315 L
.33746 .36538 L
.32692 .35623 L
.3157 .34615 L
.30769 .33909 L
.29426 .32692 L
.28846 .3217 L
.27317 .30769 L
.26923 .30407 L
.2524 .28846 L
.25 .28621 L
.23196 .26923 L
.23077 .26809 L
.21185 .25 L
.21154 .24969 L
.19231 .23097 L
.19211 .23077 L
.17308 .21194 L
.17271 .21154 L
.15385 .19246 L
.15372 .19231 L
.1353 .17308 L
.13462 .17231 L
.1176 .15385 L
.11538 .1512 L
.1011 .13462 L
.09615 .12777 L
.08772 .11538 L
.09615 .1139 L
Mfstroke
.8 g
.13462 .1499 m
.13962 .15385 L
.15385 .16534 L
.16309 .17308 L
.17308 .18162 L
.18543 .19231 L
.19231 .19843 L
.20709 .21154 L
.21154 .21563 L
.22825 .23077 L
.23077 .23314 L
.24902 .25 L
.25 .25095 L
.26923 .26897 L
.26946 .26923 L
.28846 .28675 L
.28979 .28846 L
.30769 .30409 L
.31004 .30769 L
.32692 .32526 L
.3304 .32692 L
.34615 .34452 L
.34783 .34615 L
.36538 .36401 L
.3668 .36538 L
.38462 .3837 L
.38558 .38462 L
.40385 .40352 L
.40421 .40385 L
.40385 .40915 L
.39457 .40385 L
.38462 .39632 L
.36767 .38462 L
.36538 .38277 L
.34615 .36745 L
.34379 .36538 L
.32692 .35109 L
.32133 .34615 L
.30769 .33431 L
.29943 .32692 L
.28846 .31716 L
.27803 .30769 L
.26923 .29966 L
.25708 .28846 L
.25 .28183 L
.23656 .26923 L
.23077 .26366 L
.21646 .25 L
.21154 .24513 L
.1968 .23077 L
.19231 .22618 L
.17764 .21154 L
.17308 .2067 L
.1591 .19231 L
.15385 .18644 L
.14144 .17308 L
.13462 .16477 L
.12541 .15385 L
F
0 g
.13462 .1499 m
.13962 .15385 L
.15385 .16534 L
.16309 .17308 L
.17308 .18162 L
.18543 .19231 L
.19231 .19843 L
.20709 .21154 L
.21154 .21563 L
.22825 .23077 L
.23077 .23314 L
.24902 .25 L
.25 .25095 L
.26923 .26897 L
.26946 .26923 L
.28846 .28675 L
.28979 .28846 L
.30769 .30409 L
.31004 .30769 L
.32692 .32526 L
.3304 .32692 L
.34615 .34452 L
.34783 .34615 L
.36538 .36401 L
.3668 .36538 L
.38462 .3837 L
.38558 .38462 L
.40385 .40352 L
.40421 .40385 L
.40385 .40915 L
.39457 .40385 L
.38462 .39632 L
.36767 .38462 L
.36538 .38277 L
.34615 .36745 L
.34379 .36538 L
.32692 .35109 L
.32133 .34615 L
.30769 .33431 L
.29943 .32692 L
.28846 .31716 L
.27803 .30769 L
.26923 .29966 L
.25708 .28846 L
.25 .28183 L
.23656 .26923 L
.23077 .26366 L
.21646 .25 L
.21154 .24513 L
.1968 .23077 L
Mistroke
.19231 .22618 L
.17764 .21154 L
.17308 .2067 L
.1591 .19231 L
.15385 .18644 L
.14144 .17308 L
.13462 .16477 L
.12541 .15385 L
.13462 .1499 L
Mfstroke
.9 g
.17308 .18784 m
.17856 .19231 L
.19231 .20409 L
.20098 .21154 L
.21154 .22109 L
.22243 .23077 L
.23077 .23863 L
.2432 .25 L
.25 .25664 L
.2634 .26923 L
.26923 .27515 L
.28301 .28846 L
.28846 .29425 L
.30192 .30769 L
.30769 .31426 L
.31965 .32692 L
.30769 .3284 L
.30599 .32692 L
.28846 .31179 L
.28386 .30769 L
.26923 .29456 L
.26254 .28846 L
.25 .27681 L
.24186 .26923 L
.23077 .25857 L
.22178 .25 L
.21154 .23977 L
.20234 .23077 L
.19231 .22028 L
.1837 .21154 L
.17308 .19965 L
.16629 .19231 L
F
0 g
.17308 .18784 m
.17856 .19231 L
.19231 .20409 L
.20098 .21154 L
.21154 .22109 L
.22243 .23077 L
.23077 .23863 L
.2432 .25 L
.25 .25664 L
.2634 .26923 L
.26923 .27515 L
.28301 .28846 L
.28846 .29425 L
.30192 .30769 L
.30769 .31426 L
.31965 .32692 L
.30769 .3284 L
.30599 .32692 L
.28846 .31179 L
.28386 .30769 L
.26923 .29456 L
.26254 .28846 L
.25 .27681 L
.24186 .26923 L
.23077 .25857 L
.22178 .25 L
.21154 .23977 L
.20234 .23077 L
.19231 .22028 L
.1837 .21154 L
.17308 .19965 L
.16629 .19231 L
.17308 .18784 L
s
1 g
.23077 .24802 m
.23319 .25 L
.25 .2678 L
.2517 .26923 L
.25 .26934 L
.24988 .26923 L
.23077 .25084 L
.22988 .25 L
F
0 g
.23077 .24802 m
.23319 .25 L
.25 .2678 L
.2517 .26923 L
.25 .26934 L
.24988 .26923 L
.23077 .25084 L
.22988 .25 L
.23077 .24802 L
s
.8 g
.44231 .43992 m
.44751 .44231 L
.46154 .45149 L
.48077 .45917 L
.49019 .46154 L
.5 .46434 L
.51923 .47069 L
.53551 .48077 L
.53846 .48241 L
.55769 .49804 L
.56031 .5 L
.57692 .51555 L
.58108 .51923 L
.59615 .53469 L
.59999 .53846 L
.61538 .55515 L
.61777 .55769 L
.63462 .57682 L
.6347 .57692 L
.65196 .59615 L
.65385 .59886 L
.66768 .61538 L
.67308 .62264 L
.6822 .63462 L
.69231 .64886 L
.69571 .65385 L
.70848 .67308 L
.71154 .67785 L
.72025 .69231 L
.72981 .71154 L
.71154 .72226 L
.69682 .71154 L
.69231 .70801 L
.67433 .69231 L
.67308 .69118 L
.65411 .67308 L
.65385 .67306 L
.63505 .65385 L
.63462 .65372 L
.61671 .63462 L
.61538 .63404 L
.59885 .61538 L
.59615 .61403 L
.57886 .59615 L
.57692 .59392 L
.56155 .57692 L
.55769 .57408 L
.54422 .55769 L
.53846 .54869 L
.52674 .53846 L
.51923 .52734 L
.50895 .51923 L
.5 .50609 L
.49044 .5 L
.48077 .48501 L
.47679 .48077 L
.46154 .46413 L
.45902 .46154 L
.44231 .44347 L
.44108 .44231 L
F
0 g
.44231 .43992 m
.44751 .44231 L
.46154 .45149 L
.48077 .45917 L
.49019 .46154 L
.5 .46434 L
.51923 .47069 L
.53551 .48077 L
.53846 .48241 L
.55769 .49804 L
.56031 .5 L
.57692 .51555 L
.58108 .51923 L
.59615 .53469 L
.59999 .53846 L
.61538 .55515 L
.61777 .55769 L
.63462 .57682 L
.6347 .57692 L
.65196 .59615 L
.65385 .59886 L
.66768 .61538 L
.67308 .62264 L
.6822 .63462 L
.69231 .64886 L
.69571 .65385 L
.70848 .67308 L
.71154 .67785 L
.72025 .69231 L
.72981 .71154 L
.71154 .72226 L
.69682 .71154 L
.69231 .70801 L
.67433 .69231 L
.67308 .69118 L
.65411 .67308 L
.65385 .67306 L
.63505 .65385 L
.63462 .65372 L
.61671 .63462 L
.61538 .63404 L
.59885 .61538 L
.59615 .61403 L
.57886 .59615 L
.57692 .59392 L
.56155 .57692 L
.55769 .57408 L
.54422 .55769 L
.53846 .54869 L
.52674 .53846 L
Mistroke
.51923 .52734 L
.50895 .51923 L
.5 .50609 L
.49044 .5 L
.48077 .48501 L
.47679 .48077 L
.46154 .46413 L
.45902 .46154 L
.44231 .44347 L
.44108 .44231 L
.44231 .43992 L
Mfstroke
.9 g
.51923 .49207 m
.53846 .49877 L
.54039 .5 L
.55769 .50947 L
.56791 .51923 L
.57692 .52494 L
.58929 .53846 L
.59615 .5432 L
.60837 .55769 L
.61538 .56325 L
.62941 .57692 L
.63462 .58498 L
.64468 .59615 L
.65385 .60869 L
.65917 .61538 L
.67285 .63462 L
.67308 .63493 L
.68622 .65385 L
.69231 .66337 L
.69798 .67308 L
.70553 .69231 L
.69231 .69465 L
.68874 .69231 L
.67308 .68061 L
.66446 .67308 L
.65385 .66868 L
.64384 .65385 L
.63462 .64884 L
.62467 .63462 L
.61538 .62856 L
.60633 .61538 L
.59615 .60784 L
.585 .59615 L
.57692 .58663 L
.56883 .57692 L
.55769 .5647 L
.55268 .55769 L
.53846 .53964 L
.53699 .53846 L
.52173 .51923 L
.51923 .51559 L
.50922 .5 L
F
0 g
.51923 .49207 m
.53846 .49877 L
.54039 .5 L
.55769 .50947 L
.56791 .51923 L
.57692 .52494 L
.58929 .53846 L
.59615 .5432 L
.60837 .55769 L
.61538 .56325 L
.62941 .57692 L
.63462 .58498 L
.64468 .59615 L
.65385 .60869 L
.65917 .61538 L
.67285 .63462 L
.67308 .63493 L
.68622 .65385 L
.69231 .66337 L
.69798 .67308 L
.70553 .69231 L
.69231 .69465 L
.68874 .69231 L
.67308 .68061 L
.66446 .67308 L
.65385 .66868 L
.64384 .65385 L
.63462 .64884 L
.62467 .63462 L
.61538 .62856 L
.60633 .61538 L
.59615 .60784 L
.585 .59615 L
.57692 .58663 L
.56883 .57692 L
.55769 .5647 L
.55268 .55769 L
.53846 .53964 L
.53699 .53846 L
.52173 .51923 L
.51923 .51559 L
.50922 .5 L
.51923 .49207 L
s
1 g
.55769 .53035 m
.57255 .53846 L
.57692 .5416 L
.59585 .55769 L
.59615 .55797 L
.61507 .57692 L
.61538 .57726 L
.63218 .59615 L
.63462 .59902 L
.64765 .61538 L
.65385 .62368 L
.66133 .63462 L
.65385 .65083 L
.63512 .63462 L
.63462 .63414 L
.61568 .61538 L
.61538 .61508 L
.59766 .59615 L
.59615 .59447 L
.58073 .57692 L
.57692 .57228 L
.5651 .55769 L
.55769 .54688 L
.55249 .53846 L
F
0 g
.55769 .53035 m
.57255 .53846 L
.57692 .5416 L
.59585 .55769 L
.59615 .55797 L
.61507 .57692 L
.61538 .57726 L
.63218 .59615 L
.63462 .59902 L
.64765 .61538 L
.65385 .62368 L
.66133 .63462 L
.65385 .65083 L
.63512 .63462 L
.63462 .63414 L
.61568 .61538 L
.61538 .61508 L
.59766 .59615 L
.59615 .59447 L
.58073 .57692 L
.57692 .57228 L
.5651 .55769 L
.55769 .54688 L
.55249 .53846 L
.55769 .53035 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.663 .741 .908 r
.39902 .59806 .40512 .60374 .41536 .60067 .40929 .59498 Mtetra
.663 .742 .908 r
.40929 .59498 .41536 .60067 .42565 .5976 .41959 .59189 Mtetra
.663 .742 .909 r
.41959 .59189 .42565 .5976 .43597 .59451 .42994 .58878 Mtetra
.42994 .58878 .43597 .59451 .44633 .59142 .44033 .58567 Mtetra
.44033 .58567 .44633 .59142 .45673 .58831 .45075 .58255 Mtetra
.45075 .58255 .45673 .58831 .46718 .5852 .46122 .57942 Mtetra
.662 .742 .909 r
.46122 .57942 .46718 .5852 .47766 .58208 .47173 .57628 Mtetra
.47173 .57628 .47766 .58208 .48818 .57895 .48228 .57313 Mtetra
.662 .743 .91 r
.48228 .57313 .48818 .57895 .49874 .57581 .49287 .56998 Mtetra
.49287 .56998 .49874 .57581 .50935 .57266 .5035 .56682 Mtetra
.5035 .56682 .50935 .57266 .51999 .5695 .51417 .56364 Mtetra
.51417 .56364 .51999 .5695 .53068 .56633 .52489 .56046 Mtetra
.662 .744 .911 r
.52489 .56046 .53068 .56633 .54141 .56315 .53564 .55726 Mtetra
.53564 .55726 .54141 .56315 .55218 .55995 .54644 .55406 Mtetra
.54644 .55406 .55218 .55995 .563 .55675 .55729 .55084 Mtetra
.662 .745 .911 r
.55729 .55084 .563 .55675 .57385 .55353 .56817 .5476 Mtetra
.662 .745 .912 r
.56817 .5476 .57385 .55353 .58475 .5503 .5791 .54435 Mtetra
.5791 .54435 .58475 .5503 .59569 .54705 .59007 .54109 Mtetra
.59007 .54109 .59569 .54705 .60668 .54378 .60109 .5378 Mtetra
.662 .746 .912 r
.60109 .5378 .60668 .54378 .61771 .5405 .61214 .5345 Mtetra
.663 .746 .912 r
.61214 .5345 .61771 .5405 .62878 .53719 .62325 .53118 Mtetra
.62325 .53118 .62878 .53719 .6399 .53387 .63439 .52783 Mtetra
.63439 .52783 .6399 .53387 .65106 .53053 .64559 .52446 Mtetra
.64559 .52446 .65106 .53053 .66226 .52717 .65682 .52107 Mtetra
.664 .746 .912 r
.65682 .52107 .66226 .52717 .67351 .52378 .6681 .51766 Mtetra
.664 .746 .911 r
.6681 .51766 .67351 .52378 .68481 .52038 .67943 .51423 Mtetra
.67943 .51423 .68481 .52038 .69615 .51696 .6908 .51077 Mtetra
.6908 .51077 .69615 .51696 .70753 .51352 .70221 .5073 Mtetra
.665 .746 .911 r
.70221 .5073 .70753 .51352 .71896 .51006 .71367 .50381 Mtetra
.665 .746 .91 r
.71367 .50381 .71896 .51006 .73043 .50658 .72518 .5003 Mtetra
.665 .745 .91 r
.72518 .5003 .73043 .50658 .74195 .50309 .73673 .49677 Mtetra
.73673 .49677 .74195 .50309 .75352 .49958 .74833 .49322 Mtetra
.74833 .49322 .75352 .49958 .76514 .49606 .75998 .48967 Mtetra
.665 .744 .909 r
.75998 .48967 .76514 .49606 .7768 .49252 .77167 .48609 Mtetra
.77167 .48609 .7768 .49252 .7885 .48897 .78341 .48251 Mtetra
.78341 .48251 .7885 .48897 .80026 .48541 .7952 .47891 Mtetra
.665 .743 .909 r
.7952 .47891 .80026 .48541 .81206 .48184 .80704 .4753 Mtetra
.664 .743 .909 r
.80704 .4753 .81206 .48184 .82392 .47825 .81893 .4717 Mtetra
.663 .743 .909 r
.81893 .4717 .82392 .47825 .83582 .47467 .83087 .46813 Mtetra
.657 .742 .912 r
.83087 .46813 .83582 .47467 .84777 .47112 .84288 .46472 Mtetra
.64 .741 .921 r
.84288 .46472 .84777 .47112 .8598 .46773 .85498 .46176 Mtetra
.598 .739 .943 r
.85498 .46176 .8598 .46773 .87192 .46476 .86725 .45981 Mtetra
.493 .733 .979 r
.86725 .45981 .87192 .46476 .88419 .46267 .87976 .45948 Mtetra
.253 .676 .963 r
.87976 .45948 .88419 .46267 .89668 .46191 .89254 .46089 Mtetra
0 .512 .75 r
.89254 .46089 .89668 .46191 .90939 .46245 .90549 .46298 Mtetra
.121 0 0 r
.90549 .46298 .90939 .46245 .92222 .46325 .91836 .46357 Mtetra
.245 .759 .776 r
.91836 .46357 .92222 .46325 .93495 .46251 .93087 .46058 Mtetra
.728 .957 .946 r
.93087 .46058 .93495 .46251 .94736 .45876 .94294 .45361 Mtetra
.813 .849 .876 r
.94294 .45361 .94736 .45876 .95944 .45202 .95473 .4443 Mtetra
.786 .764 .833 r
.95473 .4443 .95944 .45202 .97134 .44379 .96653 .435 Mtetra
.663 .742 .908 r
.39287 .59235 .39902 .59806 .40929 .59498 .40316 .58925 Mtetra
.663 .742 .909 r
.40316 .58925 .40929 .59498 .41959 .59189 .4135 .58614 Mtetra
.4135 .58614 .41959 .59189 .42994 .58878 .42387 .58302 Mtetra
.42387 .58302 .42994 .58878 .44033 .58567 .43428 .57989 Mtetra
.43428 .57989 .44033 .58567 .45075 .58255 .44473 .57675 Mtetra
.662 .742 .909 r
.44473 .57675 .45075 .58255 .46122 .57942 .45523 .5736 Mtetra
.662 .742 .91 r
.45523 .5736 .46122 .57942 .47173 .57628 .46576 .57045 Mtetra
.662 .743 .91 r
.46576 .57045 .47173 .57628 .48228 .57313 .47633 .56729 Mtetra
.47633 .56729 .48228 .57313 .49287 .56998 .48695 .56412 Mtetra
.48695 .56412 .49287 .56998 .5035 .56682 .49761 .56095 Mtetra
.662 .743 .911 r
.49761 .56095 .5035 .56682 .51417 .56364 .50831 .55776 Mtetra
.661 .744 .911 r
.50831 .55776 .51417 .56364 .52489 .56046 .51905 .55457 Mtetra
.51905 .55457 .52489 .56046 .53564 .55726 .52984 .55136 Mtetra
.661 .744 .912 r
.52984 .55136 .53564 .55726 .54644 .55406 .54066 .54814 Mtetra
.661 .745 .912 r
.54066 .54814 .54644 .55406 .55729 .55084 .55153 .54491 Mtetra
.55153 .54491 .55729 .55084 .56817 .5476 .56245 .54166 Mtetra
.661 .746 .912 r
.56245 .54166 .56817 .5476 .5791 .54435 .5734 .5384 Mtetra
.662 .746 .913 r
.5734 .5384 .5791 .54435 .59007 .54109 .58441 .53512 Mtetra
.58441 .53512 .59007 .54109 .60109 .5378 .59545 .53181 Mtetra
.662 .747 .913 r
.59545 .53181 .60109 .5378 .61214 .5345 .60654 .52849 Mtetra
.60654 .52849 .61214 .5345 .62325 .53118 .61767 .52514 Mtetra
.663 .747 .913 r
.61767 .52514 .62325 .53118 .63439 .52783 .62885 .52177 Mtetra
.62885 .52177 .63439 .52783 .64559 .52446 .64007 .51838 Mtetra
.664 .747 .912 r
.64007 .51838 .64559 .52446 .65682 .52107 .65134 .51496 Mtetra
.65134 .51496 .65682 .52107 .6681 .51766 .66265 .51152 Mtetra
.66265 .51152 .6681 .51766 .67943 .51423 .67401 .50805 Mtetra
.665 .747 .912 r
.67401 .50805 .67943 .51423 .6908 .51077 .68541 .50457 Mtetra
.665 .747 .911 r
.68541 .50457 .6908 .51077 .70221 .5073 .69686 .50106 Mtetra
.69686 .50106 .70221 .5073 .71367 .50381 .70835 .49753 Mtetra
.665 .746 .911 r
.70835 .49753 .71367 .50381 .72518 .5003 .71989 .49398 Mtetra
.665 .746 .91 r
.71989 .49398 .72518 .5003 .73673 .49677 .73147 .49041 Mtetra
.73147 .49041 .73673 .49677 .74833 .49322 .74311 .48683 Mtetra
.665 .745 .91 r
.74311 .48683 .74833 .49322 .75998 .48967 .75479 .48323 Mtetra
.665 .745 .909 r
.75479 .48323 .75998 .48967 .77167 .48609 .76651 .47962 Mtetra
.665 .744 .909 r
.76651 .47962 .77167 .48609 .78341 .48251 .77829 .476 Mtetra
.77829 .476 .78341 .48251 .7952 .47891 .79011 .47237 Mtetra
.79011 .47237 .7952 .47891 .80704 .4753 .80198 .46874 Mtetra
.663 .743 .91 r
.80198 .46874 .80704 .4753 .81893 .4717 .81391 .46514 Mtetra
.657 .742 .912 r
.81391 .46514 .81893 .4717 .83087 .46813 .8259 .46171 Mtetra
.64 .741 .922 r
.8259 .46171 .83087 .46813 .84288 .46472 .83799 .45876 Mtetra
.592 .738 .945 r
.83799 .45876 .84288 .46472 .85498 .46176 .85025 .45692 Mtetra
.462 .723 .981 r
.85025 .45692 .85498 .46176 .86725 .45981 .86277 .45699 Mtetra
.126 .608 .916 r
.86277 .45699 .86725 .45981 .87976 .45948 .87561 .45932 Mtetra
.294 0 0 r
.87561 .45932 .87976 .45948 .89254 .46089 .88869 .46289 Mtetra
.373 0 0 r
.88869 .46289 .89254 .46089 .90549 .46298 .90173 .46516 Mtetra
.092 0 0 r
.90173 .46516 .90549 .46298 .91836 .46357 .91438 .4633 Mtetra
.634 .963 .886 r
.91438 .4633 .91836 .46357 .93087 .46058 .92647 .45632 Mtetra
.842 .884 .871 r
.92647 .45632 .93087 .46058 .94294 .45361 .93816 .44589 Mtetra
.811 .772 .816 r
.93816 .44589 .94294 .45361 .95473 .4443 .94978 .43496 Mtetra
.767 .722 .81 r
.94978 .43496 .95473 .4443 .96653 .435 .96163 .42571 Mtetra
.663 .742 .909 r
.38668 .5866 .39287 .59235 .40316 .58925 .397 .58348 Mtetra
.397 .58348 .40316 .58925 .4135 .58614 .40735 .58035 Mtetra
.40735 .58035 .4135 .58614 .42387 .58302 .41775 .57721 Mtetra
.662 .742 .909 r
.41775 .57721 .42387 .58302 .43428 .57989 .42819 .57407 Mtetra
.42819 .57407 .43428 .57989 .44473 .57675 .43867 .57092 Mtetra
.662 .742 .91 r
.43867 .57092 .44473 .57675 .45523 .5736 .44919 .56776 Mtetra
.662 .743 .91 r
.44919 .56776 .45523 .5736 .46576 .57045 .45975 .56459 Mtetra
.45975 .56459 .46576 .57045 .47633 .56729 .47035 .56142 Mtetra
.661 .743 .911 r
.47035 .56142 .47633 .56729 .48695 .56412 .48099 .55824 Mtetra
.48099 .55824 .48695 .56412 .49761 .56095 .49167 .55505 Mtetra
.661 .744 .911 r
.49167 .55505 .49761 .56095 .50831 .55776 .5024 .55186 Mtetra
.661 .744 .912 r
.5024 .55186 .50831 .55776 .51905 .55457 .51317 .54865 Mtetra
.661 .745 .912 r
.51317 .54865 .51905 .55457 .52984 .55136 .52398 .54544 Mtetra
.661 .745 .913 r
.52398 .54544 .52984 .55136 .54066 .54814 .53484 .54221 Mtetra
.661 .746 .913 r
.53484 .54221 .54066 .54814 .55153 .54491 .54574 .53896 Mtetra
.54574 .53896 .55153 .54491 .56245 .54166 .55668 .53571 Mtetra
.661 .747 .913 r
.55668 .53571 .56245 .54166 .5734 .5384 .56767 .53243 Mtetra
.661 .747 .914 r
.56767 .53243 .5734 .5384 .58441 .53512 .5787 .52913 Mtetra
.662 .747 .914 r
.5787 .52913 .58441 .53512 .59545 .53181 .58977 .52581 Mtetra
.662 .748 .914 r
.58977 .52581 .59545 .53181 .60654 .52849 .60089 .52247 Mtetra
.60089 .52247 .60654 .52849 .61767 .52514 .61206 .5191 Mtetra
.663 .748 .914 r
.61206 .5191 .61767 .52514 .62885 .52177 .62327 .5157 Mtetra
.62327 .5157 .62885 .52177 .64007 .51838 .63452 .51228 Mtetra
.664 .748 .913 r
.63452 .51228 .64007 .51838 .65134 .51496 .64582 .50884 Mtetra
.64582 .50884 .65134 .51496 .66265 .51152 .65716 .50536 Mtetra
.65716 .50536 .66265 .51152 .67401 .50805 .66855 .50186 Mtetra
.665 .748 .912 r
.66855 .50186 .67401 .50805 .68541 .50457 .67998 .49834 Mtetra
.67998 .49834 .68541 .50457 .69686 .50106 .69146 .49479 Mtetra
.69146 .49479 .69686 .50106 .70835 .49753 .70299 .49122 Mtetra
.666 .747 .911 r
.70299 .49122 .70835 .49753 .71989 .49398 .71456 .48763 Mtetra
.71456 .48763 .71989 .49398 .73147 .49041 .72618 .48403 Mtetra
.666 .746 .91 r
.72618 .48403 .73147 .49041 .74311 .48683 .73784 .4804 Mtetra
.73784 .4804 .74311 .48683 .75479 .48323 .74955 .47677 Mtetra
.666 .745 .91 r
.74955 .47677 .75479 .48323 .76651 .47962 .76131 .47312 Mtetra
.666 .745 .909 r
.76131 .47312 .76651 .47962 .77829 .476 .77312 .46946 Mtetra
.665 .744 .909 r
.77312 .46946 .77829 .476 .79011 .47237 .78498 .46579 Mtetra
.664 .744 .91 r
.78498 .46579 .79011 .47237 .80198 .46874 .79689 .46217 Mtetra
.658 .743 .913 r
.79689 .46217 .80198 .46874 .81391 .46514 .80886 .4587 Mtetra
.64 .741 .922 r
.80886 .4587 .81391 .46514 .8259 .46171 .82094 .45574 Mtetra
.587 .737 .947 r
.82094 .45574 .8259 .46171 .83799 .45876 .83318 .45398 Mtetra
.433 .712 .982 r
.83318 .45398 .83799 .45876 .85025 .45692 .8457 .45443 Mtetra
0 .523 .847 r
.8457 .45443 .85025 .45692 .86277 .45699 .8586 .45768 Mtetra
.465 0 0 r
.8586 .45768 .86277 .45699 .87561 .45932 .87181 .4629 Mtetra
.531 .001 0 r
.87181 .4629 .87561 .45932 .88869 .46289 .88504 .46719 Mtetra
.35 0 0 r
.88504 .46719 .88869 .46289 .90173 .46516 .89787 .46692 Mtetra
.385 .82 .669 r
.89787 .46692 .90173 .46516 .91438 .4633 .91003 .46026 Mtetra
.869 .928 .862 r
.91003 .46026 .91438 .4633 .92647 .45632 .92163 .44873 Mtetra
.838 .781 .798 r
.92163 .44873 .92647 .45632 .93816 .44589 .93306 .43591 Mtetra
.787 .717 .787 r
.93306 .43591 .93816 .44589 .94978 .43496 .94471 .42482 Mtetra
.744 .698 .808 r
.94471 .42482 .94978 .43496 .96163 .42571 .95672 .41655 Mtetra
.663 .742 .909 r
.38045 .58082 .38668 .5866 .397 .58348 .39079 .57768 Mtetra
.39079 .57768 .397 .58348 .40735 .58035 .40117 .57453 Mtetra
.662 .742 .909 r
.40117 .57453 .40735 .58035 .41775 .57721 .41159 .57138 Mtetra
.41159 .57138 .41775 .57721 .42819 .57407 .42205 .56822 Mtetra
.662 .742 .91 r
.42205 .56822 .42819 .57407 .43867 .57092 .43256 .56505 Mtetra
.662 .743 .91 r
.43256 .56505 .43867 .57092 .44919 .56776 .4431 .56188 Mtetra
.661 .743 .91 r
.4431 .56188 .44919 .56776 .45975 .56459 .45369 .5587 Mtetra
.661 .743 .911 r
.45369 .5587 .45975 .56459 .47035 .56142 .46431 .55552 Mtetra
.661 .744 .911 r
.46431 .55552 .47035 .56142 .48099 .55824 .47498 .55233 Mtetra
.661 .744 .912 r
.47498 .55233 .48099 .55824 .49167 .55505 .4857 .54914 Mtetra
.66 .744 .912 r
.4857 .54914 .49167 .55505 .5024 .55186 .49645 .54593 Mtetra
.66 .745 .913 r
.49645 .54593 .5024 .55186 .51317 .54865 .50725 .54272 Mtetra
.50725 .54272 .51317 .54865 .52398 .54544 .51809 .5395 Mtetra
.66 .746 .914 r
.51809 .5395 .52398 .54544 .53484 .54221 .52897 .53626 Mtetra
.66 .747 .914 r
.52897 .53626 .53484 .54221 .54574 .53896 .5399 .53301 Mtetra
.5399 .53301 .54574 .53896 .55668 .53571 .55087 .52974 Mtetra
.661 .748 .915 r
.55087 .52974 .55668 .53571 .56767 .53243 .56189 .52645 Mtetra
.56189 .52645 .56767 .53243 .5787 .52913 .57295 .52314 Mtetra
.661 .749 .915 r
.57295 .52314 .5787 .52913 .58977 .52581 .58406 .5198 Mtetra
.662 .749 .915 r
.58406 .5198 .58977 .52581 .60089 .52247 .59521 .51644 Mtetra
.59521 .51644 .60089 .52247 .61206 .5191 .6064 .51305 Mtetra
.663 .749 .915 r
.6064 .51305 .61206 .5191 .62327 .5157 .61764 .50963 Mtetra
.663 .75 .914 r
.61764 .50963 .62327 .5157 .63452 .51228 .62892 .50618 Mtetra
.664 .75 .914 r
.62892 .50618 .63452 .51228 .64582 .50884 .64025 .5027 Mtetra
.64025 .5027 .64582 .50884 .65716 .50536 .65163 .49919 Mtetra
.665 .75 .913 r
.65163 .49919 .65716 .50536 .66855 .50186 .66305 .49565 Mtetra
.665 .749 .913 r
.66305 .49565 .66855 .50186 .67998 .49834 .67451 .49209 Mtetra
.666 .749 .912 r
.67451 .49209 .67998 .49834 .69146 .49479 .68603 .4885 Mtetra
.68603 .4885 .69146 .49479 .70299 .49122 .69758 .48489 Mtetra
.666 .748 .912 r
.69758 .48489 .70299 .49122 .71456 .48763 .70919 .48126 Mtetra
.666 .748 .911 r
.70919 .48126 .71456 .48763 .72618 .48403 .72084 .47761 Mtetra
.666 .747 .911 r
.72084 .47761 .72618 .48403 .73784 .4804 .73254 .47394 Mtetra
.666 .747 .91 r
.73254 .47394 .73784 .4804 .74955 .47677 .74428 .47026 Mtetra
.666 .746 .91 r
.74428 .47026 .74955 .47677 .76131 .47312 .75607 .46657 Mtetra
.666 .745 .91 r
.75607 .46657 .76131 .47312 .77312 .46946 .76792 .46288 Mtetra
.664 .745 .91 r
.76792 .46288 .77312 .46946 .78498 .46579 .77981 .45922 Mtetra
.659 .743 .913 r
.77981 .45922 .78498 .46579 .79689 .46217 .79177 .45571 Mtetra
.64 .741 .922 r
.79177 .45571 .79689 .46217 .80886 .4587 .80382 .45271 Mtetra
.585 .736 .947 r
.80382 .45271 .80886 .4587 .82094 .45574 .81605 .451 Mtetra
.407 .702 .982 r
.81605 .451 .82094 .45574 .83318 .45398 .82857 .45176 Mtetra
0 .433 .766 r
.82857 .45176 .83318 .45398 .8457 .45443 .8415 .45592 Mtetra
.578 .015 0 r
.8415 .45592 .8457 .45443 .8586 .45768 .85483 .46288 Mtetra
.621 .138 .084 r
.85483 .46288 .8586 .45768 .87181 .4629 .86827 .46954 Mtetra
.499 .037 .087 r
.86827 .46954 .87181 .4629 .88504 .46719 .88131 .47137 Mtetra
0 0 0 r
.88131 .47137 .88504 .46719 .89787 .46692 .89359 .46548 Mtetra
.88 .974 .839 r
.89359 .46548 .89787 .46692 .91003 .46026 .90514 .45299 Mtetra
.865 .793 .779 r
.90514 .45299 .91003 .46026 .92163 .44873 .91639 .43805 Mtetra
.806 .713 .762 r
.91639 .43805 .92163 .44873 .93306 .43591 .9278 .42473 Mtetra
.759 .687 .782 r
.9278 .42473 .93306 .43591 .94471 .42482 .93963 .41481 Mtetra
.721 .692 .822 r
.93963 .41481 .94471 .42482 .95672 .41655 .95186 .40791 Mtetra
.663 .742 .909 r
.37417 .57499 .38045 .58082 .39079 .57768 .38453 .57184 Mtetra
.662 .742 .909 r
.38453 .57184 .39079 .57768 .40117 .57453 .39494 .56867 Mtetra
.39494 .56867 .40117 .57453 .41159 .57138 .40539 .56551 Mtetra
.662 .742 .91 r
.40539 .56551 .41159 .57138 .42205 .56822 .41587 .56233 Mtetra
.661 .743 .91 r
.41587 .56233 .42205 .56822 .43256 .56505 .4264 .55916 Mtetra
.661 .743 .911 r
.4264 .55916 .43256 .56505 .4431 .56188 .43697 .55597 Mtetra
.43697 .55597 .4431 .56188 .45369 .5587 .44759 .55279 Mtetra
.661 .744 .912 r
.44759 .55279 .45369 .5587 .46431 .55552 .45824 .5496 Mtetra
.66 .744 .912 r
.45824 .5496 .46431 .55552 .47498 .55233 .46894 .5464 Mtetra
.66 .745 .913 r
.46894 .5464 .47498 .55233 .4857 .54914 .47967 .5432 Mtetra
.47967 .5432 .4857 .54914 .49645 .54593 .49046 .53999 Mtetra
.66 .746 .914 r
.49046 .53999 .49645 .54593 .50725 .54272 .50128 .53678 Mtetra
.659 .746 .914 r
.50128 .53678 .50725 .54272 .51809 .5395 .51215 .53355 Mtetra
.659 .747 .915 r
.51215 .53355 .51809 .5395 .52897 .53626 .52306 .53031 Mtetra
.66 .748 .915 r
.52306 .53031 .52897 .53626 .5399 .53301 .53402 .52705 Mtetra
.53402 .52705 .5399 .53301 .55087 .52974 .54502 .52377 Mtetra
.66 .749 .916 r
.54502 .52377 .55087 .52974 .56189 .52645 .55607 .52047 Mtetra
.55607 .52047 .56189 .52645 .57295 .52314 .56716 .51714 Mtetra
.661 .75 .916 r
.56716 .51714 .57295 .52314 .58406 .5198 .5783 .51379 Mtetra
.5783 .51379 .58406 .5198 .59521 .51644 .58948 .51041 Mtetra
.662 .751 .916 r
.58948 .51041 .59521 .51644 .6064 .51305 .6007 .50699 Mtetra
.663 .751 .916 r
.6007 .50699 .6064 .51305 .61764 .50963 .61197 .50355 Mtetra
.663 .751 .915 r
.61197 .50355 .61764 .50963 .62892 .50618 .62329 .50007 Mtetra
.664 .751 .915 r
.62329 .50007 .62892 .50618 .64025 .5027 .63465 .49655 Mtetra
.665 .751 .915 r
.63465 .49655 .64025 .5027 .65163 .49919 .64606 .49301 Mtetra
.665 .751 .914 r
.64606 .49301 .65163 .49919 .66305 .49565 .65751 .48943 Mtetra
.666 .751 .914 r
.65751 .48943 .66305 .49565 .67451 .49209 .66901 .48582 Mtetra
.666 .75 .913 r
.66901 .48582 .67451 .49209 .68603 .4885 .68055 .48219 Mtetra
.666 .75 .912 r
.68055 .48219 .68603 .4885 .69758 .48489 .69214 .47854 Mtetra
.667 .749 .912 r
.69214 .47854 .69758 .48489 .70919 .48126 .70378 .47486 Mtetra
.667 .749 .911 r
.70378 .47486 .70919 .48126 .72084 .47761 .71546 .47116 Mtetra
.667 .748 .911 r
.71546 .47116 .72084 .47761 .73254 .47394 .72719 .46745 Mtetra
.667 .747 .91 r
.72719 .46745 .73254 .47394 .74428 .47026 .73897 .46372 Mtetra
.666 .747 .91 r
.73897 .46372 .74428 .47026 .75607 .46657 .7508 .46 Mtetra
.665 .746 .91 r
.7508 .46 .75607 .46657 .76792 .46288 .76268 .45629 Mtetra
.66 .744 .913 r
.76268 .45629 .76792 .46288 .77981 .45922 .77462 .45274 Mtetra
.642 .742 .922 r
.77462 .45274 .77981 .45922 .79177 .45571 .78665 .44969 Mtetra
.584 .736 .947 r
.78665 .44969 .79177 .45571 .80382 .45271 .79885 .44798 Mtetra
.387 .692 .98 r
.79885 .44798 .80382 .45271 .81605 .451 .81135 .44897 Mtetra
0 .349 .688 r
.81135 .44897 .81605 .451 .82857 .45176 .82431 .45396 Mtetra
.65 .117 0 r
.82431 .45396 .82857 .45176 .8415 .45592 .83775 .46271 Mtetra
.677 .229 .18 r
.83775 .46271 .8415 .45592 .85483 .46288 .85139 .47204 Mtetra
.585 .166 .212 r
.85139 .47204 .85483 .46288 .86827 .46954 .86469 .47652 Mtetra
.246 0 0 r
.86469 .47652 .86827 .46954 .88131 .47137 .87714 .47198 Mtetra
.843 .997 .773 r
.87714 .47198 .88131 .47137 .89359 .46548 .88869 .45879 Mtetra
.892 .808 .759 r
.88869 .45879 .89359 .46548 .90514 .45299 .89975 .44159 Mtetra
.824 .709 .738 r
.89975 .44159 .90514 .45299 .91639 .43805 .91091 .42561 Mtetra
.773 .676 .756 r
.91091 .42561 .91639 .43805 .9278 .42473 .92252 .41361 Mtetra
.733 .678 .797 r
.92252 .41361 .9278 .42473 .93963 .41481 .93461 .40548 Mtetra
.701 .699 .845 r
.93461 .40548 .93963 .41481 .95186 .40791 .94704 .39981 Mtetra
.662 .742 .909 r
.36784 .56913 .37417 .57499 .38453 .57184 .37823 .56596 Mtetra
.37823 .56596 .38453 .57184 .39494 .56867 .38866 .56278 Mtetra
.662 .742 .91 r
.38866 .56278 .39494 .56867 .40539 .56551 .39914 .5596 Mtetra
.661 .743 .91 r
.39914 .5596 .40539 .56551 .41587 .56233 .40965 .55642 Mtetra
.661 .743 .911 r
.40965 .55642 .41587 .56233 .4264 .55916 .4202 .55323 Mtetra
.4202 .55323 .4264 .55916 .43697 .55597 .4308 .55004 Mtetra
.66 .744 .912 r
.4308 .55004 .43697 .55597 .44759 .55279 .44144 .54685 Mtetra
.44144 .54685 .44759 .55279 .45824 .5496 .45212 .54366 Mtetra
.659 .745 .913 r
.45212 .54366 .45824 .5496 .46894 .5464 .46284 .54046 Mtetra
.659 .745 .914 r
.46284 .54046 .46894 .5464 .47967 .5432 .47361 .53725 Mtetra
.659 .746 .914 r
.47361 .53725 .47967 .5432 .49046 .53999 .48442 .53404 Mtetra
.659 .746 .915 r
.48442 .53404 .49046 .53999 .50128 .53678 .49527 .53082 Mtetra
.659 .747 .915 r
.49527 .53082 .50128 .53678 .51215 .53355 .50617 .52759 Mtetra
.659 .748 .916 r
.50617 .52759 .51215 .53355 .52306 .53031 .51711 .52435 Mtetra
.659 .749 .916 r
.51711 .52435 .52306 .53031 .53402 .52705 .5281 .52108 Mtetra
.659 .749 .917 r
.5281 .52108 .53402 .52705 .54502 .52377 .53913 .5178 Mtetra
.659 .75 .917 r
.53913 .5178 .54502 .52377 .55607 .52047 .5502 .51449 Mtetra
.66 .751 .917 r
.5502 .51449 .55607 .52047 .56716 .51714 .56132 .51115 Mtetra
.56132 .51115 .56716 .51714 .5783 .51379 .57249 .50778 Mtetra
.661 .752 .917 r
.57249 .50778 .5783 .51379 .58948 .51041 .5837 .50438 Mtetra
.662 .752 .917 r
.5837 .50438 .58948 .51041 .6007 .50699 .59496 .50094 Mtetra
.663 .752 .917 r
.59496 .50094 .6007 .50699 .61197 .50355 .60626 .49746 Mtetra
.664 .753 .916 r
.60626 .49746 .61197 .50355 .62329 .50007 .61761 .49395 Mtetra
.61761 .49395 .62329 .50007 .63465 .49655 .629 .4904 Mtetra
.665 .753 .915 r
.629 .4904 .63465 .49655 .64606 .49301 .64044 .48681 Mtetra
.666 .752 .915 r
.64044 .48681 .64606 .49301 .65751 .48943 .65193 .48319 Mtetra
.666 .752 .914 r
.65193 .48319 .65751 .48943 .66901 .48582 .66346 .47954 Mtetra
.667 .751 .914 r
.66346 .47954 .66901 .48582 .68055 .48219 .67503 .47586 Mtetra
.667 .751 .913 r
.67503 .47586 .68055 .48219 .69214 .47854 .68666 .47216 Mtetra
.667 .75 .912 r
.68666 .47216 .69214 .47854 .70378 .47486 .69833 .46843 Mtetra
.668 .75 .912 r
.69833 .46843 .70378 .47486 .71546 .47116 .71004 .46468 Mtetra
.668 .749 .911 r
.71004 .46468 .71546 .47116 .72719 .46745 .72181 .46092 Mtetra
.667 .748 .911 r
.72181 .46092 .72719 .46745 .73897 .46372 .73362 .45716 Mtetra
.666 .747 .911 r
.73362 .45716 .73897 .46372 .7508 .46 .74548 .45341 Mtetra
.661 .746 .913 r
.74548 .45341 .7508 .46 .76268 .45629 .7574 .4498 Mtetra
.644 .743 .921 r
.7574 .4498 .76268 .45629 .77462 .45274 .76942 .44669 Mtetra
.585 .736 .947 r
.76942 .44669 .77462 .45274 .78665 .44969 .78159 .44493 Mtetra
.376 .686 .979 r
.78159 .44493 .78665 .44969 .79885 .44798 .79407 .44606 Mtetra
.305 0 0 r
.79407 .44606 .79885 .44798 .81135 .44897 .80703 .45177 Mtetra
.697 .188 .023 r
.80703 .45177 .81135 .44897 .82431 .45396 .82055 .46227 Mtetra
.713 .291 .243 r
.82055 .46227 .82431 .45396 .83775 .46271 .83439 .47447 Mtetra
.639 .249 .289 r
.83439 .47447 .83775 .46271 .85139 .47204 .84797 .48216 Mtetra
.412 .015 .173 r
.84797 .48216 .85139 .47204 .86469 .47652 .86065 .47964 Mtetra
.679 .92 .601 r
.86065 .47964 .86469 .47652 .87714 .47198 .87225 .4662 Mtetra
.919 .827 .739 r
.87225 .4662 .87714 .47198 .88869 .45879 .88316 .4467 Mtetra
.84 .706 .715 r
.88316 .4467 .88869 .45879 .89975 .44159 .89406 .42766 Mtetra
.786 .664 .73 r
.89406 .42766 .89975 .44159 .91091 .42561 .90541 .41309 Mtetra
.744 .663 .77 r
.90541 .41309 .91091 .42561 .92252 .41361 .91733 .40336 Mtetra
.711 .685 .823 r
.91733 .40336 .92252 .41361 .93461 .40548 .92966 .39692 Mtetra
.685 .712 .869 r
.92966 .39692 .93461 .40548 .94704 .39981 .94225 .39211 Mtetra
.662 .742 .909 r
.36147 .56323 .36784 .56913 .37823 .56596 .37189 .56005 Mtetra
.662 .742 .91 r
.37189 .56005 .37823 .56596 .38866 .56278 .38234 .55686 Mtetra
.661 .742 .91 r
.38234 .55686 .38866 .56278 .39914 .5596 .39284 .55367 Mtetra
.661 .743 .911 r
.39284 .55367 .39914 .5596 .40965 .55642 .40338 .55047 Mtetra
.66 .743 .911 r
.40338 .55047 .40965 .55642 .4202 .55323 .41396 .54728 Mtetra
.66 .744 .912 r
.41396 .54728 .4202 .55323 .4308 .55004 .42458 .54409 Mtetra
.659 .744 .913 r
.42458 .54409 .4308 .55004 .44144 .54685 .43524 .54089 Mtetra
.659 .745 .913 r
.43524 .54089 .44144 .54685 .45212 .54366 .44595 .53769 Mtetra
.659 .745 .914 r
.44595 .53769 .45212 .54366 .46284 .54046 .4567 .53449 Mtetra
.658 .746 .915 r
.4567 .53449 .46284 .54046 .47361 .53725 .46749 .53129 Mtetra
.658 .747 .915 r
.46749 .53129 .47361 .53725 .48442 .53404 .47833 .52808 Mtetra
.658 .747 .916 r
.47833 .52808 .48442 .53404 .49527 .53082 .48921 .52486 Mtetra
.658 .748 .917 r
.48921 .52486 .49527 .53082 .50617 .52759 .50014 .52163 Mtetra
.658 .749 .917 r
.50014 .52163 .50617 .52759 .51711 .52435 .51111 .51839 Mtetra
.658 .75 .918 r
.51111 .51839 .51711 .52435 .5281 .52108 .52213 .51512 Mtetra
.658 .751 .918 r
.52213 .51512 .5281 .52108 .53913 .5178 .53319 .51183 Mtetra
.659 .752 .919 r
.53319 .51183 .53913 .5178 .5502 .51449 .54429 .50851 Mtetra
.54429 .50851 .5502 .51449 .56132 .51115 .55545 .50516 Mtetra
.66 .753 .919 r
.55545 .50516 .56132 .51115 .57249 .50778 .56664 .50178 Mtetra
.661 .753 .919 r
.56664 .50178 .57249 .50778 .5837 .50438 .57789 .49835 Mtetra
.662 .754 .918 r
.57789 .49835 .5837 .50438 .59496 .50094 .58918 .49489 Mtetra
.663 .754 .918 r
.58918 .49489 .59496 .50094 .60626 .49746 .60051 .49138 Mtetra
.664 .754 .918 r
.60051 .49138 .60626 .49746 .61761 .49395 .61189 .48783 Mtetra
.665 .754 .917 r
.61189 .48783 .61761 .49395 .629 .4904 .62332 .48424 Mtetra
.666 .754 .916 r
.62332 .48424 .629 .4904 .64044 .48681 .63479 .48061 Mtetra
.63479 .48061 .64044 .48681 .65193 .48319 .6463 .47695 Mtetra
.667 .753 .915 r
.6463 .47695 .65193 .48319 .66346 .47954 .65787 .47325 Mtetra
.668 .753 .914 r
.65787 .47325 .66346 .47954 .67503 .47586 .66948 .46951 Mtetra
.668 .752 .913 r
.66948 .46951 .67503 .47586 .68666 .47216 .68113 .46576 Mtetra
.668 .751 .913 r
.68113 .46576 .68666 .47216 .69833 .46843 .69283 .46198 Mtetra
.668 .751 .912 r
.69283 .46198 .69833 .46843 .71004 .46468 .70458 .45818 Mtetra
.668 .75 .911 r
.70458 .45818 .71004 .46468 .72181 .46092 .71638 .45437 Mtetra
.667 .749 .911 r
.71638 .45437 .72181 .46092 .73362 .45716 .72823 .45058 Mtetra
.663 .747 .913 r
.72823 .45058 .73362 .45716 .74548 .45341 .74013 .44691 Mtetra
.646 .745 .921 r
.74013 .44691 .74548 .45341 .7574 .4498 .75212 .44371 Mtetra
.589 .737 .946 r
.75212 .44371 .7574 .4498 .76942 .44669 .76427 .44186 Mtetra
.373 .683 .978 r
.76427 .44186 .76942 .44669 .78159 .44493 .77671 .44303 Mtetra
.355 0 0 r
.77671 .44303 .78159 .44493 .79407 .44606 .78965 .44929 Mtetra
.728 .238 .076 r
.78965 .44929 .79407 .44606 .80703 .45177 .80322 .46142 Mtetra
.739 .335 .285 r
.80322 .46142 .80703 .45177 .82055 .46227 .81724 .47662 Mtetra
.677 .307 .338 r
.81724 .47662 .82055 .46227 .83439 .47447 .83111 .48802 Mtetra
.513 .146 .28 r
.83111 .48802 .83439 .47447 .84797 .48216 .84408 .4883 Mtetra
0 0 0 r
.84408 .4883 .84797 .48216 .86065 .47964 .85579 .47521 Mtetra
.944 .85 .719 r
.85579 .47521 .86065 .47964 .87225 .4662 .86659 .45351 Mtetra
.856 .704 .694 r
.86659 .45351 .87225 .4662 .88316 .4467 .87723 .43107 Mtetra
.797 .654 .705 r
.87723 .43107 .88316 .4467 .89406 .42766 .88831 .41342 Mtetra
.754 .647 .743 r
.88831 .41342 .89406 .42766 .90541 .41309 .90002 .40167 Mtetra
.72 .669 .799 r
.90002 .40167 .90541 .41309 .91733 .40336 .91224 .3942 Mtetra
.692 .701 .853 r
.91224 .3942 .91733 .40336 .92966 .39692 .92477 .38896 Mtetra
.674 .725 .888 r
.92477 .38896 .92966 .39692 .94225 .39211 .93745 .38463 Mtetra
.662 .742 .91 r
.35505 .5573 .36147 .56323 .37189 .56005 .36549 .5541 Mtetra
.661 .742 .91 r
.36549 .5541 .37189 .56005 .38234 .55686 .37597 .5509 Mtetra
.661 .743 .911 r
.37597 .5509 .38234 .55686 .39284 .55367 .3865 .5477 Mtetra
.66 .743 .911 r
.3865 .5477 .39284 .55367 .40338 .55047 .39706 .5445 Mtetra
.66 .743 .912 r
.39706 .5445 .40338 .55047 .41396 .54728 .40767 .5413 Mtetra
.659 .744 .913 r
.40767 .5413 .41396 .54728 .42458 .54409 .41831 .53811 Mtetra
.41831 .53811 .42458 .54409 .43524 .54089 .429 .53491 Mtetra
.658 .745 .914 r
.429 .53491 .43524 .54089 .44595 .53769 .43974 .53172 Mtetra
.658 .746 .915 r
.43974 .53172 .44595 .53769 .4567 .53449 .45051 .52852 Mtetra
.657 .747 .916 r
.45051 .52852 .4567 .53449 .46749 .53129 .46134 .52532 Mtetra
.657 .747 .917 r
.46134 .52532 .46749 .53129 .47833 .52808 .4722 .52211 Mtetra
.657 .748 .918 r
.4722 .52211 .47833 .52808 .48921 .52486 .48311 .5189 Mtetra
.657 .749 .918 r
.48311 .5189 .48921 .52486 .50014 .52163 .49406 .51567 Mtetra
.657 .75 .919 r
.49406 .51567 .50014 .52163 .51111 .51839 .50506 .51243 Mtetra
.657 .751 .919 r
.50506 .51243 .51111 .51839 .52213 .51512 .51611 .50916 Mtetra
.657 .752 .92 r
.51611 .50916 .52213 .51512 .53319 .51183 .5272 .50587 Mtetra
.658 .753 .92 r
.5272 .50587 .53319 .51183 .54429 .50851 .53834 .50254 Mtetra
.659 .754 .92 r
.53834 .50254 .54429 .50851 .55545 .50516 .54952 .49918 Mtetra
.66 .755 .92 r
.54952 .49918 .55545 .50516 .56664 .50178 .56075 .49578 Mtetra
.661 .755 .92 r
.56075 .49578 .56664 .50178 .57789 .49835 .57203 .49233 Mtetra
.662 .756 .92 r
.57203 .49233 .57789 .49835 .58918 .49489 .58335 .48884 Mtetra
.663 .756 .919 r
.58335 .48884 .58918 .49489 .60051 .49138 .59471 .4853 Mtetra
.664 .756 .919 r
.59471 .4853 .60051 .49138 .61189 .48783 .60613 .48171 Mtetra
.665 .756 .918 r
.60613 .48171 .61189 .48783 .62332 .48424 .61758 .47808 Mtetra
.666 .756 .917 r
.61758 .47808 .62332 .48424 .63479 .48061 .62909 .4744 Mtetra
.667 .755 .916 r
.62909 .4744 .63479 .48061 .6463 .47695 .64064 .47069 Mtetra
.668 .755 .915 r
.64064 .47069 .6463 .47695 .65787 .47325 .65223 .46693 Mtetra
.668 .754 .915 r
.65223 .46693 .65787 .47325 .66948 .46951 .66387 .46315 Mtetra
.669 .753 .914 r
.66387 .46315 .66948 .46951 .68113 .46576 .67556 .45933 Mtetra
.669 .753 .913 r
.67556 .45933 .68113 .46576 .69283 .46198 .6873 .45549 Mtetra
.669 .752 .912 r
.6873 .45549 .69283 .46198 .70458 .45818 .69908 .45164 Mtetra
.668 .75 .912 r
.69908 .45164 .70458 .45818 .71638 .45437 .71091 .4478 Mtetra
.664 .749 .913 r
.71091 .4478 .71638 .45437 .72823 .45058 .7228 .44407 Mtetra
.649 .746 .921 r
.7228 .44407 .72823 .45058 .74013 .44691 .73477 .44077 Mtetra
.594 .739 .944 r
.73477 .44077 .74013 .44691 .75212 .44371 .74688 .43879 Mtetra
.38 .684 .978 r
.74688 .43879 .75212 .44371 .76427 .44186 .75928 .43989 Mtetra
.38 0 0 r
.75928 .43989 .76427 .44186 .77671 .44303 .77218 .44651 Mtetra
.75 .273 .11 r
.77218 .44651 .77671 .44303 .78965 .44929 .78577 .46005 Mtetra
.758 .367 .313 r
.78577 .46005 .78965 .44929 .80322 .46142 .79993 .47823 Mtetra
.705 .349 .371 r
.79993 .47823 .80322 .46142 .81724 .47662 .81408 .49376 Mtetra
.579 .232 .345 r
.81408 .49376 .81724 .47662 .83111 .48802 .82738 .49764 Mtetra
0 0 0 r
.82738 .49764 .83111 .48802 .84408 .4883 .83928 .48569 Mtetra
.967 .879 .694 r
.83928 .48569 .84408 .4883 .85579 .47521 .85003 .46209 Mtetra
.87 .705 .674 r
.85003 .46209 .85579 .47521 .86659 .45351 .86042 .43599 Mtetra
.806 .645 .682 r
.86042 .43599 .86659 .45351 .87723 .43107 .87121 .41475 Mtetra
.763 .633 .717 r
.87121 .41475 .87723 .43107 .88831 .41342 .88269 .4005 Mtetra
.729 .652 .773 r
.88269 .4005 .88831 .41342 .90002 .40167 .89477 .39169 Mtetra
.7 .687 .835 r
.89477 .39169 .90002 .40167 .91224 .3942 .90723 .38589 Mtetra
.678 .718 .879 r
.90723 .38589 .91224 .3942 .92477 .38896 .91988 .38135 Mtetra
.668 .734 .899 r
.91988 .38135 .92477 .38896 .93745 .38463 .93264 .37721 Mtetra
.661 .742 .91 r
.34859 .55133 .35505 .5573 .36549 .5541 .35905 .54812 Mtetra
.661 .743 .911 r
.35905 .54812 .36549 .5541 .37597 .5509 .36956 .54492 Mtetra
.66 .743 .911 r
.36956 .54492 .37597 .5509 .3865 .5477 .38011 .54171 Mtetra
.659 .743 .912 r
.38011 .54171 .3865 .5477 .39706 .5445 .3907 .5385 Mtetra
.659 .744 .913 r
.3907 .5385 .39706 .5445 .40767 .5413 .40133 .5353 Mtetra
.658 .744 .914 r
.40133 .5353 .40767 .5413 .41831 .53811 .412 .53211 Mtetra
.658 .745 .914 r
.412 .53211 .41831 .53811 .429 .53491 .42272 .52891 Mtetra
.657 .746 .915 r
.42272 .52891 .429 .53491 .43974 .53172 .43348 .52572 Mtetra
.656 .747 .916 r
.43348 .52572 .43974 .53172 .45051 .52852 .44428 .52253 Mtetra
.656 .747 .917 r
.44428 .52253 .45051 .52852 .46134 .52532 .45513 .51934 Mtetra
.656 .748 .918 r
.45513 .51934 .46134 .52532 .4722 .52211 .46602 .51615 Mtetra
.655 .749 .919 r
.46602 .51615 .4722 .52211 .48311 .5189 .47696 .51294 Mtetra
.655 .75 .92 r
.47696 .51294 .48311 .5189 .49406 .51567 .48794 .50972 Mtetra
.655 .752 .921 r
.48794 .50972 .49406 .51567 .50506 .51243 .49897 .50648 Mtetra
.656 .753 .921 r
.49897 .50648 .50506 .51243 .51611 .50916 .51005 .50321 Mtetra
.656 .754 .922 r
.51005 .50321 .51611 .50916 .5272 .50587 .52117 .49992 Mtetra
.657 .755 .922 r
.52117 .49992 .5272 .50587 .53834 .50254 .53234 .49659 Mtetra
.658 .756 .922 r
.53234 .49659 .53834 .50254 .54952 .49918 .54355 .49321 Mtetra
.659 .756 .922 r
.54355 .49321 .54952 .49918 .56075 .49578 .55481 .48979 Mtetra
.66 .757 .922 r
.55481 .48979 .56075 .49578 .57203 .49233 .56612 .48632 Mtetra
.662 .758 .921 r
.56612 .48632 .57203 .49233 .58335 .48884 .57747 .4828 Mtetra
.663 .758 .921 r
.57747 .4828 .58335 .48884 .59471 .4853 .58887 .47922 Mtetra
.664 .758 .92 r
.58887 .47922 .59471 .4853 .60613 .48171 .60032 .47559 Mtetra
.666 .758 .919 r
.60032 .47559 .60613 .48171 .61758 .47808 .61181 .47192 Mtetra
.667 .757 .918 r
.61181 .47192 .61758 .47808 .62909 .4744 .62334 .46819 Mtetra
.668 .757 .917 r
.62334 .46819 .62909 .4744 .64064 .47069 .63493 .46442 Mtetra
.669 .756 .916 r
.63493 .46442 .64064 .47069 .65223 .46693 .64656 .4606 Mtetra
.669 .756 .915 r
.64656 .4606 .65223 .46693 .66387 .46315 .65823 .45676 Mtetra
.67 .755 .914 r
.65823 .45676 .66387 .46315 .67556 .45933 .66995 .45288 Mtetra
.67 .754 .913 r
.66995 .45288 .67556 .45933 .6873 .45549 .68172 .44899 Mtetra
.67 .753 .913 r
.68172 .44899 .6873 .45549 .69908 .45164 .69354 .44509 Mtetra
.666 .751 .914 r
.69354 .44509 .69908 .45164 .71091 .4478 .70541 .44129 Mtetra
.652 .748 .92 r
.70541 .44129 .71091 .4478 .7228 .44407 .71736 .43788 Mtetra
.601 .741 .943 r
.71736 .43788 .7228 .44407 .73477 .44077 .72943 .43573 Mtetra
.395 .689 .979 r
.72943 .43573 .73477 .44077 .74688 .43879 .74178 .43666 Mtetra
.383 0 0 r
.74178 .43666 .74688 .43879 .75928 .43989 .75462 .44342 Mtetra
.765 .295 .129 r
.75462 .44342 .75928 .43989 .77218 .44651 .76819 .45808 Mtetra
.774 .391 .331 r
.76819 .45808 .77218 .44651 .78577 .46005 .78244 .47908 Mtetra
.727 .381 .393 r
.78244 .47908 .78577 .46005 .79993 .47823 .79685 .49901 Mtetra
.626 .292 .386 r
.79685 .49901 .79993 .47823 .81408 .49376 .8105 .50729 Mtetra
.237 0 .181 r
.8105 .50729 .81408 .49376 .82738 .49764 .82268 .49741 Mtetra
.979 .91 .659 r
.82268 .49741 .82738 .49764 .83928 .48569 .83344 .47241 Mtetra
.884 .707 .658 r
.83344 .47241 .83928 .48569 .85003 .46209 .84362 .44254 Mtetra
.814 .637 .663 r
.84362 .44254 .85003 .46209 .86042 .43599 .85412 .41723 Mtetra
.77 .619 .693 r
.85412 .41723 .86042 .43599 .87121 .41475 .86535 .39997 Mtetra
.736 .634 .746 r
.86535 .39997 .87121 .41475 .88269 .4005 .87726 .38947 Mtetra
.707 .671 .813 r
.87726 .38947 .88269 .4005 .89477 .39169 .88963 .38291 Mtetra
.683 .709 .867 r
.88963 .38291 .89477 .39169 .90723 .38589 .90225 .37809 Mtetra
.67 .73 .895 r
.90225 .37809 .90723 .38589 .91988 .38135 .91498 .37387 Mtetra
.665 .738 .905 r
.91498 .37387 .91988 .38135 .93264 .37721 .92779 .3698 Mtetra
.661 .742 .911 r
.34208 .54533 .34859 .55133 .35905 .54812 .35257 .54211 Mtetra
.66 .743 .911 r
.35257 .54211 .35905 .54812 .36956 .54492 .3631 .5389 Mtetra
.659 .743 .912 r
.3631 .5389 .36956 .54492 .38011 .54171 .37367 .53569 Mtetra
.659 .744 .913 r
.37367 .53569 .38011 .54171 .3907 .5385 .38428 .53248 Mtetra
.658 .744 .914 r
.38428 .53248 .3907 .5385 .40133 .5353 .39494 .52928 Mtetra
.657 .745 .915 r
.39494 .52928 .40133 .5353 .412 .53211 .40564 .52609 Mtetra
.656 .746 .916 r
.40564 .52609 .412 .53211 .42272 .52891 .41638 .5229 Mtetra
.656 .746 .917 r
.41638 .5229 .42272 .52891 .43348 .52572 .42717 .51972 Mtetra
.655 .747 .918 r
.42717 .51972 .43348 .52572 .44428 .52253 .438 .51654 Mtetra
.654 .748 .919 r
.438 .51654 .44428 .52253 .45513 .51934 .44887 .51336 Mtetra
.654 .749 .92 r
.44887 .51336 .45513 .51934 .46602 .51615 .4598 .51018 Mtetra
.654 .751 .921 r
.4598 .51018 .46602 .51615 .47696 .51294 .47076 .50698 Mtetra
.654 .752 .922 r
.47076 .50698 .47696 .51294 .48794 .50972 .48177 .50377 Mtetra
.654 .753 .922 r
.48177 .50377 .48794 .50972 .49897 .50648 .49283 .50054 Mtetra
.655 .754 .923 r
.49283 .50054 .49897 .50648 .51005 .50321 .50394 .49728 Mtetra
.655 .755 .923 r
.50394 .49728 .51005 .50321 .52117 .49992 .51509 .49398 Mtetra
.656 .756 .924 r
.51509 .49398 .52117 .49992 .53234 .49659 .52629 .49064 Mtetra
.657 .757 .924 r
.52629 .49064 .53234 .49659 .54355 .49321 .53754 .48725 Mtetra
.659 .758 .923 r
.53754 .48725 .54355 .49321 .55481 .48979 .54883 .48381 Mtetra
.66 .759 .923 r
.54883 .48381 .55481 .48979 .56612 .48632 .56017 .48032 Mtetra
.662 .759 .922 r
.56017 .48032 .56612 .48632 .57747 .4828 .57155 .47676 Mtetra
.663 .76 .922 r
.57155 .47676 .57747 .4828 .58887 .47922 .58299 .47315 Mtetra
.665 .76 .921 r
.58299 .47315 .58887 .47922 .60032 .47559 .59446 .46947 Mtetra
.667 .76 .92 r
.59446 .46947 .60032 .47559 .61181 .47192 .60599 .46574 Mtetra
.668 .759 .919 r
.60599 .46574 .61181 .47192 .62334 .46819 .61756 .46196 Mtetra
.669 .759 .918 r
.61756 .46196 .62334 .46819 .63493 .46442 .62917 .45813 Mtetra
.67 .758 .916 r
.62917 .45813 .63493 .46442 .64656 .4606 .64084 .45426 Mtetra
.671 .757 .915 r
.64084 .45426 .64656 .4606 .65823 .45676 .65254 .45034 Mtetra
.671 .756 .914 r
.65254 .45034 .65823 .45676 .66995 .45288 .6643 .44641 Mtetra
.671 .755 .914 r
.6643 .44641 .66995 .45288 .68172 .44899 .6761 .44246 Mtetra
.668 .753 .914 r
.6761 .44246 .68172 .44899 .69354 .44509 .68796 .43859 Mtetra
.656 .75 .92 r
.68796 .43859 .69354 .44509 .70541 .44129 .69988 .43507 Mtetra
.609 .744 .94 r
.69988 .43507 .70541 .44129 .71736 .43788 .71193 .43271 Mtetra
.418 .697 .979 r
.71193 .43271 .71736 .43788 .72943 .43573 .72422 .43337 Mtetra
.363 0 0 r
.72422 .43337 .72943 .43573 .74178 .43666 .73698 .44004 Mtetra
.775 .309 .136 r
.73698 .44004 .74178 .43666 .75462 .44342 .75049 .45547 Mtetra
.786 .41 .343 r
.75049 .45547 .75462 .44342 .76819 .45808 .76477 .47896 Mtetra
.745 .405 .407 r
.76477 .47896 .76819 .45808 .78244 .47908 .7794 .50337 Mtetra
.662 .337 .413 r
.7794 .50337 .78244 .47908 .79685 .49901 .79341 .51677 Mtetra
.392 .069 .295 r
.79341 .51677 .79685 .49901 .8105 .50729 .80592 .51001 Mtetra
.959 .93 .597 r
.80592 .51001 .8105 .50729 .82268 .49741 .81678 .48434 Mtetra
.898 .712 .644 r
.81678 .48434 .82268 .49741 .83344 .47241 .82681 .45078 Mtetra
.822 .632 .646 r
.82681 .45078 .83344 .47241 .84362 .44254 .83702 .421 Mtetra
.776 .608 .671 r
.83702 .421 .84362 .44254 .85412 .41723 .84798 .4002 Mtetra
.742 .618 .72 r
.84798 .4002 .85412 .41723 .86535 .39997 .85972 .3876 Mtetra
.714 .654 .788 r
.85972 .3876 .86535 .39997 .87726 .38947 .87199 .38006 Mtetra
.689 .697 .852 r
.87199 .38006 .87726 .38947 .88963 .38291 .88455 .37487 Mtetra
.673 .725 .889 r
.88455 .37487 .88963 .38291 .90225 .37809 .89726 .37052 Mtetra
.666 .737 .903 r
.89726 .37052 .90225 .37809 .91498 .37387 .91005 .36641 Mtetra
.664 .741 .907 r
.91005 .36641 .91498 .37387 .92779 .3698 .92291 .36234 Mtetra
.66 .743 .911 r
.33552 .5393 .34208 .54533 .35257 .54211 .34603 .53607 Mtetra
.659 .743 .912 r
.34603 .53607 .35257 .54211 .3631 .5389 .35659 .53285 Mtetra
.658 .743 .913 r
.35659 .53285 .3631 .5389 .37367 .53569 .36718 .52964 Mtetra
.658 .744 .914 r
.36718 .52964 .37367 .53569 .38428 .53248 .37782 .52643 Mtetra
.657 .745 .915 r
.37782 .52643 .38428 .53248 .39494 .52928 .3885 .52324 Mtetra
.656 .745 .916 r
.3885 .52324 .39494 .52928 .40564 .52609 .39923 .52005 Mtetra
.655 .746 .917 r
.39923 .52005 .40564 .52609 .41638 .5229 .41 .51688 Mtetra
.654 .747 .918 r
.41 .51688 .41638 .5229 .42717 .51972 .42081 .51371 Mtetra
.654 .748 .919 r
.42081 .51371 .42717 .51972 .438 .51654 .43167 .51054 Mtetra
.653 .749 .92 r
.43167 .51054 .438 .51654 .44887 .51336 .44257 .50738 Mtetra
.652 .75 .922 r
.44257 .50738 .44887 .51336 .4598 .51018 .45352 .50421 Mtetra
.652 .752 .923 r
.45352 .50421 .4598 .51018 .47076 .50698 .46451 .50103 Mtetra
.652 .753 .923 r
.46451 .50103 .47076 .50698 .48177 .50377 .47556 .49783 Mtetra
.653 .754 .924 r
.47556 .49783 .48177 .50377 .49283 .50054 .48664 .49461 Mtetra
.653 .756 .925 r
.48664 .49461 .49283 .50054 .50394 .49728 .49778 .49135 Mtetra
.654 .757 .925 r
.49778 .49135 .50394 .49728 .51509 .49398 .50896 .48805 Mtetra
.655 .758 .925 r
.50896 .48805 .51509 .49398 .52629 .49064 .52019 .48471 Mtetra
.657 .759 .925 r
.52019 .48471 .52629 .49064 .53754 .48725 .53147 .48131 Mtetra
.658 .76 .925 r
.53147 .48131 .53754 .48725 .54883 .48381 .5428 .47785 Mtetra
.66 .761 .924 r
.5428 .47785 .54883 .48381 .56017 .48032 .55417 .47432 Mtetra
.662 .761 .924 r
.55417 .47432 .56017 .48032 .57155 .47676 .56559 .47073 Mtetra
.664 .762 .923 r
.56559 .47073 .57155 .47676 .58299 .47315 .57705 .46707 Mtetra
.666 .762 .922 r
.57705 .46707 .58299 .47315 .59446 .46947 .58856 .46335 Mtetra
.667 .761 .921 r
.58856 .46335 .59446 .46947 .60599 .46574 .60012 .45957 Mtetra
.669 .761 .919 r
.60012 .45957 .60599 .46574 .61756 .46196 .61173 .45572 Mtetra
.67 .76 .918 r
.61173 .45572 .61756 .46196 .62917 .45813 .62338 .45183 Mtetra
.671 .759 .917 r
.62338 .45183 .62917 .45813 .64084 .45426 .63507 .44789 Mtetra
.672 .758 .916 r
.63507 .44789 .64084 .45426 .65254 .45034 .64681 .44391 Mtetra
.672 .757 .915 r
.64681 .44391 .65254 .45034 .6643 .44641 .6586 .43991 Mtetra
.67 .755 .915 r
.6586 .43991 .6643 .44641 .6761 .44246 .67044 .43597 Mtetra
.659 .753 .919 r
.67044 .43597 .6761 .44246 .68796 .43859 .68235 .43233 Mtetra
.618 .747 .938 r
.68235 .43233 .68796 .43859 .69988 .43507 .69436 .42975 Mtetra
.445 .707 .978 r
.69436 .42975 .69988 .43507 .71193 .43271 .70659 .43006 Mtetra
.319 0 0 r
.70659 .43006 .71193 .43271 .72422 .43337 .71927 .43641 Mtetra
.781 .314 .131 r
.71927 .43641 .72422 .43337 .73698 .44004 .73267 .45219 Mtetra
.797 .423 .349 r
.73267 .45219 .73698 .44004 .75049 .45547 .74694 .47772 Mtetra
.76 .424 .417 r
.74694 .47772 .75049 .45547 .76477 .47896 .76171 .50647 Mtetra
.69 .37 .43 r
.76171 .50647 .76477 .47896 .7794 .50337 .77607 .52555 Mtetra
.493 .178 .362 r
.77607 .52555 .7794 .50337 .79341 .51677 .78895 .523 Mtetra
.849 .894 .471 r
.78895 .523 .79341 .51677 .80592 .51001 .80001 .49759 Mtetra
.911 .72 .632 r
.80001 .49759 .80592 .51001 .81678 .48434 .80995 .46065 Mtetra
.828 .628 .632 r
.80995 .46065 .81678 .48434 .82681 .45078 .81991 .42614 Mtetra
.781 .598 .653 r
.81991 .42614 .82681 .45078 .83702 .421 .8306 .40131 Mtetra
.747 .602 .696 r
.8306 .40131 .83702 .421 .84798 .4002 .84214 .38617 Mtetra
.72 .636 .763 r
.84214 .38617 .84798 .4002 .85972 .3876 .85429 .37738 Mtetra
.695 .683 .834 r
.85429 .37738 .85972 .3876 .87199 .38006 .8668 .3717 Mtetra
.676 .719 .881 r
.8668 .3717 .87199 .38006 .88455 .37487 .87948 .36719 Mtetra
.667 .735 .9 r
.87948 .36719 .88455 .37487 .89726 .37052 .89225 .36302 Mtetra
.665 .74 .906 r
.89225 .36302 .89726 .37052 .91005 .36641 .90509 .35892 Mtetra
.664 .741 .908 r
.90509 .35892 .91005 .36641 .92291 .36234 .91798 .35483 Mtetra
.659 .743 .912 r
.32891 .53323 .33552 .5393 .34603 .53607 .33944 .53 Mtetra
.658 .743 .913 r
.33944 .53 .34603 .53607 .35659 .53285 .35002 .52677 Mtetra
.658 .744 .914 r
.35002 .52677 .35659 .53285 .36718 .52964 .36065 .52356 Mtetra
.657 .744 .915 r
.36065 .52356 .36718 .52964 .37782 .52643 .37131 .52036 Mtetra
.656 .745 .916 r
.37131 .52036 .37782 .52643 .3885 .52324 .38202 .51718 Mtetra
.655 .746 .917 r
.38202 .51718 .3885 .52324 .39923 .52005 .39277 .51401 Mtetra
.654 .747 .918 r
.39277 .51401 .39923 .52005 .41 .51688 .40356 .51084 Mtetra
.653 .748 .919 r
.40356 .51084 .41 .51688 .42081 .51371 .4144 .50769 Mtetra
.652 .749 .921 r
.4144 .50769 .42081 .51371 .43167 .51054 .42529 .50454 Mtetra
.651 .75 .922 r
.42529 .50454 .43167 .51054 .44257 .50738 .43622 .5014 Mtetra
.651 .751 .923 r
.43622 .5014 .44257 .50738 .45352 .50421 .44719 .49825 Mtetra
.651 .753 .924 r
.44719 .49825 .45352 .50421 .46451 .50103 .45822 .49508 Mtetra
.651 .754 .925 r
.45822 .49508 .46451 .50103 .47556 .49783 .46929 .4919 Mtetra
.651 .756 .926 r
.46929 .4919 .47556 .49783 .48664 .49461 .48041 .48869 Mtetra
.652 .757 .927 r
.48041 .48869 .48664 .49461 .49778 .49135 .49157 .48543 Mtetra
.653 .759 .927 r
.49157 .48543 .49778 .49135 .50896 .48805 .50279 .48214 Mtetra
.654 .76 .927 r
.50279 .48214 .50896 .48805 .52019 .48471 .51405 .47878 Mtetra
.656 .761 .927 r
.51405 .47878 .52019 .48471 .53147 .48131 .52536 .47537 Mtetra
.658 .762 .927 r
.52536 .47537 .53147 .48131 .5428 .47785 .53672 .47189 Mtetra
.66 .763 .926 r
.53672 .47189 .5428 .47785 .55417 .47432 .54812 .46833 Mtetra
.662 .763 .925 r
.54812 .46833 .55417 .47432 .56559 .47073 .55957 .4647 Mtetra
.664 .763 .924 r
.55957 .4647 .56559 .47073 .57705 .46707 .57107 .461 Mtetra
.667 .763 .923 r
.57107 .461 .57705 .46707 .58856 .46335 .58262 .45722 Mtetra
.668 .763 .921 r
.58262 .45722 .58856 .46335 .60012 .45957 .59421 .45338 Mtetra
.67 .763 .92 r
.59421 .45338 .60012 .45957 .61173 .45572 .60585 .44947 Mtetra
.671 .762 .918 r
.60585 .44947 .61173 .45572 .62338 .45183 .61753 .4455 Mtetra
.673 .761 .917 r
.61753 .4455 .62338 .45183 .63507 .44789 .62926 .44149 Mtetra
.673 .76 .916 r
.62926 .44149 .63507 .44789 .64681 .44391 .64104 .43745 Mtetra
.671 .758 .916 r
.64104 .43745 .64681 .44391 .6586 .43991 .65286 .43344 Mtetra
.663 .755 .919 r
.65286 .43344 .6586 .43991 .67044 .43597 .66475 .42968 Mtetra
.627 .75 .936 r
.66475 .42968 .67044 .43597 .68235 .43233 .67673 .42687 Mtetra
.475 .717 .976 r
.67673 .42687 .68235 .43233 .69436 .42975 .68891 .42675 Mtetra
0 .313 .693 r
.68891 .42675 .69436 .42975 .70659 .43006 .70148 .43259 Mtetra
.782 .31 .116 r
.70148 .43259 .70659 .43006 .71927 .43641 .71476 .44829 Mtetra
.806 .433 .35 r
.71476 .44829 .71927 .43641 .73267 .45219 .72894 .47527 Mtetra
.773 .44 .423 r
.72894 .47527 .73267 .45219 .74694 .47772 .74378 .508 Mtetra
.713 .397 .442 r
.74378 .508 .74694 .47772 .76171 .50647 .75844 .5331 Mtetra
.562 .254 .403 r
.75844 .5331 .76171 .50647 .77607 .52555 .77173 .53581 Mtetra
0 0 0 r
.77173 .53581 .77607 .52555 .78895 .523 .78306 .51177 Mtetra
.926 .732 .622 r
.78306 .51177 .78895 .523 .80001 .49759 .793 .472 Mtetra
.834 .625 .621 r
.793 .472 .80001 .49759 .80995 .46065 .80276 .43267 Mtetra
.785 .59 .638 r
.80276 .43267 .80995 .46065 .81991 .42614 .81319 .40337 Mtetra
.751 .589 .675 r
.81319 .40337 .81991 .42614 .8306 .40131 .82452 .38525 Mtetra
.725 .618 .738 r
.82452 .38525 .8306 .40131 .84214 .38617 .83654 .37492 Mtetra
.701 .667 .814 r
.83654 .37492 .84214 .38617 .85429 .37738 .84898 .3686 Mtetra
.68 .71 .871 r
.84898 .3686 .85429 .37738 .8668 .3717 .86163 .36387 Mtetra
.669 .732 .897 r
.86163 .36387 .8668 .3717 .87948 .36719 .87438 .35962 Mtetra
.665 .739 .905 r
.87438 .35962 .87948 .36719 .89225 .36302 .8872 .3555 Mtetra
.664 .741 .907 r
.8872 .3555 .89225 .36302 .90509 .35892 .90008 .35138 Mtetra
.664 .741 .908 r
.90008 .35138 .90509 .35892 .91798 .35483 .91302 .34725 Mtetra
.658 .743 .912 r
.32225 .52713 .32891 .53323 .33944 .53 .33281 .52389 Mtetra
.657 .743 .913 r
.33281 .52389 .33944 .53 .35002 .52677 .34341 .52067 Mtetra
.656 .744 .914 r
.34341 .52067 .35002 .52677 .36065 .52356 .35406 .51746 Mtetra
.655 .745 .916 r
.35406 .51746 .36065 .52356 .37131 .52036 .36475 .51427 Mtetra
.654 .745 .917 r
.36475 .51427 .37131 .52036 .38202 .51718 .37548 .5111 Mtetra
.653 .746 .918 r
.37548 .5111 .38202 .51718 .39277 .51401 .38626 .50794 Mtetra
.652 .747 .92 r
.38626 .50794 .39277 .51401 .40356 .51084 .39708 .5048 Mtetra
.651 .748 .921 r
.39708 .5048 .40356 .51084 .4144 .50769 .40795 .50167 Mtetra
.65 .75 .922 r
.40795 .50167 .4144 .50769 .42529 .50454 .41886 .49854 Mtetra
.649 .751 .924 r
.41886 .49854 .42529 .50454 .43622 .5014 .42981 .49542 Mtetra
.649 .753 .925 r
.42981 .49542 .43622 .5014 .44719 .49825 .44082 .49229 Mtetra
.649 .754 .926 r
.44082 .49229 .44719 .49825 .45822 .49508 .45187 .48914 Mtetra
.649 .756 .927 r
.45187 .48914 .45822 .49508 .46929 .4919 .46297 .48598 Mtetra
.649 .757 .928 r
.46297 .48598 .46929 .4919 .48041 .48869 .47412 .48277 Mtetra
.65 .759 .929 r
.47412 .48277 .48041 .48869 .49157 .48543 .48532 .47953 Mtetra
.652 .76 .929 r
.48532 .47953 .49157 .48543 .50279 .48214 .49656 .47623 Mtetra
.654 .762 .929 r
.49656 .47623 .50279 .48214 .51405 .47878 .50786 .47287 Mtetra
.656 .763 .929 r
.50786 .47287 .51405 .47878 .52536 .47537 .5192 .46944 Mtetra
.658 .764 .928 r
.5192 .46944 .52536 .47537 .53672 .47189 .53059 .46593 Mtetra
.66 .765 .927 r
.53059 .46593 .53672 .47189 .54812 .46833 .54203 .46234 Mtetra
.663 .765 .926 r
.54203 .46234 .54812 .46833 .55957 .4647 .55351 .45867 Mtetra
.665 .765 .925 r
.55351 .45867 .55957 .4647 .57107 .461 .56505 .45492 Mtetra
.668 .765 .923 r
.56505 .45492 .57107 .461 .58262 .45722 .57662 .45108 Mtetra
.67 .765 .922 r
.57662 .45108 .58262 .45722 .59421 .45338 .58825 .44717 Mtetra
.671 .764 .92 r
.58825 .44717 .59421 .45338 .60585 .44947 .59992 .44319 Mtetra
.673 .763 .918 r
.59992 .44319 .60585 .44947 .61753 .4455 .61164 .43915 Mtetra
.674 .762 .917 r
.61164 .43915 .61753 .4455 .62926 .44149 .6234 .43507 Mtetra
.673 .76 .916 r
.6234 .43507 .62926 .44149 .64104 .43745 .63522 .431 Mtetra
.666 .758 .919 r
.63522 .431 .64104 .43745 .65286 .43344 .64709 .42713 Mtetra
.635 .753 .933 r
.64709 .42713 .65286 .43344 .66475 .42968 .65904 .42408 Mtetra
.506 .727 .972 r
.65904 .42408 .66475 .42968 .67673 .42687 .67116 .42349 Mtetra
0 .386 .768 r
.67116 .42349 .67673 .42687 .68891 .42675 .68363 .42863 Mtetra
.778 .296 .087 r
.68363 .42863 .68891 .42675 .70148 .43259 .69676 .44384 Mtetra
.813 .439 .347 r
.69676 .44384 .70148 .43259 .71476 .44829 .71079 .4716 Mtetra
.785 .452 .425 r
.71079 .4716 .71476 .44829 .72894 .47527 .72563 .50773 Mtetra
.732 .419 .45 r
.72563 .50773 .72894 .47527 .74378 .508 .74051 .53892 Mtetra
.613 .308 .429 r
.74051 .53892 .74378 .508 .75844 .5331 .7542 .54779 Mtetra
0 0 .013 r
.7542 .54779 .75844 .5331 .77173 .53581 .76587 .52632 Mtetra
.941 .747 .613 r
.76587 .52632 .77173 .53581 .78306 .51177 .77592 .48453 Mtetra
.839 .625 .612 r
.77592 .48453 .78306 .51177 .793 .472 .78555 .44054 Mtetra
.788 .584 .625 r
.78555 .44054 .793 .472 .80276 .43267 .79574 .40646 Mtetra
.755 .578 .657 r
.79574 .40646 .80276 .43267 .81319 .40337 .80686 .38491 Mtetra
.729 .601 .714 r
.80686 .38491 .81319 .40337 .82452 .38525 .81875 .37273 Mtetra
.706 .65 .791 r
.81875 .37273 .82452 .38525 .83654 .37492 .83111 .3656 Mtetra
.685 .7 .858 r
.83111 .3656 .83654 .37492 .84898 .3686 .84372 .36058 Mtetra
.671 .728 .893 r
.84372 .36058 .84898 .3686 .86163 .36387 .85645 .35624 Mtetra
.666 .738 .904 r
.85645 .35624 .86163 .36387 .87438 .35962 .86925 .35207 Mtetra
.665 .741 .907 r
.86925 .35207 .87438 .35962 .8872 .3555 .88211 .34793 Mtetra
.664 .742 .908 r
.88211 .34793 .8872 .3555 .90008 .35138 .89504 .34378 Mtetra
.89504 .34378 .90008 .35138 .91302 .34725 .90802 .33962 Mtetra
.658 .743 .913 r
.31554 .52099 .32225 .52713 .33281 .52389 .32612 .51776 Mtetra
.656 .744 .914 r
.32612 .51776 .33281 .52389 .34341 .52067 .33675 .51454 Mtetra
.655 .744 .915 r
.33675 .51454 .34341 .52067 .35406 .51746 .34742 .51134 Mtetra
.654 .745 .917 r
.34742 .51134 .35406 .51746 .36475 .51427 .35814 .50816 Mtetra
.653 .746 .918 r
.35814 .50816 .36475 .51427 .37548 .5111 .3689 .505 Mtetra
.651 .747 .92 r
.3689 .505 .37548 .5111 .38626 .50794 .3797 .50186 Mtetra
.65 .748 .921 r
.3797 .50186 .38626 .50794 .39708 .5048 .39054 .49874 Mtetra
.649 .749 .923 r
.39054 .49874 .39708 .5048 .40795 .50167 .40144 .49563 Mtetra
.648 .75 .924 r
.40144 .49563 .40795 .50167 .41886 .49854 .41237 .49253 Mtetra
.647 .752 .926 r
.41237 .49253 .41886 .49854 .42981 .49542 .42336 .48944 Mtetra
.647 .753 .927 r
.42336 .48944 .42981 .49542 .44082 .49229 .43439 .48633 Mtetra
.647 .755 .928 r
.43439 .48633 .44082 .49229 .45187 .48914 .44547 .48321 Mtetra
.647 .757 .929 r
.44547 .48321 .45187 .48914 .46297 .48598 .4566 .48006 Mtetra
.648 .759 .93 r
.4566 .48006 .46297 .48598 .47412 .48277 .46778 .47687 Mtetra
.649 .76 .93 r
.46778 .47687 .47412 .48277 .48532 .47953 .47901 .47363 Mtetra
.651 .762 .931 r
.47901 .47363 .48532 .47953 .49656 .47623 .49028 .47033 Mtetra
.653 .763 .93 r
.49028 .47033 .49656 .47623 .50786 .47287 .50161 .46696 Mtetra
.655 .764 .93 r
.50161 .46696 .50786 .47287 .5192 .46944 .51299 .46351 Mtetra
.658 .765 .929 r
.51299 .46351 .5192 .46944 .53059 .46593 .52441 .45997 Mtetra
.661 .766 .928 r
.52441 .45997 .53059 .46593 .54203 .46234 .53588 .45635 Mtetra
.663 .767 .927 r
.53588 .45635 .54203 .46234 .55351 .45867 .5474 .45263 Mtetra
.666 .767 .925 r
.5474 .45263 .55351 .45867 .56505 .45492 .55897 .44882 Mtetra
.669 .767 .923 r
.55897 .44882 .56505 .45492 .57662 .45108 .57058 .44492 Mtetra
.671 .766 .922 r
.57058 .44492 .57662 .45108 .58825 .44717 .58224 .44094 Mtetra
.673 .765 .92 r
.58224 .44094 .58825 .44717 .59992 .44319 .59395 .43689 Mtetra
.674 .764 .918 r
.59395 .43689 .59992 .44319 .61164 .43915 .6057 .43278 Mtetra
.674 .763 .917 r
.6057 .43278 .61164 .43915 .6234 .43507 .6175 .42865 Mtetra
.669 .761 .919 r
.6175 .42865 .6234 .43507 .63522 .431 .62935 .42468 Mtetra
.643 .756 .931 r
.62935 .42468 .63522 .431 .64709 .42713 .64128 .42139 Mtetra
.535 .736 .968 r
.64128 .42139 .64709 .42713 .65904 .42408 .65335 .42032 Mtetra
0 .467 .842 r
.65335 .42032 .65904 .42408 .67116 .42349 .66573 .42462 Mtetra
.766 .271 .042 r
.66573 .42462 .67116 .42349 .68363 .42863 .67869 .43894 Mtetra
.819 .441 .34 r
.67869 .43894 .68363 .42863 .69676 .44384 .69253 .46678 Mtetra
.795 .463 .426 r
.69253 .46678 .69676 .44384 .71079 .4716 .70727 .50553 Mtetra
.749 .436 .455 r
.70727 .50553 .71079 .4716 .72563 .50773 .72229 .54258 Mtetra
.651 .348 .446 r
.72229 .54258 .72563 .50773 .74051 .53892 .73635 .55829 Mtetra
.114 0 .201 r
.73635 .55829 .74051 .53892 .7542 .54779 .74841 .5406 Mtetra
.957 .767 .607 r
.74841 .5406 .7542 .54779 .76587 .52632 .75864 .49783 Mtetra
.844 .625 .605 r
.75864 .49783 .76587 .52632 .77592 .48453 .76823 .44959 Mtetra
.792 .58 .615 r
.76823 .44959 .77592 .48453 .78555 .44054 .77824 .41057 Mtetra
.758 .569 .642 r
.77824 .41057 .78555 .44054 .79574 .40646 .78915 .38522 Mtetra
.732 .586 .692 r
.78915 .38522 .79574 .40646 .80686 .38491 .8009 .37084 Mtetra
.711 .633 .768 r
.8009 .37084 .80686 .38491 .81875 .37273 .81318 .36272 Mtetra
.689 .688 .843 r
.81318 .36272 .81875 .37273 .83111 .3656 .82575 .35733 Mtetra
.674 .723 .887 r
.82575 .35733 .83111 .3656 .84372 .36058 .83845 .35286 Mtetra
.667 .737 .902 r
.83845 .35286 .84372 .36058 .85645 .35624 .85123 .34864 Mtetra
.665 .741 .907 r
.85123 .34864 .85645 .35624 .86925 .35207 .86408 .34447 Mtetra
.664 .742 .908 r
.86408 .34447 .86925 .35207 .88211 .34793 .87699 .3403 Mtetra
.87699 .3403 .88211 .34793 .89504 .34378 .88995 .33612 Mtetra
.88995 .33612 .89504 .34378 .90802 .33962 .90297 .33192 Mtetra
.657 .743 .914 r
.30878 .51482 .31554 .52099 .32612 .51776 .31939 .51159 Mtetra
.655 .744 .915 r
.31939 .51159 .32612 .51776 .33675 .51454 .33004 .50838 Mtetra
.654 .745 .916 r
.33004 .50838 .33675 .51454 .34742 .51134 .34074 .50519 Mtetra
.652 .745 .918 r
.34074 .50519 .34742 .51134 .35814 .50816 .35148 .50203 Mtetra
.651 .746 .919 r
.35148 .50203 .35814 .50816 .3689 .505 .36226 .49889 Mtetra
.649 .747 .921 r
.36226 .49889 .3689 .505 .3797 .50186 .37309 .49577 Mtetra
.648 .748 .923 r
.37309 .49577 .3797 .50186 .39054 .49874 .38396 .49267 Mtetra
.647 .75 .924 r
.38396 .49267 .39054 .49874 .40144 .49563 .39487 .48959 Mtetra
.646 .751 .926 r
.39487 .48959 .40144 .49563 .41237 .49253 .40584 .48652 Mtetra
.645 .753 .928 r
.40584 .48652 .41237 .49253 .42336 .48944 .41685 .48345 Mtetra
.644 .754 .929 r
.41685 .48345 .42336 .48944 .43439 .48633 .42791 .48037 Mtetra
.644 .756 .93 r
.42791 .48037 .43439 .48633 .44547 .48321 .43902 .47728 Mtetra
.645 .758 .931 r
.43902 .47728 .44547 .48321 .4566 .48006 .45018 .47414 Mtetra
.646 .76 .932 r
.45018 .47414 .4566 .48006 .46778 .47687 .46139 .47097 Mtetra
.648 .761 .932 r
.46139 .47097 .46778 .47687 .47901 .47363 .47265 .46774 Mtetra
.65 .763 .932 r
.47265 .46774 .47901 .47363 .49028 .47033 .48396 .46443 Mtetra
.652 .765 .932 r
.48396 .46443 .49028 .47033 .50161 .46696 .49531 .46105 Mtetra
.655 .766 .931 r
.49531 .46105 .50161 .46696 .51299 .46351 .50672 .45758 Mtetra
.658 .767 .93 r
.50672 .45758 .51299 .46351 .52441 .45997 .51818 .45401 Mtetra
.661 .768 .929 r
.51818 .45401 .52441 .45997 .53588 .45635 .52969 .45034 Mtetra
.664 .768 .927 r
.52969 .45034 .53588 .45635 .5474 .45263 .54124 .44657 Mtetra
.667 .768 .925 r
.54124 .44657 .5474 .45263 .55897 .44882 .55284 .4427 Mtetra
.67 .768 .924 r
.55284 .4427 .55897 .44882 .57058 .44492 .56449 .43873 Mtetra
.673 .767 .922 r
.56449 .43873 .57058 .44492 .58224 .44094 .57619 .43468 Mtetra
.674 .766 .92 r
.57619 .43468 .58224 .44094 .59395 .43689 .58793 .43055 Mtetra
.675 .765 .918 r
.58793 .43055 .59395 .43689 .6057 .43278 .59972 .42638 Mtetra
.671 .763 .919 r
.59972 .42638 .6057 .43278 .6175 .42865 .61156 .42232 Mtetra
.651 .759 .929 r
.61156 .42232 .6175 .42865 .62935 .42468 .62346 .41882 Mtetra
.562 .744 .962 r
.62346 .41882 .62935 .42468 .64128 .42139 .63548 .41725 Mtetra
.086 .546 .906 r
.63548 .41725 .64128 .42139 .65335 .42032 .64777 .42062 Mtetra
.743 .229 0 r
.64777 .42062 .65335 .42032 .66573 .42462 .66056 .43372 Mtetra
.824 .44 .327 r
.66056 .43372 .66573 .42462 .67869 .43894 .67417 .46094 Mtetra
.804 .471 .423 r
.67417 .46094 .67869 .43894 .69253 .46678 .68874 .50143 Mtetra
.764 .451 .457 r
.68874 .50143 .69253 .46678 .70727 .50553 .7038 .54382 Mtetra
.68 .379 .457 r
.7038 .54382 .70727 .50553 .72229 .54258 .71816 .56671 Mtetra
.316 .031 .311 r
.71816 .56671 .72229 .54258 .73635 .55829 .73061 .55388 Mtetra
.973 .793 .601 r
.73061 .55388 .73635 .55829 .74841 .5406 .74113 .51133 Mtetra
.849 .626 .6 r
.74113 .51133 .74841 .5406 .75864 .49783 .75077 .45956 Mtetra
.794 .577 .607 r
.75077 .45956 .75864 .49783 .76823 .44959 .76065 .41566 Mtetra
.76 .562 .629 r
.76065 .41566 .76823 .44959 .77824 .41057 .77139 .38621 Mtetra
.735 .573 .673 r
.77139 .38621 .77824 .41057 .78915 .38522 .78299 .36931 Mtetra
.714 .615 .745 r
.78299 .36931 .78915 .38522 .8009 .37084 .79519 .35999 Mtetra
.694 .674 .826 r
.79519 .35999 .8009 .37084 .81318 .36272 .80771 .35413 Mtetra
.677 .717 .879 r
.80771 .35413 .81318 .36272 .82575 .35733 .82039 .3495 Mtetra
.668 .735 .9 r
.82039 .3495 .82575 .35733 .83845 .35286 .83315 .34522 Mtetra
.666 .741 .906 r
.83315 .34522 .83845 .35286 .85123 .34864 .84598 .34101 Mtetra
.665 .742 .907 r
.84598 .34101 .85123 .34864 .86408 .34447 .85887 .33681 Mtetra
.664 .742 .908 r
.85887 .33681 .86408 .34447 .87699 .3403 .87182 .33261 Mtetra
.87182 .33261 .87699 .3403 .88995 .33612 .88482 .32839 Mtetra
.88482 .32839 .88995 .33612 .90297 .33192 .89789 .32416 Mtetra
.655 .744 .915 r
.30196 .50862 .30878 .51482 .31939 .51159 .3126 .5054 Mtetra
.654 .744 .916 r
.3126 .5054 .31939 .51159 .33004 .50838 .32328 .50219 Mtetra
.652 .745 .917 r
.32328 .50219 .33004 .50838 .34074 .50519 .334 .49902 Mtetra
.651 .746 .919 r
.334 .49902 .34074 .50519 .35148 .50203 .34476 .49587 Mtetra
.649 .747 .921 r
.34476 .49587 .35148 .50203 .36226 .49889 .35557 .49275 Mtetra
.647 .748 .922 r
.35557 .49275 .36226 .49889 .37309 .49577 .36642 .48966 Mtetra
.646 .749 .924 r
.36642 .48966 .37309 .49577 .38396 .49267 .37732 .4866 Mtetra
.644 .75 .926 r
.37732 .4866 .38396 .49267 .39487 .48959 .38826 .48354 Mtetra
.643 .752 .928 r
.38826 .48354 .39487 .48959 .40584 .48652 .39925 .4805 Mtetra
.643 .753 .929 r
.39925 .4805 .40584 .48652 .41685 .48345 .41029 .47746 Mtetra
.642 .755 .931 r
.41029 .47746 .41685 .48345 .42791 .48037 .42138 .47441 Mtetra
.642 .757 .932 r
.42138 .47441 .42791 .48037 .43902 .47728 .43252 .47134 Mtetra
.643 .759 .933 r
.43252 .47134 .43902 .47728 .45018 .47414 .44371 .46823 Mtetra
.644 .761 .933 r
.44371 .46823 .45018 .47414 .46139 .47097 .45494 .46506 Mtetra
.646 .763 .934 r
.45494 .46506 .46139 .47097 .47265 .46774 .46623 .46183 Mtetra
.649 .764 .933 r
.46623 .46183 .47265 .46774 .48396 .46443 .47758 .45853 Mtetra
.651 .766 .933 r
.47758 .45853 .48396 .46443 .49531 .46105 .48897 .45513 Mtetra
.655 .767 .932 r
.48897 .45513 .49531 .46105 .50672 .45758 .50041 .45163 Mtetra
.658 .768 .931 r
.50041 .45163 .50672 .45758 .51818 .45401 .5119 .44802 Mtetra
.662 .769 .929 r
.5119 .44802 .51818 .45401 .52969 .45034 .52344 .44431 Mtetra
.665 .769 .927 r
.52344 .44431 .52969 .45034 .54124 .44657 .53503 .44048 Mtetra
.668 .769 .925 r
.53503 .44048 .54124 .44657 .55284 .4427 .54667 .43654 Mtetra
.672 .769 .923 r
.54667 .43654 .55284 .4427 .56449 .43873 .55835 .4325 Mtetra
.674 .768 .921 r
.55835 .4325 .56449 .43873 .57619 .43468 .57008 .42837 Mtetra
.676 .767 .92 r
.57008 .42837 .57619 .43468 .58793 .43055 .58186 .42418 Mtetra
.673 .765 .92 r
.58186 .42418 .58793 .43055 .59972 .42638 .59368 .42004 Mtetra
.657 .762 .927 r
.59368 .42004 .59972 .42638 .61156 .42232 .60557 .41635 Mtetra
.586 .751 .956 r
.60557 .41635 .61156 .42232 .62346 .41882 .61755 .4143 Mtetra
.208 .614 .95 r
.61755 .4143 .62346 .41882 .63548 .41725 .62975 .4167 Mtetra
.703 .166 0 r
.62975 .4167 .63548 .41725 .64777 .42062 .64237 .42831 Mtetra
.827 .435 .309 r
.64237 .42831 .64777 .42062 .66056 .43372 .65574 .45428 Mtetra
.813 .477 .419 r
.65574 .45428 .66056 .43372 .67417 .46094 .67007 .49556 Mtetra
.777 .464 .458 r
.67007 .49556 .67417 .46094 .68874 .50143 .68506 .54252 Mtetra
.704 .403 .464 r
.68506 .54252 .68874 .50143 .7038 .54382 .69963 .57256 Mtetra
.442 .15 .373 r
.69963 .57256 .7038 .54382 .71816 .56671 .71247 .56541 Mtetra
.988 .825 .594 r
.71247 .56541 .71816 .56671 .73061 .55388 .72333 .52437 Mtetra
.853 .629 .597 r
.72333 .52437 .73061 .55388 .74113 .51133 .73312 .47006 Mtetra
.797 .575 .601 r
.73312 .47006 .74113 .51133 .75077 .45956 .74297 .42159 Mtetra
.762 .556 .619 r
.74297 .42159 .75077 .45956 .76065 .41566 .75356 .38787 Mtetra
.737 .563 .657 r
.75356 .38787 .76065 .41566 .77139 .38621 .76503 .36817 Mtetra
.717 .599 .723 r
.76503 .36817 .77139 .38621 .78299 .36931 .77714 .35744 Mtetra
.698 .659 .807 r
.77714 .35744 .78299 .36931 .79519 .35999 .78961 .351 Mtetra
.68 .709 .87 r
.78961 .351 .79519 .35999 .80771 .35413 .80226 .34616 Mtetra
.67 .733 .897 r
.80226 .34616 .80771 .35413 .82039 .3495 .815 .3418 Mtetra
.666 .74 .905 r
.815 .3418 .82039 .3495 .83315 .34522 .82781 .33755 Mtetra
.665 .742 .907 r
.82781 .33755 .83315 .34522 .84598 .34101 .84069 .33332 Mtetra
.665 .742 .908 r
.84069 .33332 .84598 .34101 .85887 .33681 .85362 .32909 Mtetra
.664 .742 .908 r
.85362 .32909 .85887 .33681 .87182 .33261 .8666 .32485 Mtetra
.8666 .32485 .87182 .33261 .88482 .32839 .87965 .3206 Mtetra
.87965 .3206 .88482 .32839 .89789 .32416 .89276 .31633 Mtetra
.654 .744 .915 r
.2951 .50239 .30196 .50862 .3126 .5054 .30576 .49917 Mtetra
.653 .744 .917 r
.30576 .49917 .3126 .5054 .32328 .50219 .31646 .49598 Mtetra
.651 .745 .919 r
.31646 .49598 .32328 .50219 .334 .49902 .3272 .49282 Mtetra
.649 .746 .92 r
.3272 .49282 .334 .49902 .34476 .49587 .33799 .48969 Mtetra
.647 .747 .922 r
.33799 .48969 .34476 .49587 .35557 .49275 .34882 .4866 Mtetra
.645 .748 .924 r
.34882 .4866 .35557 .49275 .36642 .48966 .3597 .48354 Mtetra
.644 .749 .926 r
.3597 .48354 .36642 .48966 .37732 .4866 .37062 .4805 Mtetra
.642 .751 .928 r
.37062 .4805 .37732 .4866 .38826 .48354 .38159 .47748 Mtetra
.641 .752 .929 r
.38159 .47748 .38826 .48354 .39925 .4805 .39261 .47447 Mtetra
.64 .754 .931 r
.39261 .47447 .39925 .4805 .41029 .47746 .40368 .47146 Mtetra
.64 .756 .932 r
.40368 .47146 .41029 .47746 .42138 .47441 .41479 .46844 Mtetra
.64 .758 .934 r
.41479 .46844 .42138 .47441 .43252 .47134 .42596 .46539 Mtetra
.641 .76 .934 r
.42596 .46539 .43252 .47134 .44371 .46823 .43718 .4623 Mtetra
.643 .761 .935 r
.43718 .4623 .44371 .46823 .45494 .46506 .44845 .45914 Mtetra
.645 .763 .935 r
.44845 .45914 .45494 .46506 .46623 .46183 .45977 .45591 Mtetra
.648 .765 .935 r
.45977 .45591 .46623 .46183 .47758 .45853 .47114 .4526 Mtetra
.651 .767 .934 r
.47114 .4526 .47758 .45853 .48897 .45513 .48257 .44918 Mtetra
.655 .768 .933 r
.48257 .44918 .48897 .45513 .50041 .45163 .49404 .44565 Mtetra
.659 .769 .931 r
.49404 .44565 .50041 .45163 .5119 .44802 .50557 .442 Mtetra
.662 .77 .929 r
.50557 .442 .5119 .44802 .52344 .44431 .51714 .43824 Mtetra
.666 .77 .927 r
.51714 .43824 .52344 .44431 .53503 .44048 .52877 .43435 Mtetra
.67 .77 .925 r
.52877 .43435 .53503 .44048 .54667 .43654 .54044 .43034 Mtetra
.673 .769 .923 r
.54044 .43034 .54667 .43654 .55835 .4325 .55216 .42622 Mtetra
.675 .769 .921 r
.55216 .42622 .55835 .4325 .57008 .42837 .56392 .42203 Mtetra
.675 .767 .92 r
.56392 .42203 .57008 .42837 .58186 .42418 .57574 .41784 Mtetra
.662 .765 .926 r
.57574 .41784 .58186 .42418 .59368 .42004 .58761 .41398 Mtetra
.606 .756 .95 r
.58761 .41398 .59368 .42004 .60557 .41635 .59956 .41149 Mtetra
.317 .667 .974 r
.59956 .41149 .60557 .41635 .61755 .4143 .61168 .4129 Mtetra
.635 .072 0 r
.61168 .4129 .61755 .4143 .62975 .4167 .62415 .42285 Mtetra
.828 .424 .283 r
.62415 .42285 .62975 .4167 .64237 .42831 .63727 .44703 Mtetra
.821 .481 .412 r
.63727 .44703 .64237 .42831 .65574 .45428 .6513 .48819 Mtetra
.788 .474 .457 r
.6513 .48819 .65574 .45428 .67007 .49556 .66613 .53878 Mtetra
.722 .421 .469 r
.66613 .53878 .67007 .49556 .68506 .54252 .6808 .5755 Mtetra
.522 .228 .409 r
.6808 .5755 .68506 .54252 .69963 .57256 .69397 .57449 Mtetra
.995 .863 .583 r
.69397 .57449 .69963 .57256 .71247 .56541 .70522 .53624 Mtetra
.857 .632 .596 r
.70522 .53624 .71247 .56541 .72333 .52437 .71526 .48061 Mtetra
.799 .574 .596 r
.71526 .48061 .72333 .52437 .73312 .47006 .72514 .42814 Mtetra
.764 .552 .611 r
.72514 .42814 .73312 .47006 .74297 .42159 .73565 .39017 Mtetra
.739 .554 .644 r
.73565 .39017 .74297 .42159 .75356 .38787 .747 .36744 Mtetra
.719 .585 .704 r
.747 .36744 .75356 .38787 .76503 .36817 .75903 .35508 Mtetra
.702 .643 .787 r
.75903 .35508 .76503 .36817 .77714 .35744 .77145 .34795 Mtetra
.684 .7 .859 r
.77145 .34795 .77714 .35744 .78961 .351 .78406 .34286 Mtetra
.672 .73 .893 r
.78406 .34286 .78961 .351 .80226 .34616 .79679 .3384 Mtetra
.667 .74 .904 r
.79679 .3384 .80226 .34616 .815 .3418 .80958 .3341 Mtetra
.666 .742 .907 r
.80958 .3341 .815 .3418 .82781 .33755 .82243 .32984 Mtetra
.665 .742 .907 r
.82243 .32984 .82781 .33755 .84069 .33332 .83535 .32558 Mtetra
.665 .742 .908 r
.83535 .32558 .84069 .33332 .85362 .32909 .84832 .32131 Mtetra
.664 .742 .908 r
.84832 .32131 .85362 .32909 .8666 .32485 .86135 .31703 Mtetra
.86135 .31703 .8666 .32485 .87965 .3206 .87444 .31274 Mtetra
.87444 .31274 .87965 .3206 .89276 .31633 .88759 .30844 Mtetra
.653 .744 .916 r
.28818 .49612 .2951 .50239 .30576 .49917 .29887 .49291 Mtetra
.651 .744 .918 r
.29887 .49291 .30576 .49917 .31646 .49598 .30959 .48973 Mtetra
.649 .745 .92 r
.30959 .48973 .31646 .49598 .3272 .49282 .32036 .48659 Mtetra
.647 .746 .921 r
.32036 .48659 .3272 .49282 .33799 .48969 .33117 .48349 Mtetra
.645 .747 .923 r
.33117 .48349 .33799 .48969 .34882 .4866 .34203 .48042 Mtetra
.643 .748 .925 r
.34203 .48042 .34882 .4866 .3597 .48354 .35293 .47739 Mtetra
.641 .749 .927 r
.35293 .47739 .3597 .48354 .37062 .4805 .36387 .47438 Mtetra
.64 .751 .929 r
.36387 .47438 .37062 .4805 .38159 .47748 .37487 .4714 Mtetra
.638 .752 .931 r
.37487 .4714 .38159 .47748 .39261 .47447 .38591 .46842 Mtetra
.638 .754 .933 r
.38591 .46842 .39261 .47447 .40368 .47146 .39701 .46545 Mtetra
.638 .756 .934 r
.39701 .46545 .40368 .47146 .41479 .46844 .40815 .46245 Mtetra
.638 .758 .935 r
.40815 .46245 .41479 .46844 .42596 .46539 .41935 .45942 Mtetra
.639 .76 .936 r
.41935 .45942 .42596 .46539 .43718 .4623 .43059 .45634 Mtetra
.641 .762 .936 r
.43059 .45634 .43718 .4623 .44845 .45914 .4419 .4532 Mtetra
.644 .764 .936 r
.4419 .4532 .44845 .45914 .45977 .45591 .45325 .44997 Mtetra
.647 .766 .935 r
.45325 .44997 .45977 .45591 .47114 .4526 .46465 .44664 Mtetra
.651 .767 .934 r
.46465 .44664 .47114 .4526 .48257 .44918 .47611 .4432 Mtetra
.655 .769 .933 r
.47611 .4432 .48257 .44918 .49404 .44565 .48762 .43963 Mtetra
.659 .769 .931 r
.48762 .43963 .49404 .44565 .50557 .442 .49918 .43594 Mtetra
.663 .77 .929 r
.49918 .43594 .50557 .442 .51714 .43824 .51079 .43211 Mtetra
.668 .77 .927 r
.51079 .43211 .51714 .43824 .52877 .43435 .52245 .42816 Mtetra
.671 .77 .924 r
.52245 .42816 .52877 .43435 .54044 .43034 .53416 .42408 Mtetra
.674 .77 .922 r
.53416 .42408 .54044 .43034 .55216 .42622 .54591 .41989 Mtetra
.675 .769 .921 r
.54591 .41989 .55216 .42622 .56392 .42203 .55772 .41568 Mtetra
.667 .766 .925 r
.55772 .41568 .56392 .42203 .57574 .41784 .56957 .41169 Mtetra
.623 .76 .944 r
.56957 .41169 .57574 .41784 .58761 .41398 .5815 .40881 Mtetra
.407 .704 .983 r
.5815 .40881 .58761 .41398 .59956 .41149 .59355 .40927 Mtetra
.521 0 0 r
.59355 .40927 .59956 .41149 .61168 .4129 .60588 .41747 Mtetra
.825 .406 .246 r
.60588 .41747 .61168 .4129 .62415 .42285 .61875 .43945 Mtetra
.828 .483 .403 r
.61875 .43945 .62415 .42285 .63727 .44703 .63247 .47968 Mtetra
.798 .483 .456 r
.63247 .47968 .63727 .44703 .6513 .48819 .64705 .53286 Mtetra
.736 .436 .472 r
.64705 .53286 .6513 .48819 .66613 .53878 .6617 .57542 Mtetra
.575 .28 .43 r
.6617 .57542 .66613 .53878 .6808 .5755 .67512 .58056 Mtetra
.979 .899 .559 r
.67512 .58056 .6808 .5755 .69397 .57449 .68677 .54619 Mtetra
.86 .636 .597 r
.68677 .54619 .69397 .57449 .70522 .53624 .69714 .49064 Mtetra
.801 .574 .593 r
.69714 .49064 .70522 .53624 .71526 .48061 .70716 .43504 Mtetra
.766 .55 .605 r
.70716 .43504 .71526 .48061 .72514 .42814 .71764 .39301 Mtetra
.74 .547 .632 r
.71764 .39301 .72514 .42814 .73565 .39017 .72891 .36712 Mtetra
.721 .572 .686 r
.72891 .36712 .73565 .39017 .747 .36744 .74085 .35295 Mtetra
.705 .627 .767 r
.74085 .35295 .747 .36744 .75903 .35508 .75322 .345 Mtetra
.688 .689 .846 r
.75322 .345 .75903 .35508 .77145 .34795 .7658 .3396 Mtetra
.674 .726 .888 r
.7658 .3396 .77145 .34795 .78406 .34286 .77851 .33502 Mtetra
.669 .739 .903 r
.77851 .33502 .78406 .34286 .79679 .3384 .79128 .33067 Mtetra
.667 .742 .906 r
.79128 .33067 .79679 .3384 .80958 .3341 .80412 .32636 Mtetra
.666 .742 .907 r
.80412 .32636 .80958 .3341 .82243 .32984 .81701 .32206 Mtetra
.665 .742 .907 r
.81701 .32206 .82243 .32984 .83535 .32558 .82996 .31776 Mtetra
.665 .742 .908 r
.82996 .31776 .83535 .32558 .84832 .32131 .84298 .31346 Mtetra
.84298 .31346 .84832 .32131 .86135 .31703 .85605 .30915 Mtetra
.664 .742 .908 r
.85605 .30915 .86135 .31703 .87444 .31274 .86918 .30482 Mtetra
.86918 .30482 .87444 .31274 .88759 .30844 .88237 .30049 Mtetra
.652 .744 .917 r
.28121 .48982 .28818 .49612 .29887 .49291 .29192 .48662 Mtetra
.65 .744 .919 r
.29192 .48662 .29887 .49291 .30959 .48973 .30267 .48346 Mtetra
.647 .745 .921 r
.30267 .48346 .30959 .48973 .32036 .48659 .31346 .48034 Mtetra
.645 .746 .923 r
.31346 .48034 .32036 .48659 .33117 .48349 .32429 .47726 Mtetra
.643 .747 .925 r
.32429 .47726 .33117 .48349 .34203 .48042 .33517 .47422 Mtetra
.641 .748 .927 r
.33517 .47422 .34203 .48042 .35293 .47739 .3461 .47122 Mtetra
.639 .749 .929 r
.3461 .47122 .35293 .47739 .36387 .47438 .35707 .46824 Mtetra
.637 .751 .931 r
.35707 .46824 .36387 .47438 .37487 .4714 .36809 .46529 Mtetra
.636 .753 .932 r
.36809 .46529 .37487 .4714 .38591 .46842 .37916 .46235 Mtetra
.635 .754 .934 r
.37916 .46235 .38591 .46842 .39701 .46545 .39028 .4594 Mtetra
.635 .756 .935 r
.39028 .4594 .39701 .46545 .40815 .46245 .40146 .45643 Mtetra
.636 .758 .936 r
.40146 .45643 .40815 .46245 .41935 .45942 .41268 .45342 Mtetra
.638 .76 .937 r
.41268 .45342 .41935 .45942 .43059 .45634 .42396 .45036 Mtetra
.64 .762 .937 r
.42396 .45036 .43059 .45634 .4419 .4532 .43529 .44722 Mtetra
.643 .764 .936 r
.43529 .44722 .4419 .4532 .45325 .44997 .44667 .44398 Mtetra
.647 .766 .936 r
.44667 .44398 .45325 .44997 .46465 .44664 .45811 .44063 Mtetra
.651 .767 .934 r
.45811 .44063 .46465 .44664 .47611 .4432 .4696 .43716 Mtetra
.655 .769 .933 r
.4696 .43716 .47611 .4432 .48762 .43963 .48115 .43356 Mtetra
.66 .77 .931 r
.48115 .43356 .48762 .43963 .49918 .43594 .49274 .42981 Mtetra
.665 .77 .928 r
.49274 .42981 .49918 .43594 .51079 .43211 .50439 .42593 Mtetra
.669 .77 .926 r
.50439 .42593 .51079 .43211 .52245 .42816 .51608 .4219 Mtetra
.673 .77 .923 r
.51608 .4219 .52245 .42816 .53416 .42408 .52783 .41775 Mtetra
.675 .769 .922 r
.52783 .41775 .53416 .42408 .54591 .41989 .53962 .41353 Mtetra
.669 .767 .924 r
.53962 .41353 .54591 .41989 .55772 .41568 .55146 .40945 Mtetra
.637 .763 .939 r
.55146 .40945 .55772 .41568 .56957 .41169 .56336 .40623 Mtetra
.478 .728 .98 r
.56336 .40623 .56957 .41169 .5815 .40881 .57536 .40582 Mtetra
.351 0 0 r
.57536 .40582 .5815 .40881 .59355 .40927 .58757 .41226 Mtetra
.818 .379 .196 r
.58757 .41226 .59355 .40927 .60588 .41747 .60022 .43179 Mtetra
.835 .484 .392 r
.60022 .43179 .60588 .41747 .61875 .43945 .61361 .47046 Mtetra
.807 .49 .453 r
.61361 .47046 .61875 .43945 .63247 .47968 .62788 .52523 Mtetra
.747 .446 .474 r
.62788 .52523 .63247 .47968 .64705 .53286 .64239 .57243 Mtetra
.611 .315 .443 r
.64239 .57243 .64705 .53286 .6617 .57542 .65596 .58319 Mtetra
.906 .909 .507 r
.65596 .58319 .6617 .57542 .67512 .58056 .66799 .55353 Mtetra
.862 .64 .601 r
.66799 .55353 .67512 .58056 .68677 .54619 .67875 .49955 Mtetra
.803 .574 .592 r
.67875 .49955 .68677 .54619 .69714 .49064 .68899 .44192 Mtetra
.768 .548 .6 r
.68899 .44192 .69714 .49064 .70716 .43504 .69951 .39625 Mtetra
.742 .542 .624 r
.69951 .39625 .70716 .43504 .71764 .39301 .71073 .36718 Mtetra
.723 .561 .671 r
.71073 .36718 .71764 .39301 .72891 .36712 .7226 .35105 Mtetra
.708 .612 .748 r
.7226 .35105 .72891 .36712 .74085 .35295 .73492 .34217 Mtetra
.692 .678 .832 r
.73492 .34217 .74085 .35295 .75322 .345 .74748 .33639 Mtetra
.677 .721 .882 r
.74748 .33639 .75322 .345 .7658 .3396 .76016 .33167 Mtetra
.67 .738 .901 r
.76016 .33167 .7658 .3396 .77851 .33502 .77291 .32724 Mtetra
.668 .742 .906 r
.77291 .32724 .77851 .33502 .79128 .33067 .78573 .32289 Mtetra
.667 .743 .907 r
.78573 .32289 .79128 .33067 .80412 .32636 .79861 .31855 Mtetra
.666 .742 .907 r
.79861 .31855 .80412 .32636 .81701 .32206 .81154 .31422 Mtetra
.665 .742 .907 r
.81154 .31422 .81701 .32206 .82996 .31776 .82454 .30988 Mtetra
.665 .742 .908 r
.82454 .30988 .82996 .31776 .84298 .31346 .83759 .30554 Mtetra
.83759 .30554 .84298 .31346 .85605 .30915 .85071 .30119 Mtetra
.664 .742 .908 r
.85071 .30119 .85605 .30915 .86918 .30482 .86388 .29683 Mtetra
.86388 .29683 .86918 .30482 .88237 .30049 .87712 .29246 Mtetra
.65 .744 .918 r
.27419 .48348 .28121 .48982 .29192 .48662 .28492 .48029 Mtetra
.648 .744 .92 r
.28492 .48029 .29192 .48662 .30267 .48346 .29569 .47715 Mtetra
.645 .745 .922 r
.29569 .47715 .30267 .48346 .31346 .48034 .3065 .47405 Mtetra
.643 .746 .924 r
.3065 .47405 .31346 .48034 .32429 .47726 .31736 .47099 Mtetra
.641 .747 .926 r
.31736 .47099 .32429 .47726 .33517 .47422 .32827 .46798 Mtetra
.638 .748 .928 r
.32827 .46798 .33517 .47422 .3461 .47122 .33922 .46501 Mtetra
.636 .749 .93 r
.33922 .46501 .3461 .47122 .35707 .46824 .35021 .46207 Mtetra
.635 .751 .932 r
.35021 .46207 .35707 .46824 .36809 .46529 .36126 .45915 Mtetra
.633 .752 .934 r
.36126 .45915 .36809 .46529 .37916 .46235 .37236 .45624 Mtetra
.633 .754 .935 r
.37236 .45624 .37916 .46235 .39028 .4594 .3835 .45332 Mtetra
.633 .756 .936 r
.3835 .45332 .39028 .4594 .40146 .45643 .3947 .45037 Mtetra
.634 .758 .937 r
.3947 .45037 .40146 .45643 .41268 .45342 .40596 .44738 Mtetra
.636 .76 .937 r
.40596 .44738 .41268 .45342 .42396 .45036 .41727 .44433 Mtetra
.639 .762 .937 r
.41727 .44433 .42396 .45036 .43529 .44722 .42863 .44118 Mtetra
.642 .764 .937 r
.42863 .44118 .43529 .44722 .44667 .44398 .44004 .43794 Mtetra
.646 .766 .935 r
.44004 .43794 .44667 .44398 .45811 .44063 .45152 .43457 Mtetra
.651 .767 .934 r
.45152 .43457 .45811 .44063 .4696 .43716 .46304 .43106 Mtetra
.656 .768 .932 r
.46304 .43106 .4696 .43716 .48115 .43356 .47462 .42741 Mtetra
.661 .769 .93 r
.47462 .42741 .48115 .43356 .49274 .42981 .48625 .42361 Mtetra
.666 .77 .927 r
.48625 .42361 .49274 .42981 .50439 .42593 .49793 .41966 Mtetra
.67 .77 .925 r
.49793 .41966 .50439 .42593 .51608 .4219 .50966 .41556 Mtetra
.673 .769 .923 r
.50966 .41556 .51608 .4219 .52783 .41775 .52144 .41137 Mtetra
.671 .768 .923 r
.52144 .41137 .52783 .41775 .53962 .41353 .53327 .40723 Mtetra
.647 .764 .935 r
.53327 .40723 .53962 .41353 .55146 .40945 .54515 .40374 Mtetra
.531 .743 .973 r
.54515 .40374 .55146 .40945 .56336 .40623 .55711 .40254 Mtetra
0 .402 .78 r
.55711 .40254 .56336 .40623 .57536 .40582 .56922 .40729 Mtetra
.803 .337 .126 r
.56922 .40729 .57536 .40582 .58757 .41226 .58167 .42428 Mtetra
.841 .483 .377 r
.58167 .42428 .58757 .41226 .60022 .43179 .59475 .46098 Mtetra
.814 .495 .45 r
.59475 .46098 .60022 .43179 .61361 .47046 .60866 .51645 Mtetra
.754 .453 .475 r
.60866 .51645 .61361 .47046 .62788 .52523 .62293 .56687 Mtetra
.634 .338 .451 r
.62293 .56687 .62788 .52523 .64239 .57243 .63654 .58221 Mtetra
.734 .848 .41 r
.63654 .58221 .64239 .57243 .65596 .58319 .64889 .55769 Mtetra
.862 .644 .606 r
.64889 .55769 .65596 .58319 .66799 .55353 .66007 .50672 Mtetra
.804 .575 .591 r
.66007 .50672 .66799 .55353 .67875 .49955 .67061 .44835 Mtetra
.769 .547 .596 r
.67061 .44835 .67875 .49955 .68899 .44192 .68125 .39969 Mtetra
.743 .538 .616 r
.68125 .39969 .68899 .44192 .69951 .39625 .69246 .36756 Mtetra
.724 .552 .658 r
.69246 .36756 .69951 .39625 .71073 .36718 .70429 .34938 Mtetra
.71 .599 .73 r
.70429 .34938 .71073 .36718 .7226 .35105 .71656 .33946 Mtetra
.695 .665 .816 r
.71656 .33946 .7226 .35105 .73492 .34217 .72908 .33325 Mtetra
.68 .715 .875 r
.72908 .33325 .73492 .34217 .74748 .33639 .74174 .32835 Mtetra
.672 .736 .898 r
.74174 .32835 .74748 .33639 .76016 .33167 .75447 .32384 Mtetra
.669 .742 .905 r
.75447 .32384 .76016 .33167 .77291 .32724 .76727 .31943 Mtetra
.667 .743 .907 r
.76727 .31943 .77291 .32724 .78573 .32289 .78013 .31505 Mtetra
.78013 .31505 .78573 .32289 .79861 .31855 .79305 .31068 Mtetra
.666 .742 .907 r
.79305 .31068 .79861 .31855 .81154 .31422 .80603 .30631 Mtetra
.665 .742 .907 r
.80603 .30631 .81154 .31422 .82454 .30988 .81906 .30194 Mtetra
.81906 .30194 .82454 .30988 .83759 .30554 .83216 .29756 Mtetra
.665 .742 .908 r
.83216 .29756 .83759 .30554 .85071 .30119 .84532 .29318 Mtetra
.664 .742 .908 r
.84532 .29318 .85071 .30119 .86388 .29683 .85854 .28878 Mtetra
.85854 .28878 .86388 .29683 .87712 .29246 .87181 .28437 Mtetra
.649 .744 .919 r
.26711 .4771 .27419 .48348 .28492 .48029 .27786 .47392 Mtetra
.646 .744 .921 r
.27786 .47392 .28492 .48029 .29569 .47715 .28865 .47079 Mtetra
.644 .745 .923 r
.28865 .47079 .29569 .47715 .3065 .47405 .29949 .46772 Mtetra
.641 .746 .925 r
.29949 .46772 .3065 .47405 .31736 .47099 .31038 .46469 Mtetra
.638 .747 .927 r
.31038 .46469 .31736 .47099 .32827 .46798 .3213 .46171 Mtetra
.636 .748 .929 r
.3213 .46171 .32827 .46798 .33922 .46501 .33228 .45877 Mtetra
.634 .749 .931 r
.33228 .45877 .33922 .46501 .35021 .46207 .3433 .45586 Mtetra
.632 .75 .933 r
.3433 .45586 .35021 .46207 .36126 .45915 .35437 .45297 Mtetra
.631 .752 .935 r
.35437 .45297 .36126 .45915 .37236 .45624 .36549 .45009 Mtetra
.631 .754 .936 r
.36549 .45009 .37236 .45624 .3835 .45332 .37667 .44719 Mtetra
.631 .755 .937 r
.37667 .44719 .3835 .45332 .3947 .45037 .3879 .44426 Mtetra
.633 .757 .938 r
.3879 .44426 .3947 .45037 .40596 .44738 .39918 .44128 Mtetra
.635 .759 .938 r
.39918 .44128 .40596 .44738 .41727 .44433 .41052 .43823 Mtetra
.638 .761 .937 r
.41052 .43823 .41727 .44433 .42863 .44118 .42191 .43508 Mtetra
.642 .763 .936 r
.42191 .43508 .42863 .44118 .44004 .43794 .43336 .43182 Mtetra
.647 .765 .935 r
.43336 .43182 .44004 .43794 .45152 .43457 .44486 .42842 Mtetra
.652 .766 .933 r
.44486 .42842 .45152 .43457 .46304 .43106 .45642 .42488 Mtetra
.657 .767 .931 r
.45642 .42488 .46304 .43106 .47462 .42741 .46804 .42118 Mtetra
.662 .768 .928 r
.46804 .42118 .47462 .42741 .48625 .42361 .4797 .41731 Mtetra
.667 .769 .926 r
.4797 .41731 .48625 .42361 .49793 .41966 .49142 .41329 Mtetra
.671 .769 .923 r
.49142 .41329 .49793 .41966 .50966 .41556 .50319 .40915 Mtetra
.671 .768 .923 r
.50319 .40915 .50966 .41556 .52144 .41137 .515 .40499 Mtetra
.654 .765 .931 r
.515 .40499 .52144 .41137 .53327 .40723 .52687 .40129 Mtetra
.57 .752 .963 r
.52687 .40129 .53327 .40723 .54515 .40374 .53879 .39942 Mtetra
.083 .547 .904 r
.53879 .39942 .54515 .40374 .55711 .40254 .55083 .40261 Mtetra
.774 .277 .029 r
.55083 .40261 .55711 .40254 .56922 .40729 .5631 .41711 Mtetra
.846 .48 .36 r
.5631 .41711 .56922 .40729 .58167 .42428 .57588 .4517 Mtetra
.82 .5 .447 r
.57588 .4517 .58167 .42428 .59475 .46098 .58941 .50718 Mtetra
.757 .457 .475 r
.58941 .50718 .59475 .46098 .60866 .51645 .60338 .55925 Mtetra
.648 .351 .454 r
.60338 .55925 .60866 .51645 .62293 .56687 .61692 .57766 Mtetra
0 0 0 r
.61692 .57766 .62293 .56687 .63654 .58221 .62952 .55828 Mtetra
.859 .648 .615 r
.62952 .55828 .63654 .58221 .64889 .55769 .64112 .51159 Mtetra
.804 .576 .593 r
.64112 .51159 .64889 .55769 .66007 .50672 .65201 .45389 Mtetra
.771 .547 .594 r
.65201 .45389 .66007 .50672 .67061 .44835 .66283 .40309 Mtetra
.744 .535 .611 r
.66283 .40309 .67061 .44835 .68125 .39969 .67408 .36818 Mtetra
.725 .545 .648 r
.67408 .36818 .68125 .39969 .69246 .36756 .68589 .34794 Mtetra
.711 .586 .714 r
.68589 .34794 .69246 .36756 .70429 .34938 .69813 .33689 Mtetra
.698 .653 .801 r
.69813 .33689 .70429 .34938 .71656 .33946 .71062 .33018 Mtetra
.684 .708 .867 r
.71062 .33018 .71656 .33946 .72908 .33325 .72325 .32508 Mtetra
.674 .734 .895 r
.72325 .32508 .72908 .33325 .74174 .32835 .73597 .32047 Mtetra
.67 .742 .904 r
.73597 .32047 .74174 .32835 .75447 .32384 .74875 .316 Mtetra
.668 .743 .906 r
.74875 .316 .75447 .32384 .76727 .31943 .76159 .31157 Mtetra
.667 .743 .907 r
.76159 .31157 .76727 .31943 .78013 .31505 .77449 .30715 Mtetra
.77449 .30715 .78013 .31505 .79305 .31068 .78745 .30274 Mtetra
.666 .742 .907 r
.78745 .30274 .79305 .31068 .80603 .30631 .80047 .29833 Mtetra
.665 .742 .907 r
.80047 .29833 .80603 .30631 .81906 .30194 .81355 .29392 Mtetra
.81355 .29392 .81906 .30194 .83216 .29756 .82668 .28951 Mtetra
.665 .742 .908 r
.82668 .28951 .83216 .29756 .84532 .29318 .83988 .28509 Mtetra
.664 .742 .908 r
.83988 .28509 .84532 .29318 .85854 .28878 .85315 .28066 Mtetra
.85315 .28066 .85854 .28878 .87181 .28437 .86647 .27621 Mtetra
.647 .743 .92 r
.25997 .47068 .26711 .4771 .27786 .47392 .27075 .46751 Mtetra
.644 .744 .922 r
.27075 .46751 .27786 .47392 .28865 .47079 .28157 .4644 Mtetra
.642 .745 .924 r
.28157 .4644 .28865 .47079 .29949 .46772 .29243 .46134 Mtetra
.639 .745 .926 r
.29243 .46134 .29949 .46772 .31038 .46469 .30333 .45834 Mtetra
.636 .746 .928 r
.30333 .45834 .31038 .46469 .3213 .46171 .31428 .45539 Mtetra
.634 .747 .93 r
.31428 .45539 .3213 .46171 .33228 .45877 .32528 .45247 Mtetra
.632 .748 .932 r
.32528 .45247 .33228 .45877 .3433 .45586 .33633 .44959 Mtetra
.63 .75 .934 r
.33633 .44959 .3433 .45586 .35437 .45297 .34743 .44673 Mtetra
.629 .751 .935 r
.34743 .44673 .35437 .45297 .36549 .45009 .35858 .44387 Mtetra
.629 .753 .936 r
.35858 .44387 .36549 .45009 .37667 .44719 .36978 .441 Mtetra
.63 .755 .937 r
.36978 .441 .37667 .44719 .3879 .44426 .38104 .43809 Mtetra
.631 .756 .938 r
.38104 .43809 .3879 .44426 .39918 .44128 .39235 .43511 Mtetra
.634 .758 .937 r
.39235 .43511 .39918 .44128 .41052 .43823 .40372 .43206 Mtetra
.638 .76 .937 r
.40372 .43206 .41052 .43823 .42191 .43508 .41514 .4289 Mtetra
.642 .762 .936 r
.41514 .4289 .42191 .43508 .43336 .43182 .42662 .42561 Mtetra
.647 .764 .934 r
.42662 .42561 .43336 .43182 .44486 .42842 .43816 .42218 Mtetra
.652 .765 .932 r
.43816 .42218 .44486 .42842 .45642 .42488 .44975 .41859 Mtetra
.658 .766 .929 r
.44975 .41859 .45642 .42488 .46804 .42118 .4614 .41483 Mtetra
.664 .767 .927 r
.4614 .41483 .46804 .42118 .4797 .41731 .4731 .4109 Mtetra
.668 .767 .924 r
.4731 .4109 .4797 .41731 .49142 .41329 .48485 .40683 Mtetra
.67 .767 .923 r
.48485 .40683 .49142 .41329 .50319 .40915 .49666 .40269 Mtetra
.659 .765 .928 r
.49666 .40269 .50319 .40915 .515 .40499 .50851 .39885 Mtetra
.599 .756 .954 r
.50851 .39885 .515 .40499 .52687 .40129 .52041 .39642 Mtetra
.26 .641 .964 r
.52041 .39642 .52687 .40129 .53879 .39942 .53238 .39823 Mtetra
.722 .191 0 r
.53238 .39823 .53879 .39942 .55083 .40261 .54451 .41045 Mtetra
.851 .477 .341 r
.54451 .41045 .55083 .40261 .5631 .41711 .55702 .44305 Mtetra
.824 .502 .445 r
.55702 .44305 .5631 .41711 .57588 .4517 .57017 .4981 Mtetra
.757 .456 .476 r
.57017 .4981 .57588 .4517 .58941 .50718 .58377 .5502 Mtetra
.653 .356 .455 r
.58377 .5502 .58941 .50718 .60338 .55925 .59717 .56983 Mtetra
0 0 0 r
.59717 .56983 .60338 .55925 .61692 .57766 .60994 .55512 Mtetra
.853 .649 .627 r
.60994 .55512 .61692 .57766 .62952 .55828 .62192 .51371 Mtetra
.804 .578 .595 r
.62192 .51371 .62952 .55828 .64112 .51159 .63319 .4581 Mtetra
.772 .547 .594 r
.63319 .4581 .64112 .51159 .65201 .45389 .64426 .40617 Mtetra
.746 .533 .607 r
.64426 .40617 .65201 .45389 .66283 .40309 .6556 .36891 Mtetra
.726 .54 .639 r
.6556 .36891 .66283 .40309 .67408 .36818 .66741 .34667 Mtetra
.713 .576 .7 r
.66741 .34667 .67408 .36818 .68589 .34794 .67962 .33444 Mtetra
.701 .64 .785 r
.67962 .33444 .68589 .34794 .69813 .33689 .69208 .32718 Mtetra
.687 .701 .858 r
.69208 .32718 .69813 .33689 .71062 .33018 .70469 .32185 Mtetra
.676 .732 .892 r
.70469 .32185 .71062 .33018 .72325 .32508 .71739 .31714 Mtetra
.672 .741 .903 r
.71739 .31714 .72325 .32508 .73597 .32047 .73015 .31259 Mtetra
.67 .743 .905 r
.73015 .31259 .73597 .32047 .74875 .316 .74297 .3081 Mtetra
.668 .743 .906 r
.74297 .3081 .74875 .316 .76159 .31157 .75586 .30363 Mtetra
.667 .743 .907 r
.75586 .30363 .76159 .31157 .77449 .30715 .7688 .29917 Mtetra
.667 .742 .907 r
.7688 .29917 .77449 .30715 .78745 .30274 .7818 .29473 Mtetra
.666 .742 .907 r
.7818 .29473 .78745 .30274 .80047 .29833 .79486 .29029 Mtetra
.665 .742 .907 r
.79486 .29029 .80047 .29833 .81355 .29392 .80798 .28584 Mtetra
.80798 .28584 .81355 .29392 .82668 .28951 .82116 .28139 Mtetra
.665 .742 .908 r
.82116 .28139 .82668 .28951 .83988 .28509 .83441 .27693 Mtetra
.664 .742 .908 r
.83441 .27693 .83988 .28509 .85315 .28066 .84771 .27246 Mtetra
.664 .741 .908 r
.84771 .27246 .85315 .28066 .86647 .27621 .86108 .26798 Mtetra
.646 .743 .92 r
.25278 .46421 .25997 .47068 .27075 .46751 .26358 .46106 Mtetra
.643 .744 .922 r
.26358 .46106 .27075 .46751 .28157 .4644 .27442 .45796 Mtetra
.64 .744 .924 r
.27442 .45796 .28157 .4644 .29243 .46134 .28531 .45492 Mtetra
.637 .745 .926 r
.28531 .45492 .29243 .46134 .30333 .45834 .29623 .45194 Mtetra
.634 .746 .929 r
.29623 .45194 .30333 .45834 .31428 .45539 .30721 .44901 Mtetra
.632 .747 .931 r
.30721 .44901 .31428 .45539 .32528 .45247 .31823 .44613 Mtetra
.63 .748 .933 r
.31823 .44613 .32528 .45247 .33633 .44959 .32931 .44327 Mtetra
.628 .749 .934 r
.32931 .44327 .33633 .44959 .34743 .44673 .34043 .44043 Mtetra
.627 .75 .936 r
.34043 .44043 .34743 .44673 .35858 .44387 .3516 .43759 Mtetra
.627 .752 .937 r
.3516 .43759 .35858 .44387 .36978 .441 .36283 .43473 Mtetra
.628 .753 .937 r
.36283 .43473 .36978 .441 .38104 .43809 .37412 .43183 Mtetra
.63 .755 .937 r
.37412 .43183 .38104 .43809 .39235 .43511 .38546 .42886 Mtetra
.633 .757 .937 r
.38546 .42886 .39235 .43511 .40372 .43206 .39686 .42579 Mtetra
.637 .759 .936 r
.39686 .42579 .40372 .43206 .41514 .4289 .40831 .42261 Mtetra
.642 .76 .934 r
.40831 .42261 .41514 .4289 .42662 .42561 .41983 .41929 Mtetra
.648 .762 .932 r
.41983 .41929 .42662 .42561 .43816 .42218 .4314 .41582 Mtetra
.653 .763 .93 r
.4314 .41582 .43816 .42218 .44975 .41859 .44303 .41218 Mtetra
.659 .764 .927 r
.44303 .41218 .44975 .41859 .4614 .41483 .45471 .40836 Mtetra
.665 .765 .925 r
.45471 .40836 .4614 .41483 .4731 .4109 .46644 .40438 Mtetra
.668 .765 .923 r
.46644 .40438 .4731 .4109 .48485 .40683 .47823 .40029 Mtetra
.661 .764 .926 r
.47823 .40029 .48485 .40683 .49666 .40269 .49007 .39637 Mtetra
.619 .758 .945 r
.49007 .39637 .49666 .40269 .50851 .39885 .50195 .3935 Mtetra
.386 .694 .981 r
.50195 .3935 .50851 .39885 .52041 .39642 .51388 .39413 Mtetra
.639 .08 0 r
.51388 .39413 .52041 .39642 .53238 .39823 .52589 .40439 Mtetra
.856 .474 .322 r
.52589 .40439 .53238 .39823 .54451 .41045 .53816 .43538 Mtetra
.826 .504 .443 r
.53816 .43538 .54451 .41045 .55702 .44305 .55092 .48983 Mtetra
.752 .452 .476 r
.55092 .48983 .55702 .44305 .57017 .4981 .56414 .54042 Mtetra
.65 .351 .452 r
.56414 .54042 .57017 .4981 .58377 .5502 .57735 .55919 Mtetra
0 0 0 r
.57735 .55919 .58377 .5502 .59717 .56983 .59021 .54826 Mtetra
.841 .647 .641 r
.59021 .54826 .59717 .56983 .60994 .55512 .60251 .51277 Mtetra
.802 .579 .6 r
.60251 .51277 .60994 .55512 .62192 .51371 .61417 .46058 Mtetra
.773 .548 .594 r
.61417 .46058 .62192 .51371 .63319 .4581 .62551 .40864 Mtetra
.747 .532 .604 r
.62551 .40864 .63319 .4581 .64426 .40617 .63699 .36961 Mtetra
.727 .536 .633 r
.63699 .36961 .64426 .40617 .6556 .36891 .64883 .34554 Mtetra
.714 .567 .688 r
.64883 .34554 .6556 .36891 .66741 .34667 .66103 .33213 Mtetra
.703 .629 .771 r
.66103 .33213 .66741 .34667 .67962 .33444 .67348 .32427 Mtetra
.69 .693 .848 r
.67348 .32427 .67962 .33444 .69208 .32718 .68607 .31868 Mtetra
.679 .729 .887 r
.68607 .31868 .69208 .32718 .70469 .32185 .69874 .31383 Mtetra
.674 .741 .901 r
.69874 .31383 .70469 .32185 .71739 .31714 .71149 .30921 Mtetra
.671 .743 .905 r
.71149 .30921 .71739 .31714 .73015 .31259 .72429 .30465 Mtetra
.67 .743 .906 r
.72429 .30465 .73015 .31259 .74297 .3081 .73715 .30012 Mtetra
.668 .743 .906 r
.73715 .30012 .74297 .3081 .75586 .30363 .75008 .29562 Mtetra
.667 .743 .907 r
.75008 .29562 .75586 .30363 .7688 .29917 .76306 .29113 Mtetra
.667 .742 .907 r
.76306 .29113 .7688 .29917 .7818 .29473 .7761 .28665 Mtetra
.666 .742 .907 r
.7761 .28665 .7818 .29473 .79486 .29029 .7892 .28217 Mtetra
.665 .742 .907 r
.7892 .28217 .79486 .29029 .80798 .28584 .80237 .27769 Mtetra
.80237 .27769 .80798 .28584 .82116 .28139 .81559 .2732 Mtetra
.665 .742 .908 r
.81559 .2732 .82116 .28139 .83441 .27693 .82888 .26871 Mtetra
.664 .742 .908 r
.82888 .26871 .83441 .27693 .84771 .27246 .84223 .2642 Mtetra
.664 .741 .908 r
.84223 .2642 .84771 .27246 .86108 .26798 .85564 .25968 Mtetra
.644 .743 .921 r
.24553 .45769 .25278 .46421 .26358 .46106 .25636 .45455 Mtetra
.641 .743 .923 r
.25636 .45455 .26358 .46106 .27442 .45796 .26722 .45147 Mtetra
.638 .744 .925 r
.26722 .45147 .27442 .45796 .28531 .45492 .27813 .44845 Mtetra
.635 .744 .927 r
.27813 .44845 .28531 .45492 .29623 .45194 .28908 .44549 Mtetra
.632 .745 .929 r
.28908 .44549 .29623 .45194 .30721 .44901 .30008 .44258 Mtetra
.63 .746 .931 r
.30008 .44258 .30721 .44901 .31823 .44613 .31113 .43971 Mtetra
.628 .747 .933 r
.31113 .43971 .31823 .44613 .32931 .44327 .32222 .43688 Mtetra
.626 .748 .934 r
.32222 .43688 .32931 .44327 .34043 .44043 .33337 .43406 Mtetra
.626 .749 .936 r
.33337 .43406 .34043 .44043 .3516 .43759 .34457 .43123 Mtetra
.626 .75 .936 r
.34457 .43123 .3516 .43759 .36283 .43473 .35583 .42838 Mtetra
.627 .752 .937 r
.35583 .42838 .36283 .43473 .37412 .43183 .36714 .42547 Mtetra
.63 .754 .936 r
.36714 .42547 .37412 .43183 .38546 .42886 .37852 .42249 Mtetra
.633 .755 .936 r
.37852 .42249 .38546 .42886 .39686 .42579 .38994 .41941 Mtetra
.638 .757 .934 r
.38994 .41941 .39686 .42579 .40831 .42261 .40143 .4162 Mtetra
.643 .758 .933 r
.40143 .4162 .40831 .42261 .41983 .41929 .41298 .41285 Mtetra
.649 .76 .93 r
.41298 .41285 .41983 .41929 .4314 .41582 .42458 .40932 Mtetra
.655 .761 .928 r
.42458 .40932 .4314 .41582 .44303 .41218 .43624 .40563 Mtetra
.66 .762 .925 r
.43624 .40563 .44303 .41218 .45471 .40836 .44796 .40175 Mtetra
.665 .762 .923 r
.44796 .40175 .45471 .40836 .46644 .40438 .45973 .39774 Mtetra
.662 .762 .924 r
.45973 .39774 .46644 .40438 .47823 .40029 .47155 .3938 Mtetra
.633 .758 .938 r
.47155 .3938 .47823 .40029 .49007 .39637 .48342 .3906 Mtetra
.468 .719 .979 r
.48342 .3906 .49007 .39637 .50195 .3935 .49531 .39029 Mtetra
.529 0 0 r
.49531 .39029 .50195 .3935 .51388 .39413 .50723 .399 Mtetra
.86 .472 .307 r
.50723 .399 .51388 .39413 .52589 .40439 .51927 .42899 Mtetra
.826 .504 .443 r
.51927 .42899 .52589 .40439 .53816 .43538 .53166 .48294 Mtetra
.743 .444 .476 r
.53166 .48294 .53816 .43538 .55092 .48983 .54451 .53058 Mtetra
.636 .336 .445 r
.54451 .53058 .55092 .48983 .56414 .54042 .55751 .54634 Mtetra
0 0 0 r
.55751 .54634 .56414 .54042 .57735 .55919 .57039 .53799 Mtetra
.82 .639 .658 r
.57039 .53799 .57735 .55919 .59021 .54826 .58294 .50866 Mtetra
.8 .581 .606 r
.58294 .50866 .59021 .54826 .60251 .51277 .59495 .46102 Mtetra
.773 .55 .596 r
.59495 .46102 .60251 .51277 .61417 .46058 .60661 .41023 Mtetra
.748 .532 .603 r
.60661 .41023 .61417 .46058 .62551 .40864 .61826 .37013 Mtetra
.728 .533 .628 r
.61826 .37013 .62551 .40864 .63699 .36961 .63017 .34449 Mtetra
.714 .56 .678 r
.63017 .34449 .63699 .36961 .64883 .34554 .64237 .32991 Mtetra
.705 .618 .757 r
.64237 .32991 .64883 .34554 .66103 .33213 .6548 .32144 Mtetra
.693 .684 .837 r
.6548 .32144 .66103 .33213 .67348 .32427 .66737 .31556 Mtetra
.682 .725 .883 r
.66737 .31556 .67348 .32427 .68607 .31868 .68002 .31057 Mtetra
.676 .74 .899 r
.68002 .31057 .68607 .31868 .69874 .31383 .69275 .30586 Mtetra
.673 .743 .904 r
.69275 .30586 .69874 .31383 .71149 .30921 .70553 .30123 Mtetra
.671 .744 .905 r
.70553 .30123 .71149 .30921 .72429 .30465 .71838 .29664 Mtetra
.67 .743 .906 r
.71838 .29664 .72429 .30465 .73715 .30012 .73128 .29208 Mtetra
.668 .743 .906 r
.73128 .29208 .73715 .30012 .75008 .29562 .74425 .28754 Mtetra
.667 .743 .906 r
.74425 .28754 .75008 .29562 .76306 .29113 .75727 .28302 Mtetra
.666 .742 .907 r
.75727 .28302 .76306 .29113 .7761 .28665 .77035 .2785 Mtetra
.77035 .2785 .7761 .28665 .7892 .28217 .7835 .27398 Mtetra
.665 .742 .907 r
.7835 .27398 .7892 .28217 .80237 .27769 .79671 .26947 Mtetra
.79671 .26947 .80237 .27769 .81559 .2732 .80998 .26494 Mtetra
.664 .742 .908 r
.80998 .26494 .81559 .2732 .82888 .26871 .82331 .26041 Mtetra
.82331 .26041 .82888 .26871 .84223 .2642 .8367 .25587 Mtetra
.664 .741 .908 r
.8367 .25587 .84223 .2642 .85564 .25968 .85015 .25131 Mtetra
.643 .742 .921 r
.23823 .45112 .24553 .45769 .25636 .45455 .24908 .44798 Mtetra
.64 .743 .923 r
.24908 .44798 .25636 .45455 .26722 .45147 .25996 .44492 Mtetra
.637 .743 .925 r
.25996 .44492 .26722 .45147 .27813 .44845 .27089 .44191 Mtetra
.633 .743 .927 r
.27089 .44191 .27813 .44845 .28908 .44549 .28187 .43897 Mtetra
.631 .744 .929 r
.28187 .43897 .28908 .44549 .30008 .44258 .29289 .43607 Mtetra
.628 .745 .931 r
.29289 .43607 .30008 .44258 .31113 .43971 .30396 .43322 Mtetra
.626 .745 .933 r
.30396 .43322 .31113 .43971 .32222 .43688 .31509 .4304 Mtetra
.625 .746 .934 r
.31509 .4304 .32222 .43688 .33337 .43406 .32626 .42759 Mtetra
.624 .747 .935 r
.32626 .42759 .33337 .43406 .34457 .43123 .33749 .42477 Mtetra
.625 .749 .936 r
.33749 .42477 .34457 .43123 .35583 .42838 .34877 .42192 Mtetra
.627 .75 .936 r
.34877 .42192 .35583 .42838 .36714 .42547 .36012 .41901 Mtetra
.63 .752 .935 r
.36012 .41901 .36714 .42547 .37852 .42249 .37152 .41601 Mtetra
.633 .753 .934 r
.37152 .41601 .37852 .42249 .38994 .41941 .38298 .4129 Mtetra
.638 .755 .933 r
.38298 .4129 .38994 .41941 .40143 .4162 .3945 .40966 Mtetra
.644 .756 .931 r
.3945 .40966 .40143 .4162 .41298 .41285 .40608 .40626 Mtetra
.65 .757 .928 r
.40608 .40626 .41298 .41285 .42458 .40932 .41771 .40268 Mtetra
.656 .758 .925 r
.41771 .40268 .42458 .40932 .43624 .40563 .42941 .39893 Mtetra
.661 .759 .923 r
.42941 .39893 .43624 .40563 .44796 .40175 .44116 .39502 Mtetra
.44116 .39502 .44796 .40175 .45973 .39774 .45296 .39109 Mtetra
.641 .756 .932 r
.45296 .39109 .45973 .39774 .47155 .3938 .46481 .38767 Mtetra
.521 .731 .97 r
.46481 .38767 .47155 .3938 .48342 .3906 .47668 .38665 Mtetra
.415 0 0 r
.47668 .38665 .48342 .3906 .49531 .39029 .48852 .3943 Mtetra
.864 .474 .3 r
.48852 .3943 .49531 .39029 .50723 .399 .50033 .42407 Mtetra
.824 .502 .445 r
.50033 .42407 .50723 .399 .51927 .42899 .51236 .47785 Mtetra
.729 .432 .476 r
.51236 .47785 .51927 .42899 .53166 .48294 .52489 .52129 Mtetra
.607 .305 .431 r
.52489 .52129 .53166 .48294 .54451 .53058 .53771 .53195 Mtetra
.562 .936 .841 r
.53771 .53195 .54451 .53058 .55751 .54634 .55056 .52479 Mtetra
.79 .623 .673 r
.55056 .52479 .55751 .54634 .57039 .53799 .56326 .50146 Mtetra
.795 .583 .614 r
.56326 .50146 .57039 .53799 .58294 .50866 .57558 .45921 Mtetra
.774 .552 .598 r
.57558 .45921 .58294 .50866 .59495 .46102 .58754 .41067 Mtetra
.749 .533 .603 r
.58754 .41067 .59495 .46102 .60661 .41023 .5994 .37028 Mtetra
.729 .531 .624 r
.5994 .37028 .60661 .41023 .61826 .37013 .6114 .34342 Mtetra
.715 .555 .67 r
.6114 .34342 .61826 .37013 .63017 .34449 .62362 .32778 Mtetra
.706 .609 .745 r
.62362 .32778 .63017 .34449 .64237 .32991 .63604 .31868 Mtetra
.696 .676 .827 r
.63604 .31868 .64237 .32991 .6548 .32144 .64859 .3125 Mtetra
.684 .721 .877 r
.64859 .3125 .6548 .32144 .66737 .31556 .66123 .30736 Mtetra
.678 .739 .897 r
.66123 .30736 .66737 .31556 .68002 .31057 .67394 .30254 Mtetra
.674 .743 .902 r
.67394 .30254 .68002 .31057 .69275 .30586 .68671 .29783 Mtetra
.672 .744 .904 r
.68671 .29783 .69275 .30586 .70553 .30123 .69953 .29318 Mtetra
.671 .743 .905 r
.69953 .29318 .70553 .30123 .71838 .29664 .71242 .28856 Mtetra
.669 .743 .906 r
.71242 .28856 .71838 .29664 .73128 .29208 .72536 .28396 Mtetra
.668 .743 .906 r
.72536 .28396 .73128 .29208 .74425 .28754 .73837 .27939 Mtetra
.667 .742 .906 r
.73837 .27939 .74425 .28754 .75727 .28302 .75143 .27483 Mtetra
.666 .742 .907 r
.75143 .27483 .75727 .28302 .77035 .2785 .76456 .27028 Mtetra
.76456 .27028 .77035 .2785 .7835 .27398 .77775 .26573 Mtetra
.665 .742 .907 r
.77775 .26573 .7835 .27398 .79671 .26947 .791 .26117 Mtetra
.791 .26117 .79671 .26947 .80998 .26494 .80431 .25661 Mtetra
.664 .742 .908 r
.80431 .25661 .80998 .26494 .82331 .26041 .81769 .25204 Mtetra
.664 .741 .908 r
.81769 .25204 .82331 .26041 .8367 .25587 .83112 .24746 Mtetra
.83112 .24746 .8367 .25587 .85015 .25131 .84462 .24286 Mtetra
.642 .742 .922 r
.23087 .44449 .23823 .45112 .24908 .44798 .24174 .44136 Mtetra
.638 .742 .924 r
.24174 .44136 .24908 .44798 .25996 .44492 .25265 .4383 Mtetra
.635 .742 .926 r
.25265 .4383 .25996 .44492 .27089 .44191 .2636 .43531 Mtetra
.632 .743 .928 r
.2636 .43531 .27089 .44191 .28187 .43897 .2746 .43237 Mtetra
.629 .743 .929 r
.2746 .43237 .28187 .43897 .29289 .43607 .28565 .42949 Mtetra
.627 .743 .931 r
.28565 .42949 .29289 .43607 .30396 .43322 .29675 .42665 Mtetra
.625 .744 .933 r
.29675 .42665 .30396 .43322 .31509 .4304 .30789 .42383 Mtetra
.624 .745 .934 r
.30789 .42383 .31509 .4304 .32626 .42759 .3191 .42103 Mtetra
.624 .746 .934 r
.3191 .42103 .32626 .42759 .33749 .42477 .33035 .4182 Mtetra
.625 .747 .935 r
.33035 .4182 .33749 .42477 .34877 .42192 .34166 .41534 Mtetra
.627 .748 .934 r
.34166 .41534 .34877 .42192 .36012 .41901 .35303 .41241 Mtetra
.63 .749 .934 r
.35303 .41241 .36012 .41901 .37152 .41601 .36446 .40939 Mtetra
.634 .751 .932 r
.36446 .40939 .37152 .41601 .38298 .4129 .37596 .40625 Mtetra
.639 .752 .93 r
.37596 .40625 .38298 .4129 .3945 .40966 .38751 .40296 Mtetra
.645 .753 .928 r
.38751 .40296 .3945 .40966 .40608 .40626 .39912 .39951 Mtetra
.651 .754 .925 r
.39912 .39951 .40608 .40626 .41771 .40268 .41079 .39588 Mtetra
.656 .755 .923 r
.41079 .39588 .41771 .40268 .42941 .39893 .42252 .39208 Mtetra
.659 .756 .922 r
.42252 .39208 .42941 .39893 .44116 .39502 .4343 .3882 Mtetra
.646 .754 .928 r
.4343 .3882 .44116 .39502 .45296 .39109 .44613 .38466 Mtetra
.552 .734 .96 r
.44613 .38466 .45296 .39109 .46481 .38767 .45797 .38314 Mtetra
0 .215 .638 r
.45797 .38314 .46481 .38767 .47668 .38665 .46973 .39027 Mtetra
.869 .481 .302 r
.46973 .39027 .47668 .38665 .48852 .3943 .48132 .42075 Mtetra
.819 .5 .449 r
.48132 .42075 .48852 .3943 .50033 .42407 .49299 .47485 Mtetra
.709 .414 .475 r
.49299 .47485 .50033 .42407 .51236 .47785 .50525 .51301 Mtetra
.554 .25 .406 r
.50525 .51301 .51236 .47785 .52489 .52129 .51795 .51668 Mtetra
.755 .865 .929 r
.51795 .51668 .52489 .52129 .53771 .53195 .53076 .50925 Mtetra
.75 .596 .685 r
.53076 .50925 .53771 .53195 .55056 .52479 .54354 .49142 Mtetra
.789 .585 .625 r
.54354 .49142 .55056 .52479 .56326 .50146 .5561 .45509 Mtetra
.774 .555 .603 r
.5561 .45509 .56326 .50146 .57558 .45921 .56834 .40976 Mtetra
.75 .535 .604 r
.56834 .40976 .57558 .45921 .58754 .41067 .58041 .36989 Mtetra
.73 .531 .622 r
.58041 .36989 .58754 .41067 .5994 .37028 .59252 .34225 Mtetra
.716 .551 .664 r
.59252 .34225 .5994 .37028 .6114 .34342 .60478 .3257 Mtetra
.708 .601 .735 r
.60478 .3257 .6114 .34342 .62362 .32778 .6172 .31599 Mtetra
.698 .668 .817 r
.6172 .31599 .62362 .32778 .63604 .31868 .62974 .30949 Mtetra
.687 .717 .872 r
.62974 .30949 .63604 .31868 .64859 .3125 .64236 .30418 Mtetra
.68 .737 .894 r
.64236 .30418 .64859 .3125 .66123 .30736 .65505 .29926 Mtetra
.676 .743 .901 r
.65505 .29926 .66123 .30736 .67394 .30254 .6678 .29447 Mtetra
.674 .744 .903 r
.6678 .29447 .67394 .30254 .68671 .29783 .68061 .28974 Mtetra
.672 .744 .904 r
.68061 .28974 .68671 .29783 .69953 .29318 .69348 .28505 Mtetra
.671 .743 .905 r
.69348 .28505 .69953 .29318 .71242 .28856 .70641 .2804 Mtetra
.669 .743 .905 r
.70641 .2804 .71242 .28856 .72536 .28396 .71939 .27577 Mtetra
.668 .743 .906 r
.71939 .27577 .72536 .28396 .73837 .27939 .73244 .27117 Mtetra
.667 .742 .906 r
.73244 .27117 .73837 .27939 .75143 .27483 .74555 .26657 Mtetra
.666 .742 .907 r
.74555 .26657 .75143 .27483 .76456 .27028 .75872 .26199 Mtetra
.75872 .26199 .76456 .27028 .77775 .26573 .77195 .2574 Mtetra
.665 .742 .907 r
.77195 .2574 .77775 .26573 .791 .26117 .78524 .25281 Mtetra
.78524 .25281 .791 .26117 .80431 .25661 .7986 .24821 Mtetra
.664 .742 .908 r
.7986 .24821 .80431 .25661 .81769 .25204 .81202 .2436 Mtetra
.664 .741 .908 r
.81202 .2436 .81769 .25204 .83112 .24746 .8255 .23898 Mtetra
.8255 .23898 .83112 .24746 .84462 .24286 .83904 .23435 Mtetra
.64 .741 .922 r
.22345 .43779 .23087 .44449 .24174 .44136 .23434 .43467 Mtetra
.637 .741 .924 r
.23434 .43467 .24174 .44136 .25265 .4383 .24528 .43162 Mtetra
.634 .741 .926 r
.24528 .43162 .25265 .4383 .2636 .43531 .25626 .42862 Mtetra
.631 .741 .928 r
.25626 .42862 .2636 .43531 .2746 .43237 .26728 .42569 Mtetra
.628 .742 .929 r
.26728 .42569 .2746 .43237 .28565 .42949 .27835 .42282 Mtetra
.626 .742 .931 r
.27835 .42282 .28565 .42949 .29675 .42665 .28947 .41998 Mtetra
.624 .742 .932 r
.28947 .41998 .29675 .42665 .30789 .42383 .30065 .41716 Mtetra
.623 .743 .933 r
.30065 .41716 .30789 .42383 .3191 .42103 .31187 .41435 Mtetra
.623 .744 .933 r
.31187 .41435 .3191 .42103 .33035 .4182 .32316 .41151 Mtetra
.625 .745 .933 r
.32316 .41151 .33035 .4182 .34166 .41534 .3345 .40863 Mtetra
.627 .746 .933 r
.3345 .40863 .34166 .41534 .35303 .41241 .3459 .40568 Mtetra
.63 .747 .931 r
.3459 .40568 .35303 .41241 .36446 .40939 .35736 .40262 Mtetra
.635 .748 .93 r
.35736 .40262 .36446 .40939 .37596 .40625 .36888 .39944 Mtetra
.64 .749 .928 r
.36888 .39944 .37596 .40625 .38751 .40296 .38046 .3961 Mtetra
.646 .75 .925 r
.38046 .3961 .38751 .40296 .39912 .39951 .39211 .39259 Mtetra
.652 .751 .922 r
.39211 .39259 .39912 .39951 .41079 .39588 .40381 .38891 Mtetra
.655 .752 .921 r
.40381 .38891 .41079 .39588 .42252 .39208 .41557 .38512 Mtetra
.648 .75 .924 r
.41557 .38512 .42252 .39208 .4343 .3882 .42738 .38152 Mtetra
.569 .733 .952 r
.42738 .38152 .4343 .3882 .44613 .38466 .4392 .37972 Mtetra
0 .226 .662 r
.4392 .37972 .44613 .38466 .45797 .38314 .45087 .38687 Mtetra
.873 .491 .314 r
.45087 .38687 .45797 .38314 .46973 .39027 .4622 .41905 Mtetra
.813 .497 .455 r
.4622 .41905 .46973 .39027 .48132 .42075 .4735 .47407 Mtetra
.684 .393 .474 r
.4735 .47407 .48132 .42075 .49299 .47485 .48557 .50605 Mtetra
.449 .145 .355 r
.48557 .50605 .49299 .47485 .50525 .51301 .49827 .50114 Mtetra
.739 .686 .8 r
.49827 .50114 .50525 .51301 .51795 .51668 .51103 .49208 Mtetra
.705 .561 .689 r
.51103 .49208 .51795 .51668 .53076 .50925 .52382 .47898 Mtetra
.779 .585 .638 r
.52382 .47898 .53076 .50925 .54354 .49142 .53654 .44872 Mtetra
.773 .559 .609 r
.53654 .44872 .54354 .49142 .5561 .45509 .54903 .40739 Mtetra
.75 .537 .606 r
.54903 .40739 .5561 .45509 .56834 .40976 .56131 .36883 Mtetra
.731 .531 .622 r
.56131 .36883 .56834 .40976 .58041 .36989 .57355 .34088 Mtetra
.717 .548 .66 r
.57355 .34088 .58041 .36989 .59252 .34225 .58586 .3236 Mtetra
.709 .594 .726 r
.58586 .3236 .59252 .34225 .60478 .3257 .59828 .31334 Mtetra
.7 .66 .807 r
.59828 .31334 .60478 .3257 .6172 .31599 .61081 .30652 Mtetra
.69 .712 .865 r
.61081 .30652 .6172 .31599 .62974 .30949 .62342 .30104 Mtetra
.682 .736 .891 r
.62342 .30104 .62974 .30949 .64236 .30418 .63609 .29601 Mtetra
.678 .743 .899 r
.63609 .29601 .64236 .30418 .65505 .29926 .64883 .29113 Mtetra
.676 .744 .902 r
.64883 .29113 .65505 .29926 .6678 .29447 .66162 .28633 Mtetra
.674 .744 .903 r
.66162 .28633 .6678 .29447 .68061 .28974 .67447 .28157 Mtetra
.672 .743 .904 r
.67447 .28157 .68061 .28974 .69348 .28505 .68738 .27685 Mtetra
.67 .743 .905 r
.68738 .27685 .69348 .28505 .70641 .2804 .70034 .27217 Mtetra
.669 .743 .905 r
.70034 .27217 .70641 .2804 .71939 .27577 .71337 .26751 Mtetra
.668 .742 .906 r
.71337 .26751 .71939 .27577 .73244 .27117 .72646 .26287 Mtetra
.667 .742 .906 r
.72646 .26287 .73244 .27117 .74555 .26657 .73961 .25824 Mtetra
.666 .742 .907 r
.73961 .25824 .74555 .26657 .75872 .26199 .75282 .25362 Mtetra
.75282 .25362 .75872 .26199 .77195 .2574 .7661 .249 Mtetra
.665 .742 .907 r
.7661 .249 .77195 .2574 .78524 .25281 .77944 .24437 Mtetra
.77944 .24437 .78524 .25281 .7986 .24821 .79284 .23974 Mtetra
.664 .741 .908 r
.79284 .23974 .7986 .24821 .81202 .2436 .8063 .23509 Mtetra
.8063 .23509 .81202 .2436 .8255 .23898 .81983 .23043 Mtetra
.81983 .23043 .8255 .23898 .83904 .23435 .83342 .22576 Mtetra
.639 .741 .922 r
.21598 .43103 .22345 .43779 .23434 .43467 .22689 .42791 Mtetra
.636 .74 .924 r
.22689 .42791 .23434 .43467 .24528 .43162 .23785 .42485 Mtetra
.633 .74 .926 r
.23785 .42485 .24528 .43162 .25626 .42862 .24885 .42186 Mtetra
.63 .74 .927 r
.24885 .42186 .25626 .42862 .26728 .42569 .2599 .41893 Mtetra
.627 .74 .929 r
.2599 .41893 .26728 .42569 .27835 .42282 .271 .41605 Mtetra
.625 .74 .93 r
.271 .41605 .27835 .42282 .28947 .41998 .28214 .4132 Mtetra
.623 .741 .931 r
.28214 .4132 .28947 .41998 .30065 .41716 .29334 .41038 Mtetra
.623 .741 .932 r
.29334 .41038 .30065 .41716 .31187 .41435 .3046 .40755 Mtetra
.623 .742 .932 r
.3046 .40755 .31187 .41435 .32316 .41151 .31591 .40469 Mtetra
.625 .742 .931 r
.31591 .40469 .32316 .41151 .3345 .40863 .32728 .40178 Mtetra
.628 .743 .93 r
.32728 .40178 .3345 .40863 .3459 .40568 .33871 .39879 Mtetra
.631 .744 .929 r
.33871 .39879 .3459 .40568 .35736 .40262 .3502 .39569 Mtetra
.636 .745 .927 r
.3502 .39569 .35736 .40262 .36888 .39944 .36175 .39245 Mtetra
.642 .746 .925 r
.36175 .39245 .36888 .39944 .38046 .3961 .37337 .38906 Mtetra
.647 .747 .922 r
.37337 .38906 .38046 .3961 .39211 .39259 .38504 .3855 Mtetra
.652 .748 .92 r
.38504 .3855 .39211 .39259 .40381 .38891 .39678 .3818 Mtetra
.647 .747 .922 r
.39678 .3818 .40381 .38891 .41557 .38512 .40857 .37821 Mtetra
.575 .729 .947 r
.40857 .37821 .41557 .38512 .42738 .38152 .42035 .37631 Mtetra
0 .185 .631 r
.42035 .37631 .42738 .38152 .4392 .37972 .43193 .38403 Mtetra
.877 .504 .334 r
.43193 .38403 .4392 .37972 .45087 .38687 .44295 .41893 Mtetra
.806 .494 .462 r
.44295 .41893 .45087 .38687 .4622 .41905 .45386 .47546 Mtetra
.654 .366 .471 r
.45386 .47546 .4622 .41905 .4735 .47407 .46584 .50052 Mtetra
.217 0 .235 r
.46584 .50052 .4735 .47407 .48557 .50605 .47865 .48582 Mtetra
.716 .59 .714 r
.47865 .48582 .48557 .50605 .49827 .50114 .4914 .47394 Mtetra
.661 .523 .685 r
.4914 .47394 .49827 .50114 .51103 .49208 .50414 .46464 Mtetra
.765 .585 .654 r
.50414 .46464 .51103 .49208 .52382 .47898 .51694 .44029 Mtetra
.771 .563 .618 r
.51694 .44029 .52382 .47898 .53654 .44872 .52962 .40351 Mtetra
.75 .54 .61 r
.52962 .40351 .53654 .44872 .54903 .40739 .5421 .36697 Mtetra
.731 .533 .623 r
.5421 .36697 .54903 .40739 .56131 .36883 .55447 .33922 Mtetra
.718 .547 .657 r
.55447 .33922 .56131 .36883 .57355 .34088 .56684 .32146 Mtetra
.709 .589 .719 r
.56684 .32146 .57355 .34088 .58586 .3236 .57928 .3107 Mtetra
.702 .653 .798 r
.57928 .3107 .58586 .3236 .59828 .31334 .5918 .30358 Mtetra
.692 .707 .859 r
.5918 .30358 .59828 .31334 .61081 .30652 .6044 .29793 Mtetra
.684 .734 .888 r
.6044 .29793 .61081 .30652 .62342 .30104 .61706 .29279 Mtetra
.68 .742 .897 r
.61706 .29279 .62342 .30104 .63609 .29601 .62977 .28782 Mtetra
.678 .744 .901 r
.62977 .28782 .63609 .29601 .64883 .29113 .64255 .28293 Mtetra
.675 .744 .902 r
.64255 .28293 .64883 .29113 .66162 .28633 .65538 .2781 Mtetra
.673 .743 .903 r
.65538 .2781 .66162 .28633 .67447 .28157 .66827 .27332 Mtetra
.672 .743 .904 r
.66827 .27332 .67447 .28157 .68738 .27685 .68122 .26857 Mtetra
.67 .743 .905 r
.68122 .26857 .68738 .27685 .70034 .27217 .69423 .26386 Mtetra
.669 .742 .905 r
.69423 .26386 .70034 .27217 .71337 .26751 .7073 .25917 Mtetra
.668 .742 .906 r
.7073 .25917 .71337 .26751 .72646 .26287 .72043 .2545 Mtetra
.667 .742 .906 r
.72043 .2545 .72646 .26287 .73961 .25824 .73362 .24984 Mtetra
.666 .742 .907 r
.73362 .24984 .73961 .25824 .75282 .25362 .74688 .24518 Mtetra
.665 .742 .907 r
.74688 .24518 .75282 .25362 .7661 .249 .7602 .24052 Mtetra
.7602 .24052 .7661 .249 .77944 .24437 .77358 .23586 Mtetra
.77358 .23586 .77944 .24437 .79284 .23974 .78702 .23119 Mtetra
.664 .741 .908 r
.78702 .23119 .79284 .23974 .8063 .23509 .80053 .2265 Mtetra
.80053 .2265 .8063 .23509 .81983 .23043 .8141 .22181 Mtetra
.8141 .22181 .81983 .23043 .83342 .22576 .82774 .21709 Mtetra
.639 .74 .922 r
.20845 .4242 .21598 .43103 .22689 .42791 .21939 .42107 Mtetra
.635 .74 .924 r
.21939 .42107 .22689 .42791 .23785 .42485 .23037 .41801 Mtetra
.632 .739 .925 r
.23037 .41801 .23785 .42485 .24885 .42186 .24139 .41501 Mtetra
.629 .739 .927 r
.24139 .41501 .24885 .42186 .2599 .41893 .25247 .41207 Mtetra
.627 .739 .928 r
.25247 .41207 .2599 .41893 .271 .41605 .26359 .40917 Mtetra
.625 .739 .929 r
.26359 .40917 .271 .41605 .28214 .4132 .27476 .40631 Mtetra
.623 .739 .93 r
.27476 .40631 .28214 .4132 .29334 .41038 .28599 .40347 Mtetra
.28599 .40347 .29334 .41038 .3046 .40755 .29727 .40061 Mtetra
.624 .739 .93 r
.29727 .40061 .3046 .40755 .31591 .40469 .30861 .39772 Mtetra
.626 .74 .929 r
.30861 .39772 .31591 .40469 .32728 .40178 .32 .39477 Mtetra
.629 .74 .928 r
.32 .39477 .32728 .40178 .33871 .39879 .33146 .39174 Mtetra
.633 .741 .926 r
.33146 .39174 .33871 .39879 .3502 .39569 .34299 .38859 Mtetra
.637 .742 .924 r
.34299 .38859 .3502 .39569 .36175 .39245 .35457 .38529 Mtetra
.643 .743 .922 r
.35457 .38529 .36175 .39245 .37337 .38906 .36622 .38184 Mtetra
.648 .743 .919 r
.36622 .38184 .37337 .38906 .38504 .3855 .37793 .37824 Mtetra
.645 .743 .92 r
.37793 .37824 .38504 .3855 .39678 .3818 .38969 .3747 Mtetra
.572 .723 .945 r
.38969 .3747 .39678 .3818 .40857 .37821 .40144 .37287 Mtetra
.442 0 0 r
.40144 .37287 .40857 .37821 .42035 .37631 .41288 .38168 Mtetra
.879 .517 .357 r
.41288 .38168 .42035 .37631 .43193 .38403 .42355 .42025 Mtetra
.797 .49 .469 r
.42355 .42025 .43193 .38403 .44295 .41893 .43403 .47882 Mtetra
.618 .335 .467 r
.43403 .47882 .44295 .41893 .45386 .47546 .44601 .49638 Mtetra
0 0 0 r
.44601 .49638 .45386 .47546 .46584 .50052 .45908 .47108 Mtetra
.704 .541 .665 r
.45908 .47108 .46584 .50052 .47865 .48582 .47188 .4555 Mtetra
.625 .488 .675 r
.47188 .4555 .47865 .48582 .4914 .47394 .48454 .449 Mtetra
.746 .583 .673 r
.48454 .449 .4914 .47394 .50414 .46464 .49734 .43011 Mtetra
.769 .569 .628 r
.49734 .43011 .50414 .46464 .51694 .44029 .51015 .39815 Mtetra
.75 .544 .616 r
.51015 .39815 .51694 .44029 .52962 .40351 .5228 .36424 Mtetra
.732 .535 .625 r
.5228 .36424 .52962 .40351 .5421 .36697 .53529 .33718 Mtetra
.718 .547 .657 r
.53529 .33718 .5421 .36697 .55447 .33922 .54773 .3192 Mtetra
.71 .586 .714 r
.54773 .3192 .55447 .33922 .56684 .32146 .56019 .30806 Mtetra
.703 .647 .791 r
.56019 .30806 .56684 .32146 .57928 .3107 .57271 .30066 Mtetra
.694 .703 .854 r
.57271 .30066 .57928 .3107 .5918 .30358 .5853 .29485 Mtetra
.686 .731 .884 r
.5853 .29485 .5918 .30358 .6044 .29793 .59794 .28959 Mtetra
.682 .741 .895 r
.59794 .28959 .6044 .29793 .61706 .29279 .61064 .28453 Mtetra
.679 .743 .899 r
.61064 .28453 .61706 .29279 .62977 .28782 .6234 .27956 Mtetra
.677 .743 .901 r
.6234 .27956 .62977 .28782 .64255 .28293 .63622 .27466 Mtetra
.675 .743 .902 r
.63622 .27466 .64255 .28293 .65538 .2781 .64909 .2698 Mtetra
.673 .743 .903 r
.64909 .2698 .65538 .2781 .66827 .27332 .66202 .26499 Mtetra
.671 .743 .904 r
.66202 .26499 .66827 .27332 .68122 .26857 .67501 .26022 Mtetra
.67 .742 .905 r
.67501 .26022 .68122 .26857 .69423 .26386 .68806 .25548 Mtetra
.669 .742 .905 r
.68806 .25548 .69423 .26386 .7073 .25917 .70117 .25076 Mtetra
.668 .742 .906 r
.70117 .25076 .7073 .25917 .72043 .2545 .71435 .24606 Mtetra
.667 .742 .906 r
.71435 .24606 .72043 .2545 .73362 .24984 .72758 .24136 Mtetra
.666 .742 .907 r
.72758 .24136 .73362 .24984 .74688 .24518 .74088 .23667 Mtetra
.665 .742 .907 r
.74088 .23667 .74688 .24518 .7602 .24052 .75425 .23198 Mtetra
.75425 .23198 .7602 .24052 .77358 .23586 .76767 .22728 Mtetra
.665 .741 .907 r
.76767 .22728 .77358 .23586 .78702 .23119 .78116 .22257 Mtetra
.664 .741 .908 r
.78116 .22257 .78702 .23119 .80053 .2265 .79471 .21784 Mtetra
.79471 .21784 .80053 .2265 .8141 .22181 .80833 .2131 Mtetra
.80833 .2131 .8141 .22181 .82774 .21709 .82201 .20835 Mtetra
.638 .739 .922 r
.20086 .41729 .20845 .4242 .21939 .42107 .21182 .41415 Mtetra
.635 .739 .923 r
.21182 .41415 .21939 .42107 .23037 .41801 .22283 .41107 Mtetra
.632 .738 .925 r
.22283 .41107 .23037 .41801 .24139 .41501 .23388 .40806 Mtetra
.629 .738 .926 r
.23388 .40806 .24139 .41501 .25247 .41207 .24498 .4051 Mtetra
.626 .737 .927 r
.24498 .4051 .25247 .41207 .26359 .40917 .25612 .40219 Mtetra
.625 .737 .928 r
.25612 .40219 .26359 .40917 .27476 .40631 .26732 .3993 Mtetra
.624 .737 .928 r
.26732 .3993 .27476 .40631 .28599 .40347 .27858 .39642 Mtetra
.27858 .39642 .28599 .40347 .29727 .40061 .28988 .39353 Mtetra
.625 .737 .928 r
.28988 .39353 .29727 .40061 .30861 .39772 .30125 .3906 Mtetra
.627 .737 .927 r
.30125 .3906 .30861 .39772 .32 .39477 .31268 .38761 Mtetra
.63 .738 .925 r
.31268 .38761 .32 .39477 .33146 .39174 .32417 .38452 Mtetra
.634 .738 .923 r
.32417 .38452 .33146 .39174 .34299 .38859 .33572 .38131 Mtetra
.639 .739 .921 r
.33572 .38131 .34299 .38859 .35457 .38529 .34734 .37795 Mtetra
.644 .739 .919 r
.34734 .37795 .35457 .38529 .36622 .38184 .35902 .37445 Mtetra
.642 .738 .919 r
.35902 .37445 .36622 .38184 .37793 .37824 .37075 .37099 Mtetra
.563 .716 .944 r
.37075 .37099 .37793 .37824 .38969 .3747 .38245 .36937 Mtetra
.559 .018 0 r
.38245 .36937 .38969 .3747 .40144 .37287 .39374 .37974 Mtetra
.879 .529 .38 r
.39374 .37974 .40144 .37287 .41288 .38168 .40396 .42282 Mtetra
.789 .486 .476 r
.40396 .42282 .41288 .38168 .42355 .42025 .41399 .48381 Mtetra
.576 .3 .46 r
.41399 .48381 .42355 .42025 .43403 .47882 .42609 .4934 Mtetra
.898 .888 .465 r
.42609 .4934 .43403 .47882 .44601 .49638 .43954 .45714 Mtetra
.697 .513 .635 r
.43954 .45714 .44601 .49638 .45908 .47108 .45245 .4373 Mtetra
.599 .46 .663 r
.45245 .4373 .45908 .47108 .47188 .4555 .46501 .43264 Mtetra
.722 .578 .693 r
.46501 .43264 .47188 .4555 .48454 .449 .47776 .41855 Mtetra
.765 .576 .642 r
.47776 .41855 .48454 .449 .49734 .43011 .49064 .39144 Mtetra
.75 .549 .623 r
.49064 .39144 .49734 .43011 .51015 .39815 .50341 .36059 Mtetra
.733 .538 .629 r
.50341 .36059 .51015 .39815 .5228 .36424 .51602 .33469 Mtetra
.719 .548 .657 r
.51602 .33469 .5228 .36424 .53529 .33718 .52853 .31677 Mtetra
.711 .584 .712 r
.52853 .31677 .53529 .33718 .54773 .3192 .54102 .30537 Mtetra
.704 .642 .785 r
.54102 .30537 .54773 .3192 .56019 .30806 .55354 .29773 Mtetra
.696 .698 .848 r
.55354 .29773 .56019 .30806 .57271 .30066 .56612 .29176 Mtetra
.688 .729 .881 r
.56612 .29176 .57271 .30066 .5853 .29485 .57875 .2864 Mtetra
.684 .74 .893 r
.57875 .2864 .5853 .29485 .59794 .28959 .59143 .28126 Mtetra
.681 .743 .898 r
.59143 .28126 .59794 .28959 .61064 .28453 .60418 .27621 Mtetra
.679 .743 .899 r
.60418 .27621 .61064 .28453 .6234 .27956 .61697 .27122 Mtetra
.676 .743 .901 r
.61697 .27122 .6234 .27956 .63622 .27466 .62983 .2663 Mtetra
.674 .743 .902 r
.62983 .2663 .63622 .27466 .64909 .2698 .64274 .26142 Mtetra
.673 .742 .903 r
.64274 .26142 .64909 .2698 .66202 .26499 .65572 .25659 Mtetra
.671 .742 .904 r
.65572 .25659 .66202 .26499 .67501 .26022 .66875 .25179 Mtetra
.67 .742 .905 r
.66875 .25179 .67501 .26022 .68806 .25548 .68184 .24702 Mtetra
.668 .742 .905 r
.68184 .24702 .68806 .25548 .70117 .25076 .695 .24227 Mtetra
.667 .742 .906 r
.695 .24227 .70117 .25076 .71435 .24606 .70821 .23754 Mtetra
.666 .742 .906 r
.70821 .23754 .71435 .24606 .72758 .24136 .72149 .23281 Mtetra
.666 .742 .907 r
.72149 .23281 .72758 .24136 .74088 .23667 .73484 .22808 Mtetra
.665 .742 .907 r
.73484 .22808 .74088 .23667 .75425 .23198 .74824 .22335 Mtetra
.665 .741 .907 r
.74824 .22335 .75425 .23198 .76767 .22728 .76171 .21862 Mtetra
.664 .741 .907 r
.76171 .21862 .76767 .22728 .78116 .22257 .77525 .21387 Mtetra
.664 .741 .908 r
.77525 .21387 .78116 .22257 .79471 .21784 .78885 .20911 Mtetra
.78885 .20911 .79471 .21784 .80833 .2131 .80251 .20433 Mtetra
.80251 .20433 .80833 .2131 .82201 .20835 .81624 .19953 Mtetra
.638 .738 .921 r
.19321 .41031 .20086 .41729 .21182 .41415 .2042 .40714 Mtetra
.634 .738 .923 r
.2042 .40714 .21182 .41415 .22283 .41107 .21523 .40405 Mtetra
.631 .737 .924 r
.21523 .40405 .22283 .41107 .23388 .40806 .2263 .40101 Mtetra
.629 .736 .925 r
.2263 .40101 .23388 .40806 .24498 .4051 .23743 .39803 Mtetra
.627 .736 .926 r
.23743 .39803 .24498 .4051 .25612 .40219 .2486 .39508 Mtetra
.625 .735 .926 r
.2486 .39508 .25612 .40219 .26732 .3993 .25983 .39216 Mtetra
.624 .735 .926 r
.25983 .39216 .26732 .3993 .27858 .39642 .27111 .38925 Mtetra
.625 .735 .926 r
.27111 .38925 .27858 .39642 .28988 .39353 .28245 .38631 Mtetra
.626 .735 .925 r
.28245 .38631 .28988 .39353 .30125 .3906 .29384 .38333 Mtetra
.628 .735 .924 r
.29384 .38333 .30125 .3906 .31268 .38761 .3053 .38027 Mtetra
.631 .735 .922 r
.3053 .38027 .31268 .38761 .32417 .38452 .31682 .37712 Mtetra
.636 .735 .92 r
.31682 .37712 .32417 .38452 .33572 .38131 .3284 .37384 Mtetra
.64 .736 .918 r
.3284 .37384 .33572 .38131 .34734 .37795 .34005 .37043 Mtetra
.638 .734 .918 r
.34005 .37043 .34734 .37795 .35902 .37445 .35175 .36706 Mtetra
.546 .706 .945 r
.35175 .36706 .35902 .37445 .37075 .37099 .3634 .36578 Mtetra
.672 .143 0 r
.3634 .36578 .37075 .37099 .38245 .36937 .37449 .37813 Mtetra
.878 .538 .402 r
.37449 .37813 .38245 .36937 .39374 .37974 .38419 .4264 Mtetra
.78 .481 .482 r
.38419 .4264 .39374 .37974 .40396 .42282 .39372 .48995 Mtetra
.53 .26 .451 r
.39372 .48995 .40396 .42282 .41399 .48381 .40605 .49122 Mtetra
.996 .856 .577 r
.40605 .49122 .41399 .48381 .42609 .4934 .42003 .4441 Mtetra
.693 .496 .616 r
.42003 .4441 .42609 .4934 .43954 .45714 .4331 .41977 Mtetra
.584 .439 .65 r
.4331 .41977 .43954 .45714 .45245 .4373 .44557 .4161 Mtetra
.693 .571 .714 r
.44557 .4161 .45245 .4373 .46501 .43264 .45823 .40603 Mtetra
.759 .584 .659 r
.45823 .40603 .46501 .43264 .47776 .41855 .47111 .38357 Mtetra
.749 .555 .632 r
.47111 .38357 .47776 .41855 .49064 .39144 .48396 .35606 Mtetra
.733 .543 .635 r
.48396 .35606 .49064 .39144 .50341 .36059 .49667 .3317 Mtetra
.72 .551 .66 r
.49667 .3317 .50341 .36059 .51602 .33469 .50924 .31412 Mtetra
.711 .583 .711 r
.50924 .31412 .51602 .33469 .52853 .31677 .52176 .3026 Mtetra
.705 .639 .781 r
.52176 .3026 .52853 .31677 .54102 .30537 .53428 .29477 Mtetra
.697 .694 .843 r
.53428 .29477 .54102 .30537 .55354 .29773 .54685 .28867 Mtetra
.69 .726 .878 r
.54685 .28867 .55354 .29773 .56612 .29176 .55947 .28321 Mtetra
.685 .738 .891 r
.55947 .28321 .56612 .29176 .57875 .2864 .57215 .27798 Mtetra
.682 .742 .896 r
.57215 .27798 .57875 .2864 .59143 .28126 .58487 .27286 Mtetra
.68 .742 .898 r
.58487 .27286 .59143 .28126 .60418 .27621 .59765 .2678 Mtetra
.678 .742 .9 r
.59765 .2678 .60418 .27621 .61697 .27122 .61049 .2628 Mtetra
.676 .742 .901 r
.61049 .2628 .61697 .27122 .62983 .2663 .62339 .25786 Mtetra
.674 .742 .902 r
.62339 .25786 .62983 .2663 .64274 .26142 .63634 .25296 Mtetra
.672 .742 .903 r
.63634 .25296 .64274 .26142 .65572 .25659 .64936 .24811 Mtetra
.67 .742 .904 r
.64936 .24811 .65572 .25659 .66875 .25179 .66243 .24329 Mtetra
.669 .742 .905 r
.66243 .24329 .66875 .25179 .68184 .24702 .67557 .23849 Mtetra
.668 .742 .905 r
.67557 .23849 .68184 .24702 .695 .24227 .68877 .23371 Mtetra
.667 .742 .906 r
.68877 .23371 .695 .24227 .70821 .23754 .70203 .22895 Mtetra
.666 .742 .906 r
.70203 .22895 .70821 .23754 .72149 .23281 .71535 .22418 Mtetra
.666 .742 .907 r
.71535 .22418 .72149 .23281 .73484 .22808 .72874 .21942 Mtetra
.665 .741 .907 r
.72874 .21942 .73484 .22808 .74824 .22335 .74219 .21466 Mtetra
.74219 .21466 .74824 .22335 .76171 .21862 .7557 .20988 Mtetra
.664 .741 .907 r
.7557 .20988 .76171 .21862 .77525 .21387 .76928 .20509 Mtetra
.664 .741 .908 r
.76928 .20509 .77525 .21387 .78885 .20911 .78293 .20029 Mtetra
.78293 .20029 .78885 .20911 .80251 .20433 .79663 .19547 Mtetra
.79663 .19547 .80251 .20433 .81624 .19953 .81041 .19063 Mtetra
.638 .737 .921 r
.18551 .40324 .19321 .41031 .2042 .40714 .19652 .40005 Mtetra
.634 .737 .922 r
.19652 .40005 .2042 .40714 .21523 .40405 .20757 .39692 Mtetra
.632 .736 .923 r
.20757 .39692 .21523 .40405 .2263 .40101 .21868 .39386 Mtetra
.629 .735 .924 r
.21868 .39386 .2263 .40101 .23743 .39803 .22983 .39084 Mtetra
.627 .734 .924 r
.22983 .39084 .23743 .39803 .2486 .39508 .24103 .38786 Mtetra
.626 .734 .925 r
.24103 .38786 .2486 .39508 .25983 .39216 .25228 .38489 Mtetra
.625 .733 .924 r
.25228 .38489 .25983 .39216 .27111 .38925 .26359 .38193 Mtetra
.626 .733 .924 r
.26359 .38193 .27111 .38925 .28245 .38631 .27496 .37893 Mtetra
.627 .732 .923 r
.27496 .37893 .28245 .38631 .29384 .38333 .28638 .37589 Mtetra
.63 .732 .921 r
.28638 .37589 .29384 .38333 .3053 .38027 .29787 .37277 Mtetra
.633 .732 .919 r
.29787 .37277 .3053 .38027 .31682 .37712 .30942 .36955 Mtetra
.637 .732 .917 r
.30942 .36955 .31682 .37712 .3284 .37384 .32104 .36621 Mtetra
.634 .731 .918 r
.32104 .36621 .3284 .37384 .34005 .37043 .3327 .36294 Mtetra
.524 .695 .947 r
.3327 .36294 .34005 .37043 .35175 .36706 .34429 .36208 Mtetra
.761 .254 0 r
.34429 .36208 .35175 .36706 .3634 .36578 .35513 .37675 Mtetra
.876 .545 .42 r
.35513 .37675 .3634 .36578 .37449 .37813 .36421 .43067 Mtetra
.772 .477 .487 r
.36421 .43067 .37449 .37813 .38419 .4264 .37323 .49669 Mtetra
.477 .215 .437 r
.37323 .49669 .38419 .4264 .39372 .48995 .3859 .48941 Mtetra
.97 .78 .592 r
.3859 .48941 .39372 .48995 .40605 .49122 .40053 .43194 Mtetra
.69 .484 .603 r
.40053 .43194 .40605 .49122 .42003 .4441 .41382 .40323 Mtetra
.577 .426 .64 r
.41382 .40323 .42003 .4441 .4331 .41977 .4262 .39985 Mtetra
.66 .561 .733 r
.4262 .39985 .4331 .41977 .44557 .4161 .43874 .39298 Mtetra
.751 .593 .68 r
.43874 .39298 .44557 .4161 .45823 .40603 .45157 .37478 Mtetra
.747 .562 .644 r
.45157 .37478 .45823 .40603 .47111 .38357 .46447 .3507 Mtetra
.733 .548 .643 r
.46447 .3507 .47111 .38357 .48396 .35606 .47724 .32819 Mtetra
.72 .554 .665 r
.47724 .32819 .48396 .35606 .49667 .3317 .48987 .31121 Mtetra
.711 .584 .711 r
.48987 .31121 .49667 .3317 .50924 .31412 .50241 .29971 Mtetra
.705 .636 .778 r
.50241 .29971 .50924 .31412 .52176 .3026 .51495 .29176 Mtetra
.698 .69 .839 r
.51495 .29176 .52176 .3026 .53428 .29477 .52751 .28554 Mtetra
.691 .723 .874 r
.52751 .28554 .53428 .29477 .54685 .28867 .54012 .28 Mtetra
.686 .736 .889 r
.54012 .28 .54685 .28867 .55947 .28321 .55278 .2747 Mtetra
.684 .741 .894 r
.55278 .2747 .55947 .28321 .57215 .27798 .56549 .2695 Mtetra
.681 .742 .896 r
.56549 .2695 .57215 .27798 .58487 .27286 .57825 .26438 Mtetra
.679 .742 .898 r
.57825 .26438 .58487 .27286 .59765 .2678 .59108 .25931 Mtetra
.677 .742 .9 r
.59108 .25931 .59765 .2678 .61049 .2628 .60396 .2543 Mtetra
.675 .742 .901 r
.60396 .2543 .61049 .2628 .62339 .25786 .61689 .24934 Mtetra
.673 .742 .902 r
.61689 .24934 .62339 .25786 .63634 .25296 .62989 .24443 Mtetra
.672 .742 .903 r
.62989 .24443 .63634 .25296 .64936 .24811 .64295 .23955 Mtetra
.67 .742 .904 r
.64295 .23955 .64936 .24811 .66243 .24329 .65606 .23471 Mtetra
.669 .742 .905 r
.65606 .23471 .66243 .24329 .67557 .23849 .66924 .22989 Mtetra
.668 .742 .906 r
.66924 .22989 .67557 .23849 .68877 .23371 .68248 .22508 Mtetra
.667 .742 .906 r
.68248 .22508 .68877 .23371 .70203 .22895 .69579 .22028 Mtetra
.666 .742 .906 r
.69579 .22028 .70203 .22895 .71535 .22418 .70915 .21548 Mtetra
.665 .741 .907 r
.70915 .21548 .71535 .22418 .72874 .21942 .72258 .21069 Mtetra
.72258 .21069 .72874 .21942 .74219 .21466 .73608 .20588 Mtetra
.73608 .20588 .74219 .21466 .7557 .20988 .74964 .20107 Mtetra
.664 .741 .907 r
.74964 .20107 .7557 .20988 .76928 .20509 .76326 .19624 Mtetra
.664 .741 .908 r
.76326 .19624 .76928 .20509 .78293 .20029 .77695 .1914 Mtetra
.77695 .1914 .78293 .20029 .79663 .19547 .79071 .18654 Mtetra
.79071 .18654 .79663 .19547 .81041 .19063 .80453 .18166 Mtetra
.638 .736 .92 r
.17774 .39608 .18551 .40324 .19652 .40005 .18878 .39286 Mtetra
.635 .736 .921 r
.18878 .39286 .19652 .40005 .20757 .39692 .19986 .3897 Mtetra
.632 .735 .922 r
.19986 .3897 .20757 .39692 .21868 .39386 .21099 .3866 Mtetra
.63 .734 .922 r
.21099 .3866 .21868 .39386 .22983 .39084 .22217 .38353 Mtetra
.628 .733 .923 r
.22217 .38353 .22983 .39084 .24103 .38786 .2334 .3805 Mtetra
.627 .732 .923 r
.2334 .3805 .24103 .38786 .25228 .38489 .24468 .37749 Mtetra
.627 .731 .922 r
.24468 .37749 .25228 .38489 .26359 .38193 .25602 .37446 Mtetra
.25602 .37446 .26359 .38193 .27496 .37893 .26741 .37141 Mtetra
.629 .73 .92 r
.26741 .37141 .27496 .37893 .28638 .37589 .27887 .36829 Mtetra
.632 .73 .919 r
.27887 .36829 .28638 .37589 .29787 .37277 .29039 .3651 Mtetra
.635 .73 .917 r
.29039 .3651 .29787 .37277 .30942 .36955 .30197 .36181 Mtetra
.63 .727 .917 r
.30197 .36181 .30942 .36955 .32104 .36621 .3136 .35863 Mtetra
.495 .681 .949 r
.3136 .35863 .32104 .36621 .3327 .36294 .32511 .35827 Mtetra
.82 .34 0 r
.32511 .35827 .3327 .36294 .34429 .36208 .33566 .37553 Mtetra
.874 .55 .435 r
.33566 .37553 .34429 .36208 .35513 .37675 .34405 .43529 Mtetra
.763 .471 .491 r
.34405 .43529 .35513 .37675 .36421 .43067 .35254 .50338 Mtetra
.417 .163 .419 r
.35254 .50338 .36421 .43067 .37323 .49669 .36566 .48748 Mtetra
.936 .724 .591 r
.36566 .48748 .37323 .49669 .3859 .48941 .38102 .42054 Mtetra
.687 .475 .594 r
.38102 .42054 .3859 .48941 .40053 .43194 .39457 .38788 Mtetra
.575 .418 .631 r
.39457 .38788 .40053 .43194 .41382 .40323 .40688 .38426 Mtetra
.628 .551 .748 r
.40688 .38426 .41382 .40323 .4262 .39985 .41929 .37978 Mtetra
.741 .604 .705 r
.41929 .37978 .4262 .39985 .43874 .39298 .43205 .36532 Mtetra
.744 .571 .659 r
.43205 .36532 .43874 .39298 .45157 .37478 .44494 .34462 Mtetra
.732 .555 .652 r
.44494 .34462 .45157 .37478 .46447 .3507 .45775 .32416 Mtetra
.72 .559 .671 r
.45775 .32416 .46447 .3507 .47724 .32819 .47042 .30801 Mtetra
.711 .587 .714 r
.47042 .30801 .47724 .32819 .48987 .31121 .48299 .29667 Mtetra
.705 .635 .777 r
.48299 .29667 .48987 .31121 .50241 .29971 .49552 .28866 Mtetra
.698 .687 .836 r
.49552 .28866 .50241 .29971 .51495 .29176 .50808 .28236 Mtetra
.691 .72 .871 r
.50808 .28236 .51495 .29176 .52751 .28554 .52068 .27675 Mtetra
.687 .734 .887 r
.52068 .27675 .52751 .28554 .54012 .28 .53332 .27139 Mtetra
.685 .739 .892 r
.53332 .27139 .54012 .28 .55278 .2747 .54602 .26613 Mtetra
.683 .741 .895 r
.54602 .26613 .55278 .2747 .56549 .2695 .55877 .26094 Mtetra
.68 .741 .897 r
.55877 .26094 .56549 .2695 .57825 .26438 .57158 .25581 Mtetra
.678 .741 .898 r
.57158 .25581 .57825 .26438 .59108 .25931 .58444 .25074 Mtetra
.676 .741 .9 r
.58444 .25074 .59108 .25931 .60396 .2543 .59736 .24572 Mtetra
.674 .741 .901 r
.59736 .24572 .60396 .2543 .61689 .24934 .61034 .24075 Mtetra
.673 .741 .902 r
.61034 .24075 .61689 .24934 .62989 .24443 .62338 .23582 Mtetra
.671 .741 .903 r
.62338 .23582 .62989 .24443 .64295 .23955 .63648 .23092 Mtetra
.67 .741 .904 r
.63648 .23092 .64295 .23955 .65606 .23471 .64964 .22605 Mtetra
.668 .741 .905 r
.64964 .22605 .65606 .23471 .66924 .22989 .66286 .2212 Mtetra
.667 .741 .906 r
.66286 .2212 .66924 .22989 .68248 .22508 .67614 .21637 Mtetra
.666 .741 .906 r
.67614 .21637 .68248 .22508 .69579 .22028 .68949 .21154 Mtetra
.666 .741 .907 r
.68949 .21154 .69579 .22028 .70915 .21548 .7029 .20671 Mtetra
.665 .741 .907 r
.7029 .20671 .70915 .21548 .72258 .21069 .71638 .20187 Mtetra
.71638 .20187 .72258 .21069 .73608 .20588 .72992 .19703 Mtetra
.664 .741 .907 r
.72992 .19703 .73608 .20588 .74964 .20107 .74352 .19218 Mtetra
.74352 .19218 .74964 .20107 .76326 .19624 .75719 .18731 Mtetra
.664 .741 .908 r
.75719 .18731 .76326 .19624 .77695 .1914 .77093 .18243 Mtetra
.77093 .18243 .77695 .1914 .79071 .18654 .78473 .17753 Mtetra
.78473 .17753 .79071 .18654 .80453 .18166 .7986 .17261 Mtetra
.638 .736 .919 r
.16992 .38883 .17774 .39608 .18878 .39286 .18098 .38558 Mtetra
.635 .735 .92 r
.18098 .38558 .18878 .39286 .19986 .3897 .19209 .38238 Mtetra
.633 .734 .921 r
.19209 .38238 .19986 .3897 .21099 .3866 .20325 .37923 Mtetra
.631 .733 .921 r
.20325 .37923 .21099 .3866 .22217 .38353 .21445 .37611 Mtetra
.629 .732 .921 r
.21445 .37611 .22217 .38353 .2334 .3805 .22571 .37303 Mtetra
.628 .731 .921 r
.22571 .37303 .2334 .3805 .24468 .37749 .23702 .36995 Mtetra
.628 .73 .92 r
.23702 .36995 .24468 .37749 .25602 .37446 .24839 .36685 Mtetra
.629 .729 .919 r
.24839 .36685 .25602 .37446 .26741 .37141 .25982 .36373 Mtetra
.631 .728 .918 r
.25982 .36373 .26741 .37141 .27887 .36829 .2713 .36054 Mtetra
.633 .728 .916 r
.2713 .36054 .27887 .36829 .29039 .3651 .28285 .35728 Mtetra
.626 .725 .917 r
.28285 .35728 .29039 .3651 .30197 .36181 .29444 .35418 Mtetra
.46 .665 .951 r
.29444 .35418 .30197 .36181 .3136 .35863 .30587 .35437 Mtetra
.857 .404 .086 r
.30587 .35437 .3136 .35863 .32511 .35827 .31608 .37436 Mtetra
.871 .554 .447 r
.31608 .37436 .32511 .35827 .33566 .37553 .32372 .43989 Mtetra
.755 .466 .494 r
.32372 .43989 .33566 .37553 .34405 .43529 .33168 .50939 Mtetra
.347 .103 .395 r
.33168 .50939 .34405 .43529 .35254 .50338 .34535 .48494 Mtetra
.907 .684 .588 r
.34535 .48494 .35254 .50338 .36566 .48748 .36149 .40977 Mtetra
.684 .468 .587 r
.36149 .40977 .36566 .48748 .38102 .42054 .37532 .37378 Mtetra
.577 .414 .624 r
.37532 .37378 .38102 .42054 .39457 .38788 .3876 .3696 Mtetra
.6 .542 .761 r
.3876 .3696 .39457 .38788 .40688 .38426 .39988 .36677 Mtetra
.727 .616 .734 r
.39988 .36677 .40688 .38426 .41929 .37978 .41253 .35547 Mtetra
.741 .581 .677 r
.41253 .35547 .41929 .37978 .43205 .36532 .42538 .33794 Mtetra
.731 .563 .664 r
.42538 .33794 .43205 .36532 .44494 .34462 .4382 .31963 Mtetra
.72 .566 .679 r
.4382 .31963 .44494 .34462 .45775 .32416 .45089 .30449 Mtetra
.711 .59 .719 r
.45089 .30449 .45775 .32416 .47042 .30801 .46348 .29345 Mtetra
.704 .635 .777 r
.46348 .29345 .47042 .30801 .48299 .29667 .47602 .28546 Mtetra
.697 .684 .834 r
.47602 .28546 .48299 .29667 .49552 .28866 .48857 .27911 Mtetra
.691 .717 .869 r
.48857 .27911 .49552 .28866 .50808 .28236 .50116 .27345 Mtetra
.688 .732 .885 r
.50116 .27345 .50808 .28236 .52068 .27675 .51379 .26804 Mtetra
.685 .738 .891 r
.51379 .26804 .52068 .27675 .53332 .27139 .52648 .26274 Mtetra
.683 .739 .893 r
.52648 .26274 .53332 .27139 .54602 .26613 .53921 .25749 Mtetra
.681 .74 .895 r
.53921 .25749 .54602 .26613 .55877 .26094 .552 .2523 Mtetra
.679 .74 .897 r
.552 .2523 .55877 .26094 .57158 .25581 .56485 .24717 Mtetra
.677 .741 .899 r
.56485 .24717 .57158 .25581 .58444 .25074 .57775 .2421 Mtetra
.675 .741 .9 r
.57775 .2421 .58444 .25074 .59736 .24572 .59072 .23707 Mtetra
.673 .741 .901 r
.59072 .23707 .59736 .24572 .61034 .24075 .60374 .23208 Mtetra
.672 .741 .902 r
.60374 .23208 .61034 .24075 .62338 .23582 .61681 .22714 Mtetra
.67 .741 .904 r
.61681 .22714 .62338 .23582 .63648 .23092 .62996 .22222 Mtetra
.669 .741 .904 r
.62996 .22222 .63648 .23092 .64964 .22605 .64316 .21733 Mtetra
.668 .741 .905 r
.64316 .21733 .64964 .22605 .66286 .2212 .65642 .21245 Mtetra
.667 .741 .906 r
.65642 .21245 .66286 .2212 .67614 .21637 .66975 .20758 Mtetra
.666 .741 .906 r
.66975 .20758 .67614 .21637 .68949 .21154 .68314 .20272 Mtetra
.666 .741 .907 r
.68314 .20272 .68949 .21154 .7029 .20671 .6966 .19785 Mtetra
.665 .741 .907 r
.6966 .19785 .7029 .20671 .71638 .20187 .71012 .19298 Mtetra
.71012 .19298 .71638 .20187 .72992 .19703 .7237 .1881 Mtetra
.664 .741 .907 r
.7237 .1881 .72992 .19703 .74352 .19218 .73735 .18321 Mtetra
.664 .741 .908 r
.73735 .18321 .74352 .19218 .75719 .18731 .75107 .1783 Mtetra
.75107 .1783 .75719 .18731 .77093 .18243 .76485 .17338 Mtetra
.76485 .17338 .77093 .18243 .78473 .17753 .7787 .16844 Mtetra
.7787 .16844 .78473 .17753 .7986 .17261 .79262 .16347 Mtetra
.639 .735 .918 r
.16204 .3815 .16992 .38883 .18098 .38558 .17313 .3782 Mtetra
.636 .734 .919 r
.17313 .3782 .18098 .38558 .19209 .38238 .18426 .37495 Mtetra
.634 .733 .919 r
.18426 .37495 .19209 .38238 .20325 .37923 .19545 .37174 Mtetra
.632 .731 .92 r
.19545 .37174 .20325 .37923 .21445 .37611 .20668 .36857 Mtetra
.631 .73 .919 r
.20668 .36857 .21445 .37611 .22571 .37303 .21797 .36542 Mtetra
.63 .729 .919 r
.21797 .36542 .22571 .37303 .23702 .36995 .22931 .36227 Mtetra
.63 .728 .918 r
.22931 .36227 .23702 .36995 .24839 .36685 .24071 .35911 Mtetra
.631 .727 .917 r
.24071 .35911 .24839 .36685 .25982 .36373 .25216 .3559 Mtetra
.632 .726 .915 r
.25216 .3559 .25982 .36373 .2713 .36054 .26368 .35264 Mtetra
.623 .722 .918 r
.26368 .35264 .2713 .36054 .28285 .35728 .27524 .34961 Mtetra
.419 .647 .952 r
.27524 .34961 .28285 .35728 .29444 .35418 .28656 .35038 Mtetra
.879 .449 .16 r
.28656 .35038 .29444 .35418 .30587 .35437 .29641 .37316 Mtetra
.867 .555 .457 r
.29641 .37316 .30587 .35437 .31608 .37436 .30323 .44408 Mtetra
.747 .46 .496 r
.30323 .44408 .31608 .37436 .32372 .43989 .31071 .51406 Mtetra
.262 .03 .361 r
.31071 .51406 .32372 .43989 .33168 .50939 .32502 .48134 Mtetra
.884 .653 .585 r
.32502 .48134 .33168 .50939 .34535 .48494 .34196 .39946 Mtetra
.681 .462 .582 r
.34196 .39946 .34535 .48494 .36149 .40977 .35607 .36095 Mtetra
.579 .412 .619 r
.35607 .36095 .36149 .40977 .37532 .37378 .36833 .35603 Mtetra
.579 .535 .77 r
.36833 .35603 .37532 .37378 .3876 .3696 .38049 .35423 Mtetra
.71 .628 .764 r
.38049 .35423 .3876 .3696 .39988 .36677 .39302 .34547 Mtetra
.735 .594 .698 r
.39302 .34547 .39988 .36677 .41253 .35547 .4058 .33082 Mtetra
.729 .573 .679 r
.4058 .33082 .41253 .35547 .42538 .33794 .4186 .31466 Mtetra
.719 .574 .69 r
.4186 .31466 .42538 .33794 .4382 .31963 .4313 .30065 Mtetra
.711 .596 .726 r
.4313 .30065 .4382 .31963 .45089 .30449 .44389 .29003 Mtetra
.704 .637 .779 r
.44389 .29003 .45089 .30449 .46348 .29345 .45643 .28212 Mtetra
.697 .683 .833 r
.45643 .28212 .46348 .29345 .47602 .28546 .46898 .27576 Mtetra
.691 .715 .867 r
.46898 .27576 .47602 .28546 .48857 .27911 .48155 .27008 Mtetra
.688 .73 .883 r
.48155 .27008 .48857 .27911 .50116 .27345 .49418 .26464 Mtetra
.686 .736 .889 r
.49418 .26464 .50116 .27345 .51379 .26804 .50685 .25929 Mtetra
.684 .738 .892 r
.50685 .25929 .51379 .26804 .52648 .26274 .51957 .25401 Mtetra
.682 .739 .894 r
.51957 .25401 .52648 .26274 .53921 .25749 .53235 .24877 Mtetra
.68 .739 .896 r
.53235 .24877 .53921 .25749 .552 .2523 .54518 .24359 Mtetra
.678 .74 .897 r
.54518 .24359 .552 .2523 .56485 .24717 .55806 .23846 Mtetra
.676 .74 .899 r
.55806 .23846 .56485 .24717 .57775 .2421 .57101 .23337 Mtetra
.674 .741 .9 r
.57101 .23337 .57775 .2421 .59072 .23707 .58401 .22834 Mtetra
.673 .741 .902 r
.58401 .22834 .59072 .23707 .60374 .23208 .59707 .22334 Mtetra
.671 .741 .903 r
.59707 .22334 .60374 .23208 .61681 .22714 .61019 .21838 Mtetra
.67 .741 .904 r
.61019 .21838 .61681 .22714 .62996 .22222 .62338 .21344 Mtetra
.669 .741 .905 r
.62338 .21344 .62996 .22222 .64316 .21733 .63662 .20852 Mtetra
.668 .741 .905 r
.63662 .20852 .64316 .21733 .65642 .21245 .64993 .20362 Mtetra
.667 .741 .906 r
.64993 .20362 .65642 .21245 .66975 .20758 .6633 .19872 Mtetra
.666 .741 .906 r
.6633 .19872 .66975 .20758 .68314 .20272 .67673 .19382 Mtetra
.665 .741 .907 r
.67673 .19382 .68314 .20272 .6966 .19785 .69023 .18892 Mtetra
.69023 .18892 .6966 .19785 .71012 .19298 .7038 .18402 Mtetra
.7038 .18402 .71012 .19298 .7237 .1881 .71743 .1791 Mtetra
.664 .741 .907 r
.71743 .1791 .7237 .1881 .73735 .18321 .73113 .17417 Mtetra
.664 .741 .908 r
.73113 .17417 .73735 .18321 .75107 .1783 .74489 .16922 Mtetra
.74489 .16922 .75107 .1783 .76485 .17338 .75872 .16425 Mtetra
.75872 .16425 .76485 .17338 .7787 .16844 .77261 .15926 Mtetra
.77261 .15926 .7787 .16844 .79262 .16347 .78658 .15425 Mtetra
.639 .734 .917 r
.1541 .37408 .16204 .3815 .17313 .3782 .16521 .37072 Mtetra
.637 .733 .918 r
.16521 .37072 .17313 .3782 .18426 .37495 .17638 .36742 Mtetra
.635 .732 .918 r
.17638 .36742 .18426 .37495 .19545 .37174 .18759 .36415 Mtetra
.633 .73 .918 r
.18759 .36415 .19545 .37174 .20668 .36857 .19886 .36092 Mtetra
.632 .729 .918 r
.19886 .36092 .20668 .36857 .21797 .36542 .21017 .35769 Mtetra
.632 .728 .917 r
.21017 .35769 .21797 .36542 .22931 .36227 .22154 .35447 Mtetra
.632 .727 .916 r
.22154 .35447 .22931 .36227 .24071 .35911 .23297 .35122 Mtetra
.633 .726 .915 r
.23297 .35122 .24071 .35911 .25216 .3559 .24446 .34794 Mtetra
.621 .721 .918 r
.24446 .34794 .25216 .3559 .26368 .35264 .25597 .34496 Mtetra
.372 .625 .951 r
.25597 .34496 .26368 .35264 .27524 .34961 .2672 .34632 Mtetra
.891 .48 .216 r
.2672 .34632 .27524 .34961 .28656 .35038 .27664 .37183 Mtetra
.864 .556 .465 r
.27664 .37183 .28656 .35038 .29641 .37316 .28262 .44748 Mtetra
.738 .453 .497 r
.28262 .44748 .29641 .37316 .30323 .44408 .28969 .51684 Mtetra
.156 0 .315 r
.28969 .51684 .30323 .44408 .31071 .51406 .30469 .47633 Mtetra
.863 .629 .583 r
.30469 .47633 .31071 .51406 .32502 .48134 .3224 .38944 Mtetra
.677 .456 .578 r
.3224 .38944 .32502 .48134 .34196 .39946 .33678 .34931 Mtetra
.583 .412 .616 r
.33678 .34931 .34196 .39946 .35607 .36095 .34903 .34362 Mtetra
.567 .533 .777 r
.34903 .34362 .35607 .36095 .36833 .35603 .3611 .34233 Mtetra
.69 .641 .795 r
.3611 .34233 .36833 .35603 .38049 .35423 .37351 .33555 Mtetra
.728 .607 .722 r
.37351 .33555 .38049 .35423 .39302 .34547 .38619 .32342 Mtetra
.727 .584 .696 r
.38619 .32342 .39302 .34547 .4058 .33082 .39895 .30931 Mtetra
.718 .583 .703 r
.39895 .30931 .4058 .33082 .4186 .31466 .41164 .29651 Mtetra
.71 .602 .734 r
.41164 .29651 .4186 .31466 .4313 .30065 .42423 .28639 Mtetra
.702 .639 .783 r
.42423 .28639 .4313 .30065 .44389 .29003 .43677 .27864 Mtetra
.696 .682 .833 r
.43677 .27864 .44389 .29003 .45643 .28212 .44931 .27231 Mtetra
.69 .713 .866 r
.44931 .27231 .45643 .28212 .46898 .27576 .46187 .26662 Mtetra
.687 .728 .881 r
.46187 .26662 .46898 .27576 .48155 .27008 .47448 .26116 Mtetra
.685 .734 .888 r
.47448 .26116 .48155 .27008 .49418 .26464 .48714 .25579 Mtetra
.684 .736 .89 r
.48714 .25579 .49418 .26464 .50685 .25929 .49985 .25047 Mtetra
.682 .737 .892 r
.49985 .25047 .50685 .25929 .51957 .25401 .51261 .2452 Mtetra
.681 .738 .894 r
.51261 .2452 .51957 .25401 .53235 .24877 .52542 .23997 Mtetra
.679 .739 .896 r
.52542 .23997 .53235 .24877 .54518 .24359 .53829 .2348 Mtetra
.677 .739 .898 r
.53829 .2348 .54518 .24359 .55806 .23846 .55122 .22967 Mtetra
.675 .74 .899 r
.55122 .22967 .55806 .23846 .57101 .23337 .5642 .22458 Mtetra
.673 .74 .901 r
.5642 .22458 .57101 .23337 .58401 .22834 .57725 .21954 Mtetra
.672 .74 .902 r
.57725 .21954 .58401 .22834 .59707 .22334 .59035 .21453 Mtetra
.67 .741 .903 r
.59035 .21453 .59707 .22334 .61019 .21838 .60351 .20954 Mtetra
.669 .741 .904 r
.60351 .20954 .61019 .21838 .62338 .21344 .61674 .20459 Mtetra
.668 .741 .905 r
.61674 .20459 .62338 .21344 .63662 .20852 .63003 .19964 Mtetra
.667 .741 .905 r
.63003 .19964 .63662 .20852 .64993 .20362 .64338 .19471 Mtetra
.666 .741 .906 r
.64338 .19471 .64993 .20362 .6633 .19872 .65679 .18978 Mtetra
.65679 .18978 .6633 .19872 .67673 .19382 .67027 .18485 Mtetra
.665 .741 .907 r
.67027 .18485 .67673 .19382 .69023 .18892 .68382 .17991 Mtetra
.68382 .17991 .69023 .18892 .7038 .18402 .69743 .17497 Mtetra
.664 .741 .907 r
.69743 .17497 .7038 .18402 .71743 .1791 .7111 .17001 Mtetra
.7111 .17001 .71743 .1791 .73113 .17417 .72485 .16504 Mtetra
.664 .741 .908 r
.72485 .16504 .73113 .17417 .74489 .16922 .73865 .16005 Mtetra
.73865 .16005 .74489 .16922 .75872 .16425 .75253 .15504 Mtetra
.75253 .15504 .75872 .16425 .77261 .15926 .76647 .15001 Mtetra
.76647 .15001 .77261 .15926 .78658 .15425 .78049 .14496 Mtetra
.64 .734 .916 r
.14609 .36656 .1541 .37408 .16521 .37072 .15724 .36315 Mtetra
.638 .732 .917 r
.15724 .36315 .16521 .37072 .17638 .36742 .16843 .35979 Mtetra
.636 .731 .917 r
.16843 .35979 .17638 .36742 .18759 .36415 .17968 .35646 Mtetra
.635 .73 .916 r
.17968 .35646 .18759 .36415 .19886 .36092 .19097 .35315 Mtetra
.634 .728 .916 r
.19097 .35315 .19886 .36092 .21017 .35769 .20232 .34985 Mtetra
.634 .727 .915 r
.20232 .34985 .21017 .35769 .22154 .35447 .21372 .34654 Mtetra
.633 .725 .914 r
.21372 .34654 .22154 .35447 .23297 .35122 .22518 .34322 Mtetra
.619 .72 .918 r
.22518 .34322 .23297 .35122 .24446 .34794 .23666 .34027 Mtetra
.32 .6 .947 r
.23666 .34027 .24446 .34794 .25597 .34496 .24777 .34222 Mtetra
.898 .502 .258 r
.24777 .34222 .25597 .34496 .2672 .34632 .25678 .37027 Mtetra
.86 .555 .472 r
.25678 .37027 .2672 .34632 .27664 .37183 .26195 .44974 Mtetra
.729 .446 .497 r
.26195 .44974 .27664 .37183 .28262 .44748 .26869 .51724 Mtetra
.021 0 .249 r
.26869 .51724 .28262 .44748 .28969 .51684 .28443 .46967 Mtetra
.845 .609 .581 r
.28443 .46967 .28969 .51684 .30469 .47633 .30285 .37958 Mtetra
.673 .451 .575 r
.30285 .37958 .30469 .47633 .3224 .38944 .31745 .33877 Mtetra
.587 .414 .614 r
.31745 .33877 .3224 .38944 .33678 .34931 .3297 .33238 Mtetra
.562 .535 .783 r
.3297 .33238 .33678 .34931 .34903 .34362 .34169 .33122 Mtetra
.67 .652 .823 r
.34169 .33122 .34903 .34362 .3611 .34233 .35399 .32588 Mtetra
.719 .622 .748 r
.35399 .32588 .3611 .34233 .37351 .33555 .36657 .31587 Mtetra
.723 .597 .716 r
.36657 .31587 .37351 .33555 .38619 .32342 .37926 .30366 Mtetra
.716 .593 .717 r
.37926 .30366 .38619 .32342 .39895 .30931 .39192 .29207 Mtetra
.708 .61 .744 r
.39192 .29207 .39895 .30931 .41164 .29651 .40451 .28253 Mtetra
.701 .643 .789 r
.40451 .28253 .41164 .29651 .42423 .28639 .41704 .27499 Mtetra
.694 .682 .834 r
.41704 .27499 .42423 .28639 .43677 .27864 .42956 .26872 Mtetra
.689 .711 .865 r
.42956 .26872 .43677 .27864 .44931 .27231 .44211 .26305 Mtetra
.686 .726 .88 r
.44211 .26305 .44931 .27231 .46187 .26662 .4547 .2576 Mtetra
.685 .732 .886 r
.4547 .2576 .46187 .26662 .47448 .26116 .46734 .25222 Mtetra
.684 .735 .889 r
.46734 .25222 .47448 .26116 .48714 .25579 .48004 .24688 Mtetra
.682 .736 .891 r
.48004 .24688 .48714 .25579 .49985 .25047 .49279 .24158 Mtetra
.681 .737 .893 r
.49279 .24158 .49985 .25047 .51261 .2452 .50558 .23632 Mtetra
.679 .738 .895 r
.50558 .23632 .51261 .2452 .52542 .23997 .51844 .23111 Mtetra
.677 .739 .897 r
.51844 .23111 .52542 .23997 .53829 .2348 .53135 .22593 Mtetra
.676 .739 .898 r
.53135 .22593 .53829 .2348 .55122 .22967 .54432 .2208 Mtetra
.674 .74 .9 r
.54432 .2208 .55122 .22967 .5642 .22458 .55734 .21572 Mtetra
.672 .74 .901 r
.55734 .21572 .5642 .22458 .57725 .21954 .57043 .21066 Mtetra
.671 .74 .902 r
.57043 .21066 .57725 .21954 .59035 .21453 .58357 .20564 Mtetra
.67 .741 .903 r
.58357 .20564 .59035 .21453 .60351 .20954 .59678 .20064 Mtetra
.669 .741 .904 r
.59678 .20064 .60351 .20954 .61674 .20459 .61004 .19566 Mtetra
.668 .741 .905 r
.61004 .19566 .61674 .20459 .63003 .19964 .62338 .19069 Mtetra
.667 .741 .906 r
.62338 .19069 .63003 .19964 .64338 .19471 .63677 .18573 Mtetra
.666 .741 .906 r
.63677 .18573 .64338 .19471 .65679 .18978 .65023 .18076 Mtetra
.665 .741 .907 r
.65023 .18076 .65679 .18978 .67027 .18485 .66375 .1758 Mtetra
.66375 .1758 .67027 .18485 .68382 .17991 .67734 .17083 Mtetra
.67734 .17083 .68382 .17991 .69743 .17497 .691 .16584 Mtetra
.664 .741 .907 r
.691 .16584 .69743 .17497 .7111 .17001 .70472 .16084 Mtetra
.664 .741 .908 r
.70472 .16084 .7111 .17001 .72485 .16504 .71851 .15583 Mtetra
.71851 .15583 .72485 .16504 .73865 .16005 .73236 .1508 Mtetra
.73236 .1508 .73865 .16005 .75253 .15504 .74629 .14574 Mtetra
.74629 .14574 .75253 .15504 .76647 .15001 .76028 .14067 Mtetra
.76028 .14067 .76647 .15001 .78049 .14496 .77434 .13557 Mtetra
.641 .733 .915 r
.13803 .35896 .14609 .36656 .15724 .36315 .14921 .35549 Mtetra
.639 .732 .915 r
.14921 .35549 .15724 .36315 .16843 .35979 .16043 .35206 Mtetra
.638 .73 .915 r
.16043 .35206 .16843 .35979 .17968 .35646 .1717 .34865 Mtetra
.637 .729 .915 r
.1717 .34865 .17968 .35646 .19097 .35315 .18303 .34527 Mtetra
.636 .727 .914 r
.18303 .34527 .19097 .35315 .20232 .34985 .1944 .34188 Mtetra
.635 .726 .913 r
.1944 .34188 .20232 .34985 .21372 .34654 .20584 .33851 Mtetra
.617 .719 .919 r
.20584 .33851 .21372 .34654 .22518 .34322 .21728 .33558 Mtetra
.264 .572 .939 r
.21728 .33558 .22518 .34322 .23666 .34027 .22827 .33807 Mtetra
.901 .517 .289 r
.22827 .33807 .23666 .34027 .24777 .34222 .23685 .36838 Mtetra
.856 .554 .477 r
.23685 .36838 .24777 .34222 .25678 .37027 .24124 .45053 Mtetra
.72 .437 .497 r
.24124 .45053 .25678 .37027 .26195 .44974 .24778 .51492 Mtetra
0 0 .155 r
.24778 .51492 .26195 .44974 .26869 .51724 .26426 .46123 Mtetra
.829 .592 .58 r
.26426 .46123 .26869 .51724 .28443 .46967 .28328 .36979 Mtetra
.669 .447 .574 r
.28328 .36979 .28443 .46967 .30285 .37958 .29805 .32918 Mtetra
.59 .416 .614 r
.29805 .32918 .30285 .37958 .31745 .33877 .31032 .32223 Mtetra
.564 .541 .788 r
.31032 .32223 .31745 .33877 .3297 .33238 .32225 .32095 Mtetra
.651 .662 .848 r
.32225 .32095 .3297 .33238 .34169 .33122 .33444 .3166 Mtetra
.708 .637 .775 r
.33444 .3166 .34169 .33122 .35399 .32588 .34691 .30831 Mtetra
.718 .611 .737 r
.34691 .30831 .35399 .32588 .36657 .31587 .35953 .2978 Mtetra
.714 .605 .734 r
.35953 .2978 .36657 .31587 .37926 .30366 .37215 .28738 Mtetra
.706 .619 .756 r
.37215 .28738 .37926 .30366 .39192 .29207 .38471 .27846 Mtetra
.699 .648 .795 r
.38471 .27846 .39192 .29207 .40451 .28253 .39723 .27118 Mtetra
.692 .683 .836 r
.39723 .27118 .40451 .28253 .41704 .27499 .40973 .265 Mtetra
.687 .709 .865 r
.40973 .265 .41704 .27499 .42956 .26872 .42227 .25937 Mtetra
.685 .724 .879 r
.42227 .25937 .42956 .26872 .44211 .26305 .43485 .25393 Mtetra
.684 .73 .885 r
.43485 .25393 .44211 .26305 .4547 .2576 .44747 .24856 Mtetra
.683 .733 .888 r
.44747 .24856 .4547 .2576 .46734 .25222 .46015 .24322 Mtetra
.682 .735 .89 r
.46015 .24322 .46734 .25222 .48004 .24688 .47288 .23791 Mtetra
.681 .736 .892 r
.47288 .23791 .48004 .24688 .49279 .24158 .48567 .23262 Mtetra
.679 .737 .894 r
.48567 .23262 .49279 .24158 .50558 .23632 .4985 .22738 Mtetra
.678 .738 .896 r
.4985 .22738 .50558 .23632 .51844 .23111 .5114 .22217 Mtetra
.676 .738 .897 r
.5114 .22217 .51844 .23111 .53135 .22593 .52435 .217 Mtetra
.675 .739 .899 r
.52435 .217 .53135 .22593 .54432 .2208 .53735 .21187 Mtetra
.673 .739 .9 r
.53735 .21187 .54432 .2208 .55734 .21572 .55042 .20678 Mtetra
.672 .74 .902 r
.55042 .20678 .55734 .21572 .57043 .21066 .56354 .20172 Mtetra
.67 .74 .903 r
.56354 .20172 .57043 .21066 .58357 .20564 .57673 .19668 Mtetra
.669 .74 .904 r
.57673 .19668 .58357 .20564 .59678 .20064 .58998 .19166 Mtetra
.668 .741 .905 r
.58998 .19166 .59678 .20064 .61004 .19566 .60329 .18665 Mtetra
.667 .741 .905 r
.60329 .18665 .61004 .19566 .62338 .19069 .61666 .18166 Mtetra
.666 .741 .906 r
.61666 .18166 .62338 .19069 .63677 .18573 .6301 .17667 Mtetra
.6301 .17667 .63677 .18573 .65023 .18076 .64361 .17167 Mtetra
.665 .741 .907 r
.64361 .17167 .65023 .18076 .66375 .1758 .65718 .16667 Mtetra
.65718 .16667 .66375 .1758 .67734 .17083 .67081 .16166 Mtetra
.664 .741 .907 r
.67081 .16166 .67734 .17083 .691 .16584 .68451 .15664 Mtetra
.68451 .15664 .691 .16584 .70472 .16084 .69828 .1516 Mtetra
.664 .741 .908 r
.69828 .1516 .70472 .16084 .71851 .15583 .71211 .14654 Mtetra
.71211 .14654 .71851 .15583 .73236 .1508 .72602 .14146 Mtetra
.72602 .14146 .73236 .1508 .74629 .14574 .73999 .13637 Mtetra
.73999 .13637 .74629 .14574 .76028 .14067 .75403 .13125 Mtetra
.75403 .13125 .76028 .14067 .77434 .13557 .76814 .1261 Mtetra
.643 .733 .914 r
.12991 .35127 .13803 .35896 .14921 .35549 .14111 .34773 Mtetra
.641 .731 .914 r
.14111 .34773 .14921 .35549 .16043 .35206 .15236 .34423 Mtetra
.639 .73 .914 r
.15236 .34423 .16043 .35206 .1717 .34865 .16367 .34075 Mtetra
.638 .728 .913 r
.16367 .34075 .1717 .34865 .18303 .34527 .17502 .33728 Mtetra
.637 .727 .913 r
.17502 .33728 .18303 .34527 .1944 .34188 .18643 .33383 Mtetra
.617 .72 .919 r
.18643 .33383 .1944 .34188 .20584 .33851 .19784 .33091 Mtetra
.207 .543 .928 r
.19784 .33091 .20584 .33851 .21728 .33558 .20871 .3339 Mtetra
.902 .527 .313 r
.20871 .3339 .21728 .33558 .22827 .33807 .21687 .36608 Mtetra
.852 .552 .48 r
.21687 .36608 .22827 .33807 .23685 .36838 .22056 .44961 Mtetra
.711 .428 .495 r
.22056 .44961 .23685 .36838 .24124 .45053 .22704 .50971 Mtetra
0 0 .027 r
.22704 .50971 .24124 .45053 .24778 .51492 .24422 .45103 Mtetra
.814 .576 .579 r
.24422 .45103 .24778 .51492 .26426 .46123 .26371 .36003 Mtetra
.665 .442 .572 r
.26371 .36003 .26426 .46123 .28328 .36979 .27859 .32043 Mtetra
.593 .419 .615 r
.27859 .32043 .28328 .36979 .29805 .32918 .29086 .31309 Mtetra
.571 .551 .793 r
.29086 .31309 .29805 .32918 .31032 .32223 .30274 .31151 Mtetra
.636 .671 .867 r
.30274 .31151 .31032 .32223 .32225 .32095 .31485 .3078 Mtetra
.696 .652 .802 r
.31485 .3078 .32225 .32095 .33444 .3166 .32722 .30085 Mtetra
.711 .626 .76 r
.32722 .30085 .33444 .3166 .34691 .30831 .33975 .2918 Mtetra
.71 .618 .752 r
.33975 .2918 .34691 .30831 .35953 .2978 .35232 .28249 Mtetra
.704 .628 .77 r
.35232 .28249 .35953 .2978 .37215 .28738 .36485 .27419 Mtetra
.697 .654 .803 r
.36485 .27419 .37215 .28738 .38471 .27846 .37735 .2672 Mtetra
.69 .684 .839 r
.37735 .2672 .38471 .27846 .39723 .27118 .38984 .26114 Mtetra
.686 .708 .865 r
.38984 .26114 .39723 .27118 .40973 .265 .40235 .25556 Mtetra
.683 .722 .879 r
.40235 .25556 .40973 .265 .42227 .25937 .41491 .25016 Mtetra
.683 .729 .885 r
.41491 .25016 .42227 .25937 .43485 .25393 .42752 .24481 Mtetra
.682 .731 .888 r
.42752 .24481 .43485 .25393 .44747 .24856 .44018 .23948 Mtetra
.681 .733 .89 r
.44018 .23948 .44747 .24856 .46015 .24322 .4529 .23416 Mtetra
.68 .734 .891 r
.4529 .23416 .46015 .24322 .47288 .23791 .46567 .22887 Mtetra
.679 .735 .893 r
.46567 .22887 .47288 .23791 .48567 .23262 .47849 .2236 Mtetra
.678 .736 .895 r
.47849 .2236 .48567 .23262 .4985 .22738 .49136 .21837 Mtetra
.676 .737 .896 r
.49136 .21837 .4985 .22738 .5114 .22217 .50429 .21317 Mtetra
.675 .738 .898 r
.50429 .21317 .5114 .22217 .52435 .217 .51728 .20801 Mtetra
.673 .739 .9 r
.51728 .20801 .52435 .217 .53735 .21187 .53033 .20288 Mtetra
.672 .739 .901 r
.53033 .20288 .53735 .21187 .55042 .20678 .54344 .19778 Mtetra
.671 .74 .902 r
.54344 .19778 .55042 .20678 .56354 .20172 .5566 .1927 Mtetra
.669 .74 .903 r
.5566 .1927 .56354 .20172 .57673 .19668 .56983 .18765 Mtetra
.668 .74 .904 r
.56983 .18765 .57673 .19668 .58998 .19166 .58312 .18261 Mtetra
.667 .741 .905 r
.58312 .18261 .58998 .19166 .60329 .18665 .59648 .17758 Mtetra
.667 .741 .906 r
.59648 .17758 .60329 .18665 .61666 .18166 .6099 .17255 Mtetra
.666 .741 .906 r
.6099 .17255 .61666 .18166 .6301 .17667 .62338 .16753 Mtetra
.665 .741 .906 r
.62338 .16753 .6301 .17667 .64361 .17167 .63693 .1625 Mtetra
.665 .741 .907 r
.63693 .1625 .64361 .17167 .65718 .16667 .65054 .15746 Mtetra
.65054 .15746 .65718 .16667 .67081 .16166 .66422 .15241 Mtetra
.664 .741 .907 r
.66422 .15241 .67081 .16166 .68451 .15664 .67797 .14735 Mtetra
.67797 .14735 .68451 .15664 .69828 .1516 .69178 .14227 Mtetra
.664 .741 .908 r
.69178 .14227 .69828 .1516 .71211 .14654 .70566 .13717 Mtetra
.70566 .13717 .71211 .14654 .72602 .14146 .71961 .13205 Mtetra
.71961 .13205 .72602 .14146 .73999 .13637 .73363 .1269 Mtetra
.73363 .1269 .73999 .13637 .75403 .13125 .74772 .12174 Mtetra
.74772 .12174 .75403 .13125 .76814 .1261 .76188 .11655 Mtetra
.644 .732 .913 r
.12172 .34349 .12991 .35127 .14111 .34773 .13295 .33989 Mtetra
.642 .731 .913 r
.13295 .33989 .14111 .34773 .15236 .34423 .14424 .33631 Mtetra
.641 .73 .913 r
.14424 .33631 .15236 .34423 .16367 .34075 .15557 .33275 Mtetra
.639 .728 .912 r
.15557 .33275 .16367 .34075 .17502 .33728 .16696 .32922 Mtetra
.616 .72 .92 r
.16696 .32922 .17502 .33728 .18643 .33383 .17833 .32629 Mtetra
.152 .514 .914 r
.17833 .32629 .18643 .33383 .19784 .33091 .18908 .32971 Mtetra
.901 .533 .33 r
.18908 .32971 .19784 .33091 .20871 .3339 .19684 .36329 Mtetra
.848 .549 .483 r
.19684 .36329 .20871 .3339 .21687 .36608 .19995 .44679 Mtetra
.701 .417 .492 r
.19995 .44679 .21687 .36608 .22056 .44961 .2065 .50158 Mtetra
0 0 0 r
.2065 .50158 .22056 .44961 .22704 .50971 .22433 .4392 Mtetra
.801 .563 .578 r
.22433 .4392 .22704 .50971 .24422 .45103 .24414 .35029 Mtetra
.661 .439 .572 r
.24414 .35029 .24422 .45103 .26371 .36003 .25906 .31239 Mtetra
.596 .424 .618 r
.25906 .31239 .26371 .36003 .27859 .32043 .27132 .30483 Mtetra
.579 .562 .799 r
.27132 .30483 .27859 .32043 .29086 .31309 .28318 .30288 Mtetra
.626 .679 .88 r
.28318 .30288 .29086 .31309 .30274 .31151 .29521 .29951 Mtetra
.684 .666 .827 r
.29521 .29951 .30274 .31151 .31485 .3078 .30749 .29358 Mtetra
.704 .641 .784 r
.30749 .29358 .31485 .3078 .32722 .30085 .31993 .28575 Mtetra
.705 .632 .772 r
.31993 .28575 .32722 .30085 .33975 .2918 .33244 .27743 Mtetra
.7 .639 .784 r
.33244 .27743 .33975 .2918 .35232 .28249 .34493 .26975 Mtetra
.694 .66 .812 r
.34493 .26975 .35232 .28249 .36485 .27419 .3574 .26306 Mtetra
.688 .686 .843 r
.3574 .26306 .36485 .27419 .37735 .2672 .36987 .25714 Mtetra
.683 .708 .867 r
.36987 .25714 .37735 .2672 .38984 .26114 .38237 .25163 Mtetra
.682 .721 .879 r
.38237 .25163 .38984 .26114 .40235 .25556 .39491 .24628 Mtetra
.681 .727 .885 r
.39491 .24628 .40235 .25556 .41491 .25016 .4075 .24096 Mtetra
.681 .73 .887 r
.4075 .24096 .41491 .25016 .42752 .24481 .42014 .23565 Mtetra
.68 .732 .889 r
.42014 .23565 .42752 .24481 .44018 .23948 .43283 .23035 Mtetra
.68 .733 .891 r
.43283 .23035 .44018 .23948 .4529 .23416 .44558 .22505 Mtetra
.679 .734 .892 r
.44558 .22505 .4529 .23416 .46567 .22887 .45839 .21977 Mtetra
.678 .735 .894 r
.45839 .21977 .46567 .22887 .47849 .2236 .47125 .21452 Mtetra
.676 .736 .896 r
.47125 .21452 .47849 .2236 .49136 .21837 .48416 .2093 Mtetra
.675 .737 .897 r
.48416 .2093 .49136 .21837 .50429 .21317 .49713 .20411 Mtetra
.674 .738 .899 r
.49713 .20411 .50429 .21317 .51728 .20801 .51016 .19895 Mtetra
.672 .739 .9 r
.51016 .19895 .51728 .20801 .53033 .20288 .52325 .19381 Mtetra
.671 .739 .901 r
.52325 .19381 .53033 .20288 .54344 .19778 .53639 .1887 Mtetra
.67 .74 .903 r
.53639 .1887 .54344 .19778 .5566 .1927 .5496 .18362 Mtetra
.669 .74 .904 r
.5496 .18362 .5566 .1927 .56983 .18765 .56287 .17854 Mtetra
.668 .74 .904 r
.56287 .17854 .56983 .18765 .58312 .18261 .57621 .17348 Mtetra
.667 .741 .905 r
.57621 .17348 .58312 .18261 .59648 .17758 .5896 .16842 Mtetra
.666 .741 .906 r
.5896 .16842 .59648 .17758 .6099 .17255 .60307 .16337 Mtetra
.60307 .16337 .6099 .17255 .62338 .16753 .61659 .15831 Mtetra
.665 .741 .907 r
.61659 .15831 .62338 .16753 .63693 .1625 .63018 .15325 Mtetra
.63018 .15325 .63693 .1625 .65054 .15746 .64384 .14817 Mtetra
.664 .741 .907 r
.64384 .14817 .65054 .15746 .66422 .15241 .65757 .14308 Mtetra
.65757 .14308 .66422 .15241 .67797 .14735 .67136 .13798 Mtetra
.664 .741 .908 r
.67136 .13798 .67797 .14735 .69178 .14227 .68522 .13285 Mtetra
.68522 .13285 .69178 .14227 .70566 .13717 .69915 .12771 Mtetra
.69915 .12771 .70566 .13717 .71961 .13205 .71315 .12254 Mtetra
.71315 .12254 .71961 .13205 .73363 .1269 .72722 .11735 Mtetra
.72722 .11735 .73363 .1269 .74772 .12174 .74135 .11214 Mtetra
.74135 .11214 .74772 .12174 .76188 .11655 .75556 .10691 Mtetra
.645 .732 .912 r
.11347 .33563 .12172 .34349 .13295 .33989 .12473 .33196 Mtetra
.644 .731 .912 r
.12473 .33196 .13295 .33989 .14424 .33631 .13605 .3283 Mtetra
.642 .729 .912 r
.13605 .3283 .14424 .33631 .15557 .33275 .14741 .32469 Mtetra
.616 .721 .921 r
.14741 .32469 .15557 .33275 .16696 .32922 .15875 .32173 Mtetra
.103 .486 .899 r
.15875 .32173 .16696 .32922 .17833 .32629 .16939 .3255 Mtetra
.9 .537 .342 r
.16939 .3255 .17833 .32629 .18908 .32971 .17678 .35994 Mtetra
.844 .546 .484 r
.17678 .35994 .18908 .32971 .19684 .36329 .17946 .442 Mtetra
.689 .405 .487 r
.17946 .442 .19684 .36329 .19995 .44679 .18623 .49067 Mtetra
.801 .791 .294 r
.18623 .49067 .19995 .44679 .2065 .50158 .20461 .42598 Mtetra
.788 .551 .578 r
.20461 .42598 .2065 .50158 .22433 .4392 .22457 .3406 Mtetra
.657 .436 .572 r
.22457 .3406 .22433 .4392 .24414 .35029 .23945 .30495 Mtetra
.599 .429 .623 r
.23945 .30495 .24414 .35029 .25906 .31239 .2517 .29735 Mtetra
.589 .575 .806 r
.2517 .29735 .25906 .31239 .27132 .30483 .26353 .295 Mtetra
.621 .686 .89 r
.26353 .295 .27132 .30483 .28318 .30288 .27551 .29176 Mtetra
.672 .678 .847 r
.27551 .29176 .28318 .30288 .29521 .29951 .2877 .28656 Mtetra
.695 .656 .807 r
.2877 .28656 .29521 .29951 .30749 .29358 .30006 .27972 Mtetra
.7 .645 .792 r
.30006 .27972 .30749 .29358 .31993 .28575 .3125 .27226 Mtetra
.696 .65 .799 r
.3125 .27226 .31993 .28575 .33244 .27743 .32494 .26515 Mtetra
.69 .667 .822 r
.32494 .26515 .33244 .27743 .34493 .26975 .33738 .25877 Mtetra
.685 .689 .848 r
.33738 .25877 .34493 .26975 .3574 .26306 .34983 .253 Mtetra
.681 .708 .868 r
.34983 .253 .3574 .26306 .36987 .25714 .3623 .24758 Mtetra
.68 .72 .88 r
.3623 .24758 .36987 .25714 .38237 .25163 .37482 .24228 Mtetra
.679 .726 .885 r
.37482 .24228 .38237 .25163 .39491 .24628 .38739 .23701 Mtetra
.679 .729 .887 r
.38739 .23701 .39491 .24628 .4075 .24096 .40002 .23173 Mtetra
.679 .73 .889 r
.40002 .23173 .4075 .24096 .42014 .23565 .41269 .22645 Mtetra
.679 .732 .89 r
.41269 .22645 .42014 .23565 .43283 .23035 .42542 .22116 Mtetra
.678 .733 .892 r
.42542 .22116 .43283 .23035 .44558 .22505 .43821 .21588 Mtetra
.677 .734 .893 r
.43821 .21588 .44558 .22505 .45839 .21977 .45105 .21062 Mtetra
.676 .735 .895 r
.45105 .21062 .45839 .21977 .47125 .21452 .46394 .20538 Mtetra
.675 .736 .897 r
.46394 .20538 .47125 .21452 .48416 .2093 .4769 .20017 Mtetra
.674 .737 .898 r
.4769 .20017 .48416 .2093 .49713 .20411 .4899 .19498 Mtetra
.673 .738 .9 r
.4899 .19498 .49713 .20411 .51016 .19895 .50297 .18982 Mtetra
.671 .739 .901 r
.50297 .18982 .51016 .19895 .52325 .19381 .5161 .18468 Mtetra
.67 .739 .902 r
.5161 .18468 .52325 .19381 .53639 .1887 .52929 .17956 Mtetra
.669 .74 .903 r
.52929 .17956 .53639 .1887 .5496 .18362 .54254 .17446 Mtetra
.668 .74 .904 r
.54254 .17446 .5496 .18362 .56287 .17854 .55585 .16937 Mtetra
.667 .74 .905 r
.55585 .16937 .56287 .17854 .57621 .17348 .56923 .16428 Mtetra
.667 .741 .905 r
.56923 .16428 .57621 .17348 .5896 .16842 .58267 .1592 Mtetra
.666 .741 .906 r
.58267 .1592 .5896 .16842 .60307 .16337 .59618 .15411 Mtetra
.665 .741 .906 r
.59618 .15411 .60307 .16337 .61659 .15831 .60975 .14902 Mtetra
.665 .741 .907 r
.60975 .14902 .61659 .15831 .63018 .15325 .62338 .14391 Mtetra
.62338 .14391 .63018 .15325 .64384 .14817 .63709 .1388 Mtetra
.664 .741 .907 r
.63709 .1388 .64384 .14817 .65757 .14308 .65086 .13367 Mtetra
.65086 .13367 .65757 .14308 .67136 .13798 .6647 .12852 Mtetra
.664 .741 .908 r
.6647 .12852 .67136 .13798 .68522 .13285 .67861 .12335 Mtetra
.67861 .12335 .68522 .13285 .69915 .12771 .69258 .11816 Mtetra
.69258 .11816 .69915 .12771 .71315 .12254 .70663 .11295 Mtetra
.70663 .11295 .71315 .12254 .72722 .11735 .72074 .10772 Mtetra
.72074 .10772 .72722 .11735 .74135 .11214 .73493 .10246 Mtetra
.73493 .10246 .74135 .11214 .75556 .10691 .74919 .09717 Mtetra
.647 .732 .911 r
.10515 .32769 .11347 .33563 .12473 .33196 .11645 .32394 Mtetra
.644 .731 .912 r
.11645 .32394 .12473 .33196 .13605 .3283 .12779 .32024 Mtetra
.617 .722 .921 r
.12779 .32024 .13605 .3283 .14741 .32469 .1391 .31725 Mtetra
.061 .464 .885 r
.1391 .31725 .14741 .32469 .15875 .32173 .14963 .32126 Mtetra
.898 .538 .35 r
.14963 .32126 .15875 .32173 .16939 .3255 .15671 .356 Mtetra
.84 .542 .484 r
.15671 .356 .16939 .3255 .17678 .35994 .15912 .43525 Mtetra
.677 .392 .481 r
.15912 .43525 .17678 .35994 .17946 .442 .16623 .47727 Mtetra
.931 .86 .427 r
.16623 .47727 .17946 .442 .18623 .49067 .18503 .41166 Mtetra
.776 .54 .578 r
.18503 .41166 .18623 .49067 .20461 .42598 .20498 .33103 Mtetra
.653 .433 .573 r
.20498 .33103 .20461 .42598 .22457 .3406 .21976 .29802 Mtetra
.602 .435 .629 r
.21976 .29802 .22457 .3406 .23945 .30495 .23198 .29051 Mtetra
.6 .59 .813 r
.23198 .29051 .23945 .30495 .2517 .29735 .2438 .28777 Mtetra
.621 .693 .896 r
.2438 .28777 .2517 .29735 .26353 .295 .25574 .28453 Mtetra
.663 .689 .864 r
.25574 .28453 .26353 .295 .27551 .29176 .26785 .27982 Mtetra
.687 .67 .828 r
.26785 .27982 .27551 .29176 .2877 .28656 .28013 .27375 Mtetra
.694 .659 .811 r
.28013 .27375 .2877 .28656 .30006 .27972 .2925 .26703 Mtetra
.692 .661 .815 r
.2925 .26703 .30006 .27972 .3125 .27226 .3049 .26044 Mtetra
.687 .674 .832 r
.3049 .26044 .3125 .27226 .32494 .26515 .3173 .25435 Mtetra
.682 .693 .854 r
.3173 .25435 .32494 .26515 .33738 .25877 .32972 .24875 Mtetra
.679 .709 .871 r
.32972 .24875 .33738 .25877 .34983 .253 .34217 .24341 Mtetra
.677 .719 .881 r
.34217 .24341 .34983 .253 .3623 .24758 .35467 .23818 Mtetra
.677 .725 .885 r
.35467 .23818 .3623 .24758 .37482 .24228 .36721 .23296 Mtetra
.678 .727 .887 r
.36721 .23296 .37482 .24228 .38739 .23701 .37981 .22772 Mtetra
.678 .729 .889 r
.37981 .22772 .38739 .23701 .40002 .23173 .39247 .22246 Mtetra
.678 .731 .89 r
.39247 .22246 .40002 .23173 .41269 .22645 .40518 .21719 Mtetra
.677 .732 .892 r
.40518 .21719 .41269 .22645 .42542 .22116 .41795 .21192 Mtetra
.677 .733 .893 r
.41795 .21192 .42542 .22116 .43821 .21588 .43077 .20667 Mtetra
.676 .735 .895 r
.43077 .20667 .43821 .21588 .45105 .21062 .44364 .20142 Mtetra
.675 .736 .896 r
.44364 .20142 .45105 .21062 .46394 .20538 .45658 .19619 Mtetra
.674 .737 .898 r
.45658 .19619 .46394 .20538 .4769 .20017 .46957 .19099 Mtetra
.673 .737 .899 r
.46957 .19099 .4769 .20017 .4899 .19498 .48262 .1858 Mtetra
.671 .738 .9 r
.48262 .1858 .4899 .19498 .50297 .18982 .49572 .18064 Mtetra
.67 .739 .902 r
.49572 .18064 .50297 .18982 .5161 .18468 .50889 .17549 Mtetra
.669 .739 .903 r
.50889 .17549 .5161 .18468 .52929 .17956 .52212 .17036 Mtetra
.668 .74 .904 r
.52212 .17036 .52929 .17956 .54254 .17446 .53541 .16523 Mtetra
.667 .74 .904 r
.53541 .16523 .54254 .17446 .55585 .16937 .54877 .16012 Mtetra
.667 .74 .905 r
.54877 .16012 .55585 .16937 .56923 .16428 .56219 .155 Mtetra
.666 .741 .906 r
.56219 .155 .56923 .16428 .58267 .1592 .57567 .14989 Mtetra
.57567 .14989 .58267 .1592 .59618 .15411 .58922 .14477 Mtetra
.665 .741 .907 r
.58922 .14477 .59618 .15411 .60975 .14902 .60284 .13964 Mtetra
.60284 .13964 .60975 .14902 .62338 .14391 .61652 .1345 Mtetra
.664 .741 .907 r
.61652 .1345 .62338 .14391 .63709 .1388 .63027 .12935 Mtetra
.63027 .12935 .63709 .1388 .65086 .13367 .64409 .12417 Mtetra
.664 .741 .908 r
.64409 .12417 .65086 .13367 .6647 .12852 .65797 .11898 Mtetra
.65797 .11898 .6647 .12852 .67861 .12335 .67193 .11377 Mtetra
.67193 .11377 .67861 .12335 .69258 .11816 .68595 .10853 Mtetra
.68595 .10853 .69258 .11816 .70663 .11295 .70005 .10328 Mtetra
.70005 .10328 .70663 .11295 .72074 .10772 .71421 .09799 Mtetra
.71421 .09799 .72074 .10772 .73493 .10246 .72844 .09269 Mtetra
.72844 .09269 .73493 .10246 .74919 .09717 .74275 .08735 Mtetra
.647 .732 .911 r
.09677 .31968 .10515 .32769 .11645 .32394 .10809 .31589 Mtetra
.618 .723 .922 r
.10809 .31589 .11645 .32394 .12779 .32024 .11937 .31286 Mtetra
.032 .448 .874 r
.11937 .31286 .12779 .32024 .1391 .31725 .1298 .31701 Mtetra
.896 .536 .354 r
.1298 .31701 .1391 .31725 .14963 .32126 .13664 .35143 Mtetra
.836 .537 .483 r
.13664 .35143 .14963 .32126 .15671 .356 .13896 .42665 Mtetra
.663 .375 .473 r
.13896 .42665 .15671 .356 .15912 .43525 .14651 .46177 Mtetra
.987 .871 .516 r
.14651 .46177 .15912 .43525 .16623 .47727 .1656 .39661 Mtetra
.765 .53 .579 r
.1656 .39661 .16623 .47727 .18503 .41166 .18536 .32164 Mtetra
.649 .431 .574 r
.18536 .32164 .18503 .41166 .20498 .33103 .19998 .29151 Mtetra
.605 .444 .637 r
.19998 .29151 .20498 .33103 .21976 .29802 .21217 .2842 Mtetra
.609 .605 .821 r
.21217 .2842 .21976 .29802 .23198 .29051 .22399 .28111 Mtetra
.623 .699 .899 r
.22399 .28111 .23198 .29051 .2438 .28777 .23588 .27779 Mtetra
.655 .698 .877 r
.23588 .27779 .2438 .28777 .25574 .28453 .24794 .27339 Mtetra
.678 .682 .847 r
.24794 .27339 .25574 .28453 .26785 .27982 .26014 .2679 Mtetra
.687 .672 .829 r
.26014 .2679 .26785 .27982 .28013 .27375 .27244 .26178 Mtetra
.27244 .26178 .28013 .27375 .2925 .26703 .28479 .25564 Mtetra
.683 .681 .842 r
.28479 .25564 .2925 .26703 .3049 .26044 .29716 .24984 Mtetra
.679 .696 .859 r
.29716 .24984 .3049 .26044 .3173 .25435 .30954 .24438 Mtetra
.676 .71 .874 r
.30954 .24438 .3173 .25435 .32972 .24875 .32197 .23914 Mtetra
.675 .719 .882 r
.32197 .23914 .32972 .24875 .34217 .24341 .33444 .23398 Mtetra
.675 .724 .886 r
.33444 .23398 .34217 .24341 .35467 .23818 .34696 .22881 Mtetra
.676 .727 .888 r
.34696 .22881 .35467 .23818 .36721 .23296 .35954 .22361 Mtetra
.676 .728 .889 r
.35954 .22361 .36721 .23296 .37981 .22772 .37217 .21839 Mtetra
.676 .73 .89 r
.37217 .21839 .37981 .22772 .39247 .22246 .38486 .21315 Mtetra
.676 .731 .892 r
.38486 .21315 .39247 .22246 .40518 .21719 .39761 .2079 Mtetra
.676 .733 .893 r
.39761 .2079 .40518 .21719 .41795 .21192 .41041 .20265 Mtetra
.675 .734 .894 r
.41041 .20265 .41795 .21192 .43077 .20667 .42326 .1974 Mtetra
.674 .735 .896 r
.42326 .1974 .43077 .20667 .44364 .20142 .43618 .19217 Mtetra
.673 .736 .897 r
.43618 .19217 .44364 .20142 .45658 .19619 .44915 .18695 Mtetra
.672 .737 .899 r
.44915 .18695 .45658 .19619 .46957 .19099 .46218 .18175 Mtetra
.671 .738 .9 r
.46218 .18175 .46957 .19099 .48262 .1858 .47526 .17656 Mtetra
.67 .738 .901 r
.47526 .17656 .48262 .1858 .49572 .18064 .48841 .17139 Mtetra
.669 .739 .902 r
.48841 .17139 .49572 .18064 .50889 .17549 .50162 .16623 Mtetra
.668 .739 .903 r
.50162 .16623 .50889 .17549 .52212 .17036 .51489 .16108 Mtetra
.668 .74 .904 r
.51489 .16108 .52212 .17036 .53541 .16523 .52823 .15594 Mtetra
.667 .74 .905 r
.52823 .15594 .53541 .16523 .54877 .16012 .54162 .15079 Mtetra
.666 .74 .906 r
.54162 .15079 .54877 .16012 .56219 .155 .55509 .14565 Mtetra
.666 .741 .906 r
.55509 .14565 .56219 .155 .57567 .14989 .56861 .14051 Mtetra
.665 .741 .906 r
.56861 .14051 .57567 .14989 .58922 .14477 .58221 .13535 Mtetra
.665 .741 .907 r
.58221 .13535 .58922 .14477 .60284 .13964 .59587 .13018 Mtetra
.59587 .13018 .60284 .13964 .61652 .1345 .6096 .125 Mtetra
.664 .741 .907 r
.6096 .125 .61652 .1345 .63027 .12935 .62339 .11981 Mtetra
.62339 .11981 .63027 .12935 .64409 .12417 .63725 .11459 Mtetra
.664 .741 .908 r
.63725 .11459 .64409 .12417 .65797 .11898 .65119 .10935 Mtetra
.65119 .10935 .65797 .11898 .67193 .11377 .66519 .1041 Mtetra
.66519 .1041 .67193 .11377 .68595 .10853 .67926 .09881 Mtetra
.67926 .09881 .68595 .10853 .70005 .10328 .6934 .09351 Mtetra
.6934 .09351 .70005 .10328 .71421 .09799 .70762 .08818 Mtetra
.70762 .08818 .71421 .09799 .72844 .09269 .7219 .08282 Mtetra
.7219 .08282 .72844 .09269 .74275 .08735 .73626 .07744 Mtetra
.619 .725 .922 r
.08831 .31163 .09677 .31968 .10809 .31589 .09956 .30855 Mtetra
.016 .441 .868 r
.09956 .30855 .10809 .31589 .11937 .31286 .10991 .31272 Mtetra
.893 .533 .354 r
.10991 .31272 .11937 .31286 .1298 .31701 .11658 .34625 Mtetra
.832 .531 .48 r
.11658 .34625 .1298 .31701 .13664 .35143 .11898 .41638 Mtetra
.648 .356 .463 r
.11898 .41638 .13664 .35143 .13896 .42665 .12707 .44465 Mtetra
.997 .851 .57 r
.12707 .44465 .13896 .42665 .14651 .46177 .14628 .38118 Mtetra
.755 .522 .579 r
.14628 .38118 .14651 .46177 .1656 .39661 .16571 .31252 Mtetra
.645 .43 .577 r
.16571 .31252 .1656 .39661 .18536 .32164 .18013 .28538 Mtetra
.608 .453 .646 r
.18013 .28538 .18536 .32164 .19998 .29151 .19227 .27834 Mtetra
.618 .62 .83 r
.19227 .27834 .19998 .29151 .21217 .2842 .20407 .27495 Mtetra
.627 .705 .902 r
.20407 .27495 .21217 .2842 .22399 .28111 .21594 .27149 Mtetra
.651 .705 .887 r
.21594 .27149 .22399 .28111 .23588 .27779 .22795 .26726 Mtetra
.671 .693 .862 r
.22795 .26726 .23588 .27779 .24794 .27339 .24009 .26219 Mtetra
.681 .683 .846 r
.24009 .26219 .24794 .27339 .26014 .2679 .25233 .25655 Mtetra
.682 .682 .843 r
.25233 .25655 .26014 .2679 .27244 .26178 .26462 .2508 Mtetra
.679 .689 .852 r
.26462 .2508 .27244 .26178 .28479 .25564 .27695 .24524 Mtetra
.676 .7 .865 r
.27695 .24524 .28479 .25564 .29716 .24984 .2893 .23993 Mtetra
.674 .711 .877 r
.2893 .23993 .29716 .24984 .30954 .24438 .30169 .23478 Mtetra
.673 .719 .884 r
.30169 .23478 .30954 .24438 .32197 .23914 .31414 .22968 Mtetra
.673 .724 .887 r
.31414 .22968 .32197 .23914 .33444 .23398 .32663 .22457 Mtetra
.674 .726 .889 r
.32663 .22457 .33444 .23398 .34696 .22881 .33919 .21943 Mtetra
.675 .728 .89 r
.33919 .21943 .34696 .22881 .35954 .22361 .3518 .21424 Mtetra
.675 .729 .891 r
.3518 .21424 .35954 .22361 .37217 .21839 .36446 .20903 Mtetra
.675 .73 .892 r
.36446 .20903 .37217 .21839 .38486 .21315 .37719 .2038 Mtetra
.675 .732 .893 r
.37719 .2038 .38486 .21315 .39761 .2079 .38997 .19857 Mtetra
.674 .733 .894 r
.38997 .19857 .39761 .2079 .41041 .20265 .4028 .19333 Mtetra
.674 .734 .896 r
.4028 .19333 .41041 .20265 .42326 .1974 .41569 .18809 Mtetra
.673 .735 .897 r
.41569 .18809 .42326 .1974 .43618 .19217 .42864 .18287 Mtetra
.672 .736 .898 r
.42864 .18287 .43618 .19217 .44915 .18695 .44165 .17765 Mtetra
.671 .737 .9 r
.44165 .17765 .44915 .18695 .46218 .18175 .45472 .17245 Mtetra
.67 .738 .901 r
.45472 .17245 .46218 .18175 .47526 .17656 .46785 .16726 Mtetra
.669 .739 .902 r
.46785 .16726 .47526 .17656 .48841 .17139 .48103 .16207 Mtetra
.669 .739 .903 r
.48103 .16207 .48841 .17139 .50162 .16623 .49428 .1569 Mtetra
.668 .74 .904 r
.49428 .1569 .50162 .16623 .51489 .16108 .5076 .15173 Mtetra
.667 .74 .905 r
.5076 .15173 .51489 .16108 .52823 .15594 .52097 .14656 Mtetra
.666 .74 .905 r
.52097 .14656 .52823 .15594 .54162 .15079 .53441 .1414 Mtetra
.666 .741 .906 r
.53441 .1414 .54162 .15079 .55509 .14565 .54792 .13622 Mtetra
.665 .741 .906 r
.54792 .13622 .55509 .14565 .56861 .14051 .56149 .13104 Mtetra
.665 .741 .907 r
.56149 .13104 .56861 .14051 .58221 .13535 .57513 .12585 Mtetra
.57513 .12585 .58221 .13535 .59587 .13018 .58883 .12064 Mtetra
.664 .741 .907 r
.58883 .12064 .59587 .13018 .6096 .125 .60261 .11542 Mtetra
.60261 .11542 .6096 .125 .62339 .11981 .61645 .11018 Mtetra
.664 .741 .908 r
.61645 .11018 .62339 .11981 .63725 .11459 .63036 .10492 Mtetra
.63036 .10492 .63725 .11459 .65119 .10935 .64434 .09964 Mtetra
.64434 .09964 .65119 .10935 .66519 .1041 .65839 .09433 Mtetra
.65839 .09433 .66519 .1041 .67926 .09881 .67251 .08901 Mtetra
.67251 .08901 .67926 .09881 .6934 .09351 .6867 .08365 Mtetra
.6867 .08365 .6934 .09351 .70762 .08818 .70096 .07827 Mtetra
.70096 .07827 .70762 .08818 .7219 .08282 .71529 .07287 Mtetra
.71529 .07287 .7219 .08282 .73626 .07744 .7297 .06744 Mtetra
.015 .443 .868 r
.07967 .30431 .08831 .31163 .09956 .30855 .08995 .30839 Mtetra
.89 .527 .35 r
.08995 .30839 .09956 .30855 .10991 .31272 .09654 .34048 Mtetra
.828 .524 .477 r
.09654 .34048 .10991 .31272 .11658 .34625 .0992 .40471 Mtetra
.629 .333 .449 r
.0992 .40471 .11658 .34625 .11898 .41638 .10785 .42644 Mtetra
.983 .818 .601 r
.10785 .42644 .11898 .41638 .12707 .44465 .12703 .36573 Mtetra
.745 .514 .581 r
.12703 .36573 .12707 .44465 .14628 .38118 .14601 .30374 Mtetra
.642 .43 .58 r
.14601 .30374 .14628 .38118 .16571 .31252 .16018 .27958 Mtetra
.612 .465 .659 r
.16018 .27958 .16571 .31252 .18013 .28538 .17228 .27284 Mtetra
.626 .635 .839 r
.17228 .27284 .18013 .28538 .19227 .27834 .18407 .26919 Mtetra
.632 .71 .903 r
.18407 .26919 .19227 .27834 .20407 .27495 .19592 .26557 Mtetra
.648 .711 .893 r
.19592 .26557 .20407 .27495 .21594 .27149 .20788 .26143 Mtetra
.665 .702 .874 r
.20788 .26143 .21594 .27149 .22795 .26726 .21996 .25664 Mtetra
.675 .693 .86 r
.21996 .25664 .22795 .26726 .24009 .26219 .23214 .25136 Mtetra
.677 .691 .856 r
.23214 .25136 .24009 .26219 .25233 .25655 .24438 .24593 Mtetra
.676 .696 .861 r
.24438 .24593 .25233 .25655 .26462 .2508 .25667 .24059 Mtetra
.673 .704 .871 r
.25667 .24059 .26462 .2508 .27695 .24524 .26899 .23541 Mtetra
.671 .713 .88 r
.26899 .23541 .27695 .24524 .2893 .23993 .28135 .23035 Mtetra
.671 .72 .886 r
.28135 .23035 .2893 .23993 .30169 .23478 .29376 .22531 Mtetra
.671 .724 .888 r
.29376 .22531 .30169 .23478 .31414 .22968 .30623 .22026 Mtetra
.672 .726 .89 r
.30623 .22026 .31414 .22968 .32663 .22457 .31876 .21516 Mtetra
.673 .727 .891 r
.31876 .21516 .32663 .22457 .33919 .21943 .33135 .21002 Mtetra
.673 .729 .891 r
.33135 .21002 .33919 .21943 .3518 .21424 .34399 .20484 Mtetra
.674 .73 .892 r
.34399 .20484 .3518 .21424 .36446 .20903 .35669 .19964 Mtetra
.674 .731 .893 r
.35669 .19964 .36446 .20903 .37719 .2038 .36944 .19443 Mtetra
.673 .732 .894 r
.36944 .19443 .37719 .2038 .38997 .19857 .38226 .1892 Mtetra
.673 .734 .896 r
.38226 .1892 .38997 .19857 .4028 .19333 .39513 .18397 Mtetra
.672 .735 .897 r
.39513 .18397 .4028 .19333 .41569 .18809 .40806 .17874 Mtetra
.672 .736 .898 r
.40806 .17874 .41569 .18809 .42864 .18287 .42104 .17352 Mtetra
.671 .737 .899 r
.42104 .17352 .42864 .18287 .44165 .17765 .43409 .1683 Mtetra
.67 .737 .901 r
.43409 .1683 .44165 .17765 .45472 .17245 .4472 .16309 Mtetra
.669 .738 .902 r
.4472 .16309 .45472 .17245 .46785 .16726 .46036 .15789 Mtetra
.669 .739 .903 r
.46036 .15789 .46785 .16726 .48103 .16207 .47359 .1527 Mtetra
.668 .739 .904 r
.47359 .1527 .48103 .16207 .49428 .1569 .48688 .1475 Mtetra
.667 .74 .904 r
.48688 .1475 .49428 .1569 .5076 .15173 .50024 .14231 Mtetra
.667 .74 .905 r
.50024 .14231 .5076 .15173 .52097 .14656 .51366 .13712 Mtetra
.666 .74 .906 r
.51366 .13712 .52097 .14656 .53441 .1414 .52714 .13192 Mtetra
.665 .741 .906 r
.52714 .13192 .53441 .1414 .54792 .13622 .54069 .12671 Mtetra
.665 .741 .907 r
.54069 .12671 .54792 .13622 .56149 .13104 .5543 .1215 Mtetra
.5543 .1215 .56149 .13104 .57513 .12585 .56799 .11627 Mtetra
.664 .741 .907 r
.56799 .11627 .57513 .12585 .58883 .12064 .58174 .11102 Mtetra
.58174 .11102 .58883 .12064 .60261 .11542 .59555 .10576 Mtetra
.59555 .10576 .60261 .11542 .61645 .11018 .60944 .10047 Mtetra
.664 .741 .908 r
.60944 .10047 .61645 .11018 .63036 .10492 .6234 .09517 Mtetra
.6234 .09517 .63036 .10492 .64434 .09964 .63743 .08984 Mtetra
.63743 .08984 .64434 .09964 .65839 .09433 .65152 .08448 Mtetra
.65152 .08448 .65839 .09433 .67251 .08901 .66569 .07911 Mtetra
.66569 .07911 .67251 .08901 .6867 .08365 .67993 .0737 Mtetra
.67993 .0737 .6867 .08365 .70096 .07827 .69424 .06828 Mtetra
.69424 .06828 .70096 .07827 .71529 .07287 .70863 .06282 Mtetra
.70863 .06282 .71529 .07287 .7297 .06744 .72309 .05734 Mtetra
.886 .519 .341 r
.06993 .30401 .07967 .30431 .08995 .30839 .07652 .3342 Mtetra
.823 .516 .471 r
.07652 .3342 .08995 .30839 .09654 .34048 .07959 .39195 Mtetra
.607 .304 .43 r
.07959 .39195 .09654 .34048 .0992 .40471 .08882 .40764 Mtetra
.961 .785 .62 r
.08882 .40764 .0992 .40471 .10785 .42644 .10781 .35058 Mtetra
.736 .508 .583 r
.10781 .35058 .10785 .42644 .12703 .36573 .12624 .29536 Mtetra
.639 .431 .585 r
.12624 .29536 .12703 .36573 .14601 .30374 .14015 .27405 Mtetra
.616 .48 .673 r
.14015 .27405 .14601 .30374 .16018 .27958 .15219 .26764 Mtetra
.633 .65 .849 r
.15219 .26764 .16018 .27958 .17228 .27284 .16397 .26378 Mtetra
.637 .715 .904 r
.16397 .26378 .17228 .27284 .18407 .26919 .1758 .26 Mtetra
.648 .716 .898 r
.1758 .26 .18407 .26919 .19592 .26557 .18772 .25587 Mtetra
.661 .709 .883 r
.18772 .25587 .19592 .26557 .20788 .26143 .19975 .25126 Mtetra
.67 .702 .871 r
.19975 .25126 .20788 .26143 .21996 .25664 .21188 .24625 Mtetra
.673 .699 .867 r
.21188 .24625 .21996 .25664 .23214 .25136 .22407 .24107 Mtetra
.672 .702 .869 r
.22407 .24107 .23214 .25136 .24438 .24593 .23632 .23591 Mtetra
.67 .708 .876 r
.23632 .23591 .24438 .24593 .25667 .24059 .2486 .23085 Mtetra
.669 .715 .883 r
.2486 .23085 .25667 .24059 .26899 .23541 .26093 .22586 Mtetra
.669 .721 .888 r
.26093 .22586 .26899 .23541 .28135 .23035 .27332 .22088 Mtetra
.669 .724 .89 r
.27332 .22088 .28135 .23035 .29376 .22531 .28576 .21588 Mtetra
.67 .726 .891 r
.28576 .21588 .29376 .22531 .30623 .22026 .29826 .21083 Mtetra
.671 .727 .892 r
.29826 .21083 .30623 .22026 .31876 .21516 .31082 .20573 Mtetra
.672 .728 .892 r
.31082 .20573 .31876 .21516 .33135 .21002 .32344 .20059 Mtetra
.672 .73 .893 r
.32344 .20059 .33135 .21002 .34399 .20484 .33611 .19542 Mtetra
.672 .731 .894 r
.33611 .19542 .34399 .20484 .35669 .19964 .34884 .19022 Mtetra
.672 .732 .895 r
.34884 .19022 .35669 .19964 .36944 .19443 .36163 .18501 Mtetra
.672 .733 .896 r
.36163 .18501 .36944 .19443 .38226 .1892 .37448 .17979 Mtetra
.672 .734 .897 r
.37448 .17979 .38226 .1892 .39513 .18397 .38739 .17457 Mtetra
.671 .735 .898 r
.38739 .17457 .39513 .18397 .40806 .17874 .40035 .16934 Mtetra
.671 .736 .899 r
.40035 .16934 .40806 .17874 .42104 .17352 .41338 .16412 Mtetra
.67 .737 .9 r
.41338 .16412 .42104 .17352 .43409 .1683 .42646 .1589 Mtetra
.669 .738 .902 r
.42646 .1589 .43409 .1683 .4472 .16309 .43961 .15368 Mtetra
.668 .738 .903 r
.43961 .15368 .4472 .16309 .46036 .15789 .45281 .14846 Mtetra
.668 .739 .903 r
.45281 .14846 .46036 .15789 .47359 .1527 .46608 .14325 Mtetra
.667 .739 .904 r
.46608 .14325 .47359 .1527 .48688 .1475 .47941 .13804 Mtetra
.667 .74 .905 r
.47941 .13804 .48688 .1475 .50024 .14231 .49281 .13282 Mtetra
.666 .74 .905 r
.49281 .13282 .50024 .14231 .51366 .13712 .50627 .1276 Mtetra
.666 .74 .906 r
.50627 .1276 .51366 .13712 .52714 .13192 .5198 .12237 Mtetra
.665 .741 .906 r
.5198 .12237 .52714 .13192 .54069 .12671 .53339 .11713 Mtetra
.665 .741 .907 r
.53339 .11713 .54069 .12671 .5543 .1215 .54705 .11187 Mtetra
.54705 .11187 .5543 .1215 .56799 .11627 .56078 .1066 Mtetra
.664 .741 .907 r
.56078 .1066 .56799 .11627 .58174 .11102 .57457 .10131 Mtetra
.57457 .10131 .58174 .11102 .59555 .10576 .58844 .096 Mtetra
.664 .741 .908 r
.58844 .096 .59555 .10576 .60944 .10047 .60237 .09067 Mtetra
.60237 .09067 .60944 .10047 .6234 .09517 .61638 .08532 Mtetra
.61638 .08532 .6234 .09517 .63743 .08984 .63045 .07994 Mtetra
.63045 .07994 .63743 .08984 .65152 .08448 .6446 .07454 Mtetra
.6446 .07454 .65152 .08448 .66569 .07911 .65881 .06912 Mtetra
.65881 .06912 .66569 .07911 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06828 .68746 .05818 Mtetra
.68746 .05818 .69424 .06828 .70863 .06282 .7019 .05268 Mtetra
.7019 .05268 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.818 .507 .463 r
.05652 .32747 .06993 .30401 .07652 .3342 .06012 .37843 Mtetra
.579 .267 .404 r
.06012 .37843 .07652 .3342 .07959 .39195 .06992 .38876 Mtetra
.936 .754 .632 r
.06992 .38876 .07959 .39195 .08882 .40764 .08859 .33597 Mtetra
.727 .503 .586 r
.08859 .33597 .08882 .40764 .10781 .35058 .1064 .28742 Mtetra
.637 .435 .592 r
.1064 .28742 .10781 .35058 .12624 .29536 .12003 .26878 Mtetra
.62 .496 .69 r
.12003 .26878 .12624 .29536 .14015 .27405 .13201 .26267 Mtetra
.639 .664 .858 r
.13201 .26267 .14015 .27405 .15219 .26764 .14377 .25865 Mtetra
.642 .719 .904 r
.14377 .25865 .15219 .26764 .16397 .26378 .15558 .25472 Mtetra
.649 .72 .901 r
.15558 .25472 .16397 .26378 .1758 .26 .16748 .25056 Mtetra
.658 .715 .89 r
.16748 .25056 .1758 .26 .18772 .25587 .17947 .24606 Mtetra
.666 .71 .881 r
.17947 .24606 .18772 .25587 .19975 .25126 .19155 .24123 Mtetra
.669 .707 .876 r
.19155 .24123 .19975 .25126 .21188 .24625 .20369 .23624 Mtetra
.669 .708 .877 r
.20369 .23624 .21188 .24625 .22407 .24107 .2159 .23122 Mtetra
.668 .712 .881 r
.2159 .23122 .22407 .24107 .23632 .23591 .22815 .22626 Mtetra
.667 .718 .886 r
.22815 .22626 .23632 .23591 .2486 .23085 .24045 .22133 Mtetra
.667 .722 .89 r
.24045 .22133 .2486 .23085 .26093 .22586 .2528 .21641 Mtetra
.668 .725 .892 r
.2528 .21641 .26093 .22586 .27332 .22088 .26521 .21145 Mtetra
.669 .726 .892 r
.26521 .21145 .27332 .22088 .28576 .21588 .27769 .20644 Mtetra
.67 .727 .893 r
.27769 .20644 .28576 .21588 .29826 .21083 .29022 .20138 Mtetra
.67 .728 .893 r
.29022 .20138 .29826 .21083 .31082 .20573 .30281 .19628 Mtetra
.671 .73 .894 r
.30281 .19628 .31082 .20573 .32344 .20059 .31546 .19114 Mtetra
.671 .731 .895 r
.31546 .19114 .32344 .20059 .33611 .19542 .32816 .18597 Mtetra
.671 .732 .895 r
.32816 .18597 .33611 .19542 .34884 .19022 .34093 .18078 Mtetra
.671 .733 .896 r
.34093 .18078 .34884 .19022 .36163 .18501 .35375 .17557 Mtetra
.671 .734 .897 r
.35375 .17557 .36163 .18501 .37448 .17979 .36664 .17035 Mtetra
.671 .735 .898 r
.36664 .17035 .37448 .17979 .38739 .17457 .37958 .16512 Mtetra
.67 .736 .899 r
.37958 .16512 .38739 .17457 .40035 .16934 .39258 .1599 Mtetra
.67 .737 .9 r
.39258 .1599 .40035 .16934 .41338 .16412 .40564 .15467 Mtetra
.669 .737 .901 r
.40564 .15467 .41338 .16412 .42646 .1589 .41876 .14944 Mtetra
.668 .738 .902 r
.41876 .14944 .42646 .1589 .43961 .15368 .43195 .14421 Mtetra
.668 .739 .903 r
.43195 .14421 .43961 .15368 .45281 .14846 .44519 .13897 Mtetra
.667 .739 .904 r
.44519 .13897 .45281 .14846 .46608 .14325 .4585 .13374 Mtetra
.667 .74 .905 r
.4585 .13374 .46608 .14325 .47941 .13804 .47188 .1285 Mtetra
.666 .74 .905 r
.47188 .1285 .47941 .13804 .49281 .13282 .48532 .12325 Mtetra
.666 .74 .906 r
.48532 .12325 .49281 .13282 .50627 .1276 .49882 .118 Mtetra
.665 .741 .906 r
.49882 .118 .50627 .1276 .5198 .12237 .51239 .11273 Mtetra
.665 .741 .907 r
.51239 .11273 .5198 .12237 .53339 .11713 .52603 .10745 Mtetra
.52603 .10745 .53339 .11713 .54705 .11187 .53973 .10216 Mtetra
.664 .741 .907 r
.53973 .10216 .54705 .11187 .56078 .1066 .5535 .09685 Mtetra
.5535 .09685 .56078 .1066 .57457 .10131 .56734 .09151 Mtetra
.56734 .09151 .57457 .10131 .58844 .096 .58125 .08616 Mtetra
.664 .741 .908 r
.58125 .08616 .58844 .096 .60237 .09067 .59524 .08078 Mtetra
.59524 .08078 .60237 .09067 .61638 .08532 .60929 .07538 Mtetra
.60929 .07538 .61638 .08532 .63045 .07994 .62341 .06996 Mtetra
.62341 .06996 .63045 .07994 .6446 .07454 .6376 .06451 Mtetra
.6376 .06451 .6446 .07454 .65881 .06912 .65187 .05903 Mtetra
.65187 .05903 .65881 .06912 .6731 .06366 .66621 .05353 Mtetra
.66621 .05353 .6731 .06366 .68746 .05818 .68062 .048 Mtetra
.68062 .048 .68746 .05818 .7019 .05268 .6951 .04244 Mtetra
.6951 .04244 .7019 .05268 .71641 .04714 .70966 .03685 Mtetra
.543 .217 .366 r
.04076 .3645 .05652 .32747 .06012 .37843 .05108 .37021 Mtetra
.911 .727 .64 r
.05108 .37021 .06012 .37843 .06992 .38876 .06932 .32213 Mtetra
.72 .499 .59 r
.06932 .32213 .06992 .38876 .08859 .33597 .08646 .27995 Mtetra
.635 .44 .601 r
.08646 .27995 .08859 .33597 .1064 .28742 .09981 .26372 Mtetra
.625 .516 .709 r
.09981 .26372 .1064 .28742 .12003 .26878 .11174 .2579 Mtetra
.644 .676 .866 r
.11174 .2579 .12003 .26878 .13201 .26267 .12349 .25375 Mtetra
.646 .723 .905 r
.12349 .25375 .13201 .26267 .14377 .25865 .13528 .24968 Mtetra
.65 .724 .903 r
.13528 .24968 .14377 .25865 .15558 .25472 .14714 .24547 Mtetra
.657 .72 .895 r
.14714 .24547 .15558 .25472 .16748 .25056 .1591 .24102 Mtetra
.663 .716 .888 r
.1591 .24102 .16748 .25056 .17947 .24606 .17113 .23631 Mtetra
.666 .713 .883 r
.17113 .23631 .17947 .24606 .19155 .24123 .18324 .23145 Mtetra
.667 .713 .883 r
.18324 .23145 .19155 .24123 .20369 .23624 .1954 .22655 Mtetra
.666 .716 .886 r
.1954 .22655 .20369 .23624 .2159 .23122 .20762 .22166 Mtetra
.665 .72 .89 r
.20762 .22166 .2159 .23122 .22815 .22626 .21989 .21679 Mtetra
.666 .723 .892 r
.21989 .21679 .22815 .22626 .24045 .22133 .23221 .2119 Mtetra
.666 .725 .893 r
.23221 .2119 .24045 .22133 .2528 .21641 .24459 .20698 Mtetra
.667 .727 .894 r
.24459 .20698 .2528 .21641 .26521 .21145 .25703 .20201 Mtetra
.668 .728 .894 r
.25703 .20201 .26521 .21145 .27769 .20644 .26954 .19699 Mtetra
.669 .729 .894 r
.26954 .19699 .27769 .20644 .29022 .20138 .2821 .19192 Mtetra
.669 .73 .895 r
.2821 .19192 .29022 .20138 .30281 .19628 .29472 .18681 Mtetra
.67 .731 .895 r
.29472 .18681 .30281 .19628 .31546 .19114 .3074 .18166 Mtetra
.67 .732 .896 r
.3074 .18166 .31546 .19114 .32816 .18597 .32014 .17649 Mtetra
.67 .733 .897 r
.32014 .17649 .32816 .18597 .34093 .18078 .33294 .1713 Mtetra
.67 .734 .898 r
.33294 .1713 .34093 .18078 .35375 .17557 .3458 .16609 Mtetra
.67 .735 .899 r
.3458 .16609 .35375 .17557 .36664 .17035 .35872 .16087 Mtetra
.67 .736 .9 r
.35872 .16087 .36664 .17035 .37958 .16512 .3717 .15564 Mtetra
.669 .736 .901 r
.3717 .15564 .37958 .16512 .39258 .1599 .38474 .1504 Mtetra
.669 .737 .901 r
.38474 .1504 .39258 .1599 .40564 .15467 .39784 .14516 Mtetra
.668 .738 .902 r
.39784 .14516 .40564 .15467 .41876 .14944 .411 .13992 Mtetra
.668 .739 .903 r
.411 .13992 .41876 .14944 .43195 .14421 .42422 .13467 Mtetra
.667 .739 .904 r
.42422 .13467 .43195 .14421 .44519 .13897 .43751 .12941 Mtetra
.667 .739 .905 r
.43751 .12941 .44519 .13897 .4585 .13374 .45086 .12416 Mtetra
.666 .74 .905 r
.45086 .12416 .4585 .13374 .47188 .1285 .46427 .11889 Mtetra
.666 .74 .906 r
.46427 .11889 .47188 .1285 .48532 .12325 .47775 .11361 Mtetra
.665 .74 .906 r
.47775 .11361 .48532 .12325 .49882 .118 .4913 .10832 Mtetra
.665 .741 .907 r
.4913 .10832 .49882 .118 .51239 .11273 .50491 .10302 Mtetra
.50491 .10302 .51239 .11273 .52603 .10745 .51859 .0977 Mtetra
.664 .741 .907 r
.51859 .0977 .52603 .10745 .53973 .10216 .53234 .09236 Mtetra
.53234 .09236 .53973 .10216 .5535 .09685 .54616 .08701 Mtetra
.54616 .08701 .5535 .09685 .56734 .09151 .56005 .08163 Mtetra
.664 .741 .908 r
.56005 .08163 .56734 .09151 .58125 .08616 .574 .07623 Mtetra
.574 .07623 .58125 .08616 .59524 .08078 .58803 .0708 Mtetra
.58803 .0708 .59524 .08078 .60929 .07538 .60213 .06535 Mtetra
.60213 .06535 .60929 .07538 .62341 .06996 .6163 .05988 Mtetra
.6163 .05988 .62341 .06996 .6376 .06451 .63054 .05438 Mtetra
.63054 .05438 .6376 .06451 .65187 .05903 .64486 .04885 Mtetra
.64486 .04885 .65187 .05903 .66621 .05353 .65925 .0433 Mtetra
.65925 .0433 .66621 .05353 .68062 .048 .67371 .03771 Mtetra
.67371 .03771 .68062 .048 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.888 .704 .648 r
.03225 .35237 .04076 .3645 .05108 .37021 .04996 .3092 Mtetra
.713 .496 .595 r
.04996 .3092 .05108 .37021 .06932 .32213 .06642 .27293 Mtetra
.635 .447 .611 r
.06642 .27293 .06932 .32213 .08646 .27995 .07951 .25887 Mtetra
.631 .537 .73 r
.07951 .25887 .08646 .27995 .09981 .26372 .09137 .25329 Mtetra
.648 .688 .874 r
.09137 .25329 .09981 .26372 .11174 .2579 .1031 .24903 Mtetra
.649 .726 .905 r
.1031 .24903 .11174 .2579 .12349 .25375 .11488 .24485 Mtetra
.652 .727 .904 r
.11488 .24485 .12349 .25375 .13528 .24968 .12672 .24058 Mtetra
.656 .724 .899 r
.12672 .24058 .13528 .24968 .14714 .24547 .13864 .23613 Mtetra
.661 .721 .893 r
.13864 .23613 .14714 .24547 .1591 .24102 .15064 .2315 Mtetra
.664 .718 .889 r
.15064 .2315 .1591 .24102 .17113 .23631 .1627 .22673 Mtetra
.665 .718 .889 r
.1627 .22673 .17113 .23631 .18324 .23145 .17483 .2219 Mtetra
.664 .72 .89 r
.17483 .2219 .18324 .23145 .1954 .22655 .18701 .21707 Mtetra
.664 .722 .892 r
.18701 .21707 .1954 .22655 .20762 .22166 .19925 .21224 Mtetra
.664 .725 .894 r
.19925 .21224 .20762 .22166 .21989 .21679 .21154 .20739 Mtetra
.665 .727 .895 r
.21154 .20739 .21989 .21679 .23221 .2119 .22389 .20249 Mtetra
.666 .728 .896 r
.22389 .20249 .23221 .2119 .24459 .20698 .23631 .19755 Mtetra
.667 .728 .896 r
.23631 .19755 .24459 .20698 .25703 .20201 .24878 .19256 Mtetra
.668 .729 .896 r
.24878 .19256 .25703 .20201 .26954 .19699 .26131 .18752 Mtetra
.668 .73 .896 r
.26131 .18752 .26954 .19699 .2821 .19192 .27391 .18244 Mtetra
.669 .731 .896 r
.27391 .18244 .2821 .19192 .29472 .18681 .28656 .17732 Mtetra
.669 .732 .897 r
.28656 .17732 .29472 .18681 .3074 .18166 .29928 .17216 Mtetra
.669 .733 .898 r
.29928 .17216 .3074 .18166 .32014 .17649 .31205 .16698 Mtetra
.669 .734 .898 r
.31205 .16698 .32014 .17649 .33294 .1713 .32488 .16178 Mtetra
.669 .735 .899 r
.32488 .16178 .33294 .1713 .3458 .16609 .33778 .15657 Mtetra
.669 .735 .9 r
.33778 .15657 .3458 .16609 .35872 .16087 .35073 .15134 Mtetra
.669 .736 .901 r
.35073 .15134 .35872 .16087 .3717 .15564 .36375 .1461 Mtetra
.668 .737 .902 r
.36375 .1461 .3717 .15564 .38474 .1504 .37682 .14085 Mtetra
.668 .738 .902 r
.37682 .14085 .38474 .1504 .39784 .14516 .38996 .1356 Mtetra
.667 .738 .903 r
.38996 .1356 .39784 .14516 .411 .13992 .40316 .13033 Mtetra
.667 .739 .904 r
.40316 .13033 .411 .13992 .42422 .13467 .41642 .12506 Mtetra
.666 .739 .905 r
.41642 .12506 .42422 .13467 .43751 .12941 .42975 .11979 Mtetra
.666 .74 .905 r
.42975 .11979 .43751 .12941 .45086 .12416 .44314 .1145 Mtetra
.666 .74 .906 r
.44314 .1145 .45086 .12416 .46427 .11889 .4566 .1092 Mtetra
.665 .74 .906 r
.4566 .1092 .46427 .11889 .47775 .11361 .47012 .10389 Mtetra
.665 .741 .906 r
.47012 .10389 .47775 .11361 .4913 .10832 .48371 .09856 Mtetra
.665 .741 .907 r
.48371 .09856 .4913 .10832 .50491 .10302 .49737 .09322 Mtetra
.664 .741 .907 r
.49737 .09322 .50491 .10302 .51859 .0977 .51109 .08786 Mtetra
.51109 .08786 .51859 .0977 .53234 .09236 .52489 .08248 Mtetra
.52489 .08248 .53234 .09236 .54616 .08701 .53875 .07708 Mtetra
.664 .741 .908 r
.53875 .07708 .54616 .08701 .56005 .08163 .55268 .07165 Mtetra
.55268 .07165 .56005 .08163 .574 .07623 .56669 .0662 Mtetra
.56669 .0662 .574 .07623 .58803 .0708 .58076 .06073 Mtetra
.58076 .06073 .58803 .0708 .60213 .06535 .59491 .05523 Mtetra
.59491 .05523 .60213 .06535 .6163 .05988 .60913 .04971 Mtetra
.60913 .04971 .6163 .05988 .63054 .05438 .62342 .04416 Mtetra
.62342 .04416 .63054 .05438 .64486 .04885 .63778 .03858 Mtetra
.63778 .03858 .64486 .04885 .65925 .0433 .65222 .03297 Mtetra
.65222 .03297 .65925 .0433 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.706 .496 .601 r
.03049 .29725 .03225 .35237 .04996 .3092 .04628 .26638 Mtetra
.635 .457 .625 r
.04628 .26638 .04996 .3092 .06642 .27293 .0591 .25418 Mtetra
.636 .561 .753 r
.0591 .25418 .06642 .27293 .07951 .25887 .07092 .24881 Mtetra
.651 .699 .881 r
.07092 .24881 .07951 .25887 .09137 .25329 .08263 .24447 Mtetra
.652 .729 .905 r
.08263 .24447 .09137 .25329 .1031 .24903 .09438 .24019 Mtetra
.653 .73 .905 r
.09438 .24019 .1031 .24903 .11488 .24485 .1062 .23584 Mtetra
.656 .727 .902 r
.1062 .23584 .11488 .24485 .12672 .24058 .11809 .23138 Mtetra
.66 .725 .897 r
.11809 .23138 .12672 .24058 .13864 .23613 .13006 .22678 Mtetra
.662 .723 .894 r
.13006 .22678 .13864 .23613 .15064 .2315 .14209 .22207 Mtetra
.663 .722 .893 r
.14209 .22207 .15064 .2315 .1627 .22673 .15418 .2173 Mtetra
.663 .723 .894 r
.15418 .2173 .1627 .22673 .17483 .2219 .16633 .21251 Mtetra
.663 .725 .895 r
.16633 .21251 .17483 .2219 .18701 .21707 .17853 .2077 Mtetra
.663 .727 .896 r
.17853 .2077 .18701 .21707 .19925 .21224 .19079 .20287 Mtetra
.664 .728 .897 r
.19079 .20287 .19925 .21224 .21154 .20739 .20311 .198 Mtetra
.665 .729 .897 r
.20311 .198 .21154 .20739 .22389 .20249 .2155 .19308 Mtetra
.666 .729 .897 r
.2155 .19308 .22389 .20249 .23631 .19755 .22794 .18811 Mtetra
.666 .73 .897 r
.22794 .18811 .23631 .19755 .24878 .19256 .24045 .18309 Mtetra
.667 .731 .897 r
.24045 .18309 .24878 .19256 .26131 .18752 .25301 .17803 Mtetra
.668 .731 .897 r
.25301 .17803 .26131 .18752 .27391 .18244 .26564 .17293 Mtetra
.668 .732 .898 r
.26564 .17293 .27391 .18244 .28656 .17732 .27833 .1678 Mtetra
.668 .733 .898 r
.27833 .1678 .28656 .17732 .29928 .17216 .29108 .16263 Mtetra
.668 .734 .899 r
.29108 .16263 .29928 .17216 .31205 .16698 .30388 .15744 Mtetra
.668 .735 .9 r
.30388 .15744 .31205 .16698 .32488 .16178 .31675 .15223 Mtetra
.31675 .15223 .32488 .16178 .33778 .15657 .32968 .14701 Mtetra
.668 .736 .901 r
.32968 .14701 .33778 .15657 .35073 .15134 .34267 .14177 Mtetra
.668 .737 .902 r
.34267 .14177 .35073 .15134 .36375 .1461 .35572 .13651 Mtetra
.667 .738 .903 r
.35572 .13651 .36375 .1461 .37682 .14085 .36884 .13125 Mtetra
.36884 .13125 .37682 .14085 .38996 .1356 .38201 .12597 Mtetra
.667 .739 .904 r
.38201 .12597 .38996 .1356 .40316 .13033 .39525 .12069 Mtetra
.666 .739 .905 r
.39525 .12069 .40316 .13033 .41642 .12506 .40855 .11539 Mtetra
.666 .74 .905 r
.40855 .11539 .41642 .12506 .42975 .11979 .42192 .11009 Mtetra
.666 .74 .906 r
.42192 .11009 .42975 .11979 .44314 .1145 .43535 .10477 Mtetra
.665 .74 .906 r
.43535 .10477 .44314 .1145 .4566 .1092 .44885 .09943 Mtetra
.44885 .09943 .4566 .1092 .47012 .10389 .46242 .09408 Mtetra
.665 .741 .907 r
.46242 .09408 .47012 .10389 .48371 .09856 .47605 .08872 Mtetra
.664 .741 .907 r
.47605 .08872 .48371 .09856 .49737 .09322 .48975 .08334 Mtetra
.48975 .08334 .49737 .09322 .51109 .08786 .50352 .07793 Mtetra
.50352 .07793 .51109 .08786 .52489 .08248 .51736 .07251 Mtetra
.51736 .07251 .52489 .08248 .53875 .07708 .53127 .06706 Mtetra
.664 .741 .908 r
.53127 .06706 .53875 .07708 .55268 .07165 .54525 .06159 Mtetra
.54525 .06159 .55268 .07165 .56669 .0662 .5593 .05609 Mtetra
.5593 .05609 .56669 .0662 .58076 .06073 .57342 .05057 Mtetra
.57342 .05057 .58076 .06073 .59491 .05523 .58762 .04502 Mtetra
.58762 .04502 .59491 .05523 .60913 .04971 .60188 .03944 Mtetra
.60188 .03944 .60913 .04971 .62342 .04416 .61623 .03384 Mtetra
.61623 .03384 .62342 .04416 .63778 .03858 .63064 .0282 Mtetra
.63064 .0282 .63778 .03858 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01114 Mtetra
.67433 .01114 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.005 w
.0614 .07902 m
.07268 .0872 L
.0872 .09852 L
.10489 .113 L
.113 .11983 L
.13503 .1388 L
.1388 .14211 L
.16409 .1646 L
.1646 .16506 L
.1904 .18857 L
.19239 .1904 L
.2162 .21258 L
.22005 .2162 L
.242 .23707 L
.24714 .242 L
.2678 .26205 L
.27367 .2678 L
.2936 .28756 L
.29962 .2936 L
.3194 .31372 L
.3249 .3194 L
.3452 .34075 L
.34934 .3452 L
.371 .36927 L
.3725 .371 L
.371 .39198 L
.3452 .37188 L
.34412 .371 L
.3194 .3503 L
.31347 .3452 L
.2936 .32785 L
.28409 .3194 L
.2678 .30475 L
.25557 .2936 L
.242 .28111 L
.2277 .2678 L
.2162 .25699 L
.20043 .242 L
.1904 .23238 L
.17371 .2162 L
.1646 .20729 L
.14756 .1904 L
.1388 .18163 L
.12204 .1646 L
.113 .15529 L
.09729 .1388 L
.0872 .12799 L
.07362 .113 L
.0614 .09888 L
.05202 .0872 L
Mistroke
.0614 .07902 L
Mfstroke
.242 .20675 m
.2678 .20116 L
.2936 .20046 L
.3194 .20405 L
.3452 .21166 L
.35693 .2162 L
.371 .22324 L
.3968 .23904 L
.401 .242 L
.4226 .25953 L
.43148 .2678 L
.4484 .28576 L
.45501 .2936 L
.47388 .3194 L
.4742 .31989 L
.48923 .3452 L
.5 .36746 L
.50151 .371 L
.51114 .3968 L
.51822 .4226 L
.52281 .4484 L
.52487 .4742 L
.52424 .5 L
.52059 .5258 L
.51333 .5516 L
.50131 .5774 L
.5 .57963 L
.48235 .6032 L
.4742 .61114 L
.4486 .629 L
.4484 .6291 L
.4226 .63925 L
.3968 .64364 L
.371 .64332 L
.3452 .6388 L
.3194 .63027 L
.31619 .629 L
.2936 .61776 L
.27082 .6032 L
.2678 .60094 L
.242 .57924 L
.24007 .5774 L
.21633 .5516 L
.2162 .55145 L
.19724 .5258 L
.1904 .51505 L
.18181 .5 L
.1694 .4742 L
.1646 .46247 L
.1597 .4484 L
Mistroke
.15251 .4226 L
.14782 .3968 L
.14566 .371 L
.14618 .3452 L
.14972 .3194 L
.15685 .2936 L
.1646 .27521 L
.16861 .2678 L
.18733 .242 L
.1904 .23878 L
.2162 .21843 L
.21962 .2162 L
.242 .20675 L
Mfstroke
.5 .43831 m
.51712 .4484 L
.5258 .45472 L
.54934 .4742 L
.5516 .47621 L
.57697 .5 L
.5774 .50042 L
.60242 .5258 L
.6032 .52599 L
.62638 .5516 L
.629 .55306 L
.64916 .5774 L
.6548 .58195 L
.67454 .6032 L
.6806 .61313 L
.6939 .629 L
.7064 .64704 L
.71229 .6548 L
.73008 .6806 L
.7322 .68363 L
.74745 .7064 L
.758 .72339 L
.7655 .7322 L
.77589 .758 L
.758 .77922 L
.7322 .76199 L
.72815 .758 L
.7064 .7402 L
.69897 .7322 L
.6806 .71541 L
.66999 .7064 L
.6548 .68859 L
.64654 .6806 L
.629 .66004 L
.62405 .6548 L
.6032 .62983 L
.60248 .629 L
.58135 .6032 L
.5774 .6009 L
.55714 .5774 L
.5516 .56769 L
.53968 .5516 L
.5258 .52923 L
.52358 .5258 L
.50743 .5 L
.5 .48725 L
.4931 .4742 L
.48335 .4484 L
.5 .43831 L
s
0 g
.03 w
.21929 .2377 Mdot
.33526 .42212 Mdot
.63181 .61018 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.78431 .20392 Mdot
.43529 .38824 Mdot
.7451 .68235 Mdot
.75686 .73333 Mdot
.63529 .54118 Mdot
.43137 .44314 Mdot
.72157 .68235 Mdot
.7098 .63529 Mdot
.75294 .75686 Mdot
.79216 .78431 Mdot
.71765 .62745 Mdot
.83137 .80784 Mdot
.81569 .83137 Mdot
.58824 .43922 Mdot
.68627 .61176 Mdot
.63137 .63922 Mdot
.81961 .82745 Mdot
.63529 .51373 Mdot
.66275 .60392 Mdot
.74902 .75294 Mdot
.8 .80784 Mdot
.62353 .48235 Mdot
.76471 .66667 Mdot
.83137 .81569 Mdot
.81176 .83137 Mdot
.83529 .05098 Mdot
.60392 .5451 Mdot
.75686 .72941 Mdot
.30588 .43137 Mdot
.79608 .81176 Mdot
.63922 .51373 Mdot
.80784 .72549 Mdot
.7098 .68627 Mdot
.83137 .83922 Mdot
.74902 .77255 Mdot
.73333 .63137 Mdot
.80784 .72941 Mdot
.73333 .70588 Mdot
.81569 .82353 Mdot
.52549 .21569 Mdot
.73725 .64706 Mdot
.78431 .70588 Mdot
.72941 .72549 Mdot
.81569 .8549 Mdot
.82745 .05098 Mdot
.7451 .66275 Mdot
.79216 .7098 Mdot
.83137 .81176 Mdot
.82353 .84706 Mdot
.49804 .54118 Mdot
.71765 .61961 Mdot
.81569 .81961 Mdot
.80784 .76863 Mdot
.83922 .85098 Mdot
.79608 .81569 Mdot
.65882 .57647 Mdot
.75686 .64706 Mdot
.76471 .71765 Mdot
.73725 .77255 Mdot
.78039 .80392 Mdot
.59216 .45882 Mdot
.7098 .61569 Mdot
.79608 .70196 Mdot
.70588 .67843 Mdot
.83922 .86667 Mdot
.75686 .81569 Mdot
.68627 .6 Mdot
.7451 .63137 Mdot
.75686 .68627 Mdot
.44706 .52157 Mdot
.79216 .82353 Mdot
.56078 .41176 Mdot
.67843 .58431 Mdot
.76471 .67451 Mdot
.84706 .81176 Mdot
.22353 .36863 Mdot
.81176 .83922 Mdot
.61176 .49804 Mdot
.7098 .60392 Mdot
.78824 .69412 Mdot
.77647 .74902 Mdot
.83137 .8549 Mdot
.73725 .76078 Mdot
.58039 .5098 Mdot
.43922 .39608 Mdot
.76078 .66667 Mdot
.77647 .75686 Mdot
.83529 .85882 Mdot
.57647 .62353 Mdot
.14118 .09412 Mdot
.57647 .53333 Mdot
.75294 .6549 Mdot
.76863 .74118 Mdot
.83137 .8549 Mdot
.34902 .4 Mdot
.15294 .08235 Mdot
.62353 .54118 Mdot
.76471 .66667 Mdot
.69412 .67059 Mdot
.83529 .86667 Mdot
.26275 .3451 Mdot
.26275 .17647 Mdot
.61176 .53725 Mdot
.77647 .68235 Mdot
.82353 .8 Mdot
.83922 .84706 Mdot
.79216 .84314 Mdot
.61569 .51373 Mdot
.65882 .53333 Mdot
.76078 .65882 Mdot
.70588 .64314 Mdot
.5098 .48627 Mdot
.77647 .75294 Mdot
.56863 .47843 Mdot
.63922 .5098 Mdot
.7451 .63922 Mdot
.70588 .61569 Mdot
.38824 .37255 Mdot
.81176 .83529 Mdot
.44314 .32941 Mdot
.61961 .50196 Mdot
.41569 .4 Mdot
.74902 .65882 Mdot
.64314 .61569 Mdot
.64314 .66667 Mdot
.46667 .5098 Mdot
.61176 .50196 Mdot
.61569 .43922 Mdot
.76863 .67059 Mdot
.75686 .6902 Mdot
.02745 .03922 Mdot
.72941 .58431 Mdot
.51765 .44314 Mdot
.61569 .46667 Mdot
.72549 .61961 Mdot
.73725 .63529 Mdot
.03529 .04314 Mdot
.80392 .82745 Mdot
.5451 .55686 Mdot
.62353 .51765 Mdot
.61176 .43922 Mdot
.76863 .68235 Mdot
.64314 .57255 Mdot
.01961 .02353 Mdot
.79216 .71765 Mdot
.56471 .48627 Mdot
.6 .44314 Mdot
.7098 .57647 Mdot
.73333 .63137 Mdot
.01961 .03137 Mdot
.24314 .25882 Mdot
.66275 .68235 Mdot
.58824 .47451 Mdot
.61176 .41569 Mdot
.76078 .68627 Mdot
.61961 .57255 Mdot
.01961 .02745 Mdot
.59608 .03922 Mdot
.73333 .75686 Mdot
.59608 .4549 Mdot
.6549 .50196 Mdot
.46667 .43137 Mdot
.02745 .03922 Mdot
.02353 .03137 Mdot
.27843 .31765 Mdot
.59608 .53333 Mdot
.57255 .37647 Mdot
.72157 .60392 Mdot
.71765 .63137 Mdot
.03137 .03922 Mdot
.58824 .59216 Mdot
.82745 .05098 Mdot
.58039 .48235 Mdot
.62745 .43922 Mdot
.49412 .45882 Mdot
.07451 .0549 Mdot
.30588 .40392 Mdot
.59216 .19608 Mdot
.77647 .80784 Mdot
.6 .47843 Mdot
.65098 .49412 Mdot
.5451 .51373 Mdot
.04314 .05098 Mdot
.28627 .42353 Mdot
.62745 .01176 Mdot
.82353 .83529 Mdot
.58824 .43137 Mdot
.68235 .54902 Mdot
.76471 .68235 Mdot
.11373 .11765 Mdot
.28235 .33725 Mdot
.43922 .38824 Mdot
.56863 .51765 Mdot
.56863 .37647 Mdot
.72549 .61961 Mdot
.61176 .57647 Mdot
.23529 .38431 Mdot
.02353 .03922 Mdot
.53725 .52941 Mdot
.58824 .53725 Mdot
.59216 .40392 Mdot
.76078 .66275 Mdot
.06667 .06667 Mdot
.81961 .82353 Mdot
.67059 .71373 Mdot
.7451 .76471 Mdot
.57255 .48627 Mdot
.63529 .47451 Mdot
.78824 .70196 Mdot
.05882 .05098 Mdot
.68235 .68627 Mdot
.59216 .08235 Mdot
.77255 .81569 Mdot
.59608 .50588 Mdot
.66667 .55686 Mdot
.78824 .72157 Mdot
.34118 .39216 Mdot
.74902 .79216 Mdot
.50196 .02353 Mdot
.57647 .60784 Mdot
.58039 .47451 Mdot
.6902 .57647 Mdot
.77647 .69804 Mdot
.24314 .41961 Mdot
.27843 .38431 Mdot
.46275 .03922 Mdot
.66275 .67843 Mdot
.57647 .46275 Mdot
.69804 .59216 Mdot
.76078 .68235 Mdot
.61961 .58039 Mdot
.79608 .85882 Mdot
.39216 .01569 Mdot
.81569 .84706 Mdot
.56471 .42353 Mdot
.70588 .61176 Mdot
.25882 .23137 Mdot
.4549 .41961 Mdot
.81961 .8549 Mdot
.43922 .04706 Mdot
.69412 .70196 Mdot
.56471 .38824 Mdot
.7098 .61176 Mdot
.08235 .06667 Mdot
.04314 .05098 Mdot
.82353 .85882 Mdot
.37255 .02745 Mdot
.55294 .54118 Mdot
.55686 .39608 Mdot
.72157 .62745 Mdot
.0902 .05882 Mdot
.02353 .04314 Mdot
.82745 .8549 Mdot
.30196 .00392 Mdot
.56471 .54118 Mdot
.56863 .41569 Mdot
.71373 .62745 Mdot
.09412 .05882 Mdot
.02353 .03529 Mdot
.74118 .77255 Mdot
.38431 .01569 Mdot
.56863 .54902 Mdot
.56471 .41176 Mdot
.72941 .64314 Mdot
.30196 .29804 Mdot
.02745 .03529 Mdot
.37647 .42353 Mdot
.51765 .05882 Mdot
.58431 .56078 Mdot
.59216 .4549 Mdot
.74118 .65882 Mdot
.27059 .46275 Mdot
.11765 .12549 Mdot
.07843 .12157 Mdot
.49412 .06275 Mdot
.58431 .56078 Mdot
.6 .46275 Mdot
.73725 .6549 Mdot
.30196 .49804 Mdot
.34902 .43922 Mdot
.07059 .11373 Mdot
.44706 .02353 Mdot
.59216 .56078 Mdot
.62353 .49804 Mdot
.72941 .64706 Mdot
.58431 .69804 Mdot
.16863 .36471 Mdot
.06275 .1098 Mdot
.47451 .02353 Mdot
.58431 .55686 Mdot
.62745 .50588 Mdot
.72549 .64706 Mdot
.74118 .76471 Mdot
.41176 .53333 Mdot
.07059 .10196 Mdot
.43137 .00784 Mdot
.58824 .56863 Mdot
.61961 .5098 Mdot
.72941 .63529 Mdot
.7451 .7098 Mdot
.77255 .78039 Mdot
.06667 .08627 Mdot
.47451 .03137 Mdot
.54902 .53333 Mdot
.63529 .52549 Mdot
.72549 .63137 Mdot
.72941 .67451 Mdot
.62353 .58431 Mdot
.07451 .09804 Mdot
.55686 .08235 Mdot
.53333 .51373 Mdot
.62745 .52549 Mdot
.72157 .63529 Mdot
.67451 .62353 Mdot
.50196 .45882 Mdot
.06667 .09804 Mdot
.57255 .15686 Mdot
.52941 .50196 Mdot
.63922 .54118 Mdot
.73333 .64314 Mdot
.26275 .24314 Mdot
.16863 .15294 Mdot
.0549 .08235 Mdot
.58039 .2902 Mdot
.50588 .47843 Mdot
.63922 .55294 Mdot
.72549 .63529 Mdot
.11765 .10196 Mdot
.0549 .06275 Mdot
.0549 .08235 Mdot
.65882 .50588 Mdot
.50588 .48235 Mdot
.63922 .54902 Mdot
.72549 .63137 Mdot
.10196 .08235 Mdot
.05882 .05098 Mdot
.0549 .08235 Mdot
.63529 .58039 Mdot
.49804 .47451 Mdot
.64314 .5451 Mdot
.73333 .65098 Mdot
.1098 .0902 Mdot
.22353 .21176 Mdot
.04706 .06667 Mdot
.5451 .53333 Mdot
.48627 .46667 Mdot
.63529 .54118 Mdot
.73333 .64314 Mdot
.23529 .23529 Mdot
.18824 .25882 Mdot
.03922 .06275 Mdot
.72549 .73725 Mdot
.46275 .46275 Mdot
.61569 .52941 Mdot
.72157 .62745 Mdot
.30588 .3098 Mdot
.31373 .34118 Mdot
.06667 .0902 Mdot
.56863 .60784 Mdot
.69412 .70196 Mdot
.61569 .54118 Mdot
.7098 .61569 Mdot
.47059 .50196 Mdot
.04706 .04314 Mdot
.31373 .34118 Mdot
.41961 .50196 Mdot
.76471 .78039 Mdot
.62745 .56078 Mdot
.71765 .63137 Mdot
.47059 .56863 Mdot
.04706 .05882 Mdot
.35686 .42745 Mdot
.73333 .81176 Mdot
.76078 .78431 Mdot
.65098 .58039 Mdot
.70196 .60784 Mdot
.3098 .45882 Mdot
.07843 .07843 Mdot
.4549 .52549 Mdot
.47451 .58039 Mdot
.65098 .66667 Mdot
.64706 .58431 Mdot
.70196 .61961 Mdot
.66275 .70588 Mdot
.17647 .16471 Mdot
.63137 .6902 Mdot
.79608 .87451 Mdot
.51765 .52549 Mdot
.6549 .59216 Mdot
.6902 .61569 Mdot
.77255 .72549 Mdot
.27451 .25882 Mdot
.41961 .49412 Mdot
.79216 .84706 Mdot
.5098 .51765 Mdot
.64314 .6 Mdot
.68235 .59608 Mdot
.78039 .7098 Mdot
.3098 .30588 Mdot
.03922 .07843 Mdot
.77647 .83137 Mdot
.45882 .47059 Mdot
.6549 .60784 Mdot
.67451 .58824 Mdot
.78039 .71373 Mdot
.30196 .30196 Mdot
.01176 .02745 Mdot
.80392 .84314 Mdot
.42353 .45098 Mdot
.65098 .61569 Mdot
.67843 .58824 Mdot
.78431 .72157 Mdot
.30196 .30588 Mdot
.01569 .03529 Mdot
.79216 .83922 Mdot
.46275 .50588 Mdot
.63922 .60784 Mdot
.66275 .57647 Mdot
.78824 .72157 Mdot
.62353 .6 Mdot
.38824 .42353 Mdot
.79608 .85098 Mdot
.6549 .7098 Mdot
.63137 .59216 Mdot
.6549 .56078 Mdot
.76078 .69412 Mdot
.68627 .64706 Mdot
.65098 .66275 Mdot
.79216 .82353 Mdot
.54902 .55294 Mdot
.61176 .56471 Mdot
.64314 .55294 Mdot
.75686 .6902 Mdot
.72549 .67451 Mdot
.63137 .60392 Mdot
.79608 .83137 Mdot
.56078 .40784 Mdot
.56863 .52549 Mdot
.64314 .54902 Mdot
.75294 .67059 Mdot
.7098 .67059 Mdot
.60392 .54902 Mdot
.80392 .8549 Mdot
.26667 .21961 Mdot
.56471 .53725 Mdot
.63922 .54118 Mdot
.74118 .66667 Mdot
.71765 .69412 Mdot
.61176 .56078 Mdot
.7451 .80784 Mdot
.16863 .21176 Mdot
.56471 .55294 Mdot
.61569 .52157 Mdot
.73725 .67843 Mdot
.73333 .69804 Mdot
.61961 .56863 Mdot
.2549 .32549 Mdot
.59216 .63137 Mdot
.56078 .56078 Mdot
.61569 .52941 Mdot
.73725 .67843 Mdot
.72941 .69412 Mdot
.63529 .59608 Mdot
.02353 .05882 Mdot
.63922 .65882 Mdot
.69412 .71373 Mdot
.62745 .54902 Mdot
.73725 .66275 Mdot
.72941 .69804 Mdot
.61176 .57647 Mdot
.00784 .02745 Mdot
.48627 .51373 Mdot
.42745 .44706 Mdot
.62353 .56078 Mdot
.72549 .6549 Mdot
.75686 .73333 Mdot
.12941 .1451 Mdot
.26667 .29804 Mdot
.52941 .60784 Mdot
.65098 .67451 Mdot
.60784 .55686 Mdot
.70196 .63922 Mdot
.76471 .72941 Mdot
.0549 .06275 Mdot
.59216 .59608 Mdot
.76863 .83529 Mdot
.30196 .33333 Mdot
.62353 .58824 Mdot
.69804 .63922 Mdot
.74902 .71373 Mdot
.04706 .05882 Mdot
.04314 .05098 Mdot
.78824 .84706 Mdot
.45098 .49804 Mdot
.64314 .61176 Mdot
.67451 .60392 Mdot
.75686 .71373 Mdot
.07843 .09412 Mdot
.01569 .03137 Mdot
.77647 .83529 Mdot
.55686 .59216 Mdot
.61176 .6 Mdot
.65882 .59216 Mdot
.74902 .70588 Mdot
.28235 .27451 Mdot
.00784 .02353 Mdot
.79216 .84314 Mdot
.58039 .63137 Mdot
.61961 .59608 Mdot
.65882 .57647 Mdot
.73725 .69804 Mdot
.68627 .66667 Mdot
.01569 .03922 Mdot
.69412 .7098 Mdot
.66275 .60392 Mdot
.6 .58039 Mdot
.64706 .56078 Mdot
.72941 .68627 Mdot
.72549 .69804 Mdot
.01569 .03529 Mdot
.01961 .06275 Mdot
.21176 .12941 Mdot
.58824 .58431 Mdot
.63529 .53725 Mdot
.7451 .6902 Mdot
.72941 .69804 Mdot
.02353 .04706 Mdot
.00392 .04314 Mdot
.08235 .18431 Mdot
.55686 .56471 Mdot
.61961 .53333 Mdot
.72941 .66275 Mdot
.75294 .72549 Mdot
.03922 .0549 Mdot
.00392 .04706 Mdot
.1098 .2 Mdot
.81961 .8549 Mdot
.60784 .54118 Mdot
.68627 .61176 Mdot
.75686 .72941 Mdot
.02745 .05098 Mdot
.44706 .49412 Mdot
.65882 .70196 Mdot
.35294 .38824 Mdot
.58039 .54118 Mdot
.63922 .55686 Mdot
.76078 .73333 Mdot
.03137 .04706 Mdot
.43529 .53333 Mdot
.29804 .40392 Mdot
.6902 .72549 Mdot
.56078 .52549 Mdot
.61961 .51765 Mdot
.76863 .75294 Mdot
.04314 .0549 Mdot
.03529 .07843 Mdot
.78039 .85098 Mdot
.34902 .37255 Mdot
.59216 .55294 Mdot
.59608 .49412 Mdot
.59216 .58824 Mdot
.05098 .07451 Mdot
.01569 .03529 Mdot
.77255 .84314 Mdot
.48627 .52157 Mdot
.58431 .5451 Mdot
.61176 .50588 Mdot
.66667 .64706 Mdot
.11373 .14118 Mdot
.00784 .03137 Mdot
.77647 .86275 Mdot
.73725 .78824 Mdot
.58824 .56863 Mdot
.60784 .50196 Mdot
.71373 .67059 Mdot
.62745 .63529 Mdot
.00392 .03529 Mdot
.4549 .62353 Mdot
.59216 .53725 Mdot
.55686 .55294 Mdot
.59608 .48235 Mdot
.63922 .58431 Mdot
.70588 .68235 Mdot
.01176 .03529 Mdot
.08235 .32549 Mdot
.32941 .30588 Mdot
.56863 .55294 Mdot
.57255 .48235 Mdot
.62353 .56471 Mdot
.70588 .69804 Mdot
.03137 .05098 Mdot
.04706 .25882 Mdot
.30196 .29804 Mdot
.54118 .55294 Mdot
.58431 .4902 Mdot
.63922 .57255 Mdot
.72941 .71373 Mdot
.02745 .03529 Mdot
.47843 .5451 Mdot
.39216 .37647 Mdot
.48627 .50196 Mdot
.55686 .48627 Mdot
.60392 .51765 Mdot
.75686 .73725 Mdot
.02745 .04314 Mdot
.72941 .79216 Mdot
.48627 .4902 Mdot
.40392 .43922 Mdot
.55294 .50196 Mdot
.58824 .48627 Mdot
.75686 .74118 Mdot
.03529 .04706 Mdot
.56078 .7451 Mdot
.73725 .76863 Mdot
.33333 .38824 Mdot
.53725 .49412 Mdot
.57647 .44314 Mdot
.77647 .75294 Mdot
.03137 .04706 Mdot
.1451 .37647 Mdot
.40392 .49412 Mdot
.45882 .51765 Mdot
.53333 .50588 Mdot
.56471 .43529 Mdot
.75294 .73725 Mdot
.04706 .05882 Mdot
.31765 .45098 Mdot
.39608 .47843 Mdot
.73725 .78824 Mdot
.55294 .53725 Mdot
.56471 .44706 Mdot
.74118 .71765 Mdot
.03529 .04314 Mdot
.3098 .37647 Mdot
.78039 .83529 Mdot
.75686 .82353 Mdot
.53725 .5098 Mdot
.54902 .43529 Mdot
.63137 .58431 Mdot
.1098 .13333 Mdot
.1451 .18039 Mdot
.37255 .4549 Mdot
.64706 .58431 Mdot
.56471 .54902 Mdot
.54118 .42745 Mdot
.61176 .55294 Mdot
.72157 .70588 Mdot
.03922 .06667 Mdot
.42745 .47451 Mdot
.23922 .27451 Mdot
.53725 .53333 Mdot
.52941 .41961 Mdot
.60392 .53333 Mdot
.72549 .72549 Mdot
.10588 .14118 Mdot
.81176 .86275 Mdot
.36078 .36471 Mdot
.47843 .4902 Mdot
.54118 .45098 Mdot
.59216 .51765 Mdot
.73725 .73725 Mdot
.62745 .6549 Mdot
.64314 .73333 Mdot
.2549 .34118 Mdot
.12157 .14902 Mdot
.54902 .49804 Mdot
.63137 .57255 Mdot
.7451 .74118 Mdot
.58431 .62745 Mdot
.31373 .40392 Mdot
.43529 .49804 Mdot
.33333 .36471 Mdot
.55686 .52941 Mdot
.58824 .50588 Mdot
.74902 .7451 Mdot
.12941 .16863 Mdot
.56078 .58431 Mdot
.12549 .29804 Mdot
.18431 .18431 Mdot
.54118 .52157 Mdot
.59216 .50196 Mdot
.74902 .74902 Mdot
.12157 .18039 Mdot
.37647 .40392 Mdot
.63529 .68235 Mdot
.11373 .12157 Mdot
.49412 .48627 Mdot
.6 .50196 Mdot
.58039 .57647 Mdot
.1451 .21176 Mdot
.13333 .17255 Mdot
.43922 .52157 Mdot
.22353 .21569 Mdot
.49804 .4902 Mdot
.55294 .45882 Mdot
.56471 .53725 Mdot
.64706 .66667 Mdot
.10588 .12941 Mdot
.78824 .83137 Mdot
.70588 .08235 Mdot
.5098 .50196 Mdot
.56863 .46667 Mdot
.66667 .62353 Mdot
.71373 .70196 Mdot
.14902 .18431 Mdot
.11373 .18039 Mdot
.07059 .18824 Mdot
.48235 .48627 Mdot
.54902 .45098 Mdot
.67059 .62745 Mdot
.72941 .73333 Mdot
.12549 .16863 Mdot
.00784 .04706 Mdot
.04706 .19608 Mdot
.47451 .4902 Mdot
.54118 .4549 Mdot
.68627 .65882 Mdot
.73333 .72157 Mdot
.15294 .18431 Mdot
.00392 .03137 Mdot
.07843 .20784 Mdot
.43137 .43922 Mdot
.52941 .48235 Mdot
.65882 .63529 Mdot
.7451 .74902 Mdot
.20392 .2549 Mdot
.00784 .02745 Mdot
.39608 .42745 Mdot
.21176 .23529 Mdot
.50588 .47059 Mdot
.64706 .61176 Mdot
.72157 .71765 Mdot
.35686 .47451 Mdot
.00784 .04706 Mdot
.46275 .45882 Mdot
.08627 .09804 Mdot
.43922 .41569 Mdot
.63922 .6 Mdot
.71765 .7098 Mdot
.23922 .39216 Mdot
.00784 .04314 Mdot
.47059 .48235 Mdot
.20784 .22745 Mdot
.42745 .41569 Mdot
.61176 .56471 Mdot
.71765 .71373 Mdot
.28627 .43137 Mdot
.02353 .04314 Mdot
.44706 .48627 Mdot
.19608 .18039 Mdot
.44314 .41961 Mdot
.61176 .56078 Mdot
.72157 .72941 Mdot
.67451 .68627 Mdot
.04314 .06667 Mdot
.18039 .22745 Mdot
.31373 .26275 Mdot
.47451 .46275 Mdot
.59216 .52549 Mdot
.70588 .71765 Mdot
.71373 .70588 Mdot
.06275 .10196 Mdot
.00392 .03529 Mdot
.31373 .33725 Mdot
.42353 .43529 Mdot
.54902 .48627 Mdot
.7098 .7098 Mdot
.6902 .67843 Mdot
.07059 .10588 Mdot
.16078 .20392 Mdot
.34118 .37255 Mdot
.40392 .4 Mdot
.56863 .49412 Mdot
.67059 .65098 Mdot
.71373 .72157 Mdot
.03137 .05882 Mdot
.5098 .53725 Mdot
.40392 .4 Mdot
.34902 .35686 Mdot
.54902 .48627 Mdot
.68627 .6549 Mdot
.7098 .7098 Mdot
.01961 .03922 Mdot
.03137 .07451 Mdot
.1098 .18431 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.69412 .66667 Mdot
.68627 .69412 Mdot
.02353 .05098 Mdot
.00392 .04314 Mdot
.44314 .43922 Mdot
.30196 .31765 Mdot
.4549 .43922 Mdot
.66275 .63529 Mdot
.72941 .73333 Mdot
.00784 .03529 Mdot
.00392 .02745 Mdot
.47843 .47451 Mdot
.12157 .11373 Mdot
.43922 .43137 Mdot
.63922 .59608 Mdot
.71373 .72157 Mdot
.03529 .05882 Mdot
.00784 .03529 Mdot
.6 .6902 Mdot
.3451 .31765 Mdot
.4549 .44706 Mdot
.61961 .55294 Mdot
.70196 .6902 Mdot
.03922 .06667 Mdot
.04314 .08627 Mdot
.04706 .09412 Mdot
.27843 .32157 Mdot
.38431 .38824 Mdot
.6 .53725 Mdot
.58824 .56078 Mdot
.34902 .38431 Mdot
.56471 .57647 Mdot
.42745 .49804 Mdot
.0549 .23529 Mdot
.31765 .33333 Mdot
.55294 .50196 Mdot
.54902 .49412 Mdot
.68235 .69804 Mdot
.59216 .62353 Mdot
.80392 .90588 Mdot
.08627 .20392 Mdot
.27451 .29412 Mdot
.52549 .49412 Mdot
.61569 .58824 Mdot
.66275 .67451 Mdot
.4902 .62353 Mdot
.18824 .4 Mdot
.43922 .43529 Mdot
.27451 .27451 Mdot
.50196 .47451 Mdot
.66275 .62745 Mdot
.69804 .72157 Mdot
.18824 .46275 Mdot
.12941 .39216 Mdot
.47451 .46667 Mdot
.39608 .38824 Mdot
.44314 .43529 Mdot
.61961 .57647 Mdot
.70588 .70588 Mdot
.33333 .48627 Mdot
.12941 .36471 Mdot
.48627 .4902 Mdot
.37647 .37647 Mdot
.44314 .43922 Mdot
.57255 .50196 Mdot
.69804 .69804 Mdot
.07059 .0902 Mdot
.18039 .22745 Mdot
.74902 .80784 Mdot
.27843 .3098 Mdot
.38431 .38039 Mdot
.52157 .43529 Mdot
.61961 .60392 Mdot
.02353 .04706 Mdot
.32941 .34902 Mdot
.15686 .3451 Mdot
.40392 .42353 Mdot
.29804 .3098 Mdot
.46275 .4 Mdot
.6549 .64314 Mdot
.06275 .09412 Mdot
.58039 .58039 Mdot
.10196 .13725 Mdot
.41569 .39608 Mdot
.12549 .14118 Mdot
.45098 .43137 Mdot
.6549 .63137 Mdot
.65882 .66275 Mdot
.12549 .19608 Mdot
.03137 .0549 Mdot
.44706 .43137 Mdot
.28235 .29412 Mdot
.4549 .44314 Mdot
.55294 .49804 Mdot
.66667 .6549 Mdot
.07843 .12941 Mdot
.03529 .07059 Mdot
.46275 .46275 Mdot
.38824 .38824 Mdot
.49804 .4902 Mdot
.57255 .5098 Mdot
.68627 .69412 Mdot
.38824 .51765 Mdot
.26667 .32157 Mdot
.48627 .48627 Mdot
.26275 .27451 Mdot
.41961 .42353 Mdot
.47843 .37647 Mdot
.65098 .66275 Mdot
.22353 .48235 Mdot
.67843 .69412 Mdot
.03137 .07843 Mdot
.07451 .23529 Mdot
.35294 .37255 Mdot
.4902 .39608 Mdot
.71373 .71765 Mdot
.24314 .33333 Mdot
.48235 .58431 Mdot
.00392 .03922 Mdot
.0549 .23529 Mdot
.3098 .33725 Mdot
.43529 .38039 Mdot
.67451 .65882 Mdot
.05098 .07843 Mdot
.04314 .08627 Mdot
.00784 .05882 Mdot
.06667 .2902 Mdot
.22353 .23137 Mdot
.39608 .38824 Mdot
.53725 .50196 Mdot
.5098 .5451 Mdot
.56863 .63922 Mdot
.03529 .09412 Mdot
.0902 .28627 Mdot
.31765 .30196 Mdot
.47059 .47843 Mdot
.58039 .53333 Mdot
.69412 .70588 Mdot
.32157 .54118 Mdot
.42745 .48627 Mdot
.31373 .36078 Mdot
.4 .31373 Mdot
.47843 .48627 Mdot
.56471 .50588 Mdot
.7098 .72157 Mdot
.32941 .50588 Mdot
.77647 .84314 Mdot
.00392 .03529 Mdot
.40784 .39216 Mdot
.37647 .38824 Mdot
.52941 .47059 Mdot
.6902 .70588 Mdot
.06667 .08627 Mdot
.63529 .66667 Mdot
.10588 .13725 Mdot
.42353 .41569 Mdot
.30588 .32549 Mdot
.43529 .38824 Mdot
.59216 .57647 Mdot
.20784 .22745 Mdot
.15294 .39216 Mdot
.0902 .13725 Mdot
.09804 .23137 Mdot
.26667 .27059 Mdot
.38039 .33333 Mdot
.82745 .82353 Mdot
.07059 .0902 Mdot
.27451 .35686 Mdot
.02353 .04706 Mdot
.45098 .47059 Mdot
.22745 .21569 Mdot
.44706 .44706 Mdot
.51373 .4902 Mdot
.65882 .66275 Mdot
.03922 .07451 Mdot
.00392 .03137 Mdot
.17255 .3451 Mdot
.29804 .28235 Mdot
.46275 .47059 Mdot
.59608 .54118 Mdot
.70588 .71373 Mdot
.07451 .12157 Mdot
.01961 .0549 Mdot
.06275 .31373 Mdot
.18431 .27451 Mdot
.43137 .46667 Mdot
.52549 .47059 Mdot
.68235 .6902 Mdot
.1098 .19216 Mdot
.64314 .71765 Mdot
.0549 .10588 Mdot
.0549 .25882 Mdot
.33725 .37647 Mdot
.5098 .45098 Mdot
.66275 .66667 Mdot
.03922 .06667 Mdot
.49804 .54902 Mdot
.71373 .73725 Mdot
.12941 .23922 Mdot
.27451 .27843 Mdot
.41961 .4 Mdot
.53725 .52941 Mdot
.08235 .12941 Mdot
.71373 .73725 Mdot
.04314 .07843 Mdot
.18431 .30196 Mdot
.08627 .08235 Mdot
.41569 .40784 Mdot
.5451 .52941 Mdot
.70588 .71373 Mdot
.65882 .72549 Mdot
.16078 .31373 Mdot
.41569 .4902 Mdot
.30196 .27843 Mdot
.38039 .4 Mdot
.57647 .5451 Mdot
.69804 .71373 Mdot
.34118 .53333 Mdot
.01961 .05882 Mdot
.2 .37647 Mdot
.27059 .30588 Mdot
.03529 .06667 Mdot
.51373 .45882 Mdot
.63137 .63529 Mdot
.43137 .62745 Mdot
.55294 .59608 Mdot
.21961 .31373 Mdot
.21569 .28235 Mdot
.13725 .17255 Mdot
.4549 .42353 Mdot
.54118 .52549 Mdot
.06275 .1098 Mdot
.6 .62745 Mdot
.0549 .07451 Mdot
.44314 .43529 Mdot
.25098 .25882 Mdot
.41176 .41176 Mdot
.50588 .48235 Mdot
.29412 .32941 Mdot
.6 .62353 Mdot
.02353 .0549 Mdot
.48235 .47843 Mdot
.28235 .26275 Mdot
.38431 .40392 Mdot
.55686 .53725 Mdot
.6902 .69804 Mdot
.71765 .73333 Mdot
.03529 .07843 Mdot
.44314 .46275 Mdot
.12941 .01569 Mdot
.30588 .32941 Mdot
.58431 .55294 Mdot
.6902 .70588 Mdot
.66275 .67451 Mdot
.61961 .67059 Mdot
.29412 .30588 Mdot
.11765 .17647 Mdot
.31373 .35686 Mdot
.52157 .47451 Mdot
.5098 .5098 Mdot
.23137 .39608 Mdot
.6549 .7451 Mdot
.02745 .07451 Mdot
.37647 .37255 Mdot
.26275 .28627 Mdot
.44706 .42353 Mdot
.50196 .47843 Mdot
.05098 .07059 Mdot
.63137 .68235 Mdot
.00392 .03529 Mdot
.46667 .46275 Mdot
.06667 .06667 Mdot
.40784 .42353 Mdot
.46275 .4549 Mdot
.66275 .68627 Mdot
.66275 .67843 Mdot
.11373 .17647 Mdot
.43529 .43137 Mdot
.09804 .01569 Mdot
.2902 .3098 Mdot
.49412 .4549 Mdot
.65098 .66275 Mdot
.64314 .67059 Mdot
.5098 .59216 Mdot
0 .02745 Mdot
.05882 .17255 Mdot
.27451 .31765 Mdot
.55294 .51765 Mdot
.50196 .50588 Mdot
.35294 .46667 Mdot
.80784 .8549 Mdot
.00392 .03137 Mdot
.04706 .2 Mdot
.28235 .32157 Mdot
.50588 .47843 Mdot
.4902 .48235 Mdot
.03529 .05098 Mdot
.64706 .77255 Mdot
.00392 .02745 Mdot
.11765 .24706 Mdot
.27059 .2902 Mdot
.44706 .43922 Mdot
.43529 .43922 Mdot
.31765 .35686 Mdot
.72941 .81961 Mdot
0 .03137 Mdot
.42745 .41176 Mdot
.21961 .19216 Mdot
.33725 .34902 Mdot
.33725 .33333 Mdot
.63137 .64706 Mdot
.67843 .70196 Mdot
0 .03137 Mdot
.02745 .0549 Mdot
.6549 .12157 Mdot
.24706 .28235 Mdot
.49412 .44314 Mdot
.56471 .57255 Mdot
.06667 .13333 Mdot
.00392 .03529 Mdot
.26275 .34118 Mdot
.35294 .34118 Mdot
.27059 .3098 Mdot
.51765 .49412 Mdot
.4902 .48235 Mdot
.03922 .07059 Mdot
.02353 .08235 Mdot
.21176 .40784 Mdot
.03529 .21961 Mdot
.10196 .13333 Mdot
.44706 .45098 Mdot
.47059 .45098 Mdot
.65098 .67451 Mdot
.62353 .68627 Mdot
.11373 .16863 Mdot
.42353 .45098 Mdot
.39608 .38824 Mdot
.39216 .41569 Mdot
.50196 .4902 Mdot
.57255 .59608 Mdot
.65882 .68235 Mdot
.40784 .44706 Mdot
.13725 .25882 Mdot
.80784 .03529 Mdot
.27451 .30588 Mdot
.45098 .41961 Mdot
.56471 .56471 Mdot
.03529 .06275 Mdot
.07451 .12157 Mdot
.00392 .02353 Mdot
.36863 .35294 Mdot
.27451 .30588 Mdot
.52549 .50588 Mdot
.83922 .87451 Mdot
.04706 .07451 Mdot
.00784 .04706 Mdot
.05882 .12941 Mdot
.21176 .26275 Mdot
.2 .20784 Mdot
.40784 .40392 Mdot
.49804 .47451 Mdot
.61569 .63529 Mdot
.00392 .03922 Mdot
.36078 .52941 Mdot
.40392 .39216 Mdot
.12941 .13725 Mdot
.39608 .41961 Mdot
.50588 .48627 Mdot
.56471 .58039 Mdot
.06275 .11373 Mdot
.16471 .23922 Mdot
.06667 .07059 Mdot
.63529 .03137 Mdot
.28627 .31765 Mdot
.47451 .43137 Mdot
.59216 .60392 Mdot
.04706 .07451 Mdot
.20784 .31373 Mdot
.00784 .03137 Mdot
.38824 .35686 Mdot
.2549 .28235 Mdot
.46275 .43529 Mdot
.53333 .53333 Mdot
.26667 .29412 Mdot
.19216 .43529 Mdot
.00392 .04706 Mdot
.40392 .38039 Mdot
.16471 .17255 Mdot
.33725 .32157 Mdot
.53333 .52941 Mdot
.74902 .76863 Mdot
.2549 .36078 Mdot
.00392 .03137 Mdot
.40784 .39216 Mdot
.32941 .30588 Mdot
.37647 .4 Mdot
.47451 .46275 Mdot
.53725 .55294 Mdot
.03922 .06667 Mdot
.31373 .48627 Mdot
.06667 .09804 Mdot
.64706 .1098 Mdot
.04314 .0902 Mdot
.45098 .42745 Mdot
.57647 .58824 Mdot
.09412 .14118 Mdot
.13333 .18824 Mdot
.30196 .37647 Mdot
.36863 .3451 Mdot
.24314 .2902 Mdot
.49804 .47451 Mdot
.51373 .50588 Mdot
.77647 .79216 Mdot
.11765 .22353 Mdot
.24706 .36078 Mdot
.41176 .38039 Mdot
.24706 .2549 Mdot
.42745 .41961 Mdot
.4902 .48235 Mdot
.61961 .65098 Mdot
.46667 .61176 Mdot
.02353 .05098 Mdot
.41176 .39216 Mdot
.27451 .23922 Mdot
.33333 .34118 Mdot
.48627 .46667 Mdot
.76863 .78431 Mdot
.13333 .16471 Mdot
.00784 .04314 Mdot
.18431 .20392 Mdot
.62353 .00784 Mdot
.24706 .27843 Mdot
.47843 .45098 Mdot
.60392 .62353 Mdot
.0549 .08627 Mdot
.54118 .65882 Mdot
0 .02745 Mdot
.38824 .36078 Mdot
.04706 .06275 Mdot
.51373 .50196 Mdot
.46667 .46275 Mdot
.42353 .47451 Mdot
.29412 .40392 Mdot
.12941 .18824 Mdot
.41176 .4 Mdot
.26667 .26275 Mdot
.42353 .43529 Mdot
.46275 .45098 Mdot
.63137 .66667 Mdot
.29412 .34118 Mdot
.08627 .3098 Mdot
.38824 .37255 Mdot
.15294 .12157 Mdot
.27843 .31765 Mdot
.46667 .45882 Mdot
.78039 .78824 Mdot
.02353 .07059 Mdot
.00392 .04314 Mdot
.00392 .01176 Mdot
.32157 .28627 Mdot
.30196 .32157 Mdot
.54902 .53333 Mdot
.38431 .43922 Mdot
.07451 .11765 Mdot
.83529 .87843 Mdot
0 .01569 Mdot
.4 .36471 Mdot
.22745 .2549 Mdot
.46667 .46275 Mdot
.47843 .48235 Mdot
.27451 .3451 Mdot
.28627 .52157 Mdot
.00392 .03529 Mdot
.40392 .37647 Mdot
.23137 .19608 Mdot
.41176 .42745 Mdot
.47843 .47451 Mdot
.80784 .84314 Mdot
.15686 .21961 Mdot
.00784 .0549 Mdot
.33333 .37647 Mdot
.08627 0 Mdot
.35294 .38824 Mdot
.48627 .45882 Mdot
.58431 .60392 Mdot
.0549 .10196 Mdot
.16078 .21569 Mdot
.00784 .02745 Mdot
.37647 .36078 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.50588 .55686 Mdot
.21569 .38431 Mdot
.82353 .87059 Mdot
.21176 .31373 Mdot
.4 .38039 Mdot
.25098 .2549 Mdot
.30196 .31373 Mdot
.49412 .4902 Mdot
.6902 .72549 Mdot
.8549 .91765 Mdot
.01569 .05098 Mdot
.41176 .39608 Mdot
.08627 .05098 Mdot
.37255 .38824 Mdot
.82353 .83137 Mdot
.77255 .80392 Mdot
.02745 .07059 Mdot
.00784 .04314 Mdot
.08627 .23529 Mdot
.33333 .26667 Mdot
.12157 .14902 Mdot
.54902 .5098 Mdot
.52549 .54118 Mdot
.48235 .52157 Mdot
.81569 .85098 Mdot
.01569 .04706 Mdot
.38039 .35686 Mdot
.13333 .16471 Mdot
.42353 .42353 Mdot
.18431 .35294 Mdot
.31373 .33725 Mdot
.83529 .87059 Mdot
.60784 .72941 Mdot
.40784 .39608 Mdot
.28235 .2549 Mdot
.40392 .41961 Mdot
.47059 .45882 Mdot
.84706 .88627 Mdot
.23137 .44314 Mdot
.17255 .35686 Mdot
.41176 .38824 Mdot
.25098 .0549 Mdot
.41176 .43137 Mdot
.49804 .50588 Mdot
.56078 .58824 Mdot
.06667 .09412 Mdot
.18824 .24706 Mdot
.37255 .4549 Mdot
.38039 .3451 Mdot
.28627 .30196 Mdot
.4902 .47451 Mdot
.72941 .74902 Mdot
.30196 .55294 Mdot
.82745 .86275 Mdot
.53725 .59216 Mdot
.40392 .38039 Mdot
.08235 .10196 Mdot
.16078 .18431 Mdot
.10588 .32941 Mdot
.69412 .79608 Mdot
.83529 .86667 Mdot
.58824 .65882 Mdot
.40784 .38824 Mdot
.26667 .19608 Mdot
.3451 .38824 Mdot
.47059 .48235 Mdot
.82353 .84706 Mdot
.16863 .4 Mdot
.61569 .72941 Mdot
.42745 .42353 Mdot
.37255 .32941 Mdot
.37647 .41569 Mdot
.56863 .5451 Mdot
.68627 .71373 Mdot
.05098 .0902 Mdot
.82353 .85882 Mdot
.57647 .60392 Mdot
.38431 .36471 Mdot
.33333 .36471 Mdot
.39216 .38431 Mdot
.48627 .4902 Mdot
.23529 .47843 Mdot
.83529 .87451 Mdot
.7451 .79608 Mdot
.41569 .39608 Mdot
.04706 .01176 Mdot
.22353 .24314 Mdot
.45882 .47451 Mdot
.8549 .88235 Mdot
.84706 .87843 Mdot
.65882 .76078 Mdot
.43137 .42353 Mdot
.36078 .30588 Mdot
.14118 .18431 Mdot
.57255 .55294 Mdot
.60784 .64706 Mdot
.20784 .47059 Mdot
.82745 .86667 Mdot
.49412 .51765 Mdot
.39216 .37255 Mdot
.3098 .35686 Mdot
.46275 .44314 Mdot
.56863 .58431 Mdot
.12157 .2 Mdot
.83137 .86275 Mdot
.62353 .66275 Mdot
.41176 .40784 Mdot
.21569 .18039 Mdot
.47451 .49804 Mdot
.21176 .44314 Mdot
.84706 .8902 Mdot
.8549 .88627 Mdot
.37255 .48235 Mdot
.41961 .41569 Mdot
.1451 .02745 Mdot
.40392 .43137 Mdot
.62353 .61176 Mdot
.67059 .69412 Mdot
.8549 .88627 Mdot
.81961 .85882 Mdot
.53725 .55294 Mdot
.39608 .36078 Mdot
.18431 .21176 Mdot
.53333 .52549 Mdot
.84314 .86275 Mdot
.72157 .91373 Mdot
.83922 .87059 Mdot
.78431 .82353 Mdot
.41569 .38824 Mdot
.25882 .26667 Mdot
.43529 .45098 Mdot
.58431 .61176 Mdot
.83137 .87843 Mdot
.8549 .88235 Mdot
.56078 .63137 Mdot
.43137 .41176 Mdot
.15294 .07451 Mdot
.40784 .43922 Mdot
.53333 .63922 Mdot
.69412 .73333 Mdot
.8549 .88627 Mdot
.83137 .87451 Mdot
.55686 .57647 Mdot
.37255 .3451 Mdot
.36471 .40392 Mdot
.50588 .49412 Mdot
.61176 .63529 Mdot
.72157 .8549 Mdot
.8549 .88235 Mdot
.65882 .69412 Mdot
.40784 .39216 Mdot
.13333 .12157 Mdot
.33333 .3451 Mdot
.61569 .64706 Mdot
.78824 .9098 Mdot
.85882 .88627 Mdot
.5451 .64706 Mdot
.45882 .43529 Mdot
.13725 .0902 Mdot
.20784 .25098 Mdot
.12941 .46667 Mdot
.98039 1 Mdot
.87451 .90196 Mdot
.83922 .90196 Mdot
.58824 .61176 Mdot
.39216 .35686 Mdot
.35686 .4 Mdot
.56863 .57255 Mdot
.84706 .86667 Mdot
.91765 .9451 Mdot
.85098 .89804 Mdot
.79608 .81961 Mdot
.41176 .39216 Mdot
.32941 .35294 Mdot
.4549 .45098 Mdot
.76471 .81569 Mdot
.91373 .9451 Mdot
.86275 .89804 Mdot
.64706 .72157 Mdot
.47451 .46667 Mdot
.1098 .06275 Mdot
.29412 .30588 Mdot
.14902 .52157 Mdot
1 1 Mdot
.88235 .91373 Mdot
.77255 .86275 Mdot
.68235 .69804 Mdot
.40392 .36471 Mdot
.29804 .32941 Mdot
.56078 .56078 Mdot
.94902 .96471 Mdot
.91373 .95294 Mdot
.83922 .88235 Mdot
.76471 .8 Mdot
.44314 .42745 Mdot
.32549 .34118 Mdot
.50196 .50588 Mdot
.87451 .89804 Mdot
.92157 .98824 Mdot
.84706 .88627 Mdot
.35686 .4902 Mdot
.4902 .49412 Mdot
.18431 .11765 Mdot
.19216 .22353 Mdot
.23529 .63922 Mdot
.9451 .95686 Mdot
.84706 .8902 Mdot
.81569 .87059 Mdot
.62353 .64706 Mdot
.42353 .38824 Mdot
.31373 .34118 Mdot
.64706 .6549 Mdot
.99608 1 Mdot
.87451 .9098 Mdot
.82745 .87451 Mdot
.4902 .52941 Mdot
.46667 .46275 Mdot
.11373 .12157 Mdot
.57255 .59216 Mdot
.88235 .91373 Mdot
.89412 .98824 Mdot
.83137 .87843 Mdot
.43137 .54902 Mdot
.46275 .46667 Mdot
.23529 .12549 Mdot
.22353 .23922 Mdot
.30588 .69804 Mdot
.52157 .6549 Mdot
.85098 .8902 Mdot
.82353 .8902 Mdot
.53333 .5451 Mdot
.44706 .42745 Mdot
.06275 .1098 Mdot
.76863 .77647 Mdot
.76863 .82745 Mdot
.86667 .90196 Mdot
.83137 .97647 Mdot
.58039 .6549 Mdot
.43922 .43137 Mdot
.18039 .18039 Mdot
.64314 .65098 Mdot
.80784 .85098 Mdot
.81176 .92549 Mdot
.64706 .92941 Mdot
.33333 .63529 Mdot
.50588 .52157 Mdot
.23529 .12941 Mdot
.15294 .22353 Mdot
.23922 .61176 Mdot
.84706 .89412 Mdot
.62353 .9098 Mdot
.18039 .60392 Mdot
.34902 .5451 Mdot
.60784 .61961 Mdot
.22745 .25098 Mdot
.69804 .72157 Mdot
.8549 .88627 Mdot
.74902 .9451 Mdot
.17255 .5098 Mdot
.09804 .41176 Mdot
.42745 .40784 Mdot
.13333 .13333 Mdot
.63922 .6549 Mdot
.85098 .87843 Mdot
.71765 .94118 Mdot
.43137 .91373 Mdot
.04706 .18039 Mdot
.14902 .38824 Mdot
.12549 .02745 Mdot
.23922 .25882 Mdot
.15686 .41176 Mdot
.7098 .93725 Mdot
.66667 1 Mdot
.03137 .08627 Mdot
.03922 .18039 Mdot
.60392 .62353 Mdot
.37647 .41569 Mdot
.62745 .65098 Mdot
.56471 .87843 Mdot
.85882 1 Mdot
.03137 .09412 Mdot
.02745 .08235 Mdot
.34118 .47059 Mdot
.25882 .26275 Mdot
.60392 .62745 Mdot
.59608 .86275 Mdot
.83529 .99216 Mdot
.06667 .20392 Mdot
.32157 .38039 Mdot
.03922 .16078 Mdot
.04706 .03137 Mdot
.53333 .57255 Mdot
.54118 .78824 Mdot
.6 .99608 Mdot
.15686 .48235 Mdot
.53725 .55686 Mdot
0 .02353 Mdot
.37647 .32549 Mdot
.47451 .5098 Mdot
.62745 .74118 Mdot
.4902 .98039 Mdot
.18431 .44706 Mdot
.41961 .52157 Mdot
.57647 .59608 Mdot
.21961 .45882 Mdot
.27843 .28235 Mdot
.64706 .67843 Mdot
.45098 .97255 Mdot
.21569 .47843 Mdot
.06275 .10588 Mdot
.57255 .62745 Mdot
.01176 .05882 Mdot
.20392 .17647 Mdot
.58431 .60392 Mdot
.28235 .84314 Mdot
.27451 .52549 Mdot
.31765 .67843 Mdot
.58039 .64706 Mdot
.13725 .17647 Mdot
.22353 .17647 Mdot
.47451 .50196 Mdot
.21176 .73333 Mdot
.28235 .54118 Mdot
.57255 .99608 Mdot
.6 .67059 Mdot
0 .01176 Mdot
.69412 .07451 Mdot
.4 .43922 Mdot
.21961 .69412 Mdot
.22745 .4902 Mdot
.54902 .94902 Mdot
.34902 .4549 Mdot
.31373 .36863 Mdot
.06667 .18039 Mdot
.37647 .40392 Mdot
.2 .65882 Mdot
.18824 .45098 Mdot
.5098 .93333 Mdot
.05882 .09804 Mdot
.21176 .2902 Mdot
.59608 .63137 Mdot
.43137 .43529 Mdot
.16863 .61176 Mdot
.11373 .52157 Mdot
.44314 .93333 Mdot
.11765 .26667 Mdot
.10588 .20392 Mdot
.42745 .45882 Mdot
.4 .33333 Mdot
.18039 .58039 Mdot
.17647 .45882 Mdot
.4 .92157 Mdot
.46667 .95294 Mdot
.04314 .09804 Mdot
.47451 .4902 Mdot
.31373 .21176 Mdot
.14118 .47451 Mdot
.03922 .30588 Mdot
.37255 .8902 Mdot
.66275 .99608 Mdot
.05882 .1098 Mdot
.00392 .04706 Mdot
.55686 .0902 Mdot
.17647 .38824 Mdot
.13333 .33725 Mdot
.33725 .83529 Mdot
.88627 1 Mdot
.05098 .12549 Mdot
.00392 .03137 Mdot
.1451 .23922 Mdot
.40392 .47843 Mdot
.10196 .29804 Mdot
.28627 .79216 Mdot
.87451 .98039 Mdot
.06667 .14902 Mdot
.01961 .06275 Mdot
.42353 .50196 Mdot
.38431 .40392 Mdot
.10196 .25882 Mdot
.19216 .7098 Mdot
.64706 .89412 Mdot
.14118 .38824 Mdot
.06275 .18824 Mdot
.02745 .10588 Mdot
.38824 .39608 Mdot
.12157 .34902 Mdot
.23137 .76863 Mdot
.5451 .96078 Mdot
.2549 .68627 Mdot
.12549 .41176 Mdot
.01961 .06275 Mdot
.38431 .36863 Mdot
.11765 .43529 Mdot
.22745 .79216 Mdot
.48235 .97255 Mdot
.27843 .76078 Mdot
.17647 .58431 Mdot
.03137 .05882 Mdot
.36471 .3098 Mdot
.09412 .41961 Mdot
.41569 .95294 Mdot
.41569 .93333 Mdot
.31373 .76863 Mdot
.19608 .62353 Mdot
.03137 .14118 Mdot
.35294 .25882 Mdot
.09412 .41961 Mdot
.25882 .81961 Mdot
.37647 .88627 Mdot
.31765 .72549 Mdot
.24706 .53333 Mdot
.09412 .40392 Mdot
.34902 .24706 Mdot
.10588 .45098 Mdot
.23529 .78039 Mdot
.36078 .86667 Mdot
.38431 .61176 Mdot
.4902 .57647 Mdot
.13333 .47451 Mdot
.34118 .23137 Mdot
.11765 .4902 Mdot
.22353 .74902 Mdot
.34118 .83137 Mdot
.52157 .57647 Mdot
.7098 .7098 Mdot
.18824 .39608 Mdot
.3451 .17255 Mdot
.13725 .51765 Mdot
.26275 .78431 Mdot
.3451 .76863 Mdot
.59608 .60392 Mdot
.77255 .77255 Mdot
.35294 .4 Mdot
.34118 .12157 Mdot
.15294 .5451 Mdot
.23137 .73333 Mdot
.41176 .62745 Mdot
.67059 .67451 Mdot
.78431 .80784 Mdot
.38039 .37255 Mdot
.23529 .07451 Mdot
.14902 .55686 Mdot
.21176 .71373 Mdot
.55294 .57255 Mdot
.87843 .88235 Mdot
.49412 .52549 Mdot
.36471 .34902 Mdot
.07451 .12941 Mdot
.16078 .58039 Mdot
.14118 .61569 Mdot
.59608 .59216 Mdot
.56471 .58824 Mdot
.41961 .37647 Mdot
.34902 .31765 Mdot
.07843 .21569 Mdot
.16078 .58824 Mdot
.21961 .51765 Mdot
.78824 .78824 Mdot
.45098 .40392 Mdot
.39608 .2902 Mdot
.34118 .29804 Mdot
.03529 .0902 Mdot
.14902 .59216 Mdot
.52157 .53333 Mdot
.54902 .58039 Mdot
.41176 .30588 Mdot
.38039 .28627 Mdot
.32549 .28627 Mdot
.09804 .36863 Mdot
.18824 .62353 Mdot
.60784 .6 Mdot
.43922 .37255 Mdot
.36471 .24314 Mdot
.39608 .3098 Mdot
.30588 .25098 Mdot
.13333 .52157 Mdot
.28235 .52549 Mdot
.60784 .63137 Mdot
.39216 .2902 Mdot
.37255 .25882 Mdot
.38431 .28627 Mdot
.27843 .20392 Mdot
.09412 .47843 Mdot
.56078 .57647 Mdot
.36078 .27843 Mdot
.38824 .26275 Mdot
.36078 .2549 Mdot
.36863 .25882 Mdot
.1451 .03529 Mdot
.12941 .53333 Mdot
.76078 .74902 Mdot
.40392 .28627 Mdot
.37255 .25098 Mdot
.39608 .29412 Mdot
.35686 .25098 Mdot
.07843 .15686 Mdot
.17647 .43137 Mdot
.39608 .38039 Mdot
.41569 .31765 Mdot
.36863 .25098 Mdot
.38039 .2902 Mdot
.33725 .27843 Mdot
.12549 .45098 Mdot
.56863 .56471 Mdot
.46275 .38431 Mdot
.43922 .33333 Mdot
.37255 .25098 Mdot
.37647 .27451 Mdot
.27843 .2 Mdot
.11765 .49412 Mdot
.68627 .69412 Mdot
.52157 .46275 Mdot
.41961 .32941 Mdot
.35686 .23529 Mdot
.41569 .33333 Mdot
.33725 .24314 Mdot
.15294 .42353 Mdot
.52549 .4549 Mdot
.55686 .49412 Mdot
.39216 .31373 Mdot
.36078 .27451 Mdot
.36863 .28627 Mdot
.14118 .02745 Mdot
.65098 .64314 Mdot
.57255 .59608 Mdot
.45098 .39608 Mdot
.40784 .34902 Mdot
.41569 .38039 Mdot
.34902 .30588 Mdot
.16471 .52549 Mdot
.35686 .31373 Mdot
.42745 .39216 Mdot
.52157 .48235 Mdot
.34118 .32157 Mdot
.37255 .32157 Mdot
.41961 .36471 Mdot
.25098 .43137 Mdot
.39608 .28627 Mdot
.41569 .31765 Mdot
.23137 .21569 Mdot
.27059 .24314 Mdot
.44706 .38431 Mdot
.38431 .29804 Mdot
.55686 .54902 Mdot
.38431 .2549 Mdot
.47059 .41961 Mdot
.33333 .30588 Mdot
.22353 .18039 Mdot
.34118 .30588 Mdot
.26667 .61961 Mdot
.40392 .3098 Mdot
.40392 .2902 Mdot
.43137 .4 Mdot
.39216 .33333 Mdot
.41176 .36078 Mdot
.44314 .40784 Mdot
.45098 .42745 Mdot
.41176 .27451 Mdot
.39608 .33333 Mdot
.51373 .47059 Mdot
.43922 .33333 Mdot
.37647 .32157 Mdot
.6549 .04706 Mdot
.40392 .28627 Mdot
.4 .25882 Mdot
.7098 .69412 Mdot
.41961 .26667 Mdot
.39608 .30588 Mdot
.50196 .46667 Mdot
.38824 .31765 Mdot
.41176 .2902 Mdot
.40392 .31373 Mdot
.5098 .43922 Mdot
.38039 .26275 Mdot
.42353 .4 Mdot
.35686 .17647 Mdot
.40784 .28235 Mdot
.39216 .27451 Mdot
.44314 .39216 Mdot
.37255 .25098 Mdot
.42353 .32549 Mdot
.54902 .52549 Mdot
.30588 .16863 Mdot
.40392 .27059 Mdot
.78431 .76471 Mdot
.3451 .33333 Mdot
.43137 .38039 Mdot
.59608 .59216 Mdot
.3098 .18824 Mdot
.41569 .29804 Mdot
.4 .21961 Mdot
.4549 .40392 Mdot
.48235 .43922 Mdot
.62353 .61569 Mdot
.38431 .27843 Mdot
.34118 .1451 Mdot
.36863 .19608 Mdot
.45882 .38824 Mdot
.44706 .37255 Mdot
.52157 .46667 Mdot
.59608 .59608 Mdot
.35686 .27843 Mdot
.43922 .33725 Mdot
.38039 .23529 Mdot
.63137 .64314 Mdot
.48627 .41176 Mdot
.71373 .71765 Mdot
.23922 .16471 Mdot
.41569 .28627 Mdot
.46275 .36078 Mdot
.6 .57255 Mdot
.53725 .52157 Mdot
.78824 .79608 Mdot
.37255 .19216 Mdot
.40784 .29412 Mdot
.44706 .32157 Mdot
.53725 .42353 Mdot
.64706 .63922 Mdot
.8902 .89412 Mdot
.33725 .07843 Mdot
.41569 .32941 Mdot
.45882 .3451 Mdot
.45882 .29804 Mdot
.59608 .48627 Mdot
.92157 .93725 Mdot
.35686 .0902 Mdot
.39608 .33333 Mdot
.46275 .36863 Mdot
.56078 .42745 Mdot
.8902 .81569 Mdot
.85882 .8902 Mdot
.3451 .19608 Mdot
.38824 .32157 Mdot
.4549 .37647 Mdot
.63137 .55294 Mdot
.99608 .98824 Mdot
.81569 .84706 Mdot
.34902 .30196 Mdot
.4902 .43922 Mdot
.52941 .45098 Mdot
.88235 .84706 Mdot
.99216 .99608 Mdot
.73725 .74118 Mdot
.43137 .38824 Mdot
.47843 .42745 Mdot
.61176 .56078 Mdot
.99216 .99216 Mdot
.87451 .89412 Mdot
.35686 .16471 Mdot
.42745 .36078 Mdot
.57647 .55294 Mdot
.99608 .99216 Mdot
.89412 .9098 Mdot
.76863 .78039 Mdot
.47451 .43137 Mdot
.59608 .58431 Mdot
1 .99216 Mdot
.97255 .98039 Mdot
.82353 .82745 Mdot
.45098 .41569 Mdot
.57647 .55294 Mdot
.92157 .92157 Mdot
.97647 .98039 Mdot
.83529 .84314 Mdot
.43137 .38824 Mdot
.60784 .59216 Mdot
.90196 .90588 Mdot
.92157 .92941 Mdot
.83137 .84706 Mdot
.46275 .43137 Mdot
.67059 .66275 Mdot
.98824 .99216 Mdot
.93333 .92941 Mdot
.52549 .44314 Mdot
.53725 .51373 Mdot
.89804 .90588 Mdot
.96078 .96078 Mdot
.85098 .8549 Mdot
.48235 .43922 Mdot
.7451 .7451 Mdot
.96863 .96471 Mdot
.8902 .8902 Mdot
.38824 .2549 Mdot
.72549 .72549 Mdot
.93333 .93725 Mdot
.90196 .9098 Mdot
.4902 .41569 Mdot
.83529 .83922 Mdot
.91765 .92941 Mdot
.77255 .18824 Mdot
.6902 .68627 Mdot
.94118 .94118 Mdot
.78039 .20784 Mdot
.69804 .67451 Mdot
.65882 .59608 Mdot
.49804 .32157 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002@3ooonf
o`000=40oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0c`3oool000T0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`3?0?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooo`800000
00?o00000?ooo`3oool0[03oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?oo
o`3oool300000003o`000000000000000:L00000103oool00ol00000oooo0?ooo`3?0?ooo`002@3o
ool01_l00000oooo0?ooo`3ooooo000004a<C080000000?o6ATI000000000000YP0000040?ooo`03
o`00003oool0oooo0<l0oooo00090?ooo`07o`00003oool0oooo0?ooo`1VIVKo000004a<C0020000
0003oaTI6@00003o00000:D00000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000
oooo0?ooo`3oool206IVIP0300000?l00000<c<c0080000000?o6ATI000000000000X`0000040?oo
o`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooo`<0IVIV0P00000203<c
<`0300000?lI6AT000000:<00000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000
oooo0?ooo`3oool206IVIP@0000000@0<c<c00000?lI6AWo6ATIX`0000040?ooo`03o`00003oool0
oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooo`80000000<0Ogmo0000000000000P000000
1?l00000000000000?l0002R000000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co0000
0?ooo`3oool0oooo0P00000307moO`@0000000<0<c<c00000?lI6AT0X@0000040?ooo`03o`00003o
ool0oooo0<l0oooo00090?ooo`07o`00003oool0oooo0?ooo`000000IVIV0000000407moO`04o`00
000000000000000000?o6ATIW`0000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00
003oool0oooo0?ooo`80000000<0IVIV0000001oOgl00`1oOgl500000003oaTI6Ol00000000009d0
0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3oool4000000D0
Ogmo00<00000o`00001<C4`00P000002oaTI6Id00000103oool00ol00000oooo0?ooo`3?0?ooo`00
2@3oool01_l00000oooo0?ooo`3oool0000003<c<`<000001@1oOgl20000000304a<C00000000000
00;o6ATIW00000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`07o`00003oool0oooo0?oo
ool00000000003<c<`02000000@0Ogmo10000000101<C4`0000000000?lI6AVL000000@0oooo00?o
00000?ooo`3oool0R`3oool2o`000480oooo00090?ooo`07o`00003oool0oooo0?ooo`00003o6ATI
o`00000600000080VIVI0`0000001?l00000000000000?lI6AVK000000@0oooo00?o00000?ooo`3o
ool0R03oool3o`0000030?ooool00000oooo0440oooo00090?ooo`04o`00003oool0oooo0?ooo`80
00000_lI6AT20000000304a<C0000000000000D0VIVI0`0000000ol000000000oaTI6@2I000000@0
oooo00?o00000?ooo`3oool0QP3oool2o`0000<0oooo00<0ZKgXo`000?l00000@@3oool000T0oooo
00Co00000?ooo`3oool0oooo0`000002oaTI6@D00000102IVIT40000000303<c<`00003o6ATI09P0
0000103oool00ol00000oooo0?ooo`230?ooo`?o00000P3oool40:Vmj003o`00003ooooo00000400
oooo00090?ooo`04o`00003oool0oooo0?ooo`<0000000Co000000000?lI6AWo0000100000000`2I
VIT000000000000400000004o`00000c<c<00000oaTI6IL00000103oool00ol00000oooo0?ooo`20
0?ooo`?o00000P3oool70:Vmj003o`00003ooooo00000400oooo00090?ooo`04o`00003oool0oooo
0?ooo`H0000000So6ATI0000000000000000o`0000000000VIVI00000080/k>c100000001?l00000
0000oaTI6OlI6AVE000000@0oooo00?o00000?ooo`3oool0OP3oool2o`0000<0oooo2@2Y_NP01?l0
0000ZKgX0?ooool0000o0?ooo`002@3oool01?l00000oooo0?ooo`3oool700000004oaTI6@000000
0000o`000080000000H0VIVI0000002c/k<0/k>co`00002IVIT500000003oaTI6@00000000000980
0000103oool00ol00000oooo0?ooo`1k0?ooo`?o00000P3oool<0:Vmj005o`00002Y_NP0oooo0?oo
ool00000?P3oool000T0oooo00Co00000?ooo`3oool0oooo200000000olI6AT00000000000030000
0006o`00002c/k<0/k>c0;>c/`000000VIVI0_l0000010000000<c<c00000?lI6AVC000000@0oooo
00?o00000?ooo`3oool0N@3oool2o`0000<0oooo3P2Y_NP01Ol00000ZKgX0:Vmj03ooooo000003h0
oooo00090?ooo`04o`00003oool0oooo0?ooo`P0000000?o6ATI0000000c<c<00P0000000`1oOgoo
0000000000030;>c/`D0000000Co0000oaTI6OlI6AWo0000T@0000040?ooo`03o`00003oool0oooo
07H0oooo0ol000020?oooa40ZKgX00Ko00000:Vmj02Y_NP0ZKgX0?ooool0000m0?ooo`002@3oool0
1?l00000oooo0?ooo`3oool900000003oaTI6@000000<c<c00<0000000<0VIVI0000002c/k<00P2c
/k<6000000?o6ATIT00000040?ooo`03o`00003oool0oooo07@0oooo0_l000020?oooa@0ZKgX00?o
00000:Vmj02Y_NP00P2Y_NP00ol00000oooo0?ooo`0k0?ooo`002@3oool01?l00000oooo0?ooo`3o
ool:00000003oaTI6@000000<c<c00<0000000H0VIVI0000002c/k<0/k>co`00002c/k<5000000?o
6ATIS`0000040?ooo`03o`00003oool0oooo0740oooo0ol000020?oooaH0ZKgX00?o00000:Vmj02Y
_NP00`2Y_NP00ol00000oooo0?ooo`0j0?ooo`002@3oool01?l00000oooo0?ooo`3oool>000000;o
000000D00000o`00002c/k?o00000<c<c00200000003o`000000003o00000080000000?o0000oaTI
6OlI6AT0SP0000040?ooo`03o`00003oool0oooo06h0oooo0ol000020?oooaT0ZKgX00?o00000:Vm
j02Y_NP00`2Y_NP00`3ooooo00000?ooo`0j0?ooo`002@3oool01?l00000oooo0?ooo`3oool=0000
0005oaTI6@000000000000000?l000000P0000030<c<c0@0000000?o00000000000000000_lI6AV=
000000@0oooo00?o00000?ooo`3oool0K03oool2o`0000<0oooo702Y_NP00ol00000ZKgX0:Vmj003
0:Vmj003o`00003oool0oooo03T0oooo00090?ooo`04o`00003oool0oooo0?ooo`h0000000?o6ATI
0000000000001@0000020<c<c0L000000_lI6AV<000000@0oooo00?o00000?ooo`3oool0J@3oool3
o`000080oooo7`2Y_NP00ol00000ZKgX0:Vmj0030:Vmj0030?ooool00000oooo03T0oooo00090?oo
o`04o`00003oool0oooo0?ooo`l0000000?o6ATI00000?l000000`0000000ol0000000000<c<c002
0<c<c00300000?l00000000000<0000000Co0000oaTI6@00003o00001`000008oaTI6GX00000103o
ool00ol00000oooo0?ooo`1W0?ooo`;o00000`3ooolQ0:Vmj003o`00002Y_NP0ZKgX00@0ZKgX00<0
ooooo`00003oool0>03oool000T0oooo00Co00000?ooo`3oool0oooo3`0000000olI6AT000000000
000200000003o`0000000000000000<0c<c<1@0000000ol000000000oaTI6@03oaTI6@<000003?lI
6AT00ol0000000000000001f000000@0oooo00?o00000?ooo`3oool0I03oool3o`000080oooo902Y
_NP00ol00000ZKgX0:Vmj0040:Vmj0030?ooool00000oooo03P0oooo00090?ooo`04o`00003oool0
oooo0?oooa00000000?o6ATI0000000000001@0000030<c<c0L000001?lI6AT00`00003o6ATIoaTI
6@0=oaTI6GL00000103oool00ol00000oooo0?ooo`1R0?ooo`;o00000`3ooolV0:Vmj003o`00002Y
_NP0ZKgX00D0ZKgX00<0ooooo`00003oool0=`3oool000T0oooo00Co00000?ooo`3oool0oooo4@00
00000olI6AT000000000000500000080c<c<00Go00000<c<c00000000000o`000004000001?o6ATI
MP0000040?ooo`03o`00003oool0oooo05l0oooo0ol000020?ooo`80Z[gX9`2Y_NP00ol00000ZKgX
0:Vmj0060:Vmj0030?ooool00000oooo03H0oooo00090?ooo`04o`00003oool0oooo0?oooa800000
00?o6ATIo`000?l0000010000002o`0000040>KVi_l0003o0000o`0000H000005?lI6AUd000000@0
oooo00?o00000?ooo`3oool0G@3oool2o`0000<0oooo00<0Z[gW0:Zmj02Z_NP00P2Z_NP00`2Y_NP0
Z[gX0:Vmj00S0:Vmj003o`00002Y_NP0ZKgX00L0ZKgX00?o00000?ooo`3oool0=@3oool000T0oooo
00Co00000?ooo`3oool0oooo4`0000000olI6AT000000000000200000004o`0000000000c<c<o`00
0080i^KV00Go00000000000000000000o`000003000001Go6ATILP0000040?ooo`03o`00003oool0
oooo05X0oooo0ol000020?ooo`D0Z[gW0P2Z_NP0102Z_NL0Z[gX0:Zmj02Z_NP20:Vmj0030:Zmj02Y
_NP0ZKgX01h0ZKgX00?o00000:Vmj02Y_NP0202Y_NP00ol00000oooo0?ooo`0d0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolD000000;o6ATI1@0000001P3<c<co00000>KViP3Vi^Ko00000<c<c0L0
00005OlI6AU`000000@0oooo00?o00000?ooo`3oool0E`3oool3o`0000<0oooo2`2Z_NL60:Zmj080
ZKgX0P2Z_NP00`2Y_NP0Z[gX0:Zmj00H0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX00<0ooooo`00003o
ool0=03oool000T0oooo00Co00000?ooo`3oool0oooo5@000002oaTI6@D000000_l000020>KViP03
o`00003<c<co000000@0000000<0<c<c00000?lI6AT05?lI6AU_000000@0oooo00?o00000?ooo`3o
ool0E@3oool2o`0000<0oooo3`2Z_NL=0:Zmj1L0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP00ol00000
oooo0?ooo`0c0?ooo`002@3oool01?l00000oooo0?ooo`3ooolF00000003oaTI6@00000000000080
000000Co000000000000003o00000P3Vi^H00ol0000000000;>c/`0200000003o`00000000000000
01Oo6ATIK@0000040?ooo`03o`00003oool0oooo0580oooo0ol000030?oooaD0Z[gW0P2Z_NP00`2Z
_NL0Z[gX0:Zmj0040:Zmj1L0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP00`3ooooo00000?ooo`0c0?oo
o`002@3oool01?l00000oooo0?ooo`3ooolG00000003oaTI6@000000000000D0000000Ko00000>KV
iP3Vi^Ko00000000002c/k<6000001Ko6ATIK00000040?ooo`03o`00003oool0oooo0500oooo0_l0
00040?oooa/0Z[gW1P2Z_NP20:Vmj0030:Zmj02Y_NP0ZKgX0140ZKgX00?o00000:Vmj02Y_NP02P2Y
_NP00ol00000oooo0?ooo`0b0?ooo`002@3oool01?l00000oooo0?ooo`3ooolH00000003oaTI6@00
0000000000D0000000Oo00000>KViP3Vi^Ko00000000002c/k?o000000<0000000<0<c<c00000?lI
6AT05OlI6AU[000000@0oooo00?o00000?ooo`3oool0C@3oool3o`0000<0oooo0P2Z_>LL0:Zmi`X0
Z[gX00@0ZKgX0:Zmj02Z_NP0Z[gX3P2Y_NP00ol00000ZKgX0:Vmj00:0:Vmj0030?ooool00000oooo
0380oooo00090?ooo`04o`00003oool0oooo0?oooaT0000000?o6ATIo`000?l0000010000002o`00
0080i^KV0_l0000200000003o`000000003o0000008000005_lI6AT00ol0000000000000001W0000
00@0oooo00?o00000?ooo`3oool0B`3oool2o`0000@0oooo1@2Z_>L00`2Z_NL0Z[cW0:Zli`020:Zm
i`030:^mi`2Z_NL0Z[gW01@0Z[gW0P2Z_NP00`2Z_NL0Z[gX0:Zmj0080:Zmj0h0ZKgX00?o00000:Vm
j02Y_NP02`2Y_NP00`3ooooo00000?ooo`0a0?ooo`002@3oool01?l00000oooo0?ooo`3ooolJ0000
0003oaTI6@00000000000080000000Co000000000000003o00000`3Vi^H00ol00000000000000002
0000000404a<C000003o0000000001Go6ATIJ@0000040?ooo`03o`00003oool0oooo04P0oooo0ol0
00030?ooo`80ZkcV1@2Z_>L20:^liP030:Zli`2[_>H0ZkcV00<0ZkgW0P2Z_NL00`2[_NL0Z[gW0:Zm
i`0D0:Zmi`040:Zmj02Z_NL0Z[gW0:Zmi`H0Z[gX00<0ZKgX0:Zmj02Y_NP02P2Y_NP00ol00000ZKgX
0:Vmj00<0:Vmj003o`00003oool0oooo0300oooo00090?ooo`04o`00003oool0oooo0?oooa/00000
0_lI6AT200000005o`0000000000000000000?l000000`3Vi^H00ol0000000000000000200000004
04a<C0000000<c<c000001Go6ATIJ00000040?ooo`03o`00003oool0oooo04D0oooo0ol000040?oo
o`D0ZkcV00<0Z[cW0:^liP2[_>H01`2[_>H00`2[_NL0ZkcV0:^liP030:^mi`030:Zmi`2[_NL0ZkgW
01H0Z[gW2@2Z_NP:0:Vmj003o`00002Y_NP0ZKgX00`0ZKgX00<0ooooo`00003oool0<03oool000T0
oooo00Co00000?ooo`3oool0oooo6`0000001?l0003o6ATIoaTI6Ol00004000000;o000000@0i^KV
o`00003Vi^Ko000010000000101<C4co000003<c<`00000FoaTI6FH00000103oool00ol00000oooo
0?ooo`130?ooo`;o00001@3ooolE0:^liP030:^mi`2[_>L0ZkgW00<0ZkgW00<0Z[gW0:^mi`2Z_NL0
4`2Z_NL00`2Z_NP0Z[gW0:Zmi`060:Zmj0T0ZKgX00?o00000:Vmj02Y_NP03@2Y_NP00`3ooooo0000
0?ooo`0_0?ooo`002@3oool01?l00000oooo0?ooo`3ooolL000000?o6ATI0`0000000ol000000000
00000002o`0000030>KVi_l00000c<c<00D0000000<0<c<co`00000000001olI6AT5000000[o6ATI
I@0000040?ooo`03o`00003oool0oooo0400oooo0ol000040?oooaP0ZkcV0`2[_>L60:^mi`80Z[gW
0P2[_NL20:Zmi`030:^mi`2Z_NL0Z[gW00h0Z[gW1P2Z_NP00`2Y_NP0Z[gX0:Zmj0050:Vmj003o`00
002Y_NP0ZKgX00d0ZKgX00<0ooooo`00003oool0;`3oool000T0oooo00Co00000?ooo`3oool0oooo
7@000002oaTI6@030000000c<c<0000000@000000_l000000`3Vi^Ko0000o`00000500000080<c<c
0P000002oaTI6@<000001@0c<c<2000000Wo6ATII00000040?ooo`03o`00003oool0oooo03h0oooo
0_l000050?ooo`80Zk_V0P2[_>H00`2[^nD0ZkcV0:^liP0D0:^liP060:^li`2[_>H0ZkcV0:^liP2[
_NL0ZkgV2P2[_NL@0:Zmi`T0Z[gX102Y_NP00ol00000ZKgX0:Vmj00>0:Vmj0030?ooool00000oooo
02h0oooo00090?ooo`04o`00003oool0oooo0?oooah000000_lI6AT00`000000<c<co`0000040000
00;o00000P3Vi^H00ol000000000o`00000400000080<c<c0P00000:03<c<`0300000?lI6AWo6ATI
00Oo6ATIH`0000040?ooo`03o`00003oool0oooo03/0oooo0ol000020?ooo`D0Zk_U00<0Zk_V0:^k
i@2[^nD00`2[^nD20:^liP030:^ki@2[_>H0ZkcV00<0ZkcV00<0ZkcU0:^liP2[_>H03P2[_>H30:^m
iP80ZkgW00<0ZkgV0:^mi`2[_NL0102[_NLC0:Zmi`L0Z[gX00@0ZKgX0:Zmj02Y_NSo00004@2Y_NP0
0`3ooooo00000?ooo`0]0?ooo`002@3oool01?l00000oooo0?ooo`3ooolN00000005o`000000003o
6ATIo`00000c<c<010000004o`0000030>KVi_l00000000000D000003P0c<c<00`00003o0000oaTI
6@07oaTI6F800000103oool00ol00000oooo0?ooo`0i0?ooo`;o00000`3ooolA0:^ki@030:^liP2[
^nD0Zk_U00<0ZkcU00@0ZkcV0:^li@2[_>D0ZkcU302[_>H00`2[_NH0ZkcV0:^liP030:^miPH0ZkgW
0P2Z_NL20:^mi`l0Z[gW2@2Z_NP00ol00000ZKgX0:Vmj00@0:Vmj003o`00003oool0oooo02`0oooo
00090?ooo`04o`00003oool0oooo0?ooob40000000Ko6ATI000000000000000004a<C?l000020000
00;o00000P3Vi^H00ol00000000000000004000000l0<c<c00<00000oaTI6OlI6AT01_lI6AT00ol0
000000000000001N000000@0oooo00?o00000?ooo`3oool0=P3oool3o`0000<0oooo00<0Z[_U0:^k
i@2[^nD0502[^nD00`2[_>D0[;_U0:bki@020:^li@D0[;cU00<0ZkcV0:bli@2[_>H02@2[_>H20:^m
iPh0ZkgW302Z_NL80:Zmj003o`00002Y_NP0ZKgX0140ZKgX00?o00000?ooo`3oool0:`3oool000T0
oooo00Co00000?ooo`3oool0oooo8P000002oaTI6@80000000<0C4a<0000000000000P0000001_l0
0000i^KV0>KVi_l000000000o`0000D000003P0c<c<00`00003o6ATIoaTI6@06oaTI6F000000103o
ool00ol00000oooo0?ooo`0c0?ooo`?o0000103oool0102Z^^D0Z[_U0:Zki@2Z^nD20:^ki@030:^j
i@2[^nD0Zk_U00l0Zk_U1@2/^nD90:bli@80ZkcV00<0[;cV0:^liP2[_>H01@2[_>H20:^miP80ZkgW
0P2[_NH90:^mi`d0Z[gW1`2Z_NP00ol00000Z[gX0:Zmj0020:Zmj0l0ZKgX00?o00000?ooo`3oool0
:`3oool000T0oooo00Co00000?ooo`3oool0oooo8P0000001_l0003o6ATIoaTI6Ol00000000004a<
C080000000?o000000000?l000000P3Vi^H00ol000000000000000030000000304a<C0000000<c<c
00d0<c<c00<00000o`00000000001_lI6AUO000000@0oooo00?o00000?ooo`3oool0<@3oool2o`00
00@0oooo1@2Z^^D00`2Z^nD0Zk[U0:^ji@030:^ji@030:^ki@2[^^D0Zk[U00X0Zk_U102/^nD20:bk
i0<0[;_U00<0[;cU0:bki@2/^nD01P2/_>D30:bliP060:^liP2/_>H0[;cV0:bliP2[_>H0[;cV1P2[
_NH:0:^mi`030:Zmi`2[_NL0Z[gW00`0Z[gW1@2Z_NP01?l00000Z[gX0:Zmj02Z_NP@0:Vmj003o`00
003oool0oooo02X0oooo00090?ooo`04o`00003oool0oooo0?ooob<000000olI6AT300000005o`00
00000000000000000?l000000P3Vi^H01?l00000c<c<0000002c/k<20000000304a<C?l00000<c<c
00l0<c<c00<00000oaTI6OlI6AT01OlI6AUM000000@0oooo00?o00000?ooo`3oool0;P3oool3o`00
00@0oooo202Z^^D40:^ji@80Zk[T0`2[^^D01P2[^nD0Zk[T0:^ji02[^^@0Zk_U0:bji0@0[;_T00<0
[;_U0:bki02/^n@00`2/^n@00`2/^nD0[;_T0:bki@030:bki@H0[;cU00<0[;cV0:bli@2/_>D00P2/
_>H0102/_>D0[;cV0:bliP2/_>H20:^miP040:bmiP2[_NH0ZkgV0:^miP80ZkgW00<0ZkgV0:^mi`2[
_NL01`2[_NL20:Zmi`80ZkgW2@2Z_NL40:Zmj003o`00002Z_NP0Z[gX0080Z[gX402Y_NP00ol00000
oooo0?ooo`0Y0?ooo`002@3oool01?l00000oooo0?ooo`3ooolT000000;o6ATI00<0000003<c<`00
0000100000001_l00000i^KV0>KViP3Vi^Ko00000<c<c0@0000000<0C4a<0000000c<c<03`0c<c<0
0`00003o6ATIoaTI6@04oaTI6Ed00000103oool00ol00000oooo0?ooo`0/0?ooo`;o00001@3oool0
0`2Y^^D0Z[[U0:Zji@080:Zji@030:^ji@2[^^@0Zk[T00<0Zk[T00<0Zk[U0:^ji02[^^@00P2[^^@4
0:bji080[;_T00<0[;[T0:bki02/^n@01`2/^n@20:bki@030:bki02/_>D0[;cU00/0[;cU0`2/_>H3
0:bmiP030:^miP2/_NH0[;gV00<0ZkgV302[_NL:0:Zmi`<0Z[gX00?o00000:Zmj02Z_NP00`2Z_NP2
0:Vmj0030:Zmj02Y_NP0ZKgX00X0ZKgX00?o00000?ooo`3oool0:@3oool000T0oooo00Co00000?oo
o`3oool0oooo9@000002oaTI6@030000000c<c?o000000@0000000Oo00000>KViP3Vi^H0i^KVo`00
003<c<co000000<0000000<0C4a<0000000c<c<03P0c<c<00`00003o6ATIoaTI6@05oaTI6E`00000
103oool00ol00000oooo0?ooo`0Y0?ooo`?o00001@3oool40:Vji@P0Z[[U0P2Z^^@00`2[^^@0ZkWT
0:^ii0060:^ji0T0[;[T00<0[;_T0:bji02/^^@0102/^n@30:fki080[;_T00H0[;cU0:fli@2]_>D0
[KcU0:bli@2]_>D60:bli@@0[;cV1P2/_NH00`2[_NH0[;gV0:bmiP020:^mi`030:^miP2[_NL0ZkgW
00L0ZkgW0P2Z_NL00`2[_NL0Z[gW0:Zmi`050:Zmi`80Z[gX00?o00000:Zmj02Z_NP01`2Z_NP<0:Vm
j003o`00003oool0oooo02P0oooo00090?ooo`04o`00003oool0oooo0?ooobD0000000Go0000oaTI
6OlI6AWo000003<c<`0300000004o`000000003o0000o`000080i^KV00Co000000000000003o0000
100000000ol0000000000000000203<c<`80000000?o00000000000000001@0c<c<2000000Ko6ATI
F`0000040?ooo`03o`00003oool0oooo02L0oooo0_l000050?ooo`<0ZKWU0`2Y^^D30:Vii0030:Zj
i@2Z^N@0Z[WT00<0Z[WT00<0Z[[T0:^ii02[^N@00`2[^N@00`2[^^@0ZkWT0:^ji0030:^ji0`0[;[T
00<0[;_T0:fki02]^n@01P2]^n@20:fli@040:fki02]_>D0[KcU0:fli@80[;cU00@0[KcU0:bli@2/
_>D0[;cU0P2/_>H20:bli@P0[;gV102[_NH<0:^mi`H0Z[gW0P2Z_NP00ol00000Z[gX0:Zmj0070:Zm
j0d0ZKgX00?o00000?ooo`3oool09`3oool000T0oooo00Co00000?ooo`3oool0oooo9`000002oaTI
6@80000000<0<c<c0000000000000`0000001?l00000i^KV0>KVi_l00006000000<0C4a<0P000005
04a<C08000001@0c<c<00`00003o6ATIoaTI6@04oaTI6@03o`0000000000000005L00000103oool0
0ol00000oooo0?ooo`0T0?ooo`?o00000`3oool00`2Y^>@0ZKWT0:Vii0020:Vii0030:Vii@2Y^><0
ZKST00<0ZKST00<0ZKWT0:Zhh`2Z^N@0102Z^N@00`2Z^><0ZkWT0:^ii0030:^ii0040:^ih`2[^N@0
ZkWT0:^ii080Zk[T00<0[;WS0:bji02/^^@00`2/^^@00`2/^^<0[;[T0:bji0030:bji080[K[S00<0
[K_T0:fkh`2]^n<02@2]^n@00`2]_>D0[KcT0:fli0030:fli@060:bli@2]_>D0[KcU0:fli@2/_>D0
[KcU2@2/_NH20:^miP030:bmiP2[_NL0ZkgW00/0ZkgW1P2Z_NL00`2Z_NSo00000:Zmj0090:Zmj0`0
ZKgX00?o00000?ooo`3oool09`3oool000T0oooo00Co00000?ooo`3oool0oooo:0000003oaTI6@03
0000000c<c?o000000@0000000Co00000>KViP3Vi^Ko00001P00000;04a<C0800000100c<c<00`00
003o6ATIoaTI6@04oaTI6ET00000103oool00ol00000oooo0?ooo`0R0?ooo`;o0000103oool0102Y
^N@0ZKST0:Vhi02Y^>@20:Vii0040:Zgh`2Y^><0ZKSS0:Vhh`80ZKST00@0Z[OR0:Zhh`2Z^><0Z[SS
0P2Z^N@01@2Z]n80Z[SS0:Zhh`2Z^><0ZkWT0080ZkSS0`2[^N<00`2[^N@0ZkWS0:^ih`030:bih`03
0:bji02/^N<0[;WS00<0[;[S00<0[;[T0:fjh`2]^^<00`2]^^<40:fkh`030:fki02]^n<0[K_T00D0
[K_T102]_>@90:fli@030:bmiP2]_ND0[KgU00T0[;gV302[_NL70:Zmi`03o`00002Z_NL0Z[gX00T0
Z[gX00<0ZKgX0:Zmj02Y_NP02@2Y_NP00ol00000oooo0?ooo`0V0?ooo`002@3oool01?l00000oooo
0?ooo`3ooolY000000?o6ATI00Oo000003<c<`00003o000000000?l00000000000Go00000P000000
0ol000000000o`00000<04a<C08000000`0c<c<2000000Go6ATIF00000040?ooo`03o`00003oool0
oooo01l0oooo0ol000040?ooo`050:Rii@2Y^N@0ZKWT0:Vii02Y^>@00P2Y]n<30:Zgh`030:Vhh`2Z
]^80Z[KR00<0Z[OR00<0Z[SS0:^fh@2[]^400`2Z]n800`2Z^><0ZkOR0:^ghP030:^hh`030:^ih`2[
^>80ZkSR00<0ZkWS1P2/^N<00`2/^^<0[K[S0:fjh`060:fjh`80[K_S00@0[K[S0:fkh`2]^n<0[K_S
0P2]^n@20:jki080[K_T102]_>@00`2]_>D0[KcT0:fli@040:fli@D0[KgU2@2/_NH20:^mi`030:bm
iP2[_NL0ZkgW00L0ZkgW00@0Z[gW0:^mi`2[_NL0ZkgW0P2Z_NL01?l00000Z[gW0:Zmi`2Z_NL;0:Zm
j0T0ZKgX00<0ooooo`00003oool09P3oool000T0oooo00Co00000?ooo`3oool0oooo:@000004oaTI
6@030000000c<c<0000000@000001@3<c<`5000000d0C4a<00<0000003<c<`0c<c<00P0c<c<00`00
003o6ATIoaTI6@02oaTI6EP00000103oool00ol00000oooo0?ooo`0L0?ooo`?o0000103oool20:Nj
iP<0Z;WU00<0ZKWT0:Vhi02Y^>@00`2Y]n<00`2Z]n<0Z[KR0:ZfhP030:ZfhP030:ZghP2[]N00ZkGP
00<0ZkKQ00<0Z[OR0:^eh02[]n800`2[]n800`2[^><0ZkKQ0:^hhP030:^hhP030:^ih`2/^>80[;SR
0080[;WS00D0[;SQ0:bihP2/^N80[;WR0:fjh`020:fihPT0[K[S00H0[K_S0:jkh`2^^n<0[[_S0:jk
i02^^n<40:jki0030:fli02^_>@0[KcT0080[KcT0`2]_>D70:fmi@030:bmiP2]_NH0[KgV00T0[;gV
302[_NL20:Zmi`04o`00002Z_NL0Z[gW0:Zmi``0Z[gX2@2Y_NP00ol00000oooo0?ooo`0U0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooolY000000Go6ATI00<0000003<c<`000000100000050<c<c080
000000@0Ogmo0000000000000000301<C4`01@000000<c<c03<c<`0c<c<0000000Go6ATIE`000004
0?ooo`03o`00003oool0oooo01X0oooo0_l000050?ooo`<0Yk[W0P2W^^H00`2X^ND0YkWV0:NiiP03
0:Vhi080ZKOS1@2Z]^800`2[]>00ZkGP0:^eh0020:^eh0030:^fh@2//mh0ZkGP0080ZkGP0P2[]n82
0:bdgP80ZkKQ0P2[^>820:bfh0030:bhhP2]]Ml0[KGO00<0[;SQ00<0[;WR0:fhh@2]^>400`2]^N80
0`2]^^<0[KWR0:fjh`040:fjh`80[[[S1P2^^n<20:jki0050:jlh`2^_>@0[[cT0:jli02]_>@00`2^
_>@20:fli@H0[KgU102]_NH90:bmiP030:^mi`2/_NL0ZkgW00T0ZkgW00<0Z[gWo`00002Z_NL00`2Z
_NL;0:Zmj0X0ZKgX00?o00000?ooo`3oool0903oool000T0oooo00Co00000?ooo`3oool0oooo:P00
0005oaTI6@030000000c<c<0000000@000001@3<c<`01_l00000000007moOol00000IVIV000000`0
C4a<00D0000003<c<`0c<c<0<c<c00000005oaTI6EH00000103oool00ol00000oooo0?ooo`0G0?oo
o`?o00000`3oool20:Jbh@<0Y[[W00<0Yk[W0:Jii`2V^^L00P2V^^L30:NiiP030:Vhi02X^>D0Z;SU
0080ZKOS0P2Z]^80102Z]N40ZkCP0:^dh02[]>020:^eh0050:bbg@2//mh0[;?N0:bcgP2[]N000`2]
/]`00`2/]=h0[K3J0:f`fP030:fcg@030:bfh02]/]/0[KGO00<0[KGO00<0[;SQ0:fegP2]^>400`2]
^>400`2]^N80[[SQ0:fihP020:fihP80[K[S0P2^^^800`2^^^<0[[[R0:jjhP060:jkh`<0[[cS2@2^
_>@20:fmi@040:jmi@2]_ND0[KgU0:fmi@@0[KgV202/_NH30:bmi`T0ZkgW0_l000050:Zmi`/0Z[gX
2@2Y_NP00`3ooooo00000?ooo`0T0?ooo`002@3oool01?l00000oooo0?ooo`3ooolZ000000Ko6ATI
00<0000003<c<`0000000_l00002000000@0c<c<0P0000000ol00000Ogmo0000000200000003o`00
00000000000000H000000`1<C4`200000080<c<c00<00000oaTI6OlI6AT00olI6AUE000000@0oooo
00?o00000?ooo`3oool05P3oool2o`0000<0oooo00<0XXo00:Jbh@2V/^400P2V/^400`2V^^L0YK3O
0:Jii`020:Jii`030:Jji`2U^NL0YKWW00<0Y[WW00<0Z;SU0:JhiP2V^>H00`2X]n<20:Zeh@030:^d
h02[/mh0Zk?N00<0[;;M00<0[;?N0:f`f`2]/=/00`2]/]`40:f`fP030:fcg@2^[]L0[K;K0080[K;K
0P2]]Ml0102^/MX0[KGN0:fegP2]]Mh20:fhh@050:jegP2^^>40[[SQ0:jhh@2]^N800`2^^>400`2^
^^80[[SQ0:jjhP030:jjhP030:jkh`2_^^80[[_S00<0[[_S00@0[[cS0:nlh`2__><0[[cT0P2__><4
0:jli080[[gT0`2^_ND30:fmi@80[KgV00@0[KgU0:fmiP2]_NH0[KgV1P2/_NH30:bmi`D0ZkgW0ol0
0000102[_NOo00000:^mi`2[_NL30:Zmi``0Z[gX2@2Y_NP00ol00000oooo0?ooo`0S0?ooo`002@3o
ool01?l00000oooo0?ooo`3ooolZ000000Oo6ATI00<0000003<c<`0c<c<00`0000000ol000000000
0<c<c0020<c<c0@0000000<0Ogmo0000001VIVH0201VIVH00`000000C4a<04a<C00204a<C0050000
000c<c<0<c<co`00000000001OlI6AUC000000@0oooo00?o00000?ooo`3oool05P3oool01?l00000
ooooo`00002RM9l30::?`080Y[;Q00D0XHVj0:F`g`2U/=l0YK3O0:Jii`020:B]g@<0YKWW00<0Y[WW
0:Bhi`2T^>L00`2V^>H00`2X]n<0YKOU0:VehP030:VehP80Zk?N00<0[;;M0:bag02]/=/00`2]/=/0
0`2]/]`0[ZkG0:j^e`020:f`fP050:n/e02^[]L0[ZkG0:j^e`2]/]/00P2_[=@30:jafP030:fegP2_
/=T0[k3I00<0[[GN00H0[[SQ0:jeg@2^]Md0[[GM0:jhh@2_]Md30:jhh@80[[[R00@0[kWQ0:njhP2_
^^80[k[R0P2^^n<20:nkhP030:nlh`2_^n<0[kcS00<0[kcS00<0[[cT0:nli02^_N@00`2^_N@30:jm
i@030:fmi@2^_ND0[[gU00<0[KgU0P2]_NH70:bmiP<0[;gW00@0ZkgWo`000?l0003o00001@2[_NL0
0ol00000ZkgW0:Zmi`030:Zmi``0Z[gX2@2Y_NP00ol00000oooo0?ooo`0R0?ooo`002@3oool01?l0
0000oooo0?ooo`3ooolZ000000So6ATI00<0000003<c<`0c<c<01@0000030<c<c0@0000000<0Ogmo
o`00001VIVH0201VIVH2000000<0C4a<00D0000003<c<`0c<c<0<c<c00000005oaTI6E800000103o
ool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0XWBO0080XWBO0P2RSl040:69^P030:F`g`2O
Q;D0WhBe00<0Y:gM00<0YKWW0:>Yf`2SZM/00`2T^>L00`2V^>H0XkOW0:Fgi@020:Fgi@80ZKGR00@0
YKKT0:Zcg`2Z/ml0Z[?O0P2//M`20:f`f`040:j^f02^[]L0[ZkG0:j^e`@0[jcD00<0[ZkG0;6Yd02a
ZM000`2_[=@00`2^/MX0/:[B0:n`f@030:n`f@030:jegP2`[mL0/:oG0080[[GM00D0/:oF0:neg@2_
]Md0[kGM0:jhh@020:neg@<0[kWQ00H0[k[R0:nih@2_^N40[kWQ0:nkhP2_^^430:nkh`<0[kcS0`2_
_>@40:jmi0H0[[gU0P2]_ND30:fmiP80[;gV0P2]_NH00`2/_NH0[;kV0:bmi`03o`0000030:^mi`2[
_^L0ZkgW00H0ZkgW00?o00000:^mi`2Z_NL00`2Z_NL<0:Zmj0P0ZKgX00?o00000?ooo`3oool08P3o
ool000T0oooo00Co00000?ooo`3oool0oooo:P000009oaTI6@03o`0000000000<c<c0080000000?o
00000000000000000`3<c<`300000003o`00001oOgl0000000X0IVIV0P00000204a<C0050000000c
<c<0<c<c03<c<`0000001OlI6AUA000000@0oooo00?o00000?ooo`3oool05P3oool00ol00000XWBO
0:9dW`020:9dW`030::?`02RLY`0XW:L00<0XHVj102OQ;D00`2T[Md0WWj`0:>Yf`030:>Yf`030:Bh
i`2RY]T0XZKI0080XkOW00<0YKOU0:6ei`2Q]NL00`2U]^@00`2Z/ml0Y[CS0:Jdh`020:^ag0<0[ZkH
00<0[ZkG0:n/e02_[=@00`2_[=@40;6Yd0030:n/e02bY/`0/:[B0080/:[B0P2_/=T01@2aZ<l0/:oG
0;2_e`2`[mL0/ZO=00<0/:oF00<0[kGM0;6^eP2_]Md00`2_]Md00`2_^N40/;KM0;2fg@020:nih@05
0;2fg@2_^^40[k[Q0:njh@2_^n<00P2`^^830:nlh`<0[kcT0P2^_N@00`2__N@0[[gU0:jmi@050:jm
i@80[KgU1@2]_NH0102]_^Ko0000o`000?l000020:bmi`040:bni`2[_^L0ZkkW0:^ni`80ZkgW0P2[
_^L30:^mi`03o`00002[_NL0ZkgW0080Z[gW302Z_NP90:Vmj003o`00003oool0oooo0240oooo0009
0?ooo`04o`00003oool0oooo0?ooobX000002_lI6AT01@000000<c<c000000000000IVIV00800000
00?o00000000003<c<`00P3<c<`30000000307moO`000000IVIV00X0IVIV00@0000004a<C01<C4co
00000P0c<c<00ol0003o6ATIoaTI6@03oaTI6E400000103oool00ol00000oooo0?ooo`0E0?ooo`03
o`00003oool0XWBO00<0XWBO0`2RLY`30:69^P@0WhBe0`2NO[020:>Yf`0409ej[02RY]T0XZKI0::V
f@@0X:;F0P2Q]NL00`2U]^@0X;CV0:2diP030:Jdh`80Zk7L00<0[ZkH0:f^f02_[=@0102_[=@20;6X
c`80/JW@00D0/jG:0;:Vc02bY/`0/ZK<0;2ZdP020;>Sb0<0/JS?00H0/:oG0;:Wc@2bYld0/ZO=0;2_
eP2bYL/30;6^eP80[kGM00D0/JkE0;2fg@2`]]d0/;KM0;:^e@030;2fg@030:njh@2`]md0/;[R00<0
/;[R00@0[kcS0;2khP2`^n80[kcT0P2_^n<30:nmi0040:jmi@2__N@0[kgT0:nmi0D0[[gU0P2]_NH3
o`0000030:fniP2/_^H0[;kV0080[;kV0P2/_^L00`2[_^L0[;kW0:bni`060:^ni`03o`00002[_NL0
ZkkW00<0Z[gW302Z_NP00`2Y_NP0Z[gX0:Zmj0060:Vmj003o`00003oool0oooo0200oooo00090?oo
o`04o`00003oool0oooo0?ooobX000002olI6AT01@000000<c<c000000000000IVIV0080000000<0
/k>c0000003<c<`00P3<c<`30000000407moO`0000000000000000T0IVIV00@0000004a<C01<C4`0
00000P0c<c<00`00003o6ATIoaTI6@03oaTI6E000000103oool00ol00000oooo0?ooo`0E0?ooo`03
o`00002dOYT0XWBO00<0XWBO102RLY`00`2QRKX0XW2I0:9`V@0209n4]@040:=_U`2NO[00WWj`09in
/0@0WGZ/00<0XZKI09agZ02LMjP00`2PX]H209jNe0@0X;CV00@0Y[CS09nbiP2W/^00Yk;P0`2][]P2
0:n/e0050:n[d`2aZ<l0/JS?0;6Xc`2aZM000`2cYLX20;:Vc0@0/j?800<0/JS?0;BPa@2bYld00P2b
Yld01@2dW/40/ZG;0;:Ub`2bYL/0/JkF0080/jC90`2a[]D01P2`]]d0/ZkE0;:^e@2b[]D0/;KM0;:^
e@<0/;OM0P2`^^820;2ggP030;2khP2`^=h0[k_S00<0[k_S00<0[kgT0:nlh`2__><00P2__N@00`2_
_>@0[[gU0:jmi@020:jmi@?o00001@2]_^H30:bniPD0[;kW1`2[_^L00ol00000ZkkW0:^ni`030:Zm
i`h0Z[gX1P2Y_NP00ol00000oooo0?ooo`0P0?ooo`002@3oool01?l00000oooo0?ooo`3ooolY0000
00go6ATI00D0000003<c<`000000000006IVIP02000000030;>c/`000000c<c<0080c<c<00?o0000
0000000000000`1oOgl6000000@0IVIV00@0000004a<C01<C4`000000P0c<c<00`00003o6ATIoaTI
6@03oaTI6Dl00000103oool00ol00000oooo0?ooo`0E0?ooo`03o`00002dOYT0XWBO0080XWBO00<0
]WjH0:9bW02RLY`00P2RLY`30:9`V@0409n4]@2SKiL0XfnG0:=_U`80WWj`102MNZ`409agZ0030:2R
eP2KLjD0Vg>U0080WYkD0P2P]>H0102KV]80Wk;V09nbiP2O/^H20:Nbh0030:f^f02Y/=d0ZK3M00<0
[j_C00<0/JS?0;6WcP2aYlh00`2cYLX00`2bY/`0]:750;BQa@020;>Sb0050;FN`02dX<D0]:350;BP
a@2bYld00`2dW/420;:Ub`@0/jC900<0/JkE0;>Sb02b[]D00P2b[]D01@2dXlL0/ZkE0;:^e@2b[]D0
/;OM00<0/ZoE00<0/;ON0;:_eP2`^=h00P2`^=h20:nkh`80/;WO00<0[kcS0;2ih02__>@00`2__>@3
o`000080[[kU1P2]_^H40:bniPD0[;kW1`2[_^L01Ol00000ZkkW0:^ni`2Z_NL0Z[kW00l0Z[gX1P2Y
_NP00ol00000oooo0?ooo`0O0?ooo`002@3oool01?l00000oooo0?ooo`3ooolY000000ko6ATI0`00
0002o`000080000000L0/k>co`0000000000c<c<0000002c/k?o0000008000001`1oOgl400000004
06IVIP000000C4a<04a<C080000000<0<c<c00000?l000001?lI6AU>000000@0oooo00?o00000?oo
o`3oool05@3oool00ol00000]7jI0;AnV@020:9dW`030;InV02RLY`0XW:L0080XW:L0`2RL9T40:=_
U`0309in/02SKYD0XfjE00<0WGZ/102LMjP309]cY@0309jNe02JLJ<0VW6S00<0Vi[B00<0Wk;V09VG
d02IUm000`2N/ND20:V`g@030:n[d`2/[MP0/JO>00<0/JO>00<0/jG:0;BTb02dXLD00P2dXLD0102c
XlP0]Ik00;FN`02eW/020;BPa@@0]9k100<0/ZG;0;FL_P2eW;h00P2cY<T01@2eV[/0/j?80;>Sb02c
XlP0/ZkE00<0]:?700<0/ZkE0;BRaP2b[mD00P2b[mD01@2dX/H0/ZoF0;:_eP2b[mH0/;SN00<0/[3F
00<0/;WO0;:ae`2`^N000P2`^N03o`0000040;2jh@2__N@0[kgT0:jni@<0[[gU00<0[KkV0:jmi@2]
_^H00P2]_^H20:bniP80[KkV1P2/_^L60:^ni`03o`00002[_^L0Z[kW0080Z[kW3`2Z_NP60:Vmj003
o`00003oool0oooo01h0oooo00090?ooo`04o`00003oool0oooo0?ooobT000004?lI6AT20000000:
04a<C00000000000o`0000000000/k>c0000003<c<`000000;>c/`@000002@1oOgl00`000000IVIV
0000000304a<C0040000000c<c<0<c<c000000Co6ATIC@0000040?ooo`03o`00003oool0oooo01D0
oooo00Co00000;AnV@2dOYT0XWBO0`2fOYP20:9bW0040;QoU`2RL9T0XW2I0:9`V@@0XfnG00<0WWj`
0:=^U@2SKYD00P2MNZ`00`2TKY@0W7NX09agZ00209agZ0<0Vg>U102JLJ<00`2KV]80VVnQ09VGd003
09VGd00409jai@2FTlh0WZoS09j_h`<0[:gH0P2aYlh0102_Z]<0]:C80;BTb02dY<P20;BQa@@0]Ik0
00<0]:350;JJ^`2fV[/00`2dW/430;FL_P040;>Tb@2eV[/0]IZk0;FJ^`80/j?800@0]YRi0;BSa`2d
XlL0]:?70`2dX/H01P2b[mD0]:;60;BRaP2dX/H0/ZoF0;BRa`<0/[3F00@0]:?70;:ae`2b/ML0/[7G
0_l00000102b/]T0/;[Q0;2jh@2`^^430:nkhP80[[gU00@0[k_S0:jmi@2^_ND0[[gU1P2]_^H60:bn
i`H0ZkkW00Co00000:^ni`2[_^L0Z[kW0P2Z_^P>0:Zmj0H0ZKgX00?o00000?ooo`3oool07P3oool0
00T0oooo00Co00000?ooo`3oool0oooo:@00000AoaTI6@L0000000@0/k>c0000003<c<`000000P2c
/k<010000000VIVI00000000000807moO`03o`00001VIVH0000000<0C4a<00@0000003<c<`0c<c<0
00001?lI6AU<000000@0oooo00?o00000?ooo`3oool05@3oool01?l00000]7jI0;AnV@2RM9l30;In
V080XW:L00@0^7nG0:9`V@2RL9T0^X2F102SKiL30:=^U@0409ej[02TKY@0Y6jD0:A^U080W7NX00@0
YFjC09]cY@2KLjD0Vg>U102JLJ<309Y_X@80VIO@00@0VFfO09JCcP2FTlh0UY?>0P2N[n<00`2/[MP0
X:gQ0:2]h@030:nZd`80]:C800<0]:750;JP`P2fX<800`2eW/040;JJ^`030;BN`@2gUkL0]iNg0080
]Ibn102eV[/01@2cXlP0]YRi0;JH^@2fV;T0]:?70080]YNh0P2dX/H0102fU[H0]:;60;BRaP2dX/H3
0;BRa`030;:`eP2dXlL0]:?700?o0000102b/]T0102`^^40/K?J0;6cfP2_^n820;6df`<0[k_S00<0
[[gU0:jli02^_>@00P2]_^H01@2^_>@0[KkV0:fniP2]_^H0[;kW0080[;kV0`2/_^L60:^ni`03o`00
002[_^L0ZkkW0080Z[kX3`2Z_NP60:Vmj003o`00003oool0oooo01d0oooo00090?ooo`04o`00003o
ool0oooo0?ooobT000004_lI6AT01@000000<c<c00000000003o00000080000000@0/k>co`000000
003o00000P2c/k<01?l00000VIVI09VIVOl0000807moO`040000001VIVH00000o`000080C4a<00@0
000003<c<`0c<c<000001?lI6AT00ol00000000000000018000000@0oooo00?o00000?ooo`3oool0
503oool01Ol00000]7jI0;AnV@2dOYT0XWBO00<0]WjH00<0XW:L0;QoU`2hOiL00P2RL9T00`2jP9H0
XfnG0:=_U`020:=_U`<0XfjE102TKY@01P2LMjP0YFjC0:E^T`2UKY<0Vg>U0:I^TP@0VW6S0`2JKj44
09U]W`80UY?>0`2DSl`30:2]h@80[j[C00<0]:C80;:Vc@2bY/d00`2fX<800`2eW/00]ibl0;NL_002
0;JJ^`050;VH]`2gUkL0]iNg0;NG]`2eW;h00P2gUK<30;FJ^`@0]YRi0`2fUkP01@2dX/H0]YJf0;JF
]P2fU[H0]:;60080]YFf0P2dX/L3o`0000040;BSa`2dY<P0]:C80;BTb080/[;I0P2cYLX00`2a/mX0
/jO<0;6df`030;6df`050:nkh`2`]]d0/;KM0:jli02_]ml0102^_>@01@2]_^H0[KgU0:fmi@2/_^H0
[KgV00@0[;kW1P2[_^L00ol00000ZkkW0:^ni`020:Znj0030:Zmj02Z_^P0Z[kX00`0Z[gX1P2Y_NP0
0ol00000oooo0?ooo`0L0?ooo`002@3oool01?l00000oooo0?ooo`3ooolY000001?o6ATI0P000000
1@1<C4`0000000000000003o00000080/k>c00D000000;>c/`2c/k<0/k>c0000000209VIV@L00000
0P1oOgl01P000000IVIV06IVIP000000C4a<00000080<c<c00?o0000oaTI6OlI6AT00_lI6AU;0000
00@0oooo00?o00000?ooo`3oool0503oool01?l00000]7jI0;AnV@2dOYT40;InV0030:9bW02hOiL0
^7nG0080XW2I00<0^X2F0:=_U`2SKiL00P2SKiL30:=^U@@0Y6jD00D0W7NX0:E^T`2UKY<0YFjC09]c
Y@020:I^TP80VW6S00@0YfjB09Y_X@2JKj40VVnQ102IKIl00`2FTlh0V6bN09Q/WP0309B?c0040:2]
h@2BSL/0XZ_M0::[g@@0/ZK=00<0]Z320;FSaP2gW;`00P2gW;`00`2fV[/0^IRg0;VH]`030;NG]`@0
]iFc00<0]IZk0;RB/02hT[000P2fV;T0102hT:d0]YNh0;JG^02fUkP40;JF]P80]YFf0ol000020;JE
]P030;BSa`2fUKH0]YFf0080]:C800@0]IJf0;>UbP2cYLX0/jG:0`2cYl`20;6df`80/jS>00<0/;KM
0;:[d@2_]ml00P2_]ml20:jli080[kSP00<0[KgU0:jihP2]_NH00P2]_NH20:bni`80[;gV1P2[_^L0
0ol00000ZkkW0:Znj0040:Znj0d0Z[gX1@2Y_NP00ol00000oooo0?ooo`0L0?ooo`002@3oool01?l0
0000oooo0?ooo`3ooolY000001Co6ATI0P0000000`1<C4`0000000000002000000H0/k>c00<00000
09VIV@2IVIT01P2IVIT010000000Ogmo07moO`00000206IVIP030000001<C4`000000080<c<c00<0
0000oaTI6OlI6AT00_lI6AU:000000@0oooo00?o00000?ooo`3oool0503oool01?l00000]7jI0;An
V@2dOYT40;InV0040:9bW02hOiL0^7nG0:9`V@80^X2F0`2SKiL0102lPYD0XfjE0:=^U@2SKYD40:A^
U0@0YFjC00<0Vg>U0:I^TP2VKY800P2JLJ<0102WKY80VVnQ09Y_X@2JKj4409U]W`<0V6bN0P2DSl`0
102GJid0TXg;09:=b`2BSL/20::[g@80/ZK=00@0YZWI0;FSaP2eXlH0]J?60P2gW;`40;VH]`80]iNg
102gUK<30;RB/0040;JH^@2hT:d0^92]0;R@[@80]YNh00<0^8n[0;JF]P2fU[H00ol000080;JE]P05
0;BTb02eU[H0]IJf0;FF]P2cYLX00P2eU[P20;>Wc0<0/jS>00D0]IVl0;:[d@2bZm40/Z_A0:ngg`02
0;:]d`80[kSP00D0/JoF0:jihP2^^N80[[WR0:fmiP030:fjh`030:bmiP2]^n@0[;gW0080[;gW00@0
ZkkW0:^mi`2[_NOo00000P2[_^L50:Znj0/0Z[gX1`2Y_NP00ol00000oooo0?ooo`0K0?ooo`002@3o
ool01?l00000oooo0?ooo`3ooolZ000001Co6ATI00?o00000000001<C4`00P0000000`2IVIT00000
000000050;>c/`030000002IVIT0VIVI00H0VIVI00@0000007moO`1oOgl000000P1VIVH00`000000
C4a<0000000203<c<`0300000?lI6AWo6ATI00;o6ATIB@0000040?ooo`03o`00003oool0oooo01@0
oooo00Co00000;AnV@2dOYT0hkBU102fOYP30;QoU`040:9`V@2jP9H0^X2F0;Z0UP80XfnG00@0_8:E
0:=^U@2SKYD0_X>D102TKY@40:E^T`<0YVjB00H0VW6S0:M^TP2WKY80YfjB09Y_X@2XKi8409U]W`<0
V6bN102GJid209:=b`<0T8[90`2VZMT20;FSaP030;NL_02hWkl0^9no00<0^IRg00<0]iNg0;ZE/P2j
UK800P2gUK<0102jTZd0^9:`0;RB/02hT[040;R@[@030;JG^02hSj_o000000;o00000P2hSJX90;JE
]P@0]IJf0`2eU[P0102cYl`0]IRi0;FH^@2cZ<h30;FI_0030;:[d@2dVkh0/ZgC0080/ZgC00D0]9k1
0;6_eP2a[mH0/JoF0:jihP020;2af@80[K[S00H0[k?K0:fki02]^n@0[K_T0:bmi`2/^nD40:^mi`03
o`00002[_NL0ZkgW00D0Z[kX202Z_NP90:Vmj0030?ooool00000oooo01/0oooo00090?ooo`04o`00
003oool0oooo0?ooobX000005?lI6AT400000003o`00000000000000008000001@2c/k<3000000H0
VIVI00?o00000000000000000P000000101VIVKo000004a<C000000203<c<`0300000?lI6AWo6ATI
00;o6ATI00?o0000000000000000A@0000040?ooo`03o`00003oool0oooo01@0oooo00Co00000;An
V@2dOYT0hkBU102fOYP30;QoU`040:9`V@2jP9H0^X2F0;Z0UP80XfnG00@0_8:E0:=^U@2SKYD0_X>D
0`2TKY@00`31QI@0YFjC0:E^T`020:E^T`<0YVjB00D0VW6S0:M^TP2WKY80YfjB09Y_X@020:Q_TP80
VFfO00@0ZG2B09Q/WP2HK9h0V6bN102GJid00`2BSL/0UfZM09MZW@03092:b@80YZWI00<0]J?60:^V
dP2hWkl00P2hWkl30;VH]`<0^YFb00@0]iFc0;ZB[@2jTZd0^Y:]0P2hT[000`2kT:T0^92]0;R@[@03
o`0000030;R?Z`2hSJX0^8fZ0080^8fZ00<0]YFf0;R=Z02hSJP00P2fUKH20;R<Z080]YFf00@0]hbX
0;FF]P2eU[H0]hbX0`2eU[P30;FH^@@0]IVl0`2dVkh01P2b[M<0]9k10;BN`@2dW/40/JoF0;>Qa@<0
/;7I102_/m/00`2]^n@0[kGM0:neg@020:bki@80ZkgW0P2/_>D00ol00000ZkcV0:^mi`020:^mi`03
0:Znj02Z_NL0Z[gX00P0Z[gX2@2Y_NP00ol00000oooo0?ooo`0J0?ooo`002@3oool01?l00000oooo
0?ooo`3ooolZ000001Ko6ATI00<0000003<c<`0000001@0000070;>c/`@000001@2IVIT01`000000
Ogmo0000001VIVH0000004a<C00000000P0c<c<00ol0003o6ATIoaTI6@02oaTI6DL00000103oool0
0ol00000oooo0?ooo`0D0?ooo`04o`00002dOYT0]7jI0>>dY@<0]WjH00@0jKZS0;QoU`2hOiL0^7nG
102jP9H00`2SKiL0_8:E0;b2U@020:=^U@050;j3U02TKY@0Y6jD0:A^U031QI@0102UKY<30:I^TP@0
YfjB00<0VVnQ0:Q_TP2XKi800P2IKIl0102YL980V6bN09Q/WP2HK9h409M[W@<0UfZM0P2@R/T00`2F
JId0ShS808n8b0030:^VdP<0^9no00<0^IRg0;ZK^02jUK800P2jUK840;ZB[@030;RB/02kT:Wo0000
00;o000000D0^92]0;R?Z`2hSj/0^8n[0;^<Y0030;R=ZP<0^8fX00D0]YFf0;R<Z02hS:P0^8bX0;JE
]P020;N<Z0040;FF]P2gS:P0]hbX0;N<Z080]IJh00@0]hbX0;FH^@2eV;T0]hfY0`2eVK`00`2gSZ/0
]9^n0;BK_P040;BN`@<0/j7500<0/;7I0;>Sb02cXlP00P2_/m/0102bYld0[kGM0:neg@2_]Md30:jg
g`80[;cU00@0[KSQo`00002[_>H0ZkcV0`2[_NL20:Zmi`T0Z[gX202Y_NP00`3ooooo00000?ooo`0J
0?ooo`002@3oool01?l00000oooo0?ooo`3ooolY00000003o`000?lI6AWo6ATI01Go6ATI00<00000
03<c<`0000000P0000000`1oOgl000000000000:0;>c/`<000000`2IVIT01`000000Ogmo0000001V
IVH0000004a<C00000000P0c<c<00`00003o6ATIoaTI6@02oaTI6DH00000103oool00ol00000oooo
0?ooo`0C0?ooo`03o`00003oool0]7jI0080hkBU0`2fOYP0103Y^Z<0^7nG0;QoU`2hOiL40;Z0UP04
0:=_U`2lPYD0_8:E0:=^U@80_X>D0`2TKY@01@31QI@0YFjC0:E^T`2UKY<0`hND00<0YVjB102WKY83
0:Q_TP0609U]W`2YL980ZG2B0:U`TP2HK9h0ZW6B102GJid309MZW@@0UVVM0P2?R<P20:^VdP80^9no
00@0/:C;0;ZK^02jVkP0^Y^h0P2jUK800`2lV;80^Y:]0;ZB[@03o`000080^i2Y00@0^92]0;^>YP2k
SZH0^8n[0P2kS:@30;R=ZP<0^8fX102hS:P70;N<Z0040;FF^02gS:P0]hbX0;FH^@<0]hfY00@0]IVl
0;N>Z`2gSZ/0]9^n0P2fSjd20;BN`@80]Y6`0P2cXLD30;>Sb0@0/ZO=00D0[kGM0;6Zd02aZ]00[[OO
0;6]e0040:fhh@05o`00002/^N<0[;WS0:^mi`2/^^@00`2Z_NL20:Zmj0030:Zmi`2Z_NP0Z[gX00@0
Z[gX202Y_NP00ol00000oooo0?ooo`0I0?ooo`002@3oool01?l00000oooo0?ooo`3oool[000001Oo
6ATI00D0000003<c<ol000000000o`00000300000080/k>c00?o00000000000000001`2c/k<20000
0080VIVI00L0000007moOol00000IVIVo`00001<C4`000000080<c<c00<00000oaTI6OlI6AT00_lI
6AU5000000@0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0;AnV@020>>dY@80]WjH0P3Y
^Z<30;QoU`@0^X2F00@0XfnG0;b2U@2lPYD0XfjE0P2nPi@20:A^U080`HFD0`2UKY<01033Qi@0YVjB
0:I^TP2VKY840:M^TP<0Z6nB00D0VFfO0:U`TP2YL980ZG2B09Q/WP020:YaTP80Uf^M00@0Zg:B09MZ
W@2GJYd0UfZM102FJId0102?R<P0UFVM0968aP2AR<H40;2Tb`80^Y^h00<0^YFb0;bH/P2lV;800_l0
00000`2jTZd0^i2Y0;^@Z@020;^@Z@<0^hjV00<0^8n[0;^<Y02kS:@00P2hSJX20;^;XP80^8fX00@0
^hVQ0;R<Z02hS:P0^8bX0`2gS:P00`2kR9l0]hbX0;N<Z0040;N<Z0@0]hfY0`2gSZ/30;J?[@050;BN
`@2fTK00]Y6`0;JA/02cXLD00P2fTk<00`2cXlP0]YJf0;JF]P020;:Wc@040;FI^P2aZ]00/J[@0;6Z
d0<0/JgD0P2]^>420;2`f003o`00002_/m/0[;[T0080[;[T00<0Z[gW0:^ki@2[^nD00`2Z_NL00`2Z
_NP0Z[gW0:Zmi`020:Zmj0T0ZKgX00?o00000?ooo`3oool0603oool000T0oooo00Co00000?ooo`3o
ool0oooo:`00000HoaTI6@040000000c<c<0000004a<C080000000Co00000000002c/k<000000P3<
c<`00`000000/k>c0;>c/`060;>c/`80000000P0VIVI0000001oOgl0000006IVIP000000C4a<o`00
0080<c<c00Co0000oaTI6OlI6AWo6ATIA@0000040?ooo`03o`00003oool0oooo01<0oooo00?o0000
0?ooo`2dOYT00P3S]:D20;InV080jKZS0P2hOiL00`3_`J40^X2F0;Z0UP020;Z0UP<0_8:E00<0XfjE
0;j3U02nPi@00P2TKY@20<65U0<0YFjC00@0`hND0:I^TP2VKY80aXZC102WKY830:Q_TP@0ZG2B00<0
V6bN0:YaTP2ZLI800P2GJid0102[LY80UfZM09MZW@2GJYd409IYW@<0UFVM0P2AR<H30;2Tb`030;ZK
^02eX<?o000000;o000000@0_9Rb0;ZB[@2mU:d0_IB]0`2kT:T30;^>YP050;R?Z`2kS:@0^hbT0;^<
Y02hSJX00P2kRj800`2hSJP0^hVQ0;^9X@020;R<Z0030;^8W`2gS:P0]hbX0080^hRO1P2gS:P40;N=
Z@<0]hj[0`2fSjd40;JA/0<0]Y>c0`2fU[H40;FI^P040;6Zd02eW;l0]Ibo0;6]e080]:340P2`/=P0
1@2cY<T0[k?Ko`00002_/m/0[;[T0080[[GN00<0Zk_U0:fgh@2[_>H00`2[_>H00`2Z_NL0Z[cV0:Zm
j0020:Zmj080ZKgX0P2Z_NP50:Vmj003o`00003oool0oooo01L0oooo00090?ooo`04o`00003oool0
oooo0?ooob/000006OlI6AT010000000<c<c0000001<C4`20000000409VIV@000000/k>c00000080
c<c<0`0000070;>c/`0;0000002IVIT0000007moO`000000IVIV0000001<C4`0000003<c<`000000
1?lI6AU4000000@0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0>>dY@020>>dY@80]WjH
0P3Y^Z<20;QoU`030>o1X@2jP9H0^X2F0080^X2F0`2lPYD00`2SKYD0_X>D0;j3U0020:A^U080`HFD
0P2UKY<20<>7U080YVjB00<0aXZC0:M^TP2WKY800P2WKY830:Q_TP@0ZG2B0`2ZLI801P2GJid0Zg:B
0:]bTP2[LY80UfZM0:acT`@0UVVM0`2EJId30968aP050;2Tbol0003o0000o`00002eX<<00P2lV;80
102jWK/0_IB]0;fD[@2mU:d20;^@Z@040;jBZ02kSZH0^hjV0;^>YP@0^hbT00@0^8fZ0;^;XP2kRj80
^8fX0P2kRJ420;R<Z080^hRO00<0]hbX0;^8W`2kR9l00P2gS:P20;^7W`030;N<Z02jQil0^XNO0080
]hfY0P2jQil00`2gSZ/0^XRP0;Z8X0020;J?[@040;Z9XP2fTK00]Y6`0;JA/0<0]Y>c0`2fU[H0102i
SJP0]IVj0;FI^P2eVKX30;FL_`<0]:34102cY<T01Ol00000/ZS>0;:XcP2^]Mh0/JcC00<0[KOQ0P2[
_>H20:bih`80Z[cV00<0Z[gX0:Zli`2Z_>L00P2Z_NP00`2Z_NL0ZKgX0:Vmj0030:Vmj003o`00003o
ool0oooo01L0oooo00090?ooo`04o`00003oool0oooo0?ooob`000006OlI6AT01?l00000<c<c0000
001<C4`20000000409VIV@000000/k>c000000@0c<c<0P0000060;>c/`0;0000002IVIWo000007mo
O`000000IVIV0000001<C4`0000003<c<`0000001?lI6AU3000000@0oooo00?o00000?ooo`3oool0
4`3oool00ol00000oooo0?ooo`020>>dY@040;InV03Y^Z<0jKZS0>VjX`80^7nG00<0kl6Q0;Z0UP2j
P9H00P2jP9H30;b2U@<0_X>D00@0Y6jD0<65U031QI@0`HFD0P2UKY<20<>7U080YVjB00D0aXZC0:M^
TP2WKY80YfjB0<V=T`030:Q_TP@0ZG2B0`2ZLI801P2GJid0Zg:B0:]bTP2[LY80UfZM0:acT`<0UVVM
00D0[GBC09EYW@2EJId0UFVM09AYWP03o`000080U8S50P2eX<<00`2lV;80^Yfk0;ZM^`030;fD[@04
0;^@Z@2nTZP0_Y:X0;jBZ080^hjV102kS:@30;^;XP@0^hVQ00@0^8bX0;^8W`2kR9l0]hbX0`2kR9l0
102gS:P0^hNO0;^7W`2gS:P20;Z7W`050;N=Z@2jQil0^XNO0;Z7W`2gSZ/00P2jR:000`2fSjd0^XVR
0;Z9XP020;JA/080^HZS00@0]Y>c0;V;Y@2iRjD0]YJf0P2iSJP30;FI^P040;V?Z`2eW;l0]Ibo0;RB
[`80]:3400L0^9Fd0;>Tb@2cY<T0]iVi0;:Xc_l00000/ZS>00<0/JcC00<0[KOQ0;2`e`2`/=L00P2/
^N<01P2_/m/0Zk[T0:^ji02[^^@0Z[cW0:^ki@<0Z[gW0P2Y_NP20:Zmi`80ZKgX00?o00000?ooo`3o
ool05P3oool000T0oooo00Co00000?ooo`3oool0oooo;000000JoaTI6@80000000Co000000000000
000000000_l0000200000003o`00003<c<`0c<c<0080c<c<00Co000000000000000000000`2c/k<0
2_l00000VIVI00000000003o000006IVI_l00000C4a<0000000c<c<2000000?o6ATI@P0000040?oo
o`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool00P3oool01@2fOYP0jKZS0>VjX`3Y^Z<0
^7nG0080kl6Q0`2jP9H0103fb9h0_8:E0;b2U@2lPYD30;j3U0040:A^U031QI@0`HFD0<65U080YFjC
0P33Qi@20:I^TP050<J:T`2WKY80YfjB0:M^TP39SI<00`2XKi840:U`TP<0ZW6B00D0Uf^M0:]bTP2[
LY80Zg:B09MZW@020:acT`80UVVM00<0[GBC09EYWOl000000_l0000309AYWP80U8S500<0]J3309V:
`P2jWK/00`2jWK/20;fD[@@0_Y:X00<0^hjV0;n?Y02kS:@00`2kS:@30;^;XP@0^hVQ1`2kR9l0102g
S:P0^hNO0;^7W`2gS:P20;Z7W`050;N=Z@2jQil0^XNO0;Z7W`2gSZ/00P2jR:001@2fSjd0^XVR0;Z9
XP2jRJ80]Y6`0080^HZS00@0]Y>c0;V;Y@2iRjD0]YJf0`2iSJP0102eVKX0^Hn[0;V?Z`2eW;l20;RB
[`040;BPa02hUK@0^9Fd0;>Tb@<0]iVi00D0/ZS>o`00002fWKh0/JcC0;JRa0030;2`e`@0[k?K00<0
Zk[T0:jegP2^]Mh00P2[^nD00`2Z_NL0Z[cV0:ZliP020:Zmi`050:Zli`2Y_NP0ZKgX0:Vmj?l00000
5`3oool000T0oooo00Co00000?ooo`3oool0oooo;@00000KoaTI6@80000000D0C4a<000000000000
000009VIV@02000000P0c<c<0`000000102c/k<000000000002IVIT20000000406IVIP000000C4a<
00000080<c<c00<00000oaTI6OlI6AT0@P0000040?ooo`03o`00003oool0oooo0180oooo00?o0000
0?ooo`3oool0103oool30>VjX`030;QoU`3_`J40kl6Q00<0^X2F00@0m/RN0;b2U@2lPYD0_8:E0`2n
Pi@0102TKY@0`HFD0<65U031QI@20:E^T`030<>7U02VKY80YVjB0080aXZC0`2WKY801039SI<0Z6nB
0:Q_TP3=T9<40:U`TP<0ZW6B102[LY80102GJYd0[7>C0:acT`2FJId3o`000080UFVM102DJIh00`2D
R<D0TfVO09V:`P0209V:`P<0^Yfk0P2mU:d40;jBZ0030;^>YP2oSj@0_hnT0080^hbT00@0_hjQ0;^;
XP2kRj80_hbO102kRJ470;^8W`<0^hNO1`2jQil30;Z8X0@0^XVR0`2iRZ<30;V;Y@@0^HfX0`2iSj/3
0;RB[`<0^9Fd102gVKT20;JM_P05o`00002fX/@0]Z;40;JRa02`/=L00P2dY/X20:ncf`80/j[@00<0
[[GN0;6^e@2]^>400P2]^>400`2Z_>H0[;WS0:Zli`030:Zli`030:Vmj02Z_>Oo000001L0oooo0009
0?ooo`04o`00003oool0oooo0?ooobd0000000?o0000oaTI6OlI6AT06OlI6AT01?l00000000004a<
C?l000020000000309VIV@000000000000X0c<c<00d000000;>c/`2c/k<0000009VIVOl000000000
06IVIP000000C4a<0000000c<c<0000000?o6ATI@@0000040?ooo`03o`00003oool0oooo0180oooo
00?o00000?ooo`3oool01@3oool20>VjX`030;QoU`3_`J40kl6Q00<0^X2F00@0m/RN0;b2U@2lPYD0
_8:E0`2nPi@40<65U0030:E^T`33Qi@0`hND0080YVjB0P36RY<30:M^TP040<V=T`2XKi80Z6nB0<f@
T`<0ZG2B00@0d9>D0:YaTP2ZLI80ZW6B102[LY80102/Li?o0000o`000?l000030:edT`0309EYW@2^
MY@0U6VN00<0U6VN0`2CJIl209V:`P<0^Yfk00<0_IB]0;fJ]02mV[@00`2nTZP30;n?Y0050;^<Y02o
SZ40_hjQ0;n>X@2kRj800P2oS9l20;^9X@030;n;W@2kR9l0^hRO00D0^hRO0`2kQil70;Z7W`<0^XRP
102jRJ830;V:X`<0^H^U00@0_XVM0;V=Z02iSJP0^HfX0`2iSj/30;RB[`040;f=Y02hUK@0^9Fd0;b@
Z0<0]iVi00@0_9:/0;JM__l00000^iJa0P2fX/@30;BVbP<0/j[@00D0^:;30;6^e@2a[]D0/JkE0:fh
h@020;2bfP80[;WS0P2Z_>L01@2[^^D0Z[cW0:Zli`2[^nKo000001H0oooo00090?ooo`04o`00003o
ool0oooo0?ooobl000006_lI6AT010000000<c<co`00001<C4`300000003o`00002c/k<0000000X0
c<c<0P0000002`2c/k?o000009VIV@00003o000006IVI_l00000C4a<0000000c<c<0000000?o6ATI
@00000040?ooo`03o`00003oool0oooo0180oooo00?o00000?ooo`3oool01`3oool30>o1X@80^X2F
0P3fb9h20;b2U@040?_AV@2nPi@0_X>D0;j3U0@0`HFD00<0YFjC0<>7U033Qi@00P2VKY820<J:T`80
YfjB0P39SI<20:Q_TP050<f@T`2YL980ZG2B0:U`TP3@Ti@00`2ZLI820:]bTP?o00000P2/Li<01@2F
JId0[GBC0:edT`2]M9<0UFVM0080[WJD0`2DJIh309=YW`<0VH[200<0^Yfk0:2=_`2mV[@00P2mV[@2
0;jBZ0050<2G[P2oSj@0_hnT0;n?Y02kS:@00`2oSZ400`2kRj80_hbO0;n<W`020;^9X@80_h^M00<0
^hRO0;n:W02kR9l00P2kR9l0102oRI/0^hNO0;^7W`2kQil30;Z7W`040;n8VP2jQil0^XNO0;Z7W`<0
^XRP00@0_hRJ0;Z9XP2jRJ80^XVR0P2iRZ<20;j8W0030;V;Y@2nRId0_XVM0080^HfX0P2mRYl0102i
Sj/0_HbQ0;f<X@2hTZl20;f=Y0050;RE]02lT:P0_92X0;b@Z02gVKT00P2lTZ`0102fWKh0^iJao`00
002fX/@20;ZI]P040;BVbP2iW[`0^Ijl0;>Zd0<0^:;300<0/JkE0;JWb@2`/]X00P2`/]X30:jeg@03
0:^ji@2]]n40[KOQ00<0Zk_V00?o00000?ooo`3oool04`3oool000T0oooo00Co00000?ooo`3oool0
oooo;`00000KoaTI6@030000000c<c<0000000<0000000@0Ogmo0000002c/k?o00002`3<c<`01@00
0000/k>c000000000000Ogmo00<0000000@0C4a<o`00000c<c<000000olI6ATo000000@0oooo00?o
00000?ooo`3oool04P3oool00ol00000oooo0?ooo`080?ooo`80kl6Q0P2jP9H20?K8WP80_8:E00@0
nm6I0;j3U02nPi@0_X>D1031QI@0102UKY<0`hND0<>7U02VKY830<J:T`80YfjB0P39SI<20:Q_TP05
0<f@T`2YL980ZG2B0:U`TP3@Ti@00`2ZLI82o`000080Zg:B0`2/Li<01@2FJId0[GBC0:edT`2]M9<0
UFVM0080[WJD0P2DJIh0102_MiH0TfVO09=YW`2CJIl309=[X@<0X8fo0P2mV[@00`2nTZP0`9N^0<2G
[P030;n?Y0@0_hjQ0`2oS9l01@2kRJ40_h^M0;n;W@2oRid0^hRO0080_hZL0P2kR9l20;n9V`040;^7
W`2oR9X0_hRJ0;Z7W`80_hRJ0P2jQil20;n8VP030;Z8X02oR9X0_hRJ0080^XVR0P2nR9/0102iRZ<0
_XRL0;j8W02iRjD20;j9W@80^HfX0P2mRYl0102iSj/0_HbQ0;f<X@2hTZl20;f=Y0@0_92X0`2lTZ`3
0;^F/@03o`00002jVKH0^YVf00<0^Ijl102hX/<30;JWb@040;2bfP2dZm00]:_@0:jeg@80/joE00<0
[KOQ0;6cfP2/^N<00P2/^N<00ol00000oooo0?ooo`0C0?ooo`002@3oool01?l00000oooo0?ooo`3o
ool`000001_o6ATI00<0000003<c<`0c<c<00`000000101oOgl000000;>c/`0000040<c<c0Co0000
0`3<c<`010000000/k>c00000000000207moO`80000000@0C4a<0000000c<c<000000olI6ATn0000
00@0oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`080?ooo`80kl6Q00@0^X2F0?K8
WP3fb9h0m/RN0P2lPYD0103kdIT0_X>D0;j3U02nPi@40<65U0<0`hND00@0YVjB0<J:T`36RY<0aXZC
0P2WKY820<V=T`80Z6nB00D0cI2C0:U`TP2YL980ZG2B0=2CU003o`0000@0Zg:B0`2/Li<40:edT`<0
[WJD0P2DJIh0102_MiH0TfVO09=YW`2CJIl409=[X@80X8fo00<0_IZd0:R?^`30Ujh00`30Ujh20;n?
Y0@0_hjQ0`2oS9l01@2kRJ40_h^M0;n;W@2oRid0^hRO0080_hZL00D0^hRO0;n9V`2oRI/0_hVK0;^7
W`020;n8VP030;Z7W`2oR9X0_hRJ0080^XNO0P2oR9X00`2jR:00_hRJ0;n8VP020;Z9XP80_XRK00@0
^HZS0;j8W02nR9`0^H^U0`2nRId00`2iSJP0_HZO0;f:W`030;f<X@<0_HfT00@0`hjN0;b@Z02lT:P0
_92X0`2lTZ`30;^F/@040<6CZ?l00000^YVf0<2F[080^Ijl00<0_iZb0;RR``2hX/<00P2mW[P00`2f
YlT0_::n0;B[d0020;B[d0<0/joE0`2a/mX0102/^N<0[kKN0:nfg_l0000D0?ooo`002@3oool01?l0
0000oooo0?ooo`3oool`00000003o`000000003o6ATI01Wo6ATI00[o00000000000c<c?o00000000
0?l00000Ogmo0000002c/k<000000P3<c<`00ol00000i^KV0>KViP020>KViP?o000000L0c<c<0000
002c/k<00000o`0000000000Ogmo0080000000@0C4a<0000000c<c?o00000olI6AT00ol000000000
0000000j000000@0oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`090?ooo`030>o1
X@2jP9H0m/RN0080m/RN00<0_8:E0?_AV@3kdIT00P2nPi@00`3ofI40`HFD0<65U0020<65U0<0`hND
00D0YVjB0<J:T`36RY<0aXZC0:M^TP030<V=T`040:Q_TP3=T9<0cI2C0:U`TP?o00000P2ZLI801@3D
Ui@0Zg:B0:]bTP2[LY80f9^D00<0[7>C102]M9<30:ifU00609AYWP2_MiH0[gNF0:mgUP2CJIl0[gVH
102CJj400`2PSKl0TffS0:R?^`020:R?^`<0`9N^00<0_hnT0<:EZ02oSZ400`2oSZ430;n<W`@0_h^M
0`2oRY`01@2kR9l0_hVK0;n9V`2oRI/0^hNO0080_hRJ00D0^XNO0;n8VP2oR9X0_hRJ0;Z7W`020;n8
VP050;Z8X02oR9X0_hRJ0;n8VP2jRJ800P2nR9/30;j8W0@0_XVM0`2mRYl30;f<X@80_HfT0P33SYh2
0;b@Z080`XnQ00@0_9:/0<:AY032TJ@0^iJa0P31TjP01?l00000`9J/0<2F[02iW[`20;nJ/P040;RR
``2mW[P0_Ijh0;fN^0<0_::n00@0]:_@0;ZVa@2jY/D0/joE0P2hZl`01P2a/mX0]ZoB0;J_dP2_]]h0
/k;Ho`0001@0oooo00090?ooo`04o`00003oool0oooo0?oooc<000006_lI6AT00`000000<c<c03<c
<`0300000003o`000000000000000080c<c<00?o00000>KViP3Vi^H01@3Vi^H01?l00000c<c<0000
0000000209VIV@<0000000D0C4a<0000000c<c<0<c<c00000002oaTI6Cd00000103oool00ol00000
oooo0?ooo`0B0?ooo`03o`00003oool0oooo00X0oooo00D0^X2F0?ooo`3fb9h0m/RN0;b2U@020?_A
V@80_X>D00<0omVA0<65U031QI@00P31QI@30<>7U0050:I^TP36RY<0aXZC0<J:T`2WKY800`39SI<0
1@2XKi;o0000o`000?l00000ZG2B0080d9>D0P2ZLI801@3DUi@0Zg:B0:]bTP2[LY80f9^D00<0[7>C
102]M9<30:ifU00609AYWP2_MiH0[gNF0:mgUP2CJIl0[gVH102CJj4209=]X`<0Z8nk0`30Ujh00`2o
Sj@0`YFX0<:EZ0020;n>X@040<>CY02oS9l0_hbO0;n<W`@0_h^M0`2oRY`0102kR9l0_hVK0;n9V`2o
RI/>0;n8VP<0_XRK0`2nR9`40;j9W@<0_HZO0`2mS:401033SI`0_HfT0<>>WP33SYh20;b@Z080`XnQ
00@0_9:/0<:AY032TJ@0^iJa0P31TjP00`30UZco00000<2F[0030;nJ/P@0_Ijh00<0aIja0;bR_P2l
X[h00`2jY/D30;R[c0<0]ZoB0`2c/]P00ol00000oooo0?ooo`0A0?ooo`002@3oool01?l00000oooo
0?ooo`3ooold000001[o6ATI00@0000003<c<`000000C4a<1@0000020<c<c003o`00003Vi^H0i^KV
00D0i^KV00?o00000<c<c00000000P0000001P2IVIT00000000000000000C4a<00000080<c<c00<0
0000oaTI6OlI6AT0?00000040?ooo`03o`00003oool0oooo0140oooo00?o00000?ooo`3oool03P3o
ool0103fb9h0_8:E0?_AV@3kdIT20;j3U0030?oIT@31QI@0`HFD0080`HFD0`33Qi@40<J:T`030:M^
TP39SI?o000000;o00000P3=T9<20:U`TP80d9>D0P2ZLI801@3DUi@0Zg:B0:]bTP2[LY80f9^D0080
[7>C00<0g:6E0:edT`2]M9<00P2]M9<30:ifU0@0[gNF00<0TfVO0:miV02_NIP00`2CJj4309=]X`<0
Z8nk00<0`9N^0;6B]P32UJP00P32UJP01@2oSZ40`i>T0<>CY033Tj@0_hbO0080a96P0`2oRid30;n:
W0@0_hVK3P2oR9X30;j8V`<0_XRL00@0a8bH0;j9W@2nRId0_XVM0P2mRYl20<B<VP040;f<X@33SI`0
`hfL0;f=Y0<0`hjN00<0_92X0<:?X@32Sj400`32TJ@30<6CZ080`9J/00Go00000<NIY`2oV[80_iZb
0<JKZ`020;fN^080aIja00@0_::n0<>R]`33X[L0^ZK50P31YKh0102hZl`0_ZW50;jYa@2f[m820;^]
c0040;>bf02h/M80^;7Bo`000180oooo00090?ooo`04o`00003oool0oooo0?oooc@0000000?o0000
oaTI6OlI6AT06?lI6AT01@000000<c<c0000001<C4co000000@000000P3<c<`00ol00000i^KV0>KV
iP050>KViP07o`00003<c<co00000;>c/`000000VIVIo`0000020000000504a<C0000000<c<c03<c
<`0000000_lI6ATk000000@0oooo00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0>0?oo
o`040?K8WP2lPYD0nm6I0?_AV@80_X>D00D0omVA0<65U031QI@0`HFD0?cNQ0030<>7U0<0aXZC0ol0
00020<V=T`030:Q_TP3=T9<0cI2C0080ZG2B0P3@Ti@20:YaTP050=BGU02[LY80Zg:B0:]bTP3HVi@0
0P2/Li<01@3LXID0[GBC0:edT`2]M9<0hZNE00<0[WJD102_MiH30:miV080Tf^Q00@0/7^J09=]X`2C
KJ<0TffS0P2XSk/00`2EL:H0/I:f0;6B]P030<:EZ0050;n>X@33Tj@0`i>T0<>CY02oS9l00P34TJ03
0;n;W@<0_hZL102oRI/>0;n8VP<0_XRK0P2nR9`20<B<V080_XVM0P34S9T0102mRYl0a8bJ0<B<VP2m
S:420<>=W0@0`hjN0`32Sj430<:AY080`I>X0P38Uj<01030UZ`0aiVWo`00002oV[830<JKZ`030;fN
^035W[40aIja00<0`j:g0`31YKh30;jYa@<0^jg<0`2h/M800ol00000oooo0?ooo`0@0?ooo`002@3o
ool01?l00000oooo0?ooo`3ooolg000001Wo6ATI00@0000003<c<ol00000C4a<0`0000001?l00000
000000000?l000080>KViP04o`00003<c<`000000;>c/`;o000000L0Ogmo000000000000C4a<0000
000c<c?o000000?o6ATI00?o0000000000000000=`0000040?ooo`03o`00003oool0oooo0140oooo
00?o00000?ooo`3oool03`3oool0103kdIT0oooo0?_AV@2nPi@30?oIT@80`HFD00@0o=j40<>7U033
Qi@0`hND0ol000000`36RY<0bHfC0<V=T`020<V=T`030:Q_TP3=T9<0cI2C0080ZG2B0P3@Ti@00`2Z
LI80e9ND0=BGU0020:]bTP80f9^D0P2/Li<01@3LXID0[GBC0:edT`2]M9<0hZNE00<0[WJD102_MiH3
0:miV00409=[X@2`NiX0/7^J0;1kVP80TffS0`2EL:H30;6B]P80`YFX1033Tj@00`2oS9l0a96P0<BA
X0020;n;W@050<F@WP2oRY`0_hZL0;n:W035Si/00`2oRI/30;n8VP030<J=V@2oR9X0_hRJ00@0_hRJ
00@0aHbH0;n8VP2oR9X0_hRJ0P2nR9/00`35S9P0_XRL0;j8W0020<B<V080_XVM0P34S9T0102mRYl0
a8bJ0<B<VP2mS:420<>=W0@0`hjN0`32Sj420<:AY080bIFO00H0`I>X0<RGX`38Uj<0`9J/0<NIYol0
00040<JKZ`<0aIja00D0cZF^0<>R]`33X[L0c:Nd0<6U_P020<VY^P040;jYa@35[L40aJg10;^]c080
`Zo800@0^;7B0;jbcP2n//ko00004@3oool000T0oooo00Co00000?ooo`3oool0oooo>P00000GoaTI
6@030000000c<c<000000080000000H0Ogmo000000000000/k>c00000?l000080>KViP;o000000/0
00000;>c/`00003o00000000001VIVH0000004a<C0000000<c<c00000003oaTI6CT00000103oool0
0ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo0140oooo00<0nm6I0;j3U03ofI400P3ofI42
0<65U0040?cNQ?l0003o0000o`0000@0aXZC1039SI<0102XKi80cI2C0<f@T`2YL9830=2CU0030:Ya
TP3DUi@0e9ND0080Zg:B0P3HVi@20:acT`050=bQU@2]M9<0[GBC0:edT`3RYiD00P2^MY@00`3X[iH0
[gNF0:mgUP020:mgUP<0[gVH00@0Tf^Q0;1kVP2`NiX0/7^J0P2CKJ<409E`YP80/I:f00<0`YFX0;RC
/@2hTk400`33Tj@30<BAX080_h^M0P35T9h00`2oRY`0aHnK0<F?V`020;n9V`030<J>VP2oR9X0_hRJ
0080aXfI0P2oR9X00`35S9P0_hRJ0;n8VP020<F<V080_hRJ00<0aHbH0;j8V`2nR9/00P35S9P00`2n
R9`0a8bH0<B<V0020;j9W@80a8bI00<0_HZO0<B<VP34S9X00`33SI`40<>>WP80`XnQ0P3:U9d01032
TJ@0bIFO0<VEW`31TjP20<RGX`<0aiVW00Ko00000<JKZ`36Vj/0aY^[0=2SZ@35W[420<jU[P030<>R
]`3<Yk@0c:Nd00<0bJVj0`35[L430<:_b0<0_[;>0_l0000@0?ooo`002@3oool01?l00000oooo0?oo
o`3oooln000000;o6ATI2`000007oaTI6@030000000c<c<0<c<c00H0000000<0c<c<o`00003Vi^H0
0`3Vi^H3o`000080i^KV00Go00000000002c/k<00000o`0000030000000404a<C0000000<c<c0000
00?o6ATI>00000040?ooo`03o`00003oool0oooo0140oooo00?o00000?ooo`3oool04P3oool0102n
Pi@0omVA0?oIT@3ofI43o`000080`hND00<0k]a]0<J:T`36RY<00P36RY<40<V=T`<0cI2C00D0ZG2B
0=2CU03@Ti@0d9>D0:YaTP020=BGU080Zg:B0P3HVi@20:acT`050=bQU@2]M9<0[GBC0:edT`3RYiD0
0P2^MY@00`3X[iH0[gNF0:mgUP020:mgUP<0[gVH102`NiX00`2CKJ<0/GjM0;5nW@0309E`YP030;6B
]P2IMJT0^9>a0080^9>a0`33Tj@40<BAX0040;n;W@35T9h0aI2N0;n:W080aHnK0P2oRI/20<J>VP03
0;n8VP36SIT0aXfI0080_hRJ0P35S9P00`2oR9X0aHbH0<F<V0020;n8VP80aHbH00@0_XRK0<F<V035
S9P0_XRL0`34S9P00`2nRId0a8bI0<B<V@030<B<VP<0`hfL00<0c9>I0<>>WP33SYh00P3;Ti/01032
Sj40bYBM0<ZDW@32TJ@20<VEW`<0b9NS00H0dj2Q0<NIY`37VJL0dZ6Uo`000036Vj/20=2SZ@030<FN
/@3>YJh0cZF^00<0c:Nd00D0ekBg0<VY^P39ZKX0d[Fl0<F]`@020<jf``040<:_b039]lT0bKO90;jb
cP80a;S?00?o00000?ooo`3oool03P3oool000T0oooo00Co00000?ooo`3oool0ooooB`0000000ol0
003o6ATIoaTI6@05oaTI6@040000000c<c<0<c<co`0000D0000000D0c<c<o`00003Vi^H0i^KVo`00
00030?ooo`03o`00003Vi^H0i^KV00;o00000P0000002?l00000Ogmo000000000000C4a<o`00000c
<c<000000olI6ATg000000@0oooo00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0B0?oo
o`050;j3U03ooooo0000o`000031QI@00P3lgX@20<>7U0030>kLK@36RY<0aXZC0080aXZC1039SI<3
0<f@T`050:U`TP3@Ti@0d9>D0=2CU02ZLI800P3DUi@20:]bTP80f9^D00@0[7>C0=bQU@3LXID0g:6E
0P2]M9<0103RYiD0[WJD0:ifU03X[iH30:mgUP040>niU`2_NIP0[gVH0:miV0@0/7^J00<0TffS0;5n
W@2aOYd00`2EL:H209UeZ@<0^9>a0`33Tj@40<BAX0<0aI2N00<0_hZL0<F?V`35Si/00P2oRI/20<J>
VP030;n8VP36SIT0aXfI0080_hRJ0P35S9P00`2oR9X0aHbH0<F<V0020;n8VP80aHbH00@0_XRK0<F<
V035S9P0_XRL0`34S9P30<B<V@<0a8bJ0`33SI`00`3<TiT0`hjN0<>>WP020<^CV`030<:?X@3:U9d0
bYBM00<0bIFO00@0eInN0<RGX`38Uj<0dj2Q0P37VJL20=:QY@03o`00003@XjT0d:>Y00<0cZF^00D0
fkBa0<bW]03G];L0ekBg0<VY^P020=:e_0<0c[K30`39]lT30<Bhc`03o`00003oool0oooo00h0oooo
00090?ooo`04o`00003oool0oooo0?ooodd000001_lI6AT00`000000<c<c03<c<`020000000606IV
IP00000000000;>c/`00003o00000P3Vi^H01?l00000oooo0?ooo`3oool2o`000080i^KV00_o0000
000000000000VIVIo`0000000000IVIVo`0000000000<c<c00000003oaTI6CL00000103oool00ol0
0000oooo0?ooo`0@0?ooo`03o`00003oool0oooo0180oooo0ol000000`3oool0omVA0<65U0020?cN
Q080`hND00D0k]a]0<J:T`36RY<0aXZC0<g:B`040<V=T`<0cI2C00D0ZG2B0=2CU03@Ti@0d9>D0:Ya
TP020=BGU0050:]bTP3HVi@0f9^D0=RKU02/Li<00`3LXID00`2]M9<0hZNE0>:WU@020:ifU0050>R_
UP2_MiH0[gNF0:mgUP3_^IL00`2_NIP40;1kVP<0/GjM0`2EL:H309UeZ@<0^9>a00<0`i>T0;jE[034
TJ000`34TJ030<F@WP@0aHnK00@0_hVK0<J>VP36SYX0_hRJ0P36SIT20;n8VP80aHbH00<0_hRJ0<F<
V035S9P00P2oR9X20<F<V0030;j8V`35S9P0aHbH00@0a8bH0`34S9T30<B<VP040<bBV033SI`0`hfL
0<bCV@80`hjN0P3;Ti/30<ZDW@<0bIFO00D0eInN0<RGX`38Uj<0dj2Q0<NIY`030=:QY@05o`00003@
XjT0d:>Y0=jd[03>YJh00P3K];400`3<Yk@0ekBg0=Nd]`030=:e_0050=g;a`3>]/<0e/O<0=K7c039
]lT00P3?aM000`34^<l0bL?Eo`00000@0?ooo`002@3oool01?l00000oooo0?ooo`3ooom>000000Ko
6ATI00<0000003<c<`0000000P0000001P1VIVH000000000002c/k<00000o`000080i^KV00?o0000
0?ooo`3oool00P3oool01?l00000i^KVo`00003<c<`20000000809VIVOl0000000000000001<C4`0
000003<c<`000003oaTI6CH00000103oool00ol00000oooo0?ooo`0@0?ooo`03o`00003oool0oooo
00l0oooo0ol000040?ooo`050?oIT@31QI@0oooo0?cNQ033Qi@00P3^g6d30<J:T`030<g:B`39SI<0
bHfC0080bHfC0`3=T9<40=2CU0040:YaTP3DUi@0e9ND0:]bTP<0f9^D00D0[7>C0=bQU@3LXID0g:6E
0:edT`020>:WU@80[WJD0P3X[iH20:mgUP040>niU`2_NIP0[gVH0:miV0@0/7^J102aOYd00`2EL:H0
/X>R09UeZ@0209UeZ@80^9>a00@0Wgb/0;jE[02nUJ`0_YF/0`34TJ030<F@WP@0aHnK0`36SYX01@2o
R9X0aXfI0<J=V@36SIT0_hRJ0080aHbH00D0_hRJ0<F<V035S9P0aHbH0;n8VP050<F<V0@0a8bH0`34
S9T20<B<VP80c9:H00D0`hfL0<bCV@3<TiT0c9>I0<>>WP020<^CV`<0bYBM0P39UIl20=FOWP040<RG
X`3CX:40dj2Q0=>PX@<0dZ6U00D0d:>Yo`00003N]:`0g[B/0<jU[P020=^d/@<0ekBg00@0i<k20=:e
_03MblL0gL_70`3Fal`01`3Gh]h0clG@0=3Ih03@fN00bL?E0?ooool000003`3oool000T0oooo00Co
00000?ooo`3oool0ooooC`000006oaTI6@030000000c<c<0<c<c00<0000000L0Ogmo000000000000
c<c<o`00003Vi^Ko000000D0oooo00Oo00000>KVi_l00000c<c<o`0000000000VIVI00;o000000D0
000004a<C0000000<c<c00000003oaTI6CD00000103oool00ol00000oooo0?ooo`0@0?ooo`03o`00
003oool0oooo00`0oooo0ol000080?ooo`040<65U03oool0oooo0<>7U080oooo00@0k]a]0<J:T`36
RY<0cLY;0`39SI<010000000cI2C0<f@T`3=T9<40=2CU0<0e9ND00D0Zg:B0=RKU03HVi@0f9^D0:ac
T`030=bQU@040:edT`3RYiD0hZNE0:ifU0<0j:nF0P2_MiH20>niU`030:miV03haiL0/7^J0080/7^J
00<0o]^C0;5nW@2aOYd00P2aOYd00`2EL:H0/X>R0;:3XP0209UeZ@030;RC/@2OO:`0Wgb/00<0_YF/
0P34TJ001033UJL0aI2N0<F@WP35T9h40<F?V`<0aXjJ1036SIT=0<F<V0@0a8bH0P34S9T00`3=TYL0
a8bJ0<B<VP020<bBV0040<>=W03<TiT0c9>I0<bCV@<0bi>K0`3:U9d20<VEW`<0eInN0`3CX:420=:Q
Y@80h[BX00<0d:>Yo`00003N]:`00`3K];401P3[dkd0ekBg0>C>`P3Tc/80hOWF0=g;a`80g^gL00<0
e/O<0=ORgP2jm?800P3@fN030?ooo`03o`00003oool0oooo00d0oooo00090?ooo`04o`00003oool0
oooo0?ooodl0000000?o000000000?lI6AT01?lI6AT00`000000<c<c03<c<`030000000707moO`00
000000000<c<c?l00000i^KVo`0000050?ooo`04o`00003Vi^Ko00000<c<c080000000T0VIVIo`00
00000000000004a<C?l00000<c<c00000?l000000_lI6ATd000000@0oooo00?o00000?ooo`3oool0
403oool00ol00000oooo0?ooo`090?ooo`?o00002`3oool0103lgX@0oooo0?ooo`33Qi@20?ooo`04
0>kLK@36RY<0aXZC0<g:B`<0bHfC00@000000<f@T`3=T9<0cI2C103@Ti@30=BGU0050:]bTP3HVi@0
f9^D0=RKU02/Li<00`3LXID0102]M9<0hZNE0>:WU@2^MY@30>R_UP050:mgUP3_^IL0kkVG0>niU`2_
NIP00P3haiL20;1kVP030?kKT`2aOYd0/GjM0080/GjM0`2bPj8209UeZ@@0Wgb/0P2nUJ`01P34TJ00
`iFW0<>EY`33UJL0aI2N0<NEX`@0aHnK0`36SYX40<J=V@d0aHbH00@0cI>G0<B<V034S9P0a8bH0P34
S9T20<fBU`040<B<VP3<TYP0c9:H0<bBV0<0c9>I0`3;Ti/20<ZDW@80eYnL00@0bIFO0=FOWP3EWih0
eInN0`3CX:420=:QY@80h[BX00D0d:>Yo`00003N]:`0lMVh0=^d/@020>_C_@040=Ooa@3Tc/80hOWF
06;AZ`80g^gL0P0n`/H00`2jm?80oooo0?ooo`040?ooo`03o`00003oool0oooo00d0oooo00090?oo
o`04o`00003oool0oooo0?oooe8000001OlI6AT010000000<c<c0000001<C4`2000000;o000000@0
00000<c<c?l0003o00001P3oool01?l00000i^KVo`000?l000020000000809VIVOl00000IVIVo`00
001<C4`0000003<c<`000003oaTI6C<00000103oool00ol00000oooo0?ooo`0@0?ooo`03o`00003o
ool0oooo00H0oooo0ol0000A0?ooo`070<>7U03oool0oooo0>kLK@36RY<0oooo0<g:B`030<V=T`04
0000003=T9<0cI2C0<f@T`@0d9>D0`3DUi@40=RKU0@0g:6E00@0[GBC0>:WU@3RYiD0[WJD0`3X[iH0
1@2_MiH0kkVG0>niU`3_^IL0[gVH0080n<NG0P2`NiX20?kKT`<0/GjM0`2bPj800`2IMJT0]8ZZ0;B:
ZP0309ml[080_YF/1033UJL00`35T9h0aiFS0<F?V`020<F?V`040<VEW`36SYX0aXjJ0<J>VP@0aXfI
3@35S9P00`3=TiL0a8bH0<B<V0020<fBU`040<B<V@3=TYL0cI:G0<B<VP<0c9:H0`3<TiT20<^CV`80
f9nJ00@0bYBM0=JOW03FWi`0bIFO0`3EWih20=>PX@80iKJT00<0dZ6U0>:dZ03R]:P00P3N]:`00ol0
0000lMVh0>_C_@020>_C_@030000003QnMH0oooo00`0oooo00?o00000?ooo`3oool03@3oool000T0
oooo00Co00000?ooo`3oool0ooooD`000005oaTI6@030000000c<c<0000000<0000000@0Ogmoo`00
00000000c<c<0_l000060?ooo`0>o`00003Vi^H0i^KVo`000000003o000009VIVOl00000IVIV0000
001<C4`0000003<c<`000003oaTI6C800000103oool00ol00000oooo0?ooo`0@0?ooo`03o`00003o
ool0oooo00<0oooo0ol0000G0?ooo`040>kLK@36RY<0oooo0<g:B`80bHfC00D0oooo0000003=T9<0
cI2C0?ooo`040=2CU0<0e9ND103HVi@40=bQU@<0hZNE00D0[WJD0>R_UP3X[iH0j:nF0:mgUP030>ni
U`040:miV03haiL0n<NG0;1kVP<0o]^C0P2aOYd0103UhgL0/X>R0;:3XP2bPj830;B:ZP<0Wgb/00<0
_YF/0:V5[`33UJL00`33UJL00`35T9h0aiFS0<NEX`020<F?V`040<VEW`36SYX0aXjJ0<J>VP@0aXfI
0`35S9P00`3=U9T0aHbH0<F<V0060<F<V080cI>G0P34S9P20<fBU`040<B<V@3=TYL0cI:G0<B<VP<0
c9:H0`3<TiT20<^CV`80f9nJ00<0bYBM0=JOW03FWi`0103EWih0103Y^:40dj2Q0>FfY03U]Z@30>:d
Z0060?OQ/@3N]:`0lMVho`00002]jiT0jm>m403oool00ol00000oooo0?ooo`0=0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooomD000000Go6ATI00Co000003<c<`0c<c<000000_l000000`1oOgoo0000
00000004o`0000D0oooo00Co00000>KViP3Vi^Ko00000P000000202IVIWo0000000000000000C4a<
0000000c<c<000000olI6ATa000000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3oool3o`0001X0oooo00@0k]a]0<J:T`3oool0oooo0P39SI<20?ooo`80cI2C00D0oooo0=2CU03@
Ti@0d9>D0?ooo`030=BGU0@0f9^D103LXID30>:WU@050:ifU03X[iH0j:nF0>R_UP2_MiH00`3_^IL0
102_NIP0n<NG0?S7U`2`NiX30?kKT`80/GjM0P3UhgL20;:3XP<0]8ZZ0`2OO:`30:V5[`<0`iFW0`37
UJ<01P35Si/0bIFO0<VEW`39UIl0aXjJ0<^EW@<0aXfI00<0c9BK0<F<V035S9P00P3=U9T20<F<V004
0<fCV035S9P0aHbH0<fCU`80aHbH0P3=TiL20<B<V080cI:G00<0a8bI0<fBU`3=TYL0103<TYP20<bC
V@80fJ2I00@0bi>K0=ROVP3HWiX0bYBM0P3FWi`30=FOWP80jKRQ00<0dj2Q0>FfY03U]Z@00P3R]:P2
0?OQ/@040000003afKP0ooooo`000140oooo00?o00000?ooo`3oool03@3oool000T0oooo00Co0000
0?ooo`3oool0ooooE0000006oaTI6@070000000c<c<000000000001VIVH00000o`00000200000003
o`00003Vi^Ko000000D0oooo00Co00000>KViP3Vi^Ko00000P000000102IVIWo00000000001VIVH2
0000000303<c<`00003o6ATI00;o6ATI<@0000040?ooo`03o`00003oool0oooo00l0oooo1?l0000N
0?ooo`030<J:T`3oool0oooo0080bHfC0P3oool20<f@T`80oooo0P3@Ti@0103oool0e9ND0=BGU03D
Ui@40=RKU0@0g:6E0`3RYiD40>R_UP@0kkVG0`3haiL01@2`NiX0o]^C0?kKT`3nfi<0/GjM00<0iN=g
00<0/X>R0:G1k@2dRZX00`2dRZX00`2OO:`0]iNf0:V5[`020:V5[`80`iFW00D0]8n`0<NEX`37UJ<0
aiFS0<F?V`030<VEW`030<J>VP3;UId0biFM0080aXfI00<0c9BK0<F<V035S9P00P3=U9T20<F<V003
0<fCV035S9P0aHbH0080cI>G00<0aHbH0<fCU`3=TiL00P34S9P50<fBU`@0c9:H0P3<TiT20=VPV@03
0<^CV`3HWiX0f9nJ00<0eYnL00<0kK^O0=FOWP3EWih00P3Y^:430>FfY0030?[XZ03R]:P0mn6a00@0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0=0?ooo`002@3oool01?l00000oooo
0?ooo`3ooomE000000Go6ATI00<0000003<c<`0c<c<00P0000000`1VIVH00000o`00000200000003
o`00003Vi^Ko000000D0oooo00Co00000>KViP3Vi^Ko00000P0000001?l00000Ogmo0000001VIVH2
0000000303<c<`00003o6ATI00;o6ATI<00000040?ooo`03o`00003oool0oooo00l0oooo0_l0000S
0?ooo`050<V=T`3oool0oooo0?ooo`3=T9<00`3oool20=2CU0040?ooo`3DUi@0e9ND0?ooo`<0f9^D
00<0Y[k[0=bQU@3LXID00P3LXID30>:WU@@0j:nF00@0Y;o]0>niU`3_^IL0kkVG0`3haiL01@3nfi<0
YL3]0:G0k@2U`>d0/GjM0080YL3]00@0iN=g0;:3XP2U`Nd000000`2dRZX30;NG]P80ZHF_00<0`iFW
0;B?/02dSk000`37UJ<01@35Si/0bIFO0<VEW`39UIl0aXjJ0080biFM0P36SIT20<bDV`030<F<V03=
U9T0cIBI0080aHbH0P3=TiP01035S9P0cI>G0<fCU`35S9P30<fCU`030<B<V03=TYL0cI:G00<0cI:G
0`3<TYP00`3JXIP0c9>I0<bCV@020=VPV@030<^CV`3HWiX0f9nJ00<0eYnL00<0kK^O0=FOWP3EWih0
0P3Y^:420>FfY080n^RX1`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00`0oooo
00090?ooo`04o`00003oool0oooo0?oooeH000001OlI6AT00`000000<c<c000000020000000306IV
IP00003o00000080000000?o00000>KVi_l000001@3oool01Ol00000i^KV0>KVi_l00000000000;o
000000L0Ogmo000000000000C4a<0000000c<c<0000000;o6ATI<00000040?ooo`03o`00003oool0
oooo0140oooo00?o00000?ooo`3oool0803oool01@39SI<0oooo0?ooo`3oool0cI2C00<0oooo00D0
d9>D0?ooo`3oool0000W0=BGU0020?ooo`80f9^D00@0YkkZ0:Jnj`3LXID0g:6E0P2V_^/20>:WU@04
0:Fok03X[iH0j:nF0>R_UP80YKo/00<0kkVG0:Fok02U_n`00P2U_n`00`2U`>d0YKo/0:Fok0030:G0
k@80Y/3/00<0/X>R0:K1k@0000000P2dRZX0102V`Nd0]iNf0;NG]P2gUkH20:V5[`@0]8n`0P37UJ<4
0<VEW`040<J>VP3;UId0biFM0<J=V@<0c9BK00<0aHbH0<fDV@3=U9T00P35S9P20<fCV0040<F<V03=
TiL0cI>G0<F<V0<0cI>G1P3=TYL00`3KXIP0c9:H0<bBV0020=ZQV0030<bCV@3IX9T0fJ2I00<0f9nJ
00<0l;nL0=JOW03FWi`00P3]^il30>VhX@030?G^V03U]Z@0n^RX00T0oooo00?o00000?ooo`3oool0
3P3oool00ol00000oooo0?ooo`0<0?ooo`002@3oool01?l00000oooo0?ooo`3ooomF00000003o`00
0000003o6ATI00?o6ATI00Ko000003<c<`0c<c<00000o`00001VIVH2o`00000500000?l0003o0000
0>KVi_l000001@3oool2o`0000040>KVi_l000000000000000;o00000P000000101<C4`0000003<c
<`000002oaTI6Bl00000103oool00ol00000oooo0?ooo`0B0?ooo`03o`00003oool0oooo01l0oooo
00D0bHfC0?ooo`3oool0oooo0<f@T`030?ooo`050=2CU03oool0oooo00009`3DUi@00P3oool20=RK
U080YkkZ0P3LXID00`2V_^/0Y[kZ0>:WU@030:Jnj`030>R_UP2V_^/0Y[k[0080Y[o[00<0YKo/0:Jo
j`2V_n/00P2V_n`00`2U_n`0Y[o/0:Jok0070:K0k0040;B:ZP2V`>`0Y/3/0:O1k080]iNf00<0ZHF_
0;f_c02m[l`00`2dSk020<NEX`040;nH[`39UIl0bIFO0<VEW`<0biFM00D0aXfI0<bDV`3<U9/0c9BK
0<F<V0030<fDV@040<F<V03=TiP0cI>H0<F<V0H0cI>G1P3=TYL00`3KXIP0c9:H0<bBV0020=ZQV003
0<bCV@3IX9T0fJ2I00<0f9nJ00<0l;nL0=JOW03]^il00P3]^il20>VhX@80mNjH303oool00ol00000
oooo0?ooo`0=0?ooo`03o`00003oool0oooo00`0oooo00090?ooo`04o`00003oool0oooo0?oooeT0
00001?lI6AT010000000<c<c0000001<C4`200000007o`00002IVIT0000000000?l00000i^KVo`00
00050?ooo`04o`00003Vi^Ko00000<c<c080000000P0VIVIo`0000000000000004a<C0000000<c<c
000000;o6ATI;P0000040?ooo`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool09P3oool0
1@3@Ti@0oooo0?ooo`3oool0e9ND0080oooo00D0f9^D0?ooo`3oool0YkkZ0=bQU@030:NnjP030>:W
U@2V_^X0Y[k[00<0Y[k[00<0Ykk[0:Joj`2V_n/01P2V_n/00`2V_n`0Y[o[0:Joj`020:Jok0030:K0
k02V_n`0Y[o/00<0Y/3/0P2W`>`00`2gUkH0Yl3/0;f_c0020;f_c0<0]8n`00<0aiFS0;nH[`2oV:l0
0`39UIl30<^EW@040<J=V@3<U9/0c9BK0<bDV`@0cIBI0`3=TiP70<fCU`<0cI:G00@0g::H0<fBU`3=
TYL0fj6H0P3<TYP20=ZQV0<0fJ2I00D0m<BK0=ROVP3HWiX0l;nL0=JOW0030>fkW`030=WTN03Y^:40
mNjH00d0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0<0?ooo`002@3oool01?l0
0000oooo0?ooo`3ooomJ000000Co6ATI00@0000003<c<`000000C4a<0P000002o`00008000000ol0
00050?ooo`04o`00003Vi^Ko00000<c<c080000000So000007moO`000000000004a<C0000000<c<c
000000;o6ATI;@0000040?ooo`03o`00003oool0oooo01@0oooo0_l0000Z0?ooo`040=BGU03oool0
oooo0=RKU0<0oooo00<0g:6E0:NnjP2W_^X0102W_^X00`2V_^/0YkkZ0:NnjP020:Nnj`030:Joj`2W
_^/0Ykk[00<0Y[o[0P2W_n/00`2V_n/0Yko[0:Noj`020:Noj`030:Jok02W_n/0Yl3[0080Yl3[00<0
Yl3/0:Noj`2W_n/00P2W`>/20;f_c0<0]8n`0`2oV:l30<VEW`<0biFM103<U9/40<fDV@<0cI>H1`3=
TiL20<fBU`80g::H0P3=TYL00`3KXIP0c9:H0<bBV0020=ZQV0<0fJ2I00<0m<BK0=ROVP3`_i`00P3`
_i`20>fkW`80fNAh403oool00ol00000oooo0?ooo`0<0?ooo`03o`00003oool0oooo00`0oooo0009
0?ooo`04o`00003oool0oooo0?oooe/000001?lI6AT00`000000<c<co`000003000000;o00000P00
00000`3<c<co0000o`0000050?ooo`04o`00003Vi^Ko00000<c<c080000000So000007moOol0003o
000004a<C0000000<c<co`0000;o6ATI00?o0000000000000000:@0000040?ooo`03o`00003oool0
oooo01H0oooo00?o00000?ooo`3oool0:P3oool00`3HVi@0oooo0?ooo`020?ooo`80Z;kY00<0YkkZ
0:Nnj@2W_^T01`2W_^X00`2W_^/0YkkZ0:NnjP0<0:Noj`040:O0j`2W_n/0Yko[0:Noj`@0Z;o[00@0
Z<3[0:Roj`2dSk00`Mg]102oV:l00`39UIl0bYn/0<^EW@020<^EW@@0c9BK103=U9T30<fCV0L0cI>G
0P3=TYL20=bRV0040<fBU`3KXIP0fj6H0=^QV0<0fZ6H0P3IX9T20?C4V`040=ROVP3`_i`0l;nL0?2o
W080kK^O00<0fNAh0?ooo`3oool0403oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo
00`0oooo00090?ooo`04o`00003oool0oooo0?oooe/000001OlI6AT03@000000<c<c000000000000
IVIV00000?l00000VIVI0000003<c<co00000>KVi_l00000103oool01?l00000i^KVo`00003<c<`2
00000008o`00001oOgl000000000001<C4`0000003<c<`000003oaTI6B/00000103oool00ol00000
oooo0?ooo`0G0?ooo`03o`00003oool0oooo02l0oooo0P2X_^T00`2W_^T0Z;kY0:Rnj@020:Nnj@03
0:NnjP2X_^X0Z;kZ00L0YkkZ00<0Yko[0:NnjP2W_^X00`2W_n/20:NojP<0Yko[102X_n/40:RojP03
0:Roj`2X_nX0`Mg]00<0_iR_00@0bIFO0<ZO[03:Wj`0biFM0P3AXjP30<bDV`@0cIBI0`3=TiP30<fC
U`040=bTV`3=TiL0cI>G0=bSV@80cI:G0P3LXYP0103=TYL0fj6H0=^QV03KXIP30=ZQV080fJ2I0`3d
a9/30?2oW0030000003]^il0oooo01<0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?oo
o`0<0?ooo`002@3oool01?l00000oooo0?ooo`3ooomL000000Go6ATI00L0000003<c<`0000000000
06IVIP00003o00000080000000@0c<c<o`00003Vi^Ko0000103oool01?l00000i^KVo`00003<c<`2
00000008o`0000000000IVIV0000001<C4`0000003<c<`000003oaTI6BX00000103oool00ol00000
oooo0?ooo`0H0?ooo`03o`00003oool0oooo02l0oooo1`2X_^T01P2X_^X0Z;kY0:Rnj@2X_^T0Z;kZ
0:NnjP<0Z;kZ0P2W_^X30:RnjP<0YkoZ102X_nX00`2X_n/0Z;oZ0:RojP070:RojP80_iR_00D0SnoG
0<ZO[03:Wj`0bYn/0<^EW@020=6SZ080c9BK00D0ejFT0<fDV@3=U9T0cIBI0=ZVX0030<fCV080cI>G
0P3LY9/20<fCU`80g:>I00@0cI:G0=bRV03LXYP0g::H0`3KXIP30=ZQV0030?W;V@3IX9T0m<BK0080
m<BK0P3`_i`G0?ooo`03o`00003oool0oooo00/0oooo00?o00000?ooo`3oool02`3oool000T0oooo
00Co00000?ooo`3oool0ooooG@000004oaTI6@080000000c<c<0000004a<C0000000IVIV00000?l0
0002000000;o000000<0i^KVo`00003oool00`3oool02Ol00000i^KVo`0000000000/k>c00000?l0
0000000006IVIP0200000080<c<c00@00000oaTI6OlI6AWo6ATI:@0000040?ooo`03o`00003oool0
oooo01T0oooo0_l0000`0?ooo`d0Z;kY00<0Z;kZ0:Rnj@2X_^T00P2X_^T00`2X_^X0Z;kY0:Rnj@02
0:RnjP030:RojP2X_^X0Z;kZ00<0Z;oZ0P2X_^X80:RojP0508o_e`3:Wj`0bYn/0<ZO[03;UId00P3A
XjP20<bDV`050=NUY03=U9T0cIBI0<fDV@3JYZ000P3=TiP00`3KYId0cI>G0<fCU`020=bTV`80cI>G
0P3LXiT0103=TYL0g::H0=bRV03LXYP30=^QV080fZ6H0P3ibiT01P3IX9T0m<BK0?C4V`3da9/00003
0?2oW1P0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0;0?ooo`002@3oool01?l0
0000oooo0?ooo`3ooomO000000?o6ATI00<0000003<c<ol000000P0000000`1VIVH00000o`000002
000000;o000000<0i^KVo`00003oool00`3oool02Ol00000i^KVo`0000000000/k>c00000?l00000
000006IVIP020000000303<c<ol0003o6ATI00;o6ATI00?o00000000000000009P0000040?ooo`03
o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0;P3ooolG0:Rnj@030:RnjP2X_^T0Z;kY0080
Z;kY00<0Z;kZ0:Rnj@2X_^T00P2X_^T00`2X_nX0Z;kY0:Rnj@030:Roj@0308o_e`3:Wj`0bYn/00@0
dJ>X00<0c9BK0=NUY03GYJ@00P3=U9T20=ZVX0040<fCV03KYId0fjFM0<fCU`80g:BK0P3=TiL20=bS
V@@0g::H0`3KXIP0103ldiP0fZ6H0?W;V@3ibiT30?C4Va`0oooo00?o00000?ooo`3oool02@3oool0
0ol00000oooo0?ooo`0;0?ooo`002@3oool01?l00000oooo0?ooo`3ooomP000000?o6ATI00<00000
03<c<`0c<c<00P0000002@1VIVH00000o`000?l00000/k>c00000?l00000i^KVo`0000030?ooo`04
o`00003Vi^Ko00000<c<c080000000P0VIVIo`0000000000000004a<C0000000<c<c000000?o6ATI
:00000040?ooo`03o`00003oool0oooo01`0oooo00?o00000?ooo`3oool0;P3oool00`2X_^T0ZKgY
0:Vmj@0O0:Rnj@D0ZKkY00<0bYn/0000003AXjP00`3AXjP30=NUY0050<fDV@3JYZ00fZJP0=ZVX03=
TiP00P3KYId01@3=TiL0g:BK0=bTV`3LY9/0cI>G0080g:>I103LXYP20=^QV080o=>H00D0fZ6H0?W;
V@3ibiT0oooo0?C4V`0N0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool02`3oool0
00T0oooo00Co00000?ooo`3oool0ooooH@000003oaTI6@0@o`00000c<c<0<c<c00000?l00000IVIV
00000?l0000000000;>c/`00003o00000>KVi_l00000ooooo`0000<0i^KV00Go00000<c<c?l00000
000009VIV@02o`0000050000001<C4`0000003<c<`0000000olI6ATW000000@0oooo00?o00000?oo
o`3oool07@3oool00ol00000oooo0?ooo`0^0?ooo`030:Vmj@2Y_NP0ZKgX0080ZKkY00<0Z;kY0:Vn
j@2Y_^T0402X_^T00`2Y_^T0Z;kY0:Rnj@020:Rnj@/0ZKkY00@000000=6SZ03AXjP000000`3GYJ@0
1@3=U9T0fZJP0=ZVX03JYZ00cI>H0080fjFM00@0cI>G0=bTV`3LY9/0g:BK0`3LXiT40=bRV0040?kL
U@3KXIP0o=>H0?cCV0<0nL^I803oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo00/0
oooo00090?ooo`04o`00003oool0oooo0?ooof8000000olI6AT03P000000<c<c03<c<ol000000000
06IVIP00003o00000000002c/k<00000o`00003Vi^Ko00001@3Vi^H01_l00000c<c<000000000000
VIVIo`000080000000@0C4a<o`00000c<c<000000olI6ATV000000@0oooo00?o00000?ooo`3oool0
7P3oool2o`0002l0oooo1@2Y_NP00`2Y_^T0ZKgX0:Vmj0020:Vnj@030:Rnj@2Y_^T0ZKkY0080ZKkY
00<0Z;kY0:Vnj@2Y_^T00P2Y_^T00`2X_^T0ZKkY0:Vnj@020:Vnj@030:Rnj@2Y_^T0ZKkY00/0ZKkY
00@0oooo0=6SZ03oool000000`3GYJ@0103=U9T0fZJP0=ZVX03JYZ030=^UW@@0g:BK0`3LXiT00`3j
iXl0g::H0=bRV0020?kLU@050=^QV03ldiP0o=>H0?ooo`3ibiT08P3oool00ol00000oooo0?ooo`07
0?ooo`03o`00003oool0oooo00/0oooo00090?ooo`04o`00003oool0oooo0?ooof8000001?lI6AT0
20000000<c<c0000001<C4`00000o`00001oOgoo00000P0000000ol00000i^KV0>KViP050>KViP0:
o`00003<c<`000000;>c/`00003o00000000001VIVKo000000000080<c<c00Co0000oaTI6OlI6AWo
00009@0000040?ooo`03o`00003oool0oooo0200oooo00?o00000?ooo`3oool0;@3oool80:Vmj080
ZKkX00<0ZKkY0:Vnj02Y_^P00`2Y_^T20:Vnj100ZKkY203oool00`000000ejFT0=NUY0040=ZVX0<0
fjFM103LY9/20=bSV@80n^J?0P3LXYP20?kLU@<0o=>H9@3oool00ol00000oooo0?ooo`070?ooo`03
o`00003oool0oooo00X0oooo00090?ooo`04o`00003oool0oooo0?ooof<000001?lI6AT010000000
<c<c0000001<C4`20000000507moOol00000000000000?l000001`3Vi^H01_l00000c<c<0000002c
/k<00000o`000080000000@0C4a<0000000c<c<000000_lI6ATV000000@0oooo00?o00000?ooo`3o
ool08@3oool00ol00000oooo0?ooo`0^0?ooo`T0ZKgX00<0ZKkX0:Vmj02Y_NP01`2Y_^P00`2Y_^T0
ZKkX0:Vnj0020:Vnj0030:Vnj@2Y_^P0ZKkX0080ZKkX00<0ZKkY0?ooo`3oool02@3oool00`3GYJ@0
oooo000000030=ZVX0<0fjFM00<0^mUX0=bTV`3LY9/00P3Wj8400`3LXiT0n^J?0?[VS`020=bRV080
o]bE00<0oooo0?cCV03oool09P3oool00ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo00X0
oooo00090?ooo`04o`00003oool0oooo0?ooof@000001?lI6AT01?l00000<c<c0000001<C4`20000
000407moOol000000000000000;o00001@3Vi^H03Ol00000c<c<0000002c/k<00000o`00001oOgoo
00000000001<C4`0000003<c<`0000000_lI6ATU000000@0oooo00?o00000?ooo`3oool08P3oool0
0ol00000oooo0?ooo`0^0?ooo`h0ZKgX00<0ZKkX0:Vmj02Y_NP0202Y_^PB0?ooo`80fZJP00<0oooo
0000003KYId00P2kfFP20=bTV`80inR100@0g:>I0?[VS`3jiXl0n^J?0P3ng9DZ0?ooo`03o`00003o
ool0oooo00H0oooo00?o00000?ooo`3oool02P3oool000T0oooo00Co00000?ooo`3oool0ooooI@00
0003oaTI6@050000000c<c<0<c<c0000001<C4`00P0000000ol00000VIVI00000002000000;o0000
103Vi^H01ol00000c<c<o`00002c/k<00000o`00001oOgl00P000000101<C4`0000003<c<`000002
oaTI6B@00000103oool00ol00000oooo0?ooo`0S0?ooo`03o`00003oool0oooo02h0oooo4`2Y_NP0
0`2Y_^P0oooo0?ooo`0E0?ooo`040=ZVX03oool0oooo0=^UW@80oooo0P3LY9/20?ooo`030?[VS`3o
ool0oooo02h0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0:0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooomV000000?o6ATI00H0000003<c<`0c<c<0000004a<C0000002o`000005
09VIVOl00000/k>c0000003<c<`00_l000020>KViP03o`00003<c<`0c<c<0080000000@0VIVIo`00
00000000IVIV0P00000203<c<`03o`000?lI6AWo6ATI02<00000103oool00ol00000oooo0?ooo`0T
0?ooo`;o0000;`3oool@0:Vmj240oooo00<0inR10?ooo`3oool0<P3oool00ol00000oooo0?ooo`04
0?ooo`03o`00003oool0oooo00X0oooo00090?ooo`04o`00003oool0oooo0?ooofL000000olI6AT0
30000000<c<c03<c<`000000C4a<o`000000003o000009VIV@000000/k>c00000080c<c<00co0000
0>KViP3Vi^Ko00000<c<c0000000/k>c0000002IVIWo00000000001VIVH20000000303<c<`00003o
6ATI00;o6ATI8P0000040?ooo`03o`00003oool0oooo02H0oooo00?o00000?ooo`3oool0;@3oool=
0:Vmj5P0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0:0?ooo`002@3oool01?l0
0000oooo0?ooo`3ooomW00000009o`000?lI6AWo6ATIoaTI6Ol00000000003<c<ol00000C4a<0080
00000_l000000`000000/k>c000000020<c<c009o`00003Vi^Ko0000o`00003<c<`000000;>c/ol0
0000VIVI00;o000000D0IVIVo`0000000000<c<c00000003oaTI6@03o`0000000000000001h00000
103oool00ol00000oooo0?ooo`0W0?ooo`03o`00003oool0oooo02d0oooo202Y_NQM0?ooo`03o`00
003oool0oooo00<0oooo00?o00000?ooo`3oool02P3oool000T0oooo00Co00000?ooo`3oool0oooo
J@000003oaTI6@030000000c<c<0<c<c0080000000P0IVIVo`00001oOgoo00000000002c/k<00000
0<c<c0;o00000`3<c<`01P000000/k>c0000002IVIWo000007moO`80000000@0C4a<o`00000c<c<0
00000_lI6ATQ000000@0oooo00?o00000?ooo`3oool0:03oool00ol00000oooo0?ooo`0]0?ooo`<0
ZKgXHP3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo00T0oooo00090?ooo`04o`00
003oool0oooo0?ooofX000000olI6AT030000000<c<c0000001<C4`0000006IVIP000000Ogmoo`00
00000000/k>c000000H0c<c<00L000000;>c/`000000VIVIo`0000000000IVIV008000000P0c<c<0
0`00003o6ATIoaTI6@0P000000@0oooo00?o00000?ooo`3oool0:@3oool2o`0002d0oooo00?o0000
0?ooo`3oool0H`3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo00T0oooo00090?oo
o`04o`00003oool0oooo0?ooof/000000olI6AT030000000<c<c0000001<C4co000006IVIP000000
Ogmoo`0000000000/k>c000000D0c<c<00H000000;>c/`2c/k<0000009VIVOl000020000000504a<
C0000000<c<c03<c<`0000000_lI6ATO000000@0oooo00?o00000?ooo`3oool0:`3oool00ol00000
oooo0?ooo`0Z0?ooo`03o`00003oool0oooo06<0oooo00?o00000?ooo`3oool00P3oool00ol00000
oooo0?ooo`090?ooo`002@3oool01?l00000oooo0?ooo`3ooom/000000?o6ATI00d0000003<c<ol0
0000C4a<0000001VIVH00000o`00002IVIT000000;>c/ol00000000000<0c<c<0P0000020;>c/`09
00000?l00000000006IVIP000000C4a<0000000c<c?o000000;o6ATI00?o00000000000000007000
00040?ooo`03o`00003oool0oooo02`0oooo00?o00000?ooo`3oool0:@3oool00ol00000oooo0?oo
o`1T0?ooo`05o`00003oool0oooo0?ooool000002`3oool000T0oooo00Co00000?ooo`3oool0oooo
K@000003oaTI6@060000000c<c<0000004a<C0000000IVIV0_l000001`2IVIWo00000;>c/`2c/k<0
00000<c<c0000000102c/k<00`00003o000007moO`0200000080C4a<0P000003oaTI6Ah00000103o
ool00ol00000oooo0?ooo`0]0?ooo`03o`00003oool0oooo02P0oooo00?o00000?ooo`3oool0I@3o
ool01?l00000oooo0?ooool0000;0?ooo`002@3oool01?l00000oooo0?ooo`3ooom^000000?o6ATI
00X0000003<c<`000000C4a<0000001VIVH00000o`00002IVIT000000P2c/k<00`000000/k>c0;>c
/`040;>c/`0500000?l00000Ogmoo`00000000000P1<C4`2000000?o6ATI7@0000040?ooo`03o`00
003oool0oooo02h0oooo0_l0000X0?ooo`03o`00003oool0oooo06H0oooo00?o00000?ooool00000
2`3oool000T0oooo00Co00000?ooo`3oool0ooooKP0000002ol0003o6ATIoaTI6OlI6AT0000003<c
<`000000C4a<0000001VIVH0000000;o00000P0000070;>c/`040000002IVIWo000007moO`800000
00@0C4a<o`00000c<c<000000olI6ATL000000@0oooo00?o00000?ooo`3oool0<03oool00ol00000
oooo0?ooo`0U0?ooo`03o`00003oool0oooo06H0oooo00?o00000?ooool000002`3oool000T0oooo
00Co00000?ooo`3oool0ooooL0000002oaTI6@0;0000000c<c<0<c<c0000001<C4`0000006IVI_l0
0000Ogmoo`00002IVIT00P0000050;>c/`060000002IVIWo000007moO`000000IVIV0P00000203<c
<`05o`000?lI6AWo6ATIoaTI6Ol000006P0000040?ooo`03o`00003oool0oooo0340oooo00?o0000
0?ooo`3oool0903oool00ol00000oooo0?ooo`1W0?ooo`03o`00003ooooo000000X0oooo00090?oo
o`04o`00003oool0oooo0?ooog4000000_lI6AT02P000000<c<c03<c<`000000C4a<0000001VIVH0
000007moOol0000209VIV@030000002c/k<0/k>c0080/k>c00L0000009VIV@2IVIWo000007moO`00
0000IVIV0080000000<0<c<c00000?lI6AT00_lI6ATK000000@0oooo00?o00000?ooo`3oool0<P3o
ool00ol00000oooo0?ooo`0S0?ooo`03o`00003oool0oooo06P0oooo0_l0000:0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooomb000000;o6ATI00X0000003<c<`0c<c<0000004a<C?l00000IVIV0000
001oOgoo00000P2IVIT00`000000/k>c0;>c/`020;>c/`0;0000002IVIWo000007moO`000000IVIV
0000001<C4`0000003<c<`0000000olI6ATJ000000@0oooo00?o00000?ooo`3oool0<`3oool2o`00
02<0oooo00?o00000?ooo`3oool0I`3oool3o`0000X0oooo00090?ooo`04o`00003oool0oooo0?oo
og<000000_lI6AT02_l00000000003<c<ol00000C4a<0000001VIVH0000007moOol0000209VIV@05
o`000000000000000;>c/ol000000P2IVIT02Ol00000Ogmoo`00001VIVH0000004a<C0000000<c<c
00000002oaTI6AX00000103oool00ol00000oooo0?ooo`0e0?ooo`03o`00003oool0oooo0200oooo
00?o00000?ooo`3oool0H`3oool4o`0000d0oooo00090?ooo`04o`00003oool0oooo0?ooog@00000
0olI6AT02@000000<c<c0000001<C4`0000006IVI_l00000Ogmoo`00000409VIV@050000002IVIT0
VIVI09VIVOl000000P1oOgl20000000504a<C0000000<c<c03<c<`0000000_lI6ATI000000@0oooo
00?o00000?ooo`3oool0=P3oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo0600oooo
0ol0000A0?ooo`002@3oool01?l00000oooo0?ooo`3ooome000000?o6ATI00P0000003<c<`000000
C4a<0000001VIVH0000007moO`;o00001`2IVIT01ol00000Ogmo0000001VIVH0000004a<C0000000
0P0c<c<00`00003o6ATIoaTI6@0H000000@0oooo00?o00000?ooo`3oool0=`3oool00ol00000oooo
0?ooo`0N0?ooo`03o`00003oool0oooo05`0oooo1?l0000D0?ooo`002@3oool01?l00000oooo0?oo
o`3ooome0000000;o`000?lI6AWo6ATIoaTI6Ol00000<c<c0000001<C4`0000006IVIP0000000P1o
Ogl2o`0000D0VIVI00[o000007moO`1oOgl0000006IVIP000000C4a<0000000c<c?o00000olI6AT0
0ol0000000000000000D000000@0oooo00?o00000?ooo`3oool0>03oool2o`0001h0oooo00?o0000
0?ooo`3oool0F03oool4o`0001P0oooo00090?ooo`04o`00003oool0oooo0?ooogL000000_lI6AT0
2@000000<c<c03<c<`000000C4a<0000001VIVKo00000000000207moO`;o00000`2IVIT02_l00000
Ogmo07moO`000000IVIVo`00001<C4`0000003<c<`000003oaTI6AL00000103oool00ol00000oooo
0?ooo`0j0?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0E03oool4o`0001`0oooo
00090?ooo`04o`00003oool0oooo0?ooogL000000olI6AT01P000000<c<c03<c<`000000C4a<0000
0080IVIV00L0000007moO`1oOgl0Ogmoo`00002IVIWo000000<0Ogmo00<0000006IVIP0000000P1<
C4`00`000000<c<c00000003oaTI6AH00000103oool00ol00000oooo0?ooo`0k0?ooo`03o`00003o
ool0oooo01X0oooo00?o00000?ooo`3oool0D@3oool3o`000200oooo00090?ooo`04o`00003oool0
oooo0?ooogP000000olI6AT01P000000<c<c03<c<`000000C4a<o`000080IVIV00D00000o`00001o
Ogl0Ogmoo`00000507moO`030000001VIVH000000080C4a<0P000003oaTI6AH00000103oool00ol0
0000oooo0?ooo`0l0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool0C@3oool4o`00
02<0oooo00090?ooo`04o`00003oool0oooo0?ooogP0000000Wo0000oaTI6OlI6AWo6ATIo`000000
0000<c<co`00001<C4`00P0000000`1VIVH000000000000707moO`090000001VIVH0IVIV0000001<
C4co000003<c<`00003o000000;o6ATI5@0000040?ooo`03o`00003oool0oooo03d0oooo0_l0000I
0?ooo`03o`00003oool0oooo04T0oooo1?l0000W0?ooo`002@3oool01?l00000oooo0?ooo`3ooomk
000000?o6ATI00<0000003<c<`0000000P1<C4`010000000IVIV06IVIP00000607moO`060000001V
IVH0IVIV0000001<C4`000000P0c<c<01000003o6ATIoaTI6OlI6ATD000000@0oooo00?o00000?oo
o`3oool0?`3oool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo04D0oooo1?l0000[0?oo
o`002@3oool01?l00000oooo0?ooo`3oooml000000?o6ATI00<0000003<c<`0000000P1<C4`00ol0
0000IVIV06IVIP02000000D0Ogmo00H0000006IVIP1VIVH0000004a<C000000203<c<`0400000?lI
6AWo6ATIoaTI6A<00000103oool00ol00000oooo0?ooo`100?ooo`03o`00003oool0oooo01@0oooo
00?o00000?ooo`3oool0@`3oool3o`0002l0oooo00090?ooo`04o`00003oool0oooo0?ooog`00000
00Ko0000oaTI6OlI6AWo6ATIo`00000c<c<20000000304a<C0000000IVIV0080IVIV0P00000207mo
O`8000000P1VIVH010000000C4a<04a<C000000203<c<`0400000?lI6AWo6ATIoaTI6A800000103o
ool00ol00000oooo0?ooo`110?ooo`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool0?`3o
ool4o`000380oooo00090?ooo`04o`00003oool0oooo0?ooogh000000_lI6AT01`000000<c<c03<c
<`0c<c<0000004a<C0000000101VIVH2000000D0IVIV00?o000004a<C00000000P0c<c<01000003o
6ATIoaTI6OlI6ATB000000@0oooo00?o00000?ooo`3oool0@P3oool2o`0001<0oooo00?o00000?oo
o`3oool0>`3oool4o`0003H0oooo00090?ooo`04o`00003oool0oooo0?ooogh000000olI6AT01000
0000<c<c03<c<`00000204a<C0030000001VIVH0IVIV00P0IVIV00@0000004a<C01<C4`000000P0c
<c<01000003o6ATIoaTI6OlI6ATA000000@0oooo00?o00000?ooo`3oool0A03oool00ol00000oooo
0?ooo`0@0?ooo`03o`00003oool0oooo03L0oooo1?l0000j0?ooo`002@3oool01?l00000oooo0?oo
o`3ooomo000000?o6ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV06IVIP0806IVIP03
0000001<C4`000000080<c<c00@00000oaTI6OlI6AWo6ATI4@0000040?ooo`03o`00003oool0oooo
04D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?ooo`Co0000?P3oool000T0
oooo00Co00000?ooo`3oool0ooooO`0000002?l0003o6ATIoaTI6OlI6AWo00000000000c<c?o0000
1P00000606IVIP040000001<C4`0C4a<00000080<c<c00Co0000oaTI6OlI6AWo6ATI400000040?oo
o`03o`00003oool0oooo04H0oooo00?o00000?ooo`3oool03P3oool00ol00000oooo0?ooo`0`0?oo
o`?o0000@P3oool000T0oooo00Co00000?ooo`3oool0ooooPP000003oaTI6@050000000c<c<0<c<c
03<c<`0000000`1<C4`00`000000IVIV06IVIP0306IVIP040000001<C4`0C4a<00000080<c<c00@0
0000oaTI6OlI6AWo6ATI400000040?ooo`03o`00003oool0oooo04L0oooo00?o00000?ooo`3oool0
3@3oool00ol00000oooo0?ooo`0/0?ooo`Co0000A@3oool000T0oooo00Co00000?ooo`3oool0oooo
P`000003oaTI6@050000000c<c<0<c<c03<c<`0000000`1<C4`30000000306IVIP000000C4a<00<0
C4a<00@0000003<c<`0c<c<000000olI6AT?000000@0oooo00?o00000?ooo`3oool0B03oool2o`00
00d0oooo00?o00000?ooo`3oool0:03oool4o`0004T0oooo00090?ooo`04o`00003oool0oooo0?oo
oh<0000000Co0000oaTI6OlI6AWo6ATI0P00000203<c<`030000001<C4`0C4a<00<0C4a<0P000004
04a<C0050000000c<c<0<c<c03<c<`0000000olI6AT>000000@0oooo00?o00000?ooo`3oool0BP3o
ool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo02@0oooo1?l0001=0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooon5000000Co6ATI00@0000003<c<`0c<c<000002P1<C4`01@000000<c<c
03<c<`0c<c<0000000?o6ATI00?o00000000000000002`0000040?ooo`03o`00003oool0oooo04/0
oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0Q0?ooo`?o0000D@3oool000T0oooo
00Co00000?ooo`3oool0ooooQ@000005oaTI6@040000000c<c<0<c<c000000T0C4a<00<0000003<c
<`0c<c<00P0c<c<00`00003o6ATIoaTI6@0>000000@0oooo00?o00000?ooo`3oool0C03oool00ol0
0000oooo0?ooo`080?ooo`03o`00003oool0oooo01d0oooo1?l0001D0?ooo`002@3oool01?l00000
oooo0?ooo`3ooon6000000Go6ATI00Co000003<c<`0c<c?o00002@1<C4`01@000000<c<c03<c<`0c
<c<0000000?o6ATI3@0000040?ooo`03o`00003oool0oooo04d0oooo0_l000080?ooo`03o`00003o
ool0oooo01T0oooo1?l0001H0?ooo`002@3oool01?l00000oooo0?ooo`3ooon600000003o`000000
003o6ATI00;o6ATI0P00000203<c<`<000001@1<C4`2000000<0<c<c00?o0000oaTI6OlI6AT00_lI
6AT<000000@0oooo00?o00000?ooo`3oool0C`3oool00ol00000oooo0?ooo`050?ooo`03o`00003o
ool0oooo01D0oooo1?l0001L0?ooo`002@3oool01?l00000oooo0?ooo`3ooon9000000Co6ATI00<0
000003<c<`0c<c<00P0c<c<30000000304a<C0000000<c<c00@0<c<c00<00000oaTI6OlI6AT00_lI
6AT<000000@0oooo00?o00000?ooo`3oool0D03oool00ol00000oooo0?ooo`040?ooo`03o`00003o
ool0oooo0180oooo0ol0001P0?ooo`002@3oool01?l00000oooo0?ooo`3ooon:000000Co6ATI00?o
000003<c<`0c<c<0100c<c<00`000000<c<c03<c<`0503<c<`0300000?lI6AWo6ATI00;o6ATI2`00
00040?ooo`03o`00003oool0oooo0540oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`0>0?ooo`Co0000H`3oool000T0oooo00Co00000?ooo`3oool0ooooRP0000000ol0003o6ATIoaTI
6@02oaTI6@8000003@0c<c<00`00003o6ATIoaTI6@02oaTI6@X00000103oool00ol00000oooo0?oo
o`1B0?ooo`;o00000`3oool00ol00000oooo0?ooo`0:0?ooo`Co0000I`3oool000T0oooo00Co0000
0?ooo`3oool0ooooS@000004oaTI6@030000000c<c<0<c<c00X0<c<c00<00000oaTI6OlI6AT00_lI
6AT:000000@0oooo00?o00000?ooo`3oool0E03oool01?l00000oooo0?ooool000080?ooo`Co0000
J`3oool000T0oooo00Co00000?ooo`3oool0ooooSP000004oaTI6@8000002`0c<c<00`00003o6ATI
oaTI6@02oaTI6@T00000103oool00ol00000oooo0?ooo`1E0?ooo`03o`00003ooooo000000D0oooo
0ol0001_0?ooo`002@3oool01?l00000oooo0?ooo`3ooon>00000003o`000?lI6AWo6ATI00?o6ATI
00?o000003<c<`0c<c<0200c<c<00`00003o6ATIoaTI6@03oaTI6@P00000103oool00ol00000oooo
0?ooo`1F0?ooo`;o000000<0ooooo`000?l000000_l0001b0?ooo`002@3oool01?l00000oooo0?oo
o`3ooon?000000Ko6ATI0P00000803<c<`0300000?lI6AWo6ATI00?o6ATI200000040?ooo`03o`00
003oool0oooo05L0oooo0_l0001f0?ooo`002@3oool01?l00000oooo0?ooo`3ooon@000000Oo6ATI
00<0000003<c<`0c<c<01@0c<c<00`00003o6ATIoaTI6@04oaTI6@L00000103oool00ol00000oooo
0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooonA000000Oo6ATI0P00000403<c<`030000
0?lI6AWo6ATI00Go6ATI1`0000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003o
ool0oooo0?oooi40000000?o000000000?lI6AT01_lI6AT5000000So6ATI00?o0000000000000000
0`0000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?oooi@00000
4olI6AT6000000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo
U@00000CoaTI6@D00000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?oo
o`3ooonE00000003o`000000003o6ATI013o6ATI1@0000040?ooo`03o`00003oool0oooo0<l0oooo
00090?ooo`04o`00003oool0oooo0?oooiL000004OlI6AT5000000@0oooo00?o00000?ooo`3oool0
c`3oool000T0oooo00Co00000?ooo`3oool0ooooV000000@oaTI6@D00000103oool00ol00000oooo
0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooonJ000000oo6ATI100000040?ooo`03o`00
003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?oooi`000003OlI6AT4000000@0oooo
00?o00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0ooooWP00000;oaTI6@@00000
103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooonO000000_o6ATI
0`0000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?oooj000000
2_lI6AT3000000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00?o00000?ooo`3oool0/P3o
ool00ol00000oooo0?ooo`3?0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0
oooo0<l0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0c`3oool000T0
oooo]_l0003A0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002@3ooonfo`000140oooo]_l0000:
0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0303oool00`2P8?00oooo0?ooo`0T0?ooo`030:0Pl03oool0oooo07`0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo04/0oooo00<0X23`0?ooo`3oool07`3oool00`2P8?00oooo0?ooo`120?ooo`03
o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0
3`3oool00`2P8?00oooo0?ooo`050?ooo`030:0Pl03oool0oooo00H0oooo00<0X23`0?ooo`3oool0
0`3oool00`2P8?00oooo0?ooo`0[0?ooo`030:0Pl03oool0X23`02T0oooo00<0X23`0?ooo`3oool0
@@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo0P2P8?000`3oool0X23`0?ooo`1<
0?ooo`050:0Pl03oool0oooo0?ooo`2P8?00103oool00`2P8?00oooo0?ooo`1H0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool5
0:0Pl0<0oooo00<0X23`0?ooo`3oool02`3oool00`2P8?00oooo0?ooo`020:0Pl2P0oooo00<0X23`
0?ooo`3oool03`3oool00`2P8?00oooo0?ooo`0K0?ooo`030:0Pl03oool0oooo03l0oooo00?o0000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?oo
o`H0X23`503oool00`2P8?00oooo0?ooo`1e0?ooo`030:0Pl03oool0oooo0200oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`80
X23`00<0oooo0:0Pl02P8?000P2P8?000`3oool0X23`0?ooo`190?ooo`030:0Pl03oool0oooo01D0
oooo00<0X23`0?ooo`3oool0A`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo0P2P8?000`3oool0X23`0:0Pl0020:0Pl4P0oooo
00<0X23`0?ooo`3oool0903oool00`2P8?00oooo0?ooo`0l0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000X23`0?oo
o`060:0Pl0070?ooo`2P8?00oooo0?ooo`2P8?00oooo0:0Pl00M0?ooo`030:0Pl03oool0oooo06D0
oooo00<0X23`0?ooo`2P8?007@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000:0Pl02P8?00102P8?000`3oool0X23`
0?ooo`060?ooo`80X23`B`3oool00`2P8?00oooo0?ooo`1E0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`2P8?020?ooo`<0X23`00<0oooo0:0Pl03oool0203oool00`2P8?00oooo0?ooo`120?ooo`030:0P
l03oool0oooo05T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooo`H0X23`0P3oool0102P8?00oooo
0?ooo`2P8?2U0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00P0oooo
00<0003o0?ooo`3oool0Y`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0080oooo
00<0X23`0?ooo`2P8?000`2P8?0@0?ooo`030:0Pl03oool0oooo00`0oooo00<0X23`0?ooo`3oool0
D03oool00`2P8?00oooo0?ooo`0e0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo00P0oooo0P000?nX0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
1`2P8?030?ooo`80X23`0P3oool00`2P8?00oooo0?ooo`060?ooo`030:0Pl03oool0oooo01l0oooo
00<0X23`0?ooo`3oool0903oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0oooo0140oooo
00<0X23`0?ooo`3oool0<`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`070?ooo`030000o`3oool0oooo0080003oYP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo0080oooo00P0X23`0?ooo`3oool0X23`0?ooo`2P8?00oooo0:0Pl:P0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0:<0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`030?ooo`04
0:0Pl03oool0X23`0:0Pl080oooo0P2P8?060?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?oo
o`3oool0903oool00`2P8?00oooo0?ooo`0Q0?ooo`030:0Pl03oool0oooo04h0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0:80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`020?ooo`80
X23`00<0oooo0:0Pl03oool01P2P8?090?ooo`030:0Pl03oool0oooo09T0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0:40oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`070?ooo`80X23`
00@0oooo0:0Pl03oool0X23`1@3oool00`2P8?00oooo0?ooo`2M0?ooo`03o`00003oool0oooo00P0
oooo00090?ooo`03o`00003oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`2P0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool00P3oool00`2P8?00oooo
0?ooo`020?ooo`80X23`00<0oooo0:0Pl03oool0IP3oool00`2P8?00oooo0?ooo`0m0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00X0oooo0P000?l40?ooo`80003oX03o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00P0oooo00<0X23`0?ooo`2P8?00203o
ool00`2P8?00oooo0?ooo`2L0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo00`0oooo00<0003o0?ooo`3oool00`3oool20000oih0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo00@0oooo00<0X23`0?ooo`3oool02P3oool0
0`2P8?00oooo0?ooo`2A0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
00d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`2K0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool01P3oool0102P8?00oooo0?ooo`3oool20:0Pl0D0oooo0P2P8?02
0?ooo`040:0Pl03oool0oooo0:0Pl0h0oooo00<0X23`0?ooo`3oool0403oool00`2P8?00oooo0?oo
o`0f0?ooo`030:0Pl03oool0oooo03`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo09X0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`070?ooo`030:0Pl03oool0oooo00<0X23`0`3oool0
0`2P8?00oooo0?ooo`0@0?ooo`050:0Pl03oool0oooo0?ooo`2P8?00RP3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00@0oooo00?o003o
0?ooo`3oool0V@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00T0oooo00H0X23`
0?ooo`3oool0oooo0:0Pl03oool30:0Pl080oooo0P2P8?2L0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo0100oooo00<0003o0?ooo`3oool00`3oool20000oiX0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`020?ooo`030:0Pl03oool0oooo00T0oooo00H0
X23`0?ooo`2P8?00X23`0?ooo`2P8?2N0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo0140oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`2G0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool02@3oool00`2P8?00oooo0?ooo`070?ooo`80X23`
9@3oool00`2P8?00oooo0?ooo`1e0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo0180oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`2F0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool06`3oool00`2P8?00oooo0?ooo`2D0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`2E0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool02`3oool0
0`2P8?00oooo0?ooo`1F0?ooo`030:0Pl03oool0oooo04/0oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`80003oU@3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00@0oooo00<0X23`0?ooo`3oool03P3oool00`2P
8?00oooo0?ooo`050?ooo`030:0Pl03oool0oooo00P0oooo00<0X23`0?ooo`3oool04P3oool00`2P
8?00oooo0?ooo`1b0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01@0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2B0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool04@3oool0102P8?00oooo0:0Pl02P8?0O0?ooo`030:0Pl03oool0oooo
07/0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo0940oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`070?ooo`030:0Pl03oool0oooo00L0oooo0P2P8?020?ooo`80X23`103oool00`2P8?00
oooo0?ooo`040?ooo`040:0Pl03oool0oooo0:0Pl0H0oooo00<0X23`0?ooo`3oool0303oool00`2P
8?00oooo0:0Pl01d0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2@0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0103oool20:0Pl0<0oooo00<0X23`0?ooo`3oool01@3oool00`2P8?00
oooo0:0Pl0030?ooo`030:0Pl03oool0oooo00<0oooo00@0X23`0?ooo`3oool0X23`0`3oool20:0P
l8`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`060?ooo`03o`00o`3oool0oooo08l0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0<0?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool00P3oool01@2P8?00
oooo0:0Pl03oool0X23`00<0oooo00<0X23`0?ooo`3oool0T@3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0S`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00P0oooo00<0X23`0?ooo`2P
8?001P3oool00`2P8?00oooo0?ooo`020:0Pl0h0oooo00<0X23`0?ooo`3oool03P3oool00`2P8?00
oooo0?ooo`080?ooo`030:0Pl03oool0oooo04D0oooo00<0X23`0?ooo`3oool09`3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool0303oool60000og`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`050?ooo`030:0Pl03oool0oooo00/0oooo00<0X23`0?ooo`3oool04@3oool00`2P8?00oooo
0?ooo`030?ooo`030:0Pl03oool0oooo00/0oooo00D0X23`0?ooo`3oool0oooo0:0Pl00X0?ooo`03
0:0Pl03oool0oooo04L0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
6P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo10000?l60?ooo`D0003o
M`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00D0oooo00D0X23`0?ooo`3oool0
oooo0:0Pl0020?ooo`040:0Pl03oool0oooo0?ooo`80X23`00<0oooo0:0Pl03oool01@3oool01@2P
8?00oooo0?ooo`3oool0X23`0100oooo00<0X23`0?ooo`3oool0F03oool00`2P8?00oooo0?ooo`0U
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01/0oooo0P000?l60?oo
o`040000o`3oool0oooo0?ooo`D0003o3`3oool30000og@0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`0;0?ooo`030:0Pl03oool0oooo01<0oooo00<0X23`0?ooo`3oool0IP3oool0
0`2P8?00oooo0?ooo`0U0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
01d0oooo00<0003o0?ooo`3oool0103oool00ol00?l0003o0000o`0G0?ooo`030000o`3oool0oooo
0740oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0G0?ooo`050:0Pl03oool0oooo
0?ooo`2P8?000P3oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0oooo00d0oooo00<0X23`
0?ooo`3oool0NP3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0N0?oo
o`030000o`3oool0oooo0080oooo00@0003oo`00o`3oool0003o603oool00`000?l0oooo0?ooo`1`
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool00`3oool00`2P8?00oooo0?ooo`05
0?ooo`030:0Pl03oool0oooo00/0oooo0P2P8?0:0?ooo`<0X23`1@3oool00`2P8?00oooo0?ooo`0E
0?ooo`030:0Pl03oool0oooo01@0oooo00<0X23`0?ooo`3oool0D`3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`0O0?ooo`050000o`3oool0oooo0000o`3oool00`000000
0`000?l0oooo0?ooo`0F0?ooo`80003oL03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo0180oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0
oooo0900oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0803oool20000
o`030?ooo`000000000000<0000000<0003o0?ooo`3oool05`3oool30000ofd0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo00`0oooo00<0X23`0?oo
o`3oool00P3oool0102P8?00oooo0?ooo`2P8?060?ooo`030:0Pl03oool0oooo00/0oooo00<0X23`
0?ooo`3oool0M@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo00D0000000<0ooooo`00o`3oool06P3oool00ol00?l0oooo0?ooo`1Z0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool01`3oool01P2P8?00oooo0?ooo`2P8?00
oooo0:0Pl1H0oooo00D0X23`0?ooo`3oool0oooo0:0Pl00E0?ooo`050:0Pl03oool0oooo0?ooo`2P
8?00L03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0O0?ooo`04o`00
o`3oool0003o0?ooo`D000000P3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo06T0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0D0?ooo`040:0Pl03oool0oooo0:0P
l0<0oooo00<0X23`0?ooo`3oool01`3oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0X23`
00/0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`1`0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo01l0oooo00D0003o0?ooo`3oool0003o0?ooo`030000
00@0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`1X0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool04P3oool00`2P8?00oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo
01X0oooo00<0X23`0?ooo`3oool0L`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0I0?ooo`030000o`3oool0oooo06L0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0R0?ooo`050:0Pl03oool0oooo0?ooo`2P8?003@3oool00`2P8?00oooo0?ooo`060?oo
o`040:0Pl03oool0X23`0:0Pl740oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool07@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool06@3oool00`000?l0oooo0?ooo`1V0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool01@3oool00`2P8?00oooo0:0Pl0070?ooo`030:0Pl03oool0oooo00@0oooo00<0X23`0?oo
o`3oool01P3oool0102P8?00oooo0?ooo`2P8?030?ooo`030:0Pl03oool0X23`0080X23`0`3oool0
0`2P8?00oooo0:0Pl00<0?ooo`@0X23`00D0oooo0:0Pl02P8?00oooo0:0Pl01/0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01d0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`03o`00o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0I@3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02<0oooo00<0X23`0?ooo`3oool01P3oool2
0:0Pl080oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`090?ooo`030:0Pl03oool0
X23`06h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`070?ooo`80003o1`3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo
06@0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0B0?ooo`030:0Pl03oool0oooo
01L0oooo0P2P8?0;0?ooo`030:0Pl03oool0oooo00X0oooo00@0X23`0?ooo`3oool0X23`J03oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0K0?ooo`03o`00o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo
06<0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0N0?ooo`030:0Pl03oool0oooo
00L0oooo00T0X23`0?ooo`3oool0oooo0:0Pl03oool0X23`0?ooo`2P8?003@3oool0102P8?00oooo
0?ooo`2P8?020?ooo`040:0Pl03oool0oooo0:0Pl6X0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`1R0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0:@3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo0080
oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?ooo`020:0Pl0<0oooo00<0X23`0?ooo`3o
ool0K@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0J0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool01@3oool00ol00?l0oooo0?ooo`0I0?ooo`03o`00
o`3oool0oooo0640oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0=0?ooo`030:0P
l03oool0oooo01@0oooo00<0X23`0?ooo`3oool00P3oool0102P8?00oooo0:0Pl02P8?020?ooo`05
0:0Pl03oool0oooo0?ooo`2P8?000`3oool20:0Pl0H0oooo00X0X23`0?ooo`2P8?00X23`0?ooo`2P
8?00oooo0:0Pl03oool0X23`J@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`0I0?ooo`030000o`3oool0oooo00l0oooo0P000?l60?ooo`030000o`3oool0oooo01T0oooo
00<0003o0?ooo`3oool0H03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00T0oooo
00<0X23`0?ooo`3oool05`3oool00`2P8?00oooo0?ooo`030?ooo`030:0Pl03oool0oooo0080oooo
00<0X23`0?ooo`3oool0403oool01@2P8?00oooo0?ooo`2P8?00oooo0080X23`7P3oool00`2P8?00
oooo0?ooo`190?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01T0oooo
00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01P0oooo
00<0003o0?ooo`3oool0H03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00l0oooo
00D0X23`0?ooo`3oool0oooo0:0Pl00I0?ooo`80X23`00D0oooo0:0Pl03oool0oooo0:0Pl0060?oo
o`030:0Pl03oool0oooo00D0oooo00L0X23`0?ooo`2P8?00oooo0:0Pl03oool0X23`00L0oooo00<0
X23`0?ooo`3oool0G`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0I
0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0H
0?ooo`030000o`3oool0oooo05l0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0N
0?ooo`030:0Pl03oool0oooo00l0oooo00@0X23`0?ooo`3oool0X23`0P3oool00`2P8?00oooo0?oo
o`030?ooo`030:0Pl03oool0oooo07<0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0603oool00`000?l0oooo0?ooo`1N0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0103oool00`2P8?00oooo0?ooo`0W0?ooo`040:0Pl03oool0oooo0?ooo`80X23`00@0
oooo0:0Pl03oool0oooo0`2P8?00103oool0X23`0?ooo`2P8?050?ooo`040:0Pl03oool0oooo0:0P
l6X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0603oool00`000?l0
oooo0?ooo`0D0?ooo`030000o`3oool0oooo00D0oooo00?o003o0?ooo`3oool0603oool00`000?l0
oooo0?ooo`1M0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0203oool01@2P8?00
oooo0?ooo`3oool0X23`00d0oooo00<0X23`0?ooo`3oool01@3oool30:0Pl0T0oooo0P2P8?000`3o
ool0X23`0?ooo`020:0Pl0P0oooo00<0X23`0?ooo`2P8?00103oool30:0Pl6/0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0603oool00`000?l0oooo0?ooo`0E0?ooo`80
003o1P3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo05`0oooo00?o00000?ooo`3o
ool03`3oool00ol00000oooo0?ooo`0^0?ooo`<0X23`0P3oool00`2P8?00oooo0?ooo`050?ooo`80
X23`1P3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo06L0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0603oool00`000?l0oooo0?ooo`0G0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`1L0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0303oool00`2P8?00oooo0?ooo`0L0?ooo`040:0P
l03oool0X23`0?ooo`80X23`0P3oool20:0Pl0D0oooo00<0X23`0?ooo`3oool00`3oool20:0Pl003
0?ooo`2P8?00oooo00@0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`060?ooo`03
0:0Pl03oool0oooo05P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
603oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`1K0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
403oool00`2P8?00oooo0?ooo`0O0?ooo`<0X23`2`3oool00`2P8?00oooo0?ooo`050?ooo`80X23`
0`3oool00`2P8?00oooo0?ooo`1R0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo01P0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo01L0oooo00<0003o0?ooo`3oool0FP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo01D0oooo00<0X23`0?ooo`3oool04@3oool00`2P8?00oooo0?ooo`040?ooo`050:0Pl03o
ool0oooo0:0Pl03oool00P2P8?030?ooo`80X23`1@3oool00`2P8?00oooo0?ooo`020:0Pl080oooo
00D0X23`0?ooo`3oool0oooo0:0Pl01U0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo01P0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`040?ooo`03o`00
o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0FP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo02/0oooo0P2P8?050?ooo`040:0Pl03oool0oooo0:0Pl080oooo0P2P8?030?ooo`03
0:0Pl03oool0oooo0780oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
603oool00`000?l0oooo0?ooo`0K0?ooo`030000ool00?l0oooo00<0oooo00<0003o0?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`1I0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
6@3oool0102P8?00oooo0?ooo`2P8?0?0?ooo`030:0Pl03oool0X23`00X0oooo00<0X23`0?ooo`3o
ool00`3oool30:0Pl0h0oooo00<0X23`0?ooo`3oool0G`3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo05T0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0C0?ooo`030:0Pl03oool0oooo00P0oooo00<0X23`0?ooo`3oool0
5`3oool00`2P8?00oooo0:0Pl0040?ooo`030:0Pl03oool0oooo00@0oooo00<0X23`0?ooo`3oool0
J@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo01h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo05T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0L0?ooo`030:0Pl03o
ool0oooo00l0oooo00<0X23`0?ooo`3oool0103oool20:0Pl0D0oooo00<0X23`0?ooo`3oool00P3o
ool0102P8?00oooo0:0Pl02P8?1]0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo01L0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo01D0oooo00<0003o0?ooo`3oool0F03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo01@0oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?ooo`0;0?ooo`030:0Pl03o
ool0X23`00T0oooo00D0X23`0?ooo`3oool0oooo0:0Pl0040?ooo`030:0Pl03oool0oooo00L0X23`
00<0oooo0:0Pl02P8?001@3oool00`2P8?00oooo0?ooo`1O0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo01L0oooo00<0003o0?ooo`3oool08@3oool00`000?oo003o0?oo
o`020?ooo`030000o`3oool0oooo01@0oooo00?o003o0000o`3oool0F03oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo00h0oooo00<0X23`0?ooo`3oool0503oool00`2P8?00oooo0?oo
o`0=0?ooo`030:0Pl03oool0oooo00X0oooo00<0X23`0?ooo`3oool02`3oool00`2P8?00oooo0?oo
o`1O0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01L0oooo00<0003o
0?ooo`3oool08`3oool010000?l0oooo0?ooo`000?lG0?ooo`030000o`3oool0oooo05L0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0j0?ooo`040:0Pl03oool0X23`0:0Pl0<0oooo
00@0X23`0?ooo`2P8?00X23`1`3oool00`2P8?00oooo0:0Pl01S0?ooo`03o`00003oool0oooo00P0
oooo00090?ooo`03o`00003oool0oooo01L0oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo
0000o`0G0?ooo`030000o`3oool0oooo05L0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0G0?ooo`030:0Pl03oool0oooo00L0oooo00<0X23`0?ooo`3oool03`3oool01P2P8?00oooo
0:0Pl03oool0X23`0?ooo`80X23`1P3oool20:0Pl0030?ooo`2P8?00X23`00@0X23`00<0oooo0:0P
l03oool00P3oool01@2P8?00oooo0?ooo`3oool0X23`00l0oooo0P2P8?1=0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo01P0oooo00<0003o0?ooo`3oool0903oool20000
oaP0oooo00<0003o0?ooo`3oool0EP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
02@0oooo00@0X23`0?ooo`3oool0X23`1`3oool00`2P8?00oooo0?ooo`0:0?ooo`030:0Pl03oool0
oooo00D0oooo00<0X23`0?ooo`3oool01`3oool00`2P8?00oooo0:0Pl01Q0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo01P0oooo00<0003o0?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo05H0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0D0?ooo`050:0Pl03oool0X23`0?ooo`2P8?00103oool00`2P8?00oooo0?ooo`08
0?ooo`030:0Pl03oool0oooo00h0oooo0`2P8?00103oool0X23`0?ooo`3oool50:0Pl0030?ooo`2P
8?00X23`00H0X23`0P3oool00`2P8?00oooo0?ooo`0@0?ooo`030:0Pl03oool0oooo04`0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0603oool00`000?l0oooo0?ooo`0n
0?ooo`030000o`3oool0oooo05H0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0O
0?ooo`030:0Pl03oool0oooo00D0oooo00<0X23`0?ooo`3oool06@3oool00`2P8?00oooo0?ooo`03
0:0Pl0<0oooo00<0X23`0?ooo`2P8?001P3oool00`2P8?00oooo0?ooo`090?ooo`030:0Pl03oool0
oooo04h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo05H0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0K0?ooo`050:0Pl03oool0oooo0?ooo`2P8?00703oool20:0Pl0<0oooo00<0X23`
0?ooo`3oool00P3oool40:0Pl0030?ooo`2P8?00oooo00<0oooo00<0X23`0?ooo`3oool0G`3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
03l0oooo00<0003o0?ooo`3oool0E@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
00h0oooo00<0X23`0?ooo`3oool04P3oool00`2P8?00oooo0?ooo`0<0?ooo`@0X23`2@3oool0102P
8?00oooo0:0Pl02P8?030?ooo`<0X23`00@0oooo0:0Pl03oool0oooo0`2P8?0B0?ooo`030:0Pl03o
ool0oooo00<0oooo00<0X23`0?ooo`3oool0A`3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0oooo0`00000N0?ooo`030000o`3oool0
oooo05D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0>0?ooo`030:0Pl03oool0
oooo0080oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`0[0?ooo`030:0Pl03oool0
oooo0080X23`2@3oool00`2P8?00oooo0?ooo`0:0?ooo`80X23`CP3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01`0oooo1@00000M0?oo
o`030000o`3oool0oooo05D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0>0?oo
o`030:0Pl03oool0oooo01P0oooo00<0X23`0?ooo`3oool05@3oool01P2P8?00oooo0?ooo`2P8?00
oooo0:0Pl080oooo0P2P8?000`3oool0X23`0:0Pl0020:0Pl080oooo00@0X23`0?ooo`3oool0X23`
1P3oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0oooo00D0oooo00<0X23`0?ooo`3oool0
A03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo01`0oooo1@00000N0?ooo`030000o`3oool0oooo05@0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0H0?ooo`030:0Pl03oool0oooo01D0oooo00<0X23`0?ooo`3oool03P3o
ool00`2P8?00oooo0:0Pl0020?ooo`030:0Pl03oool0oooo00<0X23`0P3oool20:0Pl0h0oooo00<0
X23`0?ooo`3oool00P3oool00`2P8?00oooo0?ooo`1<0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo01T0oooo00<0003o0?ooo`3oool0703oool5000001h0oooo00<0003o
0?ooo`3oool0E03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03d0oooo00<0X23`
0?ooo`3oool0103oool0102P8?00oooo0?ooo`2P8?050?ooo`80X23`103oool00`2P8?00oooo0?oo
o`090?ooo`040:0Pl03oool0oooo0:0Pl4l0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0M0?ooo`<000006P3oool3o`00o`80oooo00<0
003o0?ooo`3oool0E03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0180oooo00<0
X23`0?ooo`3oool0203oool00`2P8?00oooo0:0Pl00:0?ooo`030:0Pl03oool0oooo00<0oooo00D0
X23`0?ooo`3oool0oooo0:0Pl00A0?ooo`80X23`00<0oooo0:0Pl03oool0102P8?00103oool0X23`
0:0Pl02P8?080?ooo`030:0Pl03oool0oooo0080oooo00@0X23`0?ooo`3oool0X23`0`3oool00`2P
8?00oooo0?ooo`180?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01X0
oooo00<0003o0?ooo`3oool0>03oool01?l00?l0oooo0?ooo`3oool2o`00o`030?ooo`000?l0oooo
05@0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0l0?ooo`030:0Pl03oool0oooo
00<0oooo00<0X23`0?ooo`3oool00P2P8?040?ooo`030:0Pl03oool0X23`0080X23`103oool20:0P
l0<0oooo00<0X23`0?ooo`3oool02`3oool0102P8?00oooo0?ooo`3oool20:0Pl0030?ooo`2P8?00
oooo0480oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`0g0?ooo`03o`00o`3oool0oooo00@0oooo00?o003o0000o`3oool0E03oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01h0oooo00<0X23`0?ooo`3oool00P3oool01@2P
8?00oooo0?ooo`3oool0X23`01h0oooo00@0X23`0?ooo`3oool0oooo0P2P8?020?ooo`<0X23`1@3o
ool01`2P8?00oooo0?ooo`3oool0X23`0?ooo`2P8?001P3oool00`2P8?00oooo0:0Pl0030?ooo`03
0:0Pl03oool0oooo04H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
6P3oool00`000?l0oooo0?ooo`0g0?ooo`03o`00o`3oool0oooo00D0oooo00?o003o0?ooo`3oool0
D`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0100oooo00@0X23`0?ooo`3oool0
X23`2`3oool00`2P8?00oooo0?ooo`0D0?ooo`030:0Pl03oool0oooo0100oooo00<0X23`0?ooo`2P
8?000P3oool30:0Pl0030?ooo`2P8?00X23`00D0oooo00@0X23`0?ooo`3oool0X23`0P3oool20:0P
l540oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06`3oool00`000?l0
oooo0?ooo`0g0?ooo`03o`00o`3oool0oooo00@0oooo00<0003oo`00o`3oool0D`3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo01d0oooo00<0X23`0?ooo`3oool0103oool00`2P8?00
oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo00@0oooo00D0X23`0?ooo`3oool0oooo0:0Pl0090?oo
o`030:0Pl03oool0oooo00<0oooo0`2P8?020?ooo`<0X23`0P3oool00`2P8?00oooo0:0Pl0020?oo
o`030:0Pl03oool0X23`00H0oooo00<0X23`0?ooo`3oool0A`3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`0K0?ooo`030000o`3oool0oooo03L0oooo00?o003o0?ooo`3o
ool0103oool00`000?l0ooooo`00o`1C0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool07`3oool00`2P8?00oooo0?ooo`0<0?ooo`030:0Pl03oool0oooo01`0oooo00<0X23`0?ooo`3o
ool00`2P8?080?ooo`030:0Pl03oool0oooo00L0oooo00D0X23`0?ooo`3oool0oooo0:0Pl0180?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01/0oooo00<0003o0?ooo`3o
ool0=`3oool00ol00?l0oooo0?ooo`040?ooo`040000o`3oool0ooooo`00oe80oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0D0?ooo`030:0Pl03oool0oooo02H0oooo00<0X23`0?oo
o`3oool02`3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0X23`0080oooo00<0X23`0?oo
o`2P8?000`3oool00`2P8?00oooo0?ooo`050?ooo`030:0Pl03oool0oooo00H0oooo00<0X23`0?oo
o`3oool0@`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo03L0oooo00?o003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3oool2o`00
oe00oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0E0?ooo`80X23`2`3oool00`2P
8?00oooo0?ooo`0E0?ooo`040:0Pl03oool0oooo0:0Pl0/0oooo0P2P8?030?ooo`030:0Pl03oool0
X23`0080oooo00@0X23`0?ooo`2P8?00oooo0P2P8?00103oool0X23`0:0Pl02P8?090?ooo`80X23`
203oool00`2P8?00oooo0?ooo`0o0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo01`0oooo00<0003o0?ooo`3oool0=`3oool00ol00?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00?o003o0?ooo`3oool0CP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo00h0oooo00<0X23`0?ooo`3oool04`3oool0102P8?00oooo0?ooo`2P8?0L0?ooo`030:0P
l03oool0X23`00/0oooo00<0X23`0?ooo`2P8?000P3oool20:0Pl0X0oooo00<0X23`0?ooo`3oool0
0`3oool00`2P8?00oooo0?ooo`160?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo01d0oooo00<0003o0?ooo`3oool0=`3oool00ol00?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00?o003o0?ooo`3oool0C@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo01T0oooo00<0X23`0?ooo`3oool02@3oool00`2P8?00oooo0?ooo`0=0?ooo`050:0Pl03o
ool0oooo0?ooo`2P8?001P3oool00`2P8?00oooo0?ooo`070?ooo`050:0Pl03oool0oooo0?ooo`2P
8?000`3oool50:0Pl0040?ooo`2P8?00X23`0?ooo`80X23`0`3oool20:0Pl0040?ooo`2P8?00X23`
0?ooo`<0X23`103oool00`2P8?00oooo0?ooo`120?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo01d0oooo00<0003o0?ooo`3oool0=`3oool00ol00?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00?o003o0?ooo`3oool0C03oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo0180oooo00<0X23`0?ooo`3oool04@3oool00`2P8?00oooo0?ooo`0D0?oo
o`030:0Pl03oool0oooo00P0oooo00<0X23`0?ooo`3oool01`3oool20:0Pl0040?ooo`2P8?00X23`
0:0Pl080oooo00<0X23`0?ooo`3oool02@3oool00`2P8?00oooo0?ooo`190?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo01d0oooo00<0003o0?ooo`3oool0>03oool01Ol0
0?l0oooo0?ooo`3oool0003o00L0oooo00?o003o0?ooo`3oool0B`3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo0180oooo00<0X23`0?ooo`3oool0<@3oool0102P8?00oooo0?ooo`2P
8?040?ooo`030:0Pl03oool0oooo00@0oooo00/0X23`0?ooo`3oool0X23`0?ooo`2P8?00oooo0:0P
l03oool0X23`0?ooo`020:0Pl0030?ooo`2P8?00oooo00<0oooo00<0X23`0?ooo`3oool01`3oool0
0`2P8?00oooo0?ooo`0m0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
01h0oooo00<0003o0?ooo`3oool0>03oool01?l00?l0oooo0?ooo`000?l80?ooo`;o003oB`3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo00<0X23`0?ooo`3oool04`3oool3
0:0Pl080oooo00D0X23`0?ooo`3oool0oooo0:0Pl0020?ooo`040:0Pl03oool0oooo0?ooo`80X23`
00D0oooo0:0Pl03oool0X23`0?ooo`020:0Pl080oooo00@0X23`0?ooo`3oool0oooo0P2P8?00103o
ool0X23`0?ooo`2P8?050?ooo`030:0Pl03oool0oooo03`0oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0g0?ooo`04o`00o`3oool0oooo
0000o`X0oooo00?o003o0?ooo`3oool0B03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo03P0oooo00<0X23`0?ooo`3oool05@3oool00`2P8?00oooo0?ooo`040?ooo`050:0Pl03oool0
oooo0:0Pl03oool00P2P8?050?ooo`040:0Pl03oool0oooo0?ooo`80X23`0P3oool0102P8?00oooo
0?ooo`2P8?050?ooo`030:0Pl03oool0oooo03/0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0803oool00`000?l0oooo0?ooo`0g0?ooo`03o`00o`3oool0003o00/0oooo
00?o003o0?ooo`3oool0A`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01`0oooo
00<0X23`0?ooo`3oool0<P3oool20:0Pl080oooo00D0X23`0?ooo`3oool0oooo0:0Pl0030?ooo`@0
X23`0`3oool00`2P8?00oooo0:0Pl0050?ooo`80X23`0P3oool00`2P8?00oooo0?ooo`0o0?ooo`03
o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0200oooo00<0003o0?ooo`3oool0
>03oool00ol00?l0oooo0?ooo`0;0?ooo`03o`00o`3oool0oooo04H0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0F0?ooo`030:0Pl03oool0oooo00/0oooo00<0X23`0?ooo`3oool0
703oool00`2P8?00oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo00<0oooo00@0X23`0?ooo`3oool0
X23`1`3oool00`2P8?00oooo0:0Pl0040?ooo`030:0Pl03oool0X23`0080oooo00<0X23`0?ooo`3o
ool0@P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo03L0oooo00<0003oo`00o`3oool0303oool00ol00?l0oooo0?ooo`150?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool04@3oool01@2P8?00oooo0?ooo`3oool0X23`0080
oooo00<0X23`0?ooo`3oool05@3oool00`2P8?00oooo0?ooo`0F0?ooo`060:0Pl03oool0oooo0:0P
l03oool0X23`1@3oool20:0Pl080oooo00<0X23`0?ooo`3oool00`3oool20:0Pl0`0oooo00<0X23`
0?ooo`3oool0@`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo03L0oooo00<0003oo`00o`3oool0303oool00ol00?l0oooo0?ooo`150?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool06`3oool00`2P8?00oooo0?ooo`0@0?oo
o`030:0Pl03oool0X23`00d0oooo00<0X23`0?ooo`3oool03P3oool00`2P8?00oooo0?ooo`030?oo
o`80X23`0`3oool00`2P8?00oooo0?ooo`070:0Pl0@0oooo00T0X23`0?ooo`3oool0oooo0:0Pl03o
ool0X23`0?ooo`2P8?00@@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo03H0oooo00<0003oo`00o`3oool03@3oool00ol00?l0oooo0?oo
o`140?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0503oool00`2P8?00oooo0?oo
o`0B0?ooo`030:0Pl03oool0oooo00h0oooo00<0X23`0?ooo`3oool02P3oool01@2P8?00oooo0?oo
o`3oool0X23`00l0oooo00<0X23`0?ooo`2P8?000`2P8?040?ooo`80X23`00@0oooo0:0Pl03oool0
X23`0P3oool00`2P8?00oooo0?ooo`040?ooo`030:0Pl03oool0oooo03/0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0d0?ooo`040000
o`3oool0ooooo`00o`h0oooo00?o003o0?ooo`3oool0@`3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo0300oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?ooo`0M0?ooo`03
0:0Pl03oool0X23`0080oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0:0Pl0020?ooo`@0
X23`00@0oooo0:0Pl02P8?00X23`0P3oool00`2P8?00oooo0?ooo`0o0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo02<0oooo00<0003o0?ooo`3oool0=03oool01@000?l0
oooo0?ooo`3ooooo003o00h0oooo00?o003o0?ooo`3oool0@P3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo01P0oooo00<0X23`0?ooo`3oool08@3oool00`2P8?00oooo0?ooo`0D0?oo
o`030:0Pl03oool0oooo00<0oooo00D0X23`0?ooo`3oool0oooo0:0Pl0050?ooo`040:0Pl03oool0
X23`0:0Pl0<0oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0?ooo`0n0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02@0oooo00<0003o0?ooo`3oool0<`3oool0
0`000?l0oooo0?ooo`020?ooo`03o`00o`3oool0oooo00`0oooo0_l00?m20?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0<`3oool00`2P8?00oooo0?ooo`0E0?ooo`030:0Pl03oool0
oooo00T0oooo00<0X23`0?ooo`3oool0103oool40:0Pl0030?ooo`2P8?00X23`0080X23`00<0oooo
0:0Pl03oool00P2P8?000`3oool0X23`0:0Pl0030:0Pl0H0oooo00<0X23`0?ooo`3oool0=`3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0U0?ooo`030000o`3oool0oooo
0380oooo00<0003o0?ooo`3oool00P3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00o`3oool0oooo
0400oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0H0?ooo`030:0Pl03oool0oooo
03d0oooo00<0X23`0?ooo`3oool00`3oool20:0Pl0H0oooo00<0X23`0?ooo`3oool00P3oool00`2P
8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool0>P3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0300
oooo00<0003o0?ooo`3oool0103oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00o`3oool0oooo03l0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1R0?ooo`040:0Pl03oool0oooo0?oo
o`<0X23`0P3oool0102P8?00oooo0:0Pl02P8?030?ooo`80X23`?P3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`0W0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?oo
o`3oool01@3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00o`3oool0oooo03h0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`1B0?ooo`030:0Pl03oool0oooo00`0oooo00<0X23`0?oo
o`2P8?000`3oool01`2P8?00oooo0?ooo`3oool0X23`0?ooo`2P8?00A03oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`0X0?ooo`030000o`3oool0oooo02h0oooo00<0003o
0?ooo`3oool01@3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00o`3oool0oooo03h0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`1M0?ooo`070:0Pl03oool0oooo0?ooo`2P8?00oooo
0:0Pl0050?ooo`060:0Pl03oool0oooo0?ooo`2P8?00oooo0`2P8?100?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo02T0oooo0P000?l/0?ooo`030000ool00?l0oooo00P0
oooo00?o003o0?ooo`3oool03@3oool2o`00och0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0J0?ooo`040:0Pl03oool0oooo0:0Pl3@0oooo00@0X23`0?ooo`3oool0X23`1@3oool0
0`2P8?00oooo0?ooo`020?ooo`@0X23`0P3oool0202P8?00oooo0:0Pl02P8?00oooo0:0Pl03oool0
X23`0P3oool0102P8?00oooo0:0Pl03oool20:0Pl0<0oooo00D0X23`0?ooo`3oool0oooo0:0Pl00d
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02/0oooo00<0003o0?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`080?ooo`03o`00o`3oool0oooo00l0oooo00?o003o0?oo
o`3oool0>`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01d0oooo00<0X23`0?oo
o`3oool0=03oool00`2P8?00oooo0?ooo`0;0?ooo`80X23`0`3oool20:0Pl0@0oooo00H0X23`0?oo
o`2P8?00X23`0?ooo`2P8?040?ooo`030:0Pl03oool0oooo00L0oooo00<0X23`0?ooo`3oool0;P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0/0?ooo`030000o`3oool0
oooo02L0oooo00<0003o0?ooo`3oool02P3oool00ol00?l0oooo0?ooo`0?0?ooo`03o`00o`3oool0
oooo03X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0J0?ooo`030:0Pl03oool0
oooo04D0oooo0P2P8?001@3oool0X23`0?ooo`3oool0X23`00<0oooo0P2P8?090?ooo`030:0Pl03o
ool0oooo03P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0;@3oool0
0`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo00`0oooo00?o003o0?ooo`3oool03`3oool0
0ol00?l0oooo0?ooo`0i0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0603oool0
0`2P8?00oooo0?ooo`0n0?ooo`030:0Pl03oool0oooo0080oooo00@0X23`0?ooo`3oool0X23`0P3o
ool20:0Pl0030?ooo`2P8?00X23`0080oooo00@0X23`0?ooo`2P8?00oooo0P2P8?020?ooo`80X23`
0`3oool0102P8?00oooo0?ooo`2P8?0f0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo02h0oooo0P000?lT0?ooo`030000o`3oool0oooo00h0oooo0_l00?l70?ooo`<00000
1P3oool00ol00?l0oooo0?ooo`0h0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
J`3oool00`2P8?00oooo0:0Pl0020?ooo`80X23`1`3oool00`2P8?00oooo0?ooo`0f0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0300oooo00<0003o0?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`0?0?ooo`03o`00o`3oool0oooo00@0oooo1@0000050?ooo`03o`00o`3o
ool0oooo03P0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0M0?ooo`030:0Pl03o
ool0oooo03`0oooo00<0X23`0?ooo`3oool0103oool01P2P8?00oooo0:0Pl02P8?00oooo0:0Pl0@0
oooo00@0X23`0?ooo`2P8?00X23`0P3oool01@2P8?00oooo0:0Pl03oool0X23`00@0oooo0P2P8?00
0`3oool0X23`0?ooo`0a0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
0340oooo00<0003o0?ooo`3oool07P3oool20000oa<0oooo00?o003o0?ooo`3oool00`3oool50000
00H0oooo00?o003o0?ooo`3oool0=`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
01/0oooo00<0X23`0?ooo`3oool02P3oool00`2P8?00oooo0?ooo`0G0?ooo`030:0Pl03oool0oooo
00`0oooo00<0X23`0?ooo`3oool04P3oool20:0Pl0D0oooo00@0X23`0?ooo`3oool0oooo0P2P8?06
0?ooo`030:0Pl03oool0oooo0080X23`=03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`0b0?ooo`80003o703oool20000oaH0oooo00?o003o0?ooo`3oool00P3oool50000
00L0oooo00?o003o0?ooo`3oool0=P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
01H0oooo00<0X23`0?ooo`3oool0E03oool0102P8?00oooo0?ooo`3oool20:0Pl0H0oooo00<0X23`
0?ooo`3oool00P2P8?0d0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
03@0oooo0P000?lI0?ooo`030000o`3oool0oooo01L0oooo00?o003o0?ooo`3oool00P3oool30000
00T0oooo00?o003o0?ooo`3oool0=@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
01l0oooo0P2P8?0<0?ooo`030:0Pl03oool0oooo01l0oooo00<0X23`0?ooo`3oool00`3oool00`2P
8?00oooo0?ooo`0=0?ooo`030:0Pl03oool0oooo00@0X23`2@3oool00`2P8?00oooo0:0Pl0040?oo
o`050:0Pl03oool0X23`0?ooo`2P8?00<@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`0f0?ooo`030000ool00?l0003o01@0oooo0P000?lK0?ooo`03o`00o`3oool0oooo
00h0oooo00?o003o0?ooo`3oool0=03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
04L0oooo00D0X23`0?ooo`3oool0oooo0:0Pl00H0?ooo`030:0Pl03oool0X23`0080oooo0P2P8?0:
0?ooo`80X23`1`3oool20:0Pl380oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0>@3oool30000o`h0oooo0`000?lN0?ooo`03o`00o`3oool0oooo00d0oooo00?o003o0?oo
o`3oool0=03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03T0oooo00<0X23`0?oo
o`3oool09P3oool01`2P8?00oooo0?ooo`3oool0X23`0?ooo`2P8?000P3oool20:0Pl0030?ooo`2P
8?00X23`00<0oooo0`2P8?070?ooo`L0X23`;P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`0l0?ooo`h0003o8P3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00o`3oool0
oooo03<0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0W0?ooo`030:0Pl03oool0
oooo03<0oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`090?ooo`040:0Pl03oool0
oooo0:0Pl0P0oooo0P2P8?060?ooo`030:0Pl03oool0oooo02`0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0K@3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00o`3oool0
oooo0380oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1O0?ooo`030:0Pl03oool0
oooo00@0oooo00<0X23`0?ooo`3oool00P3oool30:0Pl0040?ooo`2P8?00oooo0?ooo`80X23`00<0
oooo0:0Pl03oool00P3oool0102P8?00oooo0?ooo`2P8?030?ooo`<0X23`0`3oool00`2P8?00oooo
0?ooo`0Y0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06h0oooo00?o
003o0?ooo`3oool03@3oool00ol00?l0oooo0?ooo`0a0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0K@3oool20:0Pl080oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0?oo
o`080?ooo`030:0Pl03oool0oooo02h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0K`3oool00ol00?l0oooo0?ooo`0<0?ooo`03o`00o`3oool0oooo0340oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`1K0?ooo`030:0Pl03oool0oooo00P0oooo00<0X23`
0?ooo`3oool01@3oool01@2P8?00oooo0:0Pl03oool0X23`0080oooo00D0X23`0?ooo`3oool0oooo
0:0Pl0060?ooo`030:0Pl03oool0X23`0080oooo00<0X23`0?ooo`3oool0:P3oool00ol00000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1_0?ooo`03o`00o`3oool0oooo00d0oooo00?o
003o0?ooo`3oool0<03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0240oooo00<0
X23`0?ooo`3oool0>`3oool00`2P8?00oooo0?ooo`050?ooo`030:0Pl03oool0oooo00<0oooo00T0
X23`0?ooo`3oool0X23`0?ooo`2P8?00oooo0:0Pl03oool00P2P8?000`3oool0X23`0?ooo`060?oo
o`@0X23`00<0oooo0:0Pl03oool0:P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`1`0?ooo`03o`00o`3oool0oooo00d0oooo00?o003o0?ooo`3oool0;`3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo06l0oooo102P8?020?ooo`040:0Pl03oool0oooo0?oo
o`80X23`203oool00`2P8?00oooo0?ooo`020:0Pl2X0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0L@3oool00ol00?l0oooo0?ooo`0<0?ooo`03o`00o`3oool0oooo02l0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1Y0?ooo`050:0Pl03oool0oooo0?oo
o`2P8?000`3oool20:0Pl080oooo0P2P8?030?ooo`80X23`00@0oooo0:0Pl02P8?00oooo0P2P8?03
0?ooo`040:0Pl03oool0X23`0:0Pl2T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0LP3oool00ol00?l0oooo0?ooo`0<0?ooo`03o`00o`3oool0oooo02h0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0f0?ooo`030:0Pl03oool0oooo03T0oooo00@0X23`
0?ooo`3oool0X23`0`3oool0102P8?00oooo0?ooo`2P8?050?ooo`030:0Pl03oool0oooo02d0oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0LP3oool00ol00?l0oooo0?oo
o`0<0?ooo`03o`00o`3oool0oooo02h0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`1_0?ooo`80X23`0`3oool20:0Pl0H0oooo00@0X23`0?ooo`3oool0X23`0`3oool00`2P8?00oooo
0?ooo`040:0Pl2P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0L`3o
ool00ol00?l0oooo0?ooo`0;0?ooo`03o`00o`3oool0oooo02h0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0[0?ooo`030:0Pl03oool0oooo03/0oooo00L0X23`0?ooo`3oool0oooo
0:0Pl03oool0X23`00D0oooo00<0X23`0?ooo`2P8?000P2P8?020?ooo`80X23`0`3oool00`2P8?00
oooo0:0Pl0020?ooo`030:0Pl03oool0oooo02T0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0M03oool00ol00?l0oooo0?ooo`0;0?ooo`03o`00o`3oool0oooo02d0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0T0?ooo`030:0Pl03oool0oooo04d0oooo
00H0X23`0?ooo`2P8?00X23`0?ooo`2P8?030?ooo`80X23`0P3oool00`2P8?00oooo0?ooo`020?oo
o`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool0903oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`1e0?ooo`03o`00o`3oool0oooo00/0oooo00?o003o0?ooo`3o
ool0;03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03@0oooo00<0X23`0?ooo`3o
ool0;`3oool00`2P8?00oooo0?ooo`0;0?ooo`030:0Pl03oool0oooo00H0X23`00<0oooo0:0Pl03o
ool00`2P8?060?ooo`050:0Pl03oool0X23`0?ooo`2P8?00903oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`1f0?ooo`;o003o303oool00ol00?l0oooo0?ooo`0[0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0M@3oool0102P8?00oooo0?ooo`3oool20:0P
l0030?ooo`2P8?00oooo0080X23`00D0oooo0:0Pl03oool0oooo0:0Pl0050?ooo`030:0Pl03oool0
oooo02D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0N03oool00ol0
0?l0oooo0?ooo`090?ooo`03o`00o`3oool0oooo02/0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0O0?ooo`030:0Pl03oool0oooo0540oooo00<0X23`0?ooo`3oool0103oool00`2P
8?00oooo0?ooo`020:0Pl0@0oooo00<0X23`0?ooo`3oool0103oool00`2P8?00oooo0:0Pl00U0?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07T0oooo00?o003o0?ooo`3o
ool02@3oool00ol00?l0oooo0?ooo`0Z0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool08`3oool00`2P8?00oooo0?ooo`1;0?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3o
ool0102P8?001P3oool0X23`0:0Pl03oool0X23`0?ooo`80X23`00<0oooo0:0Pl02P8?000P3oool0
0`2P8?00oooo0:0Pl00U0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
07X0oooo00?o003o0?ooo`3oool02@3oool00ol00?l0oooo0?ooo`0Y0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0LP3oool00`2P8?00oooo0?ooo`060?ooo`040:0Pl03oool0X23`
0:0Pl080oooo00<0X23`0?ooo`3oool01P3oool20:0Pl2H0oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool0N`3oool00ol00?l0oooo0?ooo`090?ooo`03o`00o`3oool0oooo
02P0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0f0?ooo`030:0Pl03oool0oooo
0380oooo0P2P8?070?ooo`030:0Pl03oool0oooo0080oooo00<0X23`0?ooo`3oool00`3oool30:0P
l0<0oooo102P8?060?ooo`030:0Pl03oool0oooo0200oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0O03oool00ol00?l0oooo0?ooo`080?ooo`03o`00o`3oool0oooo02P0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0S0?ooo`050:0Pl03oool0oooo0?oo
o`2P8?00B@3oool00`2P8?00oooo0?ooo`060?ooo`050:0Pl03oool0oooo0?ooo`2P8?000P3oool0
0`2P8?00oooo0?ooo`020?ooo`030:0Pl03oool0oooo02T0oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool0O@3oool2o`00o`T0oooo00?o003o0?ooo`3oool09`3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo06h0oooo00<0X23`0?ooo`3oool03@3oool0102P
8?00oooo0:0Pl03oool20:0Pl0050?ooo`2P8?00X23`0?ooo`2P8?00:@3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1o0?ooo`03o`00o`3oool0oooo00H0oooo00?o003o
0?ooo`3oool09`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0680oooo00<0X23`
0?ooo`3oool03P3oool00`2P8?00oooo0?ooo`0=0?ooo`80X23`;@3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`200?ooo`03o`00o`3oool0oooo00D0oooo00?o003o0?oo
o`3oool09`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02D0oooo00<0X23`0?oo
o`3oool0F@3oool01P2P8?00oooo0:0Pl02P8?00oooo0:0Pl080oooo00<0X23`0?ooo`3oool09P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`210?ooo`03o`00o`3oool0
oooo00D0oooo00?o003o0?ooo`3oool09P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo0840oooo00<0X23`0?ooo`3oool00P2P8?020?ooo`80X23`:03oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`210?ooo`;o003o1P3oool00ol00?l0oooo0?ooo`0V0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0;`3oool00`2P8?00oooo0?ooo`120?oo
o`030:0Pl03oool0oooo00/0oooo00<0X23`0?ooo`3oool0;@3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`230?ooo`;o003o0`3oool00ol00?l0oooo0?ooo`0W0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool09`3oool00`2P8?00oooo0?ooo`0;0?ooo`03
0:0Pl03oool0oooo00<0oooo00<0X23`0?ooo`3oool0A03oool30:0Pl0D0oooo00<0X23`0?ooo`3o
ool00P3oool00`2P8?00oooo0?ooo`0P0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo08D0oooo00?o003o0?ooool00?l0:P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo0780oooo00<0X23`0?ooo`3oool03@3oool30:0Pl0<0oooo00<0X23`0?ooo`3oool0
9`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`260?ooo`03o`00o`3o
ool0oooo02T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`280?ooo`030:0Pl03o
ool0oooo02L0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02L0oooo00<0X23`0?ooo`3oool00P3oool0
0`2P8?00oooo0?ooo`1G0?ooo`<0X23`0`3oool00`2P8?00oooo0?ooo`0S0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`1O0?ooo`030:0Pl03oool0oooo0200oooo00<0X23`0?ooo`3oool01@3oool20:0P
l2H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo02H0oooo00<0X23`0?ooo`3oool01`3oool00`2P8?00
oooo0?ooo`170?ooo`030:0Pl03oool0oooo00@0oooo00@0X23`0?ooo`2P8?00X23`103oool00`2P
8?00oooo0:0Pl00V0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`270?ooo`030:0Pl03oool0oooo00P0
oooo00<0X23`0?ooo`3oool07@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0R03oool00`2P8?00oooo
0:0Pl00W0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`210?ooo`040:0Pl03oool0X23`0:0Pl0@0oooo
0P2P8?020?ooo`030:0Pl03oool0oooo00<0oooo00@0X23`0?ooo`3oool0X23`6`3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0QP3oool30:0Pl0@0oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo
0?ooo`080?ooo`030:0Pl03oool0oooo0140oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02`0oooo00<0
X23`0?ooo`3oool0DP3oool00`2P8?00oooo0?ooo`020?ooo`060:0Pl03oool0oooo0?ooo`2P8?00
oooo0P2P8?020?ooo`<0X23`7`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0R03oool00`2P8?00oooo
0?ooo`030?ooo`030:0Pl03oool0oooo0080X23`7`3oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0>P3o
ool00`2P8?00oooo0?ooo`1;0?ooo`@0X23`00<0oooo0:0Pl03oool00P2P8?000`3oool0X23`0?oo
o`0N0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`2<0?ooo`040:0Pl03oool0oooo0:0Pl0<0oooo0P2P
8?0M0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0`0?ooo`030:0Pl03oool0oooo05D0oooo0P2P8?02
0?ooo`040:0Pl03oool0X23`0:0Pl0@0oooo00<0X23`0?ooo`3oool06`3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0RP3oool40:0Pl0040?ooo`2P8?00X23`0?ooo`<0X23`1`3oool00`2P8?00oooo0?oo
o`0C0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`1o0?ooo`030:0Pl03oool0oooo00`0oooo1P2P8?03
0?ooo`030:0Pl03oool0oooo01P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo06P0oooo00<0X23`0?oo
o`3oool07@3oool20:0Pl0<0oooo00@0X23`0?ooo`2P8?00oooo1@2P8?0L0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0n0?ooo`030:0Pl03oool0oooo0540oooo00D0X23`0?ooo`2P8?00oooo0:0Pl00K
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`2@0?ooo`050:0Pl03oool0X23`0?ooo`2P8?007@3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0H`3oool00`2P8?00oooo0?ooo`0W0?ooo`030:0Pl03oool0oooo
0080oooo0`2P8?000`3oool0X23`0:0Pl00J0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2D0?ooo`04
0:0Pl03oool0oooo0:0Pl0<0oooo00<0X23`0?ooo`3oool0503oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0@03oool20:0Pl500oooo00@0X23`0?ooo`3oool0oooo0`2P8?050?ooo`030:0Pl03oool0oooo
0140oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo0780oooo00<0X23`0?ooo`3oool08@3oool00`2P8?00
oooo0?ooo`020?ooo`040:0Pl03oool0oooo0:0Pl1<0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo09L0
oooo00D0X23`0?ooo`2P8?00oooo0:0Pl00F0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2>0?ooo`03
0:0Pl03oool0oooo00<0oooo00<0X23`0?ooo`3oool00P3oool00`2P8?00oooo0:0Pl0030?ooo`80
X23`4@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0K@3oool00`2P8?00oooo0?ooo`0K0?ooo`030:0P
l03oool0oooo00d0oooo00H0X23`0?ooo`3oool0X23`0?ooo`2P8?0A0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`1;0?ooo`030:0Pl03oool0oooo0340oooo00<0X23`0?ooo`3oool05@3oool00`2P8?00
oooo0?ooo`020?ooo`030:0Pl03oool0oooo01<0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo04D0oooo
00<0X23`0?ooo`3oool0F`3oool00`2P8?00oooo0?ooo`0<0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`1b0?ooo`030:0Pl03oool0oooo01X0oooo00<0X23`0?ooo`3oool04@3oool00`2P8?00oooo0:0P
l00<0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`180?ooo`030:0Pl03oool0oooo0080oooo00<0X23`
0?ooo`3oool02@3oool00`2P8?00oooo0?ooo`1F0?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1m0?oo
o`030:0Pl03oool0oooo02<0oooo00<0X23`0?ooo`2P8?00303oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0OP3oool00`2P8?00oooo0?ooo`030?ooo`030:0Pl03oool0oooo01/0oooo0P2P8?030?ooo`03
0:0Pl03oool0oooo00P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0600oooo00<0X23`0?ooo`3oool0
C`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0B03oool00`2P8?00oooo0?ooo`060?ooo`030:0Pl03o
ool0oooo04h0oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`070?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`1O0?ooo`030:0Pl03oool0oooo04P0oooo00<0X23`0?ooo`3oool01@3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0Z03oool01@2P8?00oooo0?ooo`3oool0X23`00D0oooo00?o0000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo04h0oooo00<0X23`0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`1K0?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3o
ool03`3oool00ol00000oooo0?ooo`2C0?ooo`030:0Pl03oool0oooo01`0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo05D0oooo00<0X23`0?ooo`3oool0@`3oool00`2P8?00oooo0?ooo`0>0?ooo`80X23`
103oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0WP3oool00`2P8?00oooo0?ooo`020?ooo`030:0Pl03o
ool0oooo00/0oooo00<0X23`o`00003oool02@3oool000T0oooo00?o00000?ooo`3oool0/P3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo09@0oooo00<0X23`0?ooo`3oool0603oool3
0:0Pl003o`00003oool0oooo00P0oooo00090?oookKo00004@3ooomWo`0000030:0Pl?l0003o0000
00;o000000<0X23`o`000?l000002Ol000000`2P8?3o0000o`00000Po`0000030:0Pl?l0003o0000
00;o000000<0X23`o`000?l000003_l000001@2P8?3o00000:0Pl02P8?3o000000X0oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-294.432, -294.52, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resulting classification of 2d space", "Subsection"],

Cell[BoxData[{
    \(\(pts\  = \ 150;\)\), "\n", 
    \(\(reg1\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model1];\)\), "\n", 
    \(\(reg2\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model2];\)\), "\[IndentingNewLine]", 
    \(\(class\  = 
        Partition[\(If[#[\([1]\)]\  < \ #[\([2]\)], \ 1, 
                0] &\)\  /@ \ \(({Flatten[reg1], \ Flatten[reg2]}\  // \ 
                Transpose)\), pts + 1];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\n\)\(classPlot1\  = 
      ListDensityPlot[class, \ 
        ColorFunction -> \((If[# \[Equal] 0, pointStyle1[\([1]\)], \ 
                White] &)\), \ Mesh -> False, \ 
        MeshRange -> {{0, 1}, {0, 1}}, FrameTicks \[Rule] None, nS]; 
    classPlot2\  = 
      ListDensityPlot[class, \ 
        ColorFunction -> \((If[# == 1, pointStyle2[\([1]\)], White] &)\), \ 
        Mesh -> False, \ MeshRange -> {{0, 1}, {0, 1}}, 
        FrameTicks \[Rule] None, nS];\[IndentingNewLine]
    \(Show[GraphicsArray[{{g1, g2}, {classPlot1, classPlot2}}], imSize, 
        yS];\)\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.86275 .04706 Mdot
.71765 .09412 Mdot
.4902 .29804 Mdot
.43137 .22745 Mdot
.52549 .36471 Mdot
.72157 .10588 Mdot
.40784 .27843 Mdot
.42745 .31765 Mdot
.72157 .10588 Mdot
.25098 .17255 Mdot
.05098 .03137 Mdot
.48235 .31373 Mdot
.49412 .32157 Mdot
.07451 .0549 Mdot
.24706 .24314 Mdot
.42745 .19216 Mdot
.07059 .01569 Mdot
.08235 .05882 Mdot
.06275 .07059 Mdot
.43137 .2 Mdot
.01569 .00392 Mdot
.08235 .07059 Mdot
.02745 .02745 Mdot
.49804 .32941 Mdot
.01569 0 Mdot
.03529 .04706 Mdot
.02745 .02353 Mdot
.83137 .8 Mdot
.39216 .28235 Mdot
.01569 .02353 Mdot
.16863 .13725 Mdot
.01176 .01569 Mdot
.45882 .25882 Mdot
.01961 .02353 Mdot
.02745 .04314 Mdot
.03529 .03529 Mdot
.80392 .79216 Mdot
.40392 .27059 Mdot
.00784 .02353 Mdot
.0549 .03922 Mdot
.03529 .03137 Mdot
.65098 .61961 Mdot
.06667 .02745 Mdot
.02745 .03529 Mdot
.07059 .0549 Mdot
.04314 .04314 Mdot
.74118 .72157 Mdot
.0549 .02353 Mdot
.01569 .01961 Mdot
.06667 .05098 Mdot
.03922 .03529 Mdot
.82353 .80392 Mdot
.18039 .08627 Mdot
.01569 .02353 Mdot
.06275 .05098 Mdot
.51373 .46275 Mdot
.73725 .71373 Mdot
.84706 .04706 Mdot
.01569 .02353 Mdot
.03922 .03529 Mdot
.7451 .69412 Mdot
.02353 .01961 Mdot
.81176 .82353 Mdot
.01176 .02353 Mdot
.02745 .03529 Mdot
.11765 .09412 Mdot
.87451 .84706 Mdot
.84314 .82353 Mdot
.32941 .06275 Mdot
.01961 .01569 Mdot
.03922 .05098 Mdot
.90196 .89804 Mdot
.06275 .06275 Mdot
.83529 .84706 Mdot
0 0 Mdot
.02353 .02353 Mdot
.07059 .05098 Mdot
.89804 .90588 Mdot
.05882 .07843 Mdot
.81176 .82745 Mdot
.00784 .01176 Mdot
.01569 .02353 Mdot
.76078 .70196 Mdot
.90196 .90588 Mdot
.83137 .83529 Mdot
.62353 .59216 Mdot
0 .01176 Mdot
.02353 .03137 Mdot
.8902 .87843 Mdot
.88235 .88235 Mdot
.68235 .65098 Mdot
.6 .51765 Mdot
.01961 .01961 Mdot
.02745 .03529 Mdot
.8902 .87843 Mdot
.88235 .88627 Mdot
.67059 .62353 Mdot
.54902 .48627 Mdot
.05098 .05098 Mdot
.02353 .02745 Mdot
.89804 .89412 Mdot
.88235 .88235 Mdot
.11373 .10196 Mdot
.75686 .72549 Mdot
.0549 .03529 Mdot
.02353 .02745 Mdot
.8902 .87843 Mdot
.87451 .88627 Mdot
.01961 .03137 Mdot
.81569 .83137 Mdot
.08627 .03922 Mdot
.02353 .02745 Mdot
.86667 .86667 Mdot
.87843 .88235 Mdot
.04314 .04314 Mdot
.81569 .82745 Mdot
.00784 .00784 Mdot
.01176 .01176 Mdot
.75294 .67059 Mdot
.82745 .81961 Mdot
.85098 .84706 Mdot
.78431 .77255 Mdot
.00392 .01176 Mdot
.0549 .04706 Mdot
.07059 .06667 Mdot
.87451 .86275 Mdot
.86667 .86667 Mdot
.75294 .71373 Mdot
.14902 .08235 Mdot
.04314 .03137 Mdot
.02745 .03922 Mdot
.88627 .87843 Mdot
.05882 .06667 Mdot
.06275 .06667 Mdot
.83137 .84314 Mdot
.03529 .03529 Mdot
.05098 .04314 Mdot
.85098 .83137 Mdot
.07451 .07843 Mdot
.8549 .8549 Mdot
.80784 .79608 Mdot
.09412 0 Mdot
.04314 .03529 Mdot
.02745 .03137 Mdot
.78824 .78431 Mdot
.03922 .04314 Mdot
.02745 .03137 Mdot
.77255 .78431 Mdot
.02353 .02353 Mdot
.0549 .03922 Mdot
.84314 .83529 Mdot
.05098 .05882 Mdot
.84706 .84706 Mdot
.70196 .67059 Mdot
.1098 .00784 Mdot
.04314 .04314 Mdot
.02745 .02353 Mdot
.18824 .18824 Mdot
.03529 .03137 Mdot
.03922 .03922 Mdot
.81961 .83137 Mdot
.02353 .03137 Mdot
.05098 .03922 Mdot
.85098 .84706 Mdot
.07059 .05882 Mdot
.82745 .80392 Mdot
.72941 .69412 Mdot
.28627 .18824 Mdot
.03922 .03922 Mdot
.07843 .05882 Mdot
.0902 .0902 Mdot
.03922 .04314 Mdot
.19216 .1451 Mdot
.81569 .82745 Mdot
.00784 .01569 Mdot
.05098 .04314 Mdot
.83922 .83922 Mdot
.07843 .06667 Mdot
.00392 .00784 Mdot
.33725 .32549 Mdot
.47843 .47059 Mdot
.01569 .02353 Mdot
.06275 .04314 Mdot
.41961 .41961 Mdot
.03137 .02353 Mdot
.84314 .84314 Mdot
.62353 .60784 Mdot
.14118 .13333 Mdot
.04706 .04314 Mdot
.74118 .7098 Mdot
.07059 .05882 Mdot
.03922 .03137 Mdot
.15686 .13333 Mdot
.75294 .76471 Mdot
.00392 .01176 Mdot
.05882 .03922 Mdot
.85098 .8549 Mdot
.66275 .60784 Mdot
.00784 .00392 Mdot
.17647 .18431 Mdot
.29412 .27451 Mdot
.01176 .02745 Mdot
.07059 .05098 Mdot
.0549 .05882 Mdot
.84706 .8 Mdot
.61961 .58431 Mdot
.65882 .64314 Mdot
.62745 .63529 Mdot
.04314 .03529 Mdot
.88627 .88627 Mdot
.08235 .03922 Mdot
.04314 .04314 Mdot
.06667 .0549 Mdot
.77255 .78039 Mdot
.00784 .02353 Mdot
.04706 .03529 Mdot
.6549 .62353 Mdot
.88627 .87451 Mdot
.00784 .01569 Mdot
.22353 .21176 Mdot
.45098 .44314 Mdot
.00784 .02745 Mdot
.07059 .0549 Mdot
.05098 .0549 Mdot
.87843 .88235 Mdot
.77647 .75686 Mdot
.66275 .64314 Mdot
.48235 .50196 Mdot
.03922 .04314 Mdot
.88235 .89412 Mdot
.85098 .81569 Mdot
.23922 .19608 Mdot
.03529 .04706 Mdot
.80784 .81961 Mdot
.00392 .00392 Mdot
.04706 .03922 Mdot
.12157 .09412 Mdot
.87843 .86667 Mdot
.02353 .02745 Mdot
.01569 .02745 Mdot
.60784 .61569 Mdot
.00392 .02745 Mdot
.07451 .05882 Mdot
.11373 .09412 Mdot
.87451 .87059 Mdot
.83529 .83137 Mdot
.68627 .67451 Mdot
.75294 .72549 Mdot
.04706 .06275 Mdot
.88235 .8902 Mdot
.88235 .86275 Mdot
.52941 .48627 Mdot
.04706 .04706 Mdot
.83529 .84314 Mdot
.00784 .01961 Mdot
.04706 .04706 Mdot
.07843 .05882 Mdot
.88235 .87843 Mdot
.02353 .02353 Mdot
.04706 .05098 Mdot
.57647 .58039 Mdot
.00784 .01176 Mdot
.0902 .06275 Mdot
.25882 .20784 Mdot
.80784 .77647 Mdot
.81176 .80392 Mdot
.23137 .21961 Mdot
.6549 .27059 Mdot
.03137 .0549 Mdot
.85882 .86667 Mdot
.86667 .86275 Mdot
.23529 .21961 Mdot
0 .00392 Mdot
.82353 .83529 Mdot
.01176 .01569 Mdot
.05882 .07059 Mdot
.05882 .04706 Mdot
.19608 .18431 Mdot
.02353 .02353 Mdot
.02353 .02745 Mdot
.83137 .86667 Mdot
0 0 Mdot
.05098 .03529 Mdot
.17647 .1451 Mdot
.08235 .03922 Mdot
.55686 .47451 Mdot
.03529 .05098 Mdot
.21176 .22353 Mdot
.01176 .01176 Mdot
.87843 .8902 Mdot
.85098 .85098 Mdot
.71373 .68627 Mdot
.03922 .03529 Mdot
.61961 .61176 Mdot
.36863 .35686 Mdot
.03529 .04706 Mdot
.06275 .04314 Mdot
.10588 .08627 Mdot
.03922 .05098 Mdot
0 .01176 Mdot
.81961 .83529 Mdot
.01176 .00784 Mdot
.04314 .04706 Mdot
.08627 .06667 Mdot
.07059 .03922 Mdot
.03137 .02353 Mdot
.02353 .02745 Mdot
.7451 .76863 Mdot
.00392 .00392 Mdot
.5451 .49412 Mdot
.84314 .83922 Mdot
.82353 .82353 Mdot
.80392 .79216 Mdot
.01961 .01569 Mdot
.34118 .24706 Mdot
.00784 .02353 Mdot
.22353 .2 Mdot
.85882 .83922 Mdot
.04706 .0549 Mdot
.00392 .01961 Mdot
.63137 .61569 Mdot
.28627 .31373 Mdot
.03137 .04314 Mdot
.04314 .04314 Mdot
.17255 .11373 Mdot
.02745 .03529 Mdot
.00784 .01176 Mdot
.77255 .80392 Mdot
0 0 Mdot
.06275 .04706 Mdot
.84314 .82745 Mdot
.86275 .85098 Mdot
.50588 .44314 Mdot
.03137 .03529 Mdot
.56471 .6 Mdot
.00392 0 Mdot
.87843 .8902 Mdot
.14118 .11373 Mdot
.04314 .03137 Mdot
.03137 .03137 Mdot
.03529 .04314 Mdot
.73725 .14118 Mdot
0 .01961 Mdot
.61569 .55686 Mdot
.87059 .84706 Mdot
.07451 .07843 Mdot
.00392 .01176 Mdot
.60392 .60392 Mdot
.00392 .00392 Mdot
.03529 .03922 Mdot
.4 .31373 Mdot
.73333 .72157 Mdot
.03137 .02745 Mdot
.00392 .01176 Mdot
.83137 .8549 Mdot
.00392 .00392 Mdot
.68235 .65098 Mdot
.2902 .24706 Mdot
.81569 .77647 Mdot
.81569 .81176 Mdot
.01961 .02353 Mdot
.53333 .5451 Mdot
.00392 .00392 Mdot
.13333 .08235 Mdot
.76471 .71765 Mdot
.8549 .85098 Mdot
.00784 .02353 Mdot
.02745 .03922 Mdot
.36863 .37647 Mdot
.01176 .03137 Mdot
.84314 .83922 Mdot
.82353 .79216 Mdot
.07843 .06275 Mdot
.01569 .03137 Mdot
.6549 .65882 Mdot
.00392 .00392 Mdot
.05098 .04314 Mdot
.80392 .78431 Mdot
.86667 .86275 Mdot
.45098 .36863 Mdot
.00392 .01961 Mdot
.78431 .82745 Mdot
.00392 .00392 Mdot
.8 .80784 Mdot
.84314 .85098 Mdot
.85882 .85882 Mdot
.09412 .06275 Mdot
.01569 .02353 Mdot
.59216 .56078 Mdot
0 0 Mdot
.80784 .81569 Mdot
.78431 .72157 Mdot
.85098 .8549 Mdot
.00784 .01961 Mdot
.0549 .07451 Mdot
.11765 .11765 Mdot
.01176 .03137 Mdot
.04706 .04314 Mdot
.90196 .9098 Mdot
.05098 .0549 Mdot
.00392 .00784 Mdot
.69804 .70588 Mdot
0 0 Mdot
.04706 .03922 Mdot
.08627 .07451 Mdot
.86275 .85882 Mdot
.82745 .82745 Mdot
0 .01961 Mdot
.78431 .82353 Mdot
0 .00392 Mdot
.18824 .18039 Mdot
.08235 .05098 Mdot
.8 .78824 Mdot
.01961 .02745 Mdot
.02353 .03922 Mdot
.68627 .05882 Mdot
.01569 .02745 Mdot
.05882 .04706 Mdot
.8902 .8902 Mdot
.82745 .83137 Mdot
.00784 .01961 Mdot
.04314 .04706 Mdot
0 0 Mdot
.01176 .01961 Mdot
.05098 .0549 Mdot
.77647 .79216 Mdot
.20392 .1451 Mdot
.00392 .01569 Mdot
.78431 .81569 Mdot
.00392 .00392 Mdot
.05882 .03529 Mdot
.08235 .06667 Mdot
.09412 .08235 Mdot
.80392 .81176 Mdot
.00392 .01569 Mdot
.49412 .52549 Mdot
.00392 .01569 Mdot
.03137 .03137 Mdot
.8549 .8549 Mdot
.84314 .81961 Mdot
.00784 .01961 Mdot
.03529 .04706 Mdot
.4 .36471 Mdot
.03922 .03922 Mdot
.04706 .04706 Mdot
.38431 .4 Mdot
.06667 .05882 Mdot
.00392 .01176 Mdot
.55294 .51765 Mdot
0 .00392 Mdot
.00784 .01961 Mdot
.05098 .04314 Mdot
.08235 .07059 Mdot
.82353 .80392 Mdot
.00784 .02353 Mdot
.82745 .85882 Mdot
.00392 .01961 Mdot
.04314 .03529 Mdot
.85098 .8549 Mdot
.27451 .22353 Mdot
.37647 .35686 Mdot
.00784 .02353 Mdot
.4 .39608 Mdot
0 .01176 Mdot
.05098 .04314 Mdot
.23922 .23529 Mdot
.19608 .18824 Mdot
.00392 .01176 Mdot
.04706 .05098 Mdot
.08627 .08627 Mdot
.03137 .04706 Mdot
.03922 .04706 Mdot
.08235 .0549 Mdot
.0549 .0549 Mdot
.00392 .00784 Mdot
.41961 .40392 Mdot
0 .00392 Mdot
.01176 .01569 Mdot
.82745 .80392 Mdot
.07451 .04706 Mdot
.81176 .82353 Mdot
0 .01569 Mdot
.74902 .78039 Mdot
.00392 .01961 Mdot
.0549 .04706 Mdot
.36078 .35686 Mdot
.77255 .75686 Mdot
.22745 .19608 Mdot
.03922 .04706 Mdot
.67843 .07451 Mdot
.36471 .36863 Mdot
.04706 .05098 Mdot
.15294 .12941 Mdot
.42353 .38824 Mdot
.00392 .01176 Mdot
.05882 .06275 Mdot
.00784 .00392 Mdot
.01569 .01961 Mdot
.25882 .21176 Mdot
.04706 .02353 Mdot
.51373 .47059 Mdot
.00392 .01569 Mdot
.63137 .63529 Mdot
.01176 .02745 Mdot
.01961 .02353 Mdot
.77647 .77255 Mdot
.87843 .87843 Mdot
.81961 .82745 Mdot
.00784 .02353 Mdot
.64706 .67843 Mdot
0 .00784 Mdot
.03529 .03922 Mdot
.84706 .85098 Mdot
.84706 .85098 Mdot
.63922 .62353 Mdot
.05098 .05098 Mdot
.70588 .74902 Mdot
.01176 .04314 Mdot
.01569 .01961 Mdot
.08235 .06275 Mdot
.47843 .47059 Mdot
.00392 .01176 Mdot
.16078 .15686 Mdot
.01176 .01569 Mdot
.01569 .02745 Mdot
.83529 .81176 Mdot
.85882 .86275 Mdot
.83529 .83529 Mdot
.00392 .01569 Mdot
.66275 .68235 Mdot
.00392 .00784 Mdot
.01569 .02745 Mdot
.82353 .80392 Mdot
.85882 .8549 Mdot
.81961 .83137 Mdot
.00392 .00784 Mdot
.33333 .3451 Mdot
.00784 .01176 Mdot
.01961 .01961 Mdot
.16863 .11765 Mdot
.84706 .85098 Mdot
.0902 .08627 Mdot
.06667 .07451 Mdot
.7098 .74902 Mdot
.01569 .01961 Mdot
.03137 .04314 Mdot
.86275 .86667 Mdot
.07059 .07059 Mdot
0 .00392 Mdot
.04706 .0549 Mdot
.00392 .00392 Mdot
.01176 .01961 Mdot
.13333 .13333 Mdot
.84706 .8549 Mdot
.76471 .74902 Mdot
.00392 .00784 Mdot
.6902 .7098 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.16078 .17255 Mdot
.22745 .24314 Mdot
.83137 .83529 Mdot
.00392 .00392 Mdot
.51373 .53725 Mdot
.00392 .01176 Mdot
.01569 .02353 Mdot
.79216 .76078 Mdot
.84706 .86275 Mdot
.04314 .03529 Mdot
.02353 .04706 Mdot
.45098 .43137 Mdot
.01176 .02353 Mdot
.02353 .03922 Mdot
.85098 .85098 Mdot
.04314 .03137 Mdot
.00392 .00392 Mdot
.04706 .05882 Mdot
.00392 .00784 Mdot
.01961 .02745 Mdot
.03529 .03922 Mdot
.21176 .23137 Mdot
.04314 .05882 Mdot
.01176 .01569 Mdot
.07451 .0902 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.08235 .0902 Mdot
.65882 .61569 Mdot
.82353 .82353 Mdot
.00392 .00784 Mdot
.76863 .82353 Mdot
.00392 .00392 Mdot
.01569 .02745 Mdot
.83529 .84706 Mdot
.84706 .84706 Mdot
.5098 .5098 Mdot
.70196 .70196 Mdot
.60784 .0549 Mdot
.00784 .01569 Mdot
.03529 .05882 Mdot
.7451 .75686 Mdot
.84706 .84706 Mdot
.00392 .01176 Mdot
.03137 .0549 Mdot
.08235 .1098 Mdot
.01176 .03922 Mdot
.03529 .04314 Mdot
.09804 .06667 Mdot
.07059 .07843 Mdot
0 .00392 Mdot
.03529 .06275 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.06275 .04706 Mdot
.86667 .87451 Mdot
.05882 .05882 Mdot
.00392 .00392 Mdot
.76471 .80392 Mdot
0 0 Mdot
.00784 .02745 Mdot
.84314 .85098 Mdot
.85098 .86275 Mdot
.81569 .81569 Mdot
.00392 .00784 Mdot
.50588 .53333 Mdot
.00784 .02353 Mdot
.01569 .02745 Mdot
.12941 .12941 Mdot
.83529 .84314 Mdot
.01961 .02745 Mdot
0 .01176 Mdot
.36078 .4 Mdot
.00784 .03529 Mdot
.02745 .03137 Mdot
.8549 .83529 Mdot
.07843 .09804 Mdot
.00784 .01569 Mdot
.01569 .04314 Mdot
.00392 0 Mdot
.01176 .03529 Mdot
.51373 .46667 Mdot
.86667 .87059 Mdot
.04314 .06275 Mdot
.00392 .01176 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .01569 Mdot
.84314 .8549 Mdot
.37647 .39608 Mdot
.05882 .06667 Mdot
.00392 .00784 Mdot
.81569 .87059 Mdot
.00784 .01176 Mdot
.00784 .03137 Mdot
.67843 .64706 Mdot
.85098 .85882 Mdot
.81176 .81176 Mdot
0 .01176 Mdot
.41176 .05098 Mdot
.00784 .02353 Mdot
.03529 .04314 Mdot
.8549 .86275 Mdot
.06667 .07059 Mdot
.00392 .01176 Mdot
.01569 .05098 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.06667 .04314 Mdot
.68235 .69804 Mdot
.03137 .05098 Mdot
.00392 .01176 Mdot
.02745 .05098 Mdot
0 .00392 Mdot
.01176 .02745 Mdot
.83137 .83922 Mdot
.61176 .58824 Mdot
.02745 .05882 Mdot
.00392 .01961 Mdot
.79608 .82353 Mdot
.00784 .00784 Mdot
.00392 .02745 Mdot
.84706 .84314 Mdot
.49412 .51373 Mdot
.03529 .05098 Mdot
.00392 .01961 Mdot
.41961 .42353 Mdot
0 .01176 Mdot
.02353 .03529 Mdot
.83922 .85098 Mdot
.06275 .07451 Mdot
.55294 .55686 Mdot
.00392 .02353 Mdot
.00784 .00784 Mdot
.00392 .02353 Mdot
.03922 .03529 Mdot
.14118 .12941 Mdot
.04706 .06667 Mdot
.00392 .01569 Mdot
.00784 .03922 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.69804 .67843 Mdot
.85882 .8549 Mdot
.07059 .08235 Mdot
.00392 .00784 Mdot
.03922 .0549 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.84706 .86275 Mdot
.08627 .10196 Mdot
.03529 .0549 Mdot
0 .00392 Mdot
.52157 .56863 Mdot
.00392 .00784 Mdot
.02353 .02745 Mdot
.14118 .15686 Mdot
.02353 .02353 Mdot
.02745 .04314 Mdot
0 .02353 Mdot
.01176 0 Mdot
.00392 .01569 Mdot
.03922 .04706 Mdot
.08627 .0902 Mdot
.6 .57255 Mdot
.01569 .03529 Mdot
.01961 .03922 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.15294 .13725 Mdot
.25882 .28627 Mdot
.79608 .77647 Mdot
.00392 .01569 Mdot
0 .02353 Mdot
.00392 .01176 Mdot
.00392 .01961 Mdot
.56471 .59608 Mdot
.0549 .04706 Mdot
.76471 .75294 Mdot
.00392 .00392 Mdot
.56863 .59216 Mdot
.00392 .00392 Mdot
.02745 .04314 Mdot
.21961 .21569 Mdot
.85098 .85882 Mdot
.06275 .05098 Mdot
.00392 .01176 Mdot
.28235 .26667 Mdot
.00784 .01569 Mdot
.04314 .05882 Mdot
.07059 .08627 Mdot
.83922 .8549 Mdot
.01176 .02745 Mdot
.01176 .03137 Mdot
.00392 0 Mdot
.00392 .01961 Mdot
.04706 .06667 Mdot
.01176 .01176 Mdot
.83137 .84706 Mdot
0 .00784 Mdot
.00392 .03529 Mdot
.00784 .00392 Mdot
.00392 .00784 Mdot
.05882 .04314 Mdot
.87843 .86667 Mdot
.83922 .83922 Mdot
0 .01176 Mdot
.04706 .05098 Mdot
.00392 .00784 Mdot
.00784 .02745 Mdot
.84706 .8549 Mdot
.85882 .87059 Mdot
.81569 .82745 Mdot
0 .00392 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.02353 .03922 Mdot
.10588 .11765 Mdot
.8549 .86667 Mdot
.34902 .32941 Mdot
0 .01176 Mdot
.00392 .00784 Mdot
.00392 .00784 Mdot
.04314 .05098 Mdot
.82745 .81961 Mdot
.83529 .84314 Mdot
0 .01569 Mdot
.00392 .02745 Mdot
.00392 .00784 Mdot
.00392 .01569 Mdot
.54902 .54118 Mdot
.87843 .8902 Mdot
.82353 .84314 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.00392 .00392 Mdot
.00784 .02353 Mdot
.85098 .86275 Mdot
.87451 .87843 Mdot
.83137 .84314 Mdot
.00392 .01569 Mdot
.53725 .54902 Mdot
0 0 Mdot
.01176 .03137 Mdot
.34902 .31765 Mdot
.72941 .76471 Mdot
.81961 .82745 Mdot
.00392 .03137 Mdot
.55294 .03137 Mdot
.00392 .01569 Mdot
.03137 .04706 Mdot
.87059 .88235 Mdot
.11765 .13725 Mdot
.10588 .11373 Mdot
.02353 .05098 Mdot
.01569 .00784 Mdot
.00784 .01961 Mdot
.04314 .06667 Mdot
.8902 .90588 Mdot
.03137 .05098 Mdot
.01176 .01961 Mdot
.00392 .02745 Mdot
0 0 Mdot
.00784 .00392 Mdot
.0549 .07059 Mdot
.86667 .87843 Mdot
.36863 .33725 Mdot
.02353 .03922 Mdot
.00392 .02745 Mdot
.00392 .00392 Mdot
.00392 .00784 Mdot
.50196 .52157 Mdot
.66275 .70588 Mdot
.09412 .1098 Mdot
.00392 .02745 Mdot
0 .01569 Mdot
.01176 .00784 Mdot
.00392 .00784 Mdot
.38039 .36078 Mdot
.11373 .13333 Mdot
.03529 .04706 Mdot
.01176 .04314 Mdot
.56078 .56863 Mdot
0 .00392 Mdot
.00784 .02745 Mdot
.90196 .90588 Mdot
.42745 .41961 Mdot
.64314 .63137 Mdot
.00784 .03137 Mdot
.12549 .11765 Mdot
.00784 .01569 Mdot
.01961 .03529 Mdot
.8902 .89804 Mdot
.87059 .87059 Mdot
.83137 .83137 Mdot
.01961 .03922 Mdot
.56078 .02353 Mdot
.00392 .01569 Mdot
.03137 .0549 Mdot
.88235 .89412 Mdot
.85098 .85882 Mdot
.08235 .09804 Mdot
0 .00392 Mdot
.00784 .00392 Mdot
0 0 Mdot
.03529 .0549 Mdot
.27451 .31765 Mdot
.6902 .7098 Mdot
.00784 .04314 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.0902 .10588 Mdot
.07451 .09412 Mdot
.03922 .0549 Mdot
.00392 .03529 Mdot
.01176 .03529 Mdot
0 .00392 Mdot
.00784 .01569 Mdot
.84706 .85098 Mdot
.14902 .14118 Mdot
.03137 .05098 Mdot
.00784 .04314 Mdot
.00392 .02745 Mdot
0 .00392 Mdot
0 .00784 Mdot
.85882 .87059 Mdot
.86275 .87843 Mdot
.37647 .34902 Mdot
.00392 .03137 Mdot
.23529 .25098 Mdot
.00392 .00784 Mdot
.00392 .00392 Mdot
.87451 .88235 Mdot
.85098 .86275 Mdot
.81961 .84314 Mdot
.00392 .02745 Mdot
.4 .40784 Mdot
.00392 .01176 Mdot
0 .00784 Mdot
.27059 .31373 Mdot
.64706 .6902 Mdot
.07451 .10196 Mdot
.01569 .04314 Mdot
.05098 .01961 Mdot
.00784 .01176 Mdot
.00784 .03922 Mdot
.08235 .08235 Mdot
.05882 .09412 Mdot
.01569 .03922 Mdot
.02353 .04314 Mdot
.03529 0 Mdot
.00392 .01176 Mdot
.01961 .02353 Mdot
.07843 .08627 Mdot
.06667 .09412 Mdot
0 .01961 Mdot
.03922 .06275 Mdot
.00392 .00392 Mdot
0 .02353 Mdot
.83137 .83922 Mdot
.50196 .5098 Mdot
.38824 .38039 Mdot
.00392 .01961 Mdot
.02353 .05098 Mdot
.00392 .00392 Mdot
.02745 .04706 Mdot
.83922 .8549 Mdot
.86667 .87059 Mdot
.85098 .86275 Mdot
.00392 .01961 Mdot
.00392 .03137 Mdot
.00784 .00784 Mdot
.01569 .03137 Mdot
.64314 .67059 Mdot
.7098 .72549 Mdot
.22745 .27451 Mdot
.00784 .03137 Mdot
.02353 .03922 Mdot
.01176 .01176 Mdot
.00392 .01176 Mdot
.06667 .08235 Mdot
.01569 .03137 Mdot
.02353 .03529 Mdot
.00784 .02745 Mdot
.34902 .35294 Mdot
0 0 Mdot
.00392 .01569 Mdot
.07059 .08235 Mdot
.44314 .42353 Mdot
.21961 .20784 Mdot
.00392 .03137 Mdot
.00392 .00392 Mdot
.00392 .00392 Mdot
.03137 .03137 Mdot
.08235 .10196 Mdot
.83529 .84314 Mdot
.01569 .01176 Mdot
.01176 .03137 Mdot
.59216 .01176 Mdot
.01176 .03922 Mdot
.81961 .81961 Mdot
.04706 .07451 Mdot
.82353 .8549 Mdot
.02745 .05882 Mdot
.03529 .04706 Mdot
0 .00392 Mdot
.00784 .03922 Mdot
.82745 .83922 Mdot
.05882 .07451 Mdot
.40784 .41961 Mdot
.00392 .03529 Mdot
.04314 .06667 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18824 .21569 Mdot
.22353 .27059 Mdot
.85098 .85882 Mdot
.00392 .02353 Mdot
.00392 .03529 Mdot
.00392 .00392 Mdot
.00784 .03529 Mdot
.01176 .02353 Mdot
.36471 .41176 Mdot
.84706 .85098 Mdot
.01176 .02745 Mdot
.00784 .01961 Mdot
.01176 .00784 Mdot
.01569 .02745 Mdot
.76471 .73333 Mdot
.12157 .17647 Mdot
.83137 .84314 Mdot
.00392 .02745 Mdot
.38431 .38824 Mdot
.00392 .00392 Mdot
.06275 .06667 Mdot
.86275 .88235 Mdot
.03137 .05098 Mdot
.83922 .84706 Mdot
.01176 .03137 Mdot
0 0 Mdot
.00784 .02353 Mdot
.80784 .79608 Mdot
.8549 .87059 Mdot
.72941 .71765 Mdot
.84314 .8549 Mdot
.01569 .03922 Mdot
.03922 .01569 Mdot
.28627 .3098 Mdot
.81961 .82745 Mdot
.6549 .66667 Mdot
.85098 .8549 Mdot
.67059 .6902 Mdot
.01961 .04314 Mdot
.00392 .00392 Mdot
.03529 .06275 Mdot
.11373 .11765 Mdot
.06667 .07451 Mdot
.85098 .85882 Mdot
.01961 .05098 Mdot
.01961 .03529 Mdot
.1098 .11373 Mdot
.00392 .02745 Mdot
.76078 .75686 Mdot
.06667 .08627 Mdot
.80784 .83922 Mdot
0 .02745 Mdot
.00784 .03529 Mdot
.00392 .00392 Mdot
.01176 .04314 Mdot
.51373 .55294 Mdot
.06275 .07843 Mdot
.1098 .15686 Mdot
.01176 .03529 Mdot
0 .02353 Mdot
.00392 .00784 Mdot
.01961 .03529 Mdot
.05882 .07843 Mdot
.62745 .61961 Mdot
.06667 .09804 Mdot
0 .01569 Mdot
.45098 .46275 Mdot
0 .00392 Mdot
.31765 .30196 Mdot
.36863 .36078 Mdot
.87059 .87843 Mdot
.76471 .76078 Mdot
0 .01569 Mdot
.00392 .00392 Mdot
0 .00784 Mdot
.83137 .83922 Mdot
.86275 .87843 Mdot
.86667 .87059 Mdot
.79608 .81569 Mdot
.00392 .01569 Mdot
0 .00784 Mdot
.00392 .01961 Mdot
.08627 .07059 Mdot
.08627 .10588 Mdot
.40784 .45882 Mdot
.03137 .0549 Mdot
.00392 .01569 Mdot
.12157 .03137 Mdot
.00784 .02353 Mdot
.83137 .83529 Mdot
.06275 .08627 Mdot
.09412 .12157 Mdot
.00784 .02745 Mdot
.00784 .03137 Mdot
.00392 .00392 Mdot
.02353 .04314 Mdot
.07059 .09412 Mdot
.07843 .0902 Mdot
.06275 .07451 Mdot
.00784 .03529 Mdot
.00392 .03137 Mdot
.00392 0 Mdot
.00784 .02353 Mdot
.01176 .01961 Mdot
.3098 .3098 Mdot
.20784 .18824 Mdot
.00392 .02745 Mdot
.00784 .03529 Mdot
0 .00392 Mdot
.01176 .03529 Mdot
.62745 .61176 Mdot
.85882 .86667 Mdot
.84314 .82745 Mdot
.00784 .04314 Mdot
.03137 .03922 Mdot
0 0 Mdot
.01961 .03922 Mdot
.85098 .86275 Mdot
.8549 .87451 Mdot
.7098 .75294 Mdot
.00392 .02353 Mdot
.10196 .11373 Mdot
.00784 .00784 Mdot
.41569 .42353 Mdot
.19608 .24314 Mdot
.14902 .2 Mdot
.06667 .10588 Mdot
0 .00784 Mdot
0 0 Mdot
.00392 .01176 Mdot
.81569 .81961 Mdot
.0549 .06275 Mdot
.05098 .07451 Mdot
.05098 .07843 Mdot
0 .01569 Mdot
0 .00392 Mdot
.00392 .00784 Mdot
.76471 .76863 Mdot
.0549 .06667 Mdot
.12157 .12549 Mdot
0 .00784 Mdot
.00392 .01176 Mdot
.01569 .01569 Mdot
.00392 .01569 Mdot
.82745 .83529 Mdot
.0549 .05882 Mdot
.73725 .73333 Mdot
0 .00784 Mdot
0 .01176 Mdot
.00392 .00392 Mdot
.00392 .01961 Mdot
.80392 .79216 Mdot
.03529 .0549 Mdot
.86667 .87059 Mdot
.00392 .01569 Mdot
.00392 .02353 Mdot
.16078 .03137 Mdot
0 .01961 Mdot
.81176 .83529 Mdot
.0549 .07843 Mdot
.84314 .84706 Mdot
.03137 .05098 Mdot
.00392 .03137 Mdot
.00784 0 Mdot
.00784 .03137 Mdot
.16471 .20392 Mdot
.0549 .07451 Mdot
.74118 .7451 Mdot
.01176 .03529 Mdot
.00392 .02353 Mdot
.00392 0 Mdot
.01176 .03922 Mdot
.03529 .06667 Mdot
.06667 .09804 Mdot
.82353 .82353 Mdot
0 .01569 Mdot
.00392 .03137 Mdot
0 0 Mdot
.01176 .04314 Mdot
.03137 .05882 Mdot
.07059 .11765 Mdot
.85098 .8549 Mdot
0 .01569 Mdot
.0902 .09412 Mdot
.00392 .00392 Mdot
.00392 .02745 Mdot
.05098 .07451 Mdot
.05882 .10196 Mdot
.8549 .86275 Mdot
.00392 .02745 Mdot
.07843 .08235 Mdot
.00392 .00392 Mdot
.01569 .03137 Mdot
.04314 .06275 Mdot
.06275 .08235 Mdot
.85882 .86667 Mdot
.00784 .02745 Mdot
0 .00392 Mdot
.00784 .01176 Mdot
.31373 .3098 Mdot
.04706 .05882 Mdot
.24706 .2549 Mdot
.85882 .86667 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
0 .00392 Mdot
.83137 .83137 Mdot
.04706 .06667 Mdot
.86667 .87059 Mdot
.8549 .86275 Mdot
.01176 .03137 Mdot
.01176 .01961 Mdot
.00392 .01176 Mdot
.82353 .82745 Mdot
.05098 .07059 Mdot
.87059 .87451 Mdot
.8549 .86275 Mdot
.01569 .03529 Mdot
.00784 .00784 Mdot
.00392 .01569 Mdot
.80392 .80392 Mdot
.05882 .07059 Mdot
.87059 .87843 Mdot
.8549 .86275 Mdot
.00784 .03137 Mdot
0 0 Mdot
0 .01961 Mdot
.14118 .14118 Mdot
.05098 .06667 Mdot
.87059 .87843 Mdot
.63922 .66275 Mdot
.01176 .04314 Mdot
.12157 .00784 Mdot
.00392 .02745 Mdot
.03922 .0549 Mdot
.07451 .10196 Mdot
.76471 .79608 Mdot
.03922 .06667 Mdot
.02745 .0549 Mdot
.23529 .22353 Mdot
.00392 .03922 Mdot
.05882 .07843 Mdot
.4 .39608 Mdot
.11373 .16471 Mdot
.01176 .02745 Mdot
.05882 .07843 Mdot
.01176 .01176 Mdot
.00784 .03922 Mdot
.0549 .07451 Mdot
.85882 .86275 Mdot
.04706 .07451 Mdot
.01569 .02745 Mdot
.21961 .22745 Mdot
.0549 .05098 Mdot
.00784 .04314 Mdot
.03922 .0549 Mdot
.87451 .8902 Mdot
.07059 .08235 Mdot
.00784 .02745 Mdot
.47843 .49804 Mdot
0 .00392 Mdot
.01569 .04706 Mdot
.04706 .06275 Mdot
.86667 .87843 Mdot
.00392 .01176 Mdot
.01176 .02745 Mdot
.33333 .35686 Mdot
0 0 Mdot
.00784 .03529 Mdot
.03922 .0549 Mdot
.87451 .88235 Mdot
.37255 .36078 Mdot
.00392 .01961 Mdot
.30588 .32157 Mdot
.00784 .00392 Mdot
.01176 .03922 Mdot
.04314 .05882 Mdot
.87059 .88235 Mdot
.78431 .76863 Mdot
.00784 .03529 Mdot
.01176 .03529 Mdot
0 0 Mdot
.00784 .03922 Mdot
.04314 .05882 Mdot
.6902 .72549 Mdot
.85098 .85098 Mdot
.01176 .03529 Mdot
.01961 .04706 Mdot
0 0 Mdot
.01961 .04314 Mdot
.03922 .05882 Mdot
.11373 .13725 Mdot
.83529 .84314 Mdot
.00784 .03137 Mdot
.00392 .02353 Mdot
.00392 .00392 Mdot
.01176 .02745 Mdot
.06275 .09412 Mdot
.72157 .71373 Mdot
.83922 .84706 Mdot
.01961 .03137 Mdot
.00392 .01569 Mdot
0 0 Mdot
.01176 .02745 Mdot
.06275 .06667 Mdot
.86667 .87451 Mdot
.83922 .84706 Mdot
.02353 .03922 Mdot
.01176 .02745 Mdot
.00784 .01569 Mdot
.02353 .05098 Mdot
.72549 .71373 Mdot
.72549 .76078 Mdot
.83922 .84706 Mdot
.01961 .04706 Mdot
.00392 .00784 Mdot
.00392 .01176 Mdot
.03137 .05098 Mdot
.86275 .87059 Mdot
.17255 .21961 Mdot
.84314 .86275 Mdot
.01176 .04314 Mdot
.01176 .01569 Mdot
.00392 .01176 Mdot
.02745 .05882 Mdot
.85882 .87451 Mdot
.01961 .03529 Mdot
.72941 .74902 Mdot
.00784 .03529 Mdot
.00784 .01176 Mdot
.00392 .00784 Mdot
.04314 .07843 Mdot
.86275 .87059 Mdot
.65882 .65882 Mdot
.75294 .76078 Mdot
.00392 .02353 Mdot
.00392 .00784 Mdot
0 .01176 Mdot
.05882 .0902 Mdot
.84706 .87059 Mdot
.87843 .87843 Mdot
.83529 .83922 Mdot
.00784 .02745 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.08627 .12157 Mdot
.30588 .37255 Mdot
.87059 .87451 Mdot
.83922 .84706 Mdot
.01569 .03137 Mdot
.00784 .00784 Mdot
0 .00784 Mdot
.18039 .20784 Mdot
.06275 .1098 Mdot
.86667 .87451 Mdot
.56078 .59216 Mdot
.16078 .16471 Mdot
.00392 .00392 Mdot
.00784 .01961 Mdot
.34902 .36078 Mdot
.08235 .10588 Mdot
.84706 .8549 Mdot
.67059 .68235 Mdot
.76471 .76863 Mdot
.01569 .00392 Mdot
0 .01176 Mdot
.47059 .49412 Mdot
.11373 .11373 Mdot
.82353 .85098 Mdot
.82745 .83137 Mdot
.5098 .52941 Mdot
.76078 .00392 Mdot
.00392 .01961 Mdot
.24314 .27843 Mdot
.56863 .56863 Mdot
.4902 .5451 Mdot
.82353 .83137 Mdot
.25882 .2902 Mdot
.52157 .00392 Mdot
.00392 .02353 Mdot
.09412 .12941 Mdot
.74118 .73725 Mdot
.14902 .21569 Mdot
.81961 .83137 Mdot
.11373 .14118 Mdot
.51765 .00392 Mdot
.03137 .05098 Mdot
.06667 .09804 Mdot
.86275 .86667 Mdot
.10196 .14902 Mdot
.81961 .83137 Mdot
.12941 .1451 Mdot
.52549 .01569 Mdot
.00784 .02353 Mdot
.01961 .03922 Mdot
.85882 .87451 Mdot
.01569 .03137 Mdot
.82353 .83137 Mdot
.32157 .33725 Mdot
.52157 .01176 Mdot
.00784 .01961 Mdot
.04314 .04314 Mdot
.79608 .83137 Mdot
.0902 .09412 Mdot
.82353 .82745 Mdot
.5451 .56471 Mdot
.52157 .01176 Mdot
.00784 .02745 Mdot
.31373 .3098 Mdot
.43137 .49412 Mdot
.61176 .61176 Mdot
.82353 .82745 Mdot
.67059 .68627 Mdot
.51765 .00392 Mdot
.00392 .02353 Mdot
.62353 .61961 Mdot
.1451 .20392 Mdot
.77647 .77647 Mdot
.81569 .83137 Mdot
.75686 .76078 Mdot
.52549 .00784 Mdot
0 .01961 Mdot
.79608 .79608 Mdot
.0902 .12941 Mdot
.86275 .86667 Mdot
.76471 .79608 Mdot
.75686 .75294 Mdot
.52157 .00784 Mdot
.00392 .03137 Mdot
.81569 .81569 Mdot
.08235 .10196 Mdot
.87843 .88235 Mdot
.53333 .57647 Mdot
.7451 .7451 Mdot
.51373 .00392 Mdot
.00784 .03137 Mdot
.81961 .82353 Mdot
.1098 .11373 Mdot
.89804 .89804 Mdot
.23922 .30196 Mdot
.74118 .74118 Mdot
.50588 .00392 Mdot
.00392 .01961 Mdot
.81961 .82353 Mdot
.17647 .15686 Mdot
.91765 .92157 Mdot
.09412 .16078 Mdot
.76078 .76471 Mdot
.5098 .00784 Mdot
.00392 .02353 Mdot
.83137 .83529 Mdot
.25098 .21569 Mdot
.93333 .93725 Mdot
.04706 .10196 Mdot
.74902 .75294 Mdot
.51765 .00784 Mdot
.00392 .02353 Mdot
.82745 .83529 Mdot
.28627 .25098 Mdot
.94902 .95686 Mdot
.03529 .06667 Mdot
.7098 .71765 Mdot
.51373 .00784 Mdot
.00392 .02745 Mdot
.80784 .82353 Mdot
.2549 .23137 Mdot
.93725 .95294 Mdot
.05098 .06667 Mdot
.73725 .7451 Mdot
.51765 .00784 Mdot
.00392 .02745 Mdot
.71765 .74118 Mdot
.29412 .27451 Mdot
.93725 .95686 Mdot
.05882 .08235 Mdot
.74902 .76471 Mdot
.5098 .00392 Mdot
.00392 .01961 Mdot
.53333 .56471 Mdot
.27451 .25882 Mdot
.89412 .95294 Mdot
.05098 .07843 Mdot
.67059 .6902 Mdot
.5098 .00392 Mdot
.00392 .02353 Mdot
.30196 .3098 Mdot
.21176 .19608 Mdot
.40392 .5098 Mdot
.05882 .07451 Mdot
.59216 .6 Mdot
.5098 0 Mdot
.00784 .03137 Mdot
.18431 .17647 Mdot
.12549 .12941 Mdot
.1451 .21961 Mdot
.06667 .03922 Mdot
.76471 .77647 Mdot
.50196 0 Mdot
.01569 .04706 Mdot
.30196 .29412 Mdot
.07059 .0902 Mdot
.08627 .11373 Mdot
.10588 .00392 Mdot
.79216 .81569 Mdot
.50588 0 Mdot
.01961 .04706 Mdot
.6902 .6902 Mdot
.06275 .07843 Mdot
.08235 .09804 Mdot
.34118 .1098 Mdot
.67059 .70196 Mdot
.01569 .00392 Mdot
.14118 .15686 Mdot
.78824 .79216 Mdot
.08235 .08235 Mdot
.09804 .09804 Mdot
.47843 .18431 Mdot
.72941 .7451 Mdot
.01961 .00392 Mdot
.10588 .13333 Mdot
.82353 .82745 Mdot
.14118 .13333 Mdot
.14118 .11373 Mdot
.28627 .04706 Mdot
.68235 .6902 Mdot
.01961 .00784 Mdot
.03529 .07059 Mdot
.76471 .80392 Mdot
.20784 .18039 Mdot
.22353 .16471 Mdot
.10588 .00392 Mdot
.64706 .65882 Mdot
.01569 .00392 Mdot
.03529 .0549 Mdot
.43529 .50196 Mdot
.28627 .23922 Mdot
.32941 .26275 Mdot
.0549 .01176 Mdot
.60784 .61569 Mdot
.01569 0 Mdot
.39216 .39608 Mdot
.12157 .18824 Mdot
.28627 .25098 Mdot
.60392 .58039 Mdot
.04314 .03529 Mdot
.58824 .6 Mdot
.02745 .00784 Mdot
.25882 .27451 Mdot
.07843 .10588 Mdot
.21569 .18824 Mdot
.63137 .64706 Mdot
.04706 .05882 Mdot
.59608 .61961 Mdot
.01961 .00392 Mdot
.3098 .33725 Mdot
.1098 .1098 Mdot
.24706 .20784 Mdot
.64706 .67059 Mdot
.04314 .07843 Mdot
.58039 .60784 Mdot
.01961 .00392 Mdot
.05098 .07843 Mdot
.14902 .13725 Mdot
.24706 .21569 Mdot
.75294 .77647 Mdot
.03529 .07451 Mdot
.55294 .57647 Mdot
.01569 .00392 Mdot
0 .02745 Mdot
.12549 .12941 Mdot
.15294 .14902 Mdot
.70588 .75294 Mdot
.05098 .07451 Mdot
.56863 .58431 Mdot
.01569 .00392 Mdot
.00784 .03137 Mdot
.10588 .12549 Mdot
.10196 .11373 Mdot
.49804 .55294 Mdot
.06667 .07843 Mdot
.6549 .67451 Mdot
.02353 .00784 Mdot
.00784 .03529 Mdot
.03529 .0549 Mdot
.09804 .1098 Mdot
.58039 .63529 Mdot
.05882 .06667 Mdot
.66667 .69412 Mdot
.01569 .00392 Mdot
.01176 .03922 Mdot
.00392 .00784 Mdot
.1098 .1098 Mdot
.45882 .52941 Mdot
.06275 .07059 Mdot
.60784 .63529 Mdot
.01176 .00392 Mdot
0 .01176 Mdot
.1098 .11765 Mdot
.14118 .13725 Mdot
.21961 .25882 Mdot
.07843 .0902 Mdot
.66667 .68235 Mdot
.01961 0 Mdot
.00784 .01176 Mdot
.33725 .3451 Mdot
.21569 .19216 Mdot
.31373 .31373 Mdot
.26667 .27451 Mdot
.80784 .82353 Mdot
.03137 .00784 Mdot
.00392 .02353 Mdot
.59216 .59608 Mdot
.2902 .2549 Mdot
.31765 .32549 Mdot
.58431 .58824 Mdot
.7451 .78824 Mdot
.01961 0 Mdot
.01961 .03922 Mdot
.76863 .77255 Mdot
.23529 .21569 Mdot
.19216 .21176 Mdot
.77255 .77255 Mdot
.63529 .68627 Mdot
.04314 .00392 Mdot
.10588 .13333 Mdot
.81569 .81961 Mdot
.18039 .15294 Mdot
.12157 .12941 Mdot
.79608 .8 Mdot
.65098 .67451 Mdot
.0549 .00392 Mdot
.01961 .05098 Mdot
.82353 .83529 Mdot
.18824 .16078 Mdot
.18824 .18039 Mdot
.81569 .82353 Mdot
.6902 .71373 Mdot
.06667 .00392 Mdot
0 .02353 Mdot
.37255 .41176 Mdot
.28235 .22745 Mdot
.24706 .23529 Mdot
.81961 .82745 Mdot
.53725 .58431 Mdot
.46275 .06667 Mdot
.00392 .02353 Mdot
.08627 .12549 Mdot
.38431 .32941 Mdot
.27451 .26275 Mdot
.81569 .82353 Mdot
.03529 .09804 Mdot
.12157 .00392 Mdot
.00392 .02745 Mdot
.08627 .0902 Mdot
.33725 .30196 Mdot
.23922 .23529 Mdot
.80784 .82745 Mdot
.02353 .06275 Mdot
.01176 .00392 Mdot
.02353 .04314 Mdot
.11373 .11373 Mdot
.29412 .28627 Mdot
.28627 .04314 Mdot
.0902 .13725 Mdot
.08627 .14118 Mdot
0 0 Mdot
.00784 .02745 Mdot
.07451 .09804 Mdot
.2549 .23529 Mdot
.67843 .05098 Mdot
.60392 .61569 Mdot
.00392 .03137 Mdot
.03922 .03529 Mdot
.01569 .03529 Mdot
.11373 .10588 Mdot
.23529 .2 Mdot
.12549 .01176 Mdot
.83529 .86667 Mdot
.01176 .03922 Mdot
0 0 Mdot
.04314 .0549 Mdot
.16078 .12549 Mdot
.21176 .17647 Mdot
.02353 .0549 Mdot
.87843 .90588 Mdot
.01176 .01961 Mdot
.00784 .00392 Mdot
.07451 .09412 Mdot
.19216 .16863 Mdot
.24706 .2 Mdot
.68235 .67843 Mdot
.90196 .93725 Mdot
.04706 .03529 Mdot
.00392 .01569 Mdot
.04706 .05098 Mdot
.67059 .6902 Mdot
.34902 .27843 Mdot
.80784 .81961 Mdot
.81961 .85882 Mdot
.37647 .00392 Mdot
.00392 .02745 Mdot
.1451 .12549 Mdot
.53725 .49412 Mdot
.46667 .37255 Mdot
.07843 .10588 Mdot
.07843 .10588 Mdot
.01569 .00784 Mdot
.03922 .0549 Mdot
.52157 .45882 Mdot
.57647 .55294 Mdot
.5098 .4549 Mdot
.78039 .81569 Mdot
.05882 .07059 Mdot
.00392 .00784 Mdot
.12549 .1098 Mdot
.73333 .69804 Mdot
.65882 .64706 Mdot
.5098 .47451 Mdot
.77647 .82745 Mdot
.02745 .03922 Mdot
.00392 .00392 Mdot
.34118 .2902 Mdot
.80784 .79608 Mdot
.84706 .85882 Mdot
.4902 .47451 Mdot
.83137 .87451 Mdot
.00392 0 Mdot
.10588 .12549 Mdot
.55294 .52941 Mdot
.89412 .92549 Mdot
.83529 .85098 Mdot
.4902 .47843 Mdot
.74902 .80392 Mdot
.23922 .07059 Mdot
.16471 .15294 Mdot
.64706 .65882 Mdot
.44314 .46275 Mdot
.52941 .53333 Mdot
.47843 .46275 Mdot
.05882 .10196 Mdot
.01569 .01176 Mdot
.52157 .50588 Mdot
.43137 .41569 Mdot
.43922 .38824 Mdot
.56471 .55686 Mdot
.46275 .43922 Mdot
.01569 .00784 Mdot
.01961 .02353 Mdot
.51373 .49804 Mdot
.45098 .37647 Mdot
.47059 .41569 Mdot
.4902 .43137 Mdot
.43922 .44706 Mdot
.67059 .06275 Mdot
.4902 .47843 Mdot
.46667 .39216 Mdot
.46667 .38824 Mdot
.59608 .60392 Mdot
.4902 .42745 Mdot
.06667 .07843 Mdot
.03529 .01961 Mdot
.4 .33725 Mdot
.4549 .36471 Mdot
.47843 .42353 Mdot
.4549 .38039 Mdot
.58039 .5451 Mdot
.08627 .05098 Mdot
.43529 .40392 Mdot
.45098 .36471 Mdot
.44706 .36863 Mdot
.46275 .39216 Mdot
.38431 .28627 Mdot
.45882 .45882 Mdot
.08627 .04314 Mdot
.47059 .37255 Mdot
.44706 .37255 Mdot
.46275 .4 Mdot
.47059 .36471 Mdot
.44706 .34902 Mdot
.09412 .07843 Mdot
.43137 .39216 Mdot
.48235 .38431 Mdot
.45098 .36863 Mdot
.45882 .38431 Mdot
.42353 .32549 Mdot
.45882 .38039 Mdot
.09412 .04314 Mdot
.45098 .34902 Mdot
.47451 .38824 Mdot
.46667 .4 Mdot
.41961 .30588 Mdot
.47059 .38824 Mdot
.38039 .36078 Mdot
.40392 .3451 Mdot
.46667 .38039 Mdot
.45882 .39608 Mdot
.47059 .40392 Mdot
.45098 .3451 Mdot
.40392 .2902 Mdot
.31765 .21569 Mdot
.46667 .36471 Mdot
.46667 .36471 Mdot
.58824 .55294 Mdot
.42353 .3098 Mdot
.45882 .34902 Mdot
.38824 .38824 Mdot
.43922 .33725 Mdot
.45882 .35686 Mdot
.47843 .43529 Mdot
.46275 .43137 Mdot
.46667 .37647 Mdot
.41569 .30588 Mdot
.41176 .29804 Mdot
.45098 .35294 Mdot
.48627 .41569 Mdot
.23922 .21961 Mdot
.42745 .33333 Mdot
.4549 .37255 Mdot
.28627 .21961 Mdot
.47451 .37255 Mdot
.47059 .37255 Mdot
.35294 .32941 Mdot
.42353 .38039 Mdot
.4549 .36471 Mdot
.31765 .24706 Mdot
.38039 .27843 Mdot
.46667 .35294 Mdot
.2902 .25882 Mdot
.58824 .5451 Mdot
.46275 .35294 Mdot
.45098 .3451 Mdot
.27059 .02745 Mdot
.46667 .36078 Mdot
.42745 .36863 Mdot
.55294 .56863 Mdot
.44706 .34902 Mdot
.45098 .3451 Mdot
.2902 .21569 Mdot
.42745 .36078 Mdot
.46275 .35686 Mdot
.40392 .32941 Mdot
.59608 .54118 Mdot
.44314 .34902 Mdot
.43137 .37255 Mdot
.42353 .32941 Mdot
.47059 .34902 Mdot
.30196 .2549 Mdot
.68235 .62353 Mdot
.47451 .38039 Mdot
.46667 .38824 Mdot
.38824 .25098 Mdot
.43922 .35294 Mdot
.32941 .2902 Mdot
.40392 .25882 Mdot
.40392 .2549 Mdot
.46667 .37255 Mdot
.31373 .25098 Mdot
.41569 .35294 Mdot
.49804 .4 Mdot
.44314 .23922 Mdot
.48235 .38431 Mdot
.48627 .37255 Mdot
.41961 .3451 Mdot
.69804 .04706 Mdot
.38431 .27451 Mdot
.40392 .29412 Mdot
.4 .32941 Mdot
.43529 .30196 Mdot
.43922 .33725 Mdot
.40784 .36863 Mdot
.4902 .44706 Mdot
.51373 .41569 Mdot
.47843 .30196 Mdot
.36471 .27451 Mdot
.50196 .38824 Mdot
.39216 .32157 Mdot
.52157 .47843 Mdot
.43529 .33725 Mdot
.47059 .3098 Mdot
.32157 .28627 Mdot
.5098 .38431 Mdot
.37647 .30588 Mdot
.42353 .17255 Mdot
.52549 .48627 Mdot
.41176 .27451 Mdot
.67843 .63529 Mdot
.50196 .39608 Mdot
.37255 .28627 Mdot
.46667 .42745 Mdot
.58431 .57255 Mdot
.43137 .23922 Mdot
.48627 .34902 Mdot
.52941 .38431 Mdot
.41569 .3098 Mdot
.47451 .45882 Mdot
.60784 .6 Mdot
.50196 .44706 Mdot
.61961 .55294 Mdot
.58039 .40784 Mdot
.45098 .33725 Mdot
.49412 .46275 Mdot
.61176 .59216 Mdot
.56471 .52157 Mdot
.47843 .41961 Mdot
.65882 .47843 Mdot
.47843 .38039 Mdot
.52549 .50196 Mdot
.60392 .57647 Mdot
.60392 .57647 Mdot
.48235 .38431 Mdot
.78431 .65098 Mdot
.56471 .50588 Mdot
.53333 .52941 Mdot
.52941 .50196 Mdot
.63137 .60784 Mdot
.49804 .35294 Mdot
.83922 .77647 Mdot
.6 .56078 Mdot
.53725 .52549 Mdot
.65098 .64314 Mdot
.62745 .60784 Mdot
.56078 .50196 Mdot
.88235 .83922 Mdot
.64706 .58824 Mdot
.50588 .47843 Mdot
.68627 .68235 Mdot
.67843 .67843 Mdot
.99608 .95294 Mdot
.83137 .83137 Mdot
.60784 .59216 Mdot
.74902 .12157 Mdot
.6902 .6902 Mdot
.8 .80392 Mdot
.99216 .99216 Mdot
.7098 .6902 Mdot
.54118 .53333 Mdot
.72157 .71373 Mdot
.72157 .71765 Mdot
.99608 .99608 Mdot
.81176 .81176 Mdot
.62745 .61176 Mdot
.69804 .6902 Mdot
.73725 .73725 Mdot
.95294 .96078 Mdot
.92549 .92157 Mdot
.65882 .65098 Mdot
.67059 .64706 Mdot
.76863 .76078 Mdot
.94118 .93725 Mdot
.92549 .92549 Mdot
.61569 .6 Mdot
.76863 .76471 Mdot
.83922 .83922 Mdot
.99216 .99216 Mdot
.84314 .8549 Mdot
.88627 .08235 Mdot
.80392 .8 Mdot
.95294 .95686 Mdot
.94902 .95294 Mdot
.41176 .26275 Mdot
.81569 .81569 Mdot
.9451 .94118 Mdot
.94118 .95294 Mdot
.76078 .15294 Mdot
.82353 .82745 Mdot
.99216 .98824 Mdot
.72549 .72157 Mdot
.6 .52157 Mdot
.97647 .98824 Mdot
.6 .57255 Mdot
.56078 .44706 Mdot
.72549 .70196 Mdot
.81961 .21176 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.78431 .20392 Mdot
.43529 .38824 Mdot
.7451 .68235 Mdot
.75686 .73333 Mdot
.63529 .54118 Mdot
.43137 .44314 Mdot
.72157 .68235 Mdot
.7098 .63529 Mdot
.75294 .75686 Mdot
.79216 .78431 Mdot
.71765 .62745 Mdot
.83137 .80784 Mdot
.81569 .83137 Mdot
.58824 .43922 Mdot
.68627 .61176 Mdot
.63137 .63922 Mdot
.81961 .82745 Mdot
.63529 .51373 Mdot
.66275 .60392 Mdot
.74902 .75294 Mdot
.8 .80784 Mdot
.62353 .48235 Mdot
.76471 .66667 Mdot
.83137 .81569 Mdot
.81176 .83137 Mdot
.83529 .05098 Mdot
.60392 .5451 Mdot
.75686 .72941 Mdot
.30588 .43137 Mdot
.79608 .81176 Mdot
.63922 .51373 Mdot
.80784 .72549 Mdot
.7098 .68627 Mdot
.83137 .83922 Mdot
.74902 .77255 Mdot
.73333 .63137 Mdot
.80784 .72941 Mdot
.73333 .70588 Mdot
.81569 .82353 Mdot
.52549 .21569 Mdot
.73725 .64706 Mdot
.78431 .70588 Mdot
.72941 .72549 Mdot
.81569 .8549 Mdot
.82745 .05098 Mdot
.7451 .66275 Mdot
.79216 .7098 Mdot
.83137 .81176 Mdot
.82353 .84706 Mdot
.49804 .54118 Mdot
.71765 .61961 Mdot
.81569 .81961 Mdot
.80784 .76863 Mdot
.83922 .85098 Mdot
.79608 .81569 Mdot
.65882 .57647 Mdot
.75686 .64706 Mdot
.76471 .71765 Mdot
.73725 .77255 Mdot
.78039 .80392 Mdot
.59216 .45882 Mdot
.7098 .61569 Mdot
.79608 .70196 Mdot
.70588 .67843 Mdot
.83922 .86667 Mdot
.75686 .81569 Mdot
.68627 .6 Mdot
.7451 .63137 Mdot
.75686 .68627 Mdot
.44706 .52157 Mdot
.79216 .82353 Mdot
.56078 .41176 Mdot
.67843 .58431 Mdot
.76471 .67451 Mdot
.84706 .81176 Mdot
.22353 .36863 Mdot
.81176 .83922 Mdot
.61176 .49804 Mdot
.7098 .60392 Mdot
.78824 .69412 Mdot
.77647 .74902 Mdot
.83137 .8549 Mdot
.73725 .76078 Mdot
.58039 .5098 Mdot
.43922 .39608 Mdot
.76078 .66667 Mdot
.77647 .75686 Mdot
.83529 .85882 Mdot
.57647 .62353 Mdot
.14118 .09412 Mdot
.57647 .53333 Mdot
.75294 .6549 Mdot
.76863 .74118 Mdot
.83137 .8549 Mdot
.34902 .4 Mdot
.15294 .08235 Mdot
.62353 .54118 Mdot
.76471 .66667 Mdot
.69412 .67059 Mdot
.83529 .86667 Mdot
.26275 .3451 Mdot
.26275 .17647 Mdot
.61176 .53725 Mdot
.77647 .68235 Mdot
.82353 .8 Mdot
.83922 .84706 Mdot
.79216 .84314 Mdot
.61569 .51373 Mdot
.65882 .53333 Mdot
.76078 .65882 Mdot
.70588 .64314 Mdot
.5098 .48627 Mdot
.77647 .75294 Mdot
.56863 .47843 Mdot
.63922 .5098 Mdot
.7451 .63922 Mdot
.70588 .61569 Mdot
.38824 .37255 Mdot
.81176 .83529 Mdot
.44314 .32941 Mdot
.61961 .50196 Mdot
.41569 .4 Mdot
.74902 .65882 Mdot
.64314 .61569 Mdot
.64314 .66667 Mdot
.46667 .5098 Mdot
.61176 .50196 Mdot
.61569 .43922 Mdot
.76863 .67059 Mdot
.75686 .6902 Mdot
.02745 .03922 Mdot
.72941 .58431 Mdot
.51765 .44314 Mdot
.61569 .46667 Mdot
.72549 .61961 Mdot
.73725 .63529 Mdot
.03529 .04314 Mdot
.80392 .82745 Mdot
.5451 .55686 Mdot
.62353 .51765 Mdot
.61176 .43922 Mdot
.76863 .68235 Mdot
.64314 .57255 Mdot
.01961 .02353 Mdot
.79216 .71765 Mdot
.56471 .48627 Mdot
.6 .44314 Mdot
.7098 .57647 Mdot
.73333 .63137 Mdot
.01961 .03137 Mdot
.24314 .25882 Mdot
.66275 .68235 Mdot
.58824 .47451 Mdot
.61176 .41569 Mdot
.76078 .68627 Mdot
.61961 .57255 Mdot
.01961 .02745 Mdot
.59608 .03922 Mdot
.73333 .75686 Mdot
.59608 .4549 Mdot
.6549 .50196 Mdot
.46667 .43137 Mdot
.02745 .03922 Mdot
.02353 .03137 Mdot
.27843 .31765 Mdot
.59608 .53333 Mdot
.57255 .37647 Mdot
.72157 .60392 Mdot
.71765 .63137 Mdot
.03137 .03922 Mdot
.58824 .59216 Mdot
.82745 .05098 Mdot
.58039 .48235 Mdot
.62745 .43922 Mdot
.49412 .45882 Mdot
.07451 .0549 Mdot
.30588 .40392 Mdot
.59216 .19608 Mdot
.77647 .80784 Mdot
.6 .47843 Mdot
.65098 .49412 Mdot
.5451 .51373 Mdot
.04314 .05098 Mdot
.28627 .42353 Mdot
.62745 .01176 Mdot
.82353 .83529 Mdot
.58824 .43137 Mdot
.68235 .54902 Mdot
.76471 .68235 Mdot
.11373 .11765 Mdot
.28235 .33725 Mdot
.43922 .38824 Mdot
.56863 .51765 Mdot
.56863 .37647 Mdot
.72549 .61961 Mdot
.61176 .57647 Mdot
.23529 .38431 Mdot
.02353 .03922 Mdot
.53725 .52941 Mdot
.58824 .53725 Mdot
.59216 .40392 Mdot
.76078 .66275 Mdot
.06667 .06667 Mdot
.81961 .82353 Mdot
.67059 .71373 Mdot
.7451 .76471 Mdot
.57255 .48627 Mdot
.63529 .47451 Mdot
.78824 .70196 Mdot
.05882 .05098 Mdot
.68235 .68627 Mdot
.59216 .08235 Mdot
.77255 .81569 Mdot
.59608 .50588 Mdot
.66667 .55686 Mdot
.78824 .72157 Mdot
.34118 .39216 Mdot
.74902 .79216 Mdot
.50196 .02353 Mdot
.57647 .60784 Mdot
.58039 .47451 Mdot
.6902 .57647 Mdot
.77647 .69804 Mdot
.24314 .41961 Mdot
.27843 .38431 Mdot
.46275 .03922 Mdot
.66275 .67843 Mdot
.57647 .46275 Mdot
.69804 .59216 Mdot
.76078 .68235 Mdot
.61961 .58039 Mdot
.79608 .85882 Mdot
.39216 .01569 Mdot
.81569 .84706 Mdot
.56471 .42353 Mdot
.70588 .61176 Mdot
.25882 .23137 Mdot
.4549 .41961 Mdot
.81961 .8549 Mdot
.43922 .04706 Mdot
.69412 .70196 Mdot
.56471 .38824 Mdot
.7098 .61176 Mdot
.08235 .06667 Mdot
.04314 .05098 Mdot
.82353 .85882 Mdot
.37255 .02745 Mdot
.55294 .54118 Mdot
.55686 .39608 Mdot
.72157 .62745 Mdot
.0902 .05882 Mdot
.02353 .04314 Mdot
.82745 .8549 Mdot
.30196 .00392 Mdot
.56471 .54118 Mdot
.56863 .41569 Mdot
.71373 .62745 Mdot
.09412 .05882 Mdot
.02353 .03529 Mdot
.74118 .77255 Mdot
.38431 .01569 Mdot
.56863 .54902 Mdot
.56471 .41176 Mdot
.72941 .64314 Mdot
.30196 .29804 Mdot
.02745 .03529 Mdot
.37647 .42353 Mdot
.51765 .05882 Mdot
.58431 .56078 Mdot
.59216 .4549 Mdot
.74118 .65882 Mdot
.27059 .46275 Mdot
.11765 .12549 Mdot
.07843 .12157 Mdot
.49412 .06275 Mdot
.58431 .56078 Mdot
.6 .46275 Mdot
.73725 .6549 Mdot
.30196 .49804 Mdot
.34902 .43922 Mdot
.07059 .11373 Mdot
.44706 .02353 Mdot
.59216 .56078 Mdot
.62353 .49804 Mdot
.72941 .64706 Mdot
.58431 .69804 Mdot
.16863 .36471 Mdot
.06275 .1098 Mdot
.47451 .02353 Mdot
.58431 .55686 Mdot
.62745 .50588 Mdot
.72549 .64706 Mdot
.74118 .76471 Mdot
.41176 .53333 Mdot
.07059 .10196 Mdot
.43137 .00784 Mdot
.58824 .56863 Mdot
.61961 .5098 Mdot
.72941 .63529 Mdot
.7451 .7098 Mdot
.77255 .78039 Mdot
.06667 .08627 Mdot
.47451 .03137 Mdot
.54902 .53333 Mdot
.63529 .52549 Mdot
.72549 .63137 Mdot
.72941 .67451 Mdot
.62353 .58431 Mdot
.07451 .09804 Mdot
.55686 .08235 Mdot
.53333 .51373 Mdot
.62745 .52549 Mdot
.72157 .63529 Mdot
.67451 .62353 Mdot
.50196 .45882 Mdot
.06667 .09804 Mdot
.57255 .15686 Mdot
.52941 .50196 Mdot
.63922 .54118 Mdot
.73333 .64314 Mdot
.26275 .24314 Mdot
.16863 .15294 Mdot
.0549 .08235 Mdot
.58039 .2902 Mdot
.50588 .47843 Mdot
.63922 .55294 Mdot
.72549 .63529 Mdot
.11765 .10196 Mdot
.0549 .06275 Mdot
.0549 .08235 Mdot
.65882 .50588 Mdot
.50588 .48235 Mdot
.63922 .54902 Mdot
.72549 .63137 Mdot
.10196 .08235 Mdot
.05882 .05098 Mdot
.0549 .08235 Mdot
.63529 .58039 Mdot
.49804 .47451 Mdot
.64314 .5451 Mdot
.73333 .65098 Mdot
.1098 .0902 Mdot
.22353 .21176 Mdot
.04706 .06667 Mdot
.5451 .53333 Mdot
.48627 .46667 Mdot
.63529 .54118 Mdot
.73333 .64314 Mdot
.23529 .23529 Mdot
.18824 .25882 Mdot
.03922 .06275 Mdot
.72549 .73725 Mdot
.46275 .46275 Mdot
.61569 .52941 Mdot
.72157 .62745 Mdot
.30588 .3098 Mdot
.31373 .34118 Mdot
.06667 .0902 Mdot
.56863 .60784 Mdot
.69412 .70196 Mdot
.61569 .54118 Mdot
.7098 .61569 Mdot
.47059 .50196 Mdot
.04706 .04314 Mdot
.31373 .34118 Mdot
.41961 .50196 Mdot
.76471 .78039 Mdot
.62745 .56078 Mdot
.71765 .63137 Mdot
.47059 .56863 Mdot
.04706 .05882 Mdot
.35686 .42745 Mdot
.73333 .81176 Mdot
.76078 .78431 Mdot
.65098 .58039 Mdot
.70196 .60784 Mdot
.3098 .45882 Mdot
.07843 .07843 Mdot
.4549 .52549 Mdot
.47451 .58039 Mdot
.65098 .66667 Mdot
.64706 .58431 Mdot
.70196 .61961 Mdot
.66275 .70588 Mdot
.17647 .16471 Mdot
.63137 .6902 Mdot
.79608 .87451 Mdot
.51765 .52549 Mdot
.6549 .59216 Mdot
.6902 .61569 Mdot
.77255 .72549 Mdot
.27451 .25882 Mdot
.41961 .49412 Mdot
.79216 .84706 Mdot
.5098 .51765 Mdot
.64314 .6 Mdot
.68235 .59608 Mdot
.78039 .7098 Mdot
.3098 .30588 Mdot
.03922 .07843 Mdot
.77647 .83137 Mdot
.45882 .47059 Mdot
.6549 .60784 Mdot
.67451 .58824 Mdot
.78039 .71373 Mdot
.30196 .30196 Mdot
.01176 .02745 Mdot
.80392 .84314 Mdot
.42353 .45098 Mdot
.65098 .61569 Mdot
.67843 .58824 Mdot
.78431 .72157 Mdot
.30196 .30588 Mdot
.01569 .03529 Mdot
.79216 .83922 Mdot
.46275 .50588 Mdot
.63922 .60784 Mdot
.66275 .57647 Mdot
.78824 .72157 Mdot
.62353 .6 Mdot
.38824 .42353 Mdot
.79608 .85098 Mdot
.6549 .7098 Mdot
.63137 .59216 Mdot
.6549 .56078 Mdot
.76078 .69412 Mdot
.68627 .64706 Mdot
.65098 .66275 Mdot
.79216 .82353 Mdot
.54902 .55294 Mdot
.61176 .56471 Mdot
.64314 .55294 Mdot
.75686 .6902 Mdot
.72549 .67451 Mdot
.63137 .60392 Mdot
.79608 .83137 Mdot
.56078 .40784 Mdot
.56863 .52549 Mdot
.64314 .54902 Mdot
.75294 .67059 Mdot
.7098 .67059 Mdot
.60392 .54902 Mdot
.80392 .8549 Mdot
.26667 .21961 Mdot
.56471 .53725 Mdot
.63922 .54118 Mdot
.74118 .66667 Mdot
.71765 .69412 Mdot
.61176 .56078 Mdot
.7451 .80784 Mdot
.16863 .21176 Mdot
.56471 .55294 Mdot
.61569 .52157 Mdot
.73725 .67843 Mdot
.73333 .69804 Mdot
.61961 .56863 Mdot
.2549 .32549 Mdot
.59216 .63137 Mdot
.56078 .56078 Mdot
.61569 .52941 Mdot
.73725 .67843 Mdot
.72941 .69412 Mdot
.63529 .59608 Mdot
.02353 .05882 Mdot
.63922 .65882 Mdot
.69412 .71373 Mdot
.62745 .54902 Mdot
.73725 .66275 Mdot
.72941 .69804 Mdot
.61176 .57647 Mdot
.00784 .02745 Mdot
.48627 .51373 Mdot
.42745 .44706 Mdot
.62353 .56078 Mdot
.72549 .6549 Mdot
.75686 .73333 Mdot
.12941 .1451 Mdot
.26667 .29804 Mdot
.52941 .60784 Mdot
.65098 .67451 Mdot
.60784 .55686 Mdot
.70196 .63922 Mdot
.76471 .72941 Mdot
.0549 .06275 Mdot
.59216 .59608 Mdot
.76863 .83529 Mdot
.30196 .33333 Mdot
.62353 .58824 Mdot
.69804 .63922 Mdot
.74902 .71373 Mdot
.04706 .05882 Mdot
.04314 .05098 Mdot
.78824 .84706 Mdot
.45098 .49804 Mdot
.64314 .61176 Mdot
.67451 .60392 Mdot
.75686 .71373 Mdot
.07843 .09412 Mdot
.01569 .03137 Mdot
.77647 .83529 Mdot
.55686 .59216 Mdot
.61176 .6 Mdot
.65882 .59216 Mdot
.74902 .70588 Mdot
.28235 .27451 Mdot
.00784 .02353 Mdot
.79216 .84314 Mdot
.58039 .63137 Mdot
.61961 .59608 Mdot
.65882 .57647 Mdot
.73725 .69804 Mdot
.68627 .66667 Mdot
.01569 .03922 Mdot
.69412 .7098 Mdot
.66275 .60392 Mdot
.6 .58039 Mdot
.64706 .56078 Mdot
.72941 .68627 Mdot
.72549 .69804 Mdot
.01569 .03529 Mdot
.01961 .06275 Mdot
.21176 .12941 Mdot
.58824 .58431 Mdot
.63529 .53725 Mdot
.7451 .6902 Mdot
.72941 .69804 Mdot
.02353 .04706 Mdot
.00392 .04314 Mdot
.08235 .18431 Mdot
.55686 .56471 Mdot
.61961 .53333 Mdot
.72941 .66275 Mdot
.75294 .72549 Mdot
.03922 .0549 Mdot
.00392 .04706 Mdot
.1098 .2 Mdot
.81961 .8549 Mdot
.60784 .54118 Mdot
.68627 .61176 Mdot
.75686 .72941 Mdot
.02745 .05098 Mdot
.44706 .49412 Mdot
.65882 .70196 Mdot
.35294 .38824 Mdot
.58039 .54118 Mdot
.63922 .55686 Mdot
.76078 .73333 Mdot
.03137 .04706 Mdot
.43529 .53333 Mdot
.29804 .40392 Mdot
.6902 .72549 Mdot
.56078 .52549 Mdot
.61961 .51765 Mdot
.76863 .75294 Mdot
.04314 .0549 Mdot
.03529 .07843 Mdot
.78039 .85098 Mdot
.34902 .37255 Mdot
.59216 .55294 Mdot
.59608 .49412 Mdot
.59216 .58824 Mdot
.05098 .07451 Mdot
.01569 .03529 Mdot
.77255 .84314 Mdot
.48627 .52157 Mdot
.58431 .5451 Mdot
.61176 .50588 Mdot
.66667 .64706 Mdot
.11373 .14118 Mdot
.00784 .03137 Mdot
.77647 .86275 Mdot
.73725 .78824 Mdot
.58824 .56863 Mdot
.60784 .50196 Mdot
.71373 .67059 Mdot
.62745 .63529 Mdot
.00392 .03529 Mdot
.4549 .62353 Mdot
.59216 .53725 Mdot
.55686 .55294 Mdot
.59608 .48235 Mdot
.63922 .58431 Mdot
.70588 .68235 Mdot
.01176 .03529 Mdot
.08235 .32549 Mdot
.32941 .30588 Mdot
.56863 .55294 Mdot
.57255 .48235 Mdot
.62353 .56471 Mdot
.70588 .69804 Mdot
.03137 .05098 Mdot
.04706 .25882 Mdot
.30196 .29804 Mdot
.54118 .55294 Mdot
.58431 .4902 Mdot
.63922 .57255 Mdot
.72941 .71373 Mdot
.02745 .03529 Mdot
.47843 .5451 Mdot
.39216 .37647 Mdot
.48627 .50196 Mdot
.55686 .48627 Mdot
.60392 .51765 Mdot
.75686 .73725 Mdot
.02745 .04314 Mdot
.72941 .79216 Mdot
.48627 .4902 Mdot
.40392 .43922 Mdot
.55294 .50196 Mdot
.58824 .48627 Mdot
.75686 .74118 Mdot
.03529 .04706 Mdot
.56078 .7451 Mdot
.73725 .76863 Mdot
.33333 .38824 Mdot
.53725 .49412 Mdot
.57647 .44314 Mdot
.77647 .75294 Mdot
.03137 .04706 Mdot
.1451 .37647 Mdot
.40392 .49412 Mdot
.45882 .51765 Mdot
.53333 .50588 Mdot
.56471 .43529 Mdot
.75294 .73725 Mdot
.04706 .05882 Mdot
.31765 .45098 Mdot
.39608 .47843 Mdot
.73725 .78824 Mdot
.55294 .53725 Mdot
.56471 .44706 Mdot
.74118 .71765 Mdot
.03529 .04314 Mdot
.3098 .37647 Mdot
.78039 .83529 Mdot
.75686 .82353 Mdot
.53725 .5098 Mdot
.54902 .43529 Mdot
.63137 .58431 Mdot
.1098 .13333 Mdot
.1451 .18039 Mdot
.37255 .4549 Mdot
.64706 .58431 Mdot
.56471 .54902 Mdot
.54118 .42745 Mdot
.61176 .55294 Mdot
.72157 .70588 Mdot
.03922 .06667 Mdot
.42745 .47451 Mdot
.23922 .27451 Mdot
.53725 .53333 Mdot
.52941 .41961 Mdot
.60392 .53333 Mdot
.72549 .72549 Mdot
.10588 .14118 Mdot
.81176 .86275 Mdot
.36078 .36471 Mdot
.47843 .4902 Mdot
.54118 .45098 Mdot
.59216 .51765 Mdot
.73725 .73725 Mdot
.62745 .6549 Mdot
.64314 .73333 Mdot
.2549 .34118 Mdot
.12157 .14902 Mdot
.54902 .49804 Mdot
.63137 .57255 Mdot
.7451 .74118 Mdot
.58431 .62745 Mdot
.31373 .40392 Mdot
.43529 .49804 Mdot
.33333 .36471 Mdot
.55686 .52941 Mdot
.58824 .50588 Mdot
.74902 .7451 Mdot
.12941 .16863 Mdot
.56078 .58431 Mdot
.12549 .29804 Mdot
.18431 .18431 Mdot
.54118 .52157 Mdot
.59216 .50196 Mdot
.74902 .74902 Mdot
.12157 .18039 Mdot
.37647 .40392 Mdot
.63529 .68235 Mdot
.11373 .12157 Mdot
.49412 .48627 Mdot
.6 .50196 Mdot
.58039 .57647 Mdot
.1451 .21176 Mdot
.13333 .17255 Mdot
.43922 .52157 Mdot
.22353 .21569 Mdot
.49804 .4902 Mdot
.55294 .45882 Mdot
.56471 .53725 Mdot
.64706 .66667 Mdot
.10588 .12941 Mdot
.78824 .83137 Mdot
.70588 .08235 Mdot
.5098 .50196 Mdot
.56863 .46667 Mdot
.66667 .62353 Mdot
.71373 .70196 Mdot
.14902 .18431 Mdot
.11373 .18039 Mdot
.07059 .18824 Mdot
.48235 .48627 Mdot
.54902 .45098 Mdot
.67059 .62745 Mdot
.72941 .73333 Mdot
.12549 .16863 Mdot
.00784 .04706 Mdot
.04706 .19608 Mdot
.47451 .4902 Mdot
.54118 .4549 Mdot
.68627 .65882 Mdot
.73333 .72157 Mdot
.15294 .18431 Mdot
.00392 .03137 Mdot
.07843 .20784 Mdot
.43137 .43922 Mdot
.52941 .48235 Mdot
.65882 .63529 Mdot
.7451 .74902 Mdot
.20392 .2549 Mdot
.00784 .02745 Mdot
.39608 .42745 Mdot
.21176 .23529 Mdot
.50588 .47059 Mdot
.64706 .61176 Mdot
.72157 .71765 Mdot
.35686 .47451 Mdot
.00784 .04706 Mdot
.46275 .45882 Mdot
.08627 .09804 Mdot
.43922 .41569 Mdot
.63922 .6 Mdot
.71765 .7098 Mdot
.23922 .39216 Mdot
.00784 .04314 Mdot
.47059 .48235 Mdot
.20784 .22745 Mdot
.42745 .41569 Mdot
.61176 .56471 Mdot
.71765 .71373 Mdot
.28627 .43137 Mdot
.02353 .04314 Mdot
.44706 .48627 Mdot
.19608 .18039 Mdot
.44314 .41961 Mdot
.61176 .56078 Mdot
.72157 .72941 Mdot
.67451 .68627 Mdot
.04314 .06667 Mdot
.18039 .22745 Mdot
.31373 .26275 Mdot
.47451 .46275 Mdot
.59216 .52549 Mdot
.70588 .71765 Mdot
.71373 .70588 Mdot
.06275 .10196 Mdot
.00392 .03529 Mdot
.31373 .33725 Mdot
.42353 .43529 Mdot
.54902 .48627 Mdot
.7098 .7098 Mdot
.6902 .67843 Mdot
.07059 .10588 Mdot
.16078 .20392 Mdot
.34118 .37255 Mdot
.40392 .4 Mdot
.56863 .49412 Mdot
.67059 .65098 Mdot
.71373 .72157 Mdot
.03137 .05882 Mdot
.5098 .53725 Mdot
.40392 .4 Mdot
.34902 .35686 Mdot
.54902 .48627 Mdot
.68627 .6549 Mdot
.7098 .7098 Mdot
.01961 .03922 Mdot
.03137 .07451 Mdot
.1098 .18431 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.69412 .66667 Mdot
.68627 .69412 Mdot
.02353 .05098 Mdot
.00392 .04314 Mdot
.44314 .43922 Mdot
.30196 .31765 Mdot
.4549 .43922 Mdot
.66275 .63529 Mdot
.72941 .73333 Mdot
.00784 .03529 Mdot
.00392 .02745 Mdot
.47843 .47451 Mdot
.12157 .11373 Mdot
.43922 .43137 Mdot
.63922 .59608 Mdot
.71373 .72157 Mdot
.03529 .05882 Mdot
.00784 .03529 Mdot
.6 .6902 Mdot
.3451 .31765 Mdot
.4549 .44706 Mdot
.61961 .55294 Mdot
.70196 .6902 Mdot
.03922 .06667 Mdot
.04314 .08627 Mdot
.04706 .09412 Mdot
.27843 .32157 Mdot
.38431 .38824 Mdot
.6 .53725 Mdot
.58824 .56078 Mdot
.34902 .38431 Mdot
.56471 .57647 Mdot
.42745 .49804 Mdot
.0549 .23529 Mdot
.31765 .33333 Mdot
.55294 .50196 Mdot
.54902 .49412 Mdot
.68235 .69804 Mdot
.59216 .62353 Mdot
.80392 .90588 Mdot
.08627 .20392 Mdot
.27451 .29412 Mdot
.52549 .49412 Mdot
.61569 .58824 Mdot
.66275 .67451 Mdot
.4902 .62353 Mdot
.18824 .4 Mdot
.43922 .43529 Mdot
.27451 .27451 Mdot
.50196 .47451 Mdot
.66275 .62745 Mdot
.69804 .72157 Mdot
.18824 .46275 Mdot
.12941 .39216 Mdot
.47451 .46667 Mdot
.39608 .38824 Mdot
.44314 .43529 Mdot
.61961 .57647 Mdot
.70588 .70588 Mdot
.33333 .48627 Mdot
.12941 .36471 Mdot
.48627 .4902 Mdot
.37647 .37647 Mdot
.44314 .43922 Mdot
.57255 .50196 Mdot
.69804 .69804 Mdot
.07059 .0902 Mdot
.18039 .22745 Mdot
.74902 .80784 Mdot
.27843 .3098 Mdot
.38431 .38039 Mdot
.52157 .43529 Mdot
.61961 .60392 Mdot
.02353 .04706 Mdot
.32941 .34902 Mdot
.15686 .3451 Mdot
.40392 .42353 Mdot
.29804 .3098 Mdot
.46275 .4 Mdot
.6549 .64314 Mdot
.06275 .09412 Mdot
.58039 .58039 Mdot
.10196 .13725 Mdot
.41569 .39608 Mdot
.12549 .14118 Mdot
.45098 .43137 Mdot
.6549 .63137 Mdot
.65882 .66275 Mdot
.12549 .19608 Mdot
.03137 .0549 Mdot
.44706 .43137 Mdot
.28235 .29412 Mdot
.4549 .44314 Mdot
.55294 .49804 Mdot
.66667 .6549 Mdot
.07843 .12941 Mdot
.03529 .07059 Mdot
.46275 .46275 Mdot
.38824 .38824 Mdot
.49804 .4902 Mdot
.57255 .5098 Mdot
.68627 .69412 Mdot
.38824 .51765 Mdot
.26667 .32157 Mdot
.48627 .48627 Mdot
.26275 .27451 Mdot
.41961 .42353 Mdot
.47843 .37647 Mdot
.65098 .66275 Mdot
.22353 .48235 Mdot
.67843 .69412 Mdot
.03137 .07843 Mdot
.07451 .23529 Mdot
.35294 .37255 Mdot
.4902 .39608 Mdot
.71373 .71765 Mdot
.24314 .33333 Mdot
.48235 .58431 Mdot
.00392 .03922 Mdot
.0549 .23529 Mdot
.3098 .33725 Mdot
.43529 .38039 Mdot
.67451 .65882 Mdot
.05098 .07843 Mdot
.04314 .08627 Mdot
.00784 .05882 Mdot
.06667 .2902 Mdot
.22353 .23137 Mdot
.39608 .38824 Mdot
.53725 .50196 Mdot
.5098 .5451 Mdot
.56863 .63922 Mdot
.03529 .09412 Mdot
.0902 .28627 Mdot
.31765 .30196 Mdot
.47059 .47843 Mdot
.58039 .53333 Mdot
.69412 .70588 Mdot
.32157 .54118 Mdot
.42745 .48627 Mdot
.31373 .36078 Mdot
.4 .31373 Mdot
.47843 .48627 Mdot
.56471 .50588 Mdot
.7098 .72157 Mdot
.32941 .50588 Mdot
.77647 .84314 Mdot
.00392 .03529 Mdot
.40784 .39216 Mdot
.37647 .38824 Mdot
.52941 .47059 Mdot
.6902 .70588 Mdot
.06667 .08627 Mdot
.63529 .66667 Mdot
.10588 .13725 Mdot
.42353 .41569 Mdot
.30588 .32549 Mdot
.43529 .38824 Mdot
.59216 .57647 Mdot
.20784 .22745 Mdot
.15294 .39216 Mdot
.0902 .13725 Mdot
.09804 .23137 Mdot
.26667 .27059 Mdot
.38039 .33333 Mdot
.82745 .82353 Mdot
.07059 .0902 Mdot
.27451 .35686 Mdot
.02353 .04706 Mdot
.45098 .47059 Mdot
.22745 .21569 Mdot
.44706 .44706 Mdot
.51373 .4902 Mdot
.65882 .66275 Mdot
.03922 .07451 Mdot
.00392 .03137 Mdot
.17255 .3451 Mdot
.29804 .28235 Mdot
.46275 .47059 Mdot
.59608 .54118 Mdot
.70588 .71373 Mdot
.07451 .12157 Mdot
.01961 .0549 Mdot
.06275 .31373 Mdot
.18431 .27451 Mdot
.43137 .46667 Mdot
.52549 .47059 Mdot
.68235 .6902 Mdot
.1098 .19216 Mdot
.64314 .71765 Mdot
.0549 .10588 Mdot
.0549 .25882 Mdot
.33725 .37647 Mdot
.5098 .45098 Mdot
.66275 .66667 Mdot
.03922 .06667 Mdot
.49804 .54902 Mdot
.71373 .73725 Mdot
.12941 .23922 Mdot
.27451 .27843 Mdot
.41961 .4 Mdot
.53725 .52941 Mdot
.08235 .12941 Mdot
.71373 .73725 Mdot
.04314 .07843 Mdot
.18431 .30196 Mdot
.08627 .08235 Mdot
.41569 .40784 Mdot
.5451 .52941 Mdot
.70588 .71373 Mdot
.65882 .72549 Mdot
.16078 .31373 Mdot
.41569 .4902 Mdot
.30196 .27843 Mdot
.38039 .4 Mdot
.57647 .5451 Mdot
.69804 .71373 Mdot
.34118 .53333 Mdot
.01961 .05882 Mdot
.2 .37647 Mdot
.27059 .30588 Mdot
.03529 .06667 Mdot
.51373 .45882 Mdot
.63137 .63529 Mdot
.43137 .62745 Mdot
.55294 .59608 Mdot
.21961 .31373 Mdot
.21569 .28235 Mdot
.13725 .17255 Mdot
.4549 .42353 Mdot
.54118 .52549 Mdot
.06275 .1098 Mdot
.6 .62745 Mdot
.0549 .07451 Mdot
.44314 .43529 Mdot
.25098 .25882 Mdot
.41176 .41176 Mdot
.50588 .48235 Mdot
.29412 .32941 Mdot
.6 .62353 Mdot
.02353 .0549 Mdot
.48235 .47843 Mdot
.28235 .26275 Mdot
.38431 .40392 Mdot
.55686 .53725 Mdot
.6902 .69804 Mdot
.71765 .73333 Mdot
.03529 .07843 Mdot
.44314 .46275 Mdot
.12941 .01569 Mdot
.30588 .32941 Mdot
.58431 .55294 Mdot
.6902 .70588 Mdot
.66275 .67451 Mdot
.61961 .67059 Mdot
.29412 .30588 Mdot
.11765 .17647 Mdot
.31373 .35686 Mdot
.52157 .47451 Mdot
.5098 .5098 Mdot
.23137 .39608 Mdot
.6549 .7451 Mdot
.02745 .07451 Mdot
.37647 .37255 Mdot
.26275 .28627 Mdot
.44706 .42353 Mdot
.50196 .47843 Mdot
.05098 .07059 Mdot
.63137 .68235 Mdot
.00392 .03529 Mdot
.46667 .46275 Mdot
.06667 .06667 Mdot
.40784 .42353 Mdot
.46275 .4549 Mdot
.66275 .68627 Mdot
.66275 .67843 Mdot
.11373 .17647 Mdot
.43529 .43137 Mdot
.09804 .01569 Mdot
.2902 .3098 Mdot
.49412 .4549 Mdot
.65098 .66275 Mdot
.64314 .67059 Mdot
.5098 .59216 Mdot
0 .02745 Mdot
.05882 .17255 Mdot
.27451 .31765 Mdot
.55294 .51765 Mdot
.50196 .50588 Mdot
.35294 .46667 Mdot
.80784 .8549 Mdot
.00392 .03137 Mdot
.04706 .2 Mdot
.28235 .32157 Mdot
.50588 .47843 Mdot
.4902 .48235 Mdot
.03529 .05098 Mdot
.64706 .77255 Mdot
.00392 .02745 Mdot
.11765 .24706 Mdot
.27059 .2902 Mdot
.44706 .43922 Mdot
.43529 .43922 Mdot
.31765 .35686 Mdot
.72941 .81961 Mdot
0 .03137 Mdot
.42745 .41176 Mdot
.21961 .19216 Mdot
.33725 .34902 Mdot
.33725 .33333 Mdot
.63137 .64706 Mdot
.67843 .70196 Mdot
0 .03137 Mdot
.02745 .0549 Mdot
.6549 .12157 Mdot
.24706 .28235 Mdot
.49412 .44314 Mdot
.56471 .57255 Mdot
.06667 .13333 Mdot
.00392 .03529 Mdot
.26275 .34118 Mdot
.35294 .34118 Mdot
.27059 .3098 Mdot
.51765 .49412 Mdot
.4902 .48235 Mdot
.03922 .07059 Mdot
.02353 .08235 Mdot
.21176 .40784 Mdot
.03529 .21961 Mdot
.10196 .13333 Mdot
.44706 .45098 Mdot
.47059 .45098 Mdot
.65098 .67451 Mdot
.62353 .68627 Mdot
.11373 .16863 Mdot
.42353 .45098 Mdot
.39608 .38824 Mdot
.39216 .41569 Mdot
.50196 .4902 Mdot
.57255 .59608 Mdot
.65882 .68235 Mdot
.40784 .44706 Mdot
.13725 .25882 Mdot
.80784 .03529 Mdot
.27451 .30588 Mdot
.45098 .41961 Mdot
.56471 .56471 Mdot
.03529 .06275 Mdot
.07451 .12157 Mdot
.00392 .02353 Mdot
.36863 .35294 Mdot
.27451 .30588 Mdot
.52549 .50588 Mdot
.83922 .87451 Mdot
.04706 .07451 Mdot
.00784 .04706 Mdot
.05882 .12941 Mdot
.21176 .26275 Mdot
.2 .20784 Mdot
.40784 .40392 Mdot
.49804 .47451 Mdot
.61569 .63529 Mdot
.00392 .03922 Mdot
.36078 .52941 Mdot
.40392 .39216 Mdot
.12941 .13725 Mdot
.39608 .41961 Mdot
.50588 .48627 Mdot
.56471 .58039 Mdot
.06275 .11373 Mdot
.16471 .23922 Mdot
.06667 .07059 Mdot
.63529 .03137 Mdot
.28627 .31765 Mdot
.47451 .43137 Mdot
.59216 .60392 Mdot
.04706 .07451 Mdot
.20784 .31373 Mdot
.00784 .03137 Mdot
.38824 .35686 Mdot
.2549 .28235 Mdot
.46275 .43529 Mdot
.53333 .53333 Mdot
.26667 .29412 Mdot
.19216 .43529 Mdot
.00392 .04706 Mdot
.40392 .38039 Mdot
.16471 .17255 Mdot
.33725 .32157 Mdot
.53333 .52941 Mdot
.74902 .76863 Mdot
.2549 .36078 Mdot
.00392 .03137 Mdot
.40784 .39216 Mdot
.32941 .30588 Mdot
.37647 .4 Mdot
.47451 .46275 Mdot
.53725 .55294 Mdot
.03922 .06667 Mdot
.31373 .48627 Mdot
.06667 .09804 Mdot
.64706 .1098 Mdot
.04314 .0902 Mdot
.45098 .42745 Mdot
.57647 .58824 Mdot
.09412 .14118 Mdot
.13333 .18824 Mdot
.30196 .37647 Mdot
.36863 .3451 Mdot
.24314 .2902 Mdot
.49804 .47451 Mdot
.51373 .50588 Mdot
.77647 .79216 Mdot
.11765 .22353 Mdot
.24706 .36078 Mdot
.41176 .38039 Mdot
.24706 .2549 Mdot
.42745 .41961 Mdot
.4902 .48235 Mdot
.61961 .65098 Mdot
.46667 .61176 Mdot
.02353 .05098 Mdot
.41176 .39216 Mdot
.27451 .23922 Mdot
.33333 .34118 Mdot
.48627 .46667 Mdot
.76863 .78431 Mdot
.13333 .16471 Mdot
.00784 .04314 Mdot
.18431 .20392 Mdot
.62353 .00784 Mdot
.24706 .27843 Mdot
.47843 .45098 Mdot
.60392 .62353 Mdot
.0549 .08627 Mdot
.54118 .65882 Mdot
0 .02745 Mdot
.38824 .36078 Mdot
.04706 .06275 Mdot
.51373 .50196 Mdot
.46667 .46275 Mdot
.42353 .47451 Mdot
.29412 .40392 Mdot
.12941 .18824 Mdot
.41176 .4 Mdot
.26667 .26275 Mdot
.42353 .43529 Mdot
.46275 .45098 Mdot
.63137 .66667 Mdot
.29412 .34118 Mdot
.08627 .3098 Mdot
.38824 .37255 Mdot
.15294 .12157 Mdot
.27843 .31765 Mdot
.46667 .45882 Mdot
.78039 .78824 Mdot
.02353 .07059 Mdot
.00392 .04314 Mdot
.00392 .01176 Mdot
.32157 .28627 Mdot
.30196 .32157 Mdot
.54902 .53333 Mdot
.38431 .43922 Mdot
.07451 .11765 Mdot
.83529 .87843 Mdot
0 .01569 Mdot
.4 .36471 Mdot
.22745 .2549 Mdot
.46667 .46275 Mdot
.47843 .48235 Mdot
.27451 .3451 Mdot
.28627 .52157 Mdot
.00392 .03529 Mdot
.40392 .37647 Mdot
.23137 .19608 Mdot
.41176 .42745 Mdot
.47843 .47451 Mdot
.80784 .84314 Mdot
.15686 .21961 Mdot
.00784 .0549 Mdot
.33333 .37647 Mdot
.08627 0 Mdot
.35294 .38824 Mdot
.48627 .45882 Mdot
.58431 .60392 Mdot
.0549 .10196 Mdot
.16078 .21569 Mdot
.00784 .02745 Mdot
.37647 .36078 Mdot
.29804 .32157 Mdot
.51765 .50196 Mdot
.50588 .55686 Mdot
.21569 .38431 Mdot
.82353 .87059 Mdot
.21176 .31373 Mdot
.4 .38039 Mdot
.25098 .2549 Mdot
.30196 .31373 Mdot
.49412 .4902 Mdot
.6902 .72549 Mdot
.8549 .91765 Mdot
.01569 .05098 Mdot
.41176 .39608 Mdot
.08627 .05098 Mdot
.37255 .38824 Mdot
.82353 .83137 Mdot
.77255 .80392 Mdot
.02745 .07059 Mdot
.00784 .04314 Mdot
.08627 .23529 Mdot
.33333 .26667 Mdot
.12157 .14902 Mdot
.54902 .5098 Mdot
.52549 .54118 Mdot
.48235 .52157 Mdot
.81569 .85098 Mdot
.01569 .04706 Mdot
.38039 .35686 Mdot
.13333 .16471 Mdot
.42353 .42353 Mdot
.18431 .35294 Mdot
.31373 .33725 Mdot
.83529 .87059 Mdot
.60784 .72941 Mdot
.40784 .39608 Mdot
.28235 .2549 Mdot
.40392 .41961 Mdot
.47059 .45882 Mdot
.84706 .88627 Mdot
.23137 .44314 Mdot
.17255 .35686 Mdot
.41176 .38824 Mdot
.25098 .0549 Mdot
.41176 .43137 Mdot
.49804 .50588 Mdot
.56078 .58824 Mdot
.06667 .09412 Mdot
.18824 .24706 Mdot
.37255 .4549 Mdot
.38039 .3451 Mdot
.28627 .30196 Mdot
.4902 .47451 Mdot
.72941 .74902 Mdot
.30196 .55294 Mdot
.82745 .86275 Mdot
.53725 .59216 Mdot
.40392 .38039 Mdot
.08235 .10196 Mdot
.16078 .18431 Mdot
.10588 .32941 Mdot
.69412 .79608 Mdot
.83529 .86667 Mdot
.58824 .65882 Mdot
.40784 .38824 Mdot
.26667 .19608 Mdot
.3451 .38824 Mdot
.47059 .48235 Mdot
.82353 .84706 Mdot
.16863 .4 Mdot
.61569 .72941 Mdot
.42745 .42353 Mdot
.37255 .32941 Mdot
.37647 .41569 Mdot
.56863 .5451 Mdot
.68627 .71373 Mdot
.05098 .0902 Mdot
.82353 .85882 Mdot
.57647 .60392 Mdot
.38431 .36471 Mdot
.33333 .36471 Mdot
.39216 .38431 Mdot
.48627 .4902 Mdot
.23529 .47843 Mdot
.83529 .87451 Mdot
.7451 .79608 Mdot
.41569 .39608 Mdot
.04706 .01176 Mdot
.22353 .24314 Mdot
.45882 .47451 Mdot
.8549 .88235 Mdot
.84706 .87843 Mdot
.65882 .76078 Mdot
.43137 .42353 Mdot
.36078 .30588 Mdot
.14118 .18431 Mdot
.57255 .55294 Mdot
.60784 .64706 Mdot
.20784 .47059 Mdot
.82745 .86667 Mdot
.49412 .51765 Mdot
.39216 .37255 Mdot
.3098 .35686 Mdot
.46275 .44314 Mdot
.56863 .58431 Mdot
.12157 .2 Mdot
.83137 .86275 Mdot
.62353 .66275 Mdot
.41176 .40784 Mdot
.21569 .18039 Mdot
.47451 .49804 Mdot
.21176 .44314 Mdot
.84706 .8902 Mdot
.8549 .88627 Mdot
.37255 .48235 Mdot
.41961 .41569 Mdot
.1451 .02745 Mdot
.40392 .43137 Mdot
.62353 .61176 Mdot
.67059 .69412 Mdot
.8549 .88627 Mdot
.81961 .85882 Mdot
.53725 .55294 Mdot
.39608 .36078 Mdot
.18431 .21176 Mdot
.53333 .52549 Mdot
.84314 .86275 Mdot
.72157 .91373 Mdot
.83922 .87059 Mdot
.78431 .82353 Mdot
.41569 .38824 Mdot
.25882 .26667 Mdot
.43529 .45098 Mdot
.58431 .61176 Mdot
.83137 .87843 Mdot
.8549 .88235 Mdot
.56078 .63137 Mdot
.43137 .41176 Mdot
.15294 .07451 Mdot
.40784 .43922 Mdot
.53333 .63922 Mdot
.69412 .73333 Mdot
.8549 .88627 Mdot
.83137 .87451 Mdot
.55686 .57647 Mdot
.37255 .3451 Mdot
.36471 .40392 Mdot
.50588 .49412 Mdot
.61176 .63529 Mdot
.72157 .8549 Mdot
.8549 .88235 Mdot
.65882 .69412 Mdot
.40784 .39216 Mdot
.13333 .12157 Mdot
.33333 .3451 Mdot
.61569 .64706 Mdot
.78824 .9098 Mdot
.85882 .88627 Mdot
.5451 .64706 Mdot
.45882 .43529 Mdot
.13725 .0902 Mdot
.20784 .25098 Mdot
.12941 .46667 Mdot
.98039 1 Mdot
.87451 .90196 Mdot
.83922 .90196 Mdot
.58824 .61176 Mdot
.39216 .35686 Mdot
.35686 .4 Mdot
.56863 .57255 Mdot
.84706 .86667 Mdot
.91765 .9451 Mdot
.85098 .89804 Mdot
.79608 .81961 Mdot
.41176 .39216 Mdot
.32941 .35294 Mdot
.4549 .45098 Mdot
.76471 .81569 Mdot
.91373 .9451 Mdot
.86275 .89804 Mdot
.64706 .72157 Mdot
.47451 .46667 Mdot
.1098 .06275 Mdot
.29412 .30588 Mdot
.14902 .52157 Mdot
1 1 Mdot
.88235 .91373 Mdot
.77255 .86275 Mdot
.68235 .69804 Mdot
.40392 .36471 Mdot
.29804 .32941 Mdot
.56078 .56078 Mdot
.94902 .96471 Mdot
.91373 .95294 Mdot
.83922 .88235 Mdot
.76471 .8 Mdot
.44314 .42745 Mdot
.32549 .34118 Mdot
.50196 .50588 Mdot
.87451 .89804 Mdot
.92157 .98824 Mdot
.84706 .88627 Mdot
.35686 .4902 Mdot
.4902 .49412 Mdot
.18431 .11765 Mdot
.19216 .22353 Mdot
.23529 .63922 Mdot
.9451 .95686 Mdot
.84706 .8902 Mdot
.81569 .87059 Mdot
.62353 .64706 Mdot
.42353 .38824 Mdot
.31373 .34118 Mdot
.64706 .6549 Mdot
.99608 1 Mdot
.87451 .9098 Mdot
.82745 .87451 Mdot
.4902 .52941 Mdot
.46667 .46275 Mdot
.11373 .12157 Mdot
.57255 .59216 Mdot
.88235 .91373 Mdot
.89412 .98824 Mdot
.83137 .87843 Mdot
.43137 .54902 Mdot
.46275 .46667 Mdot
.23529 .12549 Mdot
.22353 .23922 Mdot
.30588 .69804 Mdot
.52157 .6549 Mdot
.85098 .8902 Mdot
.82353 .8902 Mdot
.53333 .5451 Mdot
.44706 .42745 Mdot
.06275 .1098 Mdot
.76863 .77647 Mdot
.76863 .82745 Mdot
.86667 .90196 Mdot
.83137 .97647 Mdot
.58039 .6549 Mdot
.43922 .43137 Mdot
.18039 .18039 Mdot
.64314 .65098 Mdot
.80784 .85098 Mdot
.81176 .92549 Mdot
.64706 .92941 Mdot
.33333 .63529 Mdot
.50588 .52157 Mdot
.23529 .12941 Mdot
.15294 .22353 Mdot
.23922 .61176 Mdot
.84706 .89412 Mdot
.62353 .9098 Mdot
.18039 .60392 Mdot
.34902 .5451 Mdot
.60784 .61961 Mdot
.22745 .25098 Mdot
.69804 .72157 Mdot
.8549 .88627 Mdot
.74902 .9451 Mdot
.17255 .5098 Mdot
.09804 .41176 Mdot
.42745 .40784 Mdot
.13333 .13333 Mdot
.63922 .6549 Mdot
.85098 .87843 Mdot
.71765 .94118 Mdot
.43137 .91373 Mdot
.04706 .18039 Mdot
.14902 .38824 Mdot
.12549 .02745 Mdot
.23922 .25882 Mdot
.15686 .41176 Mdot
.7098 .93725 Mdot
.66667 1 Mdot
.03137 .08627 Mdot
.03922 .18039 Mdot
.60392 .62353 Mdot
.37647 .41569 Mdot
.62745 .65098 Mdot
.56471 .87843 Mdot
.85882 1 Mdot
.03137 .09412 Mdot
.02745 .08235 Mdot
.34118 .47059 Mdot
.25882 .26275 Mdot
.60392 .62745 Mdot
.59608 .86275 Mdot
.83529 .99216 Mdot
.06667 .20392 Mdot
.32157 .38039 Mdot
.03922 .16078 Mdot
.04706 .03137 Mdot
.53333 .57255 Mdot
.54118 .78824 Mdot
.6 .99608 Mdot
.15686 .48235 Mdot
.53725 .55686 Mdot
0 .02353 Mdot
.37647 .32549 Mdot
.47451 .5098 Mdot
.62745 .74118 Mdot
.4902 .98039 Mdot
.18431 .44706 Mdot
.41961 .52157 Mdot
.57647 .59608 Mdot
.21961 .45882 Mdot
.27843 .28235 Mdot
.64706 .67843 Mdot
.45098 .97255 Mdot
.21569 .47843 Mdot
.06275 .10588 Mdot
.57255 .62745 Mdot
.01176 .05882 Mdot
.20392 .17647 Mdot
.58431 .60392 Mdot
.28235 .84314 Mdot
.27451 .52549 Mdot
.31765 .67843 Mdot
.58039 .64706 Mdot
.13725 .17647 Mdot
.22353 .17647 Mdot
.47451 .50196 Mdot
.21176 .73333 Mdot
.28235 .54118 Mdot
.57255 .99608 Mdot
.6 .67059 Mdot
0 .01176 Mdot
.69412 .07451 Mdot
.4 .43922 Mdot
.21961 .69412 Mdot
.22745 .4902 Mdot
.54902 .94902 Mdot
.34902 .4549 Mdot
.31373 .36863 Mdot
.06667 .18039 Mdot
.37647 .40392 Mdot
.2 .65882 Mdot
.18824 .45098 Mdot
.5098 .93333 Mdot
.05882 .09804 Mdot
.21176 .2902 Mdot
.59608 .63137 Mdot
.43137 .43529 Mdot
.16863 .61176 Mdot
.11373 .52157 Mdot
.44314 .93333 Mdot
.11765 .26667 Mdot
.10588 .20392 Mdot
.42745 .45882 Mdot
.4 .33333 Mdot
.18039 .58039 Mdot
.17647 .45882 Mdot
.4 .92157 Mdot
.46667 .95294 Mdot
.04314 .09804 Mdot
.47451 .4902 Mdot
.31373 .21176 Mdot
.14118 .47451 Mdot
.03922 .30588 Mdot
.37255 .8902 Mdot
.66275 .99608 Mdot
.05882 .1098 Mdot
.00392 .04706 Mdot
.55686 .0902 Mdot
.17647 .38824 Mdot
.13333 .33725 Mdot
.33725 .83529 Mdot
.88627 1 Mdot
.05098 .12549 Mdot
.00392 .03137 Mdot
.1451 .23922 Mdot
.40392 .47843 Mdot
.10196 .29804 Mdot
.28627 .79216 Mdot
.87451 .98039 Mdot
.06667 .14902 Mdot
.01961 .06275 Mdot
.42353 .50196 Mdot
.38431 .40392 Mdot
.10196 .25882 Mdot
.19216 .7098 Mdot
.64706 .89412 Mdot
.14118 .38824 Mdot
.06275 .18824 Mdot
.02745 .10588 Mdot
.38824 .39608 Mdot
.12157 .34902 Mdot
.23137 .76863 Mdot
.5451 .96078 Mdot
.2549 .68627 Mdot
.12549 .41176 Mdot
.01961 .06275 Mdot
.38431 .36863 Mdot
.11765 .43529 Mdot
.22745 .79216 Mdot
.48235 .97255 Mdot
.27843 .76078 Mdot
.17647 .58431 Mdot
.03137 .05882 Mdot
.36471 .3098 Mdot
.09412 .41961 Mdot
.41569 .95294 Mdot
.41569 .93333 Mdot
.31373 .76863 Mdot
.19608 .62353 Mdot
.03137 .14118 Mdot
.35294 .25882 Mdot
.09412 .41961 Mdot
.25882 .81961 Mdot
.37647 .88627 Mdot
.31765 .72549 Mdot
.24706 .53333 Mdot
.09412 .40392 Mdot
.34902 .24706 Mdot
.10588 .45098 Mdot
.23529 .78039 Mdot
.36078 .86667 Mdot
.38431 .61176 Mdot
.4902 .57647 Mdot
.13333 .47451 Mdot
.34118 .23137 Mdot
.11765 .4902 Mdot
.22353 .74902 Mdot
.34118 .83137 Mdot
.52157 .57647 Mdot
.7098 .7098 Mdot
.18824 .39608 Mdot
.3451 .17255 Mdot
.13725 .51765 Mdot
.26275 .78431 Mdot
.3451 .76863 Mdot
.59608 .60392 Mdot
.77255 .77255 Mdot
.35294 .4 Mdot
.34118 .12157 Mdot
.15294 .5451 Mdot
.23137 .73333 Mdot
.41176 .62745 Mdot
.67059 .67451 Mdot
.78431 .80784 Mdot
.38039 .37255 Mdot
.23529 .07451 Mdot
.14902 .55686 Mdot
.21176 .71373 Mdot
.55294 .57255 Mdot
.87843 .88235 Mdot
.49412 .52549 Mdot
.36471 .34902 Mdot
.07451 .12941 Mdot
.16078 .58039 Mdot
.14118 .61569 Mdot
.59608 .59216 Mdot
.56471 .58824 Mdot
.41961 .37647 Mdot
.34902 .31765 Mdot
.07843 .21569 Mdot
.16078 .58824 Mdot
.21961 .51765 Mdot
.78824 .78824 Mdot
.45098 .40392 Mdot
.39608 .2902 Mdot
.34118 .29804 Mdot
.03529 .0902 Mdot
.14902 .59216 Mdot
.52157 .53333 Mdot
.54902 .58039 Mdot
.41176 .30588 Mdot
.38039 .28627 Mdot
.32549 .28627 Mdot
.09804 .36863 Mdot
.18824 .62353 Mdot
.60784 .6 Mdot
.43922 .37255 Mdot
.36471 .24314 Mdot
.39608 .3098 Mdot
.30588 .25098 Mdot
.13333 .52157 Mdot
.28235 .52549 Mdot
.60784 .63137 Mdot
.39216 .2902 Mdot
.37255 .25882 Mdot
.38431 .28627 Mdot
.27843 .20392 Mdot
.09412 .47843 Mdot
.56078 .57647 Mdot
.36078 .27843 Mdot
.38824 .26275 Mdot
.36078 .2549 Mdot
.36863 .25882 Mdot
.1451 .03529 Mdot
.12941 .53333 Mdot
.76078 .74902 Mdot
.40392 .28627 Mdot
.37255 .25098 Mdot
.39608 .29412 Mdot
.35686 .25098 Mdot
.07843 .15686 Mdot
.17647 .43137 Mdot
.39608 .38039 Mdot
.41569 .31765 Mdot
.36863 .25098 Mdot
.38039 .2902 Mdot
.33725 .27843 Mdot
.12549 .45098 Mdot
.56863 .56471 Mdot
.46275 .38431 Mdot
.43922 .33333 Mdot
.37255 .25098 Mdot
.37647 .27451 Mdot
.27843 .2 Mdot
.11765 .49412 Mdot
.68627 .69412 Mdot
.52157 .46275 Mdot
.41961 .32941 Mdot
.35686 .23529 Mdot
.41569 .33333 Mdot
.33725 .24314 Mdot
.15294 .42353 Mdot
.52549 .4549 Mdot
.55686 .49412 Mdot
.39216 .31373 Mdot
.36078 .27451 Mdot
.36863 .28627 Mdot
.14118 .02745 Mdot
.65098 .64314 Mdot
.57255 .59608 Mdot
.45098 .39608 Mdot
.40784 .34902 Mdot
.41569 .38039 Mdot
.34902 .30588 Mdot
.16471 .52549 Mdot
.35686 .31373 Mdot
.42745 .39216 Mdot
.52157 .48235 Mdot
.34118 .32157 Mdot
.37255 .32157 Mdot
.41961 .36471 Mdot
.25098 .43137 Mdot
.39608 .28627 Mdot
.41569 .31765 Mdot
.23137 .21569 Mdot
.27059 .24314 Mdot
.44706 .38431 Mdot
.38431 .29804 Mdot
.55686 .54902 Mdot
.38431 .2549 Mdot
.47059 .41961 Mdot
.33333 .30588 Mdot
.22353 .18039 Mdot
.34118 .30588 Mdot
.26667 .61961 Mdot
.40392 .3098 Mdot
.40392 .2902 Mdot
.43137 .4 Mdot
.39216 .33333 Mdot
.41176 .36078 Mdot
.44314 .40784 Mdot
.45098 .42745 Mdot
.41176 .27451 Mdot
.39608 .33333 Mdot
.51373 .47059 Mdot
.43922 .33333 Mdot
.37647 .32157 Mdot
.6549 .04706 Mdot
.40392 .28627 Mdot
.4 .25882 Mdot
.7098 .69412 Mdot
.41961 .26667 Mdot
.39608 .30588 Mdot
.50196 .46667 Mdot
.38824 .31765 Mdot
.41176 .2902 Mdot
.40392 .31373 Mdot
.5098 .43922 Mdot
.38039 .26275 Mdot
.42353 .4 Mdot
.35686 .17647 Mdot
.40784 .28235 Mdot
.39216 .27451 Mdot
.44314 .39216 Mdot
.37255 .25098 Mdot
.42353 .32549 Mdot
.54902 .52549 Mdot
.30588 .16863 Mdot
.40392 .27059 Mdot
.78431 .76471 Mdot
.3451 .33333 Mdot
.43137 .38039 Mdot
.59608 .59216 Mdot
.3098 .18824 Mdot
.41569 .29804 Mdot
.4 .21961 Mdot
.4549 .40392 Mdot
.48235 .43922 Mdot
.62353 .61569 Mdot
.38431 .27843 Mdot
.34118 .1451 Mdot
.36863 .19608 Mdot
.45882 .38824 Mdot
.44706 .37255 Mdot
.52157 .46667 Mdot
.59608 .59608 Mdot
.35686 .27843 Mdot
.43922 .33725 Mdot
.38039 .23529 Mdot
.63137 .64314 Mdot
.48627 .41176 Mdot
.71373 .71765 Mdot
.23922 .16471 Mdot
.41569 .28627 Mdot
.46275 .36078 Mdot
.6 .57255 Mdot
.53725 .52157 Mdot
.78824 .79608 Mdot
.37255 .19216 Mdot
.40784 .29412 Mdot
.44706 .32157 Mdot
.53725 .42353 Mdot
.64706 .63922 Mdot
.8902 .89412 Mdot
.33725 .07843 Mdot
.41569 .32941 Mdot
.45882 .3451 Mdot
.45882 .29804 Mdot
.59608 .48627 Mdot
.92157 .93725 Mdot
.35686 .0902 Mdot
.39608 .33333 Mdot
.46275 .36863 Mdot
.56078 .42745 Mdot
.8902 .81569 Mdot
.85882 .8902 Mdot
.3451 .19608 Mdot
.38824 .32157 Mdot
.4549 .37647 Mdot
.63137 .55294 Mdot
.99608 .98824 Mdot
.81569 .84706 Mdot
.34902 .30196 Mdot
.4902 .43922 Mdot
.52941 .45098 Mdot
.88235 .84706 Mdot
.99216 .99608 Mdot
.73725 .74118 Mdot
.43137 .38824 Mdot
.47843 .42745 Mdot
.61176 .56078 Mdot
.99216 .99216 Mdot
.87451 .89412 Mdot
.35686 .16471 Mdot
.42745 .36078 Mdot
.57647 .55294 Mdot
.99608 .99216 Mdot
.89412 .9098 Mdot
.76863 .78039 Mdot
.47451 .43137 Mdot
.59608 .58431 Mdot
1 .99216 Mdot
.97255 .98039 Mdot
.82353 .82745 Mdot
.45098 .41569 Mdot
.57647 .55294 Mdot
.92157 .92157 Mdot
.97647 .98039 Mdot
.83529 .84314 Mdot
.43137 .38824 Mdot
.60784 .59216 Mdot
.90196 .90588 Mdot
.92157 .92941 Mdot
.83137 .84706 Mdot
.46275 .43137 Mdot
.67059 .66275 Mdot
.98824 .99216 Mdot
.93333 .92941 Mdot
.52549 .44314 Mdot
.53725 .51373 Mdot
.89804 .90588 Mdot
.96078 .96078 Mdot
.85098 .8549 Mdot
.48235 .43922 Mdot
.7451 .7451 Mdot
.96863 .96471 Mdot
.8902 .8902 Mdot
.38824 .2549 Mdot
.72549 .72549 Mdot
.93333 .93725 Mdot
.90196 .9098 Mdot
.4902 .41569 Mdot
.83529 .83922 Mdot
.91765 .92941 Mdot
.77255 .18824 Mdot
.6902 .68627 Mdot
.94118 .94118 Mdot
.78039 .20784 Mdot
.69804 .67451 Mdot
.65882 .59608 Mdot
.49804 .32157 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002@3ooonf
o`000140oooo]_l0000:0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?oo
o`080?ooo`002@3oool01?l00000oooo0?ooo`3ooolg0?n007X0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0h0?ooogH0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolh0?n007T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`0i0?ooogD0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool01?l00000oooo0?ooo`3o
ooli0?n007P0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0j0?ooog@0X23`103o
ool00ol00000oooo0?ooo`080?ooo`002@3oool01?l00000oooo0?ooo`3ooolj0?n007L0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0k0?ooog<0X23`103oool00ol00000oooo0?oo
o`080?ooo`002@3oool01?l00000oooo0?ooo`3ooolj0?n007L0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0k0?ooog<0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool0
1?l00000oooo0?ooo`3oooll0?n007D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`0m0?ooog40X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool01?l00000oooo0?ooo`3o
oolm0?n007@0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0n0?ooog00X23`103o
ool00ol00000oooo0?ooo`080?ooo`002@3oool01?l00000oooo0?ooo`3oooln0?n007<0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0o0?ooofl0X23`103oool00ol00000oooo0?oo
o`080?ooo`002@3oool01?l00000oooo0?ooo`3ooolo0?n00780oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`100?ooofh0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool0
1?l00000oooo0?ooo`3ooom00?n00740oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`110?ooofd0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool01?l00000oooo0?ooo`3o
oom10?n00700oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`120?ooof`0X23`103o
ool00ol00000oooo0?ooo`080?ooo`002@3oool01?l00000oooo0?ooo`3ooom20?n006l0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`130?ooof/0X23`103oool00ol00000oooo0?oo
o`080?ooo`002@3oool01?l00000oooo0?ooo`3ooom20?n006l0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`130?ooof/0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolO0?n000D0oooo803oP01]0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0803oool50:0Pl200ooooJ@2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo00<0oooo7P3oP0060?oooal0oh00K03oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooo`80X23`7P3oool60:0Pl1l0ooooJ02P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00H0oooo6`3oP0080?oooah0oh00J`3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooo`D0X23`6`3oool80:0Pl1h0ooooI`2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00L0oooo6`3oP009
0?oooad0oh00JP3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooo`H0X23`6`3o
ool90:0Pl1d0ooooIP2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo00T0oooo6P3oP00:0?oooa`0oh00J@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooo`P0X23`6P3oool:0:0Pl1`0ooooI@2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo00/0oooo6P3oP00:0?oooa/0oh00J03oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooo`X0X23`6P3oool:0:0Pl1/0ooooI02P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00`0oooo6P3oP00:0?oooad0oh00I@3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooo`/0X23`6P3oool:0:0Pl1d0ooooH@2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00`0oooo6P3oP00:
0?oooad0oh00I@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooo`/0X23`6P3o
ool:0:0Pl1d0ooooH@2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo00l0oooo5`3oP00;0?oooad0oh00I03oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooo`h0X23`5`3oool;0:0Pl1d0ooooH02P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0100oooo5`3oP00<0?oooa`0oh00H`3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooo`l0X23`5`3oool<0:0Pl1`0ooooG`2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0180oooo5P3oP00=0?oooa/0oh00HP3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooa40X23`5P3oool=0:0Pl1/0ooooGP2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01<0oooo5P3oP00=
0?oooa/0oh00H@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooa80X23`5P3o
ool=0:0Pl1/0ooooG@2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo01H0oooo503oP00=0?oooa`0oh00G`3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?oooaD0X23`503oool=0:0Pl1`0ooooF`2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo01P0oooo4`3oP00=0?oooad0oh00G@3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?oooaL0X23`4`3oool=0:0Pl1d0ooooF@2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01T0oooo4P3oP00?0?oooa`0oh00G03oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooaP0X23`4P3oool?0:0Pl1`0ooooF02P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01T0oooo4P3oP00?
0?oooa`0oh00G03oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooaP0X23`4P3o
ool?0:0Pl1`0ooooF02P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo01/0oooo4P3oP00>0?oooad0oh00FP3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?oooaX0X23`4P3oool>0:0Pl1d0ooooEP2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo01`0oooo4P3oP00?0?oooa`0oh00F@3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?oooa/0X23`4P3oool?0:0Pl1`0ooooE@2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01l0oooo403oP00?0?oooa`0oh00F03oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooah0X23`403oool?0:0Pl1`0ooooE02P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0200oooo403oP00?
0?oooah0oh00E@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooal0X23`403o
ool?0:0Pl1h0ooooD@2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo0280oooo3P3oP00@0?oooah0oh00E03oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooob40X23`3P3oool@0:0Pl1h0ooooD02P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo02<0oooo3P3oP00@0?oooah0oh00D`3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooob80X23`3P3oool@0:0Pl1h0ooooC`2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02<0oooo3P3oP00@0?oooah0oh00D`3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob80X23`3P3oool@0:0Pl1h0ooooC`2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02H0oooo303oP00@
0?oooal0oh00D@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0X23`303o
ool@0:0Pl1l0ooooC@2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo02L0oooo2`3oP00A0?oooal0oh00D03oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooobH0X23`2`3ooolA0:0Pl1l0ooooC02P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo02T0oooo2P3oP00B0?ooob00oh00C@3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobP0X23`2P3ooolB0:0Pl200ooooB@2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02X0oooo2`3oP00A0?ooob00oh00C03oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0X23`2`3ooolA0:0Pl200ooooB02P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02d0oooo203oP00B
0?ooob40oh00BP3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob`0X23`203o
oolB0:0Pl240ooooAP2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo02l0oooo1`3oP00B0?ooob40oh00B@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooobh0X23`1`3ooolB0:0Pl240ooooA@2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0300oooo1P3oP00C0?ooob<0oh00AP3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobl0X23`1P3ooolC0:0Pl2<0oooo@P2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0300oooo1P3oP00C0?ooob<0oh00AP3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobl0X23`1P3ooolC0:0Pl2<0oooo@P2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0380oooo103oP00D
0?ooob@0oh00A03oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc40X23`103o
oolD0:0Pl2@0oooo@02P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo04/0oooo903oP0130?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooBP2P
8?0T0?ooocl0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1=
0?ooob@0oh00@@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oood`0X23`903o
oolm0:0Pl0@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0CP3ooolT
0?n00400oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom=0:0Pl2@0oooo?02P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo04l0oooo9P3oP00m
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooCP2P8?0V0?ooocT0X23`103o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1@0?ooobL0oh00>`3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooodl0X23`9`3ooolg0:0Pl0@0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0D@3ooolW0?n003X0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom@0:0Pl2L0oooo=P2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0540oooo9`3oP00j0?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooD02P8?0W0?ooocH0X23`103oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1B0?ooobP0oh00>03oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?oooe40X23`:03ooold0:0Pl0@0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0D`3ooolY0?n003H0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooomB0:0Pl2T0oooo<P2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo05D0oooo:@3oP00d0?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooE02P8?0Y0?oooc00X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1F0?ooobX0oh00<P3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?oooeD0X23`:P3oool^0:0Pl0@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0E`3ooolZ0?n00340oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oomF0:0Pl2X0oooo;@2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo05P0oooo;03oP00^0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooE`2P
8?0/0?ooobX0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1I
0?ooobd0oh00;03oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooeP0X23`;@3o
oolX0:0Pl0@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0F@3oool]
0?n002`0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooomH0:0Pl2d0oooo:02P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo05T0oooo;`3oP00Z
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooF02P8?0_0?ooobH0X23`103o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1J0?ooobl0oh00:@3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooeT0X23`;`3ooolU0:0Pl0@0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0G03oool`0?n002H0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooomK0:0Pl300oooo8P2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo05d0oooo<@3oP00T0?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooG02P8?0a0?ooob00X23`103oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1N0?oooc40oh008`3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?oooed0X23`<@3ooolO0:0Pl0@0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0G`3ooolb0?n00240oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooomN0:0Pl380oooo7@2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0600oooo=03oP00N0?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooG`2P8?0d0?oooaX0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1P0?oooc@0oh007P3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?oooel0X23`=03ooolJ0:0Pl0@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0H@3ooole0?n001`0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oomP0:0Pl3D0oooo602P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo0680oooo=P3oP00J0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooH@2P
8?0f0?oooaH0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1T
0?ooocD0oh006@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooof<0X23`=@3o
oolE0:0Pl0@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0I@3ooolg
0?n001H0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooomT0:0Pl3L0oooo4P2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06H0oooo>03oP00D
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooI@2P8?0h0?oooa00X23`103o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1W0?ooocT0oh004P3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooofH0X23`>@3oool>0:0Pl0@0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0I`3ooolj0?n00140oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooomV0:0Pl3X0oooo3@2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06L0oooo>P3oP00A0?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooIP2P8?0j0?ooo`d0X23`103oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1X0?oooc`0oh003P3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooofL0X23`?03oool:0:0Pl0@0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0J@3ooolm0?n000`0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooomX0:0Pl3d0oooo202P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo06X0oooo?P3oP00:0?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooJ@2P8?0n0?ooo`H0X23`103oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1/0?ooocl0oh001`3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooof/0X23`?`3oool30:0Pl0@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0K@3ooolo0?n000H0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oom/0:0Pl3l0oooo0P2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo06h0oooo@03oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooK@2P
8?140?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06l0oooo?`3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooKP2P8?130?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06l0oooo?`3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooKP2P8?130?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0700oooo?P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooK`2P8?120?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo0740oooo?@3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooL02P
8?110?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0780oooo?03oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooL@2P8?100?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0780oooo?03oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooL@2P8?100?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07@0oooo>P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooL`2P8?0n0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07D0oooo>@3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooM02P
8?0m0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07D0oooo>@3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooM02P8?0m0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07H0oooo>03oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooM@2P8?0l0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07L0oooo=`3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooMP2P8?0k0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07P0oooo=P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooM`2P
8?0j0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07T0oooo=@3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooN02P8?0i0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07X0oooo=03oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooN@2P8?0h0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07`0oooo<P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooN`2P8?0f0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07d0oooo<@3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooO02P
8?0e0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07d0oooo<@3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooO02P8?0e0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07d0oooo<@3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooO02P8?0e0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07h0oooo<03oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooO@2P8?0d0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07l0oooo;`3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooOP2P
8?0c0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0800oooo;P3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooO`2P8?0b0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0840oooo;@3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooP02P8?0a0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0880oooo;03oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooP@2P8?0`0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo08@0oooo:P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooP`2P
8?0^0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08@0oooo:P3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooP`2P8?0^0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08D0oooo:@3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooQ02P8?0]0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo08H0oooo:03oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooQ@2P8?0/0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo08H0oooo:03oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooQ@2P
8?0/0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08L0oooo9`3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooQP2P8?0[0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08P0oooo9P3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooQ`2P8?0Z0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo08T0oooo9@3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooR02P8?0Y0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo08X0oooo903oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooR@2P
8?0X0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08X0oooo903oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooR@2P8?0X0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08`0oooo8P3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooR`2P8?0V0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo08d0oooo8@3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooS02P8?0U0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07L0oooo0P3oP00E0?ooob00oh00103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooogH0X23`0P3ooolE0:0Pl2@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0M`3oool50?n001<0oooo7`3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooMP2P8?050?oooa<0X23`8`3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1h0?ooo`D0oh004P3ooolO0?n000@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooomg0:0Pl0D0oooo4P2P8?0S0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07P0oooo1P3oP00B0?oooah0oh00103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooogL0X23`1P3ooolB0:0Pl280oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0N@3oool60?n00180oooo7@3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooN02P8?060?oooa80X23`8@3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1i0?ooo`H0oh004P3ooolM0?n000@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooomh0:0Pl0H0oooo4P2P8?0Q0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07T0oooo203oP00B0?oooa/0oh00103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooogP0X23`203ooolB0:0Pl1l0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0NP3oool80?n00180oooo6P3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooN@2P8?080?oooa80X23`7P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1l0?ooo`P0oh004@3ooolI
0?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooomk0:0Pl0P0oooo4@2P
8?0M0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07d0oooo203oP00A
0?oooaP0oh00103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooog`0X23`203o
oolA0:0Pl1`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0O@3oool9
0?n00140oooo5`3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooO02P
8?090?oooa40X23`6`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1n
0?ooo`T0oh00403ooolG0?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oomm0:0Pl0T0oooo402P8?0K0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07l0oooo2@3oP00@0?oooaH0oh00103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooogh0X23`2@3oool@0:0Pl1X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0O`3oool90?n00100oooo5P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooOP2P8?090?oooa00X23`6P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`200?ooo`T0oh00403ooolE0?n000@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooomo0:0Pl0T0oooo402P8?0I0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0840oooo2@3oP00A0?oooa<0oh00103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?oooh00X23`2@3ooolA0:0Pl1L0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0P@3oool;0?n00100oooo4P3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooP02P8?0;0?oooa00X23`5P3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`220?ooo`/0oh00403ooolA0?n000@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon10:0Pl0/0oooo402P8?0E0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06`0oooo0P3oP00F0?ooo`/0oh003`3oool@
0?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom[0:0Pl080oooo5P2P
8?0;0?ooo`l0X23`503oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1/
0?ooo`<0oh005P3oool;0?n000l0oooo3`3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooJ`2P8?030?oooaH0X23`2`3oool?0:0Pl1<0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0K@3oool30?n001H0oooo2`3oP00>0?ooo`l0oh00103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooof`0X23`0`3ooolF0:0Pl0/0oooo3P2P
8?0C0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06d0oooo0`3oP00F
0?ooo`/0oh003P3oool?0?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oom/0:0Pl0<0oooo5P2P8?0;0?ooo`h0X23`4`3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1]0?ooo`@0oh005P3oool<0?n000d0oooo3P3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooK02P8?040?oooaH0X23`303oool=0:0Pl180oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0KP3oool40?n001D0oooo3@3oP00=
0?ooo`d0oh00103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooofd0X23`103o
oolE0:0Pl0d0oooo3@2P8?0A0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo06h0oooo1P3oP00D0?ooo`d0oh003P3oool;0?n000@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooom]0:0Pl0H0oooo502P8?0=0?ooo`h0X23`3`3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1_0?ooo`H0oh00503oool=0?n000h0oooo2P3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooKP2P8?060?oooa@0X23`3@3o
ool>0:0Pl0h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0K`3oool7
0?n001@0oooo3@3oP00>0?ooo`T0oh00103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooofh0X23`1`3ooolD0:0Pl0d0oooo3P2P8?0=0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0700oooo1`3oP00E0?ooo``0oh003P3oool80?n000@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom_0:0Pl0L0oooo5@2P8?0<0?ooo`h0X23`303o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1`0?ooo`L0oh005@3oool<
0?n000h0oooo203oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooK`2P
8?070?oooaD0X23`303oool>0:0Pl0`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0L03oool80?n001D0oooo303oP00=0?ooo`P0oh00103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooofl0X23`203ooolE0:0Pl0`0oooo3@2P8?0<0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0740oooo203oP00E0?ooo`d0oh00303oool7
0?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom`0:0Pl0P0oooo5@2P
8?0=0?ooo``0X23`2`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1a
0?ooo`T0oh005@3oool<0?n000d0oooo1P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooL02P8?090?oooaD0X23`303oool=0:0Pl0X0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0LP3oool80?n001D0oooo3@3oP00=0?ooo`D0oh00103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooog40X23`203ooolE0:0Pl0d0oooo3@2P
8?090?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0780oooo2P3oP00D
0?ooo`d0oh003P3oool30?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
ooma0:0Pl0X0oooo502P8?0=0?ooo`h0X23`1`3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1d0?ooo`T0oh00503oool=0?n000h0oooo0P3oP0040?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooL`2P8?090?oooa@0X23`3@3oool>0:0Pl0H0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0M03oool:0?n001D0oooo303oP00=
0?ooo`80oh00103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooog<0X23`2P3o
oolE0:0Pl0`0oooo3@2P8?060?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07@0oooo2P3oP00E0?ooo``0oh003@3oool20?n000@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooomc0:0Pl0X0oooo5@2P8?0<0?ooo`d0X23`1P3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`1e0?ooo`X0oh005@3oool<0?n000d0oooo00<0oh00
0?ooo`3oool00P3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooog@0X23`2P3o
oolE0:0Pl0`0oooo3@2P8?050?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07D0oooo2`3oP00E0?ooo``0oh004@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooog@0X23`2`3ooolE0:0Pl0`0oooo3@2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07H0oooo2`3oP00E0?ooo`d0oh003`3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooogD0X23`2`3ooolE0:0Pl0d0oooo2`2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07H0oooo303oP00E0?ooo`d0oh003P3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooogD0X23`303ooolE0:0Pl0d0oooo2P2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07L0oooo2`3oP00F
0?ooo`d0oh003@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooogH0X23`2`3o
oolF0:0Pl0d0oooo2@2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07L0oooo3@3oP00E0?ooo`d0oh00303oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooogH0X23`3@3ooolE0:0Pl0d0oooo202P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07P0oooo3@3oP00F0?ooo``0oh002`3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooogL0X23`3@3ooolF0:0Pl0`0oooo1`2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07P0oooo3@3oP00F0?ooo``0oh002`3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooogL0X23`3@3ooolF0:0Pl0`0oooo1`2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07P0oooo3P3oP00F
0?ooo``0oh002P3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooogL0X23`3P3o
oolF0:0Pl0`0oooo1P2P8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo07T0oooo3P3oP00E0?ooo`d0oh002@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooogP0X23`3P3ooolE0:0Pl0d0oooo1@2P8?040?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo07T0oooo3`3oP00E0?ooo`h0oh001`3oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooogP0X23`3`3ooolE0:0Pl0h0oooo0`2P8?040?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07X0oooo3`3oP00E0?ooo`h0oh001P3oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooogT0X23`3`3ooolE0:0Pl0h0oooo0P2P
8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07`0oooo3@3oP00F
0?ooo`h0oh001@3oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooog/0X23`3@3o
oolF0:0Pl0h0oooo00<0X23`0?ooo`3oool00P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`1l0?ooo`h0oh005P3oool=0?n000D0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooomk0:0Pl0h0oooo5P2P8?0=0?ooo`030:0Pl03oool0oooo0080oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0O@3oool?0?n001D0oooo3@3oP004
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooO02P8?0?0?oooaD0X23`4@3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1m0?ooo`l0oh005@3oool=
0?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oooml0:0Pl0l0oooo5@2P
8?0A0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo07d0oooo403oP00F
0?ooo`/0oh00103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooog`0X23`403o
oolF0:0Pl0l0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0OP3oool@
0?n001H0oooo2P3oP0040?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooO@2P
8?0@0?oooaH0X23`3P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1n
0?oooa40oh005P3oool90?n000@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oomm0:0Pl140oooo5P2P8?0=0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00P0
oooo00090?oookKo00004@3ooonfo`0000X0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo00090?oo
okKo00004@3ooonfo`0000X0oooo00090?ooo`Coogl00P3oool01oooO`00oooooomo003oooooogl0
0?ooooooO`00103oool00oooO`00oooooomo00020?ooo`03oomo003oool0oooo02/0oooo00?oogl0
0?ooo`3oool04`3oool5oomo02X0oooo00?oogl00?ooo`3oool0:@3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo00`0oooo00?oX23`0?ooo`3oool0903oool00onP8?00oooo0?ooo`1l
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`Koogl03P3oool00oooO`00oooooomo00150?oo
o`Coogl0E@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo04/0oooo00?oX23`0?oo
o`3oool07`3oool00onP8?00oooo0?ooo`120?ooo`03o`00003oool0oooo00P0oooo00090?ooo`Co
ogl00`3oool01?ooO`00oooo0?ooooooO`020?ooo`03oomo003oool0oooo00H0oooo00?oogl00?oo
o`3oool0A@3oool2oomo00/0oooo00?oogl00?ooo`3oool0A`3oool00ol00000oooo0?ooo`0?0?oo
o`03oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3oool01P3oool00onP8?00oooo0?ooo`030?oo
o`03oj0Pl03oool0oooo02/0oooo00?oX23`0?oooonP8?00:@3oool00onP8?00oooo0?ooo`110?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`Googl000D0oooooomo003oool0oooooomo002[0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?oo
o`002@3oool6oomo0080oooo00?oogl00?ooooooO`00FP3oool00oooO`00oooo0?ooo`1=0?ooo`03
o`00003oool0oooo00l0oooo0_nP8?000`3oooooX23`0?ooo`1<0?ooo`05oj0Pl03oool0oooo0?oo
oonP8?00103oool00onP8?00oooo0?ooo`1H0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`[o
ogl00P3oool00oooO`00oooo0?ooo`070?ooo`03oomo003oool0oooo00@0oooo00?oogl00?ooo`3o
ool04@3oool00oooO`00oooo0?ooo`0`0?ooo`03oomo003oool0oooo04h0oooo00?o00000?ooo`3o
ool03`3oool5oj0Pl0<0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooo0?ooo`02oj0Pl2P0
oooo00?oX23`0?ooo`3oool03`3oool00onP8?00oooo0?ooo`0K0?ooo`03oj0Pl03oool0oooo03l0
oooo00?o00000?ooo`3oool0203oool000T0oooo2oooO`2Z0?ooo`03o`00003oool0oooo00l0oooo
1_nP8?0D0?ooo`03oj0Pl03oool0oooo07D0oooo00?oX23`0?ooo`3oool0803oool00ol00000oooo
0?ooo`080?ooo`002@3oool>oomo00040?ooooooO`00oooooomo0240oooo00?oogl00?ooo`3oool0
O`3oool00ol00000oooo0?ooo`0?0?ooo`;oX23`00<0oooooj0Pl?nP8?000_nP8?000`3oooooX23`
0?ooo`190?ooo`03oj0Pl03oool0oooo01D0oooo00?oX23`0?ooo`3oool0A`3oool00ol00000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`06oomo00050?ooooooO`3oogl00?ooooooO`00
9@3oool00oooO`00oooo0?ooo`180?ooo`03oomo003oool0oooo01P0oooo00Coogl00?ooo`3ooooo
ogl0603oool00ol00000oooo0?ooo`0?0?ooo`;oX23`00<0oooooj0Pl?nP8?000_nP8?180?ooo`03
oj0Pl03oool0oooo02@0oooo00?oX23`0?ooo`3oool0?03oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`0;oomo00030?ooooooO`00oooo03T0oooo00?oogl00?ooo`3oool0
8@3oool00oooO`00oooo0?ooo`090?ooo`03oomo003oool0oooo03P0oooo00?o00000?ooo`3oool0
3`3oool00ol0003oX23`0?ooo`06oj0Pl0070?oooonP8?00oooo0?oooonP8?00oooooj0Pl00M0?oo
o`03oj0Pl03oool0oooo06D0oooo00?oX23`0?oooonP8?007@3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`020?ooo`Koogl000<0oooooomo0?ooO`000_ooO`1/0?ooo`03
oomo003oool0oooo03H0oooo00?o00000?ooo`3oool03`3oool00ol0003oX23`oj0Pl004oj0Pl003
0?oooonP8?00oooo00H0oooo0_nP8?1;0?ooo`03oj0Pl03oool0oooo05D0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00Ko00000?ooo`3oool0oooooomo003oool3oomo00030?ooooooO`3oogl0
0080oooo1?ooO`0Y0?ooo`03oomo003oool0oooo03/0oooo00?oogl00?ooo`3oool0>@3oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooooj0Pl080oooo0onP8?000`3oooooX23`0?ooo`08
0?ooo`03oj0Pl03oool0oooo0480oooo00?oX23`0?ooo`3oool0F@3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`030?ooo`[oogl000<0oooooomo003oool0603oool00ooo
O`00oooo0?ooo`0U0?ooo`03oomo003oool0oooo05l0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3oool6oj0Pl080oooo00CoX23`0?ooo`3oooooX23`Y@3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`030?ooo`03oomo003oooooogl000Coogl00P3oool0
0oooO`00oooo0?ooo`1X0?ooo`03oomo003oool0oooo03P0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`020?ooo`03oj0Pl03oooooX23`00?oX23`403oool00onP8?00oooo0?ooo`0<
0?ooo`03oj0Pl03oool0oooo0500oooo00?oX23`0?ooo`3oool0=@3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`050?ooo`Soogl000<0oooooomo003oool01@3oool01?oo
O`00oooo0?ooooooO`240?ooo`03oomo003oool0oooo0180oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3oool7oj0Pl0<0oooo0_nP8?020?ooo`03oj0Pl03oool0oooo00H0oooo00?o
X23`0?ooo`3oool07`3oool00onP8?00oooo0?ooo`0T0?ooo`03oj0Pl03oool0oooo00@0oooo00?o
X23`0?ooo`3oool04@3oool00onP8?00oooo0?ooo`0c0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo00P0oooo1_ooO`020?ooo`03oomo003oool0oooo00X0oooo00?oogl0
0?ooo`3oool0TP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0080oooo00SoX23`
0?ooo`3oooooX23`0?oooonP8?00oooooj0Pl:P0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool01`3oool00oooO`00oooo0?ooo`04oomo0:@0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`030?ooo`04oj0Pl03oooooX23`oj0Pl080oooo0_nP8?060?ooo`03
oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0903oool00onP8?00oooo0?ooo`0Q0?ooo`03
oj0Pl03oool0oooo04h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
0`3oool01?ooO`00oooo0?ooo`3oool8oomo0080oooo0oooO`1Z0?ooo`03oomo003oool0oooo0340
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`020?ooo`;oX23`00<0oooooj0Pl03o
ool01_nP8?090?ooo`03oj0Pl03oool0oooo09T0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool01@3oool00oooO`00oooooomo00020?ooo`03oomo003oooooogl000@0oooo
00?oogl00?ooo`3oool0WP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00L0oooo
0_nP8?00103oooooX23`0?oooonP8?050?ooo`03oj0Pl03oool0oooo09d0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0203oool2oomo00030?ooooooO`3oogl000;oogl0
0P3oool00oooO`00oooooomo000V0?ooo`03oomo003oool0oooo0480oooo00?oogl00?ooo`3oool0
<03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0080oooo00?oX23`0?ooo`3oool0
0P3oool2oj0Pl0030?oooonP8?00oooo06H0oooo00?oX23`0?ooo`3oool0?@3oool00ol00000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0<0?ooo`03oomo003oool0oooo00?oogl0103o
ool00oooO`00oooo0?ooo`030?ooo`03oomo003oool0oooo09<0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`080?ooo`03oj0Pl03oooooX23`00P0oooo00?oX23`0?ooo`3oool0W03o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0:0?ooo`03oomo003oool0
oooo00<0oooo1?ooO`070?ooo`03oomo003oool0oooo09@0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`0:0?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool02P3oool0
0onP8?00oooo0?ooo`2A0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
00`0oooo00Googl00?ooooooO`00oooooomo00020?ooo`05oomo003oool0oooo0?ooooooO`000P3o
ool00oooO`00oooo0?ooo`1W0?ooo`03oomo003oool0oooo02/0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`060?ooo`04oj0Pl03oool0oooo0?ooo`;oX23`1@3oool2oj0Pl080oooo
00CoX23`0?ooo`3oooooX23`3P3oool00onP8?00oooo0?ooo`0@0?ooo`03oj0Pl03oool0oooo03H0
oooo00?oX23`0?ooo`3oool0?03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`0=0?ooo`;oogl0103oool2oomo00040?ooooooO`00oooooomo09T0oooo00?o00000?ooo`3o
ool03`3oool00ol00000oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00?oX23`0`3oool00onP8?00
oooo0?ooo`0@0?ooo`05oj0Pl03oool0oooo0?oooonP8?00RP3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`0=0?ooo`03oomo003oool0oooo00?oogl00P3oool2oomo0005
0?ooooooO`3oogl00?ooooooO`00UP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
00T0oooo00KoX23`0?ooo`3oool0oooooj0Pl03oool3oj0Pl080oooo0_nP8?2L0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo00`0oooo00?oogl00?ooo`3oool00P3oool0
0oooO`00oooo0?ooo`020?ooo`03oomo003oooooogl006T0oooo00?oogl00?ooo`3oool0;@3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0080oooo00?oX23`0?ooo`3oool02@3oool0
1_nP8?00oooooj0Pl?nP8?00oooooj0Pl9h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool03`3oool00oooO`00oooo0?ooo`020?ooo`05oomo003oool0oooo0?ooooooO`00
103oool00oooO`00oooooomo00020?ooo`03oomo003oool0oooo08d0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`090?ooo`03oj0Pl03oool0oooo00L0oooo0_nP8?0U0?ooo`03oj0P
l03oool0oooo07D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06`3o
ool00oooO`00oooooomo001X0?ooo`03oomo003oool0oooo02T0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0K0?ooo`03oj0Pl03oool0oooo09@0oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool04@3oool00oooO`00oooo0?ooo`020?ooo`05oomo003oool0
oooo0?ooooooO`000P3oool00oooO`00oooo0?ooo`2B0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool02`3oool00onP8?00oooo0?ooo`1F0?ooo`03oj0Pl03oool0oooo04/0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool03P3oool01?ooO`00oooo0?oooooo
O`080?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?oo
o`2:0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0103oool00onP8?00oooo0?oo
o`0>0?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3oool0203oool00onP8?00oooo0?oo
o`0B0?ooo`03oj0Pl03oool0oooo0780oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool07`3oool00oooO`00oooo0?ooo`2@0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool04@3oool01?nP8?00oooooj0Pl?nP8?0O0?ooo`03oj0Pl03oool0oooo07/0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool04`3oool00oooO`00oooo0?ooo`04
0?ooo`05oomo003oool0oooo0?ooooooO`00103oool00oooO`00oooo0?ooo`040?ooo`03oomo003o
ool0oooo01`0oooo00?oogl00?ooo`3oool0IP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo00L0oooo00?oX23`0?ooo`3oool01`3oool2oj0Pl080oooo0_nP8?040?ooo`03oj0Pl03o
ool0oooo00@0oooo00CoX23`0?ooo`3oooooX23`1P3oool00onP8?00oooo0?ooo`0<0?ooo`03oj0P
l03oooooX23`07@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool07`3o
ool01?ooO`00oooo0?ooooooO`2?0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
103oool2oj0Pl0<0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooooj0Pl0030?ooo`03oj0P
l03oool0oooo00<0oooo00CoX23`0?ooo`3oooooX23`0`3oool2oj0Pl8`0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool07@3oool01?ooO`00oooo0?ooooooO`0b0?ooo`03
oomo003oool0oooo05`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0<0?ooo`03
oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool00P3oool01OnP8?00oooooj0Pl03oooooX23`
00<0oooo00?oX23`0?ooo`3oool0T@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0C0?ooo`03oomo003oool0oooo00T0oooo0_ooO`00103oooooogl00?ooooooO`0;0?oo
o`03oomo003oool0oooo01L0oooo00?oogl00?ooo`3oool0I@3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo00P0oooo00?oX23`0?oooonP8?001P3oool00onP8?00oooo0?ooo`02oj0P
l0h0oooo00?oX23`0?ooo`3oool03P3oool00onP8?00oooo0?ooo`080?ooo`03oj0Pl03oool0oooo
04D0oooo00?oX23`0?ooo`3oool09`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0S0?ooo`06oomo003oool0oooooomo003oooooogl0R@3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo00D0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooo0?ooo`0A
0?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?ooo`3oool02`3oool01OnP8?00oooo0?ooo`3o
ooooX23`02P0oooo00?oX23`0?ooo`3oool0A`3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`0G0?ooo`;oogl00P3oool00oooO`00oooo0?ooo`070?ooo`05oomo003ooooo
ogl00?ooooooO`008@3oool00oooO`00oooo0?ooo`1T0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool01@3oool01OnP8?00oooo0?ooo`3oooooX23`0080oooo00CoX23`0?ooo`3oool0
oooo0_nP8?000`3oooooX23`0?ooo`050?ooo`05oj0Pl03oool0oooo0?oooonP8?00403oool00onP
8?00oooo0?ooo`1H0?ooo`03oj0Pl03oool0oooo02D0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool07@3oool00oooO`00oooo0?ooo`040?ooo`03oomo003oool0oooo0080
oooo00Coogl00?ooo`3oooooogl0Q@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
00/0oooo00?oX23`0?ooo`3oool04`3oool00onP8?00oooo0?ooo`1V0?ooo`03oj0Pl03oool0oooo
02D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool07`3oool00oooO`00
oooo0?ooo`030?ooo`03oomo003oool0oooo00@0oooo00?oogl00?ooo`3oool0HP3oool00oooO`00
oooo0?ooo`0N0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05`3oool01OnP8?00
oooo0?ooo`3oooooX23`0080oooo00?oX23`0?ooo`3oool0103oool00onP8?00oooo0?ooo`0=0?oo
o`03oj0Pl03oool0oooo07X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool05`3oool2oomo00<0oooo00Coogl00?ooo`3oooooogl0103oool00oooO`00oooo0?ooo`04oomo
00D0oooo0_ooO`040?ooo`03oomo003oool0oooo07T0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`030?ooo`03oj0Pl03oool0oooo00D0oooo00?oX23`0?ooo`3oool02`3oool2oj0P
l0X0oooo0onP8?050?ooo`03oj0Pl03oool0oooo01D0oooo00?oX23`0?ooo`3oool0503oool00onP
8?00oooo0?ooo`1C0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02<0
oooo00Googl00?ooo`3oool0oooooomo00060?ooo`03oomo003oool0oooo0840oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0B0?ooo`03oj0Pl03oool0oooo00<0oooo00?oX23`0?oo
o`3oool0103oool00onP8?00oooo0?ooo`2@0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo02<0oooo0_ooO`060?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3o
ool0603oool00oooO`00oooo0?ooo`1T0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool03P3oool00onP8?00oooo0?ooo`0<0?ooo`03oj0Pl03oool0oooo0080oooo00CoX23`0?ooo`3o
ooooX23`1P3oool00onP8?00oooo0?ooo`0;0?ooo`03oj0Pl03oool0oooo07D0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0:03oool2oomo00030?ooooooO`00oooo08D0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`070?ooo`06oj0Pl03oool0oooooj0P
l03oooooX23`5P3oool01OnP8?00oooo0?ooo`3oooooX23`01D0oooo00GoX23`0?ooo`3oool0oooo
oj0Pl01`0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0200oooo00?o
ogl00?ooo`3oool00`3oool01?ooO`00oooo0?ooooooO`060?ooo`03oomo003oool0oooo01P0oooo
00?oogl00?ooooooO`00I03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01@0oooo
00CoX23`0?ooo`3oooooX23`0`3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo00@0
oooo00?oX23`0?oooonP8?002`3oool00onP8?00oooo0?ooo`020?ooo`03oj0Pl03oool0oooo0700
oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0<@3oool00oooO`00oooo
0?ooo`020?ooo`05oomo003oool0oooo0?ooooooO`00M`3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo0180oooo00?oX23`0?ooo`3oool02P3oool00onP8?00oooo0?ooo`0J0?ooo`03
oj0Pl03oool0oooo07<0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
9`3oool00oooO`00oooo0?ooo`060?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool0
2`3oool00oooO`00oooo0?ooo`1/0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
8P3oool01OnP8?00oooo0?ooo`3oooooX23`00d0oooo00?oX23`0?ooo`3oool01P3oool01?nP8?00
oooooj0Pl?nP8?1a0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02@0
oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`020?ooo`06oomo003oool0oooooomo
003oooooogl04P3oool00oooO`00oooo0?ooo`070?ooo`03oomo003oool0oooo05l0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`050?ooo`03oj0Pl03oooooX23`00L0oooo00?oX23`
0?ooo`3oool0103oool00onP8?00oooo0?ooo`060?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo00?o
X23`0?oooonP8?000_nP8?030?ooo`03oj0Pl03oooooX23`00`0oooo1?nP8?001@3oooooX23`oj0P
l03oooooX23`06`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0;P3o
ool00oooO`00oooo0?ooo`070?ooo`03oomo003oool0oooo00`0oooo00?oogl00?ooo`3oool0J03o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02<0oooo00?oX23`0?ooo`3oool01P3o
ool2oj0Pl080oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`090?ooo`03oj0Pl03o
ooooX23`06h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool09@3oool0
0oooO`00oooo0?ooo`080?ooo`03oomo003oool0oooo01<0oooo00?oogl00?ooo`3oool0:P3oool0
0oooO`00oooo0?ooo`0l0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool04P3oool0
0onP8?00oooo0?ooo`0G0?ooo`;oX23`2`3oool00onP8?00oooo0?ooo`0:0?ooo`04oj0Pl03oool0
oooooj0Pl6P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool09P3oool0
0oooO`00oooo0?ooo`030?ooo`;oogl0103oool00oooO`00oooo0?ooo`0:0?ooo`04oomo003oool0
oooooomo00@0oooo00?oogl00?ooo`3oool0J03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo01h0oooo00?oX23`0?ooo`3oool01`3oool02OnP8?00oooo0?ooo`3oooooX23`0?oooonP
8?00oooooj0Pl00=0?ooo`04oj0Pl03oool0oooooj0Pl080oooo00CoX23`0?ooo`3oooooX23`JP3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0Y0?ooo`03oomo003oool0
oooo0100oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0
oooo06T0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0Y0?ooo`03oj0Pl03oool0
oooo0080oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`040?ooo`03oj0Pl03oool0
oooo00;oX23`0`3oool00onP8?00oooo0?ooo`1]0?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo02`0oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?ooo`020?oo
o`03oomo003oool0oooo00H0oooo00Googl00?ooooooO`00oooooomo001]0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool03@3oool00onP8?00oooo0?ooo`0D0?ooo`03oj0Pl03oool0
oooo0080oooo00CoX23`0?oooonP8?3oX23`0P3oool01OnP8?00oooo0?ooo`3oooooX23`00<0oooo
0_nP8?060?ooo`0:oj0Pl03oooooX23`oj0Pl03oooooX23`0?oooonP8?00oooooj0Pl6T0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0;03oool00oooO`00oooo0?ooo`09
0?ooo`03oomo003oooooogl000/0oooo00?oogl00?ooo`3oool0J@3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo00T0oooo00?oX23`0?ooo`3oool05`3oool00onP8?00oooo0?ooo`03
0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0403oool01OnP8?00oooo0?oooonP
8?00oooo00;oX23`7P3oool00onP8?00oooo0?ooo`190?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo03<0oooo00?oogl00?ooo`3oool0403oool2oomo00d0oooo00?oogl0
0?ooo`3oool0FP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00l0oooo00GoX23`
0?ooo`3oool0oooooj0Pl00I0?ooo`;oX23`00D0oooooj0Pl03oool0oooooj0Pl0060?ooo`03oj0P
l03oool0oooo00D0oooo00OoX23`0?oooonP8?00oooooj0Pl03oooooX23`00L0oooo00?oX23`0?oo
o`3oool0G`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0X0?ooo`03
oomo003oool0oooo00/0oooo00Googl00?ooo`3oool0oooooomo000@0?ooo`03oomo003oool0oooo
00D0oooo00?oogl00?ooo`3oool0G03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
01h0oooo00?oX23`0?ooo`3oool03`3oool01?nP8?00oooo0?oooonP8?020?ooo`03oj0Pl03oool0
oooo00<0oooo00?oX23`0?ooo`3oool0L`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`110?ooo`03oomo003oool0oooo00@0oooo0_ooO`1X0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0103oool00onP8?00oooo0?ooo`0W0?ooo`04oj0Pl03oool0oooo
0?ooo`;oX23`00@0oooooj0Pl03oool0oooo0onP8?00103oooooX23`0?oooonP8?050?ooo`04oj0P
l03oool0oooooj0Pl6X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
;P3oool00oooO`00oooooomo00020?ooo`03oomo003oooooogl000l0oooo00?oogl00?ooo`3oool0
0_ooO`080?ooo`03oomo003oooooogl005d0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`080?ooo`05oj0Pl03oool0oooo0?oooonP8?003@3oool00onP8?00oooo0?ooo`050?ooo`?o
X23`2@3oool2oj0Pl0030?oooonP8?00oooo00;oX23`203oool00onP8?00oooooj0Pl0040?ooo`?o
X23`J`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0^0?ooo`03oomo
003oool0oooo00/0oooo00?oogl00?ooo`3oool02`3oool00oooO`00oooo0?ooo`1U0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0;P3oool3oj0Pl080oooo00?oX23`0?ooo`3oool0
1@3oool2oj0Pl0H0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`1W0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03@0oooo00?oogl00?ooooooO`000`3o
ool00oooO`00oooo0?ooo`070?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool02P3o
ool00oooO`00oooo0?ooo`1I0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0303o
ool00onP8?00oooo0?ooo`0L0?ooo`04oj0Pl03oooooX23`0?ooo`;oX23`0P3oool2oj0Pl0D0oooo
00?oX23`0?ooo`3oool00`3oool2oj0Pl0030?oooonP8?00oooo00@0oooo00?oX23`0?ooo`3oool0
0P3oool00onP8?00oooo0?ooo`060?ooo`03oj0Pl03oool0oooo05P0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool0?03oool2oomo00@0oooo00?oogl00?ooo`3oool00_oo
O`020?ooo`03oomo003oool0oooo00/0oooo00?oogl00?ooo`3oool0F03oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo0100oooo00?oX23`0?ooo`3oool07`3oool3oj0Pl0/0oooo00?o
X23`0?ooo`3oool01@3oool2oj0Pl0<0oooo00?oX23`0?ooo`3oool0HP3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`0e0?ooo`03oomo003oooooogl000L0oooo00?oogl0
0?ooo`3oool00`3oool00oooO`00oooo0?ooo`020?ooo`?oogl000<0oooooomo003oool0HP3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0oooo00?oX23`0?ooo`3oool04@3oool0
0onP8?00oooo0?ooo`040?ooo`05oj0Pl03oool0oooooj0Pl03oool00_nP8?030?ooo`;oX23`1@3o
ool00onP8?00oooo0?ooo`02oj0Pl080oooo00GoX23`0?ooo`3oool0oooooj0Pl01U0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0[0?ooo`;oX23`1@3oool01?nP8?00oooo0?oooonP8?020?ooo`;oX23`
0`3oool00onP8?00oooo0?ooo`1b0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo03T0oooo0_ooO`0;0?ooo`04oomo003oool0oooooomo00@0oooo00?oogl00?ooo`3oool0
H@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01T0oooo00CoX23`0?ooo`3ooooo
X23`3`3oool00onP8?00oooooj0Pl00:0?ooo`03oj0Pl03oool0oooo00<0oooo0onP8?0>0?ooo`03
oj0Pl03oool0oooo05l0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
?03oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo00@0oooo00Coogl00?ooo`3oool0
oooo0oooO`00103oooooogl0oomo0?ooO`020?ooo`03oomo003oooooogl005X0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0C0?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?oo
o`3oool05`3oool00onP8?00oooooj0Pl0040?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?oo
o`3oool0J@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0i0?ooo`03
oomo003oool0oooo0080oooo0_ooO`000`3oooooogl00?ooo`0=0?ooo`03oomo003oool0oooo05l0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0L0?ooo`03oj0Pl03oool0oooo00l0
oooo00?oX23`0?ooo`3oool0103oool2oj0Pl0D0oooo00?oX23`0?ooo`3oool00P3oool01?nP8?00
oooooj0Pl?nP8?1]0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03`0
oooo00?oogl00?ooo`3oool00oooO`030?ooo`03oomo003oool0oooo0080oooo00Coogl00?ooo`3o
ool0oooo0_ooO`000`3oooooogl0oomo00090?ooo`03oomo003oool0oooo05<0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0D0?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?oo
o`3oool02`3oool00onP8?00oooooj0Pl0090?ooo`05oj0Pl03oool0oooo0?oooonP8?00103oool0
0onP8?00oooo0?ooo`07oj0Pl0030?oooonP8?3oX23`00D0oooo00?oX23`0?ooo`3oool0G`3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0o0?ooo`03oomo003oool0oooo
00@0oooo00Googl00?ooo`3oool0oooooomo00030?ooo`03oomo003oool0oooo0640oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo01@0oooo00?oX23`
0?ooo`3oool03@3oool00onP8?00oooo0?ooo`0:0?ooo`03oj0Pl03oool0oooo00/0oooo00?oX23`
0?ooo`3oool0G`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0d0?oo
o`03oomo003oool0oooo01@0oooo00?oogl00?ooo`3oool00_ooO`000`3oooooogl0oomo00020?oo
o`03oomo003oool0oooo05X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0j0?oo
o`04oj0Pl03oooooX23`oj0Pl0<0oooo00CoX23`0?oooonP8?3oX23`1`3oool00onP8?00oooooj0P
l01S0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03l0oooo00Googl0
0?ooo`3oool0oooooomo00050?ooo`03oomo003oool0oooo0080oooo1_ooO`1N0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool05`3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03o
ool0oooo00l0oooo00KoX23`0?oooonP8?00oooooj0Pl03oool2oj0Pl0H0oooo0_nP8?000`3ooooo
X23`oj0Pl004oj0Pl0030?oooonP8?00oooo0080oooo00GoX23`0?ooo`3oool0oooooj0Pl00?0?oo
o`;oX23`C@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1@0?ooo`05
oomo003oool0oooo0?ooooooO`00103oool01?ooO`00oooo0?ooooooO`1E0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0903oool01?nP8?00oooo0?oooonP8?070?ooo`03oj0Pl03o
ool0oooo00X0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`070?ooo`03oj0Pl03o
ooooX23`0640oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0@P3oool2
oomo00D0oooo00Coogl00?ooooooO`3oogl00`3oool3oomo00@0oooo00?oogl00?ooo`3oool0F03o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01@0oooo00GoX23`0?oooonP8?00oooo
oj0Pl0040?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?ooo`3oool03P3oool3oj0Pl0040?oo
oonP8?00oooo0?ooo`GoX23`00<0oooooj0Pl?nP8?001_nP8?020?ooo`03oj0Pl03oool0oooo0100
oooo00?oX23`0?ooo`3oool0C03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`110?ooo`03oomo003oool0oooo00;oogl02P3oool00oooO`00oooo0?ooo`040?ooo`03oomo
003oool0oooo05P0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0O0?ooo`03oj0P
l03oool0oooo00D0oooo00?oX23`0?ooo`3oool06@3oool00onP8?00oooo0?ooo`03oj0Pl0<0oooo
00?oX23`0?oooonP8?001P3oool00onP8?00oooo0?ooo`090?ooo`03oj0Pl03oool0oooo04h0oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0?P3oool01OooO`00oooo0?oo
o`3oooooogl000d0oooo0_ooO`050?ooo`03oomo003oool0oooo05P0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0K0?ooo`05oj0Pl03oool0oooo0?oooonP8?00703oool2oj0Pl0<0
oooo00?oX23`0?ooo`3oool00P3oool4oj0Pl0030?oooonP8?00oooo00<0oooo00?oX23`0?ooo`3o
ool0G`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`150?ooo`07oomo
003oool0oooo0?ooooooO`00oooooomo00060?ooo`03oomo003oool0oooo0140oooo00?oogl00?oo
o`3oool0B@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00h0oooo00?oX23`0?oo
o`3oool04P3oool00onP8?00oooo0?ooo`0<0?ooo`CoX23`2@3oool01?nP8?00oooooj0Pl?nP8?03
0?ooo`?oX23`00@0oooooj0Pl03oool0oooo0onP8?0B0?ooo`03oj0Pl03oool0oooo00<0oooo00?o
X23`0?ooo`3oool0A`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0o
0?ooo`;oogl0L@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00h0oooo00?oX23`
0?ooo`3oool00P3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo02/0oooo00?oX23`
0?ooo`3oool00_nP8?090?ooo`03oj0Pl03oool0oooo00X0oooo0_nP8?1>0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo04H0oooo00?oogl00?ooo`3oool00oooO`060?oo
o`;oogl000<0oooooomo003oool00`3oool00oooO`00oooo0?ooo`1E0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool03P3oool00onP8?00oooo0?ooo`0H0?ooo`03oj0Pl03oool0oooo
01D0oooo00KoX23`0?ooo`3oooooX23`0?oooonP8?020?ooo`;oX23`00<0oooooj0Pl?nP8?000_nP
8?020?ooo`04oj0Pl03oool0oooooj0Pl0H0oooo00?oX23`0?ooo`3oool0103oool00onP8?00oooo
0?ooo`050?ooo`03oj0Pl03oool0oooo04@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0B03oool2oomo00<0oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?oo
o`1L0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0603oool00onP8?00oooo0?oo
o`0E0?ooo`03oj0Pl03oool0oooo00h0oooo00?oX23`0?oooonP8?000P3oool00onP8?00oooo0?oo
o`03oj0Pl080oooo0_nP8?0>0?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool0C03o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1A0?ooo`05oomo003oool0
oooo0?ooooooO`00G03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03d0oooo00?o
X23`0?ooo`3oool0103oool01?nP8?00oooo0?oooonP8?050?ooo`;oX23`103oool00onP8?00oooo
0?ooo`090?ooo`04oj0Pl03oool0oooooj0Pl4l0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0CP3oool00oooO`00oooooomo00020?ooo`03oomo003oooooogl005`0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0B0?ooo`03oj0Pl03oool0oooo00P0oooo
00?oX23`0?oooonP8?002P3oool00onP8?00oooo0?ooo`030?ooo`05oj0Pl03oool0oooo0?oooonP
8?004@3oool2oj0Pl0030?oooonP8?00oooo00CoX23`00@0oooooj0Pl?nP8?3oX23`203oool00onP
8?00oooo0?ooo`020?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo00?oX23`0?ooo`3oool0B03oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1@0?ooo`03oomo003oool0oooo
05l0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0l0?ooo`03oj0Pl03oool0oooo
00<0oooo00?oX23`0?ooo`3oool00_nP8?040?ooo`03oj0Pl03oooooX23`00;oX23`103oool2oj0P
l0<0oooo00?oX23`0?ooo`3oool02`3oool01?nP8?00oooo0?ooo`3oool2oj0Pl0030?oooonP8?00
oooo0480oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0C03oool00ooo
O`00oooooomo00060?ooo`04oomo003oooooogl0oomo00T0oooo00?oogl00?ooo`3oool0C@3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01h0oooo00?oX23`0?ooo`3oool00P3oool0
1OnP8?00oooo0?ooo`3oooooX23`01h0oooo00CoX23`0?ooo`3oool0oooo0_nP8?020?ooo`?oX23`
1@3oool01onP8?00oooo0?ooo`3oooooX23`0?oooonP8?001P3oool00onP8?00oooooj0Pl0030?oo
o`03oj0Pl03oool0oooo04H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0100oooo00CoX23`0?ooo`3o
ooooX23`2`3oool00onP8?00oooo0?ooo`0D0?ooo`03oj0Pl03oool0oooo0100oooo00?oX23`0?oo
oonP8?000P3oool3oj0Pl0030?oooonP8?3oX23`00D0oooo00CoX23`0?ooo`3oooooX23`0P3oool2
oj0Pl540oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0AP3oool00ooo
O`00oooo0?ooo`070?ooo`03oomo003oooooogl000H0oooo00?oogl00?ooooooO`00EP3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01d0oooo00?oX23`0?ooo`3oool0103oool00onP
8?00oooo0?ooo`0>0?ooo`03oj0Pl03oool0oooo00@0oooo00GoX23`0?ooo`3oool0oooooj0Pl009
0?ooo`03oj0Pl03oool0oooo00<0oooo0onP8?020?ooo`?oX23`0P3oool00onP8?00oooooj0Pl002
0?ooo`03oj0Pl03oooooX23`00H0oooo00?oX23`0?ooo`3oool0A`3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`1=0?ooo`;oogl0103oool01?ooO`00oooo0?ooooooO`03
0?ooo`03oomo003oool0oooo05D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0O
0?ooo`03oj0Pl03oool0oooo00`0oooo00?oX23`0?ooo`3oool0703oool00onP8?00oooo0?ooo`03
oj0Pl0P0oooo00?oX23`0?ooo`3oool01`3oool01OnP8?00oooo0?ooo`3oooooX23`04P0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0FP3oool00oooO`00oooo0?ooo`1E
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0503oool00onP8?00oooo0?ooo`0V
0?ooo`03oj0Pl03oool0oooo00/0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooooj0Pl002
0?ooo`03oj0Pl03oooooX23`00<0oooo00?oX23`0?ooo`3oool01@3oool00onP8?00oooo0?ooo`06
0?ooo`03oj0Pl03oool0oooo04<0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0D`3oool00oooO`00oooooomo00030?ooo`;oogl01P3oool00oooO`00oooo0?ooo`1>0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05@3oool2oj0Pl0/0oooo00?oX23`0?oo
o`3oool05@3oool01?nP8?00oooo0?oooonP8?0;0?ooo`;oX23`0`3oool00onP8?00oooooj0Pl002
0?ooo`04oj0Pl03oooooX23`0?ooo`;oX23`00@0oooooj0Pl?nP8?3oX23`2@3oool2oj0Pl0P0oooo
00?oX23`0?ooo`3oool0?`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`1E0?ooo`04oomo003oool0oooooomo0080oooo00?oogl00?ooo`3oool05P3oool00oooO`00oooo
0?ooo`0k0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool03P3oool00onP8?00oooo
0?ooo`0C0?ooo`04oj0Pl03oool0oooooj0Pl1`0oooo00?oX23`0?oooonP8?002`3oool00onP8?00
oooooj0Pl0020?ooo`;oX23`2P3oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo04H0
oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0G03oool01OooO`00oooo
0?ooo`3oooooogl00540oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0I0?ooo`03
oj0Pl03oool0oooo00T0oooo00?oX23`0?ooo`3oool03@3oool01OnP8?00oooo0?ooo`3oooooX23`
00H0oooo00?oX23`0?ooo`3oool01`3oool01OnP8?00oooo0?ooo`3oooooX23`00<0oooo1OnP8?00
103oooooX23`oj0Pl03oool2oj0Pl0<0oooo0_nP8?00103oooooX23`oj0Pl03oool3oj0Pl0@0oooo
00?oX23`0?ooo`3oool0@P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool04P3oool00onP8?00oooo0?oo
o`0A0?ooo`03oj0Pl03oool0oooo01@0oooo00?oX23`0?ooo`3oool0203oool00onP8?00oooo0?oo
o`070?ooo`;oX23`00@0oooooj0Pl?nP8?3oX23`0P3oool00onP8?00oooo0?ooo`090?ooo`03oj0P
l03oool0oooo04T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0B`3o
ool00oooO`00oooo0?ooo`040?ooo`03oomo003oool0oooo00T0oooo0_ooO`1B0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool04P3oool00onP8?00oooo0?ooo`0a0?ooo`04oj0Pl03o
ool0oooooj0Pl0@0oooo00?oX23`0?ooo`3oool0103oool02onP8?00oooo0?oooonP8?00oooooj0P
l03oooooX23`0?oooonP8?00oooo00;oX23`00<0oooooj0Pl03oool00`3oool00onP8?00oooo0?oo
o`070?ooo`03oj0Pl03oool0oooo03d0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0B`3oool00oooO`00oooo0?ooo`050?ooo`;oogl01@3oool00oooO`00oooooomo0005
0?ooo`03oomo003oool0oooo04d0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c
0?ooo`03oj0Pl03oool0oooo01<0oooo0onP8?020?ooo`05oj0Pl03oool0oooo0?oooonP8?000P3o
ool01?nP8?00oooo0?ooo`3oool2oj0Pl0050?oooonP8?00oooooj0Pl03oool00_nP8?020?ooo`04
oj0Pl03oool0oooo0?ooo`;oX23`00@0oooooj0Pl03oooooX23`1@3oool00onP8?00oooo0?ooo`0l
0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo05/0oooo00?oogl00?oo
o`3oool01@3oool00oooO`00oooo0?ooo`1<0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0>03oool00onP8?00oooo0?ooo`0E0?ooo`03oj0Pl03oool0oooo00@0oooo00GoX23`0?oo
o`3oooooX23`0?ooo`02oj0Pl0D0oooo00CoX23`0?ooo`3oool0oooo0_nP8?020?ooo`04oj0Pl03o
ool0oooooj0Pl0D0oooo00?oX23`0?ooo`3oool0>`3oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`160?ooo`03oomo003oool0oooo00d0oooo0_ooO`000`3oooooogl00?oo
o`1G0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0703oool00onP8?00oooo0?oo
o`0b0?ooo`;oX23`0P3oool01OnP8?00oooo0?ooo`3oooooX23`00<0oooo1?nP8?030?ooo`03oj0P
l03oooooX23`00D0oooo0_nP8?020?ooo`03oj0Pl03oool0oooo03l0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool0H@3oool00oooO`00oooo0?ooo`050?ooo`03oomo003o
ool0oooo04H0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0F0?ooo`03oj0Pl03o
ool0oooo00/0oooo00?oX23`0?ooo`3oool0703oool00onP8?00oooo0?ooo`0:0?ooo`03oj0Pl03o
ool0oooo00<0oooo00CoX23`0?ooo`3oooooX23`1`3oool00onP8?00oooooj0Pl0040?ooo`03oj0P
l03oooooX23`0080oooo00?oX23`0?ooo`3oool0@P3oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`1G0?ooo`03oomo003oool0oooo00T0oooo00?oogl00?ooo`3oool00`3o
ool00oooO`00oooo0?ooo`160?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool04@3o
ool01OnP8?00oooo0?ooo`3oooooX23`0080oooo00?oX23`0?ooo`3oool05@3oool00onP8?00oooo
0?ooo`0F0?ooo`06oj0Pl03oool0oooooj0Pl03oooooX23`1@3oool2oj0Pl080oooo00?oX23`0?oo
o`3oool00`3oool2oj0Pl0`0oooo00?oX23`0?ooo`3oool0@`3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`1@0?ooo`03oomo003oool0oooo00<0oooo00Coogl00?ooo`3o
ooooogl00`3oool2oomo0080oooo00?oogl00?ooo`3oool0CP3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo01/0oooo00?oX23`0?ooo`3oool0403oool00onP8?00oooooj0Pl00=0?oo
o`03oj0Pl03oool0oooo00h0oooo00?oX23`0?ooo`3oool00`3oool2oj0Pl0<0oooo00?oX23`0?oo
o`3oool01onP8?040?ooo`09oj0Pl03oool0oooo0?oooonP8?00oooooj0Pl03oooooX23`0440oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0F03oool01OooO`00oooo0?oo
o`3oooooogl00080oooo00?oogl00?ooo`3oool0D03oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo01@0oooo00?oX23`0?ooo`3oool04P3oool00onP8?00oooo0?ooo`0>0?ooo`03oj0P
l03oool0oooo00X0oooo00GoX23`0?ooo`3oool0oooooj0Pl00?0?ooo`03oj0Pl03oooooX23`00?o
X23`103oool2oj0Pl0040?oooonP8?00oooooj0Pl080oooo00?oX23`0?ooo`3oool0103oool00onP
8?00oooo0?ooo`0k0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo05X0
oooo00?oogl00?ooo`3oool00`3oool00oooO`00oooo0?ooo`050?ooo`03oomo003oool0oooo04L0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0`0?ooo`03oj0Pl03oool0oooo00@0
oooo00?oX23`0?ooo`3oool07@3oool00onP8?00oooooj0Pl0020?ooo`03oj0Pl03oool0oooo0080
oooo00?oX23`0?oooonP8?000P3oool4oj0Pl0040?oooonP8?3oX23`oj0Pl080oooo00?oX23`0?oo
o`3oool0?`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1E0?ooo`03
oomo003oool0oooo00D0oooo00?oogl00?ooo`3oool01P3oool2oomo04X0oooo00?o00000?ooo`3o
ool03`3oool00ol00000oooo0?ooo`0H0?ooo`03oj0Pl03oool0oooo0240oooo00?oX23`0?ooo`3o
ool0503oool00onP8?00oooo0?ooo`030?ooo`05oj0Pl03oool0oooo0?oooonP8?001@3oool01?nP
8?00oooooj0Pl?nP8?030?ooo`03oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool0?P3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1G0?ooo`04oomo003oool0oooo
oomo00<0oooo00?oogl00?ooo`3oool0103oool00oooO`00oooooomo00050?ooo`03oomo003oool0
oooo0480oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?ooo`03oj0Pl03oool0
oooo01D0oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?ooo`040?ooo`CoX23`00<0oooo
oj0Pl?nP8?000_nP8?000`3oooooX23`0?ooo`02oj0Pl0030?oooonP8?3oX23`00?oX23`1P3oool0
0onP8?00oooo0?ooo`0g0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
0640oooo00?oogl00?ooooooO`00203oool00oooO`00oooo0?ooo`130?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0603oool00onP8?00oooo0?ooo`0m0?ooo`03oj0Pl03oool0oooo
00<0oooo0_nP8?060?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool00P3oool00onP
8?00oooo0?ooo`020?ooo`03oj0Pl03oool0oooo03X0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0J03oool2oomo04P0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`1R0?ooo`04oj0Pl03oool0oooo0?ooo`?oX23`0P3oool01?nP8?00oooooj0Pl?nP8?03
0?ooo`;oX23`?P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1K0?oo
o`06oomo003oooooogl00?ooooooO`00oooo0oooO`1>0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0DP3oool00onP8?00oooo0?ooo`0<0?ooo`03oj0Pl03oooooX23`00<0oooo00Oo
X23`0?ooo`3oool0oooooj0Pl03oooooX23`04@0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0IP3oool01?ooO`00oooo0?ooooooO`180?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0G@3oool01onP8?00oooo0?ooo`3oooooX23`0?oooonP8?001@3oool0
1_nP8?00oooo0?ooo`3oooooX23`0?ooo`?oX23`@03oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`1M0?ooo`05oomo003oool0oooo0?ooooooO`000`3oool00oooO`00oooo
0?ooo`020?ooo`03oomo003oool0oooo04D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0J0?ooo`04oj0Pl03oool0oooooj0Pl3@0oooo00CoX23`0?ooo`3oooooX23`1@3oool00onP
8?00oooo0?ooo`020?ooo`CoX23`0P3oool02?nP8?00oooooj0Pl?nP8?00oooooj0Pl03oooooX23`
0P3oool01?nP8?00oooooj0Pl03oool2oj0Pl0<0oooo00GoX23`0?ooo`3oool0oooooj0Pl00d0?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo05h0oooo00?oogl00?ooo`3o
ool00P3oool00oooO`00oooo0?ooo`070?ooo`03oomo003oool0oooo0480oooo00?o00000?ooo`3o
ool03`3oool00ol00000oooo0?ooo`0M0?ooo`03oj0Pl03oool0oooo03@0oooo00?oX23`0?ooo`3o
ool02`3oool2oj0Pl0<0oooo0_nP8?040?ooo`06oj0Pl03oooooX23`oj0Pl03oooooX23`103oool0
0onP8?00oooo0?ooo`070?ooo`03oj0Pl03oool0oooo02h0oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool0IP3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo
00@0oooo00?oogl00?ooo`3oool0?@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
01X0oooo00?oX23`0?ooo`3oool0A@3oool2oj0Pl0050?oooonP8?00oooo0?oooonP8?000`3oool2
oj0Pl0T0oooo00?oX23`0?ooo`3oool0>03oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`1R0?ooo`;oogl0103oool01_ooO`00oooo0?ooooooO`00oooooomo04@0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0H0?ooo`03oj0Pl03oool0oooo03h0oooo00?o
X23`0?ooo`3oool00P3oool01?nP8?00oooo0?oooonP8?020?ooo`;oX23`00<0oooooj0Pl?nP8?00
0P3oool01?nP8?00oooooj0Pl03oool2oj0Pl080oooo0_nP8?030?ooo`04oj0Pl03oool0oooooj0P
l3H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0H`3oool01?ooO`00
oooo0?ooo`3oool2oomo0080oooo0_ooO`150?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0J`3oool00onP8?00oooooj0Pl0020?ooo`;oX23`1`3oool00onP8?00oooo0?ooo`0f0?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo06H0oooo00Googl00?oooooo
O`00oooooomo00020?ooo`?oogl01@3oool00oooO`00oooo0?ooo`0j0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool07@3oool00onP8?00oooo0?ooo`0l0?ooo`03oj0Pl03oool0oooo
00@0oooo00KoX23`0?oooonP8?3oX23`0?oooonP8?040?ooo`04oj0Pl03oooooX23`oj0Pl080oooo
00GoX23`0?oooonP8?00oooooj0Pl0040?ooo`;oX23`00<0oooooj0Pl03oool0<@3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1[0?ooo`04oomo003oooooogl0oomo04<0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0K0?ooo`03oj0Pl03oool0oooo00X0
oooo00?oX23`0?ooo`3oool05`3oool00onP8?00oooo0?ooo`0<0?ooo`03oj0Pl03oool0oooo0180
oooo0_nP8?050?ooo`04oj0Pl03oool0oooo0?ooo`;oX23`1P3oool00onP8?00oooo0?ooo`02oj0P
l3@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0JP3oool2oomo00<0
oooo00?oogl00?ooo`3oool00P3oool00oooO`00oooo0?ooo`0k0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool05P3oool00onP8?00oooo0?ooo`1D0?ooo`04oj0Pl03oool0oooo0?oo
o`;oX23`1P3oool00onP8?00oooo0?ooo`02oj0Pl3@0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0J03oool00oooO`00oooo0?ooo`020?ooo`;oogl000<0oooooomo003o
ool00_ooO`020?ooo`03oomo003oooooogl003T0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0O0?ooo`;oX23`303oool00onP8?00oooo0?ooo`0O0?ooo`03oj0Pl03oool0oooo00<0
oooo00?oX23`0?ooo`3oool03@3oool00onP8?00oooo0?ooo`04oj0Pl0T0oooo00?oX23`0?oooonP
8?00103oool01OnP8?00oooooj0Pl03oooooX23`0340oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo04L0
oooo00GoX23`0?ooo`3oool0oooooj0Pl00H0?ooo`03oj0Pl03oooooX23`0080oooo0_nP8?0:0?oo
o`;oX23`1`3oool2oj0Pl380oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0IP3oool00oooO`00oooo0?ooo`020?ooo`03oomo003oool0oooo00;oogl000<0oooooomo003o
ool0103oool00oooO`00oooo0?ooo`0h0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0>@3oool00onP8?00oooo0?ooo`0V0?ooo`07oj0Pl03oool0oooo0?oooonP8?00oooooj0Pl002
0?ooo`;oX23`00<0oooooj0Pl?nP8?000`3oool3oj0Pl0L0oooo1onP8?0^0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0W0?ooo`03oj0Pl03oool0oooo03<0oooo00?oX23`0?ooo`3oool00`3oool00onP
8?00oooo0?ooo`090?ooo`04oj0Pl03oool0oooooj0Pl0P0oooo0_nP8?060?ooo`03oj0Pl03oool0
oooo02`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0K`3oool01Ooo
O`00oooo0?ooooooO`00oooo00Coogl0>P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo05l0oooo00?oX23`0?ooo`3oool0103oool00onP8?00oooo0?ooo`020?ooo`?oX23`00@0oooo
oj0Pl03oool0oooo0_nP8?000`3oooooX23`0?ooo`020?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo
0onP8?030?ooo`03oj0Pl03oool0oooo02T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0M03oool01OooO`00oooo0?ooo`3oooooogl00140oooo00?oogl00?ooo`3oool0
9@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo06d0oooo0_nP8?020?ooo`03oj0P
l03oool0oooo0080oooo00?oX23`0?ooo`3oool0203oool00onP8?00oooo0?ooo`0^0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`1K0?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?ooo`3oool01@3o
ool01OnP8?00oooooj0Pl03oooooX23`0080oooo00GoX23`0?ooo`3oool0oooooj0Pl0060?ooo`03
oj0Pl03oooooX23`0080oooo00?oX23`0?ooo`3oool0:P3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`1`0?ooo`03oomo003oooooogl000;oogl0?@3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo0240oooo00?oX23`0?ooo`3oool0>`3oool00onP8?00oooo
0?ooo`050?ooo`03oj0Pl03oool0oooo00<0oooo00WoX23`0?ooo`3oooooX23`0?oooonP8?00oooo
oj0Pl03oool00_nP8?000`3oooooX23`0?ooo`060?ooo`CoX23`00<0oooooj0Pl03oool0:P3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1c0?ooo`03oomo003oool0oooo
03`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1_0?ooo`CoX23`0P3oool01?nP
8?00oooo0?ooo`3oool2oj0Pl0P0oooo00?oX23`0?ooo`3oool00_nP8?0Z0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0740oooo0oooO`050?ooo`04oomo003oool0oooo
oomo00P0oooo00?oogl00?ooo`3oool0:P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo06T0oooo00GoX23`0?ooo`3oool0oooooj0Pl0030?ooo`;oX23`0P3oool2oj0Pl0<0oooo0_nP
8?00103oooooX23`oj0Pl03oool2oj0Pl0<0oooo00CoX23`0?oooonP8?3oX23`:@3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1b0?ooo`03oomo003oool0oooo0080oooo
0_ooO`020?ooo`03oomo003oool0oooo03@0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0f0?ooo`03oj0Pl03oool0oooo03T0oooo00CoX23`0?ooo`3oooooX23`0`3oool01?nP8?00
oooo0?oooonP8?050?ooo`03oj0Pl03oool0oooo02d0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0M@3oool2oomo0080oooo00?oogl00?ooo`3oool0=P3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo06l0oooo0_nP8?030?ooo`;oX23`1P3oool01?nP8?00
oooo0?oooonP8?030?ooo`03oj0Pl03oool0oooo00CoX23`:03oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`1`0?ooo`03oomo003oooooogl000<0oooo00Ooogl00?oooooo
O`3oogl00?ooooooO`00oooo00;oogl0<`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo02/0oooo00?oX23`0?ooo`3oool0>`3oool01onP8?00oooo0?ooo`3oooooX23`0?oooonP8?00
1@3oool00onP8?00oooooj0Pl002oj0Pl080oooo0_nP8?030?ooo`03oj0Pl03oooooX23`0080oooo
00?oX23`0?ooo`3oool0:@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`1e0?ooo`03oomo003oool0oooo00T0oooo00?oogl00?ooooooO`00;P3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo02@0oooo00?oX23`0?ooo`3oool0C@3oool01_nP8?00oooooj0P
l?nP8?00oooooj0Pl0<0oooo0_nP8?020?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3o
ool00P3oool00onP8?00oooo0?ooo`0T0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo07H0oooo00?oogl00?ooooooO`000`3oool01?ooO`00oooo0?ooo`3oool2oomo00@0
oooo00?oogl00?ooo`3oool0:@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03@0
oooo00?oX23`0?ooo`3oool0;`3oool00onP8?00oooo0?ooo`0;0?ooo`03oj0Pl03oool0oooo00Ko
X23`00<0oooooj0Pl03oool00onP8?060?ooo`05oj0Pl03oooooX23`0?oooonP8?00903oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1e0?ooo`03oomo003oool0oooo00<0
oooo00?oogl00?ooo`3oool0=03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo07D0
oooo00CoX23`0?ooo`3oool0oooo0_nP8?000`3oooooX23`0?ooo`02oj0Pl0050?oooonP8?00oooo
0?oooonP8?001@3oool00onP8?00oooo0?ooo`0U0?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo07T0oooo00?oogl00?ooo`3oool01`3oool00oooO`00oooo0?ooo`0/0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool07`3oool00onP8?00oooo0?ooo`1A0?oo
o`03oj0Pl03oool0oooo00@0oooo00?oX23`0?ooo`3oool00_nP8?040?ooo`03oj0Pl03oool0oooo
00@0oooo00?oX23`0?oooonP8?009@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`1i0?ooo`06oomo003oool0oooo0?ooooooO`00oooo1?ooO`020?ooo`03oomo003ooooo
ogl002X0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0S0?ooo`03oj0Pl03oool0
oooo04/0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`04oj0Pl0060?oooonP8?3o
X23`0?oooonP8?00oooo0_nP8?000`3oooooX23`oj0Pl0020?ooo`03oj0Pl03oooooX23`02D0oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0P03oool2oomo00030?oooooo
O`00oooo00D0oooo00?oogl00?ooo`3oool09@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo0780oooo00?oX23`0?ooo`3oool01P3oool01?nP8?00oooooj0Pl?nP8?020?ooo`03oj0P
l03oool0oooo00H0oooo0_nP8?0V0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003o
ool0oooo07T0oooo00Googl00?ooo`3oool0oooooomo00070?ooo`;oogl0:`3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo03H0oooo00?oX23`0?ooo`3oool0<P3oool2oj0Pl0L0oooo
00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`030?ooo`?oX23`0`3oool4oj0Pl0H0oooo
00?oX23`0?ooo`3oool0803oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`220?ooo`03oomo003oool0oooo0080oooo00?oogl00?ooo`3oool0:03oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo02<0oooo00GoX23`0?ooo`3oool0oooooj0Pl0190?ooo`03oj0P
l03oool0oooo00H0oooo00GoX23`0?ooo`3oool0oooooj0Pl0020?ooo`03oj0Pl03oool0oooo0080
oooo00?oX23`0?ooo`3oool0:@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`1n0?ooo`04oomo003oool0oooo0?ooo`;oogl0;P3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo06h0oooo00?oX23`0?ooo`3oool03@3oool01?nP8?00oooooj0Pl03oool2oj0P
l0050?oooonP8?3oX23`0?oooonP8?00:@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`210?ooo`?oogl0;P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
0680oooo00?oX23`0?ooo`3oool03P3oool00onP8?00oooo0?ooo`0=0?ooo`;oX23`;@3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1l0?ooo`;oogl00`3oool00oooO`00
oooo0?ooo`030?ooo`03oomo003oool0oooo02P0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0U0?ooo`03oj0Pl03oool0oooo05T0oooo00KoX23`0?oooonP8?3oX23`0?oooonP8?02
0?ooo`03oj0Pl03oool0oooo02H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0O03oool2oomo00D0oooo0_ooO`000`3oooooogl0oomo0002oomo02P0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`210?ooo`03oj0Pl03oool0oooo00;oX23`0P3oool2oj0P
l2P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0P03oool00oooO`00
oooo0?ooo`020?ooo`Coogl00`3oool00oooO`00oooo0?ooo`0S0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0;`3oool00onP8?00oooo0?ooo`120?ooo`03oj0Pl03oool0oooo00/0
oooo00?oX23`0?ooo`3oool0;@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`210?ooo`03oomo003oooooogl000Googl000<0oooooomo003oool09P3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo02L0oooo00?oX23`0?ooo`3oool02`3oool00onP8?00oooo
0?ooo`030?ooo`03oj0Pl03oool0oooo04@0oooo0onP8?050?ooo`03oj0Pl03oool0oooo0080oooo
00?oX23`0?ooo`3oool0803oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`280?ooo`?oogl09`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0780oooo00?o
X23`0?ooo`3oool03@3oool3oj0Pl0<0oooo00?oX23`0?ooo`3oool09`3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`250?ooo`05oomo003oooooogl00?ooooooO`000`3o
ool01?ooO`00oooooomo0?ooO`030?ooo`03oomo003oool0oooo01/0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`280?ooo`03oj0Pl03oool0oooo02L0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool0Q03oool01OooO`00oooo0?ooo`3oooooogl00080oooo
00Coogl00?ooo`3oooooogl08`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02L0
oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`1G0?ooo`?oX23`0`3oool00onP8?00
oooo0?ooo`0S0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08<0oooo
00?oogl00?ooo`3oool01`3oool00oooO`00oooo0?ooo`0R0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0G`3oool00onP8?00oooo0?ooo`0P0?ooo`03oj0Pl03oool0oooo00D0oooo
0_nP8?0V0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08L0oooo00Ko
ogl00?ooooooO`00oooooomo003oool3oomo0080oooo00?oogl00?ooo`3oool07@3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo02H0oooo00?oX23`0?ooo`3oool01`3oool00onP8?00
oooo0?ooo`170?ooo`03oj0Pl03oool0oooo00@0oooo00CoX23`0?oooonP8?3oX23`103oool00onP
8?00oooooj0Pl00V0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo08d0
oooo0_ooO`040?ooo`04oomo003oool0oooooomo01/0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`270?ooo`03oj0Pl03oool0oooo00P0oooo00?oX23`0?ooo`3oool07@3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`240?ooo`03oomo003oool0oooo00;o
ogl0103oool3oomo0080oooo00?oogl00?ooo`3oool07@3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo08P0oooo00?oX23`0?oooonP8?009`3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`2=0?ooo`Coogl00`3oool00oooO`00oooo0?ooo`0K0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0P@3oool01?nP8?00oooooj0Pl?nP8?040?ooo`;o
X23`0P3oool00onP8?00oooo0?ooo`030?ooo`04oj0Pl03oool0oooooj0Pl1/0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0RP3oool01OooO`00oooooomo0?ooO`00oooo
00;oogl01P3oool00oooO`00oooo0?ooo`0H0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0QP3oool3oj0Pl0@0oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`080?oo
o`03oj0Pl03oool0oooo0140oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0R03oool00oooO`00oooooomo00020?ooo`03oomo003oooooogl000?oogl00P3oool00oooO`00
oooo0?ooo`0J0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0;03oool00onP8?00
oooo0?ooo`1B0?ooo`03oj0Pl03oool0oooo0080oooo00KoX23`0?ooo`3oool0oooooj0Pl03oool2
oj0Pl080oooo0onP8?0O0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
08T0oooo0_ooO`040?ooo`Coogl00P3oool00oooO`00oooo0?ooo`0J0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0R03oool00onP8?00oooo0?ooo`030?ooo`03oj0Pl03oool0oooo
00;oX23`7`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2=0?ooo`03
oomo003oooooogl000Koogl000<0oooooomo003oool06@3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo03X0oooo00?oX23`0?ooo`3oool0B`3oool4oj0Pl0030?oooonP8?00oooo00;o
X23`00<0oooooj0Pl03oool07P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2?0?ooo`03oomo003oool0oooo00Coogl00P3oool01OooO`00oooo0?ooo`3oooooogl001D0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2<0?ooo`04oj0Pl03oool0oooooj0P
l0<0oooo0_nP8?0M0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0940
oooo1_ooO`0K0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0<03oool00onP8?00
oooo0?ooo`1E0?ooo`;oX23`0P3oool01?nP8?00oooooj0Pl?nP8?040?ooo`03oj0Pl03oool0oooo
01/0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0TP3oool6oomo0004
0?ooooooO`3oogl0oomo01H0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2:0?oo
o`CoX23`00@0oooooj0Pl?nP8?00oooo0onP8?070?ooo`03oj0Pl03oool0oooo01<0oooo00?o0000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0TP3oool7oomo01T0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`1o0?ooo`03oj0Pl03oool0oooo00`0oooo1_nP8?030?oo
o`03oj0Pl03oool0oooo01P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0T@3oool2oomo0080oooo1OooO`000`3oooooogl0oomo000E0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0J03oool00onP8?00oooo0?ooo`0M0?ooo`;oX23`0`3oool01?nP8?00
oooooj0Pl03oool5oj0Pl1`0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0T`3oool2oomo0080oooo0oooO`000`3oooooogl00?ooo`0E0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0?P3oool00onP8?00oooo0?ooo`1A0?ooo`05oj0Pl03oooooX23`0?oo
oonP8?006`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2@0?ooo`03
oomo003oool0oooo00<0oooo1_ooO`0F0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0T03oool01OnP8?00oooooj0Pl03oooooX23`01d0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0T`3oool01?ooO`00oooo0?ooo`3oool8oomo01<0oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`1S0?ooo`03oj0Pl03oool0oooo02L0oooo00?oX23`0?oo
o`3oool00P3oool3oj0Pl0030?oooonP8?3oX23`01X0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0V@3oool4oomo01D0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`2D0?ooo`04oj0Pl03oool0oooooj0Pl0<0oooo00?oX23`0?ooo`3oool0503oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2K0?ooo`Coogl04`3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo0400oooo0_nP8?1@0?ooo`04oj0Pl03oool0oooo0?oo
o`?oX23`1@3oool00onP8?00oooo0?ooo`0A0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo09`0oooo00Coogl00?ooo`3oooooogl04P3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo0780oooo00?oX23`0?ooo`3oool08@3oool00onP8?00oooo0?ooo`020?oo
o`04oj0Pl03oool0oooooj0Pl1<0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0WP3oool3oomo0140oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2G0?oo
o`05oj0Pl03oooooX23`0?oooonP8?005P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`2K0?ooo`03oomo003oool0oooo00?oogl04@3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo08h0oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`020?oo
o`03oj0Pl03oooooX23`00<0oooo0_nP8?0A0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03
o`00003oool0oooo0:00oooo00?oogl00?ooo`3oool03`3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo06d0oooo00?oX23`0?ooo`3oool06`3oool00onP8?00oooo0?ooo`0=0?ooo`06
oj0Pl03oool0oooooj0Pl03oooooX23`4@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0B`3oool00onP
8?00oooo0?ooo`0a0?ooo`03oj0Pl03oool0oooo01D0oooo00?oX23`0?ooo`3oool00P3oool00onP
8?00oooo0?ooo`0C0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0:<0
oooo0_ooO`0=0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0A@3oool00onP8?00
oooo0?ooo`1K0?ooo`03oj0Pl03oool0oooo00`0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0WP3oool00oooO`00oooo0?ooo`030?ooo`03oomo003oool0oooo00/0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1b0?ooo`03oj0Pl03oool0oooo01X0oooo
00?oX23`0?ooo`3oool04@3oool00onP8?00oooooj0Pl00<0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`180?ooo`03oj0Pl03oool0oooo0080oooo00?oX23`0?ooo`3oool02@3oool00onP8?00oooo0?oo
o`1F0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0:00oooo00?oogl0
0?ooo`3oool00P3oool00oooO`00oooooomo000:0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0O@3oool00onP8?00oooo0?ooo`0S0?ooo`03oj0Pl03oooooX23`00`0oooo00?o0000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0Z03oool00oooO`00oooo0?ooo`070?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0OP3oool00onP8?00oooo0?ooo`030?oo
o`03oj0Pl03oool0oooo01/0oooo0_nP8?030?ooo`03oj0Pl03oool0oooo00P0oooo00?o00000?oo
o`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo0600oooo00?oX23`0?ooo`3oool0C`3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`2N0?ooo`03oomo003oool0oooo00D0oooo1?ooO`070?ooo`03oomo
0?l00000oooo0100oooo00?o00000?ooo`3oool0B03oool00onP8?00oooo0?ooo`060?ooo`03oj0P
l03oool0oooo04h0oooo00?oX23`0?ooo`3oool00`3oool00onP8?00oooo0?ooo`070?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0:T0oooo00?oogl00?ooo`3oool01P3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo05l0oooo00?oX23`0?ooo`3oool0B03o
ool00onP8?00oooo0?ooo`050?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0
oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`2X0?ooo`05oj0Pl03oool0
oooo0?oooonP8?001@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0CP3oool00onP8?00oooo0?ooo`03
0?ooo`03oj0Pl03oool0oooo05/0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo09<0oooo00?oX23`0?oo
o`3oool0703oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0E@3oool00onP8?00oooo0?ooo`130?ooo`03
oj0Pl03oool0oooo00h0oooo0_nP8?040?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo0:d0oooo00Koogl00?ooo`3oooooogl00?ooool0000A0?ooo`03o`00003oool0oooo
09h0oooo00?oX23`0?ooo`3oool00P3oool00onP8?00oooo0?ooo`0;0?ooo`03oj0Pl?l00000oooo
00T0oooo00090?ooo`03o`00003oool0oooo0;00oooo00?oogl00?ooool000004@3oool00ol00000
oooo0?ooo`2D0?ooo`03oj0Pl03oool0oooo01P0oooo0onP8?000ol00000oooo0?ooo`080?ooo`00
2@3ooondo`000003oomo0?l00000oooo0100ooooIol000000onP8?3o0000o`000002o`000003oj0P
l?l0003o000000Wo000000?oX23`o`000?l000008?l000000onP8?3o0000o`000002o`000003oj0P
l?l0003o000000ko000000GoX23`o`000?nP8?3oX23`o`00000:0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.22082, -0.0755852, 0.00575585, 0.00575585}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-13.5849, -294.52, 1.41129, 1.41129}, {{208.5, 389.438}, {190.438, \
9.5}} -> {-294.432, -294.52, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[BoxData[{
    \(\(pdf1 = 
        MixtureLikelihoodNative[{x, y}, model1];\)\), "\[IndentingNewLine]", 
    \(\(pdf2 = MixtureLikelihoodNative[{x, y}, model2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1, pdf1, pdf2, {Green, Blue}, 
          255. ];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2, pdf1, pdf2, {Green, Blue}, 
          255. ];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1, obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45448 
%%ImageSize: 400 181.791 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0108209 0.238095 [
[ 0 0 0 0 ]
[ 1 .45448 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45448 L
0 .45448 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0108209 0.245293 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0108209 0.488926 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.51788e-17 0.00653595 -0.00653595 0.00653595 [
[ 0 0 0 0 ]
[ 1 1.95425 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.95425 L
0 1.95425 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00654 translate
1.00654 1.96079 scale
462 string
154 300 8 [154 0 0 300 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0108209 0.732558 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C834
59C9355AC9365CC9365CC9355ECD3B61D14389B25CBB9C81BD9F86BC9C80B29274B59678
51C337AD9173BCA285BCA48CBAA590B19B88B29D8A857668796F639486738A7A62887760
9B886D5AD1457FAF5953CA3E56C93D55C63A55C5382AE11B00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008CB65EB89A7CBA9D81
BEA588C7B095BDA38BC2A78FDCC7B5D8C9B9CCBEAEC9BAA9CEBEACBAA793AC9580C3AE9B
D2C3B5C0B5A8CBC1B6D6CEC8B6B3B2868484B0AAA842464C1D2E39626C6FA7A8A48F9190
9B9F9DC9CCC8B0B6B1BDC1BBC7C4BACAC1B5C4B7A9C1B0A2BCA797B59E8EB39A8784B163
59CD4256C93D51C33600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE318
59C6315BC734B69169B8946CBA9A72B89E7BD2BB9DCCB69CB6A28AD4C4AED2C4B0BAA996
BCAB97D7CBBCDDD1C5CBBDB1CFC2B7CFC7BCC5BDB1AEA393BDAE9ECCBFB2C3B6AAC6BBB1
D5D0CBC2C2BEB3B1ACBCB9B5A1A2A26E6E719E9A98B1B3B399A8AF90A4AEBBC9CEA9BAC4
3450655B7B915B7B8C627E8BBCCED2C8CFCFC9CCCACCCBC9CECBC8CEC9C7CEC9C6CEC9C4
CFCAC2CEC5BCC5B8AEBCAFA3B3A393AC978555CA4300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002CE31959C7325BCA3489B14FB8986BBD9C72
C09D76C19E7AC5A484CBAB8FC4A78DC0A88FD4C3ACCFBEA9B9A790B8A68FC2B5A2CAC0AE
BFB5A5D3CABED8D2C9C8BEB3BAAE9EC6BDAFCEC9BCC7C0B4CAC2B8D6D1CAD6D1CABBB3AC
C2BDB6B3B2ADB0AEA8ABA89FCAC8C1D3D3D1C0C1C1BCC0C1AAB9C2334D66536D838FA1B2
203A5412345182A2B6748E9CB0C6D0C1D0D5C7D0D3CBD1D4CAD0D2CDCFD3CCCFD1CCCED1
CCD0D1CACECFCCCECECCCDCCCACAC8CEC9C8C7BFBBC4B9B3BAABA0AF9A8859CE4550C236
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002DE3195BCA35B8946FBB9874BC9B76C09E7AC3A480C4A682C4A682
C7A885C5A987C6AB8DD1B7A0CFB7A0C9B198C7B099C8B29DC8B09DBEA894CEBEACD3CABC
BEB6A9A69D92AEA69DC6BDB5CAC1B7CBC3B9D8D5CDD6D6CEC1BEB5C0BCB3C8C2BBC2BAB3
BCB5ADD6D4CED6D6D0C7C7BFC0C1B9CBCFCD8690938891949BA3A94B5C6F455C6F9FB1BA
A9BCC785A0B29CBAC8B6D3DF648495ABC6D2C0CFD3C8D2D4C9D1D4CCD1D5CAD0D4CDD3D7
C6CED1C9CED1CBD0D3C9D0D3C9D0D3C7CCCFC9CBCEC9CBCEC7CAC9C7C7C3CAC6BFCBC1B8
C3AFA4A88E7E94755E47B52922D81100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC935
5ECC3ABA9670BC9974BC9D76BEA07BC0A07FC4A284C7A78AC7A98DC8AB8FC9AD90C9B090
CBB293CCB393CCB296CDB39ACEB69ECEB8A0CEB9A2D5C1AEE0CCBBC8B4A1C4AF9CBCAC9D
A79F90BEB7A9CDC5BCC7C2BDCDC8C3C6BCB5CBC4BCCDCCC4C3C1B9BFBCB4D7D5CEDADAD4
C6C6C1CBCCC7CDCFCABEBEB8B3B2A9B7B5AE979B9C9DA1A3B8BCB9CAD2D7B7C8D498AFBD
B8D1E14E6F8C254E6F799FB9284C667090A7BFD2DAC7D2D5C6CFD3C8D1D3C7D1D2CBD4D7
C7D1D2C9D0D2CCD1D4C8D0D3C7D1D3C8D0D3C8CED3BFC8CEBDC8CBC4CDCFC5CCCCC6C9C8
C7C5C4C7BEBCBDB1ACB1A1969D857489674F42B02100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BCA3486AE4FB79A72BDA37E
BEA281BD9F81BEA283C0A686C2A889C7AB8ECCAE92CCAF95CAAF98CEB49ECEB7A0CBB69E
CBB79FCEBAA0D0BAA2D3BAA3D5BFA9DAC8B3CFBEA8D2C0ABCEBCA7CBB4A0D0B7A4B9A99A
CEC7BBD9D4CACDC7BDCAC5BFAAA69FC7BFB5C7C0B6D8D7CEDBDAD5CECDC8CECDC7D9D7D3
CCCAC4C0BCB5C5C1BAC2BEB8C4C0B8C3BFB9D5D8D4CFD6D6B7BFC0C8D0D7687F9623476D
6D8EAE3F5F82143A6261839DA8C2D38EA8B8BDD3DDC6D5D9C6D2D6C7D1D3C8D2D4C6D0D2
C6D0D1C6CED0C8D0D4C8CFD5C4CDD2C2CCCEC6CED4C4CDD5C0CBD0C5CDD2C4CCCEC6CECE
C4CACBC5C7C9C0C2C4C1C1C0C4BFBAB9AAA29D877686694D3DAD1D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002CE41BB09268B3986EB99E77B79C77B79F7BBAA381
C0A887C1A888C4AB8BC6AD8FCAB398C8B196CEB89FCFBBA5CCBAA5D3C0ACD2C1ACD0BFAA
C9B8A5D0BFACD3C2AFD7C3B0D7C4B0D8C6B0D7C5ACD7C3AAD6C2AADDC7B3D7C1AEC3B2A3
B2A99FCDC7BEC7C0B6ABA69CBCB9B0DAD6CECAC7BFD3D2CBDADAD3CECBC4C2BBB2CCC5BE
D3CEC8C7C2BBD2CFC8DBD8D3D6D4D0CCCAC6CACBC8B7BFC2768489A9B3B88F9EAE46607F
7D94ADBDCEE0A5BBCE9BB6C9BAD3E295B2C36E8FA1BED6DFC8D6D9CCD6D8CCD4D9C9D1D4
C8D0D3C8CFD4CBD2D8C9D0D6C7CED4C5CCD2C4CDD3C4CDD6C4CED6C4CDD2C0CACDC3CCD0
C2CBCEC5CBCFC1C8CAC3C7CABEC1C4C1C3C3C1BEBBB7ACA4988471628D381ED50D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CE3185AC8335ACA36B0946CB59B76BAA17DBCA583BAA281BBA381BCA582BDA886
BEAA8AC2AD8FC8B295CDB89ECCB8A1CAB9A3CABAA6B7AA9AADA295A69A8BCABDABD4C3B0
D4C1ADD6C4B0DBC9B5DBC9B5DAC8B4DBC9B2DCC8B0DCC6AEDAC6AFDDCBB7D7C6B1D5C4AF
BCAF9EB9AFA4C1B8B1B8B2A9D7D4CCD8D7D1C4C1BAB9B5ABC7C3B9CFCBC2C7C2BAD2CCC6
DAD6D2D8D7D3C4C1BCD3CDC8D2CDC8C5C0BABBB6B0BFC0BEA4ACADB2B8BBCBD2D6C5D3E1
A2B6C7AABDCAA3BACC2B4E6E3A607F6185A01C435D9DBCCDC4D8DBCED9DACCD6D7CAD5D7
CAD3D8CAD3DACDD5DBC9D2D5C9D3D5CCD3D8C8CFD6C8CFD7C7CED6C6CDD5C2CBD0C0C9CF
C1CBCFC4CED0C4CDD0C0C8CCC1C7CCC2C6CABCC2C5C0C1C3C5C0BCAB9B90856D583BAB1E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058C833
85AE4FB7996FBB9C75B89C78B99F7DB9A380B7A380B8A384B7A383BDA987C1AD8AC1AD8C
C3AF91C8B298CDB79FCDB8A3CEBBA9D0BFAFC2B6A6B9AFA3D4C9C1A89E94C1B4A4DAC9B6
DECAB8DDC8B5DFCAB6DCC8B6DDCBB7DFCEB9E0CFB8E0CCB5E0CCB4DAC9B2D9C9B1D8C8B0
D2C5B0DED3C5E2D7CED0C6BCCBC2B6CAC4BAA6A49D9B9B95A6A8A0D8DAD2D8D7D1C4BEB8
CFCAC5CFCAC6BCB5AFC6BCB4CFC8C0D7D4CDC9C5BFCDCDC8D5D7D4C8CBCCADB1B4A4B1BD
2745603D5D788CA6BB2A4869183C5FA1C0D68AA7BA96B4C4C3DAE1CBD9DACCD7D9CAD4D6
C5CFD1C2CDD0C5D0D2C9D4D6C9D4D6CBD4D9C9D2D7C9D2D9C7CFD6C7D0D5C1CACFBFC8CD
BCC7CBC2CDD2C3CED4C1CAD1BFC8CDBFC7CCBDC5CBBDC1C9BDBFC5BDBCBFAEA9A68A796C
5E883600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DE51A83AE4FB0956E
B89C78BC9F7DBFA282BDA283B9A083B6A084B5A082B7A284C0AB8CC1AD8CC9B393CAB697
C9B79CCDBBA1D3C0A7D1BDA6CFBCA9D0C1B1D6CEC1D9D5CFDCD7D3B3AAA0CCBDABD7C4AE
DDC8B3DECAB7DECCB8D9C7B5D9CAB8DCCEBDE0D0BDDFCDB7DECCB3DCCBB3DECEBADBCFBB
D4C8B3D4C5B4D4C5B6CFC1B2CBBFB0D6CDC3C2BFBBCBCBC88C9089CACDC5D2D1CAC0B8B1
C3BAB1D5D0C6D6D4CAC9C7BDCECDC4D8D9D2D4D6CFBBBBB4C2C4BF868B8E949A99ACB1B4
5D6F80536C80B0C4CFB3C7D58BA8BDA2C0D1B4D0E253768DA0C1D0C4D7DECAD4D6CAD3D6
C9D3D5C8D4D4C7D3D4C8D2D4C6D0D2C8D1D7C7CED6C6CFD7C5CED5C3CCD3C2C9CFC1C8D0
BCC5CCBDC6CDC2CBD2C2CBD0C3CCD3C3CAD3BEC7D0BBC2CBBBC1C8BEC4C9B8BEC3A7A6AB
7B736D55863700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002CE41958C934B0956CB09970B6A079
BAA17FBBA182BBA082BDA385BDA489B9A48CBAA58CBEA88BC8B192CAB294CCB498CDB89F
CEBBA3D1BFA7D4C0A8D3BCA5D1BDA6CDC1AFDEDBD0DCDDDADFDCDBD6CBC3D5C4B2D8C3AC
DBC6B0D9C7B1D7C9B4D7CDBFDDD6CDDFD9D0DCD2C5DECFBBDDCBB3DFCAB4DBC9B5D9C9B5
D8C8B4D8C6B1D8C8B6E1D4C5D3C8BAD3C7BCD4C9C4B1ABA6ABA79FC3BDB3D7D4CCD6D2CC
C7C1BAD8D6CDDADBD3D3D3CBC2BDB6CBC4BEC7C2BBB4AFA5BAB7B0B8BAB9B6B8B7BCBBB9
D2D8DCBDCED89CAEB6B1C4D046647E264C6C7CA0B9224764537A91C0D8E2CBD7DACCD4D7
CBD5D6CAD6D7C8D5D5CCD5D8CCD4D8CAD1D9C9D0DAC4CCD3C2CBD1BEC7CEBEC7CDBDC6CB
BBC4C8C1CACEC0C9CEC5CED3C7D0D5C5CED5C2CCD3BBC4CBB8C3C8BCC6CABFC7CFABB1BC
3F4652404042467D341AD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C73484AE51B3986FB1976FB59B74B59F78BAA482
B89E81BAA083BBA286BDA389C3AB92C3AD96C1AB92C5B095CAB599C9B499CAB49ACEB9A1
D2BFA8D2BEA9D1BCA7D1BBA6D4BEA9D4C5B1DDD8CAE0DED7DED8D1D5C7BAD7C5B2D8C3AC
D9C4AEC9BBA7B3AB9DBCBAB4CCCECCDADCDAE0DDD6DACFC0DCCCB7E0CBB5DDCAB5DBC9B4
DACAB3D7C7AED6C6B2DCD0C1D3C7BACEC0B2CFC1B6D6CCC2D3CBC3C7BFB8DCD9D1DBDAD4
CAC9C0C2BFB4CBC8BEC7C3BAC3BAB3C5BCB5DAD5D1D6D4CFC2C0BCD4D5D1D1D6D2A7ABA6
B3BABB5F74842C495F8CA3B6445F7B1033577D9FB69EBBCC7492A5B8D0DCC8D7D9CDD7D9
CCD6D8CBD6D8CBD6D8CDD5DACBD2D8CCD3DBC9D2D9C8CFD6C7CED3C1CACEBCC5C9B9C0C6
B6C0C2B7C2C6B9C4C6BFC9CDC4CFD3C6CFD7BFC9D2BFC8D0BBC6CCBAC4CDBFC8D1BDC6D0
7C8894717F8A62676B66594A1DD61000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0056C835AE936EB19672B39873B39974B49C77B69E7BB9A282B9A285
B79E87BAA28BBEA891C3AD97C3AC96C7B09CCAB59DCCB89ECCB79EC8B399CBB69CCDBBA1
CDBBA2CEBBA3D0BEA6D0BEA6D4C0A8D5C2ACD2C4B2D4C7B9D7C6B6D3BEA8D8C2AAD9C3AD
CCBBA9AEA391CDC6B9DAD8D3BFC1C2CED0D1DEDCD6D9D0C4DCCCBBDFCBB8DFCAB7DCC9B4
DAC8B2D8C6B0D5C3AFD2C1B0D2C2B1D0C1B1CEC2B4E0D7CFDFD8D2C6BEB6CAC1B6CECABF
C3BFB4BEB6ABD5CEC4DFDBD3D7D5CFC4C0BCD9D5D4DAD9D5BBB7B4B9B4B0B1B3AF767B7A
A8AAAC919BA853697E98ABBABFD1DE92AAC0849FB5B5CDDD86A3B56C8C9FC1D9E1C9D6D9
CBD5D7CBD5D7CAD3D8CDD6DBCDD6DBD0D7DCCCD5DACDD4DCCCD3DAC7CED4C2C9CFBEC7CC
BCC6C8BAC4C6B8C1C4AFB6BCB6BFC2BDC6CDBBC6CCBDC6CDC0CBD0BFC9D1BFCAD3BCC7D0
A6B4C08798A88B9CA69CA2A390827100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002AE31980AD4FAE9471B19776B39977B29B75B19C77B19B79B79E80BBA287B9A28A
B9A38DBEA893C5B09CC8B59FC6B39DCAB69FC9B49BC8B398C8B399C8B199CCB49CCAB59C
CCB89FCBB79ECBBAA0CDBDA2D2BEA6D2BCA7D4C1ABD3C0AAD7C1A7D3BDA0D8C1A5D8C4AD
B4A694BBB2A2D2CABEDDD8D1CCCCC8C4C3BDD9D2C8DCCDBDDECCB8DDC8B3DECAB4DEC9B4
D9C6AED9C6AED8C3AED1C0ACDDCDBDDDD0C1C9BCADCFC3B7CCC2B7C5B9ABBFB2A3D3CEC1
DBD8CFD3CCC5D1CBC5DBD8D3D7D8D3C1BCB7C1B8B3CAC4BFC1B9B5B6ADAAD4D1CFC5C7C5
B6B7B3CED0D0C9D4DBA0B2BBA9BCC57A93A8183B5C4F718D5778921A3E5DA6C5D9C7D7DD
C9D4D6CCD5DACCD3DBCCD5DCCDD6DACDD4DACCD5DCCCD3DCCDD6DDC7D0D5C6D0D2C4CDD2
BEC8CDC0C7CDBDC4C7B6BDC0B2BABDB3BCC1B4BEC1B8C3C5B5C0C3BFC9D1B7C5CEBCC9D3
B3C2D03A4B62334A603A515E6E76775B904400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C733
53C733A89067AD956FB09775B39978B59C7BB29C7BB19D7EB39F81BEA78BBDA68CC0A991
C3AE98C9B39CC9B39CC9B29CC8B19AC6B097C4AE93C7AF93C6B195C6B196C9B198CCB39B
CBB59DCCB99FCCBB9ECEBD9FD3BEA5D2BDA5D2BEA5D4C0A6D7C1A5D8C0A2D5BC9EDAC1A8
C2AE9AAB9D8CD2C7B9CAC2B6ACA598CBC1B2DBCCBADDCCB7DECBB4DECBB3DBC7B0DBC8B0
D8C7ADD6C3AAD4C1A9D1C2ABD3C2B0D4C2B2D0BCACCAB9A9D0C4B5DAD0C5C5BCB1CFCBBF
D9D9D1D7D5CFBDB7B0C2BDB6C7C6BEC9C3BFBEB4ADD5D0CBD8D6D3C3C1BEC9C8C5D4D5D2
B6B7B2A8A9A48F9BA130495E506D808099AB23406033536FB4CEE2728EA58FAEC1C2D7E1
C7D4DAC9D4DACBD4DBCDD6DDCFD8DFCED6DECDD6DDCBD3DCC9D2DAC2CDD2CAD4D8C8D0D5
C2CBD0C0C7CDC2CACEC2CACEBDC5CABBC2CBB6BEC4B6BFC4B6BFC6B9C3CCBDC7D1B0B9C6
B8C1D0738193667B8E4D647653657085858261914400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007BAA4BA79169
A7916AAC956FAF9773B09876B39A7AB49C7DB49E81B39E83BBA68DC0AA91C5AE95C6AF98
C4AF99C4B098C4AF96C6AF97C6AD95C5AB92C5AC92C5AE94C5B197C6B299CAB49ACCB49A
CCB59BCCB89DCEBA9FCFBBA1D0BBA2D3BDA5D1BBA3D3BDA5D4BEA2D6BEA1DABEA1DCBEA5
D9BFA8BCA995AC9C8DAFA090C8B8A5D9C8B2DCCAB4DDCBB5DBC9B3DAC8B2D8C5B0DAC6AF
D9C5ACD6C2A8D5C2AACFBDA6D0BDA7D2BFABD4C1AFC9B8A7D0C6B8DAD5CACCC6BBBBB3A5
C4BFB2C8C4B9C1BDB2BDB9AFD2D0CADCDAD6CEC9C5C4C0BBD1D1CCBFBCB8ABA5A0B9B5B2
8B8C899B9D98BABDC16372855D7485B7C8D2B0C2CF8FA8B9A0B8C8AAC2D6577992ABCADC
C1D4DBC8D2D8CCD3D9CCD5DACFD8DFCED8DECBD6DCCCD6DFCCD6DDC9D2D9C8D1D7C7CED7
C3CAD2C1C8D0C4CBD3C8D1D9C3CDD5C3C9D4BBC4CCBBC6CCBCC8CEBDC7D0C1CAD3B0B9C2
AEB6BF9FAAB592A3B198ACBB889BA59CA6AAA9A1993EB02500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A48B64A78F69A7916C
AB9370AE9574B09778B49B7CB49D7DB5A082B8A287BBA38BBFA38EC6AD97C8B29AC4AF98
C1AD95BFAE94BEAB8FC1AB90C4AB90C4AB8FC2AC92C2AD95C5B19AC9B59DCEB89ECDB59A
CEB69ACDB89ECCB9A0CDBAA2CDB9A2CFBAA2D3BEA6D3BFA6D5C0A7D6BFA5D8BFA4D7BCA1
DAC0A4D8C3A8D8C3ACD9C4AED8C3ACDCC7B1DCC7B2DFCAB4DDC9B1DAC7AFDAC7B0D9C3AC
D9C3AAD8C3A9D5C0A9D3BEA6D3BEA7D3BEABE0CFBCCDBCACC8B8A9C8BCAFC3B8ABC2B4A7
C4B9ADDDD8CFD9D5CEC4BEB8CAC4C0D5D1CDC9C2BEB4A9A1B8B0A7C2B9B6B6ADABC8C2BE
CECECBC1C2C0BDBCBDCED3DAB4C1CB95A1A9A0B1BD334F692B4E6E7F9EBC16395E648AA5
BFD7E1C9D4DACBD5D8CCD3D9CFD8DFCDD6DFCCD6DFCDD6DFCDD6DDCDD4DCCDD6DDC7CDD8
C7CED7C1CAD1C8D1D8C9D1DBC8D2DBC6CFD9C3CCD5C5CFD6C0CDD3B8C5CDBEC8D1B2BEC4
B0BAC0A0A6B1414D5E44596D5268756C7C8091979395847500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0028E11979A64CA68F6CA7916FA99171
AB9273AE9678B19B7EB29C7FBBA287C2A88CCAA98FC89C87C79782CDA48AC4A88EBEAA90
BBAA91BBAA8FBBA78AC1A98DC3AA8CC3AA8DC5AF95C5B199C7B29CC8B39DC8B399C9B196
CAB59ACCB9A1C5B6A0BEB39FBCB39FC3B8A4CBBEA8D1BFA8D2BEA6D6C0A5D7BEA5D9BFA5
D9C0A4D9C3A7D7C3A9D8C4ABDBC6AEDBC7AFDBC7AFDCC9B1DBC9B1DBC9B1D8C5ADD9C4AC
D9C2A9D9C1A9D6BDA6D4BCA6D3BAA4D0B9A4D0BAA7CDB9A6C9B5A4C9BAAADCD3C8D6CCC2
C1B5AAD4CCC0D2CDC3C4BDB2B7AFA4C2BAB0CEC6BFC1B8B0C2BCB4DAD6D2D4D2D0B9B7B3
CECFC9C4C5C0A1A09CACADAF566573364D5F96ACBA3C557214355997B5D086A2BB608096
BDD6E1C6D3D9CCD4D7CDD4DACFD6DCCED7DECBD6DCCBD4DDCED7E0CED7E0CBD4DDC4CDD6
C6CFD4C4CDD2C5CED4C6CFD8BFC9D1B7C3CCB4BEC8C5CFD6C5D0D6BEC9CFBDC8CEB6C1C7
B4BCC2B1B4BE565D6E5565794C606F6577817F8B8E9088843DB02800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A18866A18A689F8A68A18C6CA59173AA967B
B09D83B5A48AB3A28ABCA690C3A38EC69984D79482B65B4B9D3423BB644CCC987AC2A586
BBA688BCA68BBEA58CC1A78DC4AA8DC4AB8EC4AB91C4AD95C6B099C6B099C5B096C7B297
C2B29BA49B89817D707170656C6D656C6F678C8E81BCB4A2D1C1A8D6BFA7D8C0A8DAC2A9
D8BFA4D9C3A4D7C3A6D8C4A9D8C5ABDBC6ADDBC5AEDCC8B1DBC8B0DAC8B0D9C6AED9C4AC
D9C2AAD9C0A8D7BDA6D3BBA3D2BBA3D1BBA4CFB9A3D5C1ADCFBCACC8B8A8D5CABCD0C7BB
BDAFA1C1B2A2C8BDAECEC6B9C2BCB0C7C2B9DAD7D2D6D5D0B8B5B0CBC6C1CAC6C1ABA8A0
AFADA4ABABA88C8E8CB6B6B899A2AD586C7C9BAAB6BDCCD796AFBE8DA7BAA9C1D068879C
89AABBC3D5DECDD5D9CDD4DACFD6DCCED6DDCAD5DBC9D4DACBD6DDCBD5DFC9D4DDC5D0D6
C7D2D6C7D0D7C4CDD4C6CFD6C2CBD2B5BDC6A9B1B9B4BBC3C2CDD6BFCAD3C4CED8B8C1C9
B8C0C8BBC1C8909BA481939F8297A28DA0A9A1AFB6ACADB095837A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CC22F9885619A88679D8B6BA39173A59377AC9B82AE9E85
B2A38AB3A48DB6A68FBDA491C99A89A14E3DA52E1FB32418B42012A12912C98365C5A182
BDA386C2A78FC2A78EC4A98EC3A98BC4AA8CC4A98EC5AB91CDB49BC7AF95C5AE95BEAE97
8F87757272628A87789A94869A93887D7D7560645E74756BBEB5A1D3BEA6D7BFA7D7BFA8
D6BFA6DAC2A7D8C1A5D8C4A7D8C5A8DBC7ADDBC7AFDBC5AFDCC7AFDDC9B1D8C4ACD9C5AD
D8C3AAD6C0A7D9C1A7D5BDA3D5BFA7D3BEA6D0BBA4D3BFABD0BDABC8B6A2C4B59FC4B7A4
C7B8A8C1B3A3D6CFC3DBD8CFD8D6D0BFBCB5CBC9BFCBC8C0B3ACA5B0A79ECCC4BDC8C4BF
B3B1ABD4D4D3CACBCDB0B0AFC4C7C8C2CAD097A0A7A0AAB26B82932245646A8BA9345573
315473B8D3E2C9D7DBCCD3D8D1D8DECED6DFCDD7DDC9D4DACAD5DBCCD6DFC9D3DCC8D4DA
C9D4DAC3CCD5C6CFD8C6CFD8C7D0D8BFC5CFAEB5BDAEB7BEC0CCD4C0CED5C2CED6BFC8D1
C0CBD4BCC8D18494A1374C5B415966667E8685979EA4ACB3B0A9A840B42B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CC2309989649C8E6BA19274A19278A6967EAC9E85AB9D86B1A28A
B0A188B4A48BB6A28ABF9C87B6715EA83A27B12715B52110B22410B64B30D09475C4A285
C0A589C3A88CC2A78BC1A78AC3A98AC4A98BC6AB8DC6AB8DC8AD91C5AA91C1AC96968A7A
6D6D5F919283A39F8CA69F8AA9A18F9F9A8D7679725B615A92907FCEC0A5D4BFA4D5BFA4
D8C1A6DAC1A7DAC1A3D8C0A2DAC4A8DBC7AED8C7ADDCC8AFDCC8AFDBC8B0D8C6ADD6C5AB
D6C3AAD5C0A8D5BFA7D5BEA6D2BCA4CFBAA2CFB7A2CFB8A3CAB5A1CAB6A2C4B49DD2C5B3
E1D4C9C1B5AAC1B9ADCAC5BBC6C4BDB8B4AAB7B3A7D2CFC5D3CDC8B7B1ABD5D2C9D5D4CF
BCBAB6BCBAB6C2C1BEA8A7A1A0A19A939A9E3546566C7F8E849AAE17375A41607FA0BAD0
526F83A7C1CCC4D5DAC9D5D9CED5DBCED6DECCD5DDCBD4DBCBD4DACDD6DDC8D2DBCAD3DC
C9D2DBC4CDD7C4CED6C3CDD6C5CFD7C6CDD6BAC2C7ABB3B8C2CDD2C0CDD5C1CBD3C1CBD5
C2CFD8BECCD797A7B72F43583E56694A64726F858E96A3AA98989A62954D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0024DF179787649C8E6C9D8F72A1927BA49680A69A85A79B85AC9E87B1A18A
B2A189B6A48BB39B81BE91769C432DAE3720C54D33DA6B509D381DCB8164CB9F82C1A488
BFA589C0A789C1A88AC1A887C2A987C3A888C7AA89C7AA8AC5A88AC2A78BB3A48F676557
77796C9E9C89A6A08BA59E8CAAA291A8A0927F80775D675F737868CABEA6D3BCA0D6BCA2
D6BCA4DAC0A7DBC2A4DBC3A4DAC4A8D9C5ACDBC6AEDCC7AFDCC7B1D9C6AFD9C6AED7C3AA
D8C4AAD5C1A7D5C1A8D5C0A9D3BCA5D1B8A2D0B7A1CEB7A2CBB7A3D6C3B1C4B29FC5B4A3
CCBDAEC2B2A3BDAD9EB6AB9ECBC6BCD1CCC7BCBAB2D3D2CCD7D7D2C1BCB8B6AFA7C1BBB4
B2ACA4A59E95C0BCB58F8F8B9EA09CC7CCCE64717F647280C0CAD2ACB3BF8F959DBABBBC
B1B4B6909A9FC7D2D5CAD3D6CDD6D8CED6DBCBD5DAC8D4DBC8D3DBCAD3DCCAD3DCC9D2DB
C7D0D9C7CDD8C7CDD7C3CBD4C4CBD1C0C5C2C6CBC2C4CBC8C0CACEBECCD3BDCAD3C2CFD8
C2CFD8BECAD7AEBCCB7B8B9A7689976277827E939C9DACB4B6BBC0978C861BD40F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
22DD146699408C7D5B9586659B8D709B8E75A2967EA3977FA79C85A89B83A99980AE9D83
AC9A7FAF9D80B49D80BD9277A7583E982E14AB4A2BD58B69AF7554C79A7BC0A084BFA48A
BFA388BFA286BFA385BFA385C2A587C2A484C3A485C3A585C5A888C0A68B9588755C5D52
7A7F70989983A09C84A29E8A9E998B939084797C775A645E727769C6BBA3D1BCA1D6C0A5
D6BDA5D7BEA7DAC2A7DAC2A4D8C1A5D9C2A8DBC5ADDAC5ADDAC6AED9C5ADD8C4ABD6C3AA
D8C5ABD5C1A8D6C2AAD4BFAAD2BDA8D1BCA4CFBAA2CDB8A2C7B5A0CBB7A3C9B39EC5B09B
C2B09ECCBCAAC3B4A4BBAFA2D0CABFD6D5CFC4C2BCB6B1AAC1BBB3B7ADA7B1A49DC3B8B1
D2CCC6BFBAB5D1CDC8CFCBC9C2BCB9BAADAAC4AFB1B39697B38C8BC39392BB8782BA827C
B98481A67A7CBE9B9FC8AEB1CCC0C2CECDD1CFD3D8C9D1D7CAD4D9C7D0D6C7D0D7C9D2D9
CBD4DBC5CED7C7CED8C7CED7C9CDCDB1AE95ADA87DCBCAAEBFC6C0C2C9D1C2CBD5C1CDD9
B9C7D2C2CEDCBCC8D56A76864D5E6D63758076878F859299A1AAADBEBBBA43B83300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0021DC15
8473548777588B7C608D80659589709D917AA29680A39880A99E85A99C81A99A7EAB9A7C
AB9A7CAE9D7FB39F7FB99B7DC59779BA7F60B37C5AC59D7BBE9D7EBEA083BBA084BCA286
BFA386BE9F80C1A382BFA081BEA080C1A483BE9F7EC0A280C2A482BFA4868A7E6A595D52
6A7367838774898977898A7C82857B767C75646E6C57625D818272CBBFA7D0BFA3D2BEA3
D4BFA5D5BEA6D9C1A7D9C1A4DAC2A6DBC5AADBC6ADDAC7ADDAC7ABD8C3A8DAC5ADD8C4AC
D8C2ABD7C2ABD7C2ABD6C0ADD3BEA9CEBBA2D0BDA4CDB9A1C8B49DCAB59FC7B39BC7B29C
C3B29EDACEBDCCC0AFB9AC9DBCB1A2BFB7ACB7B0A5B0A69BC7C1B6D7D1CDC9C2BFC8C0BD
D7CFCDD1C5C2B8A19DC19B95B6817BAB635FA347479F33329F2423A42021A41C1CA31919
A2191C9E1C219B232A9F363DAB585EB78084C4A7AACFC5C8CFD1D3CAD2D6C5D0D5C9D2DB
CBD5DEC7D0D7C5CFD5C3CCD2C7CCCABAB89AA69D5DB3AB6ECBCBB2C6CACCC4CDD6BCC9D5
B2C1CCBBC9D4B7C3D06A76892A3C4E495F6D62748079888F7F898B9C9D9E88726700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00817154
837359887A60847B618B826A9990779F957CA2987FA39980A69C82A59A80A7997CAE9C7D
B19E7EB29F80B39F7FB59E7FB89E80BA9C7FBCA081BAA081B89E80B89F82B89F80B99D7D
BB9D7DBEA07EBEA07CBEA17EBEA17FBEA07CBE9E78C0A078C0A278BDA17B8E7C6455544B
5A635E676E686D736D6A726D67706B5D6A6654625F5B645AA7A38FCDBEA3D0BFA1D2C1A3
D2BFA3D4BFA4D7C2A7D8C2A5DCC4A9DCC5ABDAC6ADD7C5ABDCC9B0DAC5ACDBC6ADDAC7AE
D8C3ACD6C0A9D5BFA8D3BDA8D4BEA9D0BCA5CCBAA2CCB9A2CBB79FC9B59DC6B59CC4B29A
C2AE99C1B09DBFAF9BBDAC99BCAB98BDB4A4D6D0C6C7C0B9C4C0B7D4D5CED0CCC6B5A49D
C3A19CBC8480AD5B56A53733A1221DA31512A80E0FAC0C0EB20B0CB70C10B50B0DB70A10
B30A0EB30A10AE0910AD0C14A70F159D181D9A3337AA666BC8A4AAD4CBCECBD0D4CAD3DB
CAD5DCC9D4DAC5D0D5C5CED5C6CFD0CACCBCB6AE7CADA25CC7C190C9CBBCC1C9CDBAC5CF
B7C5CEB5C2CBBFCBD88C98A86573816577825C70787B8C9399A8ABA5ABAF96898300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001FDA145D913E7B6C53
7C6F5780765F847C668A846D958E779A927CA09882A19A80A49B82A89E85A99B82AC9B81
AD9C80AE9D81B09E80B29F81B4A080BAA384BAA183B89F80B59D7DB69E7CB49C77B49C77
B59C78BDA17FBA9C7ABB9C79BE9F7BBF9E79C09F76BE9D72BE9E6FBE9D70A58C6D5C5548
525855535E5D56636055615E515C59505B57545C52898776C4B7A0D0BCA2D2BFA1D2C0A3
D3BFA4D5BFA7D3BFA6D7C2A8D9C3A8D8C2A7DAC4ABD9C5ACDAC7AEDAC6AED6C4AED7C5AF
D8C4AED9C3ADD5BFA8D3BFA8D2BEA9CEBCA5CEBBA3CCB8A2CCB7A0CAB59EC7B59CC1B197
C1AE96BDAA95CAB8A6D2C1B0C2B1A1C3B7A8D6CFC5D3C8C1B2A49AC0ABA2C6A098B6726B
AB4740A42421AA1715AF0F10AF0A0CB2090AB4090AB4070BB6080AB7080AB70709BA080C
B7070AB3040AB3060AB5070AB2070AAD080DA90E149A111A972E37B2757AD1BBBFCECFD5
C8D1DAC7D1D9C4CFD5C6D1D7C4CFD2C4CDCBC2C3B0B1A87AA69A62BCBA95C0C6BCBEC7CC
B8C1C9B6C3CBB7C5CFA7B4C26978885C6E786D7F847F8C92929DA2A3A8ADACA6A21BD40F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00786951726953736C57
8C85748F8877857E6C8B8471958D7A9C9480A39984A49983A79C86A69A83A79A80AA9980
AB9A81B1A087AF9E82B2A184B3A184BCA88BBAA185B79E80B49B7BB39A77B19A73B29C75
B49D77B79C79BA9C78BA9A73BA9972BF9D76BF9D74BD9A6FBC9B69C0A06DBCA07589775C
5955464E564A555E536064597471647E76678E806CBDA990CBB599CFB99ED3BDA3D3BDA4
D3BDA5D4BCA4D3BDA5D5BFA6DAC3A9D8C4A8D8C4AADAC5ADDCC6AEDAC7AFD7C5ADD9C7AF
D6C3ABD6C1A9D6C2AAD4C1A9D0BEA6CDBDA3CDBCA2CBB9A0C9B49CC8B39CC8B49CC3AF97
C7B099C2AB97CCB9A8D4C4B4C8B7A8BCA899BCA899C1A497C69889BC7468AC433CA61E1B
AE1210B30D0BB50B0BB6090BB40608B5060BB30608B30607B40808B50808B50707B60608
B40406B60609B00406B30608B40608B00609AF060BAB070DA30B1295191DA25357C9ACB0
CDCDD3C6D0D9C5D0D9C5D0D6C3CED2C3CDD0C5CBC9C7C6B4A9A173A29D66C2C3A5C2C9C6
BEC6CCB5C0C9B7C3CDB3C1D03F5067293C505E727F82949C849096848B8E9894903DB229
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001CD81270684F6D6C5885877A
BDBDB6A7A59D868172918D7897917D9B9480A29A85A49B87A79D88A49880A89A80AA9B7F
AB9B80AFA084AF9F84B1A187B19F83B9A387B39B7DB59C7DB29978B59B76B49B73B49C74
B39C73B79E76BA9E73B99B6FBA9A6FBE9E75BB9870BD986CBD9968BF9D6CBF9E6EBA9C70
9E86637F70528D8165A08F74A99278B69D81C5A98AC8AC8ACCB293D0B99CD2BDA2D4BEA6
D3BDA4D4BFA4D3BEA3D5BFA7D8C2AADAC5ABD7C1A8DCC4ADD9C4AED9C7B2D4C4AFD4C5AF
D6C4AED4C2AAD5C3AAD2BFA6D2BEA6D0BCA4CEBAA1CCB89FCAB69EC8B49BC9B59CC7B39A
C5B098C9B29CC6AE9BC3AC99C2AB98C2A492C89C8AC68073B24B41A9231CB01410B30D0C
B90D0BB80B0BB6080AB5060BB6070CB5060BB40709B70A0BB30907B50B08B50907B50709
B6080AB4050AB00506AE0405B10707B10707AE0606AF060AAC060BA7090E951116954248
C5A6ACCDCBD2C8D0D6C4CFD5C1CCCFBFC8C4C4CBBFCBCCB3C4BF86A19949B7B278C7CAB7
C3CACCB7BFC6BAC4CDBBC6D35161733445575D7180697F8990A2A99FA9AE92918D3EB42D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF001BD711508939726F5C939788B5BFB7
C1C7C6B0B3AF86867A91907C94927D9B9782A09A87A29C88A19A84A49B81A89C82A99B80
A99B7EAC9E81AD9E83B2A186B19D7FB1997AB19779B09677B19774B49B74B19771B39A74
B39971B59870B49669BA9A69B79766BC9A6BC09A6EBE986BBD9968BE9C69BD9D6BBE9E6E
BE9D6FBE9F72BDA076BFA47CC3A67FC8A682C8A781C9AC83C9AF87CCB593D3BEA0D2BEA2
D1BDA2D3BEA5D4BEA7D5BEA6D7BFA8DAC2AAD8C1A8D7C4ACC9BCA8B1A8979F9789A29A8D
AEA89AC3BBA9CDC2ABD1C2A8CFBEA5D0BEA5CFBBA1CDB9A0CAB69DC9B69EC8B59DC7B39B
C6B19AC8B09CC7AC98C5A793CDA795CE9383BA5D51AA2924B31715BA0E0FBB0B0DBA090B
BB0A0AB8090AB9090BB50508B40608B50709B50909B60A0AB60909B70A09B80A0AB80A0B
B7090BB5060BB20509B20509AE0305AF0506B00607AD0305AC0408A9060CA3080D950F15
933E42C7A8ABCBCBCEC4CDD1C5CDCBAEAF9AAEA977B8AD62AFA339A79920A59C39C8C795
C5CBBDBEC7C9BCC5CDB7C0CA7A89926675816B7C857B8C948E9FA59CA9AEA8ABAB6A9C52
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004E863367604A6B685796998FB9C3BFBFCBCB
C2CCCDB8BCBB8A8B838D8D7B9795819D99869F9A87A19C89A09A83A39C82A49C82A89E83
A49679A99A7BAA997DAB9B7EAF9B7CB0997AAE9776A9916CAD946DB39872B59B76B09571
B3956FB7976DB9986AB69563B99863B99662BB9565BD9767BF9A68BE9C6AC1A070BF9F70
C09E6FC49F71C3A175C2A378C3A37AC6A57CC7A67EC9AB83C7AB84C8AE8CCFB698D2BCA0
D1BFA2CEBEA2D2BFA6D6BDA7D7BFA9DAC4ADD5C2AFB8AE9C8A8776908D7DA7A0939D958B
7C786F7C7C72B8B4A4CEC2ABCDBEA5CEBEA5CDBCA3CEBAA2CBB79ECAB59DC9B39DC7B29D
C7B19CCAAE9BCFA797D49E92CD7E73B03D35AF1B16BB1211BD0C0EBF0B0EBC0809BD090C
BA070ABB070CBB080BB70509B40608B30608B20707B40708B40408B6050AB7070AB7070A
B30507B10308B1070CB0040AB10509B20509AE0407AE0508AB0507AA0509A70409A4090C
931114984749D3BABACACECFC6CFCCC1C2AFB1A770AA9A3DA9991AA9980AA49511ABA33E
BDBE82C3CAAFBEC7BFB6C2C48A9AA63F55674D6877748E9891A4AA8893998C8E908A786D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00518633665F4B68655790918BBAC2C28FA0A4A9BBC1
C2CED2C4C8CB8B8D868D8E7F9696849C9A889D9A899E9C88A09B85A29C85A59C86AA9D86
A7977BAA9979AC9979B29E7FAF9B7CAD9978B19B79AE9975AE9874B19877B49B7AB29775
B49570BA9970B59467B89364B7925EB9945FBD9661BE9866C39F6EC5A172C3A073C19E71
C19F71C19F71C2A177C3A47DC6A780C7A780C8A881CCAD87CAAC87CCAF8DCDB394CEB69A
D0BDA0D0BFA2D4BFA6D6BDA7D9C0AAD6C0ACC3B3A57E796D999789B8B1A0C0B4A3C3B4A7
AFA49B74736D76776EC5BEACCFC0A9CFBFA6CFBFA5CDBBA1CDB89FCEB59FCCB39DCBB29C
CCAF9AD4A696D2837ABD5149B12923B71512BD0D0DC20B0FC0090DBE0A0DBD0B0BBA070A
BA070ABD080DBA070BB60609B40608B20608AF0507B3070BB1060AB20609B2070BB2080A
AE0909AB080AAC0A0EAB090EA9060AAE080DAE0708AD0508AB0608A80307A80307A80607
A1070B880D12A66668D1C6C7C5CFCEC3CDC7C3C5AFBAB481A89938A19009A69602A79A0C
A79F25B2AE55B7B985C3C9B4A9B3B13547513C56644F6975798F98A0AFB6A0A5A8897A72
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF001BD711665D476764548A8C85B4BABCB2BFC45A7178637D82
C1CFD3C8CCD09092908C8E829494859695869A98889D99869C9683A19A85A59B87A99B86
A6967DA89879AB9A7BAE9B7BA79472AB9975AA9775AE9C77AF9B77B19B79AF9676B09573
B49671B39369B69566B59260B99460B9935DBD9660BC9965BE9D69C3A172C5A377C5A277
C5A175C19E74C1A177C5A67EC5A880C7AA83C9AA86CCAE8AC9AB87CFB18FCBB091CDB596
CCB89AD2BEA2D3BEA6D5BFA7D8C1AAD6BFAF9C8F8475736BA4A299BCB7A8BEB5A5C2B8A9
B1AAA083847F5F6660AEAD9FCCBFABD1C0A7D0BDA4CFBBA3CEBAA3CDB7A1CFB6A1D1B29F
D8A595CF766CB7342CBD1F18C11510C30F0DC20D0BC1090BBF090BBC090BBA0909BA0A0A
B80809BA070AB70609B40607B30709B1070BAD080AAA090DA70C0DA00E0F9D13159D1C1F
9A242798282D95293092242B921B2097141B9D0E12A20C0FA5080BA70609A70405A90506
A604099B080F831C21BF9697C8CACAC1CECFC4CBCBC6C7B6ACA363A19018A99704AD9C04
AF9F08AC9F14A59A2CC0B96EB9B8886A70586C7A7568787C7180848F9DA09DA4A6A29793
1BD30D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004C873464645285887FA9AEAFBDC5CD909FA75C7076798C91
C6D1D7CBD2D68F95928B8F848F92849596889B97889F98869D96839F9683A29482A49582
A3947BA5977AA7987AA59476A79474B09B7BAE9978AC9771AE9970B09A72AD9671B49B78
B39671AF9167B59466B59361B7945FB7945EBB9460BF9965BE9B68C1A070C2A175C2A176
C19E74C09E74C4A379C5A57CC3A37AC5A57CC8A782CFAF8FCEB190CBAF8ECDB293D4BB9E
CEB99ED1BBA3D2BEA6D4C0A7D5C0A9D4C0AF897E7575736F93948FA9A89EAEAB9EAAA69A
9B9C94767E795B6760A2A496CDC1ADD0BEA7D0BEA7D1BFA8D2BEA9CEB6A2D5B2A1DDA094
C9635BB62621C21814C7130EC7110CC70F0CC50D0BC30B0BC00B0ABC0907BA0B09BA0A0A
B90909BC090CB60708B40A0AAF0F0DA40F0D9A16149B292B983E44924E58885665734E64
664E675C4A655A4B655F4F666E5568835B6B8D4F5A8C30398E141A9E0A10A5080BA9060B
A6040AA1040A920E128D3F42CFBDBDC5CBCFC2CBD2C2C9C5BEB990A69732A7930DA8970A
AE9E08AE9E04AA9A06B09F19A99C2977712B5F68536A7B7D889A9E8C979A848688968A84
3AAB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF001AD81262604C7D8378A1AAA9AEB8BCBCC6CEA3B0B7B1BEC4B9C4CA
C9D1D9CBD3D79EA4A28B8E859393849591839B93879D94859E95849E9582A0927FA39481
A39680A3947AA4957AA5957AA79478AF997AAE9676AB936EAD976DAD996FAA956EB39A77
B69B78B2936DB39366B2915FB3935DB5935DBA9561BD9765BF9C6BBE9D6EC09E72C3A076
C4A076C5A47BC5A67EC3A47DC4A47AC6A57BC9A881CBAC8ACBB190CBB190CBB293D1B89C
D3BAA2CFB8A0D6C0A8D2BEA5D6C1AAD8C2B08E83796F6F6E7D807F8A8F888C9189838B83
757E7B5F6F6A5C6960B0AF9FCFC2AED1BFACD1BEACD3C0ADD5BDAADAB4A3DF9C92C1504B
BA1F1DC61513C9120FC60D0AC60D0ACA110EC9100DC50C0EC20B0DBD0A0CB9090BB9090B
B80A0BB80D0DAE0D0DA31516A030329E4C5386566260496237335522295219234F1B2652
212E55303D633B496B3A4B6C32456838496C323C5B5A4D658856668D2F3A96121AA1090E
A5060AA305099E0A0D821316B88A8CC6C5C7C2CCD2C3CDCCC1C3A8A3974898891F645806
9E9312AC9E08AFA003AE9E04A696098D831E3D3F1E394A4D657B8494A2A8A5A8AA9A8F8D
3AAC2400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00655F47676C5E99A5A0ACB9BCB2BEC4BBC8CFBDCBD2C1CFD7C4D1D7
C8D1D7CCD2D5A7ADAB8A8C838E8E809995869A94869C95879D95859F95839E927FA0937E
A39781A3957DA3947BA5957BA7957AAC9478AA9172AB9570A8956BA9966BAC966EB09872
AC916DB0916CB19165B09360B1945FB3955FB89562BD9966BB9967C0A071C5A67AC7A67E
C7A57FC3A37DC3A681C6AA84C4A780C6A680C9AA85CBAE8CC9B18FCDB595CBB495D1B99D
D2B9A0CFB79ED3BDA4D4BFA7D6C0AAD7C1AFB4A4996A676362696867716F69737063706A
5E6D675B685F7F8678C4BEACD1C3AED4C3AFD6C3AFD7C1AEDFBBABDF9B8FBD4843BD1E1E
C91314CC1011CB0F0FCA0E0ECA0E0DCB0F0ECC100FC60C0DC30C0BBD0A0BBA0A0AB50C0A
AE0F0EA61D1EA53F42985B69674E6835355A16264E182C552F42665A6A89697289848595
9898A3969BA8A4AEBC94A6BA3451718CAFD16B8EA89EB3C98787998B6C7C954856921921
9F0A10A10409A0060A910D108D4346C6B8BCBFCACFC2CECFC5C9B3A59A5592832855490B
71680B988F0FACA20DAD9E06A797069D8F177B75346970636F7B807E898E98A1A3A7A6A4
47BE3800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0033AD225E60518D9790A9B6B7B3C1C8B7C5CDBAC9D1BECED6BDCED5BBCCD2
C5D3D8C9D2D5B3B8B88488818B8C809391849894889A94889F968AA095879E917FA2937E
A2937CA2927BA4967DA09177A39076AA9176AA8F72AD9573A8926CAA946BAE976FAC936D
AC9168AD9062B19160B2935FB39562B39462B69665BA9966BF9E6DC4A477C8AA82C8AA85
C5A583C6A785C3A684C4A886C7AB88C8AA88CBAD8DCBB092C9B091CAB495CAB699CEB99E
D2BCA2D0B8A0D2BCA4D5C1A9D5C2ABD6C2ADD5C1B0A6988C6C69616C6F69767B727D8276
7F827689887ABEB7A6D0C3B0D2C2AFD4C1B0D5BEAEDAB5A9E29C93C14A44C01E1CCE1517
D11114CD0F11CF1113CC0E0FCC0E10CE1012CC0C0FC80C0EC30C0CBD0E0CB2120FA81F1D
A9444898606F584A66232D56142855273C624D607776808C8C9196AEB1B4B5B9BCA9ABAD
CCCFD56471817A8D9E90A4BC0B284F2F547C7BA2BAA5C3D0C7D6DFC6C6D0B99EA79D565D
901A209E0A10A1060A99080D7F1B2093717BBFC5CFC3CCD2C3C6ADA49C4F8B7B1B6C5B13
7F731B4D4801959219A39B0DA19403A3940C978E2B8E92668A968C97A2A3869091888987
689B4E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00488234787E75A9B3B4B0BCC4B1BFC8B9C7D0BDCDD6BFD1DBAEC2C9B3C6CD
C3D4D9C6D1D6B8C1C28388848B8D82919185939185969286A0988DA09689A09586A19382
A2927FA4947DA3937BA29278A49277AB9378AB9174AF9576AC9472AB936EAD956DAB926A
AB9165AD9061B1915FB1915EB49562B49565B79767BC9C6ABD9D6DC1A175C6A67DC3A47E
C5A683C5A687C6A98AC6AA8BC7AD8CCBB090CBB094CAB196CCB498CAB498CDB89DCCB69C
D0BAA0CEB79DD2BEA4D3C2A9D5C2ABD7C2ADD9C4AED9C7B3C0B3A2B3AA9AB5AF9FB9B3A3
BFB6A5CEC2B0D3C4B3D6C6B6D7C6B6D5C1B2DDBAADE09B92BB453FC72422CF1716D01313
CF1111CF1111CF1110CD100ECB0F0ECD0F10CE0E13C90E0FBD100FAD1A19AB42449D6471
57486622305D162F5C32476A69738A8E919AB0B2B1C5C5C2ABACAACED1D2B3BBC28C959D
C6CED6556477384C61A9B9CB62758C4D678090ABBCB7CCD6C5D5DDCAD2DBD3D1D6C1A6AA
954A4F91151C9C070B9B070A820B117A444EAAABB6C2CBCEBDBD9DA49A3F958313826C0C
90801A4D46016261087471089B940FA19407A2961778721A696F3E8C9782ACB8B1A3A6A0
82756200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006F6D5EA3ACAAB2BEC3B5C1C9B6C4CBB8C6CEBBCBD5A7BBC480979FB3C8CF
BDD0D6C1CFD4C0C9CC868C898B8D848E90849392869491869D978C9A9285A197899F9383
9E917F9F927CA2967DA3967BA5967CA49278A99477AA9272AD9572AC946FAB926BAB9269
AB9065AC8E61AF8F5FB49463B29260B59462B69664B99968BE9D6EC0A074C0A279C2A680
C3A886C4A78BC5AA8EC5AA8DCAB092CBB394CBB295CAB197CCB49BCEB8A0CBB79DCCB79C
D4BFA3D0BBA0D0BCA2D4C0A7D6C1ABD7C4AED7C4AEDDC9B3D7C6B1D8C8B5D9C8B7D7C7B7
D7C6B6D8C7B6D7C8B6D7C8B8D6C2B4D9BAADE3A297BF4B44C2221DCD1614CF1311D01311
CF1211CE1111CC0F0ECC0F0DCC0F0DC90C0DC71212B81717B4383AAB6573675573253662
143261334D756D7C90A0A5A7CBC9C5B9B4B1C4C1BED1D0CFC6C2C5B8B1B3C9C3C7A29C9F
ACA4A2B3AEAFA5A8ACA1A7ACBAC7D25972886B89A1A4C0D2BAD0DCC7D4DDC9D1D8D1CED3
B89399882D34940E13990509900A0E7E3039897D87C2CCCDB6B895A5993CAA9715A58E07
A48F13645703554F0B4849086E6E0C968F0E9F93089B8F0C9C972887863B989B76A9AB9E
9D908400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF003AB62A92978EBAC7CBB2C2CAB5C4CDB3C3CCB4C5D09EB2BD7D949D81989EA0B5BC
82959CC2D0D8C5CED3868B8C8A8C859191869594879D998D9D988C9B93879B93859B9281
A09583A29584A09480A39881A59881A3937BA69377AC9576AF9577B09575AB906BAE936C
AB8E66AE8E63B09062B39464B59463B59363BA9568BD9B6DBD9C6FC0A076C5A882C2A988
C4AA8CC4AA8EC7AD92C6AC91CAB196CAB498C9B599CBB69BCBB89DCBB99ECCB89DCDB89D
D2BEA3D0BCA3D2BDA4D4BFA7D6C1ABD6C2ADD5C2ABDAC6ADD8C6AFD8C6B3D9C9B8D6C8B8
D7CAB8D5C6B4D4C5B2D4C2B2DABDB0E4AA9FC3564EBF221CCD1812D0140FCF100CCF110E
CF1210CE100FCC0F0FCD1010C80E0DC21515B72629B557647F5A743138651430612B4971
677B92AFB6BCB3B2AEB0ACA1D7D1C8D3C8C4B3A09EC9AAAABF9595B27D7DAD7473AC7270
B17B74C0938EC8ADAC8A8083B8BFCA2239590F2F58799AB4ABC3D1C7D5DDC9D3D9CDD3D8
CFC1C7A36B7185171F99090F970B0E81212969505CBFCAD0C1C5B5AEA467A9972AA8930C
A8930A928006867A135049046563116965069B910CA09305A6980BA7991C998F37908A5F
9588731CD40D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0069A454B6BDBDBBCAD4AFC2CCB7C8D3B4C6D19CB1BC76909A79939B8BA2A88CA1A6
A7B7BDC7D2DAC8D0D88F9396888B8690908798978B9F9B8F9B968A9891849D95869E9584
A29886A59A88A39885A29782A0937EA1927AA59479AA9576AB9273AE9471AD906AAE9069
B09268AE8F62B09062B29263B49364B69467B8966ABB996FBD9C73C6A681C8AA89C1A78A
C5AA90C4AA90C5AC90C8B093C7AF94CAB39BC8B298CAB499CDBA9CC9B89AC9B698CDB89B
D3BEA2D2BDA3D4BEA7D4BEA7D6C1ABD6C1ABD8C4ACDAC6AEDAC7B0D7C7B1D5C7B4D4C6B3
D5C6B2D6C5B1D3C2AED6BFADE5B5A9CE6C63BD2720CF1A15D51511D4170ED3150ED1110F
CE110FCE1210C8100EC31311BA1A19B74146AC7084554D791B3367213E6B5C6F8A92979F
A2A09BC3BDB4C4B8ADAC998EBA9B92BD8B87B16663A84344A52D319F1E219B17179B1417
9D1A1A9920219D3B3DAB686ABC9DA07A7988364762748CA1B6CBD4C8D5DCC8D1D8CAD2DA
D3D2D7BF9FA4852E38930C1499080D83171F603F4DA9B7C2BBC7C8C6C6B3ADA667A39327
A6930BA18E04A7971283760A5C55064A46019891139B90059D9104A69A0AA39618B0A351
A3936B3AAA1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A09E8DBFCBD0B4C4D1B2C3D2B1C2D1A2B4C2768E9B738F9A7C99A36A868D92A9AD
BECED4C7D2DBCAD2DA969CA0888B878F908696958999978A9F9A8E9C95889D9486A09787
9F9584A19886A39986A0947FA0937C9F9078A39379A89479AB9376AA9070A98E69AE9269
AD8F64AF9063B09063B39265B59368B8956BB49369BF9F76BD9F78C0A27DC2A585BFA387
C3A98EC1A98DC5AD90C4AE90C9B498C7B297CAB499C9B298CAB59ACAB69BCBB79DCDB9A0
D3BEA5D4BEA6D5BDA7D7BEA8D6BFA9D6C0ABD6C0ABD7C2ACDBC6B0D8C6B0D7C5AFD8C5AE
D6C4ADD8C6B0D8C2AEE2BBACDB8A83BB312DCB1C15D41911D41710D21510D31410CF110F
CA100FC61311B81917B12E2FB85C678262802C3B6E1B3C733E5B828791A0A6A19FAD9E94
B19D8FB59A8DBF948AB6716AAB4A46A22826A51515B31214B20B0FB0090EAC0708AB060A
AB0709AA080CA50B0F9813159B3E3BCA9E9FA5A3B15A7288B1CBDBC1D1DAC7D1D8C8D1DA
CBD1D9CFC2C995565F89121C97080F851017693C47919CA9B4C6CFBAC3C4BABCA7AAA25F
A3941FAC9B0BAE9F06A798099185106E6404988E10817707837B079E9508A49809A2941D
B6A55849BB2000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4A298BAC6CDB0BFCDB0C1D1A6B9C9798F9E6E89954A69724361686A8489A6BAC1
BFCFD6C5D0D8C8D1D89EA5A9878A86918F869593879795899A978B9992869C92869D9183
A19484A19584A29683A29480A1917C9F8F77A29179A59278A99274A99070AB906CAD8E66
AD8D61B08F64B19067B09168B6956CB5946AB3946ABB9E76BA9D77BEA07BC0A180C3A487
C6A98EC6AC91C5AB90C3AB8FC3AE93C8B398CAB39ACCB49CCDB79FCBB59DCBB69ECDB9A1
D1BCA5D3BEA6D2BCA5D2BCA4D8BFAAD8C1ACD5C0ABD7C3ABD8C4ABD6C3ABD7C5AED6C5AE
D8C7B0DAC8B2E0C3B0E8AA9DB8423BC6201CD11811D41811D4160FD51511D31310CC130F
C2140FB3211FB95860A5738859527A1B396F264B7C7086A2A4A7AAB3A99EB7A395BC9E8F
C39386BE746BAB413DA71F1EAD1112B30C0EB7090BB9080BB70609B4060AAF0405B00607
B10708AF0506B2070BAC080B9E0D109A353B956F811725465B7C97BDD4E2C5D1DAC7D0D9
C8D0D9D1CCD5AB7F88841E28950B13870B13753B48717786B4C9D3B7C5CCBDC4C3C2C0A5
A59D4DA79917AD9D04AA9B04A596089B8E06A0920B7D700C5F59008C880DA1970BA29509
A2911B50C11500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0093938BB7C4CDB0BDCDAABCCC849BA8718C984C6B742142466F8B8EA3B9BEB9CBD3
BACCD5B7C9D0C6D3D7A8B1B3868B8790918994948A95958B9592899A948A9890859A9183
9F95859C9382A39786A19482A29582A0917BA29278A79377AA9374A88F6FA88D69AB8F65
AD9063AF8F65B2926CAE906AB3966EB0956AB4986DBDA07ABC9E7CBA9C7BC1A283C6A78A
C7A98EC6AA92C8AD95C4AB93C4AE96C9B49BCDB79FCCB7A0CBB79FC9B59CCEBBA2CDBCA1
CEBDA2D0BDA4D1BDA4D4C1A7D6C3ABD4C1ABD4C1A8D7C3AAD5C1A9D9C6AEDAC9B2DACAB3
D8C8B2DBC6B3E9BEADCB6C61BF2821CF1914D21511D41711D5170FD5160FD1150EC41811
B62D29BB6D756B5B7D243769173B703D5D8590A0AEB2B0AEBAAE9FBAA893C3A290C98D80
B04F47A82220B11414B50B0DB6080ABA080BBC080BBA060BB70509B40608AE0304B00305
B00607B10406B00607B10507AE080B980A13AA57625C5067415A73B1C8D5C4D1D8C8D1DA
C8D2DBCFD1D9BEA5AC802D36900E16890A117C3A475F6372B0C6D2B5C4CDC1CDD1C5CBC6
BBB98AA5982DAC9D0DA89803A59602A09102A3920880730D5F5804615F078784119E960A
9F8F0A4CBE0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
73A0458B8C84B5C2CAB2C3D195AAB8728B985C798321404857767B4D696FA7BEC690A7B0
7B949B9EB4B9C6D5D9AFB9BB858D8A8F938C92938A96948B98948C9A968C9994889A9485
9C95839E9684A39586A39383A39381A0917BA6967CA9957AA89274AA9373A78F6AA88F68
AA8F65AD8E65AF8F68AF916AB1976FB3966FB99B76BA9D7ABB9E7DBB9E7FBFA284C4A789
C7AB8FC9AE93C6AC92C4AC93C5AF97C8B39ACBB79FCBB69FCEB7A1CDB69ECEB8A0D1BDA4
CFBEA4D0BFA6D1BFA7D2C0A8D3C0AAD6C2ACD6C2AAD8C4ACD9C6AFD9C7B0DCCAB3DBCAB6
D8C7B4DFC0B1E1998FB8362ECD201AD51A13D41610D6170FD5170ED0160DC61C14BC3C38
B474814C4C70183A6C244877617997A4A9ADBAB1A7C1B0A3C2AA9ACAA190C57C6FAC3A34
AF1917B70E0EBD0D0DB8080AB7060BBA070BBB070BB90409B70508B50609B00307B10408
B3060AB20509B10408B20509AE0508A6090D972B32A2839572869F9BB6C6C3D4DCC5D2DA
C4D2D9CAD3DAC3B6BC86414A8D111A8C0A118038454F5161B0C8D5B4C4CCC0CFD5C4CECF
BEC1A4AFA956A99B20A8970BA89805A29200A4940593850C5B53034848054B4D01908C13
9F910B92740A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AA8F688B8E87B3C3CAAABFCD7890A064808D28465154727B4B69705A767E87A0A8516A70
92AAAFBDCFD4C5D1D5B9C2C4838A898C908A94958C98978D97958999968A9C978A9B9385
9B94849D95869F93849D907EA2937DA4947CA3937AA5947AA49174A69271A48F6AA9926B
A88E65AE9065B2916AAE9069B2956EB79975BB9E7CB69C7BB79C7DBBA083BDA285C3A88A
C3AB8CC2AA8EC7AF95C5AD95C1A990C5AF96C9B39CCAB49DCBB49BD0B69DCEB69ECDB6A0
D0BCA8D0BEA8CFBDA7D3C1ABD6C3AFD6C2ADD6C3ADD4C2ACD8C7B0D7C6AED8C7B1D9C7B4
DCC3B3EBB6ABC35852C3251FD31D15D61A13D51811D2150DD0180FC41E15C24848AD778A
3B4570183E724A698E8E9EAEB1B0B0BFB0A4C5B1A1CAAEA1D09E93BF655DAB2924B11411
B70C0BBC0B0BBC0A0AB9080AB60709B60609B6050ABC070CB9070BB6070BAF0509B0060A
AE0609B3070BB10407B20507AE0406AA070A93181F7949680F1F4D2D4E73B6D0E0C2D3DB
C4D3DACAD3DCC6BDC592566089121D8B0912843A483F3F52AEC8D6B8CAD3BECCD4C3D0D6
C5CBC1BABA92C3BB6CAD9C29A7950AA79603A29301998B048F8514564E02514E07646204
979011947E1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
AD926C919290A9B8C68FA5B66A8798304F5D45646E4C6B75506F76567177A4B8BFA3B5BD
9CB3BB889FA6C5D3D8C0C9CC878E8E8C8F8D90918C93928B98958D98948A9A95899A9486
9993839E96869C927F9F927CA0917AA4967CA2947AA4957BA69578A69372A6916EAA916D
AE916BAE9167B1946BAD9069B39772B69A77BCA281B79D7EBAA081BEA388C5AA90C0A789
C4AB8EC3AA90C6B095C7B095C3AB90C6AE92C6AE95C7B199C9B49BCEB69CCEB69DD0B9A3
D0BAA4D2BEA6D0BEA6D2C1A8D4C3ABD7C5AFD6C4AFD7C6B2D6C5AFD6C6AFD7C6B0D8C3B0
E2BDAEDE8D84B93028CF2017D61A13D51612D11411CF1711C41F17C14D4CA97B92344273
193F735D7998A8AEB4BBB3AAC1B1A3C4AE9DCBAD9ED6A095C05E57AD1E1BB6100FBB0B0D
BA0A0CBB080BBC090CBA090CB50608B5080AB40709B4090CAF0A0EA90D119E0E109E0E11
A40B0FAC070CAF0509B00609AF0508AB060A96141C804C681525531B3F65A3C2D4C0D2DB
C4D2DAC9D2DCCDC4CF97606C8715208C0A11863A4736374CA9C5D5B8CAD5BCCAD5C1CFD9
BECCD0C8D0C9C8C6A3B0A652A99A1BA39305A292019E90039D9208978D0F776C0C5F5700
8C840F98851400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A588608F8E8CA1B0BD8097A74C6A783655604D6B744E6C7457747986A0A791A6AEA2B6BF
778F976A8288C2D1D9C5CDD48B91938E939090928D95958F9B97929C9590978F87979285
9A97879B96849D95829E927FA0927CA3947DA1947BA2957BA59579A59272A79070AD9172
AF9472B19772AF936DAF936DB49774B79C79B59C7AB8A081B9A485B8A487BDA98CC0A98D
C5AD92C5AD95C5AD94C5AC92C7AD94C6AD94C9B198C6AF98C7B39ACAB69CCEB89FCFB9A1
CEBAA2D2BDA8D1BEA7D0BFA6D5C4AAD3C1A9D3C1ACD5C3B0D6C5B0D5C5ACD6C4ACDFC3AF
EAB5A5C0554AC4261BD51E14D51812D31614D11713C31B15BF49499E72893245761C457A
6B87A5AEB3B7BFB5A9C5B4A2C5B09EC9AB9AD1988DBD574FB4201CBF1212BD0B0BBC090C
BB080CBC080BBA070BB8090CB40A0AAE0B0CA40E0FA11E20A0363D9D4C568F505C92515C
9E3B429C0F14AD070CAE0309AE0407A9080B9820266F475F47618585ADCC8DADC1BED4DE
C4D3DAC8D1DBC7C3CC98637086141F8E0C14883A49332F47A8C2D5BACBD8BAC8D3BDCBD4
BECFD6C3D0D5BCC0AFABA267B1A43CA39415A59509A192039D91029D8E049F900E796D07
847A0A8F7E1042B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A07F5593918D97A6B1849CAA31505C4B6C74496A6D4D6B6E88A5AA546E7591A8B1899FA8
ACC4CB81969DC0D1D7C6D0D58C9596878E8B8F928D95958F99958E9D968F9990899A9286
9C95869C96859C95839B92809D927EA2967EA2957CA3957BA19176A69376A89276AC9377
AF9577B19979B29878B29876B29976B69F7AB7A17DBDA686BDA588BAA68BB7A289C5B095
C5AE93BFA98EC4AE93C5AC92C9AF94C9B094CBB39ACBB49DCDB79FCCB69DCBB39BCDB6A0
D0BBA7CEBCA7D1BFA8D2C0A7D1C0A7D2C0AAD3C0ADD4C1AFD6C4AFD6C4ABD9C4ACE1C0AD
E09789B73127CF1F15DB1D12D4170DD21712C61B16BC4140A7778D304373214D7F728EAA
B2B4B7C0B4A8C4B3A2C4B19ECAAF9CD39D90B8544EB31E1BC31413C40E10BE0A0CBB080C
BA0A0DBA080BB80B0CAE0D0DA214149D2E329E525E8359705245662F315A1D2752242347
81526696242CA9090FAE030AAF080A9D090AA040474A3653415F89416A9422476BB1CFE1
C2D4DBC7D3DBC8C4CE98637084121D8C0B14893B4B302C45A7C1D5B8CDD8B1C0C9BECCD4
C3D2D9C0CDD5BBC2C1B9B89EA7A269B0A652A094259E910D9C8D039E8C02A69608A19309
9B8D0D86720641B20700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
977141A299908F99A47C909E4C66714C6B7048686B7D9C9F506E728DA7AEADC6CE69868F
74909997B0B6C2D3DAC3D0D6959FA1878F8B90938D96978F98968E98948A969084999183
9791819A95859A94849990809D9582A19784A398839C9178A1957AA3947AA8957CAD987D
B0977AB29979B2997AB29A7AB79F7FB69D7DBCA584BBA685BBA688BBA88BBDA88EC4AE95
C5AD93C3AC92C5B095C4AE92CAB296CAB297C8B299C9B39BCBB59DC9B39BCAB39CCDB59F
CFB9A3CFBAA5D0BBA5CFBBA3D2BDA7D2BFA9D3C1ABD3C1AAD8C5ADD6C2A9DAC4ADE8BDAC
C7675CC52921D61C17DA1B14D51911C91B13BA3532B47B8B3847751A477B7795B2B7BBBB
C2B6A8C6B5A6C6B2A4CBAFA1D6A899BB5D54AE201CC31514C91211C30C0DC00C0FBA070A
B80909B60D0BAB1714A8393B9E5C696B536E313761152B5D193260435980606E8C7B7186
A36874981D24AA080CB0050BA9070A98181A985A6A2023453F5C816280A11737589BB8D0
BED2DDC8D4DCC8C1CD985E6D85101C8C0A13893E502A27439FBBD0B1C6D2B8CAD1B7C8CF
C0D2D8BAC9D2C1CDD4C2CBCABFC4B9BDBEA4A8A56E9B9234988B129E8F07A19203A39301
A7990F8B790621D90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
9A713CB5AA9C848E9597A9B5556D774E6A6F6F8B8F5C787C77939B9CB8C35F7C857D9AA0
809CA2607C81A3BABFC0D0D49DA8A9868E8B8D908A95958E92928A908F86969287958E80
9993839A94849D97879B94829E9784A29988A49B89A09681A69982A4957CAB987FAD987E
B19A7AAE9773AD9774AE9979B6A081BBA384BBA283BCA687B8A586B9A78ABDAB90C3AF95
C0AA8FC8AF95C7AF96C3AE91C7B295C6B195C4B096C7B39AC9B49CC9B29CCBB59ECCB69F
CDB8A1CDB9A5CDBBA5CFBDA5D0BFA6D2C0A9CFC0A9D0C0A9D7C5ADD6C3ACDBC1AEE9AFA0
B84039CC221ED31813D71B14D21F16BD2C25C276824C50771B477B6083A5B6BDC3C6BCB2
C7B5A7C8B5A5CDB1A2DAABA0C5766DAB2520BD1513C5100FC70F0FC20B0EBD090CBC0A0D
B50909B3201CB6555679576D2D3660122D5F203D6A5369888691A1C2C3CDCDC1C7B28486
A13D3EA20F11AD080AAB080B9A1013A24D594F3D5D122C556C8CAAB4CCDC9FB8CBA1BED2
BDD5DFC9D4DDC4BAC795596486121A890A12863E50292A459FBFD1B0C8D2BAC9D2BDCCD5
BFD0D8BFCDD6C2CFD7BFCBD3B8C3C9B7BFC2B7BEB2A7A9818A8838928A1D9E9213A3940A
A3950E7F6E0245B90C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4EBB24B5A7957E868BA0B2BB526B7264818669848970899091ADB54D6D76617F87A1BDC3
758F968AA3A88EA2A6C4D1D6A9B3B6848E8B8E938C97969192908B9290899692888E897D
9592839390819995869B95859C96859F9886A19885A29783A59882A89880AB977FAD957C
B29B7BB09978B19B7BB29D81B49E82BAA285B9A084BAA487B8A585BCA889BEA98DC4AF94
C5AD93C6AC92C3AA8FC2AD90C4AF94C5B095C5B096C7B199C8B29BCAB59ECAB69DCBB99F
C8B79ECCBAA2CEBCA4CBBAA1CFBEA5D1C0AAD0C1ADD2C2ADD4C3ABD1C0A8DDC0ABDB8F82
BA2E25D21F19D51812D51C15C2231BCA656A7663841A3F734E739AADB8C1C7BEB5CEBDAF
C9B6A7C8B4A3D4AEA1D18A82AA3531B91716C3100FC71012C60E0EC10A0CBE0B0EBA090C
B60A0BB82B2AAF5C653C2A4A2839615668858E96A3C6C5C7B3A6A3BC9F9EB983819E3C3B
A01214AB080CAA090B9B1213A04B54634B670D21513D649084AAC795B4C67EA1B53A617B
B4D6E5C7D3DEC1B6BF905259861116860B1083414F282E45A2C2D2B1C6D1B9C6D0C1CEDA
BCCCD6BFCDD6BECCD5BACAD2B1BFC8B3BDC7B4BEC4B1BBB7869178999F6FA2A1569C9328
988D0F85790864960E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB91FAD9B847D8487A5B6BF5B727A7B979D5B757C99B4BD4C6A725C7B8188A4AA8EA8B0
98B1BC879EA79CAFB6C4D0D6B2BBBF808B88868D868B8C888D8D8990908996948A8C8A7D
9390829893849892829893829C98859E99869F9885A49B86A89A84AA9982AF9A82B09980
B19C7FB29E7FB4A185B39F85B6A286BAA186BCA48AB8A489B8A487B7A486BFAB8FC6AF97
C4AC93C3AB91C2AC90C3AE92C4AE91C7AF95C5AE96C6B199C6B29AC7B49BC9B99DC9BA9D
CABA9FCBB9A1CFBDA5CEBCA4CEBBA4D0BDA8D1BFABD4C2ACD8C5ADD6C1AAE4BCAAC96B5F
C32721D31B14D71B14CD1E16C24342A67A92273F70385D8AA9B3C4C8BBB5CEBAACD0BBAC
CCB9A7C8B2A0D69F92A7463FB01F1DC21312C8100EC60E0EC31011BC0F11B41012B50D11
B70C0FAE0E10A82B2EA5626A9A8689A29C96AA9F94B59F95BC938CB66D699E2E2DA31211
A80907A60B0A9815179D4B565D48631325560B2A5C7595B82C4B6A1F3E5D6B8DA71E425D
A1C0D4C6D2DFBBAEB9884650891319840B118545562A324AA4C3D5B2C6D1AEBCC5BECBD6
B8C8D2B9CAD4BBCCD4B8C6CFAFBCC4B5BFC9B3BEC8B1BEC67C8F93778A8394A487A1A767
9B962F978E158D7C1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B718AB9374818784A8B8BF7C919B60788290ABB6607C854F6C7288A2A6A1BBC3718E99
5976807D959CBCCCD3C3CDD3B6BEC27B8381828783868883888A828D8A83929185939486
9493849895859894849B9587A19A8B9F9887A09986A49B88A89C87AA9A83AC9A81AF9B81
B19D82B3A086B29E84B39E83B7A086B8A088B8A28ABBA68AB8A084BAA588BDA78CC0AA92
BFA991C0AC91C1AC91C1AD92C0AB91C4AD96C4AE97C4AF98C6B39BC8B69DC8B79DC9B89E
CDBAA2CDB8A2CFBBA5D0BEA5CFBEA5D1BEA6D5C1AAD3C0A8D7C5AED6C0ABE8B8A6BA4C42
C9241DD71D14D31E14C02924CC7D8A4C4F772849799399B4D6B7B8DDADA3DBAC9FD9B3A6
CEB4A3D0AE9FC87970A42723BE1A1AC91112C50E0EBE100FB01D1CB23B3EAF494FA53239
A4181AAF1010AE1111A32925C88578B89785B79584BA8075A84A44A01E1BA9100EAA0B08
A20D0B97222493505C4C3E611027561837673C54748593A291A0AE667B8F9BB2C19FB9C9
AAC4D4C5D2E0B8A8B4833C468B1119850C157F45572C3752A9C7D9BBCBD8BAC7D0BDC9D5
BCCAD5BAC8D5BBCCD6BCCAD5B3C0C9B3BFCBB2BFCAAFBDCB5C707F293C41637364778361
8C934E9592289B8D1A40B20500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A68A62858B82A6B7BE8498A27E95A274909B48666F779197A6BDC55B757E7F99A0
9BB2B9BACED6BCCED5C3CED3BCC5C77B81808184808687808A8A808C8A7E8D8C7F959486
9291839693849B97889E97899E97899F9A88A29C89A59D8AA79C8BA99B89AC9A88B29D88
B09C84B29E85B39E84B49E82BCA38AB69F87B9A289BCA58AB7A286B9A489BDA98DBEAA90
C1AC94C1AC93BFAB90C0AC90C3AB93C7AD98C9AF9AC6B199C5B29AC7B59DC8B69ECAB8A1
CBB9A2CDBBA4CEBBA4D0BCA4D3BFA7D3BFA7D6C1ABD6C3ADD7C5B0D8C0ACECB2A3B43B2F
CF231AD41B11CB2118C54D50916C863945728980A2C0818CB84F4FB83C3AB6433ED38379
D9AC9FDCACA0B5524EB1201FC41615CA1110C31412B62B2AB2636D654C6946436270576C
AC646AA12426AF1011A9100FAF3830D37C71B65C54A22B27A51413AD0E0DAA0D0B99110E
97343885566B3030570D295A23456D92ACC4C1CFDBA5B0B6BEC9D1AEC2D07893A6A1C2D7
7093A6C1D4E3AE9CA780323A8C0E15820C157847572A3B54A6C4D6B7C8D4BCC9D4BECAD5
BECCD7C0CEDBBFCFD9BACBD5B3C1CAAFBEC9AABBC5ADBECC94A6B662737D88948F8F998C
8F977696944A9B8D2448BB0D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A4885B93978D9BADB2879BA593ACB845656E6E8C9396B2BA58737E536F7692ACB2
A2BCC3A2BDC77C939BBCCBD0C3C9CD8084867E817D80817A86867E8D8C828C897D969186
9994889995889895869E988AA0998B9F9A89A39D8CA59F8EABA092AE9F93B4A193B39F8C
B5A088B6A089B59E86BAA28ABCA38DB9A18AB8A288B9A489B8A288BBA58CBDA88DC3AE93
C4B098C4B098BFAA92C2AC94C4AC95C7AD98C9B09BC7B29CC5B39CC7B59EC8B49EC9B49F
CEB9A4CCB9A2CEBCA5D1BFA9D1BFA9D0BEA9D2C0ACD5C3AFD4C3AFD7BDAAE7A899B13127
CF1F18D21C14BD231FD17882684E69A285A4B2596BB6282EC51E1FCA1C1AC11E1AAD322E
E19F99E0A8A4A9403EB51D1CC61412C81312BB1D1CC06069514062183165324D74707484
B18F90BF6664A21614B00C0AAE0E0DB11C1CAB1313AE0E10AC0B0CA3100F9A2426924852
59415D17235010325D557B9AACC6D6ADBCC3C4D0D896A7B193A6B1667E940B2B4C4B708E
41667DBBCFE1A8909D7F2833900E15800E1574495B31465EAFCEDDB5C8D5BBCBD8C0CCD9
C0CCD8C1CEDBC0CED9C0CED9BDC9D5B1C1CBACBEC8AABFCCA1BACA8FA8BB8DA3AFA1B3B6
B1BEB5A6A881978D404CC11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A584539E9D9193A0A7ACBFCB66808C5A798190AEB663828B4F6E7669848B7E989F
66838A59767D99AFB6B9C8CEC0C9CC838A8C797C7980817B83837E8B8B838F8D83928E82
9B97889D988C9A96899F9B8CA39C8CA69E8FB0A699B0A597B1A497B3A399B5A496B9A796
B6A590B7A38EB7A18AB69F87B9A38CBAA48CB49F87B8A58BB6A38AB8A58CBCA88FBBA88F
C3B199C3B098C1AB93C5AD95C2AB94C3AC96C6AD98C7B09BC6B19CC7B19EC9B49FCAB6A0
CCB6A0CDB9A1CDBAA3D1BEAAD1BEABD2C0ADD0BEAAD5C3AFD5C2AEDABEABE4A495B43329
CD1D15D31F18C03435BA73829D738AB55E70B9252DCD191DD01718CE1614C71A15AD2E2C
AF757BB890989F4244B2211FBF1313C30F11B3191ABB6270443354535B7CA19CA8BBA09D
C9978ED37871A71F1AB30B0CB7090BB80A0DB40D0CA90F0DA02221A04C537A526A31315A
0F245717335E4C6880A7BCC5C0CED19EA7AB9FAAB0495D6A5F748296A9B8486479628096
A3BECDBFCAD6A285907C1F29930E1582121B6A41533E536CB2D0E0BACBD7BBCCD8BECCD9
BFCCD8BFCAD6BECAD6BECAD7C0CFDCB2C2CFAEC2CCACC0CD738DA22F4F6A305067587480
8094979AA29499966F96845400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A47E47A7A1918C999E97ADB75C77818BA7B172909B496A7167888D47666A688488
6C858A97AFB68EA4ACB0C0C6BEC9CD899395757C797D7F7983827D8A89838A8A80929084
9C988C9F9A8F9F9B90A59F93ACA697ACA596B2A79AB3A89BB1A698B5A89AB5A597B2A291
AE9E8CB19F8BB39F8AB29E87B8A48BB7A388B8A489BCA88EBAA68CB7A489BBA88DBBA78F
C0AB95C1AC94BFA891C2AA93C3AD95C2AE96C7B099C9B19BC5AF98C7B29BC9B49ECBB6A2
D0BBA8D0BBA6D1BDA8D0BFA8CEBEA8D1C1ADD0BFADD6C5B1D5C2ADD9BFA9E6A999B0362A
CD2118D11F18CA4443B66874CF8391B12F36CC1D1FD31616D21615CD1613BC1C17B65158
69516B69637EA7656FA42629B91819C41113BC1215BB353EB55C69BB757DC07572B75A53
AD3C34AC201CB10F0EB80B0DB9090CB40C0BAC1F199B3936774751453E5E18295B132B5E
3A4D7079808F97989593938DB8BBB9B5B9B8A9B0B0C0CDD2ABBCC3ABBBC4B5CDDB89A6BA
9FBCCDBBC6D49D7C867C1A21910C118618205F3A4E4A5F79B5D0E1B7CAD2BBC9D2BBCBD8
BDCDD8C0CDD7C0CDD9C0CFDABFCFDCB7C9D7AEC2CDAFC1CE758B9C45617645637668818E
85969B828B888A8C80887E6C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00789B31A59B8684929694A8B2778F9A8DA9B649677360828847696C5D7D7E7D989B
A0B7BD8FA8B14760698CA0A5BECACE97A0A3757C787B7C7782827A84847C89887F8E8C81
969287A09992A39C94AAA199AAA298ADA59BAFA599B3A79BB2A69AB4A89AB5A698B1A190
B2A08EB39F8DB39E8AB59F89B8A28AB9A48BB7A38BBAA58DB7A289B9A48ABDA88FBCA690
BCA690BDA891C0A892C2A993C2AB94C5AF97C4AE96C6B099C6B09AC8B39CC7B59DC9B8A1
CCBBA4CDBBA4CDBBA5D0BEA9CEBDAAD0BFACCFBEAAD5C4AED3C1A9D7C2AAE7B6A4B1453A
C9251FD41F1BC72C2AF68084E1686BC22423D31C18D31815CE1714C11C16B43C3C9D6F84
2A3C655B708DC6A5AAAB5753A72824BA1817BE1212BC1215B4171BB21C1EAD1918B01816
B01411B41410B40F0DB80D0EB60A0BAB100DB54E4E5430421C2043192852414D737A748B
9B858BAB8B85B59288AF928BCEBFBCD6CFCFB7B8B8C2CBCFA5B6C17B919F8FAABD193A5A
3053737C8B9E96707B7C141B8F0A10841B2658384F526984B2D0E0B8CBD5BCCAD3BACBD8
BCCED9BDCED6BCCDD5BCCDD7BFD2DCB5C8D6ADC0CEB1C3D1A1B6C46B869799B5C294ACB6
A4B6BBAEB9BCA5ACAB8F8B862A9F1900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004CB81CA99A807E898AA1B5BE92A9B457737E5D7B845271765D7C8169888C425F66
839EA72D4951718B928A9CA0BAC5C9A2A9AD7176767B7B7780807A81817888877D8E8B80
938F859D9991A29D97A6A098ACA59DABA299AEA498B1A598AEA495ACA392AEA491B0A491
B1A28EB09F8BB39E8BB29D87B4A088B9A58CB7A38AB7A389BAA58ABDA58CBFA78FC2AC94
BDA992BFAA94C1A993C3AA93C2AB94C2AC95C5B099C5B098C5AF97C8B39BC9B69EC9B8A0
C8B8A0CABAA0CABAA1CDBDA4CCBCA4D0BFA9D4C1ABD2BFA7D0C0A7D2C2ACE1C0ADD18476
B93028CF231CCF211CCE2928D02A2BCF1D1AD21D17CC1F18BF261FBC4E4FAB7D92364673
1F4777889FB3C3B7B1D6AEA1C27C70AA3930AE1F1AB71A17BA1918B51614B11816A71715
A5201FA92D2BC03D3AAB1211B40D0DA51110A95057381C3643355386637AB07582A45056
9C3839982D2D9A2D2D9C363B9E4E54B37E82B6999AA19A9B65727C344C5B8CA2B44A637E
33516EABB4C68D5E667F1117900A10841E2951374D5F7892B6D2E1BACCD5BDCBD5B6C7D4
BBCED8B9CCD4B7C9D4BACCD8BDCFDBB7C9D7B3C6D2B8C9D6AFC3D32D495F47677B5D7889
7A919B90A1A89EABAEA9ACAC57443600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004AB417B29D81808788AABCC57E95A057737B5B788059767D71909637575C88A2A9
778E97445E6444595CA6B3B6BAC4C5A8B1B37175767A7C797F807A83837B89877D8D8B7F
928F839D998EA19D94A5A199ADA8A2A8A198ACA397B2A798AEA292A99F8EAEA492B3A795
B3A590B1A28EAE9D8AB09C85B5A188BAA48CB7A189B8A38BBCA78FBDA58EC3A993C4AC96
BEA892C0AA95C2AA94C3AC94C2AA93C2AB97C5AF9AC5AD97C8AF99CAB39CCAB49DC8B59D
C9B79FC9B8A0CCBCA2CEBEA4CEBEA4D0C0A7D4C1A9D3C0A7D1C0A7D2C3AED9C4B2E8BCAC
D27C6FBA382CC62820CA251FC6221DC2231CBC2E25BD4E4ABC7880887693304B7A1D4A7C
6888A6B2BABDC2B9ABC9B6A6CEB1A1D2A090C17B6FB25954AD4F4FAB4F54A5565CA2646E
9165767B5668BD78809D1D1FAF0C0FA30C0BD06367AC5C68A44653A02731A3161DA91015
A80A0EA8090EA8090FA60A129E0C14911319923437A67272C6BABDACB8C19CADB7B8CDDB
A1B6CA989AA9875057871317910A0E85212C4A344969829AB7D1DFBECEDABECCD6B4C6D3
B4CAD6B7CBD7B7CAD7B7CAD8BACCDAB9C9D6BBCAD7B9C8D6B0C2D45068824F6C854F6B80
6B839182949D7F8C92878C8E5C4E4300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB517B69E81888C8EA7B9C4627985657F88556F777F9CA23C5A5E79969B7F989E
768D94667D82A7B7BBB4BFC2BAC3C7B0B8BD767B7E7C7D7B80807B82807A87837B8D8980
938D859D968EA19C93A4A097ADA9A0A9A59BA6A294ABA494AEA394ACA092B1A497B3A494
B8A797B2A08FB09D89B49F88B5A189BBA68EB7A189BCA78EBAA78EBAA590BEA790C0A892
BDA68FC1A892C0A791C2AA93C3AD95C0AB94C2AE96C3AF97C4AF99C6B29DCAB7A1CDB9A4
CBB6A1CBB9A2CCBAA2CDBDA4CCBDA5CFBFA8D4C3ABD7C3ABD4C2ADD4C3B2D6C4B5DBC5B4
E6C2AFE4A696D2796CC66159C2635EC37779B58893817891415981224C7C3C668F8098B0
B8BCC1C2BAB3C4B8ABC6B9A9C7B8AAC7B2A4C4ACA1917B7C685A6A524F6A3D45632D3A5D
25375D383E5CA470809B1C22B10C0FB00B0DB61E21AA181EAC1118AE090FB2080FB2060C
B0060BAF050BAF030BAC020AA8040AA6070C9D0B0F8E1C22AA7176C8BEC87C8E9C8DA6B7
40586E5A5B6D7D404989101692090F85212F432F476D89A1B8D2DEBDCFD8BACBD5BACDD8
B9CDD8B7C9D7B8CAD6B9CDD8BCCEDABDCCD8BBCCD8B8CAD8B6C9DAA1B7CEA0BBCF9FB7C7
A0B5C0A8BBC3A3B1B8979DA25E524B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0028DB0BB094748D8E8FA4B5C07A919D58737D7D98A14B656D6A8588769093738E91
97B0B48BA3A99DB1B6B4C2C8BBC6CCB5BDC47A7F847879787E7E7986847D89867E8F8C82
948F849C978E9F9B929F9B94A6A39BA6A499A9A599ACA598AEA498AFA395B3A696B5A594
B7A694B4A290B5A28DB39F87B5A189BAA68FB6A18AB9A48CBDA991B9A58DBDA58EC0A891
C0A790C2AB93BDA78FBFA991BFA991C1AC94C2AE97C6B29DC4B29CC4B39BC8B89FC8B89E
CBB9A2CAB7A1CDBBA5CFBDA8D1BFABCFBEA8D3C2ABD6C4AED6C4B1D4C1B1D7C5B6D5C6B6
D7C8B7DCC5B6E1C3B8B59B9A80768258607C354F753257804C71957D96AEAEB8BFC0BCB8
C5BCB2C8BCB0C4B8AAC4B8AAC2B6A6C3B5A5BFB2A2BDB2A8AEA9A692939B838994828793
8E8D99A78F97A55758A11414B50B0CB40809B3070AB3070CB20709B2060AB30409B4040A
B4060AB4070AAE0406B10409AC0407AD0509AB070AA10A0F891A20A47381292F435B7486
607486635C6F803B468B0E1691070F892534402D45708EA4B8D2DEBBCED6BBCCD6B1C3CF
B8CBD6BCCFDCBCCED9BCCED8BCCED8BACCD8B6C9D4B7CAD9B1C8DD5B79944F728B6D8A9E
738A97869AA292A4AAA4AFB377706C27981000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A4835D93918FA1AFBB738A9769858F628087668187728B8E68838669858A
5E7C805C7A7D8CA6AAB1C4C9B6C5CCBAC4CB7E8589787B7A7C7D7885857E87877E8F8E82
959185A19B90A49C93A59E95A6A19AA6A298A8A499A9A396AEA698ACA191B3A796B5A595
B7A595B5A191B6A08EB39C86B79F89B9A38CB5A088B9A38CBBA58EBAA48DBDA68FC0A791
BCA58FBEA992C0AB92BFA991C2AC94C2AD96C3AF98C6B29DC7B39EC7B59EC9B8A1C8B7A0
C9B8A2CCBAA6CEBDAACEBDABD0BEABD1BFAAD3C1ACD2C0ACD5C3B0D7C5B4D9C8B7D5C6B8
D5C8BBD7C9BCD8C8BED0C4BEBAB4B6A7A9B4A7AEBBB1B8C2C0C0C3C5C0BDC9BFB6CABFB2
C9BCAFC8BAADC7BAACC5B8AAC6B8AAC7B9ACC0B5A6C1B6A6BEB6A6B8ADA1B4AB9EB4A99C
BCA499C188829D2D2AAD100FB50909B50709B40708B30608B4070BB30409B20308B6050B
B30507B40709B20809AF0506B00406AE0609AC0406A8050997090E933C44A5919E90A1B0
B8C8D1A797A27E313A8F0D1493080E8624353F2E497896AEB5CFDCBBCED6BCCDD7BCCCD9
B8CAD6BACCD8BDCFDBBDCFDBBDCFDCBBCDDBB8CAD6B8CBD8B5CBDF3A587543657F607F91
5B727E788B937B8A917E878D6F696924961000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A17C4F9A958E9AA7B28399A774919C62808985A1A75D797E617E85537076
56757767848686A2A6627C81A8BCC1BBC8CB858D8E7B7D7C7E7F7A81817A88877E8F8D82
9693879D988FA39C94A39C94A6A098A8A49BA7A499A8A498ACA59AACA497B3A797B4A395
B7A496B9A392B59E88B89F89B89F89BCA58FB6A089BBA28CBFA690B8A18AB8A28ABCA68F
BDA790BEAA92C2AD95BFAA92BFAC94BFAD96C3B099C5B09DC5B09CC7B39EC8B6A0C9B7A2
CDBBA7CDBBA9CCBBA9CFBDAAD0BEA9CFBDA7D0BEA9D3C2AED4C3B0D8C7B6D8C7B8D5C6B9
D3C5B8D5C7B9D4C7BAD4C8BBD0C5B9CDC4B9CCC3BACCC2B8CEC2B6CDBFB3CABEB1C8BCAF
C6B9ABC5B9ABC3BAACBDB5A7BEB7A8C1B8ACC0B7ABBCB4A5BAB1A1BAAE9EB6AB9ABBA496
C39187A74642A61614B30B0CB70A0CB5080AB2080AB10708B40709B6080AB50709B7060C
B40608B30608AF0507B00409B10507AD0305AE0509AB030AA2050C84121D946B7E8E9CB5
8796A7A8959D7E2B30940E1395080F8725353F2F487A9AB1B6CEDDBDCDD9BACCD6BBCDD9
BACCD6BDCDDABCCCD9BACCDAB6C9D7BACBD9BBCBDAB9CAD8B8CADB758CA18BA7BAA1BDC9
9CB2BC9EB0B8A5B4BA9EA8AE7B777A38671D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009C7440A69E91909CA5A6BAC766818D96B2BC6F8B945D7A814E6B71537477
62828488A5A85B777B55707597ABAFBCC9CE8F959A797C7B7E7E7A83827C8989828F8F86
9A978EA09B93A29D95A29C96A9A39FAAA5A0A6A297A9A298AFA89DACA499B2A699B2A393
B7A696B4A390B29F8BB39F8AB3A08BB4A28BB7A38CB9A38DBBA58EBBA58DBCA78EBCA68F
BCA690BFA994C2AC96BFAB93BEAB94BEAB95C2AE98C6B09BC7B19CC8B29DCBB6A1CCB7A3
CDB8A7CEB9ABCEBBABD1BFACCEBCA8CFBDA8D2C1ACD4C3B0D3C1AFD5C4B2D5C5B5D6C9B9
D5C8B8D5C8B8D3C8B8CFC7B5CFC6B8D0C5B9CFC3B7CDC2B6C9BFB3CAC2B4C9C0B2C8BEB2
C8BEB2C4BBADC2BBACB6B3A3BAB7A8BCB6AABCB4AAB8B0A4B5AE9EB6AB9DBBA699C4948D
AC4F4EA41A1CB00C0DB70A0CB50909B20809B20809B20809B40709B50709B30709B20409
B30A0CAD0A0CA9090BAB090DAF0A0EAE060BAC0408AA0207A5040A8C0A148B4E681B224B
2C43629B8A947A2228940A1195070E8723314333497899ADB5CFDEBCCDD9B4C6D0BBCDD7
BCCED8BDCDDABACBD6BDCFDBBBCDD9BACAD7B4C6D4B4C7D6B9CCDB7F94A9668196728F9F
7F99A383969D95A6A99DAAAD95999D48392E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A27740BAAEA188939C99AFBC87A2AD8BA6B177919B4D67704E6B70557578
4566686C888C94AFB3778F939EB0B4BECACD98A0A4767A7C7B7D7981827D8686818E8F87
9C9C949F9D969F9C959F9B96A39F9AA9A39DACA59CA9A297AEA79BAEA599AFA595B2A595
B6A696B3A090B2A08CB4A38FB5A38FB4A08BB8A38CB7A28AB6A28AB8A58DBCA990BAA68D
BAA68EBBA790C0AA96BDA994BDAB96BEAC96C1AD98C3AE99C7B29DC8B4A0CBB8A5CDBAA9
CCB9A8CDBBABD0BFAFD0BFACCDBDA6CFC0A9D1C1ACD4C3AFD4C3AFD3C3B1D4C5B6D5C8BB
D4C8BAD3C7B8D0C7B6CFC8B7D1C8BBD0C4BBCCC2B8C9C2B4C8C2B1C9C2B2C5BDAFC6BCB1
C5BBB2C2B9AFC2BBAFBFBAAEBDB8ACBAB4A8B8B2A4B5ADA0B7AD9FBBA89EC49690A94D4D
A61B1EB20E12B60A0EB6090BB70A0BB20809B20809B5080AB5090DB30A0DA90A0CA00B0E
9A1416962224983033992B3395151D9F090FA90509A90307A303078E060E8E4C62242D53
56738F9C8B977A2029960A1196050C861E2C4E384E7391A8B6D0E0BDCED9AABCC4B2C4CE
BCD0D9B4C6D4B8CBD9B8CAD5BACBD5BBCDD7BCCED9B5C8D8B2C4DA8298B32845604D6980
637C8A74868F7F8F957A878B7C83854A3F3700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004EBB24BDB09F7E8C92A6BBC99BB2C087A1AD617C864F6A73516C732A464B
223C405A747A627F856D888CB3C4C8BCC6CBA2A8AD76797B7B7C797E7D798887828E8E88
96988E999B909B9C919F9D94A49E97ABA49DADA59CAFA69DACA399ACA298AFA498B0A397
B4A396B4A092B39E8DB4A18CB6A18DB8A18EB7A28DB7A38CB4A28BB6A48EBAA68FBBA68E
BDA890BAA790BCA894BCA994BDAD96BEAD99BEAC98C1AF9AC6B59DC7B7A0C8B7A4CBB9A9
CAB7A8CCBBAACEBFACD0C1AECDBDA9CDBEAACFC1AED3C4B2D2C2B0D2C5B4D2C7B8D1C8B8
D2C9B8D1C8B8D1C8B9D0C8B8CDC5B8CCC2B9CCC3B9CAC3B6C7C3B1C5C0AFC6BEB2C8BEB7
C5BBB5C4BBB4C3BBB2C1B9AFBCB5ABB9B2A7B6B1A3BCB2A4BAA79CC79A95A74D4EA31B1D
B41112B70A0DB9090FB7090DB30709B10808B00807B10B0BA90C0C9E121498292E9A4B56
855769634E684F47655548617E4F5E932C35A10C12A80409A203078E0A12905265293457
9FBCD69E8B987A1E2595081197040C841724593B526F8BA2B4CFDFBFCFDAB9C7D2B7C9D4
BBCEDAB3C5D3B1C3D1B6C6D3B8CAD6B9CBD7BACEDAB9CADAB6C7DC92A7C26A829D8DA4BA
94A9B6A3B5BEA3B4BAA0ADB18A8F9352474227980E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004FB81EB8A690818B8FA8BCCA8EA6B47B97A45976814D69722441461C3639
7C9395849CA0658286547276758C8FBCC9CDABB2B5767A7A797B777C7D7883837E93928C
95968E989A9097988EA1A095A5A197AAA39BAAA29AAFA59DB0A69CAEA197AEA197B0A39A
B8A89CB2A092B5A190B6A18DB7A28DB5A08DB5A08CB7A28BB8A48BB9A48DBAA48DBCA68F
BEA991BCA68EBDA993BEAC95BCAC93BEAD96C2AF9AC1B09CC3B8A3C9C0AFCBC2B3C8BBAE
CCBCAECDBDABCDBEA9CDBEA8CCBDA6CEC1AACEC1ADD0C3B1D0C3B2CFC4B3CFC6B5D2C9B8
D0C6B6D3C8BBD1C7BBCFC6B8CEC4B9CCC3B9CDC4BBC9C1B8C7C1B4C7C1B4C7C0B6C7BFB8
C8BEB8C3B8B2C0B7B0BDB4ADBBB4ABB9B3A8B9B1A5BAACA2C59F99AE595BA21C1EB31013
B80C0EBA0B0EB80A0CB6080AB4090AAD0809A60E0C9D19189D393E915364634A682F335B
172D5B122C5E1B3661495F7C686677A3636C941219A3040B9C0306880D1184516415254A
304D6C867383781C2295080F99050D820E1B643F55647D95B2CFDEBACDD7BDCCD8BCCAD7
B6C7D4B9CCD9B8CBD9B7C9D8B5C7D5B7C9D7A5B7C5B6C8D7B9CADC889CB46D879E758FA1
7D95A181969F8CA0A698A8AE9BA4AA5A5352279A1300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0051B81AB29A7E878C8FADBECD8FA7B56F8D995878832F4D5518323672888D
6B828790A9B06580857B9699657B7EB8C8CBB1BABE777D7E7B7C797E7E7982827D878780
9192899B9D939B9C91A1A197A3A197A7A49AACA49CB1A7A0B3A89FB3A79DB1A59BB0A399
B6A79BB3A394B1A08FB5A38EB2A089B1A089B3A088B7A28BB8A28AB9A38BBAA48DBAA590
BBA78FBCA990BEAA92BEAB93BEAC94BFAE97BFAF9CB3A999C0BEB2D5D8D1DADCD9D0CFC9
C7BEB1CCBBAACFBEAACDBEA8CBBFA6CBC0AACDC0AECEC1B1CDC1B1CCC2B1CDC5B3CEC5B4
D1C6B6D0C4B6CFC4B6CDC3B6CCC3B7CCC4BAC6BEB6C9C0B9C8BFB6C8BFB6C9C0B8C7BEB7
C5BCB5BEB7B0BCB7AEBFB9AFBBB5ABB8AFA6BBAFA5C6A8A0B26866A12024B31115B90D0F
BB0C0EB8090EB70A0EB40A0DAC0E0F9A15169B3C3F956272554A6B20305F0F295A1B3963
445F7E7184988E9AA49FA6A9A99D9E9F6061901115A4060B9B06098E272A66465A172C4E
849CB38C7682761A2394081098040C7F08116F40525B6C83B2CFDDB9CED6BBCDD4BCCAD3
B9CAD2B9CCD6BACCD8B9CBD9B9CBD9B5C5D5A0B2C0B0C3D1B5C8D960799241637E34576C
557481748A9573868E76858D747F88575457269B1600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0050B615AD9170898C8DA9BBC87E98A56F8D994C6A75102C325C757A677F86
3E5A615A777D76909693ABB0768B90BAC7CDB9C1C77A8283797D7A7E7E7983827D86887E
9092859B9C90A1A096A4A099A9A49EABA59FAFA7A1B0A59FB0A49EB1A59CACA298AEA197
B1A397B0A394B5A494B3A090B09E8AB2A089B29E88B7A38BB49F87BAA38ABCA48DBBA68E
B8A68DBDAB92BBA791BFAB96BEAC97BDAD9BA69F8F9E9E91B3B8B2ACB4B5CED4D7D5D8D5
C4BDB2C7B9A8CCBCA9CDBDA8CABEA7CBBFAACCC0AECDC1B0CCC0B0CCC2B1CBC2B1CFC5B5
D0C4B7CFC5B7CEC6B6CCC5B5C9C1B5CAC1B9C8BEB8C8BEB7C8BFB8C7BEB7C9BFB8C6BDB6
C0B9B1BDB8AFBDB9AEB8B6AABCB9ACBDB4A9C2ADA4C28581A02B2CB31419B90D10B90B0D
B80A0CB80B0FB00C0EA512139E2F339B5E6C5A4E6D1F336110306325456F586E86848F98
9499999EA19AA19F96A69C95B89390983F419C1013A6060A95080A9A494F3A2F4C183556
98ACBC9D828B78192194071098040D8707117B3C4A535A6EB2D0DEBCD0DBBACBD4BACAD4
BBCBD5B9CBD6B9CDD7B9CBD7B8CAD6B4C6D4B3C5D3B0C4CFB2C6D588A0B54D6E836E8EA1
8CAAB596AFB98FA2AAA8B5BF75818E41444C4E3A2B00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AF8F68888785A1B1BE8198A669869423414B4A656C60777F3F575E
112A2F657F8544606758747A9DB2B9B5C4CBBBC6CB7E8789787F7D7F827C8A8D868A8D84
8E91869C9D929D9B94A4A09AA9A39DAAA39CAEA6A0AEA49FB0A59EB1A69DADA399ABA196
AEA196B0A193B2A191B29F8FB4A18DB5A08AB4A088B4A087B8A38ABAA48CBAA48DBAA68E
BBA78EBEAA91BEAA91BEAB94BDAC99B3A697938F82B8BAB0D8DDD8BFC6C7BFC4C4D0D0C9
C1B9ABC9BBAACBBCA9CDBEAACBBCA7CCBFA9CBC0ABCCC1AECEC3B2CDC1B0CEC4B2CEC4B4
D0C4B7CDC3B7CCC4B7CDC6B8C9C3B6CBC2B8C8BFB7CEC6BFCAC3BAC7C0B6C6BEB6C3BBB4
BEB9AFC0B9B1B9B2AABAB5ABBAB5AABBADA5C9A09AA44343AE191BBC1113BA0C0EBA0C0E
B60B0FAF10119E1B1DA14B547C5B752D35621030641F416D59738D8B98A0969B969D9D93
9C9A8CA4A295A8A296B19A93AE6E6C911A1EA4090DA2080A8C161984556810204822466B
7E94A299808473181D91080F99020B8F070F7D2D394D485DABC8DAB7CDDABACCD6B7C9D5
B9CAD6BACBD9BACBDAB8C8D7BAC8D5B9C7D6B5C6D3B3C5D3B2C5D3A1B5C7728C9E7D99A7
87A2AC8EA6AD90A3AA98A7B17E8F9D222E3950443800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A9865C9E9B9795A4B08EA6B546636F3E5C645C777F3B545C0F282D
627B7E8BA4A87D979C63818638565CA5BAC0BBC8CD8590937C84838386828C8E898E9089
8F92889FA0969B9A94A4A09BA6A19AABA39BAEA59FACA19CADA29BB0A69DAEA399AD9F95
AEA094B0A091B19F8FB4A191B4A08DB6A18BB4A088B4A088B7A38AB9A58CB8A48CBAA68E
BCAA92BBAA91BBAA90BCAB93BCAB97A89B8B9A9486B5B3A7C9C8C1B5B7B2B0B0A8C7BFB2
C5B9A6C9BBA5CABCA8CDBEACCDBDACCCBDAACBBFACCDC1B0CEC1B2CFC2B3CCC1B1CDC4B5
CDC3B8CDC3B8CEC4B9CEC6BBCAC4B8C9C3B7C9C3B7CCC5BBC8C2B9C5C0B5C6BFB4C5BDB3
C0BCB2C0BBB5BCB7B1C0B9B2C1B8B1C1A8A3BD7977A42222B81313BD0E10BB0C11B70F11
AA120FA52E2AAC666B5946601C2B5B1634664661858192A098A19E9C9E94A09F939E9C8F
A09F8EA5A193A89C91B085809233349F1014A4070B980C0F9845513F31540C2C5C325C82
4964778B7981731D21910A0F9B040D95050E7D1A275A4558A3BECEB7CFDBBCCDD9B8C8D5
B8C8D5BBC8D7BDCADBBCC9D8BCCAD7B8C8D7B5C7D3B2C6D1B3C8D6879FB0456479577688
66838E7B94997B8F947C8A926374811C2B36504A4000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AD8554AEA79E8F9EA77E94A23853607B97A23F5C650D272E597277
718B916C8890819AA0728A90768D929BAEB3BBC9CF8D9B9F7D86878C8F8C8F908D939490
999B939D9E969F9F97A3A29AA3A098A7A39AA9A39CABA29CADA49CAFA69CB0A298B1A096
B3A295B09E8FB09E8EB19E8FB39F8DB49F8BB19D86B19D85B4A087B9A68EB4A28BB7A590
BAA893BAA890BBA88FBCA991C0AE99B8A8978B8273A4A095A6A398979588BCB7A7CBBEAC
CCBBA7CBBBA7CABBA9CDBDADCDBCADCAB9A8CCBCABCDC0AFCEC1B1CBBEB1CDC1B4CDC3B7
CCC2B8CCC2B8CDC2B8CEC3BACCC3B8CBC2B8CBC2B9C9C1B8CAC3B9C5C0B5C6BFB4C8BFB6
C2BDB3BEBBB2B9B7B0BCB8B1C1B9B1D0ACA9A44749B11B1DBE1112BC0C10B60D0FA91310
B13F36CF837E98677070536C6256737D7E9391959B9A9D97A3A598A0A193A09E919D9E90
A4A293ABA297B5958E9E4F4E941416A5090D9E0A0D952A33754F6B112050254871A9CAE0
ABC0CB9C8E946F1F23920B1199030995020B810B167041538F9EAFB6CDDABBCCD9BCCAD7
B7C7D4B8C8D5B9C9D8B7C7D6BACAD9B8C8D7B3C5D3B2C5D3B5CAD87C94A86E8BA2557288
6D8A9788A2AAA0B4BA9EAEB58697A11E2D3858554D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00AB7E4BB5AAA08B97A0899CAB758D9C67838F143138466064698389
4C69712B4950607E8394AFB4698186A7B9BDBBC8CE9AA5AA7F888A8B8F8F919290939390
91928D9C9C979E9E96A4A49AA6A59DA6A19BAAA49FADA49EAEA39CADA299AFA097B09F94
B29F92B09F90B09E8EB19E8EB39F8DB59F8CB39D87B4A088B2A089B4A58EB6A68FB7A790
B8A892B8A793BAA993BFAC97C5B19DC1AE9BB7A798A19688A9A291BCB5A2C8BBAACAB9A8
CEBEABCDBEADCDBDAECCBCADCDBEAEC9BCAACBBDABCCC0AFCAC0ADCBC0B0CAC1B3CAC2B6
CCC4BACCC3B9CEC3BBCDC3BCCEC3BBCBC1B8CAC0B8CABFBAC6BEB7C5BEB5C5BDB3C6BDB4
C0BAB1BCB9AFBBBAAFBEBAB1C2B4AECD9F9F9B2D32B5151ABF1013B90E11AD1412B53B34
DD8079BA60609B353C96283494353EA97070AD988FA29E92A19F92A5A298A2A095A3A193
A9A093B3968EA86562931B1DA30C0EA30A0A991F219156692626530E2A5C5F7E9995ADB6
A7B9BF9E959B73292F8C0B1298030898020A8B060F7529377B7585BBCEDCBACBD9BACAD7
B6C6D5B5C7D5B8CAD8B6C8D6B4C6D2B7C7D4B6C8D4B3C6D4B2C6D68AA0B2849FB0748E9D
768E98778E96869BA090A3A88C9EA61F303A5A5B56269A0F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0053BE28A69A8B828F96AEC1D0879FAF3E5B67314C54667F854A636A
0F29304A65685D797C456266819A9F94A8ADBCC8CDA8B1B67F878A8C91918D8F8D949590
9796929B98959F9D98A4A29DA5A19AA69F97A9A199ACA39CAEA49DACA299AEA299B1A496
B0A091B3A193B09D8FB19F8DB3A08CB29D89B39E88B39F87B19F88B4A48DB7A78EBBA991
BCA894BBA794BDAC98BFAE9AC1B09DC4B29CC6B3A1C2B1A1C7B7A5C7B9A6CABBA8C9B7A5
CCBBA8CBBCA9CCBEAECABEAECABEAFC7BAABCABEADCAC1ADCBC3B0C9C0AFCAC0B3CAC2B6
CBC3B8C9C1B8CAC0B9CDC3BDCCC1BACABFB6CAC0B8CAC2BAC4BDB5C7C0B8C1BAB2C3BCB4
C5BFB8BEBBB0BCB9AEC0B9B2C2B4AEC592929C272BB81519BC1011B41310AE2B24DF7871
AA3D3B9E191BA81114AC0D11A31216902A2AB18B849D9C939EA097A7A59CA39E95A79D93
B1938DA96162982023A30C10A7080AA11010BE595C6E425928284E43507095A2AD959EA3
8B989F716A747C3841890B129702079A020A92030B780D1B7C5261B4BCC9BBCCD6BBCCD6
B7C8D5B6C8D4B8CAD8B7CAD8B7CAD5B6C7D2B8CAD6B2C5D3B2C7D68CA4B64561755D7787
69828A687C835E7274697B7D687A811A2C395B605F279D1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0052BD23AA9B86808D92A7BDCA617D8B2C4B54627C82486166122B2F
455E627C949992ABAF9AB3B76D878D556D72BECCD3B7C0C781878D87898C8B8A8B939190
9998959B9A969C9B97A3A09AA8A39DA9A39CABA39BAEA59CACA199AFA29AAD9F98AFA196
A99B8EB3A496AF9F8FB09F8CB2A18DB5A38FB4A18BB29E86B6A28AB7A48CB8A68FBAA691
BAA491BFAA97BAA895C2B2A0C1B19FC5B4A1C4B2A0C3B1A0C4B3A2CAB9A9C8B8A6CBB9A7
CBB9A7CEBDABCDBDADCEC0B3CABDB1C7BBACC5BCABC5BEAACAC3B0C8C1B0CBC4B5C7C1B3
CCC6B8C7C1B4C8C2B7CBC4BAC9C1B8CAC4BBC9C4BAC9C4BDC6C1BBC4BFB9C2BEB7C0BCB5
BEBAB2BEBAB0BEB8AFBEB7AFC2B3ADC9989899282CB81519BB0F10AD140FD96058BC4A48
A21718AE0D11B10A0DB20B0DA90E119021257F5D67606D7693A09CA1A099AC9F97B6928E
A559589B2023A70C10A9050AA70408A20A0FA82A2F9D3A47924A5A9B6A75BFA4A8B8B1B3
B9BFC4958E9681444C890E159802089A02079502098C0914782834B7A4B0C2CBD5BFCDD8
BACBD5B7C6D3BBCBD8B8CAD8B3C7D4B6C8D4B7C9D5B3C5D3B0C5D3A4BCCE2C496066879B
6F8E99738C9579909580959A82969E1C303D5B64653A6C1E00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB81A9F8B6E7A8183ABBFCA3E59637591995C757C183035364F53
6E8A9058757C809CA38DA6AC6E868C687D82C1CED5C2CAD4858991898A8D8D8B8C908F8D
9697939797929B9994A09B96A6A19DA9A29FA9A19CADA39BACA299AFA49BAEA097B1A399
A99B8EAC9F90AF9E8FAF9D8BB19F8BB19F89B5A189B59E86B79F88B6A289BAA68DBDA791
BFA996BEA897BDA999BBA99BBCAB9CC1B0A0C6B4A4C3B0A1C8B5A6C6B3A3CAB7A5C9B8A4
CBBAA8CCBDAACDC1B0CBBFB0C9BCB0C7BCADC5BEACC2BBAAC8C0AFC7BFB0C6BFB0C5C1B2
C9C3B5C9C0B5C9C0B7C8C0B7C4BFB5CAC3BAC9C3BAC3BFB6C6C1B8C3BFB6C1BDB5C1BFB7
BFBCB3C1BDB4BDB8B0BCB5ADC1B3ADD0A8A79A373AB1171BBA1011AC110EE6605CAC2424
AE1013B40B0FB40E10AC0E109D131796435150436422395A8D9BA3A79B96B08681A14A48
9B1A1AA90D10AA0709AB0509A90307A90509A4060BA0080D9A0B129010188C2C30AF797C
A69798A89FA2834E52830F1797030B97010798020996050F800D17935A64CEC4CFC0CAD5
B9C8D5B8C7D4B2C3CDBACCD8B3C7D2B3C7D2B5C9D4B6C8D6B2C7D5ACC4D5637F937695AB
7493A7688397597687637F8F6A859515313E52626252453000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB616A78F6C888D8BA8B8C270878F7F99A3304B552D454C728991
526F792B4D5564848A607B807E9599A3B6BAC2CFD5C7D0D88A8F958B8D908D8C8D8C8A8A
92918E9696929A9995A29C99A49B9BA99F9FAAA19EAFA79FADA59CACA398AB9F96AB9F93
A99C8FAC9D8FAE9C8DB09D8CB09E8AB09E89B4A088BBA28CB99F89B8A38CB6A48DBAA793
BAA895BAA997BDAA99BDAA9ABEAD9CBDAC9AC4B2A1C5B2A3C5B2A2CCB9A8C9B8A6CBBCA9
C9B9A9C9BCABCBC0B0C8BFAFCCC0B2CABFB0C5BCADC4BAADC6BCAFC6BEAFC7C0B2C3C0B3
C7C3B8C9C1B7CAC1B8CAC2B8C7BFB6C8C0B7C9C3BAC6C2B9C4C1B8C5C1B8C0BEB4BEBDB3
BEBCB3BDBEB3BDBBB1BEB7AFC0B5B0CAB0ADAD6464A42025B51115B71112B9181AB41116
B50D11B30C0FAA0E109817189A434E785B7C19285A2C4069A297A3AF74759631329E1315
A90C0DAC0709AC0809A80307A90307AA030AA70105A60105A60308A6060B9C0B0D871A1E
AB7877A29090A174757D121996050E9A02099C030B98020C8C040D76151FAD818BCAC7D0
BBC9D5B6C8D2B3C5CFBBCDD9B7C9D5B7C9D5B7CBD7B5C9D8B2C9DE7C98B33957791D385E
0A224A051B4302173D0416380C223F09243854686A554D3C00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0050B814AA926A9B9F9BA0AFB99CB0BC516C7726424B68838B58737F
264751406267617F8249636695ADB098AEB3C3D3DAC9D2DB8D939A898D908E8E8F929291
9897959797949A99959D9996A49E9BA7A19EA7A19EABA6A1ABA49CAA9F96A99C94AA9D92
AC9D90AA9A8BAF9E8EB19F8DB19F8BB09F8AB3A18BB6A089B69E88BAA28BB9A48FB8A694
B7A996B9AB98BBAB9ABEAB9BBDAA99BFAC9AC0AE9DC6B3A4C8B5A6C8B6A5C9B8A6C8B7A6
C7B7A8C9BAADC9BBAEC9BDAFC9BFB0CCC2B4C6BCB0C5BCB1C2BAAFC4BCB2C9C2B7C3BFB4
C7C5B8C6C3B7C7C1B6C8C1B9C8C0B6C9C2B7C8C2B9C6C1B8C4BFB6C5C1B8BEBCB3C1C1B8
C1C1BAC1C1BAC2C0B9BDB8B2BEB8B1BEB2ADC6A09EA24C4FA12022B01819B11415B21418
AB1217A0151996262C9E5B696B5A7A1F2F5E2F3B6A8268859E505B9A1F23A81214AB070A
AF0808AF0808AA0607A80307A70208A70206A80309A60107A90408AE060DA9060C920A0F
93454A998087A6858B7A1D2691070F98020999020998020B92020B870813751E2AB5939E
C2C6CFB5C6CFB0C4CFB1C5D2B7C9D7B2C6D5AFC8D8A7C1DC6380A81A396B011B5000144D
001146000F3F010E3B000D37000F34021833475C6554544813CC0600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98D619B9B9696A5AF869DAB24414C728E97607C83325058
3E60652B4D4F7F9B9C98AEB3627A81516970B4C6CDC8D2DA91999F8A90938E9191909290
9798959B9C989D9C999D9C97A09F99A5A09BA39C99ABA5A0A8A199A9A097A89E94A99E93
A8998EAB9B8EAD9C8DB09F8CB2A08CAE9D89AF9D89B09D86B6A189B9A38CB6A18BB6A490
B9A994BBAA96BBA998BBA897BEAC98C0AE9AC1AF9EC1AF9FC5B4A4C7B6A5C8B7A6C6B7A6
C6B8A9C7B9ADCABCB0CABEAFC9BFAFCBC3B3C9C2B2C4BCAFC4BDB2C5BDB4C3BCB3C3BEB4
C3BFB4C5C1B6C5C0B5C7C0B6C4BEB2C6BFB5C7BFB6C7BFB9C5BEB7C5C1B8BFBEB5BFBFB9
BEBEB9BFBEBAC0BDB9BEB9B5BEB9B3BAB3ADBEAFAAC7A4A2B174709F48469A353897343A
98454D995E6E7C64813A406D1C2F6151537B936580932E3B9F1319AE0E11AE0909AB0507
AD0709AD0709A90506A80305A60105A70105A70206A60207A70208A90108A8040997060C
8D323E50384A998B997830398B0A1396010998030995010992010A8F020B830814762330
B0949EBEC7CEB5C7D0B8CAD7B7CADBB1C8DE7E9CBD24447502205B011A5900155100104A
010E44010E40010D3A000B36010E340112321B2F40535A5222980D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A98552A5A19991A0AA7F94A14C66717390993A595F3B5D60
3154556C8C916D8B93718B919BB0B78B9EA6B0BFC7C8D3D89CA6A8878E918C92928F9392
9596949898949A9B959C9D989E9E989F9B97A39D99A8A19BAAA198A79F94A59C91A69A8E
A99A8CAB9A8CB09D8FB19D8CAE9A89AC9A87AE9C87AF9C85B49F87B39F86B4A08AB5A38E
BBA893BDA893C0AB98BBA793BDAB96BDAA98C0AC9CC1AF9FC1B0A0C6B6A5C5B6A3C3B7A4
C4B9A8C3B8AAC5B9ACC8BDAFC7BEB0CAC1B3C9C1B4C2BBB0C1BAB0C3BCB2C3BCB2C2BBB1
C4BDB2C7BFB5C4BCB4C6BDB5C7BEB5C8C1B9C7C1BAC4BFB8C2BFB7C3C1B7C1C1B9BFBFB9
BFC0BAC0C0BBBDBBB6C0BDB6BEBBB2BCB8AFBCB5AEBBAFAABEAEA8B09C9C7C6B756A6377
4F56732A3D66183367293A6D75648A924D62951E28AB1418AF0B0DB1070AAE070BAB0508
AB060AAC070BA90408A90409A9040AA80309A80409A80307A80307A80306A5030698070C
9237443D2A426E718485525C830F1797040B96010593000793000A94010C8D020D7F0A16
6E2F36B5B1B5B4C8D1B0C7D9A6BFDC58759F0B2A60011C5C00175A01145901135501114E
010F46010D41010D3E010C38010C33000E3005172E515A59219A1000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A87E42B2A99A89959C98ABB67F96A44F6B7736565C305155
6E8B9044606727434A5F7B828EA6AC7B8F96B6C7CEC5D1D8A7B1B6868E918E9395919595
9395939798949899949A9C979E9F9AA19E9BA49E9BA69D97A89E95A99F96A3988DA5978B
B1A093AA978AAD998BAF9A89B19C8AAD9B88AB9A83B09D85B29E85B5A189B6A48DB6A58F
B8A791B8A68FB9A792BAA693BEAC98BCAB97BCAA98BEAC9BBFAE9DC2B2A2C3B4A4BEB2A0
C0B8A5C3BBA8C2B9A8C2BBABC6BFAFC6BFB0C7BFB3C4BCB2C1BAAFC0BBAFC0BCB0C1BDB0
C6C0B2C8C0B6C7BFB7C7BFB7C6C0B6C0BEB3C4C2B8C4C2B8C1C1B7C0C0B7C1C0BABEBEB7
BDBEB6BFBFB7BBBAB3BFBCB5BCBBB1C0B9B2BAB3AEBCB5B1B4B2ABAFAFAC999EA3707F8E
5A6E855669877476949470889035469E1620AB0D12B20B10B2080CB1070EAF070DAC060A
AB060CAB060CA60409A60309A5050AA5060BA30508A50308A50207A80307A1030690060B
9648572E2647515E789B7B8677141C93070E98040995010894020993000A90020C850510
6E1F2A918898ABC4DA9AB7D73B5A8A04215D01195B01165B01185D02175B01135400104B
010E43000D40010D3D000C38000B31000D2E02132C38434A46362100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BD24BCAD9C7E878EB5C8D56983913858633B5C61607D82
486166172E327B9497718A8E687F86B3C5CCB2C1C8C1CED5B2BDC3848D908990928D9291
9496959796949A99959C99969E9D9A9F9C99A49F9AA69F98A59D93A39B90A59A8FA5988D
A7978DA7958AA89587A89683AD9B87AE9D89AA9A84AD9C84AF9C84B5A289B5A48BB4A48B
B7A78EB7A78EBAA992B9A894BCAA96BBAA96BDAA96BEAB96BCAC97BEAF9CC0B3A1BCB2A0
BCB3A0C3B8A4C3B7A5C1B8A8C1BBABC3BDADC5BEB0C9C1B6C2BBAFC1BBAEC0BCAFC0BCB0
C2BCB1C6BDB4C7BEB8C7BFBAC6C1B9C1BFB6C0C1B6C1C1B7C0C0B6C1C2B7BEBFB6BFC0B8
BEBFB7BEBFB7BBBCB4BABAB2BBB8B1BCB7B2B8B4B0BBB7B3B2B3ABAFB0AAADAFABAAADAD
A8A7ABB29EA7A86B76932531A8141CB30D13B5090FB50811B4060FB1060EB1090EAC070B
AA060CA7080D9D0A0E93090E900F15901317950C119D050BA30307A50306A00508890C15
8D546D161F484D6382A696A176252B900D1597030A96000A94010B93010B90010A86050E
7A2A3D322A4E6688B62B5085011E5E01185C00145802165B02185C01185A011551001248
01124004153C0C1F4307173C01103201122F04152F22313D4C423400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0056BF26B7A38F6F787CB1C5D04B677338596258777C516D72
152E32758D917B939AAAC1CBAFC4D0BBCFDBA9BAC4C4D0DABBC4CE838A91868E908C9392
9598979696959896949D99979F9D999C9B97A29F99A19B93A29A91A2988EA1958BA4948B
A49288A69289AA968AAB9687AD9A88AB9A85AE9D87B29E88B39F87B09F88AF9F89B3A28C
B6A48EB4A38CB6A68EB7A791B9A894BBA994BDAB95B9A78FBBAA93BEAE99BAAF9AB9B09C
BBB19DC0B4A0C2B6A3C0B7A6C0BAA9C2BDADC7C1B4C8C0B5C5BEB3BEBAAEC0BCB0C1BEB2
C3BEB3C6C0B6C4BFB6C4BFBAC4C0BCC4C3BCC3C2BAC2BFB7C2BFB6C2C1B7BEBFB4BFC1B7
BDC0B7BEC0B9BCBDB7B8B9B3B7B6B1B9B6B1B9B6B1B6B5B0B6B6ADADAEA6AFAEA8B0A8A3
BB9F9FA760659A212AAA1117B40D11B5090DB3080EB4070DB4070DB2070DAF0A0EA60A0D
9B0D12951B239539428E4D5D805466845663A04A52920B11A5060AA6040A98080C92333F
492E500D25547193B49DA3B2824D5483101795040C97010C94010B92010A8D000781050C
7B2F45201644041D5C011C6200176100145A001357011458011758011C570E2B5C1D375D
3951695066764F6275162842061C332139490920300F202E4D463E24960900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0053BA1DAA9175717474ACBFC8516C7745626B627F84173034
688185738D945C778299B2BF7A94A1748E988A9DA6C3D1DAC0C9D3888E958B9092919594
9195949496959795919C99949E9C979D9D98A19F9A9F9A92A39B90A49990A3968DA4948C
A5938BA99790A9978CAC988AAE9B8AAD9A88B09C89B49F8BB49F8BB29E89AF9C86B19F89
B3A18BB3A28BB5A58DB6A690B9A793B9A893B8A791B8A790B8A792BBAC97B8AA95AC9E8A
B5A592BDAF9CBAAD9BBEB5A5B9B3A3BEBAA9C3BEB1C7C0B5C5BEB5BDB9AEBCBAAEBFBDB0
BFBBAFC1BEB2C3C0B6C2BEB7C4C1BCC3C2BCC0C0B8C0BEB6C1BEB6BFBFB8C0C1BABDBFB8
BCC1BABBBDB8BCBEB8B7B8B2B8B9B1B9B6AFB8B8B0B8B8B0B4B4ACB1B0A6B5AEA7C0A3A1
A961649C2028AE1018B40B12B50B0EB4090FB3080EB3070DB0090BAA0A0F9D121595272E
934B5B7C57744B456C232D5D1926544D405F934A57920C14A10209A1040997171B9D5869
201C412A4A775D8CAE6D8CA389727E77181F91070E97020A9301099202098D02087E040E
7631491C144502165700155E01165B01175800165306235B1634653457815A80A07A9AAF
8BA4B093A8B35C7285061932213B4C4B64684053590E1D2A48494821960D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DC0C9F815D8C8B87A7B7BF5D75825E7A841A363B5D787B
6C878C5470794B65719EB5C1405A63859BA2C2D2D9C4D1D9C7D1D78B9298868B8D888C8D
848888878B898E8E899A98919B99929D9B979F9C979E98919E968CA1968D9F9188A4958E
A4938BA4948AA6968AA99789AA9788AE9988B09B88B19E88AF9D88AF9D88B09E87AD9C83
B2A089AF9D88B2A08CB3A18CB1A08CB3A28EB5A48EB4A58CB0A18AB1A28CB1A38EB3A38F
AE9D89AEA08BB0A492ABA190B2AB99BBB5A5BEB9ACBEB7ACC3BBB2BEB7AEBEBBAFBEBDB1
C0BDB1C0BEB2C0C0B5C4C2BAC3C2BBC2C3BEC5C5BFC2C2BBC0BFBABFC0BAC1C4BDBDC0B8
BCBFB7BEC0BABCBFB8BABDB6BABBB6BAB7B2B9B8B2B5B4AFB5B6AFB5B1ABC2ABA7AC6869
A02529AF1116B40C11B6090FB5080CB6090DB4080CAF0B109C0D0F982A309757656C5675
2E3567122964102C65253A6957517581495F8B19259E0710A4030AA1040AA41A21A34857
6C48616A6F8895AFC37792A49C97A1773139880C1395030B9401089100098A010B79071A
4E163B12114B02145901135B001559011A57092759375B8186A8C497B8D32A4C6781A1B7
7491A07794A62D4762011530506A75586F6D54646422303844484A21981100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009E7D53A5A39DA1B0BA839BA836535C48656A718D92
4D6A7146646C95B0B993AAB494ABB4A3B6BFC6D5DDC7D2DBCCD5DC8D969B7C8487787D7E
75797780827E8C8B8795928C98948D9E9A95A39C97A19790A1978E9F958CA0948A9D8F86
A19289A6958DA7968BA99889AB9988AA9885AB9A83AC9B84AB9983AC9B84AE9E85AE9D85
B19E86B5A08AB4A18BB19F87B2A088B19F88AD9D84AF9F85AF9E84AB9A81AB9A83AB9B84
AD9E87AB9E87ABA08AB1A794AFA794B0A897B4AD9EB6AEA2C2BAAFC4BFB3BDBBAFBDBBAF
C1BEB3BFBEB4BFC0B9BDBEB9C0C2BDC3C4C0C5C6C2C1C2BDBEBFBABDBFBBBEC2BBBCBFB6
BDBFB7C0BFBABDBFBBBABCB8BABCB9B5B4B2B9B8B4B4B5B0B5B5B0BEB0ACB8818299282D
AF1318B70B10B80B0EB40A0CB3070CB2090EA80D119E1F259E4F5C7156732C39690C2866
11326D36507C6F769393768B883B4B8C13209F0814A4040CA9060BA40108A1040B940914
87202BA06B75A19BA3B0BFC9A3A9B38B646E7A141D92070F95020A90000A860511600B29
240A3E0A155901145C01145A021D592748777A9BB9A1BCD1AFC7D98299AD5770846E8797
5D788833516B021E3D0F2B424660644F635C52635F3B494D3E4346219A1500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A38055A7A49E9CAAB5879FAC314D587591994B6870
3B595F88A6AB4A68716E8A95748E9995A9B3C4D3DEC0CBD5C8D0DA939BA27C8487767A7C
737674848480928F8C9C9593A098959F9793A49D969F978F9E968E9F978D9F94889E9085
A29086A49287A9978BA89687A99887A89884A99983A89780AE9B83AC9B82AA9A80AE9D84
AE9C84AF9D85B09E86AF9C83B19D84AB9A80A9987EAA987CAB977CA9977DAA9981AB9C85
AA9B83AC9E86AB9D88ACA18DAAA28DAAA290ACA596B5AFA1BBB4A7C1B9AFBDB9AFBFBBB3
C3BEB8BEBCB7A2A5A39197969FA4A4BCC0C0BFC1C0BEC1BFB0B5B29FA6A4A8AEAAB8BDB8
BCBFBABCBDBABABCBABCBDBEBBBCBDB8B8B6B4B6B1B3B4B1B5AFACC39F9F993D42A8181E
B50D13B80A10B80B0FB60A0EAD0A0EA010159B323B92607842436D122E680F346C3A5782
747C989B85949A5E698E272F970F17A0050DA40309A7030AA40308A70409A8040AA4040B
970911821E25B08C9599A6BA5A75908B8497732C35880C1392020A8D020B73081B3B0A35
0F1051041661001A5E0928614A6C949DBCD7ABC5D7ABBFCEB2C5D48297A799B2C094ACBD
4F6782071F450D284745637359727255666052605A414F5139424525A11D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A68254A6A09996A3AD748896758F9C5F7C853A575E
7D9AA04C6A72607E8675909A758D97A5B6BFC6D3DDC3CDD8C9D0DBA0A4AE7C8186727679
7B7E7E8B8C8A9392919793919D96939C958E9E998F9A958B9B968D9C948C9D9188A29087
A18E83A49186A69487A39283A69584A89784A99884A99884AA9782AB9981AA9B81AB9C82
AA9980A8957CAC987EAD997EAF9C81AF9F84AC9C81A9987DAB997FAB9980AA9B81AC9E85
A7997FAA9980AB9C85AB9F8AA9A18DA8A18EABA491AEA898B2AD9EB3ACA1BDB7ADBEBAB1
C1BEB8A9AAA5949994B2B8B5888E8DA9AEAEC2C4C5A2A5A4959A97A2A7A3A1A8A3848E8B
A3ADA9B6BDB9BABDBABEBFBDB7B7B5B7B8B4B5B6B1B2B1AEBEABABAF6C709B1D24B21016
B60B11B80B11B5090FB00C119B14199A445173577525366C0E327126477A6B79979C8B9C
9D687190333995161CA10B11A4040BA40309A40309A30208A40309A50409A50207A50309
9F030B830A138F5A676E768F1A39586C788C8B626B7A141A8B040B8605105A09261F0C45
07175F021B6213366F678EB4A6C6DCB0C7D8B1C5D4B3C5D4ABC0D23D5B7391B5D34C6B8F
14305B011B452A486173939D6B828360726E5260584856553440412CAB2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A47C4BA19A8F929EA5AABCC9849CA93C59646C8991
55727B5C7A84738F99788F97ABBDC6C4D0DAC6D1DCC5CFDAC7CFD9AAB2BA696E75727579
8385878F908F92918F96918F9D95939B96919A959093918A96938A9C948C9F91899F8F86
A18F85A18E82A18F81A69385A99686A89683A99782A79581AB9985A8967FA9977FAB9A7F
AB987CA79277B09B80B19C81AD9B80A9987CA9997AA89877AD9C80AA9A80A99A80A99B81
A8997FAB9A80AC9E85ADA28BABA08DA89D8BACA28EABA28EAEA897A9A394B5AFA3B9B6AB
C2BFB7AAAAA5888C87AEB5AF8A908DAFB2B0BABBBB8C8D8BBDBEB9BEC0BABCC0BAADB3B0
808988B5BDB9B9BAB5B9B8B3B9B8B3B6B5B1B6B5B0B9AEABC7A0A298373CAE181DB60B11
B60C10B50D10B00D129C181CA055625F5174162F6810336E475D878E849D98697491383F
8F151D9B0B11A3070EA8050DA7040AA50109A4030BA30208A10109A20108A60308A70409
A00309860610874C603C425B86A1B596A9B69B8D95762E34840D137E0919470E33121353
03165F011C5B4B749FA3C8E1AFC9D7B7CBD9B2C6D5B4C5D6AEC2D54F6D8A466C94163565
001C480D2C4C41606E5C757A53686852645E5362574D5B562D3A3A544E4500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0051BE29A397898A959EA8BDCB607B865B788257747E
58767F6C8992728D96A7BBC5BED0D8C1D0DBC3CFDAC5CFD9B2BDC6909BA26F767C737579
88878992909092908D938E8D9B959499949297928F8B8884908D859A92889C8F869F8E86
9E8B829F8C7FA29183A49383A89685A99782A5937DA4937DA4927CA7947DA7937BA8947A
AB987BA89579AF9C82AF9B82AA987EA49278AA967BA69273AA9779AA997EA7977EAA9C85
A4977FA69A81A9A089ACA28FAEA191AA9D8DA89B8AADA392ADA696AAA395A8A496AEAB9F
BEBDB3BCBBB39C9F97939B92A4ABA3BFC2BDB5B5B3959795C0C1BDBEBFBABCBEB8B4BAB7
7F8985B2BAB5B7BAB5B9B8B4B9B6B3B3B3AFB4B4AEBFB0AEB98285971F26B51117B90C12
B50C11AF0F13A01D23A35A6A554E72163168203C71717296997184943E4A91181FA00E15
A4070DA7040CA7020AA50309A30207A40309A6050BA40309A30208A60209A8050AA70309
A00509850A1488556D1A28499CC0DA6488A177889C8E6B757317226E0D26310B3A0B1454
0915531F2F633D6085A4C9DFAFC8D6B4C8D6B6C9D8B6C8DAAAC0D77694B60A2B59001E50
1C41645476877A949A6E82855D6E6F53635E5262584858562C3A3E56544E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004EB91FA59781869096A9BECA5E798473919A486771
65838B5C777F98AEB6BDCED8BDCED9C1D0DCC5D2DEABB6C3838D967B858980868A838687
88898890918D8E8E8A95919096918F98918F98928D827C758F88809D938A9D8F879D8B85
9E8A82A08D80A18E80A59384A69483A7937FA7927DA4907AA49078A8917AA9927BA8937B
A8957DAB9881A7947BAB987EA69579A39176A69277A79275A89375A9957AAA9A81AB9D85
A79C85A69B87AA9F8DACA190ACA291AEA393A69C8BA99F90A9A3999B9A8F9091869A9D94
B9BBB2BCBCB2BEBFB4C1C2B8BFC1B8C5C4BDBEBEB98B8C8BB3B6B6BCBFBDBEC2BD9FA5A2
909693BABEB9BABBB7B8B7B5B5B4B2B2B2AFB3B3AFC0B0AEAC6D70A11E22B71114B90C10
B40E11A1161AAA596659486C2334674A5182896A8B954758951C28A30F18AC0A11AE0A0C
AB0508AD080DAA060CAA070CA6050AA60409A60409A6030AA7040BA8040BA7030AA8060D
9E090C881E276E4F6E1026507CA1C11D4164385473AEA9B97137465E1637270C42121253
2813454D34583A4763A8C8DCAEC9D6B2C9D7B5CCDCADC6DE6E8DB0143464011F511F466D
5D859C88A7B28FA6AB7D8F926D7D7D5D6D6950625B394D4C253A3B61685F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004FB91CA29074899497B0C5D187A0AD54737E5E7D86
65818893A9AFACBDC6B4C3D0B9C9D7B9C9D898A6B677818C7780867B8386808689868A8D
88888A8F8F8F908F8D918F8C9992909A908E9E94918F867F8C847A938A819D908A9A8B85
9B8A819E8C7FA39081A49283A1917FA2907BA6937CA7937AAA957DAA937BAD947DAB9680
AB9681A7927BA28D73A49075A49276A8987CAC9B81A39073A79275A59174A6957CA99980
A69982AB9F8BB0A493ACA192ABA293AAA392A49E8D9C988A7C7D747D8179787E77626C66
848D88BAC0B8BCBEB5C1C1BAC5C3BBC5C2B9C1C1BBB0B2AF8E9293919899929D99949D98
B2B5B2BAB9B6BBBAB6BBBAB6B7B8B3B4B3B1B3B3AEBFB1ADAE6C71A21D23B81114B90E0F
AD1112B4474C87596B5C4E6F8769888F465D94212FA3121AAD0D13AD070EAF080DAD0709
AB0508AA0409AB050BA8030AA6060AA1060A9F0C0CA10C0FA4070DA60309A70309A20309
91080D9343543A345C1A3B667698AF7490A2849FAFC2CEDC927A8B4E2247200F47190F4C
46123C60233F3C344F9CB9D1A9C8DAAEC8E093B2D53F618F07285F011F550A27514F7089
59798668828B63767C5E6F71606F6D5464604D605C1F3439294147606E67209B1300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0027D90BA68D7093999DB4C8D86F8A9961828C5E7B81
96ADB3B6C6D1B3C1CFAFBECCABBBC98796A46B7681737A82787C807A80837F848787898D
858689888A898D8E8B92908C948F8C98908E97918B979289918D829892869B9287998B84
9A89819E8C82A39084A59284A59081A48E7CA58F79A7927AA6937BA9957DA8937BA9947C
A6947CA39278A39173AA9679AC9B7FA5957BA8987EA59376A69174A89276A59278AA9982
A89982A89C84A59A84A59B87A99F8CA69D88A39C89807F727B7D768D91898F958E737E7C
566663A3AFA8B7BBB3BFC0BBC5C5C0BEBEB6C3C4BDC0C1BCC0C2C0B8BAB8B9BCB8BEC1BC
BBBBB8BAB9B7B8B8B6B9B9B7B8B8B6B6B6B5B8B9B4BEB3B1B780829C2127B61217B80D0F
AA1111D5686AB66C75A14E5E9523319F111CA70A11B20B0FB1070BAF050BAB0509AC070B
AA050AA9040BA8070EA2080D970C0E8C1816A5423CBE504E980D12A3030BA8040B9F060B
8A1721825473102254537EAA9FC5DA9ABACA7DA0B2AECCDDB2B6C6614E6D1F164B170E49
43123C5213304535547F9BBF8CAFD44F709E10306703235C092C5D2A4B70728EA469828D
849BA1778B90697C7D6476755B716D4E6464344A52061A2D172C3D606F7025A21C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A58666939597B2C4D46B849667839088A2A9
B0C2CAB8C7D4B3C3D3A1AFBF7A808F706C786E677075737A7D7D837E8084818689858889
8888898987888E8D8A92908C928F8A938F88948F88959188969087978E84998F859A8A81
9B897F9B897FA08D82A18D80A18B7CA48979A58C79A6917BAA967EA8947BA7967BA69579
A493769F8D6FA49070A38E6EA39071A18F73A28F74A69074A79070A89270AB9676A89679
A5967CA4987DA59B7FA99D84A89C84A89D86A69F8B6B6A5F6D746E7E88827A8480627170
4D605C9BA8A0B9BDB5BFBFB8C3C2BCBFBEB9C0C0BBC0C1BBC0C0BBC2C1BDC0C0BBC1C2BD
BBBBB8B9B9B5BABBB6B8BAB5B6B9B4B7B9B6B7B8B3B8B4B0CAA5A4963339B0181DB80F11
B41012B31D21A81B22A8141CAC0E15AC070EAF090CB3090CB4090EB0070CAC070AAB060B
A6050AA0050C960B138D1A2292434A8B585DA7717396353B980B12A6050CA3070C900E14
99506238305F0627605E8FBE5585A97DA9C5234E689BBFD5BFD1E09393A92F2D5511144B
1D12472512412122541630690C2C68001D5A022157254770779AB891B1C99AB5C789A1AD
A5BCC48DA2A9889BA17A929567838B304C5C061F3701122F01142D3C4C5629AA2700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A2825D939493B0C0CE8096A578919CAAC1C8
B1C6CEB4C5D4A5B4C67072826D55635F303963383D8370747C7B7F7E83867F8585838786
8789898C8C8A8F8F8C92918C8F8F88939188918E86918D85968F86978D84988C839A8B82
9B897F9D897E9C897E9E8C7FA28B7CA18878A78D7DA7917FA28D78A7907AA59077A58F73
A69071A49070A28F6EA38E6AA8936EA18E6BA3906FA79373A79170AA9370A89371A69475
A6977BA79A7FA5987FA99C82A79D83A49C83A49E8A75756A525C57586A665566644D5C5B
616F69A9B1A7B9BDB2C0C1B6C4C3B9C5C2BBC5C4BEC5C6C0C0C0BBC5C4C0BFBFBCC0C0BE
BFBEBCBEBDBABABBB6B9BAB5B5B7B2B5B6B1B4B7B0B3B2ADC3AFACB670729F1C20B71213
B90E10B80C11B50D11B40C11B2080CB3090DB2080BB2070DB3090EB1080DAC080CA4090C
960B0F8D1E248D445075516845364F6A4D60873D4990141DA0090FA1070C921013974755
5A49710C25602147796991B2274C6B5B7F9A638396A9C5D4BFD2DEBCC4D1736D8828214D
18134914114D0B124F041A5505265B21426E6685A6A1BFD769879F82A4BD46677E7A96A7
6C87946A818F677F8F3C576D14314F031A3F011238010E330111331A2C3E4C4D4400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A38256A5A49FA9B8C397A9B596ABB5AEC4CD
B0C6D2A5B6C4717584674C5A67232D6A0D13671619865E607F797C7D82847D8485818788
888B8B8D8D8C908F8D91908C918F8A928E87918D87938F87968E86938980998B83998881
9A877F9C89809B887D9D8A7D9E8A7A9E8A78A38D7AA58F7CA7917DA68F79A28B73A38A6F
A68D72A58F71A18E6DA08F6EA39170A28D6DA28E70A39070A4906FA89272A99675A8977B
A69780A99D86A59A84A39A82A29A83A29A84A49D88989684666C625B666066716B68716A
8A9085A1A497B3B4AAC0C0BAC2C1BAC4C0BCC6C3BFC4C3BFC1BFBDC4C0BFBFBEBCBDBCB8
BDBCB8BDBCB8BCBCB7BABBB6B7B9B4B7B8B2B3B4ADB4B4AFBEB0ADC08386A02529B51315
B90E0FB7090EB70C0FB50B0CB3090BB5080EB3080EB2070DB10A0DAA0A0D9D0E12911F24
8F475372566E36365A2F33596C57727D3647860F199A070E9E0A0D901116934652625173
0F26600E346A688BA8859EAC9CB5C2ABC5D588A3B1BED4DFC0D1DBC7D2DCAFACBC694D68
4A1A3F42113D341542262B557797B5A3C2D6AFC8D8ADC6D649657A67859B486577708796
5E7481657A8E213959041A4501144301104102113B010E360110350A1A35494C4F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009B7848AEABA59CACB9BCCEDDB1C2D1B0C3D2
A8BCC978818E614D575C1D266B0C1474080E6F0E12824B4E84787A7E81847E8285848689
8687888B8B8B8A8A898E8E8B918F8B918D88918C868B877F928A83988D89978984988680
9B857EA0877E9E887E9F897DA38C7D9F8877A18A78A68F7CAB937EA38C759D876E9F896D
A38B6FA79075A89479A28F73A39173A38F73A190729E8F6EA1916FA4936FA39372A79A7F
A19580A89E8AA59C88A39885A69D88A19A83A19C86A19E8A9697879395889193869A9B8E
A3A194A3A295AFB0A7BCBDB7C1BFBBC2BFBCC5C5C1C0C0BFBFBEBEC1BFBFBEBDBABCBCB6
B9BAB5BCBDB8B8B8B5B9B9B7B7B9B4B4B7B0B4B7B0B5B6B1BCAEACA46367A11E24B50F13
B6090BB7090DB40709B6090CB70A0FB3070DB40B13AC0B0FA31113951F25954955755773
383D631D2C5948477078526E7C2737890F1A95071094090E8C1B21904F6051476B102B61
0D356B587A9DB9D2E3ACBFCDA3B9CB6384A0698EABB3CEDFBFD2DDC1CFDAC6CCD8A493A1
6B34466C142A640E26512D4A7D8EA4AECAD9B1C7D5AEC4D19CB5C58EA7BC92ABC198B0C1
7C94A2829BB1041A44021347000E42010F41010D39010D35011034031430444A5200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF009C7640A9A39992A2ADC0D3E2AFC1D2ABBBCB
848D9A6A626D59323857121570202587363A6310167E454988787B7D7E807C80817F8283
848788888B8C8D8F8D8E8E8A92908C918C87938C868F89828C857D978D89968885988582
9E85819D847EA0877FA0887DA38B7C9E88779F8B77A28D79A5907AA390779D8C6FA79479
A69277A28D73A18D71A18C70A18C6FA08E70A798799D8F70A19171A29271A39375A3967E
A69C89A5A08C9F9A86A19985A59C87A09A849F9A86A19C8A9D9A899E9B8C9F9D90A19F92
A2A093A2A195AEAFA6B6B7B1C1C1BBC2C1BDC2C3BFC1C2C0C2C1BFC0BFBDBCBBB9C2C1BD
BDBDB8B8BAB6B6B8B5BDBFBCB7B9B4B2B7B1B2B7B1B1B4B0BBB1AEAE73769B1C22B30F13
B70B0DB6080AB6080AB70A0FB2090FAD0B10A00F13921B209446537F5E7A39406E143068
2C41716C5B7F7E3C54841725930E1892070F8C0D1284252E81546B3638630B2760194073
8CAECF94A9BC9BB0C27E96AD8AA0B8324F701A3F60ACCBDFBCD0DDBECEDCC3D1DBC4C4CF
997C896D25336F0F2161263C5C5F74ACC8DAB0C8D7ABC1D29FBBD2335175203D6A48678A
7494A95E7991081E47011244001044010F40010F39010E32031633051A333B465010CD0C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053C12BACA5958E9EA5BED0DFB3C2D39198A8
6C5E695D3C416D4446562B2C734E5186585F59181F6F383C8673747C7C7F7A7E7E7C8080
828889878B8B8B8D8B93928F91908C928F8C928E8A928A84948B85968C87968985998883
97847E9D88809F8981A38D83A08B7CA08E7BA08E7AA18C77A9937DA08C749B896EA28E71
A18C6F9F8A6DA18B6DA18B6B9F8B6BA08E6FA49576A19273A49476A29275A39379A4977F
A59E889E9A83A09B84A19A84A29A86A09A88A19B88A09B889D9A879E9D8A9F9C8DA29E91
A29F93A6A69BACADA4B2B3ACBFBFBAC0BFBDC1C0BDC0C0BBC3C2BEC1BFBEBAB8B5BCBBB7
C0BFBDBDBDBBB6B8B4B4B6B3B1B6B1AFB5B1AEB3AFB4B8B4B7AFADB68284991F26B10F14
B70C0FB80B0EB50B0EAE0A10A00B13931A22994752835F7A3E4270132E6E0D33732D4D7F
7C759272283C8C101D960912930A1186131B843B48654C6A1D2B5D072863193F6F6283A1
92A8B896A4AE8696A46C80918FA1B0899DAF91ADC0B4D0DFBED2E0C2D3E0BFD0D9C4CEDB
BFBDC8906D79671E2C601C314A4055A0BCD0ACC7D792A9BF617C9B0D2958011B56031F4F
44647E536F830E2346011241010F4302113E0115360F283D324E592D47532D3D4624A220
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004FBD24B0A5919099A1BFCEDEA6B0C1786D7A
6332395813146E3A396B52536A5C61775A62581D26672C31846C6E7677797A80807B8081
8083858789888C8E8A8E8F8A90908D92918F95918E938B88968C88968C87988E86998D84
95877E97857E9D8A83A28E859E8B7E9D8A7A9E8A75A18974A78D78A188709E876BA08B6D
9E8B6BA08D6EA08C6D9D89689D8A699F8D6CA09272A29478A99A80A7977DA29279A69983
A29A849F9883A19984A099839F9984A09A879F99889F9A889D9A889C9C8A9E9C8CA19F92
9C9C90A1A298ABACA4BBBDB4B8BAB3C0C0BBC2C1BDC2C1BCC3C2BDC1C1BCBEBEBBBCBDBB
BABDBCBABDBDBABEBEB4B8B8B5B9B9AEB2B2AFB5B3B3B6B4B6AFAEC2969B92232BB11318
B60C10B30C11AD1317991A2096414D89627946486E1730680C326E234A7E5E7EA08B99AA
9D8089771B24910F18890E158327317D4E643C375E10275E0A2E6630547C6E8C9E869B9F
91A0A2A5B0B7919FA7B8CCD7B8CFDC94ADBD85A6B99BBDD1BAD3E2BFD3E1BDCFDCBDCDDB
C4CEDAB9B1BD845E6C5920324A344A839AAFA9C3D394ABBD7991AC122C5B01185601154B
4765856F8BA018315001154000133E0C2343284452425C5D4B635E4B606229393E2AAA28
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF004DB71DB7A38F91969EBFC8DA837F8F6A434B
61131664080A6424266A4F51675D62755D6460273063262C83676A747477747A7D797C7E
8484868989888C8C8A8E8F8A8F908D91918F928F8C96928E948E89948E879890879C9188
9D8D859D8A839F8B83A28E85A28E81A38E7C9D8872A18A73A187719A81689E86699E8768
A08A6A9E8A689F8B699E8C69A08D6AA59170A391719F8F72A6977DA7987FA2937EA39783
AAA08DA29988A59D8B9B95829D9784A099879E99869D99869C9A889B9B899C9D8D9C9D8F
9D9E909D9F93AAACA1B8BAB2BCBEB7BCBDB8BDBDB9C0BFBCC1C0BCBDBEBCBBBEBDB9BDBD
B7BEBCB5BCBCB6BCBCB5BBBBB4BBBBB1B8B7AFB6B2AFB3B0B1AEACC5A1A4912D33AD171D
AD1115A01D219B3E47936475554E6B3442683049752C4C765A7A968399AB91A0A79A9DA0
A58D906C262B7E232C8244555442641D2A5C07245C1338674E6F8C7B939D8E9FA08E9B9B
9CA7A9C7D4DCB0C2CC92ADBE5B819A7DA1BB355D777DA4BBB7D3E2BCD2DFBFD3E1BFD1DF
BDCDDAC2CCD9B1ADB8725A684737495E6F82A6C2D1ACC3D48098B3203D68001A53031852
1D355D718FA61F3C510B263F25415745606B4E66694C615C52635D4E61602334373A7A35
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0025D90BB9A2867C8082A4A9B468535D591C22
6D171A71181A5E161A663C4168545B775F67642E36601F26866467726E727175797A7C7E
8080818989898C8B8A8D8D8B91908F928F8E94908E928F8B928E89968E89958C859D9188
9D8C859C8A839E8C83A08E839E8C7F9F8D7B9B8872A08B73A28B739D856A9D85689E8567
A28A6B9F8969A08D6D9E8B6B9F8B6A9F8A6BA39071A09171A4967AA89C86A69A879F9380
A29987A9A192AFA7999C95859C9481A098849F98859C99849B9A879C9C8CA0A1949C9C91
9C9D909FA193A6A89CBDBEB5BFBFB9BFBEBBC1C0BFBEBEBCC1C1BFBBBEBCB9BEBDBABFC0
B8BFBFB3BCBCB6C0BEB1BAB7B2BDB9B2BCB8B0BAB5ADB4B2B3B2B2C8ABAE913D429A2226
9F393F9A6575615772373C5E605B7C7A627C917E919295A094A0A697A1A498A1A1979B9B
9A9594866D6E856F7B2E30550C255A0E2F63315377667F907F91938594919FACAAA7B2B3
8E999E97A3ADA0ADB88699A8345067688399748D9E9EB7C8BCD3E0BDCFDCBED0DCBED0DC
BED0DCBDCEDABFCDD8A5AAB5676A7A43576BA2BFD18DA8BA25425D29476F011C4E01174E
072148506F7F435F654660674F696D5168695069664D645D4E625C495C5D213238494A47
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B0926D74716D7572785B3C41551B1C
7B3C3C742D315A0C116126296A4A4F74555D682F375A1B1F8260637270716F7576757779
7D7D7F8887898B89888E8A88928D8B948E8D908A878E8885918785918482998B869F8F8A
9E8C859F8C85A28E879E8A809F8B7FA390809F8D789E8C769E89729D84699D8365A1886A
A0876AA48E719D8B6D9F8F6E9B88689E8B6FAA9A7F9F9175A092799E927DA79F8A9E9681
A29A86A39C8CB2ACA1A29C8E9A92819D96839F99859E9B869A9986A1A395A7A89FA19F98
A1A096A1A196ACADA2C0C1BAC1BFBBC1C0BDC0BFBFBDBEBDBDBFBEBCBFBEBDC1BFBFC3C2
BDC1C0BAC0BEB8C1BDB8C1BDB6BFBBB7C0BEB3BCBBB2BAB9B6B7B7C2B3B5936769A06A6E
7F66773C3F615A5A7C906C868A3B4C84212B995659A6989B959EA197A1A1999F9F979E9D
949897969594838A9320355528486D5D76917B8C94818B898A938D89928C8B9190939799
959296948F96968F95A0949CA297A0B2A7B1988E98B8B1BDC4C5D1C2CCD8C2D0DAC0D0DC
BDCFDCBACEDCBACEDBBACAD5A0AFBB51697B84A5B76985937992A0637C932E476B04204C
234563617F88637B7A596E6E5C7070546968516A664A645D4C635D43585C1D3039565B5B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A67D537B6D656C5F655634395F3334
794F50652E3152090B702F2F6B3A4077414A661E24601E217F62627172746F777A737679
7A797D8480838E8A8A8C8A878C8A858B85818E84829086848F818091817F92807D9C8984
9F8A859D898298857C9C877E9C867EA49185A29181A3907D99836D9C83679A80619C8264
9E86699F8A6D9B8A6B9D8F6D9C8D6BA09174A79A809C8F76A2967DA19780A19B859E9884
A39C8BA8A294B2ACA1A59F929C9584A099879B97829D9B869A99869D9C90A8A79DA8A49A
A9A69BACACA1B1B6ADBAC1BBBBC0BDBEC2C1BEBFBFBDBFBCBFC1BEC2C5C2BEC2C1B9BDBE
B9BCBDB9BEBEB5BEBDB5BEBDB3BCBBB7BDBDB5BABBB6BABBB3B5B6B6B4B4B6ADACB9A9AF
7C6A7F8F6B89984D65931F2EA012199F11189D424C69586A6B7F8C92A1A2979D9C9BA09D
949A969297958A949378868C7C8A93838C92888C8B8A88858E8A85928481957B7D9B747A
94606796555E9045508F39458C323C8A2F3C862F3C8B3E4C965D6BA2828FB6ACB8C3C8D4
BFCFD8BBCFD9BBCFDAB7CAD5B6C9D299B1BE82A0AF86A2B0AAC4CF8BA2AEA9BED1516D83
7F9BAD637B82677B7C586C6B596F6C566B684F67614A645E4C63602F434D1F34405D6766
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074912F7E67597262634E30336A4949
725352501D1F530E0E7A3839641F25671019670B11712E317E61636D6A6F6E747A71777A
7C7B80827D818882838886848785828983818A817F8B807F8C7C7C8E7A7A917E7C92807B
9A878099877E9C897F9E8A819E8A83A18D839D897B998471978069A0886EA0876A9A8265
9C896C9B896D9D8B6E9D8D6F9E8F719B8E73A2977FA399809F957DA9A08C9F9785A49E8D
ABA496ACA69AABA79CA9A5999A96849B98839996829B98859796849C9C8EA2A297A2A097
A8A99FA5AAA3959E978B96918994938E9B9BB0B9B9B7BEBBBEC2BCBCBFB9BCBEBBBABCBE
BBBDBEBABDBCB8BEBCB8BEBDB6BCBCB6BABAB4B7B7B7B9B8B5B6B6B6B5B6BAB2B3C09EA6
A85F6F962536A2131FAB0C14B00A12A50B149734424C3B584D69818CA2A6969F9C9CA39F
9AA09C9197938B94908B92918D8F8F8D87889885859776778E585B893B4183222C83141F
890F178F0B15950B16980A13980A119506109207128F0714870B1A8017267F303F976B79
B8ADB9C0CAD5B7CBD7B2CBD6B1C7D2B1C7D5A3BECF4F7085799BAE5C7C8A6C8794637986
5E737B5C6F725A6D6C596D6B586F685169634E67614E66673A505B091E3024404C5E6D6D
219E1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004AB2187F654B6E5F595239375E403E
70585563413E4C19177E42455E11176306096A151682474A6A4A50736B706B74766C7576
7D7E82868285857F818782808A8381877F7E877E7C8A7F7D8679758979768C7A778E7D77
95847C96837C99867F99867F9D8981A08D819C887897816C99836B9C866E9F886F9E8A6F
9E8F739B8F739A8D72A090769D8D759C8E78A0957FA69E8A9F9785B1A89AA9A193A7A294
ABA69AB1AAA1ACA69DA6A4989796869998859A9887A09F8E9B9A8DA0A094B0AEA4A9A79E
A9ABA38990899CA59DB3BAB2B5BCB89FAAA8818E8CB8C2BEBCC1BBB9BBB6B8BBB9B8BCBB
B8BBBAB7BBB9B6BABAB5B9BAB7BBBBB3B7B6B4BAB6B4B7B4B4B6B3B6B4B5BEA5AA8F3F4A
A01C29AD121AB00B10B1090EAF070DA709129123336145653A537490A8B295A2A098A09D
969B9993969393918E978A8C9B7E81935C6285353A801B21870E168F0B1592061096040C
9B060C9E060E9F040D9E02099E04089B010698010899030D94020D8F04108907157B0F1F
7B3345A68B9DBCC3D0B7CCD6B4C9D4B6C8D68197A82F4A5F446274637F8A627A83768A91
5F7376677B7B5B6F6E586A6A576D69516A674D6666384F5A0C1F3701102D0B213852656A
25A52100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004DB4158163416C5C525A423C553531
6A5250624F4C5A403D714344550B0F6210128242437946495E353A7C6C6F6E71726E7776
787A7C848284817C7D8981808C8280887F7C887E7B8178748074718575738774738C7975
92817A92817A99857F98847E9A867D9A877A9885759A88719B886F97836AA08C739C8A70
A293799D91779F9178A4957EA1927BA2957FA39782A69F8CA39E8BA9A494A4A193A5A396
A9A398B3ACA2AEAA9FAFAEA19D9F909E9F90A09F92AFAFA29D9F93A4A69BA9AA9FAAABA1
B0B2AB818983B1BAB3B6B9B4BFC1BFB5BCBB7A8483B1BAB8B8BDB9B8BBB9B9BDBCB8BEBB
BAC0BCB7BEB9B7BCB9BDC0BFBEC1BFB7BBBAAFB6B3B0B6B3B2B7B2B1AFB0BD9CA08C2932
AC131DB70D13B4090FAF080DAB060BA909138D1423754C6D2B426487A3B098A4A59CA1A1
9A98989E8E90A17A7F934F5789262F89101A8F0C1491070F94040C98010D98010A9A0109
9B02079D02089D03089E030B9F020A9E02089A020997020A94010A92010B91020C8E0410
830917721D2E9E7D8BC4C7D1B9C9D3BBCBD87E909BA6BAC6788D97A7BEC681989EA3B8C0
6A80867E93955C6E6E5A6B6A586C6A536B6B37515A081D36010F30000C31011230314454
387B3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0083592F735A4A664B43532E29
6D4A495D4443644E4E6A46474E12135F20218A5A5D612D305923277D6365717171747877
77797A7B7C7E7D7B7C817C7A857E7B88807D847B788078748077727E736D8575708C7A76
8F7E7897867F97857F95837B97847A99867B9886799B8A789E8A7697816B9C89719C8C73
9F90789F9079A1927CA29680A59883A1957FA59984A59E8AA6A08DABA596AEAA9CA5A196
AEA99FB2ACA4A9A69BAFADA1A9A69CA5A398B1ADA3B0AEA4A9ABA0A1A69CB0B5ACC2C7C0
C7CDCBB5BEBCBBC3C1AEB4B2B1B6B4ABB4B37F8988B4BCBAB7BCBBB7BBBABABFBDB5BCBA
B6BFBDB5BFBDB3BCBBB3BAB8B6BCB9B6BABBB4B9B9AFB5B3AFB5B1B5B3B6C7A9AD8C2C34
AB131BB60912B50812AF0710AB050FA80913870E1A7B506D1C31557D99A9979FA1A99C9E
A48084934B5489202B900F1A93071098051095020C95030B9401099A030B9A030A9A0107
9A01079D020B9D020A9D00099D02089B010597010692010893020991000993010B94020C
8C020C8108136F1D2AA98A95C0C5CFB5C8D5859EAB92ACB88DA6B17D99A286A0A670888F
627A7E5F73755D706F5B6B6A576A6B4A626B0E243C011034010C32010B3202123610253D
464D4C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7210754B34735047522824
7644434C1B1B6848486851525F3E3E4D292A7E5B5F5F2B31551A1F826264757171767878
79797D79797D7878787F7D7B827C7C857D7B7F76747E75727D756F7B716A837570847571
8D7B77927F79937F7899857C96827A96837C99867C9885779F8B7B9E8A749A88719A8A73
9F8E769F8E779F907DA09482A29684A79887AB9F8DA69E8DA6A090A8A395ABA79AAAA69B
AFA99FABA69BA9A79BACA9A0AFADA6A5A59DB1AFA8ACACA2ABB0A6B5BDB4CAD4CFC9D2D1
C9D3D4CEDADACDD8D9B8C3C49CA7A7838E8D9AA4A1AEB6B3B6BBB9B5B9B8B6BBBBB2B9BB
B3BDBEB2BCBDB2BCBBB1BBB8B5BDBAB6BABCB1B5B6ADB3B1AEB4B2B5B4B6C7AFB3913B43
A6121BB3090FB20910B00911A909109E0D168119257B5975182C4F7E8B9FA28B929F5D65
91272F9A131C9B08129C050C9B03099A020B97010A930008930108970108980107980108
99010A9F030D9D02089F040A9D02089E03099C040998030B93020991010891010A92020B
8D000988020B7B07126D2330BAA5B1A5B4C229475C4266784869764A676F6A8387687C82
5E76795A6F705B6E6E5A6A6A586A6E2D4354021435000C35010C33010C32001036061B3B
414D5400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00419E08713B237F574E5F3231
77393C4D0C0D68383A65494D6551536455576F5C615F313754171D805A5E776E70727174
7475777676787777767A7A78827E7E7D78787871707B73717D74717D736F80736F82726D
8874718F7875947D779C857E94807896847C9D8A809A877B988778A08E7DA08F7C9C8C76
9F8E7AA4927FA39383A39686A59989A99C8CAA9E8EA69C8DA8A192A8A194ADA79BACA79B
A9A39AA9A59CA8A59DA7A69EAAA8A2A5A49EAFB0A8ADB2A9A9B3AAC9D4CEB6C0BDAFB7B6
AAB4B3B8C4C3CDD9DABDC8CC8E9A9B9EA6A5ADB4B0B0B7B3B4B8B7B6B7B9B3B6B7B1B9B8
B1BBBBB5BEBFB5BCBEB4BBBCB4BDBCB3B9B9B2B8B8AEB4B4B1B7B6B4B3B5C5B1B59D4F58
A41722B20B13AD0A0FA70E149611178E2C358A576A453F5F494C6C8B677C8D3441981521
A50C15A80610A3030B9E01089D02089B020B9701089601079501079903089B0309970107
9A02099D020A9E0207A004099D00079D010898010698020796020892000891020B8E010A
8D020989010982020B72081380475099949D6E84904A6A7792B0B87B949A92AAAE809498
839A9C5D7675576C6A59696953656D10233D011037000B36000C33010D32000E33021738
3A47570CCB0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00449E0571321880544C683935
611B1A580C0A773939511E22643F4368565B6B5C6263363C5313177F545975686B6F6E70
7272727474747675737575737A78787D78797E79767874707B73707A706E7E706E82706D
86726E8B746F947D779681799581789A887E99877E9E8C829B897C9D8A7CA493839E8D7C
A0907FA59585A59386A59689A5978AA5988BA89C8EA89C8DA9A08FAAA495A9A497A7A398
AEAAA0A9A59CA7A79EABABA3AFADA6AEABA4AEAEA4ADB0A6B5BDB6C4CEC9A7AEABAEB2AD
A8AEA9A9B4B0C8D7D6CDD9DBB4BFC0ABB3B1B2B6B4B5BAB9B6BAB8B3B5B4B4B8B7B4BBB9
AFB8B6B1BAB9B3BBBCB1B9BBB0B6B5B4B8B7B3B7B6B0B4B3B2B7B3B5B5B5C2B0B4A65F67
9F1822AA0E149E121590252D995C6A68566E3F3E5C6E5B79874A61871B2B9A0C17A60711
AC090EA9040AA8040BA4020B9D020A9B010999020998020B960109950108970109960107
9A01099E020AA1020B9F020C9D020C99010A95020993030890030A8E01088C01098A0109
89020A8600078301077C030C6B121A846267B1BAC095ACB789A2AB9AB0BA738C907E969A
657E805E76755A6E6D586A6B465665031334010E37010D37010D33001030061833041B36
2C3D4E1D9C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D407794023754B436E3C39
580F0C5B0E0D7D3538560D115416196D4F5168575B6A3D43521114794D4F76686B717073
6F70727272717473717474727C7A78807B797D7A75797871766F6C7A6F6E7E6E6C836F6D
856C6988706A907A7395817A97847D97847C98867B9A887C9F8C7EA39183A18F81A29182
A29283A39484A09283A19485A09485A29688A59989AA9E8FAA9F93A69E92A9A399A5A198
A8A49BAEAAA2A7A79DACACA2AFAFA7A9A9A0AEAEA5AEB0AAB5BBB6C5CECBAAAFADB0B3AF
AFB5B0AFB9B5CAD7D7C8D5D7B1BABCB0B8B6B3B9B7B1B7B5B6BABAB5B8B9B5B9BAB2B9B8
B0B9B8B2BCBBB2BBBBB0B9B9B4BABAB7BBBAB2B5B4AEB3B2ADB4B2B4B7B8BCB1B3AB757B
8C1F259220259D535F7D647F363D643A42697C607D802E439214249F0A16A4040EA9060D
A9060BA9060BA7050BA3040C9F03099B02099801069B020A980108960107960107950108
98030A98020B99050E94060E8C060F870A11810C127A0A0F77080E7D070E81060E83030A
85030886020883000982030C73070F74353F8A808A72869259727E637A8260787B688283
637D7E5C75735B706E596C6F314357031239000C38000D350317361C37493D59642C4654
1D333F1C9F1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774021774C456A3837
5C1D1B60212279353A55070B5D1D1F6A484B6B4E54662F34561013794F4F6F636568686A
6A6B6D6B6A6B6C6969706C6D7976777E7C7B7E7D787A787379736F79706D7C6E6B806D6A
816A6888706C8F797496817C947D7996827999857AA28F82A29181A79686A59485A49384
9F9183A39587A497879E9280A29685A69A8AA59C8CA79E90A59C90A69D93AAA199A8A098
B2ACA4ADAAA1ACA99FAEADA1B1B1A7ABABA2AFB0A9AFB1ABAFB4B0C8CFCDBCC2C1B4B9B5
B7BBB8C4CCCCCCD7DCBBC6CBA7AFB0B2B7B6AFB4B3B4BAB8B2B8B7B6BBBDB4B8BBB5BABB
B3BCBBAEB8B5B0BAB7B0B9B8B1BAB7B3BABAAFB6B4ACB4B3ABB5B4ACB4B4B3B2B2AB8F91
8550529E788545496E1F3568545886835473842136950D1DA20814A6070FA5040BA5040A
A7060BA9050CA40309A3040C9F030A9C020A9D040A9B010A9901089402079203098E060B
85090D83121A86222C8836448346557B4E606B4A5C694D5F6E4E6077485873313F701521
7C091284040D85020B83010B7C050D6A15206146517C8B965B727C778B93738B8C768E8F
6C84865C74735A706D586C70263A5002113B000E380314342945554460634B6261445B5F
1C323A25A92B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723A15794E45663937
61322E693E3D6B343751080B69262A76434A6B313A590E135D1B1B735252665F625F6162
6365666868696665666C6A6D7473767877777E7B787D78757A746F79716B7A6E687E6D68
816D6889746F907C7598847D99857E96827A9B877CA18F80A19081A59284A59283A49484
9E8E80A190829E90809E9381A19887A19989A69C8FA59C91A6A094A79E94AAA199AFA79E
B1ACA3AFACA3B3B0A6B0B0A5AFAFA5ADAFA4B3B5ACB3B7AFA6ABA6B0B7B4C3CDCCCAD3D3
CED4D6CBD2D5BCC6C9B0B8BAADB3B2B7BBB9B6BAB8B5BABAB0B8BAABB5B7ADB7B9AFB7B7
AEB8B4ACB7B3AFB9B7ADB6B5ADB6B5ADB6B5ADB8B4AAB5B1AAB6B2ABB5B4ABB2B1B0ADAD
B3ACAF797E9323376167628E884B698C192A9F0C18A40711A5040BA9050CA9050CA7030A
A8040BA6030BA3020AA1030CA0030D9B020A98030998020A92060E870B1182182085323D
7C475572546C5A4E6F363A631F2B5A1122540F24521126541427511C2A50333855685469
6D2D3F770E1C84051084010C7E030A6D0B15552E3A9AA4AF9EB5BE798E9599B1B5698184
6E86885D73725C7270596F721E364B01123C011537203E4F405F614A64605065604C6363
1F363C40484700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00713910775043663C3A
5E3431745752643D3B541214681A1F73242A640E135D0B0D6A34346A56575E5C5E5A5C5E
6061636767676A67676B686A7371747573757976758079768178767B706E7B6F6C7B6C67
7F6D6783706A907C7596827B98847D99857C9D897EA08D7FA18F80A08E7FA1917FA1927F
9C8C7A9E8E7E9B8D7C9F95839E97869E9788A29A8BA59C8EA79E91A89E93AEA59DACA69E
AFACA3AFAFA6AFAFA6AEAFA6ACADA4ABADA4AEB1AAAFB4ABA8ADA6A7ADA8A6AEABABB3B4
B3BABDAEB4B7ACB5B5AFB6B4B2B8B4B8BDBAB5B9B8B2B8BB8F999C89979A7E8B8C9AA6A5
ACB8B4AEB8B5AFB9B6ACB5B4AEB7B6B0B9B8AFB7B6A9B2B1A6B2AEA8B3AFAFB6B4AEB0B2
ADACB1A49FAD8D72898F3E57961425A30914A9080EA9060DA8050AAA070CA8050AA60308
A30207A5050AA2020AA1030A9C030A93020B8D070F84101A832D397A4559644C6B3B3B65
1B2B5E0E245C0A225C12286020356530436A6272908D9CB598A7BE9CAAC191A3B8758497
766B7D763A48740B1681030E7F0109720510602A395D5D6D889EAA627980677F81647D7D
5D77755F787559706D5872731F3A4C011538102A434562694A65614F68614F65614D6165
1E353F44505600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00773F13794E42704445
582A2C765857684B4B5D212360060B68070B5F0C0C682E2C6C50515D56585B5D5C5B5D5C
5E5E5E6865666B66676C6768716C6F706C6F7772737D74748077747F72718173717E6D6A
816E6888736C90797395817995837997857B96847A9B897D9F8E80A08F809D8E7C9D8F7C
A39583A09181998C7C9C907F9A9180A19A88A29A8BA59B8FA9A094AAA198ADA59EAAA6A0
ABABA3B0AFA9B3B0ABAFAFA7AAACA4A4A79FADB1AAAEB2ABA8ADA7A5ABA7A6ACA9AFB5B5
AAAFB1ACB2B1AFB4B3A7ACAAACB2B0AEB4B3B9BEBFAFB6B8869092AAB6B7A3AFAE84908F
AEB9B7AEB8B7AFB9B9ABB5B6ACB5B6ADB4B6ADB2B5A9AFB1A6B0ADA8B2B1ACB5B2B0B1B3
B7ABB1B48993903642A01522AC0A14AF070FAA040BAB060DAA070CAA050BA80308A50207
A4030AA4050EA2050E9D060C91090F81121B813442734C68433D671A285D0A235F0C2865
1833683C4D7764688882738B8362768557698753638A56658C5D6B8F6A7890828E9BA3AD
B6C0C8A08B947229347C091581020C78040F6C2635392E406A80895D7579667C7B68807D
5D76725F7572597270557073223D4C0118333550614F676A54686451686347605E3F575F
17314026394604C50700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783B0C78483A794C4D
5224267553536A4C4C642D2E5806075D0A0B652D2D6A4F505E5457545457555758595A5C
5B5A5D6362646867666C686670696C716B6F766E6F7B74707F7771847A7683757282716E
86726D907874917B7594807898847C97837C9B877D9A8A7D9A8C7C9B8E7D9C8F7C9D917E
9F94829D9181998E7C9C917F9E9382A2998AA69A8FA4988FA7A095A7A198ABA69FABA8A1
ACABA1AFACA5B1AFA7AFAFA5A8AA9FA7A9A0B0B2A9AFB1A9A6ABA6A4ABA8ABB2B0ADB2B0
ABAFADA7ABA8AFB3B1AEB4B1ADB6B2B1B6B6B6B7B9B9BCBD8B949594A0A08290908F9D9D
A9B7B5ABB7B5ACB7B7ADB7B8ADB7B9AEB6B8ADB6B6B2B8B8ABB2B1A7ADAFA9ADACB9AEB0
B9899096323DA1141DAF0D14B20A10B0080FAA050DA9040BAD080FAD060EA9050CA6030B
A5050F9F070F93080F85121A863947734E6938355F12245E0725640F2F682F4B77606E8D
7F758B855B6C7F36457D1B2983101E860B1B880C17880C19810B1778141F622931888289
B5C6CDBBBDC7855967720F1F80040F7A040F6A1D2D2F2236758E989BB5B76D8383889E9C
5F75725F75735A716F59707337515E0119304863724C63665467665265654F646B1E3547
031A39071C38068B1200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008846107847357C514E
4F201F774A49663C3B6C38394F13125B282764494B5E54565351564E505354565858595B
5C5B5E626164656566696769706B6D756C6E776F6E78726E7D7870867C77877876857370
86726F91797690787495807996837D95827B97857B9486789A8C7C9E8E7EA19181A49685
A194839B8E7D988B799E917FA39685A39687A4988BA69B90AAA298A9A39AADA9A0ADACA3
ABA9A0B0AFA5B3B4AAAEAFA6A8A8A0AEAFA7ABABA5AAAAA4ACADA9ACB0ACADB2AEABB1AD
AAAFABAAADAAAFB4B2A8B0ADAEB5B3B1B6B4B6B9B8B2B6B6B1B8B89CA6A69BA7A7A5B1B1
A9B5B5A9B5B5AAB5B5A9B3B4A7B3B3A8B2B3A8B3B3AAB4B5ACB3B5AAADB0B4AAAEB4838A
99313AA5131CAF0B12B30B10B1080DAD060EAA040EA9030DAA050CAB040CA50209A2050A
99080D8C11178A343E8057703F3D6812235F0622600B2C63294A72667A93807B89885D6A
7E2B3686111C8E081294061196030F97020D98030C97040F8D08137D1D2A7654658C9CB1
A3C5D7B9CBDA967F916714287C04127B04106E1F2E2E2033506C787E9C9F677F80677F7C
6178765D73715C7071596D6F48616A021C2F405D694965675066694B616922384D031638
01143E04193D024C1B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00627209774732825A56
55201F7B37375D1516682F2F6742435843465A50555250554D4C52515155525456535655
5C5C5D6261646362676766696F6A6C726C6D746E6D78736F7E787382787688797A847373
857070937A788F7773917D7892807B95848093857C94877A998B7C9C8B7DA49284A09282
9F9382A196839D927E9F9581A09984A59E8BABA190A89E91ACA598A7A397ACAAA0AAA7A1
ADAAA4B1B0A8B0B1AAA8AAA4A4A69FA1A29CA7A5A0A8A5A1A5A4A1A8AAA7ACAEABABAFA9
AAAFA9AAAFAAAFB4B3ABB3B1AAB4B0B1B8B7B3B7B8AFB3B4B1B8B8AAB3B3A5AFB0A6AFB1
ABB5B4A8B4B2A9B4B2A7B1B1AAB5B5AAB4B4A9B3B4A9B2B4A7ABAFB3A7ADBB8B93972E3C
A91521B30D15B2080FB20910AD060DAB040DAD0711A7010CAB060DAA060DA4070D940C11
86222A86506553496F1729620726651031683A5980617991737B8A88717D823F49861723
9409149B050F9C040B9A010A9A010A9B010B9A020A93050D7E131F7545601D26530B3464
5787A9B6CEE296859666192B7C061377030E6F2434291E373B596959787C627C7A667B79
6578776175745D7170576D6C566F72102939314D5E4D6976334C5D10254101123700103A
01113C04173E06152A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A1077A4B33825A56
5A1F1E610D0C600A0C602627624A4C564D515752565250544F4C51524E53555356555557
57585A5D5D616060646766686D6968756F6F76706F7A75717F7773817675857677867274
85726F8E77738D7470917B7693827B92837D94877F95887E9C8E819E8E809E8D7EA09182
A29585A39786A49786A19683A19A86A39E8AABA593ACA596ACA598A7A398A9A79CADA9A2
AFAAA4AFACA4B2B3AAA6A79FA1A49B999B929D9E959B9B95999B97A3A5A2B0B1ADA8ABA5
ABADA9ADAFADB3B6B6AFB6B6ADB6B5ABB4B4B2B7BAB5B8BAB5BABBAFB6B9ACB3B7ABB4B6
A9B5B4A6B3B1ADB6B8ACB2B6AFB6BAACB4B7ABB3B6A9ACB0B0A5ABB78992993541A5131F
B10C14B10910B50A11B0070FAC040CA80209AD080FAA050CA8070CA10B0F8E13188E3F4D
6A4E6D26336808296A0B316D345782647F9570808C808188886771792A3787101B970712
9D030B9D02099C01079B01079A010998020996020B830B148346582A2B53072D6043759F
9FC8E1B9CBDD927C8D6616267B061276030E6E2B3D1F1C3A5272885D7B8288A0A1657A79
6275745F73735F7374596E6F546C6E324C5A0E274118335204173E000F3C010E3A010D39
010F3A02163E04162C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DAE12825336805A56
602729570A07651F1D6A41435E4D50585056534E534F4C4F4B484B545053514E50555457
545558585A5E5B5D616462666C6869706C6C7471707B76737F787581767682737383706E
8974718C7672917B778E7A75907F7791837993847B96867B9A897F9E8C7FA18F81A39484
A29585A79A8AA69988A69A89A59D8AA7A08DABA393ADA499ABA398A8A399A8A59CADA9A2
AEA9A4B0ACA7AFAEA79A9B949A9D959193899294898D90868C8F8892958FA8AAA4A7A9A3
AAAEAAA7ACA9B2B8B4ADB5B2AFB7B5B1B6B8B3B5B9B5B7BAB3B7B9B4B9BCAFB4B9AAB3B5
ADB9B9A8B2B3A9B2B4AAB2B5A9B1B4AAB3B5ABB3B4B0ACAFB99299983B44A61822AF0C14
B00A0FB30A0FB4090FB0060EB1080EAF070CAD090CA8070C9A0B118D232D8D576D4B4671
112B67072C6B234B7D5D7D9B7B919E7F8E9284848986666E75243084091492060E980209
9B01079A03059902049C03089A020A9500098C070E862E3E4C395C07265A3568949DC9E4
B6D0E0B6BCCB8664726A101C7D060E6D040D6B36491519397B99B069838B6E8385647978
6277765F74725E72705A6F6D566C6C38505D01163501123E010F3F020E3E010E39010D37
010F3702163A0D203600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050AF0F82522E795851
623939511C196D433F644E4D5D51545A5358504E5349474B49484B4F4D4F575556535253
56575A56575B5B5B5F5F5E626666676D6C6B7773727972727D747280747383757386736F
89756F8B7671917E79917D7994817A93817995847B96857C9A897C9E8C7E9F8F809F9181
A09383A49787A49787A49887A69C8AA79E8DAFA696AEA499ADA49CAAA29AA8A39BABA6A1
A9A49FAFAAA5AEABA4999A928C8D858C8E838E91848D8F828B8E838E9086A0A199A5A6A1
A3A7A5A3AAA8AAB3B0AEB8B4A5AFADAFB6B6B0B5B7AFB3B5B3B7B8B3B8B9AEB5B9ADB8BA
ABB5B6A8B0B2ACB2B5AFB4B8B1B5B8AEB2B5B0AEB0BD9CA29D4751A01720AD0C13B10A11
B00910B00910B0070CB1060DB50A0FB2090EA80B0F961017903847755274242F660B2D6E
0F387441688E7594A881969E87959885898C90777E772C37810B168F030C920109970208
9701059A03089B02079A000895020A91030D7C0C17824F6B1421511947778DBDDAAFCFE1
BDCDDBA49CAA743948790B1781050E6A0C1858354E0916384B687B617A80647A78617A76
6079745E777359716D5C6F6D596D6C354857011337010D3F010D41010D40010D3B010E37
0110320A233C31475208C90800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B3107C4820795A51
6952505E49456857536158565F57595954564E494C4440444342454B4A4C555254535155
52515659595E5B5D615C5E616262636C69697873737B72737E7576807575827473877672
8A78728C79748F7C788F7C77907D77917E7795827B9A887F9B8A7D9D8D7E9F8F80A29585
A29585A69989A79A8AA69A89A39A88A59E8CACA595ACA499AFA69DA9A298A9A39CA9A59E
AAA7A1A9A6A3A8A7A29A9A938A8C81878A7D8A8D7F8B8C808B8C838D8D8595968FA5A8A3
A4ABA7A7B0AEA1ACA8AEB8B6A4ADAEADB2B5AEB2B5AFB3B6B4B8BBABB1B3A8AFB2AAB3B5
A6B0B2A5AEB0ABB1B4B0B3B8AFB2B5B3B0B5BDA4A9A659629E1B26AD0D17AF0910B30A11
B10710B20910AE060DAF050CB50C11AA0C0F971C22934D615D4E77152A68062C6C244D82
6184A37995A281999D8093958490938D8388753D467A0C188D030F94030D95040B97020A
95010899030997040992040C8C050D8108138231444B3A65092A616595BBB0D7E8B9D0DE
B6BCCB8E6D7F6C15257F061279050D7225343525430D2346557284718889657978627773
6178726076735B716E5A6F6A566C69435864021334030F3E000E3F010D3F010E3C001037
071F3933505F50676A15971600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B80491E775A4F
665B5A61595665605C5F5B5B5854555B55584F494C47424644424549484A55525657565B
5051554F5457565A5D5A5F606364656967687471727872747B71747E7374847777887976
8879748778728D7C768F7E77917F789380799481799A887E9C8B7F9D8D809B8D7F9D8F80
A29383A39484A29585A69A8AA59D8BAAA393ADA79AA9A498AEA89EAAA59CA8A39CA9A59E
A9A69FA7A6A0A7A8A29FA29A8A8D82898C7F888C7E898D7F8B8E828D8F848E9389989F96
A0A6A1A5AEACA3ACABABB6B6A8B1B3ABAFB4ADB1B6AFB4B8B2B7BBB1B6B9AAAEB1AAAFB2
A3ABADA4ADAFA7AEB1A9AEB2B0B1B6BAAAB0AB707996212CAA0F18B10910B20910B30811
B40911B0070EAD070BAD080EA80E1598232E935B753F3F710C2C6E0C35733B638C7191A5
7F979F84989C7E9392809291878E908C6D736E182286061192040E93010B91030A8E020A
8C050D85080F7E0F167B1B247D2C36733646745879122158255282A1CDE7B4D1DFB8C6D4
9F8F9F7630427E0C1980030E6D0811713D5412173A4261805F818B869DA0697D7E627673
6378726178725B74705A706E586E6E4E646F041634010E3B01103F00103E001239102A43
33525D4664665B6F6E17991800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008852227B6152
655D5A605C59625F5E605F615A575A5853554E474945404245414547464B504E54514F56
5254584F5455555A5A5C5E5E6162626968697370717C74757E75757E7473827574897978
8B79768B79748E7C75917E788F7C7696827C98867E99897E99897C9A8C7F998C7E9C8F7E
9C8F7EA295839F917FA09383A19989A59F90A9A396A4A195A9A69CAAA69FA5A39BA8A59D
A8A59CA9A9A0A8A9A29C9D968E90858A8C80878A7C888C7D898D7E888E808B9184929990
9AA39DA5AEACA7B1B2A3ADAEA4ADAFACB2B6ADB1B6B1B5B9B3B6BAB1B6BAA6ABAFA7ACB0
A1A9ACA7B0B2AAB1B4AAACB1B5ADB3BF919B922C38A8131DB00C12AF090FAE060DB2070F
B40911B0060EAD080FA10E16972C398A5A7C2B336E072A7118437F577D9F7E9BA7849B9E
8A9C9D8A9999899897859393939092743F487C0F1A8D040E8F020A8F030B87060C790A12
7D27337C445768496355496C4043692E39671A3066072C656993BAB6D2E6BAC7D5A092A4
814759790F1E8606107B060E7126343D2C4C061A4354749065838B62797B667A7B647676
6679766177725C75715A706F5A6F71566A730A1B3601113901143C071F3E274357435F68
4864664964615A6E6C1DA12000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00637C197D6252
655C5A5F5B586663626161615B5959524D4C4C464645404044424349474A525054525055
514F545353575556575C5C5C626161696768726D6E7972727C73727F7473837676837373
8471708E7A768F7B7594807995827B93817A96857E96887E97897E998B7D9B907E9B907C
978C789A8E7C9A8D7C9A8F7E9B9582A39D8BA59F90A4A092A5A397A2A298A7A59DAAA7A0
AAA9A0ABABA3ABAAA5ABAAA5989892888B7F888C7E878C7C898C7E8A8D808C8F858A9087
959D97A1AAA8A8B1B0AAB3B2AAB2B2ACB1B4AFB4B7B2B8BBB1B7BBABB2B8A7AFB3A7B0B2
A6AFB2A7AFB3ABAFB4B2ACB1C1A3AA98424DA31823B00C13B40C10B20A11AD060EB30A11
B20A0FAD0A109E0E169634437C587E212F6E09307628538B6E92AF87A1AA8C9FA18F9F9E
92A19E8C9B9A849493838F8E998D8F6D2831860B1791020D8D020985050D781A23744459
493F6519245B0C21610621640E316B2C4F814566956080A8ACC4E1B5BACC998395804354
76101E84061280060D711620623F590F1A44103056577687678184627A785E7472607573
6579776176745B726F5C716F596D6D566B7111263803173219364A3F5F6A4C696C4F6969
4E67654A64625C7170393F3C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0041A915806253
6B5E5E615B59625F5C6565635F5C5D554F514E4548484242474444474647515053575557
5150525353555555575C5B5C615F606A6766716C6B726C6B766D6D7D7274827477837575
82716F8F7C7A8F7C768F7C7593807A94827E92817B93867C96887C968878988C7B958978
938876938777938676988E7C96907C9A94809E97869E998AA09D919F9E93A4A49BA9A7A0
A7A59EABAAA4ABA9A5AAA6A3A5A29E92938B8E9085878A7D8B8F838C8F848E92888F958D
98A09A9CA6A2A5B1AEA3AEADA9B3B1ACB4B3AEB4B4ADB6B5A6B0B1A4AEB1A3AEB0A4AEAF
A4ADB0A9B1B5B0AEB2C2A9AFAA68729B202BAC0F17B20A10B70C10B30A11B10A11B0080D
AD0C1099101599424F6D557C172F6E0A34793361917598B088A1A88C9EA091A1A192A0A1
8E9E9D8D9D9C8396947E8D899186856D252B880A1494030E8D040D7C121C77475D1F2050
06215D1C3F7A2546840226625B82ADB4D2EDBDCFE6B8BED6A498AE8F61767A293B7F0E1C
85050F82060F73141D73455D1E214A0A26555C809D64828C99B1B4687C7D5E73745A7370
6177756377775F73715C716F546D6A546C6C314C513250574664684C6B6B4F6D694F6A66
4E68654966654761633D4A4A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048AF1B856858
6E606068616067635F6968645F5D5B524A4C4B4044493E424C4346474143504B4D575554
514F4F504E515553565857595C5A5A6661606F6968716C6B756D6D7B7170807474867979
8F7E7F927F7F917D7A907E7791817990817A93817B928079907F7491827595877A938678
958878928573948573968976928773958B779A92809993849794889C9990A1A097A8A59E
A9A7A1A6A5A1A8A7A4A9A6A5ACA8A5A29F9B9A999496989193968E999D969AA098959B95
9BA29E9CA7A2A2B1ADA3B2B2AAB7B6B0B9B9ABB0B4A7B0B2A4AFB0A3AEAFA0ACACA3AEAE
A0A9ABA7AAAEB3A0A8B8828C932C37AE1820B50E15B3090EB3090EAE080CAE080FAA0A0F
9A121795425363517B133072093679426C9A83A2B790A2AB91A1A48D9DA08F9FA28E9E9E
94A4A48B9A9B82929182908F97908E743339870C1594040E87040A872E3A3F274A071B52
0E31668EAFD2AEC7E54F68888FA2BFACAFC4A08DA29161777E2D42831627880A1588060F
7F060D75182276485D2A2853041C4F28496E9FBFCE7D959C788E91697C805E72725C7471
6177756379775E74715A726E556E6A576D6B5269684F68664D68664D6866506D694D6A67
4A686A33515C0E2A3A35474F0ACA0900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049B31C856B59
6F6462625B5A696561686660645F5E52494A483E404D42444E41444E42445246495A5154
534F50504D4E5553555958595D5B596762616F6769736D6C78716F7B707182757787787B
8F7D7F8F7B7C927D7B93817B93827C917F7B927F79907D758B7A6E9080728C7E6E8E8172
8D80708C7F6C91856F928771928771918671968A78968E7F918A7E9894899D9991A8A59F
A9A7A2A5A5A0A6A7A3A8A8A5ACABA9ACABA7A5A6A1A3A7A2969C969A9E999B9C979C9E9A
A5A9A7A5ADAAA5B0ADA1AEADA5B1B1AAB4B3A9B2B4A1AAACA1ABACA3AEAE95A29F9EAAA9
9FA7AAAFA9AFB788929336439F1923B00F15B20C13AF0A11AA060CA9080EA3090E940F15
96425363507C1330720A397F4A74A286A2B695A2AC9BA2A8999EA2959C9F95A0A1909D9E
8D9C9E8999998595948491928A8C8D8254597A10198F060F88050C83243155304E30355D
6A7A97A5A9BEADA6B98D7A8D8963778340548021378710248E08178D040E8A050D7B0A13
762632724D6B252858051D551638605A7A8D748B927284886A7E8065787A657876627672
6076725D75735C757257716D546F6A546D6A546A675168654F68634F6A6653716F49676C
2A4756051E3901173531455615971700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB71D80644A
6F635F665D5D6B67646A68656A6565574E51514548513E41492F324D3438534347564D52
5853574E4C4F5452555755565C5A586863626E6768776E6E7A706F7D71728576798B7B7D
8B79798E7A7A8F7C79907D79937F7C917B778F78748B746D8E796F8D7A6D857666867969
8D806E91846E91856E998D779588749488749188748D87748F8C7B918D819693899A9891
A3A39AA7A89FAAABA4A8A9A3AAABA6AEAEABABADABA2A7A49BA29D9AA09CA0A4A0A1A6A2
999F9CA4ADAAA0A9A7A3ACADA8B2B2AAB4B3A7B1B0A5B0B0A4AEAFA6B0B19FAAAA9EA9AA
9DA1A4B6A0A69649549A1E2AA81018B10C12AC080FAB0A12A80A11A20A0F9410168A3947
614E75102A6B0935784A75A18BA1B69A9EA7A69FA5AC9BA3A98E96AA8E96AB969C9F9799
9597988A94948896968693938A91939A828770222C830A1589040D840916882B3F834258
864D5E8542537F2E407A1A2E7E0D208808199107169506119208108309107A1A237D4357
54446915215904215C1739675D7C93788F9775888B7F8F926E8082667A79617572637673
6176736278765B737159726E546F69526B65536C66526A654E68654A67693D5B66153148
02193D00113A01153A294055169B1D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B81B7C5435
79665E645C5A6A66636D69686A6465594D51574246522D324312164B2024584045554C52
57555A4E4D525353555554555E5B5C68636570686B786D707A6B6E8373758B7B7C907D7D
8C7A788876748572708D7978927C798F77738D736E8B70698D736C8A73678A7668918170
91846E978974978974988974978975978B79938B78918C799A95858F8C7D8B897C929286
9D9F92A4A69AA7A8A1A6A7A1A9AAA5ABACA9AAABABA7AAA8A1A6A2A0A5A19EA4A1A0A6A4
A3A9A8A0A6A6A0A6A7A1A9ABA9B1B3A9B4B4A5B2B0A3B1AE9FADAAA7B4B1A6B1B0A6B0B0
AAA8A9A67C828C232DA4131CAF0F14B10B10AD090CAD0C11A60A0F980F129039446B5579
132E6B0D37774C71998D9AACA18E989F707C954F5B8B2E3D8B21318C20328C2C3B934A54
9B70769F90948D949686959594A0A1A9A7AB876067721E277F0A13890511880612830715
820915890C178A07128B05118B030F8B050E87080E810D137B1F277D4252634B68252959
081C58041E5E173A6C7EA2BF7D98A5A2B5BC798C9091A4A875888D697D7D697D7B627474
63777564787661777459726E566F6A536E69506B6850696A456068264156071E3E01133D
000F3D02103D01123B1E364F2A323400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0058B91880512C
7B645A645C5B6C68686D6769675E5F5B484B5633374F191B460C0D471A1D5A4047564952
5754595455584F51535354565D5C5C66616370676A766B6E7C6F718377768E807F917F7E
8F7C798F7C788874718F7A778F79768D75708B736B886E678B6F678970658B7769907F6F
8D7E6B8F806C9C8D779F8E77A0907B998F7C96907D94907E918E7F908D808F8D808C8D7F
96968A9F9E95A4A49DAAABA6AAAAA6ABAAA8A8A8A6A6A7A5AAACAAA7A9A8A4A9A7A5ABAA
A4ACAEA0A8ABA0A8ACA1ABAEA6B0B2ABB6B5A2AEACA9B6B39BAAA79EACA9A2ACACA5AAAC
BEACAF9951589E1A22AC0C14B20C11B10A0FB20C10AD090FA00E13912E387D628119336F
103779586D9A9A8BA09257648A2A378D1421920D18980C189C0D199A0E19960B1793101C
8317249959629D8E928A9598839496828D918483868B6F7374383C74191F7A0C157E0813
7F0611850814840912810912790D18771D267A36407C50635B4C6B282D5D0D1C550B1C57
203163556289535F7B9BA6B78A939CA4ADB37C8B8F6E81856A7F81667B7C667B7C627676
6479776377755D7371596F6D56706C546E6D4E6C6E375461102A4401153B01103C031141
000E3F010D3D00113B1328452C373E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059B71587542C
80665D6A63636B696A6F696A6E5C5F5D393C551F23571C1D4A1B1B4C2F30524144554A4F
58545758575A51505552515659565968636473696E786D707C72718479788C7F7D907D7D
907C7B8F7B788F7A798F7A798D76748D757189716B886D66866B62876F628B7667877463
8C7A668F7F689A89739B897391816B958B769D97849592829290839192848F908395968B
93948B9C9B96A6A5A0AAAAA6ACAEACACACABABAAAAABACACADB0B1A8ADAFA5ACACA1AAAA
A2AAACA2AAAC9EA8AAA2ACAEA5AFB1AAB4B3A8B4B1ADB9B69CA8A59DA8A89EA7A9B2AFB3
BB949A922E36AC141BB60E14B40A10B4090FB40B10A90B1198252F966A8922336D1C3D83
5D62989263848A293D9513219D0E189908119609108E0B14840F1884161F89101B940D19
910B187E1622986C748A90957B9395819698A5B3B48C9194837F837561696844526B384C
6E354A713449733C4F71465A694E6753496A2F345D152153111F54252F624D4872654B6E
744A64763F5377384B76394877455084616985777A767C7C7484836C7E7D657877647776
657A766478765D73725A6E71546C714A6772254157051C4000123E010D40010D40020E42
010E41000F3E00133910284032434600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00936139
856B6371696B6E696A7164666C4B4E571C2058171A5524234D2F2D4C3D3C504544554B4C
584F535D555A58535757545759575A686367736B6E756B6C7C7371857C7A897D7D8C7A7A
907A7A8F7A79927B7C90777A8C7274876E6C866E69846C65836B60897262846E5C867360
8E7C678E7E6696886D8D7D648B7A60978A7399907D9A968894948891938691948995978E
99999192928B959691999D9BA4A9A7ACAEACA8A9A8ABACADA6AAACA5ACAEA7AFB1AEB4B7
ABB0B3A1A6A99DA5A7A1AAACA3ADAEA3AEACA3AFABA9B5B1A2AEAAA2AEABA5ADAEB8AEB2
B0747E9B1C28B20F17B50A10B80F15B20A0FAF0C139A141F995772393B711F397B5A5189
853E6392182FA10D1CA20A14990A108B1119872933874A5A76566D6B556D8B5C6F811F2D
8D0A15840C158244525B61716787937A959ABED1D49EADB178888F6C7B863B4B601F2C52
1A295A1B275A1A2A591222560A1D540A1E5710225934396866507575405C742238780F23
7E081B8207168206168006157A0814720F196D2229815A5C8D85847D86876A7A7C657777
677A78617574596E70566C753F586B162E4F011341010F43010C41020E41010D3F010E3F
02103F00133C0A233E334F5C43525500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0096663B
88716771696B6E6566765B5E612E315C1B1C551C1E5733344E3B3B4B40404A3F41554A4E
5A4F5660555D5D535A5E585C605A5F6C636873696C766B6D7F75768A80818A7E808B7C7C
8F7D7B8F7C788E7A768E78778A71727F67667E6964806A6282695D886E5D8C735F8D7863
8877608C7D6595886E94856998896DA0937A97907B99968792928593958A8D90868B8D86
8F8F898B8B868B8C86878B869BA09DA6ACABA9ADADACADAFA9ADAEABB3B2ADB6B7ABB3B5
A5ACAFA5ACAFA2AAACA3AEAFA3AFAEA7B2B0A8B2B0B0BAB8ACB6B4A9B3B2A7ACADC1ABB1
9A4854A51723B40C14B80D13B40B10B00C11A01019953E554A3B692B3D75796C9A853453
9B1528A20917A108149410197F212E76445D564D7427376B0F2A6310295B5148687D3143
890C17890B1482394E303254587B9574909A83969D7C8C9476899167808AA3BDCC5D7799
032558305887668CAF6D8CAF6A7EA4595C7F705673703049761529800A1B8705138D040F
8F020D8E010A8B010A8B010B87020A82010A7C060F6E12197D4A4E7D72746D7778687879
62757564797C5A727D2F4860091F49011448020F48010B45010C42010D3F010E3C01103D
001339122F4936576149646846565618971400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A17646
827164726A6C6D5B5C653E3D6029285F28285833354B373A493D3F4C42434B4044574A51
5C4F5660545B5E545B635961655A626F626974676C796D7085797B8C80818B7E7E8B7B7C
907F7E8E7C798E7B778C767388706F806A687C665E7C66597D6658876F618A73638A7864
8675618B7D699488739A8D78998B749C8F7A99917E9996859291858E8F8391938894968A
8F90868A8A8289887F8989818C8D879EA29DA9ACA8A9ACABACB0B0959D9CA6AEB1ADB5B8
AAB2B5A7AFB2A3ADAFA3ADADA4AEADADB7B8AAB3B5AAB2B4A3ACAE9EA7A8AFAFB3BD9AA2
8E2A37AB111EB40912B80D14B30B11AC101792263679587B3743738777A28835509D1322
AA0D189E0C178D1B2987485F574C78182E6A092A6E1038752F54826173938C7085791E2C
8F0B168A0B1681395128285235567772919E768F93A6B9BE94A9B52D4A5CAACADAACC8DC
3E5F7E678BA8B4CEE0A8AFC08C768A79384E7814278508178C04108D020F8D010D8E020B
90010B8E010A8B00088A020987010885020A83020A7D060F690E1782565C767574687779
61767C5067771D375502174501124801104901114A031046010D41020E3F00103D02193E
1A3B5140626A4868674A646447595916961400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A67744
8671627E6D6E67464663322E653430643F3D523B3B473B3C44393B4A3D414F404654474D
5A4E525E54595C535A60565E62595E6C6267766C707B70747F7478867A7E8C7D808F7C7E
8E7B7C8E7B7C8D7A79887472826C6B7D65637D645E7F665A7D6558846E62867164877566
8878668E7E6E9084719185719386739D917FA19787948E80908F83999B8E98988D97968C
96938A8E8B838A89808B8B818788818E90899B9D97A4A6A1A9ADABA9B0AFACB5B5ADB8B7
ACB6B7ADB5B7ABB3B5ACB5B7A8B1B3A9B1B4ACB4B7A9B2B4A5AFB1A6B0B2AEADB1AE828B
8E1F2BAC101AB50B14B40A13B20D159B121C9E5B71474066877499893650A01526A90C15
9C101791304171486E2E38720E347B0C3979335D8C6989A68091A39A88947E3944860E1C
920912830D188048641B2252476A8D8FAEBD546F78B1C9D0C0D5DF718A9983A0AF9DB8C7
768E9F6877888B8291835564751E2E8009188A030F92020E91010A8F000A91010B90000A
8E01098A00088A01098901088501078301087F00057F010974040C6D242A82707366767C
465F73122C5002174901114A010E4A01104C01114C010F47010E4002103F01153B1D3E52
3F676A496B684663614D666550626217991700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA23
8E6E5D8464655A29286E3A3575514D604948503D3E493A3C493A3E493A414D3F4653464D
574C535C535B5D545C62575F635A6067606377707272696C83797D83777B897C808D7D80
8B7A7D8C787A8D78788974728167667F625F7E615C7F635C80685D846D61836F61867365
88756893827396867591826D9C8D7B9C8F7F9E9384938C7F91908497978D9594889A988C
9C9B909091889091898C8D858A8B848689828F938DA2A5A0ACB0ABADB4B2AAB3B1ADB7B6
A9B5B4ADB8B9ADB6B8ABB3B6A7AFB1A9AFB2A9AFB4A8B1B4A2ACAF96A0A7A6A4ABA4717B
911926AD0F18B00911B40E15AB1018A0333D865A6E876684913C56A21727AF101A9E111D
8D35486A537B1D367409377D22528A6389A9809BAB8A98A09B8B918A4853871320950713
9107117D192A65446D0B20595A7EA6B5D3E47E97A17D959E90A7B0748B99536E857A96AB
9EADBD7D6D7C793C4B7A121F8506128A020B93030C93020A91020891010A91010A90010A
8F020B8C010A88010886000983010982010683010782010A7B040C630D156B505C42546E
09244F00174D00134D01114D010E48010F4901124B00124701114202143F0F2A443F6569
4A6E6B4B6A654863604B6762556A671CA11D00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B91F
9166507E53535C2727764A476D55535A4B494C3C3B44353547383C4B3D4450434A52464C
584D545B515960565E635A61675D626A6063786F717F757982797C837A7C857A7B8A7C7E
87787B8E7C7E8C78788A73727F6462785D597C615C7F645E846960866F64867062897466
8B786A907D6F9B8A7A9685729C8C7B9B8E7D9B908197908295938697988B96978B9C9A91
9C9B929799908F92898D918892968E8B8E88898F89969C98A5ACA9A7B0ADACB5B3ACB5B6
AAB4B6ABB5B7ACB5B8ADB5B8A9B0B3AAAFB3A9B1B4A6AFB1A3ACAF939AA0B1A9B0945761
941620AF0E15B40C12B30F15A21517BD656AB67D89953F4FA11826AD0E16A2141D9C4258
6854811531750B3B7F3664967396AF8BA0A88F979CA28E968A475387142397081696040E
880E1985435E28275E06276540688D7895A57A9199748B9799AEB9B2C6D7223D5C314A6B
7B738A6F31427B0E1C88040D8A02088F020A93020B93010B90000991010B8E010A8A010A
87020984030984040C84030D84020B84000986010983010A7A020C61081A472A480A1746
01154E01145201135201125001124A0013441129521D375F01123F01153A2D4E5D4A6C6A
51706A526D6A4C65624F6864576B6922A72500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057B81C
9763467B4B455D2F2D765856695A5B574A49493B384737354838384B3C3F4F4044504147
5749515A4F565C5359605A5E655E616A60637C717481757883777C84797C83777987797A
87797A8877788B76768970707F6463755A56765D587B625C816960856F62887063877061
8C7668907D709987789D8E7C9E91809D90809B90829A938795938793938A95958E9B9A94
9B9B9593958D8B91878F968B8F948B8D918A858B858F9792A2ABA7A5AEACA9B2B4A8B0B4
ADB5BBACB6B8AAB4B5ACB6B7ACB6B7A9B2B5AAB3B6A7B3B4A3B0B1A5AFB2BAB0B69D5B66
9D1824B20F17B20C11AD1014A22325E68E92AB4F57A11B26AD1116A31419A2475765507C
1130740B3C7E4F7BA5819FB391A0A99B979EA4848C883C4A88122095061397050F8B0A15
88384C4E3E690A2462143A6D61869E89A2AABACDD65A76876D8B9DBFD6E67F8FA5675F76
692F42750C1984030D8A020A8D010790010990010992010A9001098F030C89030E7F0610
740B1270131A711B2372162175081283041085010B7E01097206134A09261A0F3D05134D
001252011355001254001650061F492847614A667D1A325100153E051A3B3F616D4B6C6A
53706B516C6947626249646552696B3E494700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0D
995D386E3C3171504B776765645A5B5448474C3C394A38374736364E3E3F5245464E4243
574B4D5A4E535F545960565B665C626D61687D6F7780717982757E84777D85767A87797A
8B7B7B8B787A89747686706E8168647A5E597C615A7B625A806A5E846D60886F63907869
8772638B786A8F7E6F968878998D7CA094849D93869692849394879C9C9398989095968E
9798919599928B948A98A3999BA39A8B908A8C928C8E97939CA6A3A3ABACA9B1B3A9B2B5
AAB4B6ACB6B8A9B4B4AAB4B4AAB4B6A4AFB1A6B1B3A6B2B3A6B4B5A5B0B1B6ADB2A3616C
9D1822B10B12B50E13AD1216B9353AD15F679F1A24AE1119A711199D39496E547C142F73
0D3E7F4E7AA38DA8B989929B9B8D959B6975862837921020970712950711890E1887384D
594470102764133A6F8BAECD6A889777939EBFD7E0A7C0CE657F8F9AABBA958A9A703645
750D1A82020C8700088900088E020A9001098D00088C020989040B7F08107717237C3B4A
724F63594A64453F5D4D3F59734052710C1B7E030E77020F5A072224083707104F001357
001354011553011A4F18385D395C6E4D6E783F5C6E04193B0720470A254040646D4E6D6C
53706C4664663A5761142F401F3B4944545900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
92572D744A3C745F5D736B6B635C5D534745503E3A49353240282A4E3A3B524445504647
5247495B4F5261545A60535A675A616E5F667E707781747B85787F83787D84777A897A7B
8B7A7B8B787A8B78798874737C6561755B55775C537A61557F685B886E638970638D7666
8B78698D7C6D8F7E6F96877A96897D988E8299918496938493938598988D97988E9A9C92
9396908C938D9CA7A3C5D2D0C9D3D2B6BCBB8D93908C948F99A29EAAB3B1A7B0B0AAB4B5
A9B6B7A7B6B6A8B5B6ABB5B6ACB6B7A9B3B5AAB5B7A9B4B5A9B4B5A4B0B1B5B2B4A56D72
9D1E24B71217B80E15B00D13C9303AB41F28B3121BB0151D9D2A39875E821D33730E3B82
47719F8CA0B39C969D9D7981893E498B1A26960D199B071693091481121E87465B514370
0E2568082F704D769DB6D5E796B0BB6F89957E99A1829DA5788F998B8C987F505E781220
8A07128B000A8801088800068D01099102088B04097B060C79222A7B49595C4867292D59
102054061B5208205210224B51415B691B2D78061564051B31072F0E0F4C021359011359
0216530721512A4B6752727C5573784D6A741A365001183B27436308233B4465704F6D6E
4F6C6B39556208203C00143803193441545E08C80800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8E572676544474635F726868675D5E574846533A374A2728441D224F313857414855474D
564A4F594D545D51596556606958627060687A6D747E727882777D82777C827478897A7D
8C7A7E8A757A8B76788872727E6664755A56775B527A5E5480655B896E65907A6D8A796A
8D7D6D9384749285759B8E7E978B7D968D8196918395938396968796978B95978D91968F
7B837D7D87839CA9A89DACAEC6D1D6C6CED3888F908A918D99A39EA5B0ADA4AEADA6B0AF
A6B2B1A4B0B0A8B3B4ABB5B7ABB5B7A7B1B3AAB5B7A5B2B3A3B1B39AA8A9B3B5B6B28488
952127B51218BA0D15BB0E18BA101ABB1019B81118A91F269852693836681D3875546696
968FA7A177859547548F202E96111E9B0D15980A13890C178126367D54733336690D2A6F
0732723D66907394A88098A27B939B768C9678949BB6CFD57C89958A748271202D870815
8E030C91020C8F020A8C01088F020A8F0209850C10873D4754405B1D2858091F5906225B
11316037577A728CA5717D8E7C65716313206E0819450424170B4104115901135D011756
102C58405D755371785975775D797D385366021A3D122B4C3C58720218343A586C4B6975
3853660B224300113C020F3C0112332F435312961700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
915C277E5D49634C48715F5F6A5D5E594546522B2C440C1049121750292D563C42524048
574751594D565F535D65586168596073636A7B6D757D6F7882747C83757B827276867678
8D7A7C8B73768A7174897070806763765957735753795E577D625B866D65927B70928072
8F817197877999897A998B7B968A7B9A91829790839390829A988A999A8F999D95858D87
737E7A9FA9A8CAD7D8A6B4B9B7C3CBBCC6CC848A8F7E84828C9591A2ABAAA3ABADA5ADAF
ABB4B4A7B1B0A7B3B4A7B1B3A7B2B4A8B4B6A4B2B3A3B1B29EACAE95A2A6AFB5B7C1A2A5
8D2C31AD141CBB1019B70A16B50912BA0F18B31118B4373FB172857457797F597C934F69
922E41981C2B9F131FA00C199D0C18920F19821E2B824960584C73172C6606296D16407B
4C74997795A68298A082939BB6C7D093A8B7446173BCD1E2A8A7B67842507F0F1B8E050E
91020B92010B91010A90010A90020B8F030A800911783449281F470A2056193C694C6F8D
6D8D9E738B957A838C88747C6D2F396D091565091F2C052F0B105003135F01145A143162
4B6B815773785672715A76774D6A760C254500183C2F4C63445E710115380B2148183356
051B42011141010D3E010C3B010F361C2F46189E2200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D662E855E495B39367259596D5A5B583D3F4512134C090B5012144E2326543D3E524348
55484F574B525D515A62555E6759607263697B6C747F6E7782717983727A807074857678
887678857273897273886F6F8166647B5F5C735652795C587E645E876F688470658E7C6F
9383749787789787789B8C7C9486789E9286958E81959283959486949688989D927A827A
78837F8A9695C2CFD1A8B6BCB2BFC5A9B3B98A9194848A88949A97A4A9AAA5AAADA7ACAF
AFB4B7A6AEB0AAB4B6ABB5B7A7B2B4A4B1B2A2B0B0A6B4B4A7B3B4A7B1B3ABB4B6BBACAE
974B50A11720B50F1AB90F1AB60D15B70F16AE0C13AF242FAA3F5089263E8C1C319B1828
A51420A80F1AA50A159F0D188B101D7E2A3A8A637F454474102A69052E711640756085A4
7694A295ACB192A6AC80919DC5D4E0A5BACB29455B93A4B79586946E2230890C1690020B
91010A93010B92020B8F030C8D010A8A020A86050F791B2C63405B35415E6784987B98A3
93ADB2859297887C8379454E6E0E1B7406155606221B0638050F5201125D0117532F4E6E
5B78805E76775D767459757C2A465D00183D0A26434563724A6572061939001340001242
000E40020E42000C3D000D3B010F3710233C1DA52A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A16A2F885C465C34317356566F595B593536480B0B570F0F4E0D0E4A2020553E3F514246
55484D584A5161535D6556606A5A6275626A78656D7D69717F6C747F6F777E6E72827475
847575847374877273876E6D816664785C577659547A5E598066618670698A766D907D71
928273918172908272928575978A7B988E819A938696928598978A999A8D9A9C927D837C
727C798994939EA9AC8592998D9A9F828C8F888E91898E8EA0A6A5A3A9AAA2A8ACA7ACB0
ABB0B3A8B1B3ABB6B7A9B4B5A8B3B5A7B2B3A4AFB0A8B3B4A8B2B4A9B3B5A7B2B4B1AFB1
AD7D818F2129A9111CB10D1AB30C14B50D13B00A11A80D17A0111EA31221A7111DAA1018
A80F15A2101896131E8A25358D4F66705A7E2E3A6E0E2D6C0B32712A52825F84A17F9CAB
829BA1BACDD2B0C4CB6D7F8CA5B6C2B5C8D5758B9C7D87988C6D7C6F131F89080F8F030A
8C01098B040B83060C800B137B081080050D87040D7C081575303F9F939FA0B0B88DA2A7
ABB6BC8B7E867D4A557116227B071373041549092A11084003105501165A0421524A6A7F
5C77795D75755A74774866760C2647011A4024455B4C6B73506C740D213D011341011043
020F43000C41010E3E010E39011036091D38323F4500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A902587553D60332E765653715655522221520A0A590E0E4E1212532D2C584241554647
594A4E5A4A4F6151596756606E5963775C6577555E704E5677606878686F7E6F73827374
8374748372728772738B72718469677D5F5A7C5E577F625D836B6686706A8B776F907D72
8F7F719082728C806F928674948A7A928B7D9A95889693869594879694899E9C958A8B86
6B706C737A7A6972757981848F98988289878B908D969997A7ACACA8B0AFA6AEAEA5ABAD
A7AEB1A8B1B2A8B4B4A8B4B4A9B4B5A9B2B5AAB2B6A6ADB1A6AFB29AA5A7A5B3B4A9B2B3
B6A8AAAE6D74921521B11521B40B14B80D14B40E13AE0E15AC111AA50E17A0111895141C
8E242C8F3E4F8754706858812D3A6F0D2F6C0A33702A53845D82A17794A5AAC1C9A1B6BC
7A9197A0B3BCB1C4CE889AA680939C8C9FA6A6B8C08083907C4C5C7B0F1D8A040B8A0309
83070C7B1B2480415171475D704359702937760C15830611730B148C545DC7B8C09C939E
8E6F7D74303F760F1C82051280030D6D081B360932090D4A011357001B54294C6C5C7B83
6078765F75794D6876153151011C44102F4D446771516F6F557073243B4E02163D011142
000D41020F41010F3D011036031939031B3339474E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
55B71B814C2F6A3D367B5B5872524F531F1B510D09541615582C2D513736524040534546
584A4E5D4D5464535B6B586071525B6B3A4465242F7036407D5B6274626878696E77676B
79686A8571738973748C7373856A687F625E7E605C7E615E81686489716A8C766C8D7A6F
9180729181728A7A6A928574928A79918A7C99948897948894918696948C99989195958F
92958F878B87949A969396948A8C8880827D858883979C99A2A7A6AAB0AFA8AEADA1A8A8
A9B1B2AAB3B4AAB4B4A8B4B4A8B3B4A8B0B4A7AEB3A8AFB2A5AEB197A3A5A6B4B6A4B2B3
ACAFB1BA9298942733AE1622B80F17B51014A71B1F9E303A933A479247577F435888607D
6E5D824346771D336D0C326E123E75345C8A5E83A389A8B99BB4BB889BA2A0B1B5A4B6BC
859B9F85999F8EA1A6A5B8C178919E9DB8C4B5CFD96B707F723C4E820F1F8B030C86050B
7E1C257348602326510A22531229505049606E3542730A147F0611750F1DA45B6A7E3949
7318297E081885040F80040D7108126A263C261541051351001752193D62537886627D80
60787D516A7D173252011A4508284B3E6173516F7357716F57706F4E6671061D3C00113F
021044020F4200123C06203C314F611931423A4B500BCB0A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59BA1C814D2D784D477452526949454B221B4D1D1758322C553E3B4E3D3D4E3F4153464A
584B525F4F5866525B6D51597448506A212C670C166D1F277F5459705B61716168726166
7664677D696D81696E856B6F896E6D8468657E615E7A605C82696488706A8B736A8B766A
8F7D6F907E718977699385768F8577928A7E98918696928896938B96958D96978F9D9F98
979C939AA097979B959395908C8E8882847E8D908C969D9BA0A9A9A2A9ABA5ACADA1AAAA
A7B0B1A9B2B2A9B2B2A7B1B1A6B0B3A9B2B6A8B3B5A5B0B1A6B2B3A5B0B2A5B2B4A8B6B8
ADB1B4B58B9292202BAE131CB40C12AA1217B352628363874F55823E507D253F6E17366E
10346D1940773157884E759B7195AE84A1AE869EA59CB1B5A4B7BB92A1A690A2A58B9DA1
93A8AB849B9EA3B6BBC3D7E33A576D55788EADCAD69198A6703F4E7F101C8D060F85050F
8831413D25470E23563E5F907E9DC19DAAC096788575232D7E050E84030F8109167E0614
83061284050F78070F6B141C6835463F2F500A13460215501333604A70865F8089627C88
446078122D54011A4808244A3E5E7255747A59737458726F57706E596F73374E6004193B
00133D01163F102B4936576447666A2C454E374B5016991600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2DDD0D7E472187554D62333474504C52342B53372F55403952433F4B40404D404353454B
5A4C54624E5867444F703C4767232B6F17206E0911650F157D4B506D555B726065726265
7B696C7A666A7C656A775D61876D6F8469687F63617C615E80656289706B8A736D88746A
8F7D738F7E718D7D6E91837595897E968C82978F869892899A978F99978F98999092948B
959A92989D97979C978C918B898C8684877F979D96949D99919B9B8C9697959E9F818B8D
97A1A2A1AAACA7AFB0A8B2B2A9B3B4A7B1B3A6B2B3A2B1B19CA9AA9AA6A7A5B0B2798689
95949AB8828B991C25B10F17B60C13A91420A75A78272F69134284406EA05177A06184AB
7697B681A0B78BA6B48BA4AD89A0A58CA0A38B9FA08EA1A48DA0A393A5A88A9D9FA4B9BC
C2D9DF6A848E839DA6AFC7D3728C9F607C91768D98959DA5825E687716208C081188030F
781120783E5A513E608F88A795849F87677B8449577C1C2881060E87020B88020A85040B
7B070D6C1019662C3B5038501F214606154801164F00164F1F3F6A4B6D8A4E6C852D496B
072353011B4F07254F395A6F5B777C5D76775B737356706D587270546B6B5A72773E5764
1C37482A4A5744646B4B696B4D6969334C522E444821A62300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008345177E403164292677504C5C443E55423B56453F5243404F404050414357494B
5E4F53694C5457232C6A21286C171E731A1E690F1461171C6F4349664D55705D626E5E60
7665667B67697C666A7A626582696C806769806666836766886B6A896D6B876F6A88746C
8A786F8A7A6E8C7F708F837496897D968B81978E859A948B99958D98968E999990999B92
979B95949A95969B98878C888589828C91898A938B7F8982808A867B86827B85847E888A
919A9E97A1A39FA9ABA6B1B2A6B1B3A6B1B3A2AEAFA2B1B1A3B3B3A3B1B2A6B1B398A2A5
AAA1A8A766709F1A24B60F18BA0E15AB101CAC536E393C7130609782ABC88DA6B492A6B0
96A9B093A7AC90A3A791A1A693A4A78FA1A48CA0A18DA2A39BAFAEBFD1D595A9AF94ABB0
B1C9D177929C7C99A07F999E93ACB77792A966829AC1D4E29B8F976E2A34810D1689050F
820410780B1B74192D711C33731A3075112577091880071182030A850208830409790E13
7E374467476026274A0918470218480C28522C4B720A244F011B480A245406205001194D
011C500E2D5641637957767C5E7778667B7C5E73735A727158716F57706E5A7374536D6F
4A686753706F59757254706C4F696930494F26404437443900FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4C16702E1764261D7F58535F4D475648425748434F3F3D513E405440425C4749
5F4648653F435F272C66212361191B6825286D34376B424565494F624B556551596B585B
7563647663647762647960647C63667F6568866C6E8369698A6E6E846A67846C668B756D
8B796F8B7B708F8375948777978A7B968D8097908598938C99958D999790969590989B95
919791949D979198948389837C817B828780777F7876817A77827A7A847F7B8280828A8D
869193929EA096A2A39DAAABA5B1B3A7B2B3A4B0B1A4B3B3A4B3B4A2B1B3A2AEB1A8AEB3
A999A0954B54A61721BA0E16BC0E14B20E189A283E705480274B7B7FA6BE96AEB49BAEB1
9AABAD97A8A997A7AB96A3A990A1A69AADB0A6BABB8FA4A694A8AAB4C7CC86999F889CA2
879CA298B0B68CA9B27B9BA5B8D7E636577A092F5C7EA1BCA2B1BA8A6F766F232C7D0E19
82060F8404108003108004127E04117E04127E06107C060E7B040B7F02097B060C863844
49324F0F194803184B1029562948665677886A8793455D70162E4C041C45061E48132C52
2E4B68506F8058787C5F7C7C617B7A657D7F6277795F74765A7273597072587072526C6B
49666256716E536D69526F6B4C6968223D442441463C4D4400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0099591E642307652A1F7E5753624E4B56484353443F513D3D543A3E5E3D435E393E
5E3639693C406533365B28296D404069424767494E654E555C4A525F4C56634F58665258
705C5F7461637661647C62677D62667E636685696C866A6A8A6E6E896F6C87706A917C75
907E758F81779084779487789A8D7D9991839792879A968E96948C9A98929E9E99969A94
898E898F97917C867E727D746D776F6E766F727C7676817C77817D747F7B757F7D7E8889
828E9086959592A1A195A4A4A5B1B2A4AFB1A7B2B3A5B0B195A2A4A2B0B2A4B0B3A6ADB1
B29FA7904048A9161EB90C12B90A10B50B129E101F9750722C35636E92B293AEB79EAFB3
9EADAF98A9AA97A6A996A4A997A6AC9EAFB3A4B7BB899BA292A5A98FA2A597A9AB92A2A9
90A4AAC2D9E36182983159739CBED557779510345B3D657E9BB7BDB4B8BC91777F763B46
6B1D286A0E1C6C0B17680914680D176816206A26307C3A44812D3776050E77070F7E3C4C
25183B0E194725335877869E778591636D73676D70676E715E6D724F636F50687557717C
5471765673735A78755B79765C7A75627C7B6077786074765E77775B73755A7174546E6D
4C6A6753706C4E6965526E6A4F6C6D122D352E4B50485A5000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007483155E21046C3730774E4F624A475A4B455845415A3D3E54282C5B252C612C33
65343B6C4045613A3F5E3D41654A4F654D56665059655159615159594951624F56634E54
6853586E585D755F63785F627D64657E6567866A6B8A6C6E8668698A6F6C856F6A8F7C75
8B7A7291817B91847B93867995897C9991839A948795928798958D9898919999938B8D86
777C747C817A737B736D796F727D74737E7678817A777E7B79817E78837F727F7A768381
7D88888592928D9C9C93A2A298A5A6A6B0B4A5AEB0A6AFB1A2ACAEA3B1B2A5B3B4ACB4B7
B4A2A8924149A9161FB80D15B80A10B70A0FB00F189A283E76567E3B537C95B1C599AAB0
9EADAE9AAAAD99A9ACADBCC19CAAAF93A2A694A4A790A1A790A4A790A3A7C2D5DBAEC2CE
88A1ADB4CEDC7B98AE3A5A767190A3819CAA8BACC0527A8DA8CAD2C2D4D9C0C6CFA69EAB
6D5E6E564359583F595A415D5743604D41613938583D3550723F517109147A060D8A3543
74455B62405967415364384761313C5D2B335E2E3362363A6A4B4E6C6062656B6B5D7170
58737058736F57746F5C77745B7773637D7B647D7C62797A607B79607A7C546D72476465
4665624868634E6C6753716E476169041E2D39575E4A5E560DCE0A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0049A80C5B2206703D36683A3B684844604B455D444161363758191D5F181E682930
643138542D346A4D555B464E5B4953624D5965505B64525A5F4E575A4952614D545F4A50
624C52664F546F565B745A5D775E5F8169688A71708D7072876B6C856E6B826F698B7A72
8D7B74927F7B93847B928579998E7F9890829D978A9C988D9A978C918F8882837B797D74
767E74737971737C73727D74727C7478817A767D767C837D78817D78827E77837D7A8683
7782827D89898998988D9D9D9AAAABA4B0B4A2ACB0A4AEB19AA4A79BA6AAA2AFB1A9B1B4
C3AFB68C3B45A4141DB80F16B90B13B90C11B70D14A211209E506D3F3B657893B297ACB9
9BACAE9DACAF98A7AA99A7AD9CAAAE97A6A890A2A2BACCD0ACC1C6899FA6B5CCD399B1BD
6E8797879EAB97ADB99BB4C66C8AA09BBACE82A7BE235168ADD3DFBDD5DDC1D4DEC0D1DE
B2C5D46D8399334A69172F550B234D091F4D0F224D413A5B64283C78081581030B7F0B16
740F1E6C09196D09166D07136C071269050E65050B63040C5F0A1258171E6743456C6666
5D6C6A576F6D5B74726078765F79755D7774607A79627C7C5D7A785B7779344E56224146
40605F44625E49686449676C1B354700163018334347605D1DA01900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DAD0F6025076B342B67322E6E4642694A455F3332591A1A5D10135F13185F2327
60363A6043495B474F5A49525F4D58624E59645058604E555A49525747515C4953604B53
5F4A50614B506951556F5559785E608166678A6E6E8D70708A6E6F87717084726C8B7A72
8C7B73917F7895837A9A8B7F988E7E99928495918599978B969387817D747E7D757D8079
727871727870727A74737D78717C77737F7A79847E76807A77817D77827F75807E768282
7682837B88887C8B8B85969696A5A79AA8AB9CA7ABA2ACAF9FABAE9DAAAEAAB5B9ACB3B7
BCAAB191444EA2141EB30C13B80D12BD1015BA0C13AE0B15961B2E88587B3E4D7290ABC2
99AEB59BAAAF98A7AA99A9ADA6B7B99BADB093A7A9BBD0D49AB1B689A0A58AA2A795AAB1
9EB6C089A1AEB0C8D588A5C0183D693F6A91618FAB5E899DB8D9E3C0D7E0BFD4DFBAD0DC
BBD1DCBAD1DEB2CADE9DB0CB757E9A625C78664D666E3449710D1C82051086010987030C
83020F7E010D7B010A7600087301087201076F01057002086E020868030C5B090E623135
6E6365616F705B71705E75765D767357726E5873715D77765B78765A7678344E56153039
426364466362415E651D364B01153301103101132D384F5523A82400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0054B4156B300C592012652F286F433F6C3F3D5C1C1B6111116614165C171B6C3E44
60454B5E495058474E57484F5D4B54614C535F49505A454D59444F5946515A49535D4953
604C51634F52634D4F6C545774595D84686C8A6E708F737488706E836F6D8875728D7B73
8B7A6E91807694847B988A82998D8397908498948899978A828074807B71827D787F7E78
757973797E796E7674566462566664516260586A686A7A79758281758081747F80758182
7782837A85867B898978888889989A99A8AA9AA9AB9CA9AB9DAAAC9BA9AD9BA8AFA0A9AF
B6A9B0954F589E1720AE0910B50A0FB6080CB80910B40910A60F1A96334B644D725E7699
92ADBE98A8B19BAAB09AAAB0B2C5CB9CB3BA8EA5A98DA6A992A9AD95A9AE8CA4A7B3C9D0
A6C4D46388A383A5BF7193B2052D5B14426C6790A7B3D3DFBDD4DFC1D7DFC1D5E0C0D3E0
B8C9D6A6ACBE8E869B785C726B384B661D2D6A0D1B79081782030F87010B87010789020C
85020C80010A7C010A7601087401087301097001056E00066F00076C000867020859090E
63383C6B6A6B5B6F6E57707058737055726E54716D55726F577471577472455D640B2330
3F6068324F580E243B011034000D32010F3101112D1A303A327C3500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002DDC0C71380A4D190463342C7F53505B222063171660110E651F1F5B282A64444A
59464E58474F58464E57474F5C4B525F4B526048516046525E45505B45505B46515E4A54
5D4A4F624F52634E506C555870585C80666A8A71748C757487726F87736F8B79758E7C74
8C7A7092837990827992857D90877D958E839A948A8D887E7F7C727F7E747D7C757B7C75
798179626E6959686660736F687A766677765267674D6264677979748281748280758283
7681837985877784857685857F8F9092A3A596A6A98F9DA197A5AA95A4AA96A6AB98A4A9
ADA6AB9B5F67991822B10D15B90C13B90A10B90B12B80C12AF0A119C10209A506C48466A
7A98B1B2CAD59FAFB593A4AB8B9FA6889FA590A7A98CA2A5B8CED2BED4DDA2BEC89CB8C4
7EA1B60C3656567B987292A77095AE5B89A38BB3C1BED8E1BFD2DDC1D4E1BECBDBACADC0
9482977C4F666923386D12257209177D051381020D83020D83010B89040D85020987010A
83000881010A7C010A7501087401097300097100067001077001076E00076B0206650307
530F136E5C5C5B6C6B54706E56747156737154726D54726D55736F53706C4C666D041D31
1C364F041934000E31010A31020B31010C2F010F2C0B1D2A414D4300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007E410F521E07683A317A49465917146C1E1A5B14106A37346345465B484E
55464D54454C56454D58464F58464F5D4A545B44505D434F5F46515F49535B46515E4A53
5F4B51614C52664F536F56596B5256785F638770728F76758D74728A73708C7974907F79
93817A96857D92847A91847A91887E958D84968D86857D7674736C6A6F676E756D797F79
6F797550625F677A776E7F7A707E786D7D795C7070475E625369696B7E7A6E7D7A727F7D
707E7E717F807280817989887B8B8A83949581929489999D8C9BA098A9AC92A3A796A5A9
A6A8ACAC7F868F1A24B0121CB90C16B90912B70B10B6090DB1080DAD0D1793172A8E5A77
515B7999B5C49DB2B890A2A78BA0A3B1C5C7BBCFD29CB1B6ACC3CA9AB6C45E7F907F9EAA
7C99A67795A982A3BA7E9DAFA9CFE42C5B768EB8CBBCD5E1BDCEDAACAFC1968399855168
7826397A11217B05137D040F7C000981010A83020980010981000983010985020A850108
8401088402097E01087801077401087401087301067201067101067001076C0105690105
59060A5C393D556064526E6E547370526F6C52706B52706B4F706C4E6C6F3D5867041838
000E34010D34010C3300093101092F010B2E010E2C0314243C484300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0081420D5A240B663329793D3B651D1A6E2922652F2C6B4949634E5356464F
54444D55454E55424C59454F5C485258454F563F4B58404A59424C5E47545B46525C4950
604D525F4B51634D546F565B73595C795F63846A6E8C73748E7372896E6E8F78778F7C78
907F7893817A96867E8F83788E857B91897F877F777A776F656762656E6A5B6561777E7C
5661625063646677786D7A7A6F7C796A79765F7372475D604F6566677B796F7D7B768080
747E807481827483837383827E8E8D829392778A8A91A2A392A2A499A9AC8C9DA094A3A7
9BA5A7BB9EA48B2732A71521B60C18B70811B60B10B6090DB60A0FB40A13A80F1B972A3F
835F795E6E8391ACB697ACB18B9FA3B9CCD1BBD0D7A7BDC58BA2AA8DA8B088A5B0849EA8
87A1ACB3CEE35B7EA4406A9477A5C534617EB2D1E7B0BCCE988DA0865C707A2A3E841526
8A0A168A050E87020A8102087E01097E00087F02087D01067F010784020A840109840107
83010582010780030979030A7303097003096F03076E01066E01056E00066A0105670004
5C050B512532343A45506C6E53716D54706B536F6A516F6D4C6C7329465B071E3F000E39
010A36010A34010A3100082F000A2D000E2E00122A0012223846460ECE0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008649105F2A0E571E156B27236A241F6C36306E4D4B6D585C56474C53454A
55454E50404953414B57454E5A4A515D4B5259444B574149533C4758404D57414C5C4950
5F4C51614D5365505770595F765E61795F63886E728D75748A72708D7473907A788E7C77
90817C93847E94857E92867F8C837A8A8177807B6F78786F5F6660626D69646E6A7A817E
4B56574F62646173756775786573765D6F70586C6E44585B556A686D7F7B75837F778381
6F7C7D6E7C7E738283738383748485778888788B8A8194948A9B9D8C9C9F8B9C9F94A4A6
9AA6A9B9ACB29A515B981A26AE0F1BB40912B80C12B70A0FB50B0EB3090FB00A13A61220
9A3C506A536DA8BED4B7D2DF96AAB299AAB28FA4AB899DA78AA0A896ADB4BDD9E59BBAD1
7D9EB984A4C8062B64042F694973989AB4C9A6A4B88C667E7D344C7B12268909198F0411
8E020C8C02098800088200087F01097E00097D02097D000681000887010A870209830309
7E040976070E6F0B14660F195E161F5D19235D161E600B1468050B6A0107690104660005
5C040C542737161C2E4D696F506D6A516D694F6B6A3F5C6916314C02163E010F3F010B3B
010936020934010A2F020C2F00102B0B263726454E0E252E2C3D3B21A11A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0064790B642E0E54190B6120176F38317855536C585964555755474A504447
53434953404856414B54424B56464E56454C5A474E59454D553F4857404B57404A5A464D
5E4B51604C526650556B5659776365786164866E718A71728B73728E76748D7672917F79
8A7C778F837F908580908580908680837C727E7C6E7B7E706C736A68706A737973777C78
495655485D5E596C6F5B6D7256696E53686D485E6241575A6073716F7E7872817C6F7E7C
69787B707F836A797D7887887A88887B8A8A84959581939480919393A1A595A4A795A4A6
9FADAFADAEB2AF818A83222DA31621B30B15B80B12B80B11B50A0FB30A10B20911AE0B16
9D142492445C685E7A778DA28FA4AE92A5AA9AADB3BFD3DCB1CAD694AFBCA3C5D91C4369
244D756F91B048668B4F689178829D90798B8644597D182E880B1E8B021191030F93030E
8F020B8D010A8A020C8400088100098001087F010880010883010889020A830209770C12
72222B733F4F684861544260453C5A3F3956463952674151590D16670308690204680205
58070E512D4209142C4B66714F6D6B4D6A68425F66061F3A021541000C4000093D010839
010736010835010C3001142C18353F305454375A5728424224373125A71F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0041A2056228064F1304602C2173534C705F5D685C5B615455574A4B524144
593D44512C364A283159424A57454D55444D5B48515A454D553F4858414B543F485B484F
5E4B50624D526954576C58597461627763647F676A876F708A73738D7775907B77917F7B
8D7F7B8B7E7B8E817E8F837E897E777E766C7E7B6D7D7E7176796E72766E7679717B8079
5E6A68435657475C60455D61425C60415C5F3E585A516768697A7973807D727F7E697879
6B7B7E7283876F7F838391938390927987898897988898988191928E9C9F99AAAC94A6A7
A0B0B1A7AEB2B7A0A99C5A66901C27AD0D17B50A10B50A11B30A11B40A11B40A12AD070F
A70A15911122944F64928695BDC8CFA3B4B79CB0B5B8D2DE6C8EA17B9CAF80A0B252728A
68859F839BABABB7C9A499AE89586C8025378B10208F041391020E8D000A8E010991020B
8E010B90020D8A010B88010A8402098101097D0209810209830106820208720811804454
513E5E1E25540A1E53051E54031E4E061F49102241544357510E1A630208670102640206
55162036273E081B374966734F6D6B4E696749626A021635021040010D42020B3E010839
010936000B31071E3623454E365A573D5F573E5D56354F4C1A2E2735792B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004AAA0C5D1F0051190962392E735D557269636B615E6358575D4D4E584045
5329304409115522295C3D4353404857454F5A464F564048513B4458424C55414959464C
604C536752586B575D705C5F7460637C656881696C8970738972718C75758E7879907D7C
9384818E807B8F847E9086808379727D746A80786E7B796D76776C7B7D747C7E767D817A
757D794F5E5E3E515440595A415E5D496362536A686275726D7B7A6E7A7773837F6D7D7B
6676776B7C7D6F7F82818F918290908392928B9A998695948796968B9C9C889B9C8C9FA0
9BADAEA2AEB1ADA8AFC09DA793414DA1161FB20C14B30A11B30A12B60B13B30A10AF0910
AE0B13A30814941826A45E69D7C4CBC9D2D58DA0A598B0BB5C7B8B7E9CAB819AA4BCD0D9
C3D1DBA6A4B28B6D7E833B4E8415278F061596041096010D94010C90010A8E010991040E
8E000B90010C8D030C89040D7E060C75080F891E257D07107E030B75050F76344646385F
06195402205E1536682F4F7544607C55677D605E6F5227375A071166010765030458090F
5432420F14330C26434767744F6C6C526B6A5068700C203B010F3C020E40010C3E000938
000F341730473559603A605D3A5E563E5F563F5E55354F4C172D28444B3800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052B2135A1C00511A0B6A40345E443C71635E6E63606658585F494B532C31
571A2251060D4E0F135F383F533E4755444D58454E58424B533C4457414958444A59454A
624D536A565B6D5B607563687761657B636783696D876D71876D6F8B7273897173907D7C
91837E90847C8E857D8D857D877F757E776D7F7A707C796F7A7B70797B717D80787E827B
7D837E737C79616E6D60716D5E726D61746F6878736C79746F7B766E7C778F9E98B6C3C1
B3C0C18F9D9E7B888A7D898B8695959EAFAE97A8A69BABA997A8A793A4A593A5A89BAEB0
8EA1A39CACAFA3ACAFADA6ACB0868D8D242BA90F19B10A10B80E15B40A12B10810AF0810
AA050BAB0712A50B18961B29AA6571BBA8B0949DA28EA1A7B7CFD8B4D0DF98B2C2A6B2C1
AC9FAF925F737F2336890D1E94071597030F98020D9A030D98040E92010A8C01098D010C
8B01098B040C810A107312177D303496495184242E77040F77060F6D1D2B593F610C1B53
04235F2D507D4D708864808C6B798073646D5C2A355A081367030B6802075B0709613039
27223B03153B23425D496973506C6C536B6C546C7313274002113A010F3C00113C0A1C42
0118333A5A6542666340625B4161593D5D543E5B55334D4C162B2A49554800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0056B6145E22015F29195B2A1F5B36307B6563736161684F4F653B3E561A1F
550C125304074E0C10633B4155404954434E5A485257434B543E445941485E474E584349
604C516F5C5E7461637865687B646A7C636782686C84686D856A6D8A6F71886D6F897372
8C7B778F847C8F887F8C877E807B717C796D7B7A6F79796F76776D787B707F827782847D
82837E7D807D7A7F7D777F7C707A75758078727C75757D79707C78899895C8D7D6C9D6D7
CAD5DAC6D2D87C8B8F7887897D8E8E8A9C9C9CACAE83949587999986969B81929884969C
8EA1A5899C9F9BA9ABA5ADAFAFA5A9A3646A9A1D27AE0F16B60D13B20911B0070FB10A11
AF090FAE070FAC0710A40B17931B28A05E68C0B1B69CA8AEADC3D246657F60728E927E95
89445A88182F940C1D95031095010C99030F95010A95010A95020D93020D8A010888040D
7F081072131E7A3C49724D5B906872752E3972081478050E6A111B69405B15194A031C55
4A6A9488A4BD718694727781755D6465252F6307116B020A6C010666010572262A5D3947
1315320D23424363734C6C6F506B6A516A69546C731E3348011434061E3C2544573E5C6D
09203238576044676246665F43625B405E57415E5A284245142F2E4556480FCE0900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00642A03602B1A521D125F332D7F6362765858632F30641E2057090E
590E124F0A0D521E1F5C3C3F53404852404B5A46505A454E57434B58424859434A5B464E
6551576F5C5F7362637966687E696D785F6282666A83686B84686B886D6F82676A856E6F
8976748E837D90877F9188818177707D766D7B797078786F72736B76786D797A6F838279
82817B80827D787D7A7C8381767D7B7C868077827B76817C6E7E79A0B3B1C5D8D9C8D8DE
C9D7DFC9D7E085959D788B8E8295957E9090899A9B8396968B9C9E808F94849499798D91
889C9F8FA0A49AA8AC9AA6AAA4ABAEBBA4A9893B439E181FAA0A11B10A11B0090FAF070D
B0080EB0090EB10910AE0911A50D168F1824A25F68B09EA77D879561687E81637D812D44
8F11249806179A031098020C97020D99030E95020C94020C92020C8D030C81071071131F
753B50624A6A332E5251406075384E740D1B7A060F6A0A15734258231F4D0418540F315E
92B2CAACBDCE88819272495964162470081475050C7200067201066F0308670A125E1B29
4F2F424E4F5D536A6E4F6B6A526E6A506968536B6E334B551E3B473C5D6548696C4D6A6E
152A382E4D594568684A696444635C415E5A405D5B122D30163332435A4B21A31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006E340A622D17511C105E3029835C5B723D40611619610F105A0E11
5114174F2223533335574244523F46513D465B464E58434C58444D543F485C474F5D4951
6351576F5F6472626579676A7D6A6D755F637C6466806669896F71866C6E806668826C6A
8977748678728E827C9286818275718276717C777177766F74756D74756C7A7B717C7D74
81837C7E847D78817C78827F767F7D78837E75817B75837C6F7F7997ABA8C4D8DAC5D8DE
C4D6DFB8CAD375888F7185888295957486858FA1A1839696889B9D8191978193977A8E91
7A8E919BADB199AAAEA0AEB49FABAF9EA1A5AD8E938529319C0F18AE0C13B10B0FB0080D
B30B11AE070DAE070FB10A12AD0911A30C178F1926A86571B8939D96606E842235920C1C
9C05109E040D9E040D9C030D96000A97020C94020C92040D890810750D19722D415E4467
2D316714245F4D4978683153750D228106136F071173384D352C570516531431677E9DBD
7683937E6A7D692F456B0F217604117C020B7601067501077402077202086D010766030C
56081253282D656061546764536D6A516A685068684D68684665634867634967644D696B
1D36431D3B4944676948676245655C43615C3E5B5A082225223F3F40574A23A71C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0083481359240A4E1B0E6C3D378250516824276915157125255C2525
5831334F33354D373C513E4654414B56414B58424D56424B543F495A454F59444E5E4953
604F566B5B617361677B696E7A686D7A676B7763647C656784696D866A6D836867856E69
86726D8A7B748F837D9187827C726E7D74707A757274746F75776F787A72787B72737A71
757E7677817978827C76807C757E7A757D7A737E79727F797B8A867B8B8AA5B7BCB4C7D0
A9BCC47B8F9674888C708485839596788A8B889A9B819496809498778B9081959A84989D
788D918A9EA299ABAF98AAAE8E9DA29EAAAF9A9A9C9B6F738820289E0B13AB0A10B00A11
B30C14B00811AD0710AD070FAD0910A20910921219AF4A55A547538A17269209179C0511
9E040B9C010A9D040D9A020D9B040F95020E8C050F7D0D177E32426C4766302D5D0C1E5F
0D2267433F7A6B3459760D2582061477071279324646325C0A1756031A59485C8789869E
6F4659691A2D72081B79030F7D010B7E020A7A010877000A7300077301086F0106690005
66040856060A5D36375F62605067644E67644D66634D67644A68634A6964466560496767
27424D152F3C44666747676046665C43635C41605C133130314F4D43594D36782A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063750B592405562315713B367231307321236715136A2C2A633B3C
56373A48292E543A41513E4751414C56444F56414D58434E56414B5A454E5B46505B4650
5E49526B575E705F6579676D7C686F79656B7B65687E63678B686D8D63677C5250896962
88716B8776708F847D9088807A746C7D76707A767073746C74766C767A70737A726E786F
707B7378827C78817C77817C747C77777E7977817D75848079888675848478898B788A8E
7A8C907083866C7E817385897B8C8E7B8B8E7B8D8F7F9296748B8D758D8E6E84887B9094
73878C7A8E928EA2A49DB0B08FA2A395A5A9879495AEA6A8925C628A1A25A00D16A9040E
B50B14B30913AD070FAD080FA80B129C1418C54E54AB343E97101D9C08149C030EA0050E
9C020B9C020C99030B9A040F9606108409167821316A3B5840376511205D031F63152C6D
565386672E527A0D248805147B0813752A3D5239620E1454081A5C363E72705B7B65283D
6F0F1E7905137D020D7E000A7F01097E01097F020A7B010A7400077301076F01066B0105
6901046303055011126558575367644E67654E6865506A664C67624B6662476561466363
35505614303845676645645D47665E44625C45615C3B58513B595141574B4A4C3A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0041A208551E02622C1D61211A72222074201E6C25236F3C3B623A3A
512728481B205B383E543E4554434C54434D56424D54404A57424B5E4952604A535F4952
6049516753597260667B676E7F69707E676C796065805961854C537B3237752F2F8F615C
8C7570897C77887F788D867D7C766D7B776D7B786F78786F797A7173796E6C766D6E7670
767D797A827E767F7B76807C737E79747E7977827B81908B7C89897987877B8B8A829391
7E8E8E71838474878976888B7685897A888B88979A788B8E7E92937F9494768C8D7B8E90
7A8E90768A8D7E949596AAAA899E9E90A3A48DA0A18E9B9BA3989A995B638D1721AD131C
B40C15B50B13AD090FA90C13A0191EC74F53A72B369B0D1AA70A16A5030E9F010A9F040C
9A000A99020B97060D8F0A15811B2A81455F4C3B6417245F06256719387842568C746991
7235508010248F06168206127625385B40680D14540B165B3B366B683F6265152B770818
8106117E020B80030C7E010A7F000A7E010B7E01097C020B7501077202086E00066B0105
69010466020552070C482F364A5B5E4C68674C67644C69654F6B664D676345625D456260
4662633E5D5D44656247655F46625D48635E49635B4660563B554C42584E48504000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0049A90E591F0663271B560D0674241E6D25217F4945704141582223
5115164E14174E2328573F4454434C55424D53404B53414857464A5F4B51614A52624952
60464F6852586F5B617D676E7F686D7C676A7D656881575E712C32882D317E29298C5552
8A716D857875897F798E847F7E766F79756C7A7A7174746D78797272786F6D786D6A726C
767C787A807C77807B76807B75817C76837B7A857D848F8B7883847986877E8E8D839392
7A898A7788886D81827487886C7C7F848F948793988494978E9FA08E9F9F7C8E8F748689
798C8F788C8F6F868892A8AA96ABACBDD0D296AAAC899C9E97A1A2B3A4A688444B951823
AB0E16B40D14A80A0EA1191FCD575EA92D37A00F1CA70813AD0A12AB060FA4030C9F020B
9C040D95050E860E1883344A6E5076282F670724630B316F5A7FB299ADD67561827B314A
840D1F9006138807147E263967486E141B5A131D5F4B3A6F6025466F0D217C031382010C
86020B81000982030B81030B7D010C7800087A01097D010B7A02087501087101056E0006
69000265010355050C3F212E2F3D4A4866684866634867624968634B686346656144635E
49666249676147655F47645E47635D48625C476158435D5435504A39524A43524300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB0116227065516094F080269251E804C457A4F4C683434571214
570F12541A1D502A2C553E4255434C57434E55414C54414958464A5E4B4F5D474F624650
60414C674A536F525B785B627E65697864677A656885626882434A761B207C24238F5652
8A6D6A847370847875877C79847B7579746C74726A73736B73746E70766E6A746B69716A
6E746F757B76767D78757E7A7E888475817B75807B8B97947A88877686867586867C8C8C
7E8F8E7083826C81806A7E7F72848684929789979C8B9C9F97A6A99AABAC7385897D8F93
7285887F9395798E918CA1A49DB2B4ACBFC49DB0B499ABAE97A7A7B7BFC1A69197994D58
9B1A23AD1319A6181AD3575FAF323DA3121EA80712AC070FB00A11AC050FA5020D9D030C
920911831A2779415C443D6C0F2968052D6D325E9191B5D9AFBEDB8F74927A29448D1023
9205108A09147C22356B4970171F5B1E28675D4977631D3B760A1B83041082000A840108
8601078601098401088002087D040D75040B73010876030B75040A75040B730108710107
6C010366020453060D3F21341A293B45656A4767644A69644968644A666548656246655F
47665F4A686146645D47655E45645C46635B466058435E563B5A5526453E435748209F16
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057B615692B034F10024F10076B332C83544E7C4A485418175E1919
5D2020572C2E593E41523F4556434D503D47513D4856424B5D484E614B5260464F623A47
5E2B386E3A4668343E602F37805C617B60667C63698162678752577728297426218A5750
866B66857570817671847B76827A7477716976726B7A776E75756E70746E6C726D6F756F
707570737975747976757A79838A8978817E76817E788683758583758685768686788585
7C8A8A788A89647877667B7C728689879A9D8D9FA2859A9C94A7AA93A4A97F929775898D
6C8183B2C6CA92A6AB7D929695A9AD8D9FA69AACB1A1B2B6A7B9BCCDDEE2C5CDD2BFA8AF
954A5297242AC74B50B8353DA7131FAB0913AE0810B20A11B20A11AF0912A80A11930A10
91323C6A4260272F66062A6D1A48816F99C0B0D1EAA8B1C68A697F812B428F0F20960711
88070E7D2334725076191F5D1F27676B507C691C3677061583020B85020A810007850108
8401068501088403087F030975040A68060D5F0A12611A2367262E6A1C2568070F6F0208
6D01046303065211192F1D330D213644666E4667664968634A69654C68654C666349655F
47665E47666047676144635E46646044615D46635C415F573F5E5714332E354C4122A51C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006D2D07501003541A10713A33783936753130642220612B27
5E3735573D3E544043503D4453404A53404A523F49533E495C46505D464E624049622836
560B176416216B1F295C1A218B585F6E424A6C444B815E657B51556E383685504B87625D
856B6882726D81756F847B75867D77776F6A79726D7C787174756D6F736D6E736E727772
6E756E727973757B77737875777D7A7C8582737F7C73817E738280788886728080839091
7987887484846D7F7E677B7B728688889B9D809396889CA08DA0A592A4A97F9298778B91
758A8E6E82896F838A7F949999ACB0A3B4BBC9DBE0CBDCE2ABBDC4B2C5CCB5C8CCA4ACB0
B99FA7AD636DB03742AF1824B40F1AAE050EB30B11AF080DAE090EA8080F9B0E12AB3D41
A062732B2B57082F6D3A699D9BC3E1BED5E9AAA9BE885E787E2338910D1D9A0813910B13
7E2230704D711C24601A27696A5080701D3980081785010C84010983000983010984010A
83010A80020A79050A6C0A0F641B24693C4A584056453B5A36314F6A4D60580D196E050D
6C010659040754293513122B0C263D40646C43646245645F4867614B67644D66634A655F
496860486860476962456560476562486662405E584262563D5C512E4C452C483B25AA21
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0077350C511203581F156729226C1F1C7226236B312D643E3B
5B4341534141503D41523F464F3C44533F48523E47563E4A5B404D63414D63323E601823
6B161F630C14651419530F1378454864353A5B2E34816165806466876868846765846866
8A716F88767182756E857B75897F797C726E7A716B7E7871797A72727770737A736E7470
6B726E747C76757B76757A7671787476807B707C7874807D79848473807F6E7C7C728281
7688867183817789886B7C7D697B7D7D90918598997A8C908FA1A690A2A78093987C9096
7F949971878C8EA2A7B0C2C799ACB1889BA2BFD4DBC1D5DCA9BBC2A3B5BCB4C6CACDD9DF
C2AEBAA35263A41827AF0A16B30811B60B13B40A10B0090BA90C0CA01718C64F51A1323B
81344A48426B4975A2A7D2EDBBD3E3A8A1B58C5972821E39910B1C9E0A15910A14842738
6E4B701B25631025686056886A1F3F83091B8A030E88010A83000982000981010881030C
7C060F6D0A1267202A6A4456493F5C1E264D091C4B07194D1F26536244605709196E030E
6903075F181D40283707122C1B394C3D616442645F4766604B68634C67664A68654A6863
49686248696148696247676146655E44645B4363594161543C5C5123443C315146317A2C
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0084421155190661271C55110A6B1E186A28237148425C4540
53433F5044424E3F414E3C43503E46533F485840495E3B475F323E69354260202A5A0912
6C161E5E0E145E1B1F643334704D4E6C4F50634949725C5D7C6969806D6D806C6B836D6B
8B7572897671837770877E77887E7A857C777B726B78736977776E71756D6E746E6F7572
767C78767D78767D77767B76747A76747D79717B77737E7B727D7B6E7C7A6E7E7C6A7C7A
687A78697C7B7184847080826C7B7F80909382939595A5AA7C8E9385989C84979B7A8E91
72898B789193B0C5CBC3D8DFB5C9D08A9EA67B90989DB1B8BDCFD59FB0B7AFBEC6CAC7D3
AC77889D2639B3101FB80A15B70912B40911B30C12AA0C0F9F1819CF595BA52C3196101C
82192D674E7254779CB4D1EA9F96AB844A6282183092081B980713910C1682293C6A4D74
18276706236B4247816933567C0C218B02108C020C89010A8602098101097A030A6C060D
691F286F465B493E61141F4F061C52041E53152C5A3E436B5C405F5B162B6906136F010A
650105641A214E2C38191C2D37515943636146655F46635E4B6964486663476763496762
4766604968624C6C6649686348676046655C4564584161543C5C5128484216342C435241
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008E4F145C24095A201159180D70312876463D6E50485B4742
5443405043425245464D3E434E3D45553C485F37425D212D59121D67242D68232A61181D
6B292F6029305D323765494B6B585B6756586655577767677A69697F6D6D7E6B6C826E6F
8773718A787284777089807A8B827E89827B7F7A6F74706576746C767871767C75777D77
787C7A767A77767B76777C77777D7A798381767F7D707A776A77746979766B7B7A70807E
728381768888788A8B6E7E817584887B8A8E88989C7C8E9483949B7B8D92809395ABBEC0
B0C4C87F969C718A927E969F89A0A695A8AF9CB0B5C1D2D7CBDDE1C7D5DCA9ADB7BD9AAA
983549AC1426BC0E1ABC0B15B80A13B30A13A70D13A82327C852589F222AA3111BA00A14
881120764A68333D618C80A07E3C57851429950919970714860B1687384C574068112566
052E732E4B846E567C72132E8A05168D010D8C020B8A020984010879030C6A0E186D3648
4D3D5B172150051B55041E561D35624F5B7D6B62795A2E415E0F1E6C051172010C6F0108
69000660040A510B11502F34565A5948625C45635C44615C4867614766614A6964496862
47665E4B68634B69644A68634967624A666149655E4463583D5C523957511F3C32435343
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF003E9F02652D08541D095B231569392D7651486A4C455C433F
564342554344503F41503E43543B445429355314205E0F185A0D1264232869303559252A
6C4449603F4760444B6950586551585D4A526A595F79696C7C686B7D686B816D70856D71
8A74748A76748A7A76887D7A8A807D857F798480767C796F78766F767871777A73767B75
787B7A757878767A77787D7B747A79717A7A707B7B6F7B796B79777180806F7D7D788783
6D7C796A7D7D697C7E6B7E806D80827F92958B9EA1869A9F7E9196788A8F83969AA2B5BA
A3B6BD7D92987F949A8CA1A7B1C4C9C0D2D6A1B4B8ACBDC2C4D4DBBBC3CCB7A3AF934556
A0192AB00B18BA0B14BD0E15B80E16A80E15AD2D31CA545CA2232EA6101CAA0812A50812
870914A25C707C516B7D2F498A122796091696091186111C7E3B534D42710F2A6C0C3A7B
608CBC818AA860253C840C209003128E010D8C020B86020978050B6B18246A42572E2A51
081A50031D55153061526284766D826C4253621B2B67081671040C7401097200076F0108
6E01066D02076202054B07085C444151625846635B44625C4767604867604B6962496862
4867604B68634E69654D676549676548656347645F45635C415F543D5A522947403E5143
20A01500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047A808632E0556250E54251567372E5A29236638325C3A35
5842405544444F3C3D51363D4A2028531720591016560C1061242765383C6C484D69484D
64474E644A53654A546A515A59424C503B465F4F5775666A7B696D7C686B80696D876D72
8C74778F7B798B7B7A8C807F8C83808A847F827E798B8881797A7273756E72766F737871
757B77747977727975757E79757D7B717A7A717E7D707D7C6C79797682836E7B7A72817C
6F817C637776667A7C65797C6E8284798D8E839899819699A8BDC09AAEB38A9DA285999E
7C8F959FB2B7879AA083959CC0D2D9C6D8DEACBFC4A2B3B99FACB3B1ACB6A36C79951D2D
AE101CBA1019BA0D15B70E13A60E11AE2D31CD575DA4212DA60F1BB20D16AC070FA50710
8F0812B955637F1B2D8F0F1F980915940C15841A25844B6739366B0C2B720D3A7B6B98C4
ACC7E28672876F182A8A061792030F90020C8D040C7E061071222F6445601A1E4B041752
0A2158394B7267647D6F4B5E6B2130700B1A74031176020C7602097501087202086E0006
6C00066C01056601045704064F242451565143605942635C4567604968604C6A62496762
4968624C69664D68654D66644764614A676348676145635B425F533E5A530D2A252F433C
22A31B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004FAF0E5D260150210E602F2361231E52100B6E38325B3833
55413E534443523F40502F354E1E254F141A56181D5D282A66404465484F685057675156
634B52695059674F5966515959454F4C39445F4E5777676C7B6A6D7D6A6D836C6F876F72
8C77798A797A8A7E7E908785908A8786837E84827E8A898482827B787A7273766F70746E
757B76727A766E7A76717E7A768280707D7B6976726A7673737E7C727C7C707C7C71827E
718582677C7A627677677A7E75878B83969885999A8095967C9295788D917F94997D9598
A0B7BBC5D9DEB7C9D08FA1AA8EA1AA9FB2B99DAEB39EADB2A3AAB0A0838E852837A51320
B40E15B80C13B20D12A11012B0363AC9555DA31C29A70C1AB10B15B40A12AC070EA40510
920811BC4B578C1220960A178C0C168328397A5174292E6907276F19448382ABD2B8D6EC
AEB8C97F5A6E7C152690061492020C91030D83071179253562416113184A06164F1B295A
5C577B6542596422326E0D1D7A06137E030E7C010B7700097702097401087101076D0005
6A00056901046301025802064C19202B293145616040635F4666624665614B6A65496864
4967644967634A686449656148656049686246656044635C425F56415B5616302E324A42
23A81F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0055B5125F28005A28155F271F560E0B560A07723B355F413C
54423F4F4040533E40512C335B2A325B293062373D59383E5F454E614B54634F56665357
6853596B555E6B545E69535B5B47514735405C4C5576676D7C6B6E7E696C836C6F877174
8D7A7B88797A8477798A817F827D7A888581817F7B88888493948E85877F72746C73746F
7276736C77755D6E6F4F64665B6F71687A7968767276817B6F79746B7473627070687B7A
667B7A647A7865797A6A7E8461787F7F969B7A90918296967B8F908BA0A2B3C7C98DA3A8
92AAAFAFC4CC9AABB48798A17F9298A3B6BCC9DADEBFCACF968D94874856901624AB0E19
B71116B30F16A0161B9C3E44C87D868A1C2BA40E1EAB0612B20912B10710AC0610A70912
920A0FBF4C57881320821221793146644E7A192A6A062B712B548C98BFE2B8D7E9C1D5E3
ABB2C1815A6C7F172794071591010B88040D7A1A26744D671818451A1F52443964633E5D
641F346F0C1E7A05137D010E7E000B7D010A7901087501087301057301077101066E0106
6D01066901036401025802064F1E271413223652593F6160456561486663456560466662
47666346656049686249666147645F47665F47656045645E4362593F5B52345249284135
337B2C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDC0B692F02612C1752140B580C08560A066B362E60413A
594340523F3D52393B4D23284A161E5B2F385E42475741485E4A52614E55604D52675558
6653586B555F6E55616B545E68525B523F4963555D73656B7D6C6F826D6F876F71877172
8A76788676778376768077747E7976888481817E7B8D8C8890908C878A8477797172746E
7076745D6A6D3C5357365056385257576D6F6A7A77717C766C76726D7A766D7D7C637777
667B7B6D8181677A815B74814562707892987B918F839696849799A3B6BCC4D7DF9AADB6
80959E7B8F989CABB3AFBDC599AAB0A4B7BCCADBE0C3C6CF946F7D821E2E9D0E1BAB0C16
AF0F169F131E9742547358749476907C1B2FA40D1BAC0611AE070EB20811AB060FA50710
920E13B14E5776293A8253723935680D286C083274507AAAACD0EBBBD7E8BDD5E0C2D5E0
ADB6C4866877791B2B8E08168E030E7D040C95485550314E503D61663B5B651B346F0A1E
7B051481030F84020C82010C7F020B7C01097601057100047102047102066E02066D0206
6E01066B01046701035703074F26300A0D1F2F4D5740636145645F48676244655F476962
4666604866614967614A686048665D4C676047645E46645D4565583F5E4E3D5D4D375443
44503B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00763B095E250F511007550E085D1F166F453A62463B
583E375238345639383E1518542A30573A4157444A57484B5544495F4E555B4A51604F53
69555B6B545F6B52606B505E6E5460705B6470606775666C7A6A6E7D6A6D826B6E80686B
857074806F718477768B817E867F7C8883818C89868B8A878E8F8A8B8D8781857E72746F
7277764C5B5E385056324F55355055546A6C68777777807E6D76736D7A7968797A677A7B
65787965797D6079832A4B5C4D6D7C7E969C98ABACBACCCF8EA0A584969C8A9CA580919B
7B8C958B9DA4C9D9E0C9D6DFC5D5DD96A7AFA9B7C0AB9FAB8C4658961523A50B15AF0F18
9D131C9B455B64517F1B306B6E6692792036A20E1CA80610AA050CAE0710AA0710A30A12
8C151EA062746152761D2C6507286E1D49857CA6CEB2D4ECBBD6E4BED5E1BDD3DEC1D4DF
BBC7D28C7D896F2836830A198F081483061096364283364B6D1B30730A1C7E051382020D
83010C83010B83010981010B7C010A7801077302056C01056703066208086C1818660A0D
6902066B010565020552060C4A2B39070F252F4F5B40646342625D47666146645F476760
45655E4B686349675F48685D49695E48655E4A666046645D446457405F513D5D4D375545
43533E00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0082460E571B0452110754170D6F40366A4B415E473A
543B324F3831573D3A422929543D4050414754474E564A4E54464A5C4B525D4C53614F58
6A555F6D56617057637055626E555F715D6466565D5F515773666A79696D80696E7F656A
80676C837072867A7981777486807C8984838B88868E8E8A8E8F8A8D8D898788837F817B
7278745A6768334B4E314F52415C5D6074736C7A796F79786D77776C7979677778697A7C
6D7F826378813A5A6A284C5D6F8D98768D91899DA1A6BABF788C917F939886999EBACAD0
B5C4CC8E9FA7B0C2CBBDCED7B4C6CE8FA0A8A4ABB3A584918C2737A10D1AAA0E169F141E
8C33485D4877122B7313327A796C9880253A9D0C19A3050FA6050EA80811A4070F970811
8828385E466A112C64072F6D456FA19FC4E5B7D7EABBD5E3BCD4E0BCD3E0BCD1DEC0D3E1
C2D1DCA7A7B17F5662700F1D85041089040E83050F84061583041186020E86010B86000A
83010A83000883010980020D7B010B7301086B04085D060C591A2060363A82565A5D131A
6603086B010661030456151E35223704142D33556044656543615C46625D43615A4A6863
4B68634D68634A666048675F44655B46655F46645F42605B43625A426057405C513D574B
4254410ECE0900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF008E4E135416004F10035F251A65362E603E355F463C
58413855423D5444424D3F404E414451434A54454D55474F58494F5D4C505F4E5468545D
6D535D6B4D58745863715A636E5A616B5A605D505652464D73676C7C6D71826B70785E63
6E55597E696C8677777F757288817D8883808C8A868686818989868F8E8C91918E898B86
787C756D76715667645367666C7F7E6976746F7C796D7978727C7E68757764737765777B
667B814B687A10365062849799B4BA748A8D778D91768D9289A0A381959A8CA0A6C6D9E0
C6D9E1899BA682949F93A5AFB5C9D0BAC9CFACABB2A87480931A28AA0E199A10188D3748
675078192C6C23377C605890905C7C891C2EA10E1AA50914A30610A40812A007108F0A15
8539512A275A0F397374A2CBB2D4EBBCD4E4BFD7E1BFD4E0BCD3DFBBD2DDBFD3DFC0D2E0
C1D2E0B2B9C6977E8C7C293784061389010C87010989010B88010B860009870008870109
84010982000981010A7D020C74030B64070D5E1A235933423C30452F293C603E4C590A16
6802076B03075A060A582D3B14112D0B223B40616A47646645626049636047625E4D6764
4E68644B64604B66614A676248665E44625D43625C42615B44625C45605C425A533E574B
4357421FA11500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006C7A0F55170055190A5B1F13581C1466332C57322A
5C413C55433F4C413F493E3F4D3F4454434C56454E5746505B49525F4C5265505570525A
73475056262F79545C725B606F5D626E5E6465575D52454D6D61667C6D717E676C755B5F
6A515476616483747689807E87817E827E7A87848083847D8586818E8D8B999A988C8F8D
828682727773767E7A7D8683747E797B82807A8483737E7F707C7E67757760717364767B
5D76841B3F5C1943605F818E6F8A8C768D8F788F927C9295C2D6DAB6C8CF7B8F988FA6AE
8EA4AB8497A07789958C9EAAC6DAE2CAD8DEB6ADB69954619F1A28A9131E972B357E576E
333762605C8D7A4F79742341A33A4D981724A30D17A60B16A60C179C050F9A0812870F1C
7A42601621582B5889ADD7EEBAD5E0C2D6DFC0D4DCC2D5DDBED2DDBFD2DEBED2DDBED1DC
C3D4E09CA0AE7855677417288706148A020D86010986010A850109860107830006830107
82010880030B78050C69070F621A23663D4D4436501B2040202444533C56541224670510
6B02066105085B202A37263F0411321C3B5240656A47656445625F49656347635F4D6965
4965614966614A68624866614A686047655D46645D44625D46635E47615D445D553C584B
3C543F22A71A00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A2095418005923125A1B105C140C65251E4E211A
61433D53413E4D403F4E40415242475A484F56444C5B4852634B56684B5369434B713F47
69262F6A262D815258765B616F5D626F5F656C5C6262535966575C7B696E735B60705459
674D507460627F7072817776837D7A817C7A807C787E7C767A7A758383807C7C7C6A6E70
686E6E6A716E777F7999A09EB1BAB9B2BCBB98A2A3727F81707F806D7E7D6D8180637880
3E5B76072C534A708B6A888F6E868593A7A77D91947D9295AFC3C8A1B1B9788A93798C93
B3C6CCC7D9DFA8BAC3798D97A5BBC3B6C6CCBBB0B98B404DA11925A20F1AB84C5AA3667D
8D58748A37518E192C92101EBF424E9A131F9F0914A007149C05119B0712940A147E1829
64456A0A255D527FA7B6DAEABDD5DCC0D4DCC0D4DCC1D5DCBFD2DBC0D2DDBED1DCBFD2DC
C1D3DBA3A7B379526176132487051386010B8401098401098401098500088201097E0209
7A040D6F0912691E296B3F51483B571A21470D1944302F5452344D550E216805116C0208
6004075A1C22452F430B103503193B3357684166674767634A68644A6965466560486862
47666149686249696348686148676048675F43625A47655E43615A44625B405F533A5A4A
3D5843337A2700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BAA10581F015C281650130859160D6A3128633C33
5D423C543F3C51404055434756454B5A474D5C464F624650663E49622D37672B347C3840
76242C7B2C33845057785C6374636A7263686D5F636B5E626E60666E5D62735D62694F53
6F55597762657D6E6E7B716F7E757379716F7F797578746E76766F7F807A8485827E8181
7C8482616C67A9B4B1C7D2D4C1CDD3B9C7CCC5D3D7A7B4B86C7B7E697A7A687C7F5A7585
103257133A605C7D906B83877C9191C5DADA9FB1B5778A90768A9097A9AFA9B9BF82939A
B3C5CDC6DAE3A8BDC68EA4AE839CA394A8AEBAB3BB9655619A1B27AA121EA41A279C2332
9519289E18249C151D931C23C7546097111F9E09169D0814990511980712870914833950
37305F072B6385B0D1B8D7E3BFD5DDBFD4DEBDD3DBBED4DBBED3DBC0D3DCBFD2DABED0DA
BDD0D8A7B0BD7D61706D142484051488030F84020B84010A86020A83010B7E040D710811
6918276C3E515142611D234E0818481C26534C3F62582840600D1D6B040F6D030A5E0509
5920274A35490C143502163C1E3E5545686F4768654967624B6A6448676345666045655F
47686249686347676248686247666048676141615A44615B46645C426157405F513F5C4D
3D5544434C3500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0054B415602704511D0A4E160A5D291E6941375E4239
5C453E55423C53424157444958464C5C454B623F47602F39672D3768252E76343B813D42
711F26792A32854F57795D65715E677162687063676D60657063686E5E627A666B7D676B
70595E776366807170796E6C786E6C746B69736C6873726A77796E8A8C82878983888C88
868D89939F9AC6D1D3B8C1CB7C889174818A819095C6D4D87F8B906F7C8060737E294564
0327533055758EA9B47A8E92788D91859B9E72868A71848A778B90BFD3D7C8D9DFA6B8C1
798E9A7A919B88A0A89AB1B990A7ADB5C7CEC0C5CCAE8D94852A349B1720A5171FA01822
90141E8B252F964B55BB7B859D435191101F96071293050F91040D940B147C11207D5274
14235C1A4377A7D0E8BAD4DFC1D5DDBED5DEBBD3DCBED6DFBED4DEBED3DDBDD3DABCD2DA
BDD0D9AEBBC875647466182A81091785010E83020D83010C7F030C7406106A16216C394C
523F611F2654061C4F041E502B39634E395755142868091672040E6D040C5C09105A2935
40334C0B133A01173F1939543F646C4A6A684A68634C68644A6964476761466862466661
4667614B69644B69644A686348676244645F41615B46645E45635C436158446156405C4F
3F584747533D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059B8156C30064911024E1C0E67403262453A5C443B
5D473F56443D5745455A474B5E464C643D445E222A5F151E732B3465222A74353C7F4247
6C292F6C2F3480575D765E666F5F677060696B5E626E62656D606574666A79696C7B686B
7D686B7E6A6C7B6B6C796C6C736967716865726D677A7971777A72848880848983878C88
89938FB4BFBEC8D2D8858E987A838A798386667476B9C7CC818D9564727D465C73082551
0B2F5A51738BA1B9C184969C74888D7B9193A6BBBDB3C5C97B8E9599AEB5ADC1CA8399A2
748A948499A2C4D9DFC5D9DFB5C9D29AB1BDACC3CFA4AAB1B39498915056934853955568
855B776C5F833F42668A728F7722388C0C1A8F071088030C8C060D8A0C187D2F46463C6C
0728655984AEB5D9EAC0D6E0C3D6DEC2D6E0BED5DEBED3DEBCD2DDBBD1DCBED3DCBDD3DB
BAD1D8BACAD57368775E1C2D7708167E020D7A040D7408116C1823713C50554160232955
091D54031E552E4F7A7C9BBA70778E4F21356208156F050D67080E5C17205C38492E2849
071643011B451B3D5A4165714767684B68654966614A66624A6963496A644A6A644A6965
4968654A676446656046666043655F45666141645E40625B42635B4361584260553D5C4F
3E5A4943523A0FCF0800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00733408491503572D1B654634644C3D5E473B
5E48415C45425B434461424764384065273161111B620D15752A306423296B31387C4A50
754C5279585D77606577676D6E5F6770606972646970646870646872676B786A6E806E72
7965687B6668826F707C6F6E726965746D6878736D7D7A767D7E7A8488838A8F8A878E8D
7B8788B3C0C4C4D0D7727E84737D7E6F7A76697875BBC9CC67777F566A7C1A375C082F61
1F466B54758361787D687A807183876C8185BDD3D7C3D7DD8B9EA583979F7F929AA5B9BF
9AAEB48A9EA5C3D6DEC6D8E2AAC1CC7494A83E657CAECBD8C0CBD0A9A6B270749238487F
1839780E39783A52867E597C7E172C8E0A15900A128A050C8C09117B142360365C132460
0F3B719AC3DFBAD7E3C1D6E0C2D6DEC2D5DFC0D4DDC0D4DEBCD3DABDD3DABFD3DCBDD3DC
BBD2DABFCEDA7F77855E25366B0B176C071161111E683448584362282C5B081D5604225A
2D4E7D5070937E9EB593AFBC777E8B552D3A570C1559121B653847493A56161E47041747
05224E204760456D764A6A6C4F6B6A526C684B69634B68634B69644B69644968624C6A66
4A696549676347676245686245686245676142645D3F615A42635B426359426256415F54
425E4E47564121A11400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF007B400E4D1F075D3B25624732614B385C4639
5F46406044435E3A3D67373D5E1F276D20276A151C641118753538703F42744A5176555D
735B62715E6371616676696E72636A72626873636874636870626574666A7A6B6F826C71
85686D8764687C5B5D806C69746B64756F6878746F7F7D7A8888848C8E898A8D8A6B7474
727F81A3B2B6C5D5D9839495707F7D6D7A7795A3A2A0B1B5586C793A53700321540D3366
3D658058757E6E8488AFC2C6BECFD5758991788D9683979F8799A07E8F9696A9AFC5DADF
C4D7DF8B9FA78DA1AA93A7B0A1B6BF93B0BF65899DB8D6E8C4DAE7ADC4DA3B5D8F053282
1247945E8ABD9995B682374D8D10219108139911188F0911850F1B854259302B5C072966
5886AEB3D7E9BED6E2C1D5DFC1D5DEC1D5DDC2D6DEBED5DDBCD3DABFD6DDBED3DDBBD0DB
BED3DEC1D0DD85859354303F551A255E2E3E493552222652071A53021F5A0C3063355A80
7EA2B8698998627E8A829CA487959B564A53563B4652415622274D051A49011B4B0E2D54
3B5F74456C724B716F4B6A684D6A674C69644B69634D69644F6B674C69654968624F6D69
4C6A664B6A65496A6345676145665F46655E45655D46655F43645D3F6158436259425D55
445F5346594923A51A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00824811582F0F5C3E275F4731604B385E4639
66473F693F3F572023652229671B2372232969191D5C171A6B3C3E68494D735A62715A63
6E5C6471616A74656A76656B7D6B726F5D64725E6576626874616877636982676D845C63
8249516E2F357946497F6462786D677F7A747F7D7981807C8586808C8E888D928D898F8D
8E98998B989BB7C7CCB9CCCFA0B1B2ABBBBCA4B3B7687983556D81142E5A011957153663
5C7C8C657F83667E82A5BABFA9BBC2687B82667A808FA3A8C4D6DAB4C4CB7C919AA3BDC5
A1B7BF8B9FA772878FA6BDC3C7DCE1C6D9E2ACC6D891B4D283A9CB94B7D8254C7F03317D
1B4D8D96ACCD9564798D1B2B9F111E970A14940A148A101C7A293D553E660C245D1E4979
A3CBE3BAD6E0C2D6DEC1D4DFC1D5DFC3D6DFC0D3DCC0D4DDBCD2DABED3DCBDD3DDBCD0DC
BCD0DBC2D3E08F99A665616C685F6A343755071A4C011D58072C5F264E72466F8851788A
6C909B98B8C256747F9EBCC4A1B9BF67757D7D8997142844021C480A29542B4D6B4C6F80
5272785070704D6C6A4F6D6C4F6D6C4A68674A68654F69674F69664D6A664C6B654F6C6A
4F6C694C6B664C6B6547676147676148676246645F46645F43625C426058426058445F57
405D52475F5023A91F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008B54145B320D5A3D255B46325E4A385F4337
643A33652829681D2164151A61141B662024652B2C6A3F41684C5065515769575F6E5D66
6E5E686E5F6874646A77656B78656D78646D746067785F677D5C65785157824E54773239
80292F822E307D41418468647A6E697E77747E7B7781817D8688828B8E88898F8A8D928F
8F96958F989B889298919BA397A2A9818D936A787E5E6F7B3C5271031B540018582C4D73
98B6C29BB2B75F777D5A73786B808584989B6D82859CB2B6C5D9E0B9CBD5748994748F96
A4BCC2BFD3D9A0B6BC9AB1B8BED4DBC0D3DF97B1CB224C7F0F457F8BB8DE8CB0D042638F
738DB2A892AB8A2D419E13209D0B14970A128A0C16751E2F75577915245E0B2F6884ABCC
BAD8E4C2D7DEC3D6DCC2D5DDC2D5DDC2D4DDC3D6DEC2D3DCC2D4DCC1D4DBBED2DBBED2DD
BCD1DCBFD0DDA1B2BD99A7AFBECED74257740E2B5B1A40742D5B82608CA180A7B820475C
7196A8ACCBD77D9DA875949F9FBBC37D959C637B85314D6036546B4C6C7F688892617F84
5673754E6C6B4B6A68516F704D6B6B4B68694A68684C68674A66634A68634F6E684F6D6C
5370715572704A686547666348676146635F46625E43605C46635F446159436056466156
405C50486053434B3800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF006B830F5F390D5C3E255E4432644939633D32
581C176E212069191A661C1F5C20226B3D406C4B50654F5462515665545C6959636C5D67
6A5C6671626B77666D7B666E7D666E7C636D7A586381535E73363F752A32802F347D2427
862727781F1E8747478264627B6E6B8177767F7B797F817C868A848F948E8A908A8F9590
8F95918C9292898E9073787B70767A6B7478626E74596B7F182F5C011D5D05265E416381
69858F6A808563787D5D747698AEB0C3D8DAB0C4C96D848C91A6AE92A5AD8C9EA6758B91
BBD2D8C5DAE1B3C8D195AEBB91AEBEA3BDCBB0CBDF3C608A2A5C8E9CC8E9BDD9ECA6B5C7
B9AEBF964F629C1B2CA50F1B9D0C13910F187A1E2D6744631C2A5F082B666088B1B8D8EA
C0D8DFC3D6DCC0D4DAC2D7DDC2D7DEC6D8DFC4D5DDC4D6DFC2D4DCC0D3DABFD2DBBED3DE
BCD1DCBCD1DBBCD1DABED1D8BCD0D8AAC0D07F9DBA133762012754527A999BC1D52F546B
42687B84A5B2809DA85D798468838B839CA1647F847A949CA1BDC5658188849FA385A0A2
5773734E6C6B4E6E6B4F6D6C52706F4E6B6A4C6A674A68654A68634C6C6751706D4C6B6A
4D6C6C4C6B6A49686549676449676446645F45635D44625D45625D49645E466158476157
445F54485F5449524200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049AF0D653E0E5E40246144326842365E261D
5E130C6815116015105E24226A4346684F556352595F52595E515761535C655862695C67
6C606A6D5F6877626B80616B87626D8658646C2E3C8134416C151E7A1F2472181B893333
7E2C2A6A1F1E672F2F7B5D5C7B6E6B79726F767470797C768689838D918B8E948D8F9790
8F98918F9791888F8A797F7A707774737D7D65737D394D6D031C56092B6D264E7C4E7183
5C767A6F838396A8A8677A7D889CA2BBD0D69BAFB67488908B9FA5C3D5DAC7D8DE98ABB4
8CA3ACA1B6BF94A9B47B96A731576C88AEBFC3DBE8B6D0E685ADD075A2CB87AAC9B0B2C5
A87383942133A81320A50D1796111B781B2C775474202E62052C6548729CB3D8EBBCD8E2
C0D7DEC2D8DDC1D8DCC3D8DFC2D8DEC2D6DDC2D5DDC1D3DDC1D3DCBFD3DCBBD3DABAD1DB
BBD2DBBDD1DABDD1D9BDD1DABAD0D7B7CDD7ABC5D55B779605274F244B6D739AB07699A9
4F727F50727D8AA8B07E9AA279959BAAC7CC98B3B9728B93A3BCC37B939A637B81647D81
5B7477536D6F51706D506F6D506F6E4E6B694D6B664C6B664A6A664C6D6A4B6C6A496B68
496C694C6C6A4C6C694A686647656347656244625D47666148676149645E466159476157
476157475D524C574800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B41269400D5B3E205F402D5E2E21540E05
64130A63160E682D26603B36634A4C63535A61555D5A4F565F535A62535C6758626F606A
70606A735C6779545F6C37436C2D387E333F832B387A1E29791F24731F2068201F8D524F
82514F774A497A56547B64627C716E77736F7A7A747E817A8789838D908B8C918C8B928B
909991909991919A93828883757C796D7777637280192F59021A5D001F5E2F54775E7C86
667C7DA5B6B7C8D9DC8899A06A7D85768A919EB3B7A4B8BD93A5ADC0D1DAC1D2DB91A5B0
7E95A08A9FA7BED2DBBED5E293B1C1A6C5D3BFD5E2B1C9DE4066910A3C7A436494B59FB9
943345A81425AD0F1C9D131F8326396443671E2D62072E69416D97AED2E8BEDAE3C0D9E0
BFD7DEC1D8E0C2D9DEC3D7DEC2D6DDC2D6DEC1D5DFC1D3DEC2D4DEBFD4DDBAD3DABAD3DD
BBD4DBBFD3DBBFD3DBBCD2DCB9D1DAB8D1DAA7C3CD7795A95F809A4269844A728696B7C5
789AA8436777A7C8D5A1BECB6B899594B1BB96B1BC627D87667F8663777E5E73795D747A
64797E5D7577567371506E6E4F6F6E52706E506E6A4B69664A6A664C6B694C6C6A476965
4A6A654D6C6A4B6A674665644B696647646147646045625E48676147655F47635A49645B
466257455E524A594A209F1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0055B914693E095F4020633F2B5C2317590C03
66170D6121186D453C634D485F4E5062565B61575F5D525B60535C64545E6A5761755C66
7B586480535E6025317E3D457A3339701D24923D44691B217C393E743F407F5756866967
826A6A735E5F715E5D7F706E7E74717C79757F817B898D85878A838E908C8A8E898E948E
979F979099918D9491858B897379776B75794B5C74021A4F00175C06265A52748B93ACB1
70828676888E93A5AD68798067797F798D92C4D9DDC4D9DF9FB2BC8699A483969E95AAB1
7D929991A8AFC5DAE1C4D7E1BACFDC99B4C880A1BEABCDEA51769E1E43759D9FC6965068
A41E2EAE1321A218269239516447721B2C6A052D6A45709CAED1E9C0DAE7C3D7E0C4D8E0
C2D7E0C2D7E0C1D7DDC4D8E0C2D8DFC0D5DFC0D5E0C2D6DFC2D5DEBED3DCBAD4DBB7D2DB
B9D5DBB9D3DBBAD3DDB8D2DCB4D1DBB5D0DAB0CCD759778A88A8C2224266214569A0C4DA
799DAF254A607091A692AEC064808F55728069868F6581875A767999B1B373898C6A8287
9EB5B962797E5A7675547170506F6D516E6C4F6E6A4A6866496865496865496966466661
4969634E6D6A4D6B6B4A686848686447656046635F48656043615C47666046655E47625C
456259445F554B5C4E25A61E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00704209613B1B582A17602215570D04
6621186F3B316C4A43644E4A5D4B4C5F51555D52595C515A62545E64525E6E5461693E4A
612330752A386F242F8042478B55575C1F238E515679484D8562667C6468817072817375
78696C79676A7968698477768076747C79757F807A878B838689828D8F8A9195908C928D
929B938F99918F9995888F8E747C7C6A768122385D021D5C001A5D12325E628292B9D0D5
74868C61747A6A7E83B4C7C9A9BBBF6B7F859EB5BCA4BBC5859BA5778C93A8BCC1C6D8DD
BDCED491A5ADA6BDC4ADC2CBA9C0CF4C6D8E1646728DB6D7B6D1E8A3A5C0A9738C982236
A91A289C2231A45D78615284162F740A35785582AFB4D7EDC1D9E6C4D8E3C6D8E2C7D9E3
C3D7DFC4D8E1C4D8DFC5D8E1C3D6E0C1D5DFC3D7E1C0D5DEC0D5DDBED4DDBED7DEBAD4DC
B7D2DAB7D4DBB6D3DDB5D1DCB6D4DDB7D1DBB6D0E036536E88A9CB173662022654507895
84A9B95577884E6D7E65818E7A95A0597680A1BDC3A4BFC4647F84A1BDC09DB7BA657E84
70878D637B7F5D7877587572516E6C53706C52716D4D6C68486764476764466863486863
4668624A69664967684A69684969654A69634A67614A666247645F47655F48676046625E
46625A486359495E4E367B2A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007C490B5D300C59230E602011601F15
743931632E266C403953312F634C4E6252556054595C4F57634F5B634856714C59612D39
813F4B64162280353F6F3A40815C6075515683616680666B7C6B707A6D727F747982767B
796A6E7B686B7A686A7D71707D74727A767182827D898A84888A858E908C9395928A8F8A
8F98908D98928895918590907A858A57677E061F53001E64103572254C6E5C7B86677E81
6D80856C7F827C9195C5D9DDBCD0D66B818768818886A0A6B3C8CE9EB0B7A2B4BBC4D5DD
B3C5CD9BB1BC8CA6B1AEC8D3C4DBE892ADC6507797ABC9E0C7C8D7B4859A8F2A40971F33
9A3E53956A91414983103179164281729CC6B9D9EEC3DBE4C3D9E1C5D8E2C6D9E0C4D7DF
C5D9E0C6D9E1C6D9E0C6D8E2C7D8E2C5D6E0C4D6DEC2D5DFBED4DCBED6DCBFD7DDBED7DD
BBD5DCB9D4DBBAD6DEB8D3DEB6D3DBB7D0D9B9D3E33E5E7B3D64865378982F5473456982
6586948BA9B55172808DACB8AECAD4849FA98CA8B2ABC3CE70899369858D6C878E667D84
6981866A8284617B7D5A777459767457737153706E506F6C4B6A66476764496B66486864
4969644B6A664A69684969684969654B6A654B68624C686447645F4A686048665E45625B
46655A476457455C4E49503D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008750105E2D08622E175A23127D4438
692D246122186F372E562E2B654C4E665457665358684F58603B48693B47703C475E2E38
82535C531F26774449724D51795F657F686D7D676E7B686F76686F7A6E747F747A85797F
87777C7F6D707564667D6E7080777576726F82817F8988878C8C8B8A8C8A8D908D929692
9198938F9B948C9A958491917B8A942E4267031B5D021E6B0F3671476E88628084708585
BACDCFB5C8CA6A8085869EA47B939867808360787CA9C0C5C6D8E0BCCDD597A8B09FB2B9
A4B7BFA8BEC95E7986ADC8D6C3DBE5C4D8E3A8BCC8ACB4C0B59AA8833E4F944051B77F98
696092203E880B3E8632629999C1E2BDDCECC3DBE3C7DAE0C3D7DEC5D8E2C5D9E1C5D8DF
C4D8DFC6DCE3C5DAE2C6D8E2C6D8E1C6D9E3C6D8E1C3D6DFC0D6DEC1D7DEBED4DCBED5DE
BCD5DDBAD4DDBAD3DEB8D3DFB7D4DCBAD4DDBDD4E27492A9466D885B859B84A9C13B5F7B
7B9DB2ADCBDB36586C6185989EBDCB86A3AE5D7A8569858F6A828B5D7880819CA38BA2A8
6D858AA1B9BF6E878B5D797A597675597475546F70516E6D4D6B6A4C6B694A6969496868
4A69674968644767644969684A69664B6A654A68634967634A686347635E4A675F46645A
446458426055465F5249534300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009254185C250764311C6935246A3023
632014601A0F6931266C4B43614E4D6750526A464C5F2C355F212C733038601F265D2930
79555B65494D6D5254755E6176646978676E7B687079687171636B796D737E74797F737A
87777E8473777C6C6F7C6D6F796E6E817A7A817E807E7E808687858C908B8B908C929894
939A97939D98939F9C8A97987486980E2656031A650018660C2C606A8A9C7F97998FA3A3
BDD2D5AFC3C96A808660797EA0B7BABFD4D591A3A88DA0A7B1C4CCA0B2B998AAB298ABB1
C5D8DFC8DBE3AFC4D09EB5C2ACC5D1AFC4CDAEBEC6B4B8C08C7981AF8B95C7B4C86A79A9
103C8D084299548EC7AED9F2C0DEE9C4DDE4C6DAE2C9DAE3C8DAE2C7D9E2C5D7E0C5D8E0
C3DAE0C1DBE3C4DCE4C6DBE3C5D9E0C4D8E1C1D7E1C2D9E2C0D6E0C3D5E0C3D7E1BED4DE
BBD4DEBDD5E1BCD3DFB9D2DEB8D3DEB9D1DBBDD3DF94ADC31B40615E89A7577E9F012552
3A60829ABCD17798AA5174845F808C77949E6A878F88A5ACA9C3C978929A8BA6AEAEC4CE
768F977992996E898D5F7B7E597776587574567172506C6E516D6F4D6A6C4966684C696A
4E6D6A4D6C68496A654969664968644B6B644868624B6A654F6A674D686249675D47655C
48675D44615A4760554A5A4A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003E9D04571B02622C186F3928622113
71251C62170F642C246B4C4668514F633F42652C33702B3362171F671F2766272D5C2F36
6C515768565A66555A6D5B6273636A75666C7B6B7177676E6E6166776D737E747A7C7178
81747A7D6C727C6B6E7E6F707C6F6F817877807B7C8382838788868E918C8D938D898F8C
8C9391939C99919A998B979E51658205215D021B6A001A631F3F6BABC8D7A1B5BA8A9CA1
8A9EA47C9096889CA15D7579B7CED2C3D7DCA9BBC18EA0A88EA2A8BBCDD3BDCED59EAFB9
BDCED7C1D3DBB1C7D692B0C5668CA498BACAABC0C8B5C3C9BCC5CCC8D4E57E9DC20F448B
0440A30747A27FB8E9B9DEECC2DCE2C3DAE0C7DBE4C9DAE3C7D9E0C8D9E1C6D9E0C5D8E0
C1D8DEC3DCE4C3DAE2C4DBE2C6DCE2C4D9E4C0D6E1C3DBE4BFD6DFC1D6E1C2D8E1BFD6DE
BDD5DEBFD4DFBED3DFBBD3DEBAD3DFBCD2DDBED3E0A5BCD60B2D591B46716F9ABC14385E
446A885A7E8F86A5B06F8E9973929BAFCCD599B7C085A2ACAEC8D28CA6AF69848D7A949D
69848A637F836581836580815B7777557272567373526C70526E71516C6D4D68674B6867
4C6A674C6A674667624766644968624A6A634B6B644D6C664F6D694A676246655E47655E
47645C47615B4962574A5D4C1EA01600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0047A70C5B210168311B5C200F6F271B
64170E6320176839316D4D49674244682F35641D246D252A66242A5B262D714B53684F56
65555C675A5F64545D6D5A6474626B77676E7A6A717B6B7177696F7F757C7D727A7D7179
83757B806F737C6A6E7B6B6D796C6C8076757F7A787F7E7B8889868F938E8E948E8E9591
969D9A979E9A959D9E92A0AF28406D04236B001E6D00206033557B84A0B07F959C75888E
768A90B4C6CBC7D8DE8CA1A871899292AAB08FA3A7889AA091A5AAC8DAE0C9D9E2A9B7C3
ACBBC5ACBDC5B7CEDC5B7D942B58739DC1D4B8CFD7BED4E0A2C3DD699BC75B97CB4283C5
04469F03489F629CCFBBE0F0C4DEE4C4DCE2C6DBE4CBDDE4C8DAE1C7D9E0C7D9E0C6D8E1
C6D9E0C8DCE4C9DDE5C6DBE2C6DAE1C5DAE3C4D9E3C4D9E2C2D9E0C2D9E3C1D8E0C3DAE1
C1D8DFC3D6DFC2D6E1BFD5E0BDD5DEBED4DDBED3DEB5CEE21E42661E4C75527F9A7CA1B6
7CA0B66B8FA1B1D1DF93B2C3698B9CA6C5D49CB9C667839276929D6E899265808769858A
749093617D7E839D9F708A8C647E825F7B7E577575526E70526F70506D6C4F6E694E6B66
4D6B684C6A674868634B6A664A69644D6A654E6C664D6B654D6C674A696547666146635E
46615A476159435E53485D4C20A31800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004BAC0D5F2604612713601C0F71251A
5F1B10703C32734C456D44446A3236661E256E21277433376B3D426F515A68565F655961
62585F6559616B5A646F5D6675636C7969707868707A6A727F6F76806F767F6B73836E74
70585B8C7276826B6E7E6B6C7B6D6C817776827B7985817E8585828B8E8C888D8B8D9290
929795999F9C959EA37688A30B28640221740F3384163E7A476A8A58748072888D8A9CA2
6B7E85A2B7BEBFD4DC8DA2AB7289938AA3A8C4D9DDBFD3D9889EA6A4B8BFADBEC697A7B1
9FB1BBB9CBD4C7DCE4BCD6E1A2C0CEB2D1DEB9D5E1B6D6EE467AB00B59A62A79BB91CDF5
467AB14984BE98CCF3BDE1EFC6E0E6C9DFE4CBDEE4CCDDE4CADAE1C8DAE2C6D9E0C4D8E1
C8DCE3C9DDE4C9DDE4C9DBE2CCDFE6C8DCE3C6DBE3C6DCE4C4DBE1C2D9E2C2D9E1C2D9E1
C0D7DEC2D7E1C0D6E2BFD7E1BDD6DFBED4DEBED4DFBAD3E47FA5C24778A05888A9A7CFEA
406A8D39668AA1C8E17293AB57788E6C8A9C77929F6A86937590999EB6BD77929786A5A9
ADC9CE748D907E999E728E936380845F7D7F5C7B7B5471714E6C6B4C6C694D6F6A4E6C69
4C69664A69654B6B674C6B664A6B654B6A654E6C664F6C674D6C6749696546656043615B
405F58436058436056465B4C25A71D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0055B512682D03541606671F15611D11
70382C71423A70403C6227276722246723255C21246B41446A4E5466555E635660685D67
695F686B5E676D5E6871606872616978676F7B6871826B7485656F845863693D46946F76
67464A8462657C5B5D715857847471847C7988827F87838081817E868886868A898D9291
909896939A9B8F99A44A5F8704206A001F780124770F366F597B93627C83AEC2C7C7D9DF
869AA369828D6E8A919BB3B994ABB0829CA2C2DBE3B7D0D87F99A092AAAFAFC4C7C0D4D8
A3B9C0B1C5CDC9DAE1CCDFE5C4E0EB8DBCD782BBDFACDFFC4F89C01764AE468CC1BCE5FD
D2F2FFA3D5EF80B8DABFE5F3CCE3E9CFE1E7CCDDE5D1E1E8CDDDE4CADCE4C4DAE0C2DAE0
C6DEE3C7DCE3CBDEE4CADDE4C9DCE4C8DCE4C6DDE4C5DBE4C6DCE2C6DBE3C4DAE1C3DAE1
C1D8E0C0D6E1C0D6E3BED5E1BDD6E1BED6E1BDD4E0BCD4E96A8EB60A397B1A4C888EBEE7
15436C1E4D756C95AF7191A56D8A9B7B95A3A7C0CB92ADB78FA8B1B6CAD298B3BA7A98A0
9EBBC27893996A858B668287617D815F7D7F5E7D7C58777553736E52726E4F706C50706D
506E6B4B69684B6A674C6C674E6C674A68644D6C674B6A654C69664B6A6548676242625C
3F60593F5F57416055455C4D474D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0A7336065A190756130A753B32
78483F612F266C30296F2D2863221F71403E6E4E4F6C585C64565D6659616A5E676D626C
6A5F6971656F70626C70616A7661697D606B835D69814F5A7A37447C293770212D7E494F
805C607A55587B575A8167697C6C6B807876817E7A8484818282818A8B8A878A89858C8C
8B9494939B9E8E9BAE1F376A022071011E790122702549797A98AA627981879DA5A1B7C0
647A87637D897B989FC2DCE0C4DAE279929D738F9A7E99A094ACB1A7BDC1C0D4D6C9DCE0
C9D9DFCAD9DFC9D8E0D0E3EEC0E1F44383B22B7AB291C9E8B9E0F9A8D1EBC9F1FDDAF9FF
D2F5FF7BB5D775B6DAC7ECFBD4E6EED4E4EBD1E2E9D2E3EAD0E1E8CFDFE7C6DAE1C4DAE0
C9E1E5CBDEE5CDE0E6CBDEE5C7DBE2C5DBE4C7DDE5C7DBE4C7DCE4C9DDE4C7DBE3C6DBE3
C2D9E1C2D7E3C2D6E3C2D5E2C0D6E2BFD7E3BDD4E1BED6EB6082B00535810A4188659AC5
6F9AB7638BA57C9FB2ADCAD8A3BBC988A0ADB4CED8A9C3CE7F98A59EB6C18BA5AE738F97
789299768E936E898D7F9BA0698387647F82637F815D7C7B57777454747153756F52736F
4D6D694D6C684C6B674F6D68506E694D6A664B6A644C6B664E6C684D6B674D6B66486762
46666045645C47655A435D4E48534000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00783A085417015D2317744139
69332B62231B6D2F256A342C673B366B4D4D69585C65596163575F61555D665B636A5F69
6C616A6E606972616B765F677A525D7738467626348D354083212F811221730D168B484E
7F585C7352548C7073897476786A6A7F767376726E7574728486858C8F8F8A8E9082898A
8B96968D9BA07287A107246102217700207A00226E5478A3BBD7E87D959C5C767E607A82
A3BAC38DA5AF748D97B5CFD7A6C0C96E899490AAB2B7CED4C9DDE2C1D2D6D0DFE1D3DFE2
DDE9EDE9FAFFBBD2E1C6E0F0C7E4F595C0E1A4D4F1D9F7FFF1FEFFF4FFFFCADEE6ABC7D4
B6D8E7B3DDF2B2DBF1D7EFFADFECF4DCE8EFDAEAEFD7E8EED3E4EAD2E2E9CDDFE6CBDEE5
D0E2E9CFE0E8CCDFE6C9DDE5CADEE5CBDEE8C8DCE5C7DBE5C5DBE5C4D8E2C7DAE7C5DAE5
C1D7E1C5D9E4C5D7E3C3D6E2BFD5E0BFD7E3BED5E2BFD6E690B0CE3C679C4B7EB574A4C8
A9D0E88BB3CF81A8C1B5D2E29FB7C8809BAC96B2C08FA9B77A94A0829DA68DA8AE7A9298
9FB7BCA3BBC1748F95A1BCC47B969C6D868B6B8588708C8D6381815C7A7A597775567570
55757054726F52726E506F6B4F6E684D69654F6C674D6C674C6B684C69664E69664D6865
48656047645B47655844605247574600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C3D0E531903643122723C2E
5A190F611B1061291D7A554B71585465535561555A5F555C5F565C60555C61565F655961
6C5B63745B667D5B656F3F4A75313D701420780D199328338518247E0A147B1119914A50
724C4F7C61628A7575837473796E6C827A767D78747473707B7C7D86898A8D9192899191
8B96968E9FA7435F8104256B00237B072E87002670547AA584A2B2748C92647D8287A0A5
C4DAE1BBD0D98096A28099A290A9B0A9C1C7ACC1C8C3D8DDCCDDE1D4E1E2EFF6F6F2F7F9
E3EAEFCEDFEAADC5D3D6EDF5E4F3F9EFFCFFF4FFFFF5FFFFF0FCFDF4FEFFEFFAFEF1FFFF
EFFDFFF3FFFFECF9FCDFEBF3DFEAF1DEEBF2D7E5EAD4E5ECD4E7EBD4E6E9D2E3E8CFE1E8
D0E1E9D0E2EACADDE4CADEE6CADDE4CBDCE5CADDE6C7DBE6C3D9E4C4D7E4C5D8E5C1D7E4
C1D8E4C3D9E5C4D7E2C3D6E4BFD5E0C0D5E1BED4E0BBD2DEABC7DB9AC0E74F80B673A3CE
9CC6E82150785080A49CBDD498B3C692ABBD94AEBC9DB5C28BA4ADA3BEC6B2CBD188A0A8
A4BEC6A9C2CA7D959E7E969E778F946F888B748D8E7C9596748E90647E7F607B7C5F7B78
587674567474567676537271506F6B4D6B664E6C674A69644D6A674E6A66516B694D6864
4D686149655C486659456255465A491E9E1400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008246145621086331205B2114
5E1A0C6225155F3527735D53695A5862555860545A60555B5D53585C52595D515964545D
70565F724954672D387C374281313C7918218A2028962F3687252C76171D8D3E43835054
836769816E6F8474758174737F7573837A797F7B797B7A787B7C7C868A8A8A8F8E8C9493
8D96988B9BAC1D396B02237601248217419C012B715D85A97F9BA6ABBFC29AAEB47C919B
ADC3D09EB4C194AAB69BB2BBBBD0D6CCDEE4CDDDE2DEECEFE3ECEFF2F8FAF9FCFDFBFDFE
E6EBEEDBE4EAF2FCFEF8FEFFFBFFFFFAFFFFF3FFFFC9E8F1B7DCEAD2E9F1F2FBFDF8FCFD
FAFFFFF9FEFFE9F0F7DCE7F0DDE7F0D6E4EBD6E4EAD6E5EBD5E6EAD5E3E7D3E2E7D0E0E7
CFE0E8CDE0E8C9DEE5C9DDE5CCDFE7CADBE3CADCE5C6D9E5C3D7E4C4D9E5C3D8E4C2D8E5
C0D7E4C2D8E5C4D7E2C2D5E3C1D4E1C1D4E1C0D3E0BDD3DFB4CDE55278A806387E255A95
81B1D4527E9F648EAC85A5B8A9C1CF95ABBA9FB7C4BBD0DD9BB5BF9AB7C1ACC7D18AA2AC
87A1A9899FA9899EA78CA0A7869A9F8A9FA2849B9B81989A7A92966C8587678283637C7D
5C79775A787959777854747451716D4F6F685070694E6D68536F6A526D694F6B684E6B64
4E6A604B695E48665A476457475E4B22A41A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0060730D5D270B572412581C10
5F24156C3F2F69504371625B6A5E5F63555B60535A64565D62555B5A4D555C4E5669535B
5E3B4377434D661D2875232D82303772192077171E7521268E4B4E864E5190646884676B
7E6B707F747783787B84797A83797B837D7E7E7C7C808180808382858A88848D8A889190
909A9E798AA10B266202257E012489002685083579678DAE8AA0AAC6D4DABECED699ACB8
95ABB7AABFCABFD1DCB9CBD3C6D6DBD3DEE3E6EEF1F3F9FBF8FCFEDEE4E8DDE4E9FBFDFE
FBFCFDF6F9F9FAFFFFFAFFFFF5FFFFE7F5FCD7EDF6A5CDDCA8D4E3DEF6FBF8FFFFFBFEFF
E9F0F3D4E1E6DCE8F0DFEBF4DBE5EEDAE6EFD6E5EAD8E6EBD6E4EBD7E5EBD4E3EAD0E1E9
CDDFE8CADDE7C8DDE7C9DDE7C7DAE4C7DAE4C7D9E5C5D8E6C4D8E6C1D7E3C0D7E3C2D8E5
BFD6E2C2D6E2C3D6E2C1D3E1C1D4E2C0D2E0BED1DFBFD3E1ADC5DC4A6E9708356C295A89
6A96B0A4C8DB91B4C88DB0C0B4D2DFA8C4D585A1B0ABC4D096B2BD7797A27E9BA67D97A2
7F98A196ACB58DA1A99AACB4B3C5CB9BAEB292A6A9889DA07A9296728B8F6B8787617C7D
5E79795B78785C79795574724F6E6952706B51706851706B51706A516F6A506F6A4F6C66
4F6A604C675D4B675D49655A445C4B32772800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A309612806521B08582111
693C2C6D514364544B6D615C685D5D61565862555B66555C664F5762484F5438406B4C55
5F3B43804C546E222D721D257C30356A24296F2D338C565B8E626993656D97626C7D4D59
8666717E7277837B7D847A7B847979827B7A838181818381828686818987858F8F8D9697
909B9F8296AB0E2C65022782002891002C8E23549488ABC896A7B2A9B4BDA4B0BAAEBEC5
B2C3CAC9D9E0D0DDE6D2DEE4EBF5F7F0F6F9E9F0F4ECF2F6F7FDFFDDE3E8D8DFE4F9FCFE
FEFFFFFCFEFFEEF7FBDFEFF9B3CDDAC1D8E5DEEFF8E6FAFEEAFDFFF5FFFFF8FFFFF7FEFF
ECFBFEE4FBFFE0F6FFE1F0FADBE9F3D9E5EED7E6EED2E3EBD0E1EBCBDEE7CBDFE8C9DDE7
C9DCE9C5DAE6C7DCE7C7DDE8C1D8E1C0D7E2C3DAE6C0D7E4BFD6E3BFD7E2C0D8E2BED5E2
BCD4E0C2D6E1C2D5E0C2D3DFC0D2E0BED1E0BACFDDB9CFDDB3CCDD63849D8AB3D17BA6C8
628BA5A9D0E7517C9C5985A595BACF6D8FA27090A088A5AF7E9BA46F8E98A6C3CC9BB6C0
819CA6AFC8D298AFB8859AA49EB1BA879AA085999C8BA0A47D9297748D91698586658182
627D7E5E7A7C5D797A56737153706C58726E58726E55716D54726E52706B57736F526D69
536A65536B654F68614C685D455E4F414B3700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EAD106326014B1200522111
6A473869534867574F6D615C6C625F635758665357694B5263343D6228325E2A337B535B
603A4186545C5F1C23712A307E454A7D4F5686575F87535D8A4C577326328D303F761E2C
7F4750877276877D7F8A8081857A7A847D7B84837F888987858A89898F908F9798939C9D
94A0A293A5B6234376032C86012E9A0133973366A7AED0EAB7C5CFC3C9D0C9D0D8D1DBE2
D5DFE5DDE5EBD9E2E9E0E9EFF2F8FBF2F8FBD5DEE5D3DEE5EDF4F6F3F7F9F3F7F9F9FDFE
FDFFFFF8FBFDDAE3EAD9E8F3D2E6F0EEFDFFF6FFFFF6FFFFE5FDFFC0EBFCB4DEF4D7F3FE
BFD9E3B6D5E1C1DFECCFE3F0D1E2EDD1E1E9CEE0E8CCDFE8C6DDE6C6DDE8C4DBE6C5DBE7
C5D9E7C5D9E7C4DAE5C5DBE6C2DAE2BED7E2BDD8E2BDD7E1BED6E1BED5E2BED5DFBDD4E0
BBD2DFC0D3DFC2D4DFBFD0DCBDCFDCBED1DFBAD0DDB5CFDBB5D1DE7192A585ABCA194070
2049786F9CBE1241662C5B7D5881957596A57D9EA98FACB5ACC9D07E9CA6A6C2CDA8C3D0
73909D96B2BE839FA9849EA887A0A78A9FA6879DA1869A9F798E9472888D688285678284
617D7E5D797B5B78795976755976735971705B75725D777457757152706C55716E57716E
546B685369665369634E685E47635441513C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056B6166227004D1903582F1E
6A4F3F69564967594F6F645E6E62606E5B5D69474C622932661921650D1761172081515B
623C457D555C60343981565C8259617E4D577A364275232E8931398C2932861520831721
80383F8E7275887D808C82848980828781818B8C89888D8A8990908C9394969B9D999EA1
9AA0A49EABB94C699605328A0237A6023CA3275CA0AFCDE9C9D2DADCE0E5DBE1E9CFD9E1
D4DEE6E1E8EEE2E9F0DCE4EDDEE6EDE7EFF4E3EAEFD9E1E5F2F8F8FDFFFEF8FCFDDBE2E6
E0E6EBF9FDFFEDF1F4EEF2F7F7FEFFF4FFFFE6FAFFD1EEFF8ABEE33C8FCB549FCFC5EFFE
DBF6FFC4E9F8B7DBF3C9E1F1CBDEE9CCDEE7CCDFE8C7DCE4C2DCE3C4DCE6C1DAE3C2D8E3
C3D9E5C7DBE7C5DBE6BED6E0C0D8E1C0D8E3BCD5DFBDD6E1BDD6E0C1D6E3BFD4DFC0D4E0
BED2DEC0D3E1BED1DEBED2DEBCD0DDBACFDBBBD2DCB9D0DCB6D0DE7594AB3E668C022861
042A624170916590A46E95A8668A97ADCCD790B0BA7C9BA7ACCAD484A1AE75919F84A1AD
6B8895698591718F9875929B85A0A7869FA57F969C7B9197758A916D8489647E82627D80
6380805977775473755775765674725A74745A76765C767458757053706C57746F5A7471
516C67506963546C63516A5F4B6658465A4700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDC0C6C330554270C573822
66503D68564766594E6F625C6F5D5B76585955202464141B7B1C21700F145C10167A4C53
6F50586D50577B5D647D5E657B5058803E487D222D811A238B272F963039871920871F25
7932388F72788980848D888B8B888A87858788888B90949691989B959C9EA1A5A7A7A7AB
A9A9ADAFB2BC7D92B70938890345B00850B53672B3D0EDFFD7E1E9D7DDE4D2DBE4D2DBE5
DCE6EFD4DFE6E6EFF5D4DCE6D2DAE4E2EBF0FAFFFFFAFEFFF3F7FAF5FBFDF4FBFDD1DBE2
D9E2EAF7FCFFF8FDFFF4FCFFE5F2FDA5C4E65A8EC08FC1E99CD0F65EA0D38AC7EDBFE8FF
BEE1FC5889B384B5DBBEDCEDCADFE8C5D9E2C8DBE5C7DBE2C3DBE1C3DAE3C2DAE2C3D9E3
C3D9E3C4D9E3C0D7E1BFD8E1BDD6DFC0D6E3BFD5E0BDD4E0BED4DFC0D3E1BFD2E0BFD2DE
BED2DDBED3DFBAD0DCBCD2E0BAD1DEBAD1DBBAD2DAB8CFDAB6CFDC92B1C3456B8644698E
51789C48738CA5CADA9DBFD1638A9EA0C4D68DADBD5778886B8B9766828D607D87809DA6
7B96A0708D96A7C6CD7C99A290AEB78AA7B06E8990678085647E83637F83617E815B797B
5E7B7C5575745574745371725371725773765A76775D77765D77745E7974607E77647F7A
526D694B6661526C63516C634C695B475B4C1B9D13
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006F38075A3111583C22
644F3C66554767584E6F5D576E535077494A631D1F660B0F761719691314622324764E53
7B5A637F576177485382515B83475182323C7E1A25841C24862930852F377E292E7C3034
86525991767D91848B97929797979A919194949497989A9E9A9CA1A2A5A7ADADAFB1AFB2
B9B4B7C1BCC3AFBDD7214F92084FB41160C22F70B1B9DDF5CEDBE2D9E1E6D7E0E7D9E2EA
D7E1E9CDDBE0DFEDF3DFE8F0D7E0E8E0E9F0E5ECF3E8F0F7CFDAE3D5E2EBE2F0F6CCDBE2
DEEBF5D3E0EFBFD1E5C2D8EEC7DEF8759EC9326FA591C3EABBE0F3BDE4FC75A8D74682BD
81BBEC417DAE7AAED2C0DDECC9DDE3C7D9E1C7D9E1C8DAE2C6DAE1C5D9E2C5DAE3C4D8E2
C2D9E2C2D8E2BFD7E2C0D7E3BFD6E1BFD4E1BFD4E0C1D7E3BED5E0C0D5E2BED1DFBFD2DF
BED2DDBED5E1BCD3DFBDD2DFBBD1DEBAD1DEB6D1DAB6D0DAB8D0DCAFCAD66183939BBFD5
7FA6C6416C908EB4CF496E8C174162567E9660829258768669879296B3BC708E979DBBC4
A5C2CA708D97A0BDC67E99A364818A638289618085688488658184688587688587668385
5A767753727050706D516F6F5572735370705472725976745E7975637E796A878267817E
5A74714D6662516B664E69624D695C4D615120A319
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C470D5E3811573C20
634E3A66544769524B714F4B7A4A486422226C191A650B0C6B1A1C66272773424573454F
7C43506B222D84344073242F85343F8D364174161F7D242980393D955D6289575B996C72
9B70799268708A6C72A4969AA09EA29E9EA39E9FA39D9EA1A2A2A6ACABAFB5B5B6BCBABB
C9C7CAD1CED4CBD4E84A71A90647A5024EB24184C5B8DBF3D7E2EAE3EAEDE5ECF1E3EBF1
D5DFE7CBDAE3CBDCE4D4E3EAD0DFE5CAD7E0CAD8E4C0D0DDC5DAE6BCD3E0B3CAD5B7CFD8
C2D9E5BFD8EE6485A77596B9BCD8F2BAD7EFA0CAE990BDE3A6D1F2A2D0F31A599C0D5BB2
377FBF99CDEEABD0E5C4DBE6CADCE3C9DBE3C8DAE3C8DAE2C7DAE1C6D9E3C8DCE4C5D9E3
C3D9E4C5DAE5C4D9E5C3D9E5C1D8E4BFD5E3C0D7E4C0D7E5BED6E3BFD6E5BFD5E4BED3E2
BAD3E0BBD5E4BCD4E3BAD2E2BAD3E2B5D1E1B6D1E1B4D1E0B7D2E3B5D2E386ABC180ABCD
133E7604306E4977A24E7896355D775E85979EBEC88AA6B27B99A4A8C5D18DAEB97C9FA9
97B9C06F8C9769858E6D868D6581866B888B5C7A7D6480846683856784856B8888688486
5F7B7C5472704F6F6B4D6B6B516E6E506E6E4F6E6C516F6C5775705D797566837F677F7F
647E7C60767459726D526C64516C5F52675724A91E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00885311613D13553B1E
644F3A644C406D47415C221F742E2D6C1D1E6E1C1D601818743C3E73434867333A6A2934
6C192672101C87242E872C366B19228640477235397B42468F5E659668718F5F6A8E5B66
8D4C59702A33AB787CB39CA0ADA6ACA5A4A9A6A6AAA4A4A8AAABB0B7B8BDC2C4C6CBCDD0
C0C4C9C1C3CABEC5D37B97C10E489D044FB53172B9BEE0FADBE4EBDBE0E6D8E0E7D3DBE4
CFDAE4C6D6E1BED0D8BED0D7B7CBD3C7DAE6C6D9E7AEC4D399B2C08CA6B2ADC7D29EBAC7
B3D0DDBFDBED9AB9D492B2CDA4C0D6B0C7D79FC3E329649F256BA88AC6F24781B62B6DAC
74B2DEB6E5FDC1E0EFC6DCE6CADDE6CBDDE8C6DAE5C9DDE7C9DFE7C9DEE8C7DEE8C5DEEA
C0DDEAC0DBECBEDCECBBDDEEB7DCF0B2D8F0B3DAF5B2DAF8AFD9F7AED8F8AFDAFBA9D4F7
A6D4F8A5D4F9A1D0F6A4D1FAA1CEF69FCBF59BCAF398C6F196C4F197C5F45589BE4C85C5
0E4092023185427BB687BAE198C5E378A4BFA2CAE2A5C7DF6F93AB93B6CD6D94A75E8695
7397A270919A6E8D959AB6BD728E9493AFB4829DA2617C81648184607D80698687698588
637E815673734D6C6A506D6C4F6D6C4E6C6B506F6D52706E57757054716D55726F668180
6984838EA6A56C827F58716B536F6351685A25AB22
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00905D17624113533B1E
5D4A345A4132572A215B1812742621661B196D2E2E713E416C3C4261282F5A11186F1C25
791C2575101A81242D80353C71343C8F61688661668E646C89515E8139487D3140A35B68
8F3E4AAA555F96565BC2A4A6AFA7ABA8A9ADA8ACAEAFB5B8BAC1C5BCC2C7B6BBC0B4B5BD
AEAFB7D3D1D7CAC7D0B3BEDC24509A064AB01655A3A7CAEBC5D3DCCBD5DDC9D6E0CDDAE5
C0CED9B2C3CDC4D6DEC1D3DCA7BBC8AFC5D4A7BECE88A2B086A1AEB1C9D4C4DAE5A6C0CB
98B4C0AAC4D2A7C2D1A0BCCDAAC9DCBAD8EC9CC2E4205E9C2B75B39CCFECCEF2FFB7E7FE
88CCEC7FC0E3B6E2F8C8E1EEC9E1ECC8E1F0C4E2F4BFE3F5BFE8F9BAE5FBAFE1FBA5DEFC
9BDBFF8DD0FE83CDFC75C4F968BBF55EB1F452A5ED4E9DEB4190E23C89DD347FD52E79CE
2971C72A72C92369C21E62BC1D5EB71C5AB41856B01954AF1750AD164CAB0D45A40F48AB
0A3FA702339A0B419B1F55A2295EA71F51973362A33A64A32F5A953D689F436FA1507EAA
81ACD18DB6D56D94B09FC3DD7FA2B76E90A06E8B995F7B865C797F5A787A627F81678387
6781855A767753716E4F6C694B69654B6A674C6B68516F6B5875715775705E7C79668381
718E8D849D9E8096955F7775536E6752675D29AD26
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A808633F12563C21
5B422F573A2B54281B53130A6620175B1F197648466B3D41592128621A205D09106E171D
7622297521296B252C8D5D64835C658C616B8F5A668844527F27398A2033851B2BBB6872
9749538E3842853D43C19EA1AEA7ABAFB3B7B5BEC0BDC7CAB7BFC4BCC1C8BCBEC5BDBBC1
BDB6BCC0B5B8C6B6BAB8B4C83D5896063D9C11499AA2C8EDC0D5E2B3C5CEAABDC8B5C7D1
B2C3CDA8B9C4C5D7E2C4D7E29BB0BD8AA1B093ABB6B3CAD390A8B39BB3C0C2D8E3B6CBD4
AEC3CBADC3CCBDD8E4BDDDEF6D95AD97BBD0D0EAFBB3D5EBB6DDF1E3FEFFD0E9F4AAD3E2
7CBBD798D6EBC0EDFAC6EDFBC0F0FDA9E4FD8AD4F77BD2FB6ACBFA61C7FC44AFEE329FE8
2795E72090EC1A8BEE138AEF0B80ED0A7BEF0670E80D6CE60D60DA125AD21356CC1654C8
174EC01748BB1B47BA1B43B61A3DAD1B39A81B39A61733A0142E9A122993112890102890
122C95122E970E2A920E2C910F319209298B072684072782082C84062A8105297E052D7F
0B3483153E8811397F2C539529528C33598B4569914C708F56788E5678865B7C85618089
607E835E7B7D5675724F6E6A4D6D684D6B684D6C694E6C6851706B52716D607E7D688684
7B9896809999849B9E637B7B516B6651655D454B3A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047AD0C6841115B3C21
4A29164A26155227194D15095B21156D3A32623132591E24601C226F20265F090F67151C
6D2B306E3A4078515781646A846069763542791D2D8A2633972C3A9B22328E15239B3F48
BF7A82964D5685444AB7989BB4B0B4B6BDC4B9C3C8B7C0C6B2B8BDB4B6BCB3B2B8B3AFB4
B7AEB2B3A8A9AA9E9FA4A2B052689A08358A0C3D8B90B6DCAAC3D2A7BDC8A4BBC4BBD1D7
C5D8DFA0B3BEADC0CCA9BCC7899FA8859CA4B5CAD0C7DAE2B5CAD595ABB9B5C9D5BCD0D9
C2D6DDD4E6EBCADEE7C6E1F0ABCCDDD8F3F9F0FFFFEAFEFFDDFEFFC5F4FFA0DDF4BAFAFF
ADF4FFA5EFFF95E5FE70CEF854BFF14CC2FA32B5F523AEF411A1EF0C9EF50696F3048CF2
0787F50174EF016FED057DFA0375F5016AF00562E62152CE4441B05C399E64379463318B
692E856E2C82722B80742C7D7228777226726B236D671F68611A605E185A591555581658
53175B4E175E4C156048145F44165E3E155F3A165F371B652D19642415642319691E1A6E
1B1F77131D7710237B0B237C06227905227304226A0626670F30691D3D6D2E4F78436689
5478915F8090597C83517275517171516F6E4F6D6B4E6D684C6C67506E6C5271705B7B78
8EACAB9AB4B4859EA15B7577506A6750645C444A37
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB4106B3F0C552C12
4E23134019084F29175123126C34255C1D166522226C2428661C217023295A0F1467262C
80545A73555C735F677A676F8C67706A1F2B8216238F1E28A3363E8511198E1D24832F34
B07C8182585DA78186B6A3A7B0ADB3B0B1BAAAAEB4AAAEB2ABADB0AEADB2AFAEB3B0ADB3
ACA9AE9F9EA08E8F9089919B6179A1062E780A357B789BBF8AA1AEA2B4BDA6B9C0C1D5DC
C4D9E0A4B9C4A4B8C3AEC2CCC0D5DCB9CED4B7CAD3CADCE8BDD0DDBFD3DECCE2EDBDDEEF
B3DEF4C7F2FDCFF9FEC7F3FFC4F5FFC9FCFFB3EEFE89D6FB6BCAF449B7F032A8E837AFEC
26A1E21E9FE31CA3EC0D99E90B9CEF099FF1079FF108A3F6019BF4009AF6029AF90092F4
0391FA0283F30281F40586FA047FFA087AF8266EE96D51B7AF3980C62A5FC62250C92450
C71F47C81E47C81D44C3183EC31B3DBE1A39AE0E2DAE1330AA132FA5112DA3122E990D28
910A278C0828910C2F8E0C2E860A2C810D2F770D30701237660F37620C38650F3E600F40
5910465413504B15533C14562D11552411571E135B13135D0B145F07175F051C62042062
08266318386B2E517943678650758852737E51727552716E53726D577471537270537373
75959798B3B689A2A659727648636251645C3C7F31
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055B915723F0D532007
5524134D231157311D61311E6523165A09065B0809782C2F632023703436622F34805259
764853663E4A7A5E6879646D8A686F6C2D3781212C80141CA03D427D24288B4144956466
A68F91A49699A59B9EA8A0A5ACA6ABAFA9AFAAA6AAADADAFABACAFA7A8ACA5A6ACA4A7AC
989CA192979A8C91958491986E87A50628690A31717091B19EB3BDCCDBE0B8C8CEB4C7CF
B3C7D2A7BCC7B1C5CFBBCFDAC3DCE6C8E1ECCBE5F2CCEAF9BFE6FCB8E7FFB5EEFF74C3F6
53B4F541A6E550B5EF3CA3E2339EE039ABEC259EE81399EB0C96EF0693EF0492ED0792E9
0F93E71897DD27A4E226A0DD29A9E528AFEB23B3F31FB5F81BB7FE15B4FF0EACFF11AAFF
0DA2FF0E9BFF0D96FF0B8AFB087AF20E78F43666DB873D94C92552D61B32D2172BCF162A
C30C20C50E23C40F20BF0B1CBC0D1CBC101EAD0713A50413A30816A106149C051390010F
8A010F8C01109608198F031287051281121B923C459F5B638A424F7115287E0A1F860519
87051B84061F8006237906266C0829630A2E580A324909363A0839350F46260D4B1D0F53
15155C0B1861041A610524640E32652649733F627E50728158787D597878547271567575
7494948DA9AC819A9F5E787C46615E55685E2AAD25
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00733A08571C06
5B2313592A196333235D1F1262120B6B13105E0A09712B2C5924266F4548724C50703B46
671E2C66202D8E606A6C4D558263698E6067803842711D2387414497666AA484889C8B8F
9A93979C989C9E999DA49DA1ACA3A8ACA6AAABA8ACA8A6ACA3A4A9A0A1A6999CA29AA0A6
949CA08F989A8894968393997E95AD0C2E660A336E7295B49EB4BEC5D4DCBFCDD7B4C5D2
B5CADABFD9EABEDBF2B8D9F6AED9FC95CDF97ABDF161ACEF3B90E0308CE3238AE41186EB
078BF3068EF60B94F80891F5028CF00695F70193F20195F10596EB119EE92CAEED54C5F3
7DDCFAA0EFFFA4F7FF97F7FF75E8FF5BDBFF3DC5FD2CB9FC1BACFB0F9EFB038AF30586F6
057FF30172EE056EED0460E20351D4064ECE324EC1772B7DB51740C11225BB0C1CB7091A
B3091AAD0516AF0818AD0817A205129F08149707139104148F031294051492061383010D
7C030E7A010D7B020D7C020E70050FB1696EDFB7BBBEA3ACCFB2BCB383906A1321820715
88040E86010D86010E84020E81020E7D02107802107603147105186C051E6508275B0C33
4D0C3B3B0C42280E4B1A15570F1B60081F6305225F1334663257785176885A7C83628082
728F8F88A4A76E888C5672734966605B6E6322A41C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00723209591804
612514662F2153140A6A1C16630B076D1312590C0B703A386A424371484C643038702732
70111D680B158A4D54815C64856B748D737B6E484E8D6166937276948187988D95968E97
9991999B9399A1979CA2979DA79DA39F9AA09B9AA09A9A9F939498929599959B9F959CA1
8C9498909C9D819293819497849BAE1D40721947828DB6DEA2C0D8B2C9DEB8D0E8BAD7F5
AED5FD81B4EB5C98DC4385D82C77D7146CD8096AE00971EC0671EF0270EF0273F30278F6
0182FA0087F8028DF70190F50194F6059CF910ADFE1BB5FF33CAFF45D2FF54D5FF66D5FD
68C8F66CC3F550ACEB349EE71C92E9128CEF077DEA0879EA0772E20868DD085CD60D59D6
0F51CB1247C21942BB233EB42230A2282C9A3E25877E1F66A81134B0091CAE0819AB0617
A504139F0110A106149D0B16860A118523288F3A43893645741727780A1B7C0A16721018
78282F681C255B0C1664121C5D0E1A905261976E7C502F42776070D4BFCC7742506E0D1B
74040C77040D78030B79010B78000A7C020C7B03097901087A010A7C020B7C030D790210
77031772061F650A29570F35400E402E14501A17580B1A5D07225F0E30603C6080628595
7393988CABAE6480824F6A684B665F5E6D620ECE0A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0079350F581706
6C2D1F641F165D0C0869100D6209056C201D66302F6C4946674645562328631B24863039
700C15720C14772D359671798B78838B7C8787777F87757B8C7D848D838A9089908F8892
928B94988F96998F96978D94958E95949097908F959191968F8F958E92988D9599969DA3
929A9F93A0A287989B8D9FA693AAC13D61990C3E8B5F95DD568AC95A8BCD669BE0417DCB
2C6BC70F51BD0950C70651D00457DC0262E90064EC0067EF006BF20171F40378F7047FFA
078AFD0A92FF0D97FF0F9CFF0B9CFF0C99FE0694F80791F3098EEF0D8AEE0C85ED0D7FEB
0E7CE8157BEA1471E3156ADD1B64D9235DD42E55CC374FC23B42AD443AA04C359A553598
603793632D846A287B7627777A236E7B1F697E1759971545AA0D28B0091BAD0617AD0817
A80716A406149E07138F121ABE7072DEB6B9DCC2CBDDC3CFCDABB888505E5A1722BA898E
D7BDC0CAB2BAA48B91C8ABB1865D6A4F1D2E9A7684AD95A28E8390C2BCC78A6E7C561E29
793A3E6E2D315C1317610E1465091066040B6C040B700208710006750106770106790108
7A010B7B010C7A020D79031273051C670A2A530F35360D3E1F12490F1652051E571E4472
749EBA8FB5C465848856717049615A57605300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C391162210E
7531255E0C07660B096C141163181276403B6F4F4A6A53506C4F4F5F292C5F0D138D3238
73151C71171E6D2C348B6B74887B84847982847982837780857982887C858D838C8C858E
8E87908C858C8E858E8D848C8F868F8E878F918D9492919792939895999E959CA2979FA4
98A1A895A2AB92A6B781A0BD6B93C73060B001339A0539A50D44AF0541AF0850C20650CB
033FC20134BB0138C2013CC8004CD7076DF40473F8077BFC097EFD0B80FF097EFC0B83FE
067DFA0379F50274F10173EF0272EF046AEA076BE70865E11264DF175AD4245AD23257CD
4457C8514FBF634DB97049AE74409F803E998334898E3284952D769F2F729824679B2567
98216197236091225E8A205C8A24628425637B215F892059A3183FB81029B60818B90B18
B80C18B30916A60B189C2431F9B5C0E1B7C8996B858A6178CCB9C6CEBFC85B424CCEBDC6
C6BAC78A7286B29AAACCC5CE948893786471CDC0C9AC9FAFA79AABC3BECC9086948B7882
C5B4B8BAA9ADB59EA1B49398603239A36B75661F2963030E6A01066D01066F0003720106
7502087401097701097C010A7F010B7F031078051668051D5A0C2C44123F24134D0F2163
1138755885B07EA4B9617F8351666046493800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C6C0B6E3118
651E11610A05630C086A211A74393172443E6D4944735451634544703C3C621012711C1E
813D3E794748825F657E6C727D737A7F757E7D727A8377817E727B80737E857A84847D86
877F89887E87897F8890858D93878F938A919994999191969A9DA299A0A599A5AD99A9B6
98ACC2829DC2577EB51E529D0F4CAB0945B1012FA50126A00024A0002CAB0345C50650D4
0037C3002EBC053ECE064AD80459E7096EF90372F90473F80470F30167EC0462E9035ADF
0558DB0B58D90E51D0104AC61C4AC12C47BB3D48B7544AB56644AA743D9C863E9794398E
9F3485AB327FAD2D79B02F79AF377A9C3272953676923C7E8C3F828A478C7D4A926B4590
624A965246944B4D9C454EA23B4AA43649A83147A74D48A4883378BE1D43CE1727CD141E
CA121CC4101BBA111EB01C2EB33C52A039537E203C6A263EBEA6B2D5CED6776874CFC1CD
BBA5B6632A46662B45D1BBC89A939E968E9BCBC0CE634059552740BFAAB99B92A09B919F
B7ADB653435292828FBEB3BD584752CAB2BE7445555D08176701076700036800016B0206
6A070A6D10166E08107A030D7C010A7F030B7A010B7B030F7C07167609236311373F154B
1C1D621132754C75A47394A9556A6824A72000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003A9B026C2E0F
560D025C090260170D743B307A433C7339326028227F554E55342D784D495D221F6B3331
89676779686A786B71786D757B72797970787B70797B6E777D717B776B767A707A7A727A
7D767E857B848B808791848A9B8F959D959AA09DA29CA1A89BA5B394A6BE7C98BC567CAE
315C9E1747990B42A40540AD0441B6043EB8012CA600219D0024A4012CAE0749CC0D5FE6
0855E10349D80348D7024BD90657E5045BE9045AE50757DE084ECF0C45C31841BB1F35A8
2D319D4234995432906130887936898834808F30799D3079A62C73AA2F72B13D7CB24686
A546899C4C938D51998A65AE786BB16571B75175BB497DC24282C82E76C6257CD1218ADF
1B90E71993EC118EEA118BEF1288F20F80F2137BF1256CDF7451ADC32F61E4283AE1212A
D91A25D11823CF1D27C71D2CB01B2BA02C3AB1646ECEA7B0D5C5CFD6C1CE765565D3BAC9
C7A5B775243F732037D8B5C2A699A7A194A5CBBACA632E475D192FC5A1ADA993A276556B
CFB3C289748381727FC2B9C4544452C5B1C07B51625F091A6B01096900046B0205690308
67181ACA90926F232D720815760A1072070D72020B79020C81030E870513810516750C29
5A18482F206211286A466891556B7525A72300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0049AA0C6C2D09
5710015C140572362571392D642018772B23651F18824E4672524979605A7B625D796361
7A6E71736D73736D74706970726B71786F77736770766872746771756A747970797B727A
817980897F8890858E9589919D939EA39FAE9EA8BE849ABD5477A82F589B134496073B9A
0438A00338A40334A4012FA40034AE0136B40638B6002CAD0430B50336BB0546CD0758E1
065AE60751DE0748D40946D00440C80D42C51C3DB82B31A1422E93522A84612577712470
7C22668722639126659329669C326F973A7891488A855199795AA36F66B0646FB7607CC2
577EC15884C06698CD6FACDD75C5EE64C8F157CDFA48CEFC44D2FF34C4FF25B8FF15ADFF
0DA9FF0CA4FD0B9DFF0892FE0787FD047BF70675F30F61DC5348ADA92862D31D34CE1120
CA101EC30E1AC2121DB41520AD3940E8A9ADE3C6CCDBC3D2C79DB493506C79354BE1BBCA
C199AB79223A802839E2B9C4A48D9DA08A9DD1BFCC6B42535D2939CBADB8A789995D283F
7E4F60A98E9BBDB2BCBEB5C1584553C8B3C17C5162650C1D71020A7000036D0105670408
5A151AC9A4A87038436A10209A4951A25A6168101A6E0610750610840A1589070F8A0512
850E24691B4831205F12296138536C22A72700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B1136A2A06
5C1B08672916793E2D67231763100791392F65160B6C322779595078696379706D777071
7772786D666F6C666D6C666B70696F72697174697174667070626B6F636D776D7580767E
837C848A858F8F8C999293A8868FB1687BAC375798164292083B99073EA60438A70336A7
0032A20132A2022D9E0530A60738B10437B4063BBB0333B90331B80430B90332B90C44C9
0945CA053DC2012BAE0123A1011F9520208A5E2B847A1E69891A5B8E1B578A1B54892660
80326F6F3A7D684E975A539F4F5AA74268B7387AC8348CD8339AE435ABED33B2F14ECBFB
72E3FF90F2FF9BF4FF98F1FF7EE5FF55C9F931B0F226ADF61EABFA109AF3078CF20180F0
0381F4037FF50074EF0067E90161E8005DE20058DB074BC9393AA18D1F5FBE122EC30E1F
BF0B17BC0915BB0D18A0131EE1979EE5C9D1C09FB197597487304F861D3B95374CF9BCCD
CB8CA07E1932963447F0B7C4A5758A8C5971DEBFCDBEA6B3B6A0ABD1BEC8987585976274
C599A75F4451A3939FB7A6B466505ECDBAC67F576665102175030D770106710104670307
58161BC6A4AB6A39485E10228F525CB98B9454162385414A914F57721824850E17940E16
960B1787112E5A275D192362183156327A3800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDB0C632200
5B210976402B6929186C190F75140D781B11813727814E3E76594E746661776E70777177
78717A756C766760676963686861676E666E72697074656F75646E73656F766C74807A84
818291848EA56D7FA4405A911B3E870C368F04319704329F0131A40130A50130A50233A8
0236AA0539AD0334A7012CA00535AC073AB30839B5072DAA0B239E101B8F19137F23157A
342F950A1A85011A8600167E0415761D106764256E782464783073693C84513E8C3D4698
2B50AA1E60BF1D80DC2096ED1A9AEF26B2FB1AB4FC23BDFE30C5FF30C0FE29B7FB24A9F3
2DA6EF2696E32699E6259BED128BEA0982EE047EF10279EE0279F00170EE006AEB0066E9
005FE10267EA005EE40056DD0053DA0157DC0357DB0347C6303EAB84256DBD1437C70F1F
CA101AC60B15C10F19A91D26F0ADB6E1CAD48D6879955469DA91A3D3788D96253CC35066
AF39509F142DA51E34CB5A70A2354F8F203BBB6379D492A7B88096CF95AB964B6283364A
D59FADCCABB6CFAEBC916679855D6ECBB6C0B39AA48B4D5B6F09167A030C7701066B0407
632528C3A9AF6C4D58521C2983545FB58F9B4D1F2CB7919CB398A19C6B776F1F28801922
9317228E142D6326561F256708204D343E3E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00672B02
6B391C76462F6C2A1A6C120A7A150D6D1408925443916D5C755F55665955776E6F726B6F
766F77736B765C555E665F686B616B6B626B71676F70646C776A74756D77787685717892
566A912C4A8310388207348D033194022F9A012C9A012B9C012CA00331A70333A80233A9
0237AE063EB40836AB032696112E9B182E9A2929902D157336095B46084D5F0E496D124B
601B5C1F0D5F041877001B81021D85142B913444A72E44A6224DB21860C81474DB198BED
1995F80D8FF814A3FF13A7FC0D9EFB12A3FE0B9EFB0792F6048BF20182EF027DF0027CF2
0275EF0271EE0273ED0175EE016EED0068EA006AEB006AEB006CEB006BEA006AE7016AEA
0066E70067E9016AEC0267E80162E30162E60160E40558DB2E52C5803685C31E44D41321
D8141CD5131BD2151DC01A26E17787F5C1D0E5C2CFE8BECBFBC1D1CE6D85AC1C34BA1327
BA1123B80C1EB50B1DB40E24B30D26B00E26A61026A61B349F1A35991731961028911024
8C1F32A0455A953B507C1B31964054B87D8CC798A5B06F7F6D09197C010C7C01066F060A
804749C2B2B7C0B1B984646D8B6D75A68691532A37C8ABB8685461997B8BA8828CD19CA6
7C223184193461275920276A051D4F18612800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A3F0A
6C3D1A6E40277439256917087A21117A31209266558E7569817269685F5878706F71686C
756C746F666F4B424B575059675E686E646E726872726C7573727F6870874B5C821E3871
072B76042D86032F91022E94002893002896012A99042E9E012FA00131A30433A60633A7
0934A80F30A11B289121136C3C17644E11586B1A5970134A6E0E3E660D3B5D0C3F54114B
522D75252B870626950129A2022DAB023CBC0B56D60B63E20E71EE0B7CF50C87FC0A89F8
067FF1037AF1067DF2057DF20072ED0070EC0073F00069EA0067E90066EB036EEF0069EA
016CED006CED0172F10174F00376F10277F0037EF40281F20387F40389F40A90F80489F5
0287F5068DFA0084F50180F5017FF6037FF70177F30470EF2267DD7749A3CA2957E61E2E
E91E24E31C20E01B20DB1C28D02A3DD5556DE07A91DB7792C6506DBC2744C6182CCB1421
C70F1AC10B18BF0B17BF0B19BF0C1BBD0D1AB70C19B70D1BB50B1BAF0A19A30412A00613
9D091897091A9407198F03148C081A861024871B30861A2C7F071583010A8102076E080C
AD797DAB929C8D6778764A59AD91979A818A5C3C49CFB9C5B4A5B0766271B09FAAB1929F
A66173811F3B6223542526670820510D921C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00647609
6D350E703D2086503678381F74331B996A55917565826F667B6F6976706B6861616D6568
6F676D71686F5850565A54596D69706E67746E697B666A8343537718306606246B012479
012887042C91002A91012A94012A95012A96012A98022B9A032D9B072D980E2A931E288D
31207D401567571458620D426C103B6B113E5E1448501550380A4E290D5B1A116A141D7F
13349E0C3BB30130B10538BF0942CB0341CB0855E00760E80563E80261E50265E70160E1
0159DA015ADC005ADD005BE0005DE2005FE30265E80169EC0067E9006DEC0073F00175ED
027BEE0484F10687F20A89EE0E8EEE1492EB1B9AEA21A5F020ADF417A8F01DB0F11DB1F8
12ADF90FAEFE09A9FE0BA7FF07A0FF0B9EFF0A94FF0B8AFF1D79F47866CDC83671EC243A
EF232AEA2127E31B24DF1923DA1927D41B32CA1B35C91B38C81633C50F28C50E1FC60F1C
C30C17BC0A15B90812BD0B15B90A12B80C14B30811B80C15B60B15B00A14A3030E9C020C
9B030E97010B98050E92010B90020E8D010F8B030F88020E86010C88030C81040A6E1217
CAA0A38866736121396A243ACFA7B3C4AFBB816D78BEAFBA82767FC4B9C5C5BAC6957784
AA647690243E731F473422590E1C460C8E1700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048A809
6F3004692B0D7F4A2C8051348A634A8C715E8674667C6E646D605A746A67504747665D5F
696366716A706A6469615F66696B7764698248527B192D6305216403217302237E022484
02268A02278E01268F02289302269303279105268F0B238B1621822A1C7444196660195B
73154D7A1142761341691A47542256311A5E212478162B8A081F88051E8E032397032FA6
0B46C00E4ECA0035B70639BE053ABF0136BD0441CA024BD20045C90047CA0149CD004ED0
0152D20056D5005BDC0061E30065E60571F1006FEC017AF20382F5078BF60890F21192EB
25A2EA3DACE858BAF16DC5F383D7F895E5FE9DEFFF8FEDFF77EAFF58DAFF56E2FF3DD0FF
20BCFF11B0FF08A8FE07A1FD0498FF038FFD0280F90278F9096BED4A5ACC9B2D77D21B3B
DE1927DA1422D40E1DD4111ED1121FCC1020C50C1CC70D20C60C20BC0719BE0A1BBE0C1C
BA0916B70814B30812B30914B10811AF0811B00711B10712AF0812AA07129C020C97010B
97020D95040D8B01078900088801088701078602078200068301098201097D050C772227
D2ABB0BBA2AB9E6D7F6F233A954E63C792A6916C7ED2BAC7B0A0ABB8A6B6C4B5C3D0B4C0
AA677897253D841A354E1D40251E3909C70A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052AF0E
7129026D250A874E338E664C8B6F5883715F7B6D618173696E5E5773635F4E3E3E625455
6B61646F666D79758064677A4C58781C2F63081E64031D6E021D7604217F042181021F80
02208302228A03258E04248D051F850E1B7B1E166B37125E5615566F15497B1540791542
6D1A4C591E58402065231F6D122680092D930633A5083AB2032FA8052CA6062EA8032FA8
0437B10944C00032B20029AB0126A60026A50132B30346C80146C70049CA0657D8045EDE
0262E10167E5016EEB0478F4017EF50288F8018EF70699F413A4F233BAF652CDF97AE3FE
9DF5FFB5FEFFC3FFFFC6FEFFBEF9FFABEFFF8BDFFA69CAF648BEF52AAFF216A2F00D9AF4
0390F5028BF90286FA007FF8027DFA0275F8016BF10468F20560E72558D0683B95A92156
C01534C3112BBE0C24BE1126BA1126B60F27B20F25B10D26B00E25AD0E24A90C23A70A22
A60A1EA60A1EA50A1DA3081CA20719A30819A50818A50515A30615A1061696010D95030D
9905108D01098300068101058000067F01077C00047B00067B01067B0107750209711019
98535FB48392C78EA07A2236790A2182162E7F2239C78196D19CB0966C80C5ABBBB597A5
B26F8095223984122757142811C80D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BB613
772B00742A0D763D258C695188705B81705F7F71657C6D6479686177655E685552615151
6F62676B63716465802E3C69081D5A01176300176D021A77011A7A011B7D031A7B001271
021572051D7D081C7D12187122105E4211535C0E426E0D3878133B711A42602355452465
27217114257F09288B0630990536A6053AB0063EB90A43BF0536B000249E011E9A001B96
00219D053CB90237B90026AA0024A60026A80031B5044ACD045ADC0363E4046CEC087BF7
027EF50486F9048FFA0799FB07A1FE0EADFF15B5FF24C5FF3BD4FF51DBFF66E1FF6AD8FA
6FD4F961C4F452B6EE3FA5E4329EE52095E61593EE0B8FF2068EF4078FF90385F7027CF5
0176F30274F3006BEC016BF0026CEF0164E9025DE1035CE10156D90B51D02843AE583083
7824638220597D1F577822587425596E1F576D20586A1C556D20586A1F56641B53641A52
671B5068194C691949701D496F194474184279163D7B11377C0F31811030840E2B870D26
860A1F7B061675031173020D76020D74020A7001066F01056F02066E01056E01066F020B
750819730F2378172A7E0D1D8704129106178F071B8E11288F1E37873147E7B4C5E3B0C1
99405591172F76102729881300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7D36036D2A0884543783664D826B587C695A7A6B5E7D6F657C6C637263596F615A6F6365
6D6674484D6C16245503185C02196803196E021671011774011A78021B79051A76010C63
070B5F151060240B50400B455C0C3B6B0C336C123B601A4A481F592E21681723770A2786
05299206309E0432A20535A60837AB032FA6012CA70233AE0330AA001E99001894011A98
0127A80842C40341C7012FBA012CB6053BC40442CC0452DA076DF10679F90483FA0792FD
099AFE0B9FFF0DA4FF0EA8FF05A2FE09A7FE089FF90BA0F7099BF20C9AF30B98F20B94F1
0D94F40A90F3088BF50585F60480F50581F7027BF60177F50278F50274F30170F00067E9
0063E60161E3015EE2015EE3015EE0025CDD0155D40355D2014FCD0249C9094BC21741AF
2539A02A35982B399B2235962136961F35951A31931B2F931B2E911E30941A2D90192C8F
1C2E8E1B27871C268222298223267B2727782D277430206E3320693A20674423674A2361
54285E522352501D46491033500D2C540A2155061657030F5B030A5C03096002076A0106
77020E78021075010E7D010A8A020A94051094030F9907159908198E0E21AA4157A9455A
9D223793132C6D193A264F2800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C49107A411989644379634878645075635278685A7A695F7A685D6C5A506E625E676470
353C5C08194D01155902196702176B02176D01136A01156D02197104186E0A1364180C53
2D0A464C0E3F5A0930620A2F5F103A4B12463318591D1E6F0E2580082C8F042C96022D9D
032FA20330A4022EA201299C001C8F00188A00198C022DA20331AB0022A0001D9F0329AF
002DB60648D00450DA003FCE013ACA084DDC034CDB0760EB0979FD047FFD0587FF0991FF
068DFC0184F70285F90080F60183F80287FB0184F80283FA017EF6017DF70182FC017EF9
0179F6027BF80178F70277F70072F10371F2016CEC0268EC0267EA0466E90162E5015CE0
015CDC0058D70155D50257D90156D40256D30050CC014CC7024CC80249C70147C20346BF
0645BC053FB8043DB5043DB4023BB0053FB2043DB3043CB30238AF0437AF0333AA0435AA
0435A90231A70431A5042FA2042F9E042F9C06319A062D95062B93072B9109298F0C298B
0D288210287C14257517216E1F2167271F5E2B194C2B0E362E082634061C3F0516550515
6D071973031573010F7B01098D080F93060F91030B96040E9E08129A06129A0A19990D1B
9F14228F19326027521E184311901900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
3D9E02764016866440756042705F4670624C6C5C4B746253705D4F6B5E55605E64252E4C
05164A02175C02176601166902156A03166A011366041466081360120B4F2C09434B0B39
5C0A2F620C2F58113A40124A24115913186B081E7C05278D042E9704339E0331A1022FA3
012EA4002BA200299E01249700168700198A0020920536AD033EBA053ABD002FB70132BE
0136C5054EDA0E6AF3045BE8074FE10448DB044ADC0961EE066FF6006FF40374F90070F4
026FF4006CF2026FF6046FF7016DF20170F4006EF00270F2036CF2016BEF016FF1006AEE
0066EB0067EE046FF1016BEC036AE90264E40160E10262E2015CDB015BDB0159D90255D6
0155D20155CE0152CF0253D10053CC0151CA0151C90350C80350C4014BC20148BE0247BD
0244B70140B4023FB20341B20341B0023FAD0441B10441B10340B0033DAD033CAA043CAA
053CAB0338A70337A60335A30233A102329F02329E01309C012E9A022F9B022E9A012C95
01299201299102289004289003278C06278709227C081B680814550B1048110B3C260F3D
3F123F4F0E355A082471071B8408158B04108D010B980510A70E14A2080EA0070D9F0B12
9209177D1C3E4429620C1A4F155A2600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
50B00D7B4612805E33735F3D6B5B406A5C43695A426C59446B5B4E5854571B253D041643
01165302175F021463031467011162031261040D57110C4D23063E4108325A0B2D5D0B2F
500E39340D44190E520E186B051C7B03238802278E022A94022A96002A97012B9B002CA0
012CA4022FA70230A8022EA700289D002A9E0134AC0343BF034BCC0850D40342CC043FCC
0542D1034DD80B67EE0C66EF0146D50039CB013BCC0245D4045AE60160E90262EB0263EA
0162EA0160E80162E9005EE60162E80365EA0162E70061E5005FE30160E20160DF015EDF
015CDE0362E20363E40160E0025FDE015CD8015BD7025DD8015DD6035DD6025AD20156CB
0155C70253C50252C50655C60756C50855C10551B90851B6084EAD094FAA0D4FA70B4BA0
0F4DA00D4998104894124A95164D951A4E96164A92164B9216499015468E13468C15498E
14458C13448A1041870F3F880E3E870A3884093885063384043285073689043387043085
042F86032D88022B8B012A8E022C9001298D03268A02238203217B031E73041A6C061969
0F18671A175F2B18514316465C1237710E2B7F071C940A19A50F16A60C109F060A9D0912
8E0C22671E4F2E2C7409215E1D223400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF008C5510825F2D6E59366D5D4169593F6D5B436E5B4B534B4A13192D03143A02174B
02165502165A000F5802115D040D560907471C043936052C4C0726540B2A490D33310D41
150B500A1666031B7302217F012589052C94032C97012996012696022999012A9B012BA0
002CA40233AD0138B3023CBA0541BC0440BB0649C6034DCD0455D70757DB0347CF033CC7
063CC9003BC60351D70653DB0038C50233C30132C30037C5034ED80258E00057DD015ADE
015BDF0058DC035CE00059DD015BDE015DDE025ADC025DDD015CDD015AD80159D40059D4
0058D30159D2005AD2025AD2045BD1055CCF065CCB075CC60C63C90D5FC10E5AB5125BAF
155BA9195BA51F5CA4225A9F265F9D2B629C30659B37699B3A6A963F709743749541708E
4873924C7491507791567E94597F955B7F96587C93587A905A7B9052738A5074894A6F82
51748C5B7F955A7D935E829A5579915378904A6F8A466A893C608231587A355D8032587F
2E547D274C7A22487C143B750C3675063074022A7302297502277802257A022479012279
021E79041F780821720D1E6A1D1C61321A564F18476F1434870E1F990C16A1090FA20B15
8D102A622B651B297507235F0C922000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00788E13896026745A356B573B6A59406F5E4C5E5350181A2B031234011343031851
031759021457020E52070D4E1509402E07324507254F09224209272C0B38150D4A0A1560
031971011E7D03258503288A03298E01289101289700279900289E022DA2012FA30132A8
0237AF0139B40442BE0245C3054ACA0247C7044BCB024DD00250D4054ED30039BF002DB4
032CB3002DB50544CA094ED40036BD0133BC053EC7003CC3044ED30457DB0257DC0258DA
0257D90155D60156D50155D40155D40258D70257D50157D40357D40358D0045ACD065AC9
085BC30959BA0E5AB8135AB1175DA91E5EA62562A12E68A1366FA24276A54D79A2517C9B
578199597F9565869B6786986885936C8894728E9878949C728F95719192719191789597
7D979C7A9399829C9E89A2A38AA5A590A8AB90A7A990A7AA92ABAD8EA5A893ABAA8EA5A5
94ABAD9EB5B59CB3B595ACAFA0B8B896B1AE92ADAB8DA6A88AA4A7809BA07C989D79939B
658289607E85607F8A5879884B6F823B6279335A76274E6F19406813396A093065022965
02266C0226710225740425770425780925771824712F2161531D4D781535950F21A91724
8D1736522B68142B770420580A8F1B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002CDD099566217A582C6C53366C5942655A5121232F04103101113E011449011552
0416590410520C0A451D04333F0A2D500A254607232E082D150A3C070F52031565021A74
03238402258901248901258A01268D002892012A9A022DA10130A70134AB0238AF023BB2
0440BA0341BC0344C10145C5054ACA0445C60342C40146C80248CB0343C80235BA0026AA
0126A90128AC043ABE0A4ED10141C50343C6084FD0024ACB0550D1004ED00251D20051D0
0254D20153CF0254CF0253CD0556CD0456C80758C40855BB0953B0145BAF1C5DA92863A7
3069A03F73A14E7CA25580A06088A06386996586946886906D89916F899271898F738B8D
768C8E799192849A9D83989A869B9D879C9E8BA1A1889FA089A09F8AA29F92AAA694A9A8
97ACAC9AADAF99AFAFA0B7B5A5BAB8AFC2C1AEC1C0AEC0C0AFC4C2B3C8C6BBCCCBB6C6C5
B4C5C5BCCBCBB7C7C8B4C5C5AEC1C0ACBFBEA7BDBD99B1B195ACAE8BA4A77D969B819B9F
738F8F6D8A8A6A85876681855A787C5474774C6D6F45676C3F6067385A66325764284D61
1D445E173C600F335E03285D01276702287304297B092A7F1D2E7D3D296B671E4E8D193C
832049462D6F0E2C790B255A0D8F1A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0028DB0A7F571F6447266D5A4837333506122802123902144401144B00134F
05114E0E093D29082D4408214C08213A08291B06330A0B45021157011868001A75012183
02278B02288E02288E01248D012791022D990130A00233A50437AD053DB4023BB30139B3
023CB6003BB60140BD0140C00341BF023BB90031AE0238B5023AB9023BBB0335B70126A8
0124A70226AB0130B3094BCC0349C9034CCB024EC9014BC6024DC8034FC9024FC60451C3
0650BF0852B80B54B11055AC1A5AAA225EA22E69A03D72A04C799F5E85A562849E6D8A9C
728D98789297708A8C748D90779091748C8C768F8D79939081999879908F839A98899D9B
8FA3A18DA1A092A5A59BABAC96A5A59FAFAFA3B4B4B0BFBFB1C0C0BDCDCCB8C9C7BCCACA
BECECEC1D2D5C2D5D5C7D9DACADBDCCBDADBCADADECCDBE0C8DADDC3D5DAC4D5DAC3D3D9
B8C8CEB8C8CFBAC9D0B3C1C7A8B7BDA2B3B997ACB08DA5A8849DA27E979E7891996E8A90
6B898B658284607C7F5E7980577578516F704E6C6C48676744636142615F3C5C5A3A5C5A
3457563456592F52592A4D5C1C405911355B052D60022A6D052E7F1032882A2E7E502466
5E2D6C302F7B0C2D79122855108F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006A88185A3C13584B3D10151F02132F02153C021544011546071346
150B37330A2844071B430A20270429110A3E040D4F02145E011869011E7502227F012587
02278E01268E012890002891022D9803319F0131A30235A90336AC0135AB0136AC0137AD
0037AE0139B1013AB4013AB6023CB70137B10130A70030A60134AC0138B50436B60027A7
00219F0123A40029AC0440BE034AC5034DC4034DC0044EBA0950B50B4FAB1452A41F559D
2F619F3F6EA04E7AA15A83A261859F6686976B8B92708D92738B8F758A8D728688788C8E
758B8A7B918E8096938398977F949382979591A7A392A9A698ACAA98A9A9A6B6B5B0BABA
B9C4C5BAC7C8BDCCCBD1DCDBD9E0E1DCE3E6DDE5E7DFE5E9DBE2E8D5DFE5D4DEE4CCD4DB
C5CFD5BDC8CFB0BCC4A9B3BBA2ACB5A0A7B097A0A99399A48D929B868B937B808781878D
767E85767E86757A83757A826E747A6E767B6874766674756372766170755F6F735E7276
587172556D6C536A6C51676C51686C4C666848656549676542615D3D5E5A3C5D593B5B56
3958533656503856523755523353512D4F53264A551C405909305D0530720C35831C3789
2033861232850C307319244200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB4116C4D20352D2308132102153402153C02144006123C170C30
390B2549091A3403161A05270B0C4203105501146301196C02207502237C012482012688
02288C02278F022993012994022C98022F9D012FA2012EA40130A6012FA40031A50134A7
0439AD0338AE0135AB0136AD0137AF0239AE0238AD0338AB033BAF033BB50337B4022CA6
01249D02249D0028A0083FB00A49B00C4BA518539E2359973768994D799E5E819E69849A
79909F72899370888D6E84877186887086847089847288867C93908498978194938B9F9D
8A9E9C91A4A29DAFADA1B1B1B4C2C0BCC9C8CBD8D6D4DFE0DAE6E8E1EBEFE4EEF2E5EAF0
DFE4ECD4DBE5C6CED7BCBEC7B9B8BFA09BA296909691888F8780877D777D787276776F71
796F6F786E6B776E6A756C66776E68786E69796E6A7A706A7E71697E6F687E6F667F7168
7B6F65786D637A6D64786B60786B5E786A5D7268596F65556D65546D6558696156656355
5E6153595C4E5B5D53575B54555C56505C554B5C534C6057475D56435D573E5B543A5850
3D59513C59513B565038545039574F39585233544F3352502C4C54183B530A325D063475
0A3D8E0738871130650F911D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADD0B765526221D17061529011534021437030F33130727350A20
4509192F0315120321050B3E031358021767011A6F01207901237C02248003278703288A
002388062B93022894012691012892012996012A9A02299D01289A022C9D012FA00134A3
0135A60034A80135A90237AA0238AD033AAE023AAF0036AA0139AE023AB1043AAF0432A0
03298B0629811438842751913965984F779B61839B6A87956A858C778F93708688708487
74888B6F8687718786768B897A8F8D839894879D97889C969BAFA99FB0AEAAB9B8BDC9C9
CBD7D7D9E4E6DFEAEDE3EDF2DFE6ECDADDE4CCCDD6B9B8C3A7A7B295939F87858C837E82
7D777B7A74787972757A71717C716D7F6F6C806F6786736985736781706283715F836F5D
836C5A806B537B6A4F7D6C507D6D527D6D557668507B6D547D6D55806E577D6D557B6B54
7C6D567C6F57796A527B6C5376684C76654A76654A74634878674B7B694F7C6B52796C51
776B4F75684E7467507066506F67506D664F6B664D64644D5E634E565E4C505D4B485949
445847465A4D41574C3D544C39534B36534A3958503B5A5137554D2C4B47214249113852
0733610A3366172B490AC80B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007B55241F1A1307192C0116320411300E06212E07193F0917
2A04150F041F040B37031453041B68021E7402217C032582032583012383042687012284
03268B03279001269101258E01258E012691012693022695012697012898022C9B0333A1
0233A10132A20134A30135A60338AB023AAC023BAC033BA8053CA3063B98124291244C8B
3E5F8E547092607A91667E8B6981876E8588708688768A8A718684768B8A768C8B778E8C
7F9695809797899E9C98ACA99EAFACB4C4C1C9D8D4D7E2E0DCE6E7DBE6E9D4DEE2C4C8D0
B3B5BCA3A1AA8F8C94837F867D777B7A72757B70747C6F747E72737D716F7E7169817367
7D71627D74647E7462756C57796E5676695472654C73674B73674D72684C72684B74694E
6A5D42695D416960436A62446B6546676144635D406B654B6D674D6A634A6D68506F6B56
6A67536A675269655066624D6A674F6B674E66624966624A6761496C664D6A664C69654A
6762476A62486C644A666146696547686040665C39675D3B6860406661426160415F6145
5D61475A5D49535B484B59484557484153493B53493855483B5A4C314F4327483D214441
1E4248102F3B115B2000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF005F811A21180A0918230415290C0B222504163C0815260412
0D051E030B3100104602195E021E6E001F78012282012385012083022182011F7F022284
03268C03279100228B01238A01238901248A01248C01238E022491012793012B98022E9E
00309F0132A001349F0237A10339A0053B9A073B9017478E2C568D466B925C7C966E8796
748A916D81836D80816B7D7D748786758A88819696809595839594899B998E9FA097AAA9
ADC1C1C0D3D7D0E1E5D4E2E4D5DEE2C5CCD2ADB0B69A9BA087848A77757A737071726C6B
746B68786B67786A647D6F668073667B70607B705F7F71627E7261756C58706851746D57
6D6A526B6A536A684F6E6A506C694E68644C6A654A6A65496C684C6C674B6A6749686447
615D3E656043686445605D3E62604165614465624563614665624864604669674F666550
646651696A5565675267675665665466675266675163624E61634B5E604863664E61644E
62654F62634E5F604A5E61495F62475B593C5753325955315753305752315653305C5836
5D58375D583A5A583D575B43545C455057464C5A493F54433A5343344E402B493A27483B
244639254336139C1400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0047B21436230811191B070F1B1C0915380A152904110F061D
030C2D01113F011653031D69021F7501207D002183012285012083011F80011D7D021F81
01208602208B011E8A01208B01218900208701238802248B00238C022691012A96022D99
013299023596053A900C3F891B4886355E8D50739664829A6C869272878E75888B7B8D8E
7A8E8C758987758A8A7A8F8F7F9393879A9990A2A1A5B6B5B5C3C4C8D4D8C7D3D9BFCAD1
ADB8BE919BA17E848A74757B7471756E6969736C68716960766B5F766A5C776A57766952
7A6D5573674F6F654C70684D716C507570557A755B77705A746D576A664D67644A727056
6E6D546A6A4E69674B68644868654966654865644869654A6361446A65496B6649696547
646142666344666445646243626243605E41606042605F425E5D40615D43615F465F5E48
62614C6768536767556967576465526A6B5567674F63644E65685070745E696E59616552
6366525D604C5C5F4A5A5F485D6249605F485A5A3E59583B59583A595837575433575231
5753315651325250345153394D513852543F51563F4D58434555433E5241354E3D2D4A3A
26483525473430462F0CCD0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005A390D1F1A10130D12280810310914130516060E29
01113700154B051D64021D70011E7701217E01218101218402238503208200197B01187A
011A7F001A82001984011F8A03238D01218901228701238801268B022C8F032D8E043189
0B38821A467F305984537693678395708992788D92798C917D8F937B8D8E7E8F8F839694
8195928398948CA19F9BAFAFB4C6C8C4D3D6C7D2D5B5BEC29AA0A581858D6E70756A6769
6966626969606F6B60726A5E706456695C47665B3F675D3D6860406D64466B6044695E42
6B614471684D6F694E6B684C6868497171517976587670566A664C6F6E516E6E4F6E6D51
6E6A4F6863466763436661426966466867496766496561456764446B66496B6649696548
6965476663446665456463445F5F40646345646245615E415C593C645F465E5C435D5C41
5B5B4062604864624D69685461634D63664E62654C686B5361654D6265515E614F606453
696C5A5E62525D614E5A5F4B595E4A5B5F495D60495A5C445A5E425A5D3E575839565739
595A3D57593F5559414C543E464D374B513B494F37494F3848523D4554403D533D354E3A
2D4A382646322B46311DA31700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005F80153A250923100B2C0E121D0913090D1E031431
011540021D5B03206E011E74001E7702217C012180022284022183011C7F00197B00177A
031A7E021B80011D83012188002088012388012385032684042A80062E78123B75315682
56779363808F708A92788D90768A8A7A8F8F80939482939587999A8396948DA09C9CAEA9
B1C2BFBECECDBCCBCDAFBCC08F979E777C816A6D6D6666626A675F6B655A6E66576A604B
666046625F426663456A6447675F44685F41665E3D6A63406E69486C67496A6347655C41
665F436C664C6B694D6E6B506C6C4D6C6C4C6F70506C6A4E6C6C506B6D4E6A6C4C6D6C51
6C664D6B644768624167613E64603F666345605F40656143656343676244696447656145
666245676244656342626143656445656346666248615C42635F43615C445C5C405D5D3F
5C5C3D605F4163624665654B63654B61644960634A61644B62674E686A566B6D5B656756
646755636755646856676D5A5A614D5B604A5B5F48595D44555C41575D4153593C555B3F
565B40575C42535B434D59444451404A5645404D3B323C2938432D424F3641523840523B
3A513B324B362E483335422B00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DC0B5C360935160526100F110F19051428001636
021B4E02216701217302227A03247E02227E032381011F81011D80021F84011C7F011B7C
001C7E021F82011F820020840021840226830226760A2D6E244675496987648290708890
7387898196937E93907C908F809591899D998FA09F95A4A4A6B6B6BCCBCAC0CDCDAEB8BA
909799787E80696B6B6867656A65616D685E6F6959706A53736A4F70664B6E664A696246
6C674B6F6D506F6D516D6A4F716C51746D526F6A4E6D684B6F6C516F6C536D6A516D6750
6A654D6E6A51706D536E6A506E6D4F6C6D4E6B6E516A6B526C6E526A6B4F636546666347
69634868614468614067603C65603D615D3D5E5B3C605C3F615F3F615C3C635E40645D40
656043656142666344636242626241615D40605F43605F436160445F5E425E5E3F5F5E40
60604160604063634461604563644961604962624C5F614A60624A656550656753636451
61655060654F5E634C5D644C596149586048585E465B5F495A5F49565D46565D44555B42
545A3F565A42535B42505E494856474353472C40322639292C3C2838462F425038434F37
4350383C4E38344B363447311B9D1100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0045AB0E4B220223110B0E162101152D001840
03205C02226C01207301227B022580022381011E7E011C7D021E82021E84021E82031D80
011D8000208101227F03257B0428721539733A5A815E7A90748B977F95977E93927D9190
8899968A9E998A9F9B8B9E9C98A9A8ADBCBBBBC8C9AEB9BF98A0A7787D82696A6C646362
67656174716A7772687972657A73647B75657A75647874617B7662797460797662777560
76756072735D75755F74725E73715C76715B75715B72705A74755E70705C747160757462
7475617576626F6F5B6E6F587071576E70556C6F566F705B6C6C5567674D636446656346
666144666143666140655F3C655E3A63603D605C3E625D405F5C3E605C3D605A3B615A3D
645E41635F42615F405E5E3C5B5D3860603C5F603E5D60415C5F406060445F5E40605F40
5E5D3F5F5F416060435F5F465E5F485F604B65675164675060634D62614C5D5F465C6046
6368505C634C5D654C5C644B59624959624A5A614A595E485B5F4B5A5C4A555844555944
54574251563F4E573F55655047584933453923392C273E2D32473340503D45533F4D5843
49533B454F373D4E3734452F1EA21500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0074451429170B0D1824011837001B4C
03216201226D022273012279032580012482022180001E7E032184032186011C80011C7E
001E7C03247904286E183C6E456683708B997E93978293948B9C9C8CA19E8BA09D90A4A1
91A3A19DADABA6B7B8A9B8B9A3AFB1899192717276605F6262605F66635C6A675B716D5D
726F607C7B7081817794938AABA8A0A5A19C9E9C999C9B9693918B93928A8B8D83818479
8084778185767E80717D7D6E7B7B697A786478776273755F70745D6C6D5B6F6D606D6D60
6C715F6E73646C72616C72606E74607476627175626F73617075626B705C686B5465664F
63644C626349636448615F425F5E3D5D5B3E615F42605D405E5C3E5E5C3E5F5D3F605D40
625F415F5F415C5F405D6041585C3C5A5D395D603D585B3C585B3F5C5C415E5E415E5C3F
5E5B3F5D5C415D5D435D5E485B5E485A5E4A5C604C6165516165505D60485B5F44585D3F
595F445961495B644B626752646A555D624D5B604A585E475A5D48575945585B47545845
4E523D4D533E4D59455061503E50412C40322A3F313349373E533E4959474E5E4D4D5D4C
505D474D563E464F373C49303C442400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF003BA40B321D0B111C2A031B41021E56
022165022471012375012379032681042887032887022586012486032586012081032178
06276C1F3D6F4D6988718B98819697869592909D9996A2A19AA8A791A1A19CAEACA1B3B0
AFBEBE99A4A87F878A696F6D5E605A5F5D53665E51675D4E746E5D868674999A8BAEAFA3
BEBEB8CFD0D0D0D1D6E1E1E8F4F0F9EBE4EFD6D0DCCDC9D7BEBCC6B8B6BEACACB09EA09F
989C9693958C9091879494889294858F8E808E8E7E8C8F7C8B8E7A898B7B868578828375
7F81727A7D6E7178676C75646A74636C71616971606A72626A75646671636A74656A7465
697363657160606B5A5B64506067515B624D5E654F60654E5F654B5D624A5B614A596049
586047576149556148545D47515B4350593D565C41585B43585C46575C46565C455B5F48
595C46575A46575C495A604E585F4D57604F5761515760515B63515C644F60664F60654E
5B624A5E66505D654F5B64505B634E5C624D5E624C5A60495D634D585E49535C454F5642
4B523C5058465B685946564B2D42352C4335344A3A3E5241495C494E5F4E5163544D6254
5668565E68544E533B434B3140462200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA1B3C2407131B26041B43031E59
012168052A7C01247A00237A002581032C8D022A8E00258601248401237E01216E15336B
4560806D82908090948D9C9C93A19F9BA6A49AA5A497A2A3A5B1B3A3ADB0A1ACAD798586
676F6D5F605C615E5469635168624B6E644D786D537F765D85816A7777647374657D7C73
86848189898A949298B2B0B9C5BECCC8C0CFB3ADBBA29EAA9A97A296949B908D90888784
88898187887F87887D8384778083717E8172797B6C777A6A7579687375677175676F7365
7377697175676D7465737C6C7782727782736C78696974666A796B6C7C71697B7066776C
64756A6172695B6E66566A5E55685955665957665855655659685957665852625456675A
5264575263565467595463574F5F505261515362515260515260524F5E514C5C4E4E5E50
4C5D4E4A574D4E5A5157645D57665C5B6A615A6B625B6A605F6D5F5D6858626959686C5D
6C71616F7665687461636E5D636D5B646A596369575D64505B634E565F4B4F59444E5642
4D55415B665748594E33463D2F473A3049393D5643465D4B4F625053645554655950645A
5C7064606F5E535B44474D3134761D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005D3E121E1E1E051B3B031F56
00226909368B002A86012682022A8A043195022C900126830325770D2D6B3450765D7485
74858B818F90919E9D96A3A28E9D9D91A0A199A8AA8F9D9E7F8A8A646B69595D57585B50
6463526C67516E664D6E64496F664A6B61456960426961436E684B706B4E736D54726A55
6A64526B66566B6557706A61726C6877716E746D68736D68716D646F6C616E6B5E6C6A5C
6B6B5B6C6C5B6A6A586E705B6A6E556B6E586B6D59696C596B6F5D6D72626A72646B7669
6D7A6C6F7C6E727E7274817473827673857B75877D6F81795F776E59726B577269566F69
536B664C646147625E45615B3F5C54415C55415A53405751445B54425951405752435A57
4058553E55523E57523E58533A554E3B554D3C554C3D544C3E544E3F544D44575042574D
40564A3F534C3E52503B515038514F405854425A53455A504A5B4D4F5C4E565F52595F52
5D62525D63545C65545E69596671616A74646870605A645358625055604C4D57444C5644
5661514E5D52364A40374C413E56463F5742405743506555596B5D5A695D56675957695F
5D70665F6E6158614C4A4F3424A41300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005E7F182C22110A1B32021E51
002168093B9403389901309103349602349605328A04297021406E4C637B6B7E847A8988
84918D828E8C8F9B98909C9A909D9D8390916E797959625C585B4E62604C6A664E726F55
6F6E526E6B4F6F6A50706A5170674D6D65496E65467268486B63406B633F685F3F6C6245
6D63456D634572674B766951716550796D597C6F5C7A6E5B79705A776F59757058716E58
726E58746F586E6A516C6B506A6B506C6E566B6E586A6E5B656D5C656E6166736864736A
5F736A61766D5D726D59716C56706D4E696549636043605D32544F2546421E423C1C3B37
1C3A3717363316373413322F11312E11312E14322D14302C13302C12302B142F2D15312F
132E2E102D2C0F2D2B10302F1033301D3E3B213E3B28423D31453E3A48413E4D433A493C
3A4D3E35493E28413B1D3A381C3A3925443F334F473F574A485B4A4F5C4D55605361695B
606958616959616B5A667160636F5E687262656F5F5B645456615054614E4B5A47576658
4A5A4F384C42394F4341574A485F4E5166544F62515B6B605E6C625B685E5B6B5F58695D
5C6C625E6A5E5B624C53533313D10900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0027DB0D5237121C222B031D48
01266B053A94033EA4023CA2063C9F03358C0B32722D4B6C5568756E797D778180808C87
838E8A808B8A828E8C76827E626B645B60555D5D4E68634E73694E796E51746C506D684D
69684C6D6C4F6D6A4F6C674E70694F716A4D736B4E746C4E716A4A6F68456F66436F6241
7365417769447B6C497E6C4C7E6F4F80715184735685745985775C86785E83795D80785C
837B61847B627F785F79775F7B7C6471745F6F735F7179686C786B6470685869624D605F
3C53522E4948213E3E1938380F302E102F2C17373124443E2F504A3D5B564D6B65607B75
5C7572506B67486460405C564560583B554E3C554D3A514C394F4A344C44334B42324942
2F483F2C453E2C463F27423C24413C223E391F3A35253E38293E35314137364539374738
3243332B3F3020392E17322C0C28241230292D493F3E54464B5D4C566354677265636E60
5965565A65565D6556595F4D5D644F5D63525C62515B6151545F4D4E5F4F4C615344574E
3C524841594C4860524E645753675A5B6D606170655F6C635C6A60606F655E6F6459695D
5D6C5F616C5B5E6348417F2300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0068891F3D31220D1E3D
052D6E09449E0343AC023EA40637910F34723148654F5D62646A697377747A808077807E
757E7C6E76745E675F565C4F5B5C486B664C71684A6D64436D634373684C70674F67634B
6E6B526C694D6865496E6A4F6F6B4E716B4C6D6748716A4C72674A7569497C6F4E7B6C4A
7A6B4677694278694578684775664472644073654377674A75664A83755A7A6E54796F55
7269517169546A6753686A56696C5A6A6E616972646875676979705264612A413F122D2C
0725230A2A251A3A33314F49536E6672897F8FA49CA5B8B2BBCBC7CDDBD8C3D2CEB5C2BE
A3AEAC8A95947A89836A796E6E7A6C646D5F646E615D655960665B62665A5D6457586050
5965525864555B675A5762585160554F5E524F5E534D5E504D5D4F515C4F4D584C505B4E
535D4E4B5948425443415243364A3C2B4337253E2F2D41324C5D4D6673645D695C5C685C
5965575A65565D63515D604B60634D5C604D5C614F595E4F5560544E5F56445852455A54
4A605750675C586E625F726764756A67756B66736A62716861726760716660726759695D
606E605E66525F603F2DA91400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0E6A4C2226272F
0625590B459A0546AA053D94103670364962545D5F575A53696A6472736D737572676B67
5D61595758495C5A43676346726A4A776B4B7265476B62426E67496F684B6A6348706A51
6E69506762496B66496F6B4D6C684A6D6949706946716543716442786B4B77694B756646
74654273653F72654073654271634070633F6F603D6D5E3D7061416D5F4174664C756A50
7269526D68556265535E655561675A626B625B6B64475A562C4441112A290C2A2524433D
4261596C897F99B3A6BACEC6D2E1DDECF4F2F6F9FDEBECF3DADAE3CBC7CDB0AAA99F968F
8F8378857769796E5C736A53766C51776B507A6C51796B4F77684D806B537C6A4F79694C
7C6F508072597D705B796E5C776D5B746B59726A55706951776E547D7055786C52796D54
73684F71694F6562485C5C43595F48535E4B485746394838384938536050606B5C5F685A
5C65535D655061654F61634E6164505D6152576052545F554D5D544A5D574E625C536662
5C6E6761736B6779716A7A7061716768766E66756D67777164756E63746C637369616F63
636E5E65664E655C3430A70C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B318503C28
17284615468C094091133A7332445B4E54545B5E5461635667695E686A605D5F545B5B4B
5D5A426862426C653F7066426F654375694B7267496961436A65486D694B686346726C4F
6F684C6661446E6A4C706C4D6D694A6D67467065416E613B6D613B6A63406761426F6546
7064416E623D6E613C74664271623E70623B71643D72653F7265406C5F3D7265476F6449
6B644B66644E666857646A5B626A5F4D5D582239360A26220A292522403B58756B86A099
9EB5B1ACBFBCB0BFBEA6B1B2A4A8AC9F9BA09A919691868A8F82828D7B778D7B6F8D7A66
8D785E887255816B4A7C68457C68427E6842806B437F6A41826C42876B448568408E7145
91764A90744D89724F897254856E52866F538672538B7452957E59937B58927D5E917D60
8875598272537E6F51756A4D6D674A67634A63654E5B63504E5B4A4954455E6455636656
61644F61654E6367516266545B62565C675E56655E526460536863586F685A6F6862746F
6C7B77707E7C70817B6F807764756D6C7C766D7C766B7B7668777168756F65736B636D63
6669586B63446D582546B71500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00855E2D
342F3226426F183968314256494D4A535449585C4C6063515E604F595B49595943625E42
6D64436C5F3A6B5E376E66416A62426C634473694A6D674966624469684A6E6C4F6B674B
6F6A4D6A6547676243746F4F6E694A6F67476E633F6E613A6C623B6A65406A65456D674A
6C66486E674971694A7065446D623E6D643E6A60387168407269437169486E6949696446
6A654A686750626554535B4F36443C0B221E0C2B242B4B424E6C647B948E8EA19D919E99
89908E7B7E7C70716C716E67716C6579736B837F748D897B9D96849C93818A82706D6450
6A644A7A745A7C765D736F55635E435E593E5B573A5E5A3867603976663F79653C7A6439
76613578643B7868437B6A4A7866477666476E63446C61436A6145665D4765604D656351
60604D5E5D4966634D6C69507570536A6346686449666852696F5E5A6051626556626350
6568526067525C66545F6B615C6C665E726F5D73716A7D7C697D7B6E847E687B7571817E
78878575848471827F70837C71857D71838072837F6E7D786E7B766A756F67706864685A
686148705B2D68902000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE10
583D1F404147323A3F46463D5251405959465D5E495B5F455A5D415C5C3E5C5A3A615C39
63593267592F675B3069613A68623D6C634074684872694B6C67486763476A674E706D54
6D684C6C66476E68466D68466F694A6E65457367447266417367416E6440736A47726949
73694B736A4C72694C6C64466862446A66456A643F6B623B7069446D6846686442666141
6D684B65654E444C3B2C392E50615A4159533452484F6B5F697C73757E78747871737368
7571647C75677F77657D746065634E797D6A989E8FB1B7ABB8BCAE9D9D8F8A8879777767
7174657A8075687068505D5545554A3B4E413548373B4B35434B2F615F40756C4A776946
73633E726441736849736C516C6A516567505C624E555D4B545F4F525C4F535E51556256
5663555C685A555C4C5A5D477B7961726D54706C536D6A5671715F686C5B656956626856
5F69575E6C5E68786D6B7D787185827389877087847D908E7F93917D928E778C877D8F8D
7C8C8A7B8B89768A85768C86758B857487867182816E7E7B6C7A74656E6764695C67644A
6F5C30678F2000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
5C7F1A473419473E2750492F5A553B5F5C445E5B415C5C3D5E603D5D5D3A4D4E2B534F2A
615529635424635627645A2C635A2D645A2E6B5D356E603A706440736A4A6F6A4F6B674E
676449635D3D665E3C6A63406C65426E65436F6543716745756946726643746844776944
7568437668457567477264456D62436B60416F63416D613C6C613C615833655C37766D4A
70694B6060473D473668746ABBC8C3606E6C57685F5362565F685B6C6B5B74705C74715C
73725D77756073725D71705C6D715B7077637D81728183768385788687798182746D7265
5B675E4758553C4F4F2C44441C39351938311A3A2C2F483648563F67684C766E507D6F4F
746948736C4F7C7A636F7462636D5F5A6A5D55675A56675C57675C5D6B615F6E615F6F62
59695B505C4B5A604B706D5775705A75705C74715E7471606F7061656A5B656F5D667366
72847A7A8E897D908D8092918092927F90917C8F8F869897869998859A98819794859796
8192918496938195927D9390778D87748785768585707C7B68736E60665A6360456C5D2F
66912200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
59780D5337115544255A4F3062593C635C3E635D3F5A57395455385257384A4F2F504F29
6158296657256959276859286759286357246B5B2B6D5C2F6F5F3572643D716844706A4A
6F6A4C6965456965426C67436D67466F68476C67466A65436B62416F63406D603C6D5F36
6E5F3471623874643C7968427D6C467B694276633B76653B73663973663878693F7D6E4A
746A49636144444834898F82979C9660625C65685A6066567177667573607A7661767561
707361727968656E606672666B78696570626C7467687064646F6558655E43524D334641
1F3633142D2C08252402201E0929231C3B32415C51596B5D646C5776715672664973684B
6F6C527A7E6C7982756C7B7063776E647970657B70697A7069786E68756B627064506053
4A5A4B5F68546D705974725C75735E7776647475666F74676D766B79857B8B988E859591
8C9F9D99ABAB9AAAAA95A4A492A1A38897998696968B9A9A8494938093928B9F9D90A0A1
8A9B9B8999988294947E9290788985788984717F7B6E77736B6D63686247756132997734
29DE0C00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6A40045A40155D4C2A6657376A5C3D6B5F41565436333A1F303E26414F374D563C515536
57542C5D54246456266B5B2C66572766572565552669592C6B5A2F6D5D326D603670663E
746B457069466E6A466E69486E694B706A4E746E53777154716B4C6A62416A5F3B6D5E38
69593167592E6C5E326E60346C5D336F5E346E5C306E5E2E6B5E2D6A5F2E6F623572633D
72664365603E5B573B6F69527C766167604B6C69517479656C7262777663797462787563
6E736541504828403C1E3C371C3A341B353018302A162F28112C270E2825223938384C4A
3D514F3E5353425B595169635D7368576A5D5D6B5D676F5F71725F746F557771567B7A63
7A816F7B877B7C8A8272857C687E755F776E50685F4D6258526158536159536056556253
5F6858747765787A65797C697A7F6E8085778A93879CA79E9FADA5A6B3AFABB7B5A5B1B3
A3AFB1ACB8B9ABB6B8A2AEB0A2B0B19BA9A99AAAAA9AA8A99EABAB99A7A795A4A494A3A6
909F9F8A9A9A8798988291917E8C8877847E6C756C6F70616B5F427F643077992600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB40F
613D04604B1C6758306B5B396D5E3F564F33343A22223420203724293F2D455543515B47
595D415654305D552C5F552961562A5F562863592E675B326A5C346C5E37695D35695F36
6E633C7067416D6641706B49736D4F726C51746E55706B517670567973567B75577C7357
786D4F7167466A623D6C653F6E633D70633E6E61396E61376C61356C65396D663F6C6441
726A4A6F69476F65416F5F3B71603A6C613C726F516E725C767A67807E6B7E7A657E7D6A
4C5548283E38203D3A1738341638331B3B3723423D36554C506D6592ABA8DAEBEBF1FAFB
F0F6FBC8D0D798A1A4848D84767C6E6C715E74766171715D6767556D715E7077656B7869
697A6C6D7D7473807A707F796F817B6E847D667D7760746D627069646F676A7466757C69
787E697A7F6D898F7E9EA699AEB7ACBFC8C2BFC9C4BFC9C4BEC8C5BBC5C5C2CDD0BAC4C7
B6BFC2B4BDC1B0BABCADB7BAADB8BAA7B4B5ACB9BBA9B5B7ABB6B7A6B4B49CAAAA97A5A6
8F9C9D8B9A9C8B999A818C8D7B838073786E6C6955766440916F362ADF0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0044AD07
6443096955246C5C316D5D395E563740432B2F3D2A273E2B223B2A233B2C2D4334415244
535F4D555D45595B3B5E5C3965633F6865426561406862436A644469624168613F67603D
6C63406B63416C66456E6A49706A4D746D53756E54746E53746E516F6A4C746D50736D51
746D52736B50736A4F787154777254777052726B4A726C48726C48746F4D747151757156
7B765C797357776A4971603B7460356E5F326F6946706E557B7A64807C667F7A647E7D69
636A585A68595564565A695C5767595A685C5F6B5E6B76687D877A929992A4A3A4B0A9AF
A59EA4948E92827E797E7968817C617972557B785B62644E4B55444B5848505F52607066
819288C7D2CFE3E9EBDEE5E7BCC4C899A4A67E8985777F767C827680867A888E7E999F8C
B6BCA9CBD2C4D7DFD7D6DDDAD6DDDCD4DBDCD0D7D9C8CFD0C4CDCCC4CBCEC1C8CBC2C9CD
BEC6C8C3CBCDC5CED0C0C9CBBBC5C7B0BABDB0B9BEACB5BBAEBABBA5B2B39CACAB95A3A5
909D9E899799869293787D78716F60726448856B3C779A2D2BDF0E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042AA04
705011705B29705F31675C374A4B313947343247352F46342B43312A42312B42342F4437
3A4D3E4D5C4957624B5B60485D614761644964654B64644B65654B67674B6A684C6A684B
6C684B6D684C6F6A4E716C50736D53746D55716B52726C51736D4F726B4A6D6544716647
74674A746749726649746C4F726C4F726D50716E4F737250757252737050757154726E54
756E57756C547A6D507A6B4979683E7261356D6037706645756C507A72587F765F807962
7F7A608A8468948B6C988A6B94866798896C9C8C70A291749B896C99846C967F6C917B6D
8E7D6E8A7D6C8B806B83765A7F704E7C6D4A8880636B6D5757614E5B67555F68556E705F
807F709E9890ADA5A39D98998D8A8B898784908E87A7A49AC4C5BBD5D8CFEAEFE4F5FAF0
F4F8F1EDF2EEE7EBECE3E7E9DDE1E4D6DBDFD1D6DACCD1D4CFD5D5CED2D4D7DADCDEE3E4
D8DFE0D8E0E2D5DEE0C7D1D4BFC9CCB7C0C5AEB8BCA9B3B7A9B4B6A3B0B29AA9A995A2A6
8A9798818B89787B717067507E683E9D793E2BE01000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0045AD06
775614755F2B6E6032565331444E383E52413B5341354C3B344B3A364D3C324839324738
3246343A4B384754425862505C6551606651616550626551626551666A5466674F6A6950
6D6A506D68506D68516D68516E695275715C736F5A74715A736F54736E506D6849726B4D
756C50786E51766E50746F50716D4F7975587775587A795C79785B7E7C607B785E7A7860
7C79617B735C7E745B82755A8679598074517F724F7C714F78704D766F5079715581765A
7C72518174508978508A754C87734987714A85704A826C44826C448269427D66417C6847
7D7152827A5E7D785B7D7354776A45766842756B496E694D6B6D5374775D8280639A8F72
A6987CA59782AFA496BFB8AED4CFC7ECEAE3F8F6F0FFFEFAFFFFFCFFFFFCFBFDF8F7F8F6
F7F9F8EFF0F2EDEFF1E6E8EBE5E9EDE6EBEFE1E7EAE0E6E9E1E7EBE6EBEFDFE4E8E4E9EC
D8E0E2D5DCDFCED5DBC0C9D0BEC8CDB5C0C3ACB8B9A9B4B6A3B0B1A1ADAF9AA3A5899190
7E827A756F5B7C694494743D54C01F00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CB40B
7D5B17725F2962593053573D4654433C53423C56443D554642574A4055473D52453A503F
384D3940523D41513D43503E4E5847575D4C5B5F4F5C61515D6353616555656855666852
6F70596C6B556B6C556E6F586C6E5771715B71705B74735E75745D75725A78755D73725B
78755D79745D74735971715675745C79766078765E78785F76765F7878637C7D687E7F6A
7E7F6B7979647B78627D78617D7961827E6588846A89856B88876B8A896F89876B898569
8C88698C8968908C6B938F6D9793719994749992739990719C94749E95769C96779A967A
9F9E849FA088A3A58DA1A2879F9E81A19F829F9E839B9B819C9D85A4A48DB5B39CCFCAB4
EAE3D0F8F3E5FEFBF3FFFFF8FFFEFAFEFDFBFEFEFDFEFFFFFEFEFEFEFEFCFEFEFCFCFCFC
FCFDFDFBFCFEF5F6F9F2F2F8E9ECF3E2E8F0D9E0E5D2DCE1D0DBE2D1DBE3D3DBE4D1D9E0
CCD4DACAD3D7C5CED3B8C2C8B7C2C6B2BDBFA8B6B6A4AFB0A1ADAD9AA09E898880796E5B
7E6A4498773E52BE1F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053BA11
845F1B725E295D58324F57404A5A4B4056483C5647415B4D475F52465D50455C4F445D4B
4059434458444657444856444F5947525845565947545A47525C48535C4A58604E5B6352
696F5E7278647178646D77636B746070736071716073736071735F70725E6D715D6C705C
7374617878667E806C7F826D797C677777637475607778627374607274647B7F6F7E8270
7D826E7478637679647B7E687F816C8689758D917C8F927F8D907D868A78868A738C8F78
8F957D949B82939A83979D8897A18B9BA18DA0A391A3A593A4A793A8AB98ABAF9CB5BAA9
B9BEAFB9BEB2BAC0B3BCC2B4C2C7BAD1D4C9D9DED1E4E9DDF1F5EBF9FBF3FEFFF8FEFEFA
FEFEFAFEFEFDFEFEFCFDFDFCFEFEFDFDFDFDFEFEFEFDFEFDFDFEFEFEFEFFFDFEFEFCFDFE
F6F7FAEEEFF5E2E5EBDDE0E7D1D7DFD0D7E0D1DAE1CCD6DFCCD9E1C8D4DDCDD6E0C7D0D8
C6CFD3BFCACEBBC7CAB7C3C6B4BFC3ACB7B9A4B0B09EA7A38C8C817F735C856C45729831
2ADF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8C621B775F2A5A542F49523B4D5F4F495E52425B4E3F594D465F534C65594E655A506858
516955526654516051546051555F4D59604B595F48565E47525C464F5947505B4B535F51
596557606C5D636E61697569707D706E786B6D73656D71646F75656E7767717B6A737D6B
71796872796A747B6C757B6B747867757866787C687B806D8388787E83767D84767C8472
7E87747D87737E86737F8775868E7C89907F8A92819196889196898F95878D9482939C89
97A39097A49195A38F9DA9989CA998A4AC9EA9AFA4B2B5ABC3C7BDD4D7CFDEE1D8E5E7E0
EAEDE6ECEFECF2F5F2F8FBF6FCFDFAFEFFFBFDFEFCFDFEFDFEFFFDFEFEFDFDFEFDFEFEFE
FDFDFCFDFDFEFEFEFDFEFEFEFEFEFFFEFEFEFCFDFFFBFDFEF5F8FAECF1F5E4EAEDE2E7EA
DBE0E6D6DBE2D1D7DED4D9E1D3DAE1D2DBE2D2DCE2CCD6DDC7D3DAC5D0D8C9D3DAC4CDD2
C0CCCEBAC5C8B7C5C6B4C0C2B2BCBDA1A3A188867A7B6F578A7146789D342BE01000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
6E8D147A5E235F552D454C33495A484961514B6658466053475F544C625951675D586F63
5D73666275685F6E63616E63636F6165705E626B57606A555D6753576150556250546252
536052525F5354605755625956675C5B6B61606D6265706768756A6473676A786C6D7A6D
6F7C707581767582777886787784747C88787E8A7A7C887A7A867B839086849186889488
8392848493848998898B9A8A8C9B8A899786909C8C959E91939C8F99A2949EA798A4AD9F
A7B2A3B0BBAEBBC6B9CCD6CBD7DFD4E4E8E1F1F4EEF8FAF5FDFEFBFDFEFDFEFFFCFDFEFD
FEFEFDFEFEFEFEFFFEFEFDFDFEFEFDFDFDFDFDFDFCFDFDFDFDFEFEFDFDFEFDFEFEFEFEFE
FEFFFEFEFEFFFCFDFEF8F8FBF6F7FBEDEEF3E2E6EBD7DEE4D6DFE4D2DDE3D2DCE1D2DCE0
D1DADFD5DEE4D5DFE4D1DBE1D0D9DFD0DAE0CBD7DCCAD5D9C8D3D6C5D0D5C4CFD3C4CED0
C0CACDBEC6C7B2B8B79D9F998A8373857353957A497BA1332BE00F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DC0987621E6C5B2A4B4D2C4E5C47495E4F486251526B5D51685C52675D556B62536B61
576D6262766C68797168786E6C7B706E7A6C6C7867697564667260626F5E5E6E5C5D6D5C
616E5F5E6B5C5C685C5A695E5D6E635F6F655E6C635F6D6461726A5D6E655B6D6365786F
697C756A7B77697B766A7D7670847A73887D768980778A8281938D80918E84959080928C
83978F889C938FA49998AB9F9EB1A2AEBFB0B7C5B7C4CFC4D3DCD2E2E8E0EFF4ECF4F7F1
F8FDF6FCFFF9FCFFFBFDFEFCFEFFFDFEFEFDFEFDFDFEFEFDFEFEFCFEFDFDFDFDFCFDFEFD
FDFDFDFDFEFDFEFEFEFEFDFDFEFEFEFEFEFEFDFEFFFDFEFEFDFFFEFCFEFEFBFBFDF5F7F9
EEF1F5E9EDF0E0E4E8DDE0E7DDE2E9DADFE5D5DCE1CFD8DDD0DBDFD3DFE4D4E0E4D5DFE2
D2DCE0CED8DECAD6DCCBD7DCCAD5D9C4CFD2C7D3D6C0CDCFC3CFD2C4CFD1C0CACCC0C4C7
ADABA8988F858B786192785279A03C57C32400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007492187D601F5E55284950364D5D4D485E50506759536A5D586D63576D655A7169
5C72695F756B60746A67796E6E7E73748075738172717F6F707D6D707E6E6C7C6C6F7E6F
6C7A6C6C7B6C6C796D6E7B706E7E756C7D7472817973827A798981788B83748982788D88
859895869896849695879A988AA19D8BA39F97ADAA96AAA69DB1AF9FB1B2ACBEBFA7BBBA
AFC3C1BACDC9CADED8CDE1DAD3E5DCE1EEE7E7F2EBF2FAF4FBFFFCFDFFFDFEFEFDFEFEFE
FDFEFCFDFEFDFEFEFDFEFEFEFEFEFEFEFEFEFEFDFDFEFEFEFDFDFCFEFDFEFEFEFEFEFEFE
FEFEFEFEFEFEFDFEFEFEFFFFFDFEFFF9FBFCF3F8FAEEF3F5E9EFF0E4EAEDE0E4E8DDE2E6
DEE4E8DAE1E5DAE2E6D8DDE2D9DFE5DEE4EAD4DBE0D6DFE1D4DEE1CFDADECDD7DACED6DA
CDD6DACCD5D9C8D4D8C5D2D3C8D3D5C4CFD0C8D1D3C4CCCFC2C8C9B6B6B4999086917E6A
977A59A7835357C2292DE11100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF006D8F15745B205954304E5843475A4C4C6355536A5D5B70655E736A5D726A
60746C60736C64776D65776C68796E68786E6F7E75707E7472807573807478867A77867A
73827874837978877D76867E77898171847D7F928B84938D7F8E898697928DA19F91A3A2
8B9E9D95A7A695A6A592A6A4A1B6B5A6B9BAA7B9BAAABBBBBAC9CAACBDBFB2C5C7B7CACC
C5D7D8C2D2D2D4E4E4D8E7E7DDEBEBE7F0F1EAF0F0F5F9F9FDFFFEFEFFFFFEFEFEFDFDFC
FDFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFDFDFDFEFEFEFDFEFEFDFEFFFDFDFEFEFEFF
FBFBFCF8F9FAF2F6F7EDF0F2E7EDEEE2E7E9DCE4E6DEE5E8DBE4E5DFE9EADCE5E7D7E0E2
E2EAECE2EAEEE1E9EDE3E8EDE4E8EDDCE1E8D2D9DFCDD6D9CED8DACDD7DACBD5D7CBD4D8
C6D0D2C6CFD2C9D3D5C8D2D4C9D1D2CACCCAB8B4ADA1968A94816C9A7E5CA7805156C027
2EE11200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006C8D167259225C583648553D4A5F4E53685B5A6E635F726961736A
66776F66766F6979736F80776C7E756C7F786E807972827A73827972807872827874857B
73867D74867F7A8B847B8D867F938D819590879B978699968DA09C8FA3A095A6A598A9AA
9AADAF9DB1B1A4B8B6A4B8B6B3C4C4B2C1C3B5C5C8B4C3C7C3D2D4C2D4D4C3D5D6C7D8D9
CDDCDED2E0E0D2DFDFDBE6E7E2EBECEBF0F2F3F7F6FCFDFEFFFEFFFFFEFEFEFFFEFDFEFD
FDFFFDFEFEFEFDFEFFFDFDFEFBFDFEF9FAFBF9FBFCF6F8F9F2F6F5EFF2F4ECEFF1EAEEF0
E7EBEDE9EEF0E6EBEBE9EFF0E3ECEBE1E9EAE0E8E9E3E8EBE4EDEDE2ECECDFEAEADFE9EA
DCE3E6D5DCE2D5DEE3D7DEE3D5D9DED5D9E0CCD4D9C9D2D7C9D3D6CCD4D8C9D2D4C9CFD3
CED4D7CED1D3C6C5C4AFABA39A8F7D9882659F80587DA13F5AC42A00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004CB61381632A655B3354583D515E4C596A5D61726866776E
68797066766E6B7B746C7E746C81766B807873857E76868077857F7887827B8C85798C83
7D908981928E80928E829691899D9A889C9A8CA09F91A5A38DA29F95A9A699ABA99FB1B2
9CAEB0A9BBBBB0C1C2AEBEBFB8C6C7B9C6C7C0CDD1C4D3D7C8D9DAD0DFDED3E0E0E4EEEE
EAF1F2EDF4F5F1F7F7F3F9F8F9FDFCFCFFFEFAFDFDFAFCFDF9FBFBF8FAFBF4F7F8F3F6F7
EEF1F1F0F3F3EEF2F3EBEEF0EAEFF1E7ECEDEBF0F0ECF2F2E8EFEFE6EDEFE8EEF0EDF2F3
EDF3F3EEF4F7EBF2F2EBF2F4E4EEEDE5EEEDE4EDECE0E5E8DBE3E5DAE4E6D7E3E3D6DFE1
D6DEE0D0D9DDCFD9DBD1D9DBD3D8DCCFD4DACDD3D8D3D9DDD2D8DBD2D5D8C6C6C6B1ACA5
A194879B86719D8061A8855983A73E2DE21400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0029DE0D698D1F78612E68623D5D644B5E6A59637367
6B7C71667970687A716F81766D81766E837974837D7A85807E8A847A89837A8C8780938E
8596928A9A968C9E9B8DA19E95A8A696A9A897A9A99AADAEA1B3B4ADBEBDABBDBBADC0BF
BBCCCCC2D1D2C3D1D3C1D0D2C2D1D1CBDADBD7E5E7DBE9EAE5F1F1F0F9F9F7FDFCFBFFFE
FCFEFDFCFDFDF6F9F9F3F6F6F4F7F7F4F5F7EDF1F2F0F4F6E9F0EFEEF4F5EDF2F3ECF0F2
EBEFF0EFF3F4F2F9F8EEF5F5E9F1F0EAF1F1EFF7F5EEF6F6ECF5F3E9F1F2E9F2F1ECF3F4
EBF0F2E7EFF1E3ECEDDFE8E9E0EAEBDEE8E8DAE4E3DAE2E2D5DDDED5DFE0D3DFDFD2DADC
D0D9DAD0D9DBD4DDDCD4D9D9DBDCDFD7D5DAC8C5C5B6ADA6A9998A9C87709C8362A7865B
80A23E59C32900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0027DC0B658E207A65336D6340696951
666F5D6573656C7B7072817573827873857B7988827A867F7C88827987807D8C887D8E8C
869693859692869996889C9B8FA2A18FA1A295A7A898A9ACA0B2B4A9BABBB5C4C4AFBEBE
C0D0CFC4D3D2C5D3D6C7D5D8CCDDDED0E0E1DBEAECDCE9EAE7F2F3F2F8FBF3F8F8F6FBFA
F4F9F9F2F7F7F2F7F8F4F9F9F3F7F8F6F8FAF6FAFBF6FAFBF0F7F6F1F7F7F1F7F7F1F6F7
F4F9F9EBF0F1F1F7F9EEF6F5E9F2F1E8F1F0E8F1F0E6EFEEE6F0EDE8F1F0E4EDECE5EDEF
E4EAEDE1EAEBD9E5E6DCE6E7DAE3E4DAE3E3D7E1DFD7E0DED8E1DFD6DDDCD6DEDCDCE1E0
D8D9D9CFD0CBC7C2B9B8AC9CAB9785A28771A18364AB875B5AC7305BC42800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002ADF0E47B618866931
7561366B63416D6D536B715D707A6B7380747484797988807B89827F8B867A888480908D
8395928295928499968398978EA3A28FA2A490A2A393A4A696A8A9A0B2B3A8B9B9B0BFC0
B6C6C5B7C6C6C1CED0C3D1D4C8D7D9CEDEDFD0E0E2D5E4E6DCE9EADFEAEBE0E9EAE2EDED
E7F2F2E6EFEFEDF4F4ECF2F2EDF1F2ECF0F1EDF2F4E9EEEFE9EFEDE7EFEEEAF2F1E8EDEF
EBF0F2E8EDF0E9F0F1E6ECECE5EDEBE6EFEEE3EDECE3ECEBE3ECEBE2EBEBE0E9E8E4EAED
DDE4E6D6E0E0D6E0E0DCE1E2E5E6E8E6E7E7E2E4E1DDDFDBD2CFC9BFB8AEB6AB9AAD9B87
A48C73A68A68AB8B5E57C6315CC72E5EC52900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28DE0D47B5188E6E347F6A3C746843726D4F71735A777D6A7981747E847D7F877F808C86
82908C80918F839794809593879B9A90A4A48D9E9F96A8A89CAEAE9FB2B2A6BABAA9BCBB
B2C2C1B7C7C7B9C8CABFCED0C6D5D6C9D9D9C8DADACFE0E1D5E4E4DAE7E7DCE7E6DDE8E8
E2EDEDE1ECECE5EFEEEAF1F1E6ECEDE8EDEEEAF1F0E7EFEEE7F0EEE4EEEDE5EEEDE6EBEE
E7EBEEE5EAEDE2E9E9E8EDEDE3E8E6E4E9EAE4EAEAE6EBEAE5E9E8EAEDEDEBEDEDEEEDEE
E5E5E4E3E3DFD6D2CBCFC2B9C3B0A5B7A092AD967EA88E6EA98B647DA44757C5305BC62D
2EE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0052BF204ABA1E6B962D8A713F836F467F6C4B7F70537F775E
807B6983847681877C848D8585908B8C96948A96948B999890A2A099ABAA9CB0AFA4B7B7
A8B9B8B3C2C2B2C2C4B7C7C9BFCED0C5D5D6C8D8DACBDDDED0DFDED7E1E1DEE7E6DEE8E7
E2ECECDFE8E8E1EAEAE4EDEDE3ECECE7ECEDE6EDECE8F0F0E9F0EFE9F1F0E7EDEDEAEBEE
EDECF0EEEDF2ECEDEEECEAE9EAE6E4E9E3E0E1D8D4D5C8C2CDBEB3C6B3A4BBA694B49B85
B09578AE906FB18E6759C6385CC7355EC6312FE31700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059C32453C0224CBA22
47B7239A77478E724687714B85725483725783775F837D6683826E898A798C8E80989A90
9EA49AA0A69EA6ACA5ABB2ACB8BDBBBBC0BFC1C7C6C0C6C3CCD0CCD3D4CED5D6D1D2D4D1
D6D7D4D7D4D2D8D5D2DBD8D5D5D2CED4CFCBCFCAC4CCC6BFC7C0B5C0B7ACBFB3A7BEACA0
BDA898B69F8FB09A84AE957AAF9272B2926EB2906A87AB505AC7375ECA365EC83130E418
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0059C32657C32851C0274CBE264ABE2845B92543B826
6F9C3C9B80529A7F529B81579C815B9E84619F84639E8361A18662A38863A68C66A88D69
A98B69AC8D69AE9069AD8E66AB8B62B08F6581A94C81AA4A54C63556C6335AC9365CC834
5FC9335EC83030E41700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0108209 0.97619 0.443655 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00574713 -0.00574713 0.00574713 [
[ 0 0 0 0 ]
[ 1 1.67816 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.67816 L
0 1.67816 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00575 translate
1.00575 1.68391 scale
525 string
175 293 8 [175 0 0 293 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000
FF8000A020F0FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 181.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000]B000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooolP003o000@00[f0`0W
f``09]/<05F^6P1bTR<0Li8T07NC901eTbH0VG8g09]d>`2JMCd0LiP`07JJ<P1hVc<0IJd^03g?7080
:MlC00D0:=hA01oV3000o`002_L401C^1`0Q003o00Wooooo8000o`00100Xb3`0D91h052@N02XR3`4
0=1@N0<0oh00103@D7P00`1XZ3`0D91h052@N002052@N003003o000Xb3`0D91h02400?l0cOooool0
00[ooooo7000o`00800VfP/0QGdY09I[<02FKc<0Ug4h09M_>P2FKSX0V70l09mb@P2UMT80/7U80;Ek
CP2fOU<0]hAL0;Z3F`2kQEh0/hML0;::H02bRF40/HQN0:n7GP2]QU`0ZH9D0:ImC02RNdX0WGY409ij
@P1fVc40CK`N04bj701;^1/0C[TL7000o`09oooooa`00?l000<0D91h0=1@N03oP0002P3oP0030:0P
l080oh0000@0X23`0=1@N02P8?00d51h1@3oP0000`3@D7P0X23`0:0Pl0020:0Pl1`00?l0cOooool0
00[ooooo5@00o`00;00Dk@H09]X;02KJ2`0/d@h0II/R06nB9`1`Ubd0VGI209afA`2ONDd0XWY?0:1a
B`2LI4@0UUHl09M==P2VAc80]SlY0;Xf8P2k;ah0^R/N0<mBA`2b:a`0[b@E0:0_702JAS<0OBXK08D_
8@2<=BP0T3d/0952;@2BB340ZFeD0:1/C@2RM5@0Wg=?0:UlE02SOe80Wga<09]gA@2KM3d0QhDd07>F
:`13`AP07N@:5`00o`09oooooaD00?l000@0:<Pl052@N01@T7P0D91h0`3@D7P00`3oP000d51h0=1@
N0020=1@N0030;Ph]03@D7P0d51h00@0d51h00D0j6Pl0=1@N03oP000oh000>QX?0070=1@N0030;Ph
]03@D7P0d51h00<0d51h0`3oP000103XJ3`0d51h06RX?01@T7PG003o0<gooooo000:oooooa<00?l0
0380;M4<05ZR6P2?J340SV/d099_>P2IMTH0VgA:09IW@`2;F3L0Pd<Y088^6`1k7@h0O1D9084=1`24
20L0R@P908d72P2?1@P0W@L80;<>2`385100eA@A0=@E403C50h0dA@=0=4F3`2m4`l0Y@d<09hK702I
8R<0R`P:090:2P2:20X0XSTk08d[:P2XCD`0M14<08TV7`1g81@0Qd<`0<FMR@2kXXX0Zi5b0:66G`2P
PE80VWHo07^><01^TRD0E:dJ00[f0a<00?l02OoooolC003o000306RX?02XR3`0oh000080oh001P3@
D7PA0?n00080j6Pl0`3oP0000`3@D7P0j6Pl0=1@N0030?n000070=1@N02P8?00X23`0:0Pl03@D7P0
j6Pl0?n000020=1@N003091`N00Xb3`00?l001800?l0cOooool000[ooooo4000o`00=`09mP<0Ak@C
07Yi902:JC80TFdo09=UA027DCD0NcdV06lP4@1Z3PD0K0L207060`1h0`<0Q0@408X50`2?1@@0U`D6
09T51`2N1@L0X@H:09`6202G1PT0U`L;09l82`2g3`l0dQLC0=hH503R6a<0h1PA0=lJ4P3J5`l0aQH@
0:dQ7`2F61H0ZQlO09d:302K1PT0U`P709@K4P3=NVX0QBLO09/^;@2I;2`0VTi90=2i/`3<`k/0dLNk
0;b^V`2dWhD0[9=`0:65G@2MOD`0U70e062F6P0Sf0L04@00o`09oooooa000?l000H0:<Pl091`N03@
D7P0oh000=1@N02P8?020=1@N0030>QX?03oP000oh0001D0oh000P3XJ3`50?n000080:0Pl03XJ3`0
j6Pl0?n0002h>;@0j6Pl0;Ph]03@D7P20:0Pl0060;Ph]03@D7P0j6Pl0?n0003@D7P0D91h4@00o`3=
ooooo`002_ooool?003o000i01;/1028Hb80RfXi09=]A@2JK4`0OCXW06`A201b2@D0M@H307T4101l
0P<0O08407/11@250PL0S`@609<4102H1PL0X0H80:X9302X1PP0[@P:0:T82`2U20`0WPH;09l:302S
30`0/`l=0=0H5@3T71H0hB@L0>8l<`3N6a40hQTA0=l`;02_7A`0VP@50:@82`2X2@T0X`L709TA3037
JEd0Q1/D07h31@1k20H0[UA;0:MhK`3?_kT0_k^d0<_6`P3:`kd0dlRm0<2dYP2iZ9D0X8Y[09IiB@2>
JBl0=/L>01000?l02Oooool?003o0003052@N03oP000oh000080X23`00<0d51h0?n0003oP0005P3o
P000103@D7P0oh000?n0003@D7P60?n0000:0:0Pl03oP000oh000?n0003@D7P0X23`0?n0002P8?00
oh000=1@N0@0X23`0P3oP0000`1@T7P00?l0003o000>003o0<gooooo000:ooooo`d00?l003d0:lh8
05BN5P21LB`0S6<m07m5<01d9QX0Ka8:07L71P241PP0Q`@508H4102710<0S`D708d31`2;0PL0T@<6
09`51`2O1@H0X`L80:T72@2[1`X0[@P90;492@2b2P/0Z0L;0:L9302/30l0[10?0:P?2`2b3P/0aaTB
0=m>A@3REU40hB8F0>HL4`3S7AH0eQdH0;dC4P2W3@d0WPT:0:892@2L20L0W0h>09D:1`290`@0N@83
07X>301b5a<0]HB10=S<bP3>cL/0_[Vf0;jg/02f/JT0aL6k0<[3_02n/:40[i^009^1F01NZ2T02OH4
00h00?l02Oooool=003o0003052@N03@D7P0d51h00<0d51h6@3oP0020=1@N0l0oh0000<0d51h0?n0
003oP0000P3@D7P0202P8?00oh000>QX?02h>;@0X23`0=1@N02@L7P0:<Pl3P00o`3=ooooo`002_oo
ool;003o0011032o0P1dHa<0Q5l_07e<;01a;a`0JA4807<7201l10T0OP<608430`290`@0S0@208d5
0`2B10@0V@D609/51P2I1@H0W@H60:H82@2Z2@X0ZPL90:/7202^2@T0/`X;0;<;2P2a2`X0[@/:0:/<
2`2[3Ph0ZQ0>0:hB3P2_5100YaXD0>>TW02jM6/0WB@L08lL501i5a00JA@?05lC3@1D4Ph0E@l=06P?
3P1j3a00V1dN09X;302K1`P0S0@308<20P231@D0PaTI0<bCTP3?`;d0a/G00=C?b@2l][40cL[70<_:
b031_k`0cL_80<c8`P2k[Y/0TXeK05NT:P0Bk@P03000o`09ooooo`/00?l000<0T71h0>QX?03XJ3`0
0P3@D7PL0?n000030;Ph]03@D7P0oh0000P0oh0000<0j6Pl0?n0003oP0000`3oP0001P3XJ3`0d51h
0>QX?03XJ3`0oh000=1@N080oh0000@0j6Pl0?n0003XJ3`0^3Rd0P2P8?000`0Xb3`00?l0003o000:
003o0<gooooo000:ooooo`T00?l004@0:<X2071[4022FRP0K3dP05lD2@1Z20H0L0H607@51@1h0`D0
O`<708<31P270`@0SP@609051P2C1@H0U`@609X41P2P1@L0XPL90:871P2Z2@P0[0X90:d:2`2]2PT0
[`/:0;8:2P2e30`0]0h<0:l=2`2^40`0Za0=0:PE4@2P7AP0RQhI06XM601@<Rh0J5U>08MaIP2RShD0
^JRM0<BdZ@31]JX0^:fQ0:2BQ`1gIEd0DSXd03XE4`1L3Pd0S0l>09P;2@2H20L0XQ<?09hU8P36MWH0
^Y>@0=G<a`3<aL00^kB]0<>n^03:b/H0b/[:0<c=cP3<c]00c<k=0<S6`P2f[:00X8e_03g07@/00?l0
2Oooool9003o000406RX?03@D7P0j6Pl0>QX?1l0oh0000@0j6Pl0=1@N03@D7P0^3Rd102P8?000`2h
>;@0d51h0=1@N0060?n000060>QX?03@D7P0^3Rd0?n0003XJ3`0X23`0P3XJ3`40?n000040>QX?03@
D7P0^3Rd07QH]0/00?l0cOooool000[ooooo2000o`00AP0AjP40OELE07mH;`1L9a80E0L206L41@1`
1@L0L@<607020`1h0PH0O`<808@41`2910D0R`8409021`2D0`L0U`@609L51@2M1@H0X`D70:P72@2]
20X0Z`L90:X:302/2`T0[PX:0;@<302d30X0/0`90:h@3P2Y3`d0Xa<A08XP6P1:5@`0A2XP099nM@3L
b/00i]K:0>[Le03^i>00k^OT0>[Wi03Vi>80jNGQ0>cVh03Xfm@0h]760<FfZ`0m;BH0A@X907hA3`2F
2``0UPL809db<`3mblh0[XF70=2h]03Gc/P0`kji0=OCcP3>bL<0_[^h0<S8a`37b/`0c];E0<_<c`2m
_[h0alBm0:>AM`0caQL:003o00Wooooo2000o`00101@T7P0oh000:0Pl03@D7PO0?n000<0X23`203o
P0020:0Pl0030=1@N03oP000oh000080oh0000@0d51h0?n0002P8?00d51h2P3oP0000`3@D7P0X23`
052@N00:003o0<gooooo000:ooooo`L00?l004T04^X107=b4P1j=QD0GQ4605450@1D0P40I`<406l4
1`1a10L0L@8607L21P1k0P@0P`@708T51@2>1@D0TP@509H61`2G1@H0U`D50:881`2X20P0Y`P70:X;
2@2R20P0WPH80:<;2@2Y2@/0[PX<0:l=2P2[3PT0XQ4>08`E4P1Z61@0Id8g0:ZFR03Ibkd0imcA0>[T
h03/inH0inCT0>SViP3VinD0i^KV0>GTi`3Xi^P0inGW0>GSh@3UhMd0i=oH0<o4_@1ZEU40>``:07PB
4P2B2P`0YSHi09Lh?P219BH0/gij0=72_@2bYj00`KRa0<S3_03=cLX0e=?C0<k>d03=d=<0cm3C0<S8
c@33aLH0^KF^09^HL`1GXbh09[H500P00?l02Oooool7003o000302S8?03XJ3`0j6Pl01h0oh0000@0
j6Pl0;Ph]02P8?00^3Rd2`3oP0030=1@N0<0oh000P3@D7P20>QX?0040=1@N02P8?00d51h0>QX?0L0
oh0000@0d51h0:0Pl02P8?00T71h2000o`3=ooooo`002_ooool6003o001;01?Z0`1XM0h0R1X709T9
1@2N2@P0UPP908P51@261PD0OPD407H20`1f0PH0O@@808441`271@T0Q`@608h51P2E1PD0V0H609X7
202O1PL0YPP90:@72@2P1PP0Y0T809T31P2I1`T0W0L90:<9302T2Pd0X@d;09<F401L7140LE=50;>R
U03Re//0jN3K0>SUh03Wi>40inKU0>SVi@3Vi>@0inKV0>KVi03Wi^L0iNKX0>OWj@3VinP0hnCS0>;S
hP3PhN40gn3O0=cGd@2^X9H0GSPb07L?402B5QX0S0L;09@:2P2OBDX0flS80;fd[@3Eb/80b<2j0;fh
]03GemH0e=OH0<oAd@3Ad]D0bL_?0<W=d034aLL0YZ:N0:FGR029KDl09[H500L00?l02Oooool6003o
0003052@N030X000oh0001d0oh0000@0d51h0;Ph]02h>;@0j6Pl3`3oP0000`3XJ3`0X23`0=1@N004
0?n00080j6Pl00@0X23`0>QX?03@D7P0j6Pl1`3oP000102h>;@0X23`0;Ph]02@L7P7003o0<gooooo
000:ooooo`D00?l004d09=<608Hj4@1n40<0V0D50:T8202]2@T0[P`:0;HK502h6100^0h:0;4<2`2M
2@P0S0D608<21P2310H0Q`@508X51P2?10@0UPH709d71P2Q1@H0XPL809l61`2O1`T0W0H809X41P2L
1@P0W0T;09T;302B4A00Ka8=06i6>P34]jP0i=cA0>OUh03UiN<0hnCQ0>;Rg`3Thn40i>?R0>GUhP3U
h^@0i^?W0>KTiP3Wi>L0hn;T0>CTi@3TiN@0hn;R0>;QhP3Rh^@0i>?S0>?Sh`3Th=d0^ZnW05<H5P23
2@`0SP850:X>402B2Ph0Mb`]0;nMTP3:^Jh0_k:W0;fh[`3>c/T0dM?B0<_<cP3AdM<0dmCG0<o@e@37
al`0_;^o0;:`Y`2ESG`0QVQ901?J0P06003o00Wooooo1@00o`000`1@T7P0oh000?n0000L0?n00004
0>QX?02P8?00d51h0>QX?1<0oh0000<0d51h0?n0003oP0000`3oP0001@3XJ3`0X23`0:0Pl02P8?00
^3Rd00L0oh0000D0d51h0:0Pl02P8?00^3Rd052@N006003o0<gooooo000:ooooo`D00?l004d0LE88
074:00260P40X@D70:/92P2_2`/0_24K0;@I3`327AD0_Ph90<4<2@343@`0^0h;0:P92@2C0`@0Q0<4
08P51P280@80TPD40:07202R1`D0X@L60:47202O1`T0W0<50:872P2S2PX0U`X908D@3@1H30T0Id<c
0=30/@3UgmX0hN3M0>;Sh03Rh^40h^7P0>?Rh03RhMl0hn;Q0>?Qh03Qh=l0hMoR0>?QhP3ThN<0h=oQ
0>3PhP3Ph><0h>3Q0>7Qh@3PhN40i>;S0>CRi03Og^40g][H07IFD01j5Q@0T1TH08`61`2;1@P0OaLF
09]QF`3Kc<L0c/>l0<:f[@2h/:H0_kbe0<[;b`3Be]L0e=KJ0=;De`3AdM@0_[o10::SWP2LVY40SGIV
01_>2006003o00Wooooo1@00o`000`3@D7P0oh000?n0000K0?n000030=1@N02P8?00oh0001H0oh00
00<0d51h0?n0003oP0000`3oP0000`2P8?00oh000=1@N0020:0Pl0030=1@N03oP000oh0000@0oh00
0`2P8?000`1@T7P00?l0003o0004003o00Sooooo8`00o`005P1Ae3L0RkEM08njI02F`Fd0Y<>20<B]
U`2eVh80Yk>00;j[UP39^JX0ZYjD08^1NP1SI600Th]n09NbQP2@_H40T<Ij08;4J01MdDX0C]<k02cU
800El0hP003o00Sooooo8`00o`001@1XZ3`0X23`0:0Pl02P8?00^3Rd00@0X23`00<0d51h0;Ph]02P
8?000P2P8?00202h>;@0j6Pl0:0Pl02P8?00D91h06RX?01@T7P0:<Pl8000o`0;ooooo`002_ooool4
003o000=03:e0`1b4P40N@<109830`2T1`/0WPD60:/=3@2e6A<0^B4E0;hK4P2m3@T0`P`90<@<2P02
0<D=2`100;l=2`2W20L0SP<408P40`2=1@@0VPD80:071P2N1`D0XPT:0:@92P2U2@/0X`X:09d92P27
3P`0FA`C089UDP39]Z<0h=_B0=gKfP3Og]`0h^7O0>7Sh03Qh^00h^;P0>CSh03ShN00i=oN0>?LfP3S
f]T0gm?A0=W7a`3Ka/L0fLC40=k<c@3SfMT0i=oO0>7Ph03Ogn00h=kQ0=[Kg@3IfMT0^jbW06PQ702^
BDL0PPT:08@51`2B:B/0R4=70<:RY032]:l0_[BZ0=C;`@30_KD0`[nk0<O7a`3AdmH0dMCH0<g=d@36
bLX0_<2o09RJT`2OT8H0C6DF01o@1`D00?l02Oooool4003o0003091`N03oP000oh0001/0oh0000<0
d51h0:0Pl03@D7P0303oP0000`3XJ3`0d51h0=1@N0080?n000030=1@N03oP000d51h0080oh0000@0
j6Pl0=1@N03XJ3`0j6Pl0P2P8?000`3@D7P0j6Pl0?n000050?n00080X23`00<0d51h052@N000o`00
1000o`08oooooa/00?l002802oP702kT6P1AdRl0PKU=0:JWI`31XGl0b;6E0<>`V038^J@0`;>P0=S?
`P38^jl0bl>g0<2eZ03?a[`0aknh0;Ne/02d/JX0[:^Z0;>d]022UJ80TZFb035?I`1]Ri/0_/gB0<[>
c`3=cLd0cLc<0<g<b037`K/0_[B[07SAK@1KdDX0:n@O7000o`08oooooa/00?l000@0:<Pl052@N020
`000^3Rd2P2P8?020=1@N0060;Ph]03@D7P0d51h0>QX?02P8?00^3Rd0P2P8?001@3XJ3`0oh000?n0
003oP000j6Pl0080d51h00<0Z8Pl052@N01@T7P07000o`0;ooooo`002_ooool3003o001A01?W0@1a
9P40L`8108010P2K10L0Y`H90:T92@2_4Q00]A`F0;HI4P2k5a00^P`90;l<2@332`P0aPd:0<T>2`39
3PX0b`l<0<4>2`2c2`X0X0H509H41@2L20P0X0L90:06202R20L0W@P908d61`2440h0HbTO0;JST@3M
dlH0h=cD0=cJe@3Jf]H0gMgK0>;Qh03QhN00hN3Q0>?Qh03Vgm`0g<W60<6DT@2`L6d0XE1=09<a<@2>
7B40U1/N09HL702F8R@0UcXh0:1LF02oUY<0h=?B0>3Ng`3Kfmd0emOI0=_Fe@25CDH0NP/:08P61`2:
1`P0P`H:07L42023;Bh0b[2Y0<W2^P33^k40]ZnT0<C3`03=c/h0c<c@0<oAe@3Ae=L0b/g@0;Jj_@2`
/k80V9B<06Dn<@2VNV<0;Z`<00@00?l02Oooool3003o000302S8?03XJ3`0oh0001X0oh0000@0j6Pl
0:0Pl02P8?00j6Pl203oP0000`3XJ3`0d51h0=1@N0020=1@N0030>QX?03oP000oh0000@0d51h1@3o
P0000`3@D7P0oh000?n000030?n000050>QX?03@D7P0d51h0=1@N02P8?001`3oP0001@3XJ3`0X23`
0=1@N02P8?00N5Rd00@00?l02?oooolH003o000Y02oU701Nc3T0PK]@0;jLNP33Xh80ajV90<R/R`39
[i00ckJN0<beW@3B_:T0a[>P0;jcY@2h/:H0b/>k0<k7_P3:bL00b<Bm0<S4_P3Bd/`0`l>l0;jn^02A
V9X0VjBZ08fQ[`2>Z;X0OInd06Z:WP34d]H0bM7D0<_Ce@38d=80bm7D0<S@dP37c=00a<[:0<W7``2o
/:T0Timc05>a=P0Ak0T06000o`08oooooaP00?l00P1@T7P<0:0Pl0030=1@N02h>;@0d51h0080d51h
0P3oP0000`2h>;@0X23`0=1@N0040:0Pl0P0oh0000D0j6Pl0=1@N02P8?00N5Rd02S8?00H003o00_o
oooo000:ooooo`<00?l00540AI@108070@1j0@80NP0009T31P2X1@H0[@T80;4D4@2]4`h0^b0J0;LB
3P2i2PP0`0`80<@<2P3930/0b0h90<P>1P3<3P`0c0d;0<l>3@374@l0WP@309X61`2O1PP0XPP80:<:
2@2>1@L0PA8A05LF3P2cWhh0g=K<0=_Ie03KfmH0g=_F0=kKf03Jf]L0gMkL0>3Og`3Vgmd0im?A0<BG
TP2?>cL0UQhN09dD5P2O4Q<0X0l?0:4;3@2T2`d0Y@`;0:@<2`2J2`X0T`l?088C4`2hMg<0iMSF0=[J
f`3If]X0f=OG0:AlM01a3`P0R0L4098A4@2630l0O0@7090S8`2IIF00bL6m0=3;b038`[/0dM3>0<72
`@3Bd]<0d=7D0<_>d@38c<h0d]GG0:FUY`2UY9h0JDY209QdJ`1cNCl01000o`09ooooo`<00?l000<0
P<000?n0003oP0006P3oP0000`2P8?00d51h0?n000080?n000030:0Pl03@D7P0oh0000X0oh0000<0
X23`0?n0003oP0002@3oP000103@D7P0oh000?n0003@D7P70?n000030=1@N02P8?00d51h0080X23`
1000o`08oooooaD00?l002h0=mhQ07;0A`2[XFd0_ZB20<2VQP35[8h0bk6F0<feWP3A^jH0c;ZS0=6n
Z03F`J`0e/F^0=C1ZP3D_JX0_k>V0<o9_`2g/j/0cLRo0=WHd@3;b<80d/g80<S4_@3?blH0blS20<[?
c@2X/[L0FG:<07ZD/01^S:H0X[c=0:c4cP39e=L0bM;E0<O@dP3:dMH0aLgB0<G>e@34cM<0a<c?0<C:
c@32aLH0_kbi0:NGR@1>/3802?D45P00o`08oooooaD00?l000<0J:Pl091`N02h>;@03P2P8?002P2h
>;@0d51h0>QX?03XJ3`0oh000>QX?03oP000j6Pl0?n0003@D7P40:0Pl0030>QX?03oP000oh0000P0
oh0000@0j6Pl0;Ph]02@L7P0:<Pl5P00o`0;ooooo`002_ooool2003o001C01CY0@1l>P40R@@108P2
0`2<0P80V`840:L51`2Y1`L0YPP70;<I5`2_4@h0/PX70;X;2@2n2`P0`P/90<L<2`372`X0b@d;0</>
3@3<3@/0c`h;0=0@30353P/0]PX:0:X71`2R1`H0V0L707X:2`1J6A<0VGi^0=WCb@3LgMX0fm[H0=[J
eP3KfmL0gm_I0=gLfP3Rgm`0g/K40;EgMP2Q@D00XB@S0:@E5@2W4A00Y`l?0:H?4@2W3@h0YPX=0:@8
2`2U2PT0X@P709d92@2J2`/0T@T;09<K6@3>VIH0hMWH0=[IfP3JfMT0`jFN07@J40241`D0Q`@60884
201n1PL0VS4a08e<B@3Fa<00_KF]0;:ZWP2n^k@0cLc<0<o>dP3;c=00c<kA0<K:c@34bLd0^;jn09bN
V@1dGeL0Ke==0:B@P`0:iP800`00o`09ooooo`800?l000<0D91h0>QX?03oP0006P3oP0020;Ph]0L0
oh0000<0j6Pl0=1@N03@D7P03P3oP0001@2h>;@0oh000?n0003oP000d51h00D0oh0000<0d51h0;Ph
]03oP0000P2P8?000`3@D7P0oh000?n000040?n000060>QX?02h>;@0d51h0:0Pl02h>;@0:<Pl0`00
o`08oooooa800?l00380>=hQ07nhC02OYfH0^:5m0;ZTP`2nZ8D0`:b<0<RcU`3=^J<0b[ZX0;fbY@2g
Zi`0f<Jc0=c8]@3Lb[H0g/be0=k9/P3JbK<0cl2/0<o5^`3;a;X0`l6i0;6_Y`3Bd<P0d<_60<[6`P3=
aKh0d<_40<C3_P2m`/<0^L;:06f6V`1ROYP0EGVE07NGZ`39fM`0bmKH0<OAe@39dmL0bmCH0<WAf037
cmH0`L[?0<7<c`33c=40`LS<0;k3a`2k][D0OhmR01SR3QD00?l02?oooolB003o000306RX?02h>;@0
X23`00L0X23`00<0^3Rd0:0Pl02P8?001`2P8?00202h>;@0d51h0:0Pl03@D7P0oh000>QX?03@D7P0
oh000P3XJ3`00`2h>;@0X23`0:0Pl0020:0Pl0/0oh000P3XJ3`00`2P8?00@>00003o000D003o00_o
oooo000:ooooo`800?l005<0F7d109<C1P2:0`80S@8509/51`2R10P0Y@@70:H51P2W10H0Z@D90:/6
202e2PT0^PX:0;`;2`2n2`X0``/:0<L=2@3;3Pd0b`d<0<h?2`3?3`X0dQ0=0=<B3P3E4@h0da@A0;X=
2`2830X0IblT0;JQS@3Kd/T0g=[H0=gJf03LfMP0g=[I0=oKf`3PemD0ckNd0;AhM`2V<300[QPF0;<F
4`2h5A@0/a8A0:dA3P2Y4@h0Y@h=0:L=3@2U2P/0YP/;0:T;302S2@P0W@T909P8202C1`P0S@L908h`
;@3E]:d0f]KD0=OFeP3E_k`0UC/c08l;1`261P@0TAlL098X:01g20/0MA8D09][HP31/ZL0_[F[0;nj
/P2o_;P0clk=0<S:bP3=cm<0a<S;0<O<cP2g_;d0WjBQ089dK01;<B`0_kJe02bP4@03003o00Wooooo
0P00o`000`2P8?00oh000?n0000H0?n000030>QX?02P8?00d51h00H0oh000P3@D7P00`3XJ3`0oh00
0?n0000>0?n000050>QX?03@D7P0oh000?n0003@D7P00`3oP0001@3XJ3`0d51h0?n0003oP000^3Rd
0080X23`00<0d51h0>QX?03oP000103oP0001P3XJ3`0^3Rd0;Ph]03oP000d51h052@N0<00?l02?oo
ool@003o000e027[5025/E80]Yeh0;fQP@2lXhD0^:>80<2ZS039/Y<0c;RN0=:oYP3A_JL0eL^m0=gJ
eP3;_[40f/J`0=c:]@3JcKl0g]?40=o=]P3Nc;H0f<Zf0=K7]@3Db;T0d<O00:f/YP3>c<@0b<:k0=SF
c@3>cL@0cL[30<?1^@2_/Jh0[K2`092Q[@2/`</0IhJO06Z<Y02N^lT0bmGH0<[EeP39e=H0bM;G0<O?
e`33c=80`<S>0;k7c033c=40aLgD0;k7c`2la<T0/kRo05APC`0He1405000o`08oooooa000?l000<0
D91h0>QX?02P8?002@2P8?000`3oP000^3Rd0:0Pl0080:0Pl0070=1@N02h>;@0j6Pl0=1@N02h>;@0
d51h0>QX?0030=1@N0050;Ph]02P8?00X23`0:0Pl03@D7P0103oP0000`3XJ3`0oh000?n000030?n0
00050=1@N03oP000d51h0;Ph]01XZ3`05000o`0;ooooo`002_ooool0E@00o`004^L108HM002A3PP0
PP4109041`2I10H0V@4409l41`2Q1@H0Y0@80:H42P2Z1`P0/`T90;P;2P2l2`X0_`/;0<<=2@3330T0
a`d;0<T=303=3``0d10:0=8A2`3A4@/0e14=0=LD3@365a80NRXR0<BaY@3MeM00f=KE0=_HeP3OfmT0
gMWG0=kHe`3E`<00YfMR08XS7@2Q5aD0/Q@C0;HC502b4Q80/1<B0:XD4@2P5Q<0U1@B08dF4`2;4a40
S`lA09`<3P2T2`/0XPT90:092@2I1PH0T@<508h31@2220H0XEU>0=[8`03Ee]L0f<S70:E@A`2a8QL0
XbHJ09/g<@2H?ch0M@L:07P92`1m=C00dkNb0<2c[P2dZ:40^;J^0<c=bP3:bl`0al[=0<W=d@39bll0
/[Rj0::XY`2?Qh@0@B@P09N<RP1EQcH00`00o`09ooooo`03003o000Xb3`0oh0001T0oh0000<0j6Pl
0;Ph]03@D7P01@3oP0000`3XJ3`0d51h0?n0000C0?n00080d51h0P3oP0001@2P8?00oh000?n0003X
J3`0d51h0080oh000`3@D7P00`2h>;@0d51h0?n000040?n000060>QX?03@D7P0X23`0?n0003@D7P0
X23`0`00o`08ooooo`d00?l003<05_8>05O9=`2@ZE/0/iYc0;NON`2iXH@0_:>:0<:ZTP36/9T0b[FK
0<ZeVP3?_:<0dKfW0=>nZ03GbKL0fm760=K4/03F`Zd0_[BT0<W9aP3Jf]H0fljn0=o;]`3KbK@0elJ`
0=G7^03?`[@0f];:0<g6_P3>bl80b<>i0=??a`39`kd0fMKC0<?1_@2X[:T0TifU06V0U01ZQ9d0U[;6
08RU]P38f=/0c=KH0<cFfP3=eM/0bm?J0<O?e02na//0^L?60;S2a@30bLl00P2nb<l0102nb=40QiFR
07b0P00/eR4C003o00Sooooo3@00o`00100Xb3`0D91h0;Ph]02h>;@;0:0Pl0040=1@N02P8?00X23`
0:0Pl080oh001P2P8?00103XJ3`0d51h0;Ph]02P8?020=1@N080oh0000<0d51h0;Ph]02P8?000`2P
8?080?n000050>QX?03oP000j6Pl0>QX?02h>;@00P2P8?000`1@T7P00?l0003o000A003o00_ooooo
000:ooooo`1E003o000_/P80LA<207P8101j0@80RP8408l00`2D0@80VP<509l4202O0`D0X`D70:L6
1P2b2@X0]`X:0;d;2P2n30X0`@`90<@=2P363@/0aP/;0<X=2`3>40/0dA0;0=8A2`3F4`l0d1D@09@B
3@2cTHH0hMSG0=cHf`3JemX0gMWJ0=_HeP3Lf=H0g<O609I;BP2K61L0YQ4=0:/B3@2_4Pl0ZPl@0:TD
502R71T0PAhK05<B3P0j30L0:PT302T91P0g20X0Ga4B08P@4@2J2@T0W0P609H40`2B0@40T@8208T4
0P2081H0dK6W0=OGf03LcL/0[E]A0;l_8`2T4@X0UadI07`91`1m1@H0QaLD080e<02kVYP0eLc>0<S3
a02h/Jd0aL?10<O;c035blh0`l[>0<;6b`32aLT0TYND09^CT@169R80R7Md06eoC@03003o00Wooooo
00<00?l0052@N03oP0006@3oP0000`2P8?00oh000?n000050?n000030=1@N03oP000oh0001@0oh00
00@0d51h0?n0003oP000X23`1P3oP0001@3@D7P0X23`0?n0003oP000d51h00H0oh0000<0X23`0=1@
N03oP0000P2P8?03003o00Sooooo2`00o`00?00Fl@d0B/l]0:>LJ@2bV7L0/iai0;:MO02lY8P0_ZRA
0<J`VP38/id0b;:I0<RbU`39/YT0c;JM0<bjW`3A_Z@0dknW0=K1Y`3G_j80b[NQ0<>iZP38`kX0dLVm
0=k=^03Nb[<0flR`0=O4[03EaK80dl>d0<k1/`39_[40e]?80<k9``3?blD0b/S20<S0^`35`;`0c/k;
0;Vj]`2:VjH0OIJW031@KP1VQIh0/<WF0<[Ef@3=eM`0c]KM0<gEg@38d]P0am7E0<39cP2na/T0^<35
0;K0a02i`lX0^<C?08NDYP19Gg40JGe/01WT4A800?l02?ooool;003o000302S8?01hF;@0^3Rd0180
X23`00<0d51h0;Ph]02P8?001`2P8?000`2h>;@0j6Pl0?n000030>QX?0030?n0003XJ3`0^3Rd00<0
X23`00<0d51h0?n0003oP0001P3oP0000`3XJ3`0oh000>QX?0030:0Pl0030;Ph]010h0000?l00140
0?l02oooool000[ooooo05D00?l003JF0P132080O3`k06`41@260PH0S`8409410`2I0`H0X0@90:44
202T1PL0Z0H80:l82P2e2@/0_0/;0<0<2`3330/0``X;0<H=2`383PX0c0l:0<l@2`3A40`0dQ8<0<hE
4@2[5Q<0TDi70=c?b`3Ke]P0fmSJ0=WGf@3Lf]/0h=KF0<BUY02HBdT0VADD0:P?402Z3`h0Y`h=0:HD
4P2B61D0KaHD05<K5@1M@cT0OF]O09F4M`2PTH<0Vheo07IUF@1<=Rh0C0l=098?3`2M2PT0V@@509D2
0`2A0P40R`8107/<1P37V8h0f]KF0=[;b@2/FDl0]b<H0;lY7P2T81P0P`h:09/[:`275Q<0Ob0M0:1Y
J@3B`<@0_[bm0;Zh]03;c</0`l[:0<37b034blh0`<K90;jo``2Z[Jd0V9FC04hh<`21LW00OfmM00<0
0?l02Oooool01000o`00P<000?n0003@D7PG0?n000030=1@N03XJ3`0oh0000@0oh000P3@D7P80?n0
00<0d51h0P2P8?020=1@N0P0oh0000@0^3Rd0?n0003oP000X23`103oP000103@D7P0oh000?n0003@
D7P30>QX?0H0oh0000D0d51h0:0Pl03oP000X23`0;Ph]003003o00Sooooo2P00o`00?@0YhQT0W9MS
0:^DL02aVGP0]9al0;JOPP2jXh/0aJjF0<B_V032[YD0aJfD0<F/TP35/9L0b[FL0<ffV`3=^Il0ck^R
0=:mY@3D_jH0f;nS0=ZoY@36/ih0b[RT0=c9/`3Mb[@0f/Na0=[5[@3F`ZX0d[jW0=O4/@3<_Jh0cLBh
0<:hZ`3@c<80`Kbd0=C@c034_[P0`kji0;Vc[`2^[j/0Zk2h09RX/`25Vj`0OYZb0622W@35eM`0c=CJ
0<oHg`3=e]l0c=GL0<WAf@33bm<0b=3H0<K>f030b]40_LW@0;W3b`2X/;X0K7j>07V:T@24Vg804P00
o`08ooooo`X00?l000<0:<Pl0;Ph]02P8?007P2P8?000`2h>;@0d51h0?n000020>QX?080d51h00<0
j6Pl0:0Pl02P8?000P2P8?050?n000070>QX?03oP000oh000=1@N03oP000j6Pl0=1@N0040:0Pl180
0?l02oooool000[ooooo05D00?l004YV1P1[Ee00MVY]04<310251@P0T08709<11P2O10P0W@<709d4
1`2Q1@L0YPH90:h82@2e2`T0^P`:0;h;2P3230/0a0/:0<D<2@393PX0cA0;0=0>2`3B4@`0d18>0:@E
401o@cP0elNo0=oMg03Ge]H0f]OH0=_Hf03Md<l0XfUU08`Q7P2O5140ZPl?0:L>402S40h0Ta@B06HG
4@1WAST0VXMh0<Zk[P3QeL`0h]OA0>CMf03Th=/0iMkI0>3Gc`3Ibl80[i6807lH502M2@X0V`L:09D5
202=0P<0R@8207`70P2nQgP0em??0<VbZ`2L=bP0]A8:0<4M502e81T0RP@408XB5P2C71X0Qa/G08Ha
;`1k@T80b[^h0<C0_02j^KH0^[bk0<C;cP36cm40_lS:0<39b`2LYZL0V9bJ05U=B02:PX40QgY]00<0
0?l02Oooool01000o`00d51h0=1@N02P8?0F0?n00080d51h1@3oP0000`3@D7P0oh000?n000050?n0
0080d51h00<0X23`0=1@N03XJ3`00P3oP000103XJ3`0d51h0=1@N03@D7P70?n000030:0Pl03oP000
d51h00D0oh0000@0j6Pl0?n0003oP000d51h0`3XJ3`00`3@D7P0j6Pl0?n000030?n00080^3Rd00<0
X23`0>QX?03@D7P00`00o`08ooooo`T00?l003l0Fkdj09RCH`2XTg@0/9]n0;FPQP2oXh/0bj290;Ua
GP36TWP0_ZR<0;fWS033ZHd0aJbA0<J`V@37/YX0ak>I0:jRS`2FTH80XYf>0<fmYP3G`:L0f/6V0=S3
Y`3IaJ`0flN_0=c9/@3Jb;00fL>[0=RoZ03D_:D0dKZU0<nkZ@3Aa;H0bKjc0<c2]@39`[H0`KZ`0=3;
a@38a;h0`Kjj0;bk]P2TYJ@0H75o08^N[`1dT:T0OY^`0;C:e@3=eMT0cmOM0<_Eg03=en00b=;J0<O@
e@36cmH0_<G>0;Joa`32cM@0_<K>0;Jma01_O8/0L8B?09NLWP0ecBT04@00o`08ooooo`T00?l000<0
N5Rd0;Ph]02P8?00102P8?000`2h>;@0X23`0:0Pl00K0:0Pl0<0j6Pl00<0d51h0;Ph]02P8?000`2P
8?000`3@D7P0oh000?n000050?n000030=1@N02h>;@0oh000080d51h0`2P8?000`1@T7P00?l0003o
000?003o00_ooooo000:ooooo`0^003o001MPbL0RhR506AXJ`0I0@40H@H808831`2>0PH0TP<809<2
202H0PL0W@@80:@72@2^20/0]0/;0;T;2`2m2`T0_`/:0<<=2P373@X0b@d:0<`>303@3`h0dA4?0;/E
4@29A3d0elO00>;Og@3Lg=d0fMOH0=WEe@3I`;`0_UiD0:LG4P2N2`P0X@/<0:4=3P2E4Q@0MQLE06<c
;02]Vhh0gM?80>7Le03Rh=d0h^7P0>7Qh080h>3N02D0h>3O0=kOg`3KgM`0hMSE09iGC`2I2`X0V`H7
09T6202C1PL0S@D6088>1@2oR7H0dlg70<2OV02@81<0/0T40<8;2`2n2Pd0[PT<08l31@231@P0PAhO
0>>WZP28De@0aJjZ0;Vb[@32_k/0b<W90<;:c032b/d0aLg@0;c5a`2W/[80SYRH07ejN01kM7D0RGme
00<00?l02Oooool01000o`00X23`0:0Pl02P8?0E0?n000030>QX?03@D7P0oh0000<0oh0000<0j6Pl
0=1@N03oP0001@3oP000103XJ3`0^3Rd0=1@N03@D7P90?n000030=1@N03oP000oh0000@0oh0000<0
X23`0=1@N03@D7P0203oP0001@3@D7P0^3Rd0=1@N02h>;@0d51h00D0oh0000D0j6Pl0;Ph]02P8?00
j6Pl0=1@N003003o00Sooooo1`00o`00@@0Cl0`0QiQH09n>L02WUg`0[Yj60;>SR`2jXXd0`8Id0:Ph
9P2d8a<0_F=70<:SQP33Z8h0`jV<0<FZS@39[Y<0aJfE09B;NP2=Rg/0XIZ:07enM@28QgX0e;nV0=O0
YP3J`ZH0fLBW0=_7[P3Lb:l0f/N_0=S4Z`3G`:P0eKjV0=6kY03?^jL0akJP0=32/`37_;00dlo50<K3
_038aK/0_;F^0=3<a@30_k/0^KVg0:nc]01fQ900BfJ0061oV`1iUZT0bMGJ0<oGgP3<eM`0c=KM0<WD
g037d=T0aLoG0<G=eP2a^Kl0`LkD0<7<e02oc=D0HG>304aULP2<Vj<0Nj=_01400?l02?ooool7003o
000302S8?02P8?00X23`00D0X23`00<0j6Pl0?n0002h>;@06`2P8?000`3@D7P0^3Rd0;Ph]0030>QX
?0030=1@N02P8?00X23`0080X23`1@3oP0001@3XJ3`0oh000>QX?02h>;@0oh000080d51h0`2P8?00
0`2h>;@00?l0003o000?003o00_ooooo000:ooooo`1E003o002RPeh0MG^005eWJ`0=0@40<@8205T2
0P210`H0P@4208/21P2C0@<0VP870:842@2/1PX0/PT<0;P;302l30/0`@`;0<8;2@3730X0bP`:0<d@
3P3>3`h0cA4?09<C4031YIh0h]kL0>7PhP3Ogn40h=kN0=c6`P2jHeX0`AdD0<LD402e40`0X0/:094B
4@1J4@d0JDe20<Zl[P3Rg=D0g]kJ0=kNg03Ph=l0h>7P0>?Sh`3Ph>00h>3O0=oOg`3Kg]d0gMoN0=oL
g02`OgH0U@l<09T31P2L1PT0VPL909@720284PP0a8mn0=O?b@2ZQgh0M0L10:L61P2l20T0`0X=0;T>
402Q3@l0Q0<708hK7`1g51d0M2L/0=O0`@3<b<D0aLBo0;Rh]`30a/X0a]3B0;Jn`@35cm40YK6c09FQ
XP1hN7@0KFMU08^1M`03003o00Wooooo00@00?l00=1@N02P8?00X23`5@3oP0000`3@D7P0oh000?n0
00030?n000030=1@N03oP000oh0000@0oh000P2P8?000`3@D7P0oh000?n0000@0?n000030:0Pl03o
P000X23`00T0oh0000<0d51h0?n0003oP0001P3oP0000`3@D7P0X23`0:0Pl0020=1@N0<00?l02?oo
ool6003o001302;M5@1gVdl0W8ma0:>FO`2XVhD0[Yj60;6PQ@2iUg`0XThf0:i09@2oJD/0b9Mj0<2T
R@30YXP0`JN70<BWQ`35Z8T0/in706i_HP2OWHL0Y9j=08f;P@1XKf@0cKfS0=JnY@3J`JL0f/>V0=[5
[03Kajl0fLJ^0=S4Z`3F`ZT0e;nY0=6jX`3<]j80c;RU0<JeX`34]:@0^JfP0=7=a@33`;T0a;nj0;^b
Z`2j]:d0_;Ve0;Vf]02@RY80^JN/0;2GUP2XTiD0a[bo0<k?dP3;e=T0bM?J0<WBfP38d=T0a/kG0<33
_P31`jh0`<[=0<7=e`2oc=P0U::`06=ePP26UYl0[:b/01SS4@0@003o00Sooooo1P00o`000`1XZ3`0
X23`0:0Pl0060:0Pl0030=1@N02P8?00X23`01/0X23`0`3@D7P01@2P8?00d51h0=1@N03@D7P0X23`
00<0^3Rd00<0d51h0?n0003oP0000P3oP0001`3XJ3`0d51h0>QX?03@D7P0oh000=1@N02h>;@00`2P
8?000`3@D7P0D91h003o000?003o00_ooooo000:ooooo`1E003o002dW800RIRM051MGP0@0`80:P<5
02/10@1I10D0Q0<608d2202@0@L0U@870:432@2[1`/0[``>0;8?3P2j30`0`Pd<0<@<2`373@/0b`h<
0<`@3P3=40h0`Q@A09=6?`3NeM40h>3Q0>;Ri@3Qgn40i<W80<=YHP2o91`0bQ8?0<`C3`395A00[1HB
06<F3`2>MFD0eLVj0>;Me03Rh=d0gMkK0=oPg@3OhMh0g]oN0>7Rh`3Qh^40h>7Q0=oOgP3Mg]l0gMkN
0=cIe`2WM6/0V0l;0:<92P2Q1PL0W@H709@61P2;70h0bYn;0=_Fd@2KLFX0M0T509@4102h2PX0`0X:
0;X<3@2i5aT0T`<608P62@281`/0N`T<07`m?032];80`l:o0<W9b@35a/X0b<oB0<G=d02nal/0^lK:
08nLW`2AUiL0JVAU08n4O003003o00Wooooo00@00?l00>QX?02P8?00^3Rd503oP0000`3@D7P0oh00
0?n000020?n000030>QX?03@D7P0oh0000D0oh0000<0^3Rd0:0Pl03XJ3`0303oP0000`3@D7P0oh00
0?n000040?n000030:0Pl03oP000d51h00D0oh0000<0j6Pl0?n0003oP0000P3oP0001@3@D7P0oh00
0?n0003oP000j6Pl00<0oh0000D0j6Pl0;Ph]02P8?00^3Rd0>QX?003003o00Sooooo1@00o`00A00Y
da/0QWIJ08YoI@2KT7P0XiR00:RLP`2[Vgd0[ieo0;FNO`2oVgd0^Hi_0;jOO`2kX8<0_:220;nQO`2o
XH00_j5n0<6RO@2UT7@0GF9I07QmL01hOG@0HfiZ07MkK`3>_j@0dl2T0=O1YP3J`jL0g<J/0=[7[@3J
aJ`0fLF]0=O1ZP3E_jX0ckbT0<bhX039]Id0aK6L0<ZlZ@2k[9/0_K:S0<:j/03>b/<0a[fh0<Z_Z`2c
M6l0ZTM30:HV9P2/5aT0[A<E0:XC5`2V72<0ZT160;J2QP3>aLT0bM;H0<[Df`35cmD0aLRl0:nWJ@39
bK<0_lWB0;O5c`2KYkL0D69`06enQ`2GWj40B;lk4000o`08ooooo`D00?l000<0D91h0:0Pl02P8?00
3P2P8?000`3@D7P0X23`0:0Pl00E0:0Pl0070;Ph]03@D7P0j6Pl0=1@N02h>;@0d51h0>QX?0030?n0
0080d51h00<0^3Rd0>QX?03oP0000P3oP000103@D7P0oh000=1@N03@D7P50:0Pl003052@N000o`00
0?l000h00?l02oooool000[ooooo05D00?l00;BTR01KKG80DEiO01L41@0_10L07`8301`10@1N10H0
Q@8408X1102?0@L0WPD;0:<73@2N3Q80XQ0B0;@>3P2l3@d0```;0<H=2`393P`0bPl<0<PB3@2K7QD0
c;6X0>;Og`3Ng^00g]kN0=o5``33De00bA`E0=8E403D5A00d1P@0;TJ4`1h71<0Yi1n0=gEb`3Pg]X0
h>3L0=oPf`3Ngml0h=gO0>7Pg`3OfmP0h=7A0>?Bd`3RgMX0h>7O0=oOg`3Ngml0g=CA0914?02N3@T0
Y0P90:H72@2P1PL0T`P709Th:@3<[9/0f]7A08YBC@202PL0RP<30:T92@2k2PX0^`X<0;L72`2/2PX0
S0@5098>4P2520X0Uchh0<J/ZP39aL@0^[^i0;o4a03?f=X0bm?G0<G>e02la/`0Tj6R08J>S`1MFed0
ThV100<00?l02Oooool01000o`00j6Pl0:0Pl02P8?0D0?n000060;Ph]03oP000oh000?n0003XJ3`0
^3Rd1P3oP0000`2h>;@0d51h0?n0000=0?n000030=1@N03oP000oh0000@0oh0000<0X23`0?n0003@
D7P02P3oP000103XJ3`0d51h0?n0003XJ3`50?n000<0X23`00@0d51h003o0000o`000?l02?ooool4
003o001502KA6P1`MDl0QWeY08R1K02HTG`0XiZ30:NLQ02ZVh40[Yf30;6OPP2dXH80^jB60;NNOP2d
W7P0]9eg0;ZNN`2lW7L0`9ig0;jMK`2hVg00IEm@05ANE`1OIEh0K6aO0;JWT03B_J40dknU0=BnYP3H
`ZP0fLBZ0=_6[P3IaZl0f<F^0=O2ZP3C_jT0c[fT0<bhX039]Id0`k2H0<JbW`3C`k80`k:S0<Zi[P2m
Uh`0]5eG0:dS7`2b3`l0/`P;0;@82@2f20T0]`L90;H62@2c1PT0/@L:0:P;4P2Q<ST0`j>W0<W@f036
dML0a<k@0<2oZP2/YGD0`LNm0;W3b`2b`<`0C5e^07B5S@2@VId0Ik1K01000?l02?ooool4003o0003
052@N02h>;@0X23`00h0X23`00<0d51h0?n0003XJ3`05P2P8?00102h>;@0X23`0=1@N03XJ3`90?n0
0080d51h0`3oP000103@D7P0j6Pl0=1@N02h>;@50:0Pl1000?l02oooool000[ooooo05H00?l008Z;
G`1:GE`0DUmO01T20`0X0P<0608200D1000P0@40IP@507d110260PD0TP880:06302]6Ql0ZaPK0;DR
902V5AD0]Pd>0<@=3@363PT0aQ4:0;<K4`2PHEP0h]cK0=oOh@3Jf]`0f<O30;M@AP335a40ba8<0<dB
3P3?5A00[1TB07<X7@2bV8/0h=WC0=cKfP3LgM/0gMkK0=kNf`3NemD0f<2o0;n<R@2WCd/0WS4]09Dh
<P2dU8X0g]kL0=gLgP3Pf]T0^I:?08TE5P2P2@/0Y`X;0:@8202M1`L0S0/70;EXE@3;]jT0e<S607ha
:`2:1`H0S`@609<20`2b2@T0^0T80;L92P2e2@/0U@<508H;3P2G:BX0QA/J08Y<B02m[j`0b/c=0<W?
d@36cm80bmCJ0<_Eg02i`lT0WJV^08bEV01JFeh0T8J000Kc0@800?l02Oooool01000o`00^3Rd0:0P
l02P8?0;0?n00080j6Pl1P3oP000103XJ3`0oh000?n0003oP0020>QX?0H0oh0000<0^3Rd0>QX?03o
P000103oP0060=1@N0<0oh0000<0d51h0?n0003oP000103oP000102P8?00^3Rd0?n0003XJ3`90?n0
00040>QX?03oP000d51h0=1@N0H0oh0000D0^3Rd0:0Pl02P8?00d51h02S8?002003o00Sooooo0`00
o`00AP07m@D0E8ln08nCQ@2f]k80S8Yh09VDO`2RVhL0Y9^40:VKP@2/WH40/:260;6NP@2dW7h0/iUh
0;BJM02dVg<0]i]a0;ZJK02nVg00_YUZ0;nNK02eV6`0XXeX0;>KNP33YH@0bZn:0=6kW@3C_Z@0e;nU
0=O0Z03I`jX0e/:/0<2cX@2o/j40cl6[0=;0Y`3@_:<0c;RO0<VeW@37/YX0b:nK0<BZUP38Xi40_FUM
0;<U8@2g3Ph0^@/;0;L82`2e1`X0]PT:0;H:2@2g2PX0]PP;0;45202`1PL0[`H80:X7302I6b40^iJK
0<O>d`2maKh0_[bC0:nUB`2k^800`<O70;[4cP1JJGP0Jgn909NUZ`1iXfh@003o00Sooooo0`00o`00
100Xb3`0^3Rd0:0Pl03XJ3`;0:0Pl0040;Ph]03@D7P0oh000>QX?080oh0000D0j6Pl0=1@N02h>;@0
X23`0=1@N00A0:0Pl0030;Ph]03oP000oh0000/0oh0000@0j6Pl0;Ph]03oP000j6Pl0`3@D7P00`3X
J3`0^3Rd0:0Pl0020:0Pl0030;Ph]000o`000?l000h00?l02oooool000[ooooo04800?l005^B?@14
EU<0G6QW01d4100R0P<03@4000400@0@0@40@`4207051`1l0@@0R`870:062`2[2@h0X@L<0:L?4`2J
20X0[``=0<0<30353P/0`1@=08dQ5@36ZZ@0gM_N0=oOhP3Ke=<0_81i0;HK5@333P`0a@`90<L?3031
5a@0NRLN0;ZRT`3Oelh0g=cK0=_Kf`3NgN00gmgL0>CGe@2dPGh0Sc8_0:8Q7P2^5a@0X1hJ060I3P2_
Vhh0g=_H0=cFe@3B]K40UChg09/=302R2@`0XPP80:061`2I1PP0TQP>0<>7L03?`[L0bKVe07TK5`2@
20T0T@D708d1102R1PL20;H72@0B0;@81P2U2@T0O@D50;=GF`2;3A00OadN0=Nj^P3=blh0]kbn0<gE
f@3<eMd0bM?L0<WBfP2AWZ80TYfP04a?D@2>QWd05L`30P00o`09ooooo`04003o002P8?00X23`0:0P
l1<0oh0000D0d51h0?n0003oP000oh000:0Pl0060?n000030:0Pl03@D7P0oh0000@0oh0000<0X23`
0?n0003oP0000`3oP0001@2P8?00oh000?n0003oP000d51h00H0oh0000<0X23`0=1@N03@D7P02P3o
P0000`2P8?00oh000?n000050?n000030=1@N03oP000X23`0080X23`00@0d51h052@N000o`000?l0
2?ooool2003o001701GQ3@1QJdP0TiJ=0:bk_030b<X0S8f109ZHQ@2OVhT0XYb40:NMQ@2XVGX0[I]m
0:nKO02`VGT0[IIa0;BJM`2cUW80^9M/0;REH`2kUV80`9]Y0<:PL031Wg40`j1d0<BUO038Ygl0bZb6
0<bbTP3A_9l0dKnT0=NoZ@3B_j`0Ui:30:bUU@2SVXl0R8Mm0<c0ZP3?_jD0cKZQ0<bdWP3:/I`0d:2A
0<UhKP2j?cP0^a8A0;l;3P2m2@/0^`P<0;T72P2d1PP0/`L90;@62P2e20/0/0L90:l83@2_1`/0[PH8
0:X5202W1PT0UA/O0<J][P34c<@0]Zmh0:NG6P2WVaP0]kI[0;c3[`1ZNh@0E6ik08fNY@2@RXH04000
o`08ooooo`800?l000D0@>000;Ph]02h>;@0j6Pl0?n0000<0:0Pl0L0oh000`3@D7P@0:0Pl0030>QX
?03oP000oh0000d0oh00103XJ3`20:0Pl0030=1@N03XJ3`0^3Rd00<0X23`4000o`0;ooooo`002_oo
ool0EP00o`00DH<[05aZI`1CGUd07@@401H10@050@000@0001<10P0`0@80CP4206l310240PD0W`D:
0:/8302E20/0VRX/08T:2`2`3`h0``l<0<<=2P2c81D0TUI60=cDcP3Mh><0hmkP0=6TX@2a=Rh0`14?
0<D?3P353P`0a0l=09DE402^Rh00h=S?0=gLf03Kg=`0g=_L0>3Lf`3C_KX0Y5aJ09dT8`2V5aH0[AHC
09dJ5P1X9Q/0X8Mi0=[@b@3NfMT0`jRQ0953>`2G5Q80X@X;0:<9302Q1`T0V`H709051P2D:1`0_8mj
0=?:`@2hWIT0OA8>08d41P2;0P@0S0<709D21@2`20`0]`P:0;D72@2`20T0V`H808L8302;1`/0QAHH
0<6ET`30^[/0`lG90;o5b@37cmL0b=3J0;o:e02V]K`0PY:E05]NH@27N6l05L/20P00o`09ooooo`04
003o002P8?00X23`0;Ph]0`0oh0000<0j6Pl0?n0003oP0000`3oP0001P3@D7P0j6Pl0?n0003oP000
d51h0>QX?0D0oh0000<0^3Rd0=1@N03oP0000`3oP0000`3XJ3`0^3Rd0>QX?0030?n000060>QX?02P
8?00j6Pl0?n0002h>;@0d51h1P3oP000103XJ3`0X23`0=1@N03@D7P=0?n000030:0Pl03XJ3`0oh00
0080oh0000<0j6Pl0;Ph]02h>;@00`2P8?000`1@T7P00?l0003o0008ooooo`800?l004P0CHPh08R:
PP2]^;h0IG^10<O@e02>TXX0U9F609fIQ`2OUh@0YYR50:JGN`2ZVGX0YiAc0:fIN02^VW@0/9Ue0;>G
M02dU6L0]iAQ0;ZEG`2nVfL0`j9d0<BQMP32X7H0aJIm0<RYPP3=[hd0cK6A0<niV`3C_ZD0e/6Y0;BT
UP29Qh40]K2S0:jYWP1]M6h0^kFT0=6oY`3@_JH0d;JR0=BGR@30>S@0`QTC0<DA3P3330/0_PX:0;X:
2P2j2@X0]PP90:h;302T51H0WBX_08he@01m>DP0NCY:08LhA02F9bd0W`/@0:P62@2R1@`0VD140<S9
bP34b/L0[J5@0:ZH202^W`X0/:<_096>CP1XMW40QYBG09NCTP0Fg``?003o00Sooooo0P00o`001@2h
>;@0X23`0>QX?02P8?00oh0000T0X23`00<0^3Rd0:0Pl02P8?00203oP0000`3@D7P0X23`0:0Pl00=
0:0Pl0030>QX?03oP000oh0000L0oh000P3@D7P0102h>;@0X23`0=1@N03@D7P30?n000040=1@N03o
P000j6Pl0=1@N080X23`00<0^3Rd0=1@N02P8?000P2P8?000`1@T7P00?l0003o000=003o00_ooooo
000:ooooo`1F003o001MSC80JWId06Y`L`0M1PL03P4100D20@010@404`8302P10@0_0@40A`4207X2
1@2K10X0Y`H<09l<3P2YADH0YQ`K0;`<3@3330X0`a0;0:U1=03E_kH0gmoP0=oOhP3AYJ@0/3@^0;dE
40323Pl0bA8@0<LA302a5@l0UU]<0=O@aP3If]L0fm_K0=cKf@3FdL/0VXf2080h;`2Q61D0ZQHF0:@I
6`1o6QH0ICX]0;j`XP3Pf]80hM_H0<NSW`2A;BL0U`h=09l;3P2Q2Pd0WPP:09l82@2K20T0T@T609m4
<`2jWX`0e/o:09Y]I`222PP0S`@708h21@2:0PD0R08309820`2_2@/0/`P:0;@91`2]2PL0T@<308D7
1`1l3@h0PSXk0<F_[P2k^k`0`LG90<_@e039d=H0`lcD09j]/P2FYZX0FEeN07e[G00Gc082003o00Wo
oooo00@00?l00:0Pl02P8?00X23`303oP0000`2h>;@0oh000?n000020?n000040>QX?02P8?00oh00
0?n00080d51h1@3oP0000`3@D7P0^3Rd0?n000020?n000030>QX?02P8?00j6Pl00@0oh0000H0j6Pl
0:0Pl03@D7P0oh000=1@N03XJ3`70?n000040=1@N02P8?00j6Pl0>QX?0d0oh000P3@D7P50?n00005
0;Ph]02P8?00^3Rd0:0Pl01@T7P00P00o`08ooooo`1:003o000PcQL0N7ea0:bg^P2f`lX0_<W@0<_B
e`2GViH0U9:409bEQ`2OUH@0XI>00:>FO`2UUG/0YiEi0:fFM`2[UFh0ZiM^0;:HM02bTVX0/Y=O0;NE
H02mVVP0`J5c0<JSN`34YGh0aJMo0<RXP@3;[hh0c;>D0=:jW`3B_:<0eL2X0;f[W@1_L6l0NX5m06mj
M01VLVT0aKfZ0=C1[P3H_jd0eXf20<4X9`3:4Q40b0h<0<X?3@393Ph0`0/<0;T;2`2a4A80Y2ld07M0
DP15?EX0>D=V04UAL01PJ840K7^D04]TQP1VLhd0RUm^09PO:02R1`/0U@`@0;FCUP32cM00];1o07U/
5`2ER`h0[Z0709j@4P1GG440NXV?0:2PX00QfQL?003o00Sooooo00<00?l0052@N02P8?000P3XJ3`2
0?n000T0X23`0P3@D7P00`2P8?00d51h0?n000030?n000040>QX?03@D7P0^3Rd0;Ph]0h0X23`00<0
j6Pl0?n0003oP0001@3oP0000`3@D7P0X23`0:0Pl0070:0Pl0070>QX?03oP000oh000=1@N03oP000
d51h0;Ph]0030:0Pl0040;Ph]02P8?00X23`052@N0l00?l02oooool000[ooooo05H00?l006RI@@1l
RY00K7Z301H61`0>0@401`4100410@0B0@40;04202l00P0f0@40K0<809P52P2X20d0ZPX>0:LB502h
40l0`@`;0<D>302m4`d0]g=V0>3Je03Kg]h0fM3B0:]=B02g4a40_a8?0<8B403740l0aA<>09HM503D
^Zd0fmWE0=OGeP3Mg=d0fm_I0=oJd`37^Zd0Mcha0:DO6`2D81d0GQHB05@e:P3=_k80hmkH0=oKf@3B
]KD0Tc4]0:8B3`2T30h0X`X>09l8302O2@T0VP@609d72@2C2@H0ZEa:0<bgZ`3Ec//0PTQ008<51@2:
0@@0S@8708X210280P<0Q`010:06202]1PL0[`H60:l7202J0`<0PPH508@F5`1_5AH0Z8>10<[<c@2l
`<<0b<_A0<_Bf02ka/h0^/K=08BCV01[Kg40OfeO01S<0P800?l02Oooool01000o`00X23`0:0Pl02P
8?0A0?n000050:0Pl03oP000oh000?n0003@D7P01P3oP0000`2P8?00oh000?n000020?n000030=1@
N02P8?00d51h00<0oh0000@0d51h0:0Pl03oP000oh000P3@D7P80?n000040=1@N02P8?00oh000=1@
N0h0oh0000<0d51h0?n0003oP0000P3oP0020=1@N0<0X23`00<0D91h003o0000o`002?ooool0BP00
o`00EHA70:B_/02e`l`0_/kG0;O9d036dmP0WJ>P08n?P`2GThL0X9N:0:6CPP2STgd0XiAj0:BAM`2[
TGD0[9Ab0:fEKP2/TVX0[i5Q0;>DH@2fUVD0_Ie[0<FVN`36Yh<0aZR70<J[RP3;[Xl0bk:E0<^fV@3?
^Yl0dK^R0=G2ZP3G`jh0ZinA09>AQP2MW8h0^k:Q0=C5/`3G_k00eXf40<HY9P3@4a@0ca4B0<d?3`3=
4100b`d@0;/A4@2Y=ST0KdMO034lH@1=FgL0SiJN0:f`/P2X[K80TifY07^>XP0kEgH0V[S70<OAfP2k
Vj80UR4W09d83024=cl0_<;:0;:_MP24LQ@0Jf4>08B03P2PU0X0T8Xa08J@O02HWY/0>l@/3`00o`08
ooooo`04003o002h>;@0d51h0=1@N0<0oh0000<0d51h0:0Pl02P8?00202P8?000`2h>;@0oh000?n0
00030?n00140X23`00<0j6Pl0?n0003oP000103oP0001@3@D7P0X23`0:0Pl02P8?00d51h0080^3Rd
00P0d51h0:0Pl02P8?00X23`0>QX?02h>;@0j6Pl0?n000<0d51h00@0^3Rd0=1@N02P8?00X23`0P2h
>;@00`2P8?00J:Pl003o000>003o00_ooooo000:ooooo`1F003o001/WTX0QiJO07N6T@0<0`@03041
00L10P010@405`8203<20`0c0@80=@410581102>1Ph0Y0H;0:d93@2_2@`0^@/=0;d<3@3330d0]b8J
0=^dZ03Mg]/0g=kO0<bYZ02V8a`0XQ8@07T=2`213@`0_A@B0;LP5`2PF4X0g=?<0=SIeP3JemH0g/o?
0=g8a03Qf=@0h]_F0<2VW@1Z9al0HSP[09>0L@3?a;P0i=kI0>?Fe02jV9H0UD4n09hF4P2V3P`0YP`>
0:<93@2Q2PX0X@P80:062@2M1`X0TP/70;UlJ@3Ic/D0clG107L[90241080R@8408/31P2:0P@0R@84
08D20P2>0P<0Y`H70;LE502^1`T0Z@/908TD4`2[E5H0KA`M0:9dL02e];<0`<K90<C;d033bm@0bM?N
0;?1b@2N[K@0JW1d08=dJP0Gc0@2003o00Wooooo00@00?l00:0Pl02P8?00X23`4@3oP000102P8?00
oh000?n0003@D7P60?n000030=1@N03XJ3`0oh000080oh0000`0j6Pl0?n0003oP000^3Rd0?n0003X
J3`0d51h0:0Pl03XJ3`0oh000=1@N03XJ3`90?n000040:0Pl03@D7P0j6Pl0>QX?0`0oh0000<0^3Rd
0?n0002h>;@00P3XJ3`0103oP000j6Pl0=1@N03@D7P30:0Pl003052@N000o`000?l000Sooooo04X0
3nd;09RNV@2d`/T0]/G>0:2d_@2F[;<0/L;80:F/[P2>ShD0UiB909bFR@2NU8D0X9B10::FO`2UUgl0
YYAi0:fEM@2]Tfl0[95Y0:n?HP2dU6<0]iEU0;fLK@32XgX0`jV70<F[S`38[Y80bkBG0<beV`3=^Ih0
d;bP0=6mX`3E`JT0el>^0=[7/03Ib;H0elRh0=O7]@3G`k@0fIN=0<@Z903?5140d18A0<d@403=40l0
b10?0;/Z;P24C680<d9Z05Q]RP2LX:80c<K10<Fg]P2lXZ<0/I:C0;FIU@2WX:80O8fP06J5X02md=X0
c=;H0:ekPP2C3A<0RQXP09fIX@2c[g`0ZI@E095o2P1ME`/0MG8=09jB2P2LU2<0ViQ[05Bk@Pl00?l0
2?ooool0200Xb3`0^3Rd0;Ph]03@D7P0X23`0;Ph]03XJ3`0d51h2P2P8?000`2h>;@0oh000?n00002
0?n000030>QX?02P8?00X23`00h0X23`00<0j6Pl0?n0003oP0000`3oP0001P3XJ3`0X23`0:0Pl02P
8?00^3Rd0>QX?080d51h00<0^3Rd0:0Pl02P8?000P2P8?00103@D7P0oh000;Ph]03oP0020=1@N004
0;Ph]02P8?00X23`0>QX?080X23`00<0^3Rd0=1@N01hF;@03`00o`0;ooooo`002_ooool0EP00o`00
L:=?09BVZ`1`PhX01`<400T10@040@400P0001T20P0e0@80=`8103X20P160P<0M`H:09h93@2Y20`0
[@P:0;H:2`2n3Pd0`@l;0<15>P3Nc<D0g^?R0>3Lg@2^FeP0Ma0=04/M601TDDD0PDm40:@Q5035JED0
b;2R0=WHeP3Kb<L0aHB00;i7@P2e=Bl0`Y6:0>;LeP3Of=<0YYV:0=K>_`3ThM/0h^;P0<C8aP1iH5d0
GBHS05LF4`1M4a00LQ0@090B4`2L30`0X@P80:47202P1PT0W0H909HI4P38Wi00fmC@0<2]Z@1j5a<0
RP<408L10P270P<0Q`8408H11@260@<0Q@8209h6202]1PP0/0D70:X;3@2Z>Ch0OQ<D08hT8`1h:bT0
a[Vi0;c1``30bld0`LcB0<C@f@2iam80U:B]071lPP1mN7805L`50P00o`09ooooo`04003o002P8?00
X23`0:0Pl100oh000P3@D7P20?n000030=1@N03oP000oh000080d51h00D0oh000:0Pl02h>;@0oh00
0>QX?0020=1@N00:0>QX?03@D7P0oh000?n0002P8?00^3Rd0=1@N03oP000j6Pl0=1@N0/0oh0000<0
X23`0?n0003@D7P0303oP0000`3@D7P0oh000?n000030>QX?080oh0000<0j6Pl0;Ph]02P8?000P2P
8?000`1@T7P00?l0003o0008ooooo`1:04?@>@2ja/d0/lCA09Z_^`1hTid0QIfS0;g;dP2^]KX0S8j7
09ZHS02LUXT0WYJ60::HQP2RV8@0X9=m0::CN@2ZU7L0[95^0:nAJ02`T6<0]9=U0;NEJP2mWGD0a:J3
0<:XS034[900ak6D0<VcV@3;]YX0b[NK0=2lX@3D_ZH0e[nY0=O2[03JaZl0elNb0=K6/@3Ga;00gZnR
0<Di<P3D6180daH?0<hA3`355180^R4P0:]7DP1BCWP0@EQn096BV02cYY/0^YJ<0;9WHP2]=C@0ZQPL
0:@>4@2S4aD0XS4c0:MmP@1[NY00_LoJ0<WBf@3;`/P0SRTb08h>5@21M800_<K40:jVI@2VU@l0X94;
06YQ1`2CRP`0VHl80:NJ901hZ40?003o00Sooooo00<0J:Pl0=1@N02P8?000`2P8?000`3XJ3`0d51h
0:0Pl0090:0Pl0050=1@N03oP000oh000?n0003XJ3`0402P8?000`3XJ3`0oh000?n000030?n00003
0;Ph]02P8?00X23`00<0X23`00<0^3Rd0=1@N03XJ3`00P3oP0002@3@D7P0X23`0:0Pl03XJ3`0oh00
0>QX?03@D7P0oh000:0Pl0020=1@N080X23`00<0d51h0:0Pl02P8?000P2h>;@?003o00_ooooo000:
ooooo`1F003o001]XT`0RYfQ06UhP0080`@00`4100400@010@406@8103/20P0o0P80?`8304P1101R
0PH0Q0D<09l73@2/1`/0/`X:0;`;2`2o40h0afIL0>;He`3Ph><0eKZi090X8023EDP0`[FX0=;<``3L
b;h0Y5Y50<bKR03KdLP0fMKB09QYHP2@9b40QAXD05PD3@1VCd80clJk0>;OfP3Ng=H0gmgK0<_>c@22
RX@0B59906]TFP28O6l0Rgmb07]`I01DAS`0<a4>068>3`2I30d0X@T:0:871P2N20L0X3DU0<bbX@3H
d]40Zhb8084>2`2<10D0RP<408D10P250@<0Q04508@20`230@80S`<40:/8202^1`P0[0H70:H93@2C
4Q<0TA`K07hR8030Z:P0/;Bf0<O?d`33c]D0a<kG0;_5d02@X:P0M86607A`JP0Fc@L2003o00Wooooo
00@00?l00:0Pl02P8?00X23`403oP0002@3@D7P0oh000?n0003@D7P0oh000=1@N02P8?00d51h0;Ph
]0020:0Pl0030=1@N03oP000^3Rd00<0oh0000<0d51h0:0Pl03oP0000`3oP0070=1@N0H0oh0000@0
d51h0:0Pl03oP000d51h403oP0020=1@N0030?n0003XJ3`0d51h00@0X23`00<0D91h003o0000o`00
2?ooool0701>cDT0]L;=0:6ea01YQ900B6I/09ba]`2nc]D0]Ko308b>R02FUHX0VIB909^AQ@2PUH@0
XiJ30::CO`2QTGT0Z9=f0:Z@KP2]Sf@0/I1X0;:DJ`2dUV/0_9mi0;nPO`36Z8`0ajbC0<B]T`3;]I`2
0<bgW`0/0<nlX`3B_ZD0eL2Y0=K1Z`3G`j/0fLJ_0=S8/@3Pa;40bf1G0<lJ5@3E6100e1D@0<8L5P2U
DEd0IEEi0399N01fRIl0/jZO0<2MSP2gGUL0[R0P0;D<3P2j20/0]PH90;051P2a1PL0/0L90:0F6`1]
CfD0Pifa0<OAfP3<d=T0W5aU08h<501aE680]<O@0<;8`02[XTL0Zi`70::C1@2APP`0JfL609ZB301h
Z14?003o00Sooooo00<0D91h0;Ph]02P8?000P2P8?000`3@D7P0oh000>QX?00:0:0Pl0040>QX?03@
D7P0^3Rd0?n00100X23`00<0d51h0?n0003oP0000P3oP000102h>;@0X23`0:0Pl02h>;@20:0Pl003
0;Ph]03XJ3`0oh0000D0oh0000<0j6Pl0:0Pl02P8?000P3oP0001P2P8?00oh000:0Pl02h>;@0j6Pl
0=1@N0H0X23`3`00o`0;ooooo`002_ooool0@000o`00KZ9<08^NX`1AGVD02@840080000000000P00
02830`0k0P<0?@4103l10@1=0PH0H@8:06d01P2D1``0[0P<0;@82P2l2PX0_a4>0<UeK03Ug]h0h^7R
0;fDT@2=<240ckBW0=GAc03Ce]@0f<_60:EZF@3C/J80gMOC0=3;aP0j;B<07P`302PJ3`1nM6D0bKn_
0=gGc03Ng]T0g=cH09^QU`1HGU40Wj6C0<k7^@3Kcl@0h=G=0=kEcP3Md//0bkjb0:bNT`1:91l0Ra0D
0:8;3@2S2PL0WPX80:Q??@3<_K00eM3?0:=iMP2830`0S`<709052@270@@208810`0D084100240P@0
R@430:<62@2Z10H0[0H60:h92`2D1`P0QPh>07DF5`3;[k<0`lG80;g6b@2iaLT0aM;I0;K6cP2S];/0
MH>7071]J00FcPP2003o00Wooooo00@00?l00:0Pl02P8?00X23`403oP0001P3@D7P0oh000?n0003@
D7P0oh000:0Pl0<0oh000P2P8?000`3oP000d51h0?n000020?n000<0X23`0P3oP0050:0Pl0<0oh00
0P2P8?050?n00080d51h4P3oP0000`3@D7P0oh000?n000020?n000050=1@N02P8?00X23`0:0Pl01@
T7P00P00o`08ooooo`1:08fCK`2a`/d0NI:P03mMIP1CL7L0Q9bT09^a]P2mbL`0RHn;09FES02IUX/0
ViF709fFQ@2QTh<0Xi=o0:BDO02WU7L0Yi5^0:V@J02`T6L0/IA]0;RKMP2iWG`0_J630<FZS037[I<0
a:fD0<VcV`3<]Yh0ckNO0=2lY03@_jL0e<:/0=K3[@3HaJh0fLRa0=[7]@3LVY00abLP0=HI4P3D5`l0
abHP09MLK@0bC7L0FG>C09jQY`33/:<0aiB70;@m=`2g40l0^`X;0;P72P2j1P/0]`L:0;452@2b1PX0
/PD80:/72P2BA5@0Df^:0<7Cg@37dm/0ZH>;08`>5`1U@E40/lSC0<;?e02l_9@0/J<`0:NF1@2MSPH0
HU`806AS202GQ@h?003o00Sooooo0P2h>;@40:0Pl0030;Ph]03oP000X23`00T0X23`0P2h>;@B0:0P
l0<0oh0000D0j6Pl0;Ph]02P8?00X23`0;Ph]0020:0Pl0030>QX?03oP000oh0000L0oh0000/0^3Rd
0:0Pl03XJ3`0oh000:0Pl03oP000X23`0=1@N03oP000d51h0;Ph]0020:0Pl0030>QX?03@D7P0X23`
00l00?l02oooool000[ooooo05H00?l006FF@@1MK6l0DEeP00@20P020@40000000<0000Q0P<0=083
03410@0e0@40BP8505h3201U0`P0P0@90:/9302g2@X0_P/;0;`A303<P7D0hn7Q0>;Si@29O7@0RVUM
0>3He03Mg=d0fmWI0=B[ZP2dFdh0fkFX0=gIe@3Hdm40YY^A09jDQP2i[Il0d/[10=cJd`3LgMH0gMgJ
0<g7_P2]ZIH0e]C40=kLdP3NfmH0g]cJ0=oMg03Lf]X0gM_L0=gIf@3Id</0ZiJ?07TH5P2L2`/0W@P7
09P=2@2eL5d0d/[20=OAd02DH5`0S@`<0984202A0`H0S@<608D110260PH0P`4408H21@250PL0V@H9
0:`7202_1PL0[@H80:882`2;1`X0P@hA08M3A@2j];@0b<oC0;k8c@31cMD0^<O@09NX[`1lRXl0LFiY
01O>2@800?l02Oooool01000o`00X23`0:0Pl03@D7P@0?n000060;Ph]03oP000oh000?n0003@D7P0
j6Pl0P3oP0020=1@N0030:0Pl03oP000oh0000<0X23`0P3@D7P20?n000050=1@N02P8?00X23`0=1@
N03XJ3`01P3oP0000`3@D7P0oh000?n000020?n000040;Ph]03@D7P0oh000=1@N100oh000P3@D7P3
0?n000050=1@N02P8?00X23`0:0Pl01@T7P00P00o`08ooooo`1;09f?NP2GZKT0AfId04]ZL`1QOX@0
Wk>k08:IX034cmD0Ri6@09:CS@2JUXl0VI>709bFQ@2NTh00X99k0:>EO02UUGX0Yi9a0:jBL02`U6d0
/IE_0;RMN`2iXH80_ZN;0<>ZSP35[Y@0aZfC0<N_U@38/YX0cKNM0=2jX`3B_ZL0dl:Y0=G3[@3FaK40
elJ^0>6n[@37CTD0e1`E0=<F4`369b80Sf1h03EDPP2MY:`0`;BV0<F_W`3<T8@0^2`Y0;/<3@2l2@`0
^PT<0;@92P2/4140YRL]09P`=`2S5ad0[`H:0:d62P28<T<0?ef30:c6e037dm/0/I>N08X@6P1N=dT0
/LSF0;g;eP32cm40^;B30:RJ7@2RT`@0W90807a`2@2>PA008MT400h00?l02?ooool70:0Pl0030?n0
002P8?00X23`00T0X23`00<0^3Rd0:0Pl02P8?003`2P8?00103@D7P0oh000?n0003XJ3`60:0Pl003
0>QX?03oP000oh0000<0oh000P3@D7P02@3XJ3`0oh000?n0003@D7P0X23`0=1@N03oP000X23`0>QX
?0020:0Pl0030;Ph]03oP000d51h00D0X23`00<0D91h003o0000o`003000o`0;ooooo`002_ooool0
1@00o`00DX<X0760O01EIVH00@8200800@4103/00`4101X20@0/0@80<@4103L20P0o0@40BP4305@0
0P1`0PL0WPT<0;T;302o30X0_Q4>0<UeKP3Ge=@0eMOI0;Bd[P2j]k80e=KF0=WCe03>ZJH0/3/f0;HR
6P3<MF/0gl:o0=gFeP3Me]L0h=OG0>3Cd@3?`<00/jjT0=KAb@3OgMX0g=OB0>GSgP3Uin<0hN;P0=cL
f`3MgMd0gMgL0=cJfP3Mf]`0fm[L0=KFe@3JeM40XF=L09@>302J1`T0UaD?0<6@O@3Hd/d0em3;08]>
A@2<20L0UPH909<21`2?0PH0Q`8308D20`0208H20`0B08<31`290P@0YPT:0:`61`2^1PT0Z@X<0949
302L:BT0PR<S0<>_/02h_l40/kk20;k;dP2ib=<0[ko707b>T`1cLFh06<l:0P00o`09ooooo`04003o
002P8?00X23`0=1@N100oh0000<0d51h0?n0003oP0000P3XJ3`20?n000050=1@N03XJ3`0oh000:0P
l03XJ3`0103oP000103XJ3`0^3Rd0?n0003oP0020>QX?0X0oh0000P0d51h0?n0003oP000oh000:0P
l03XJ3`0oh000=1@N0l0oh000`3XJ3`30?n000050;Ph]02P8?00X23`0:0Pl01@T7P00P00o`08oooo
o`1;09Z8L@2>XJh0?UiX04][KP1^RY00SJB]09N]]033dMH0RY:A09:DSP2KUXl0VY6809bFQP2LU880
WI9n0::FO@2RTgT0Yi=f0:jDM`2bVGT0/YUf0;NPO02mYXL0^JB:0<F_U032[940ajjC0<ZbU`3<]Yh0
c;FL0<niY03@_ZP0d/2W0=?0[03E`jl0f<B/0>6/V`33:1h0f1X@0<`I502bG6L0:DQi09:Q/@32]:D0
a;6N0<nVUP2f>CD0a14B0;d9302j2@`0/``=0:0Q8`2AEVL0@C]P024UC@2<>dT0[0H=0:H92P1e>dd0
@FF?06Z;YP35e=/0/9BO08P?6@1M=4P0/<OG0;S6c`32d=L0^[f`0:bTGP2OTaT0WHd30:BE2@2AP0X0
@K8700h00?l02?ooool60:0Pl0030=1@N03oP000X23`01`0X23`0`3oP0020:0Pl0050=1@N02P8?00
X23`0:0Pl03@D7P0103oP0000`3@D7P0X23`0:0Pl0020:0Pl080oh000`2P8?000`3oP000X23`0?n0
00020:0Pl0040=1@N03oP000d51h0?n000D0X23`3P00o`0;ooooo`002_ooool0EP00o`00D7lQ04]K
E@17EeL0004100810@010@000P0101T30@0R0P40;08203d20`100@40CP4405d11@1d10T0R`D90;8=
3P2n2`/0`Pd;0;hg=03N^;P0gMSI0=[He`3Cc</0bZNX0;IRH@2a:2H0_Q0>0<DA402n5aD0_chk0<ij
N03;OGd0aVa[0;Q?CP1i=2l0_:jQ0>7LeP3NgM/0hN7Q0>GVi`3Ui^P0h^;T0=cMg@3LgMh0g]gM0=_K
f`3JfM/0fMWJ0=WHfP3HemP0^I>=094B4@2M30h0WR/O0<Z[W03Ie=@0f/c;08M2>`2@2@P0UPH90902
1P2>0PD0QP4308H30`230P80Q08308D31@240@@0U0@50:L71P2/1`/0[0P<0:P;3`2H20d0TA/H0:5k
N02b][P0^lK90;_8c`2ncMH0UJJ_08FEVP1cKVX06]4;0P00o`09ooooo`04003o002P8?00X23`0=1@
N100oh000P3XJ3`30?n00080d51h00@0j6Pl0?n0003oP000oh001@3@D7P00`3XJ3`0X23`0=1@N00=
0?n000050=1@N03oP000oh000>QX?02P8?000P3oP0000`3@D7P0oh000?n0000?0?n000050:0Pl03@
D7P0oh000>QX?03@D7P00`2P8?000`1@T7P00?l0003o0008ooooo`1;0:>:J`2:VJ@0Cf]b06F2QP1m
VJ00OIVQ07^FW@2kc=40T9ZH09>DSP2EThX0Ui6409VDQ02KU8@0WYJ30:>IQP2QUWh0YiIm0:nIO02`
V7L0]9em0;^RP`2kYXL0_:V=0<B^T`36[iD0ak2D0<NbU`39]9`0b[BM0<jhX@3?^jD0d;fV0=;1ZP3E
`j`0fL>]0=F5N@3?81/0ea`D0<4m>`1EEgd0JXNV0<:i/039]:D0djfQ0<5XG`2m5aD0aPl?0;d:3@2f
40l0XCm505=5IP0_@Vd0JWRD09N:V02P=CX0[@P;0:0P9@17>UT0LHf[07fJ/P34e=h0[hfJ08T>5`1I
=4X0Z<;B0;[:dP2oc]H0`/gC0;_2^P2YZ7H0UH`L0::C2@2EQPX0<lT800h00?l02?ooool00`3@D7P0
X23`0:0Pl0020:0Pl0030;Ph]02P8?00oh0001`0X23`00D0^3Rd0?n0003oP000j6Pl0:0Pl0020;Ph
]080X23`00<0^3Rd0?n0003oP0000P3oP000202h>;@0X23`0:0Pl02P8?00^3Rd0=1@N03oP000j6Pl
0`2P8?000`3XJ3`0X23`0?n000020:0Pl080j6Pl00@0oh000=1@N03@D7P0^3Rd0`2P8?0>003o00_o
oooo000:ooooo`1F003o001BP200JGE`04QGE`000@800P41004100020040608101T0000O0000=`<5
04010@1G0@H0KPD:07P31`241@T0Y@T;0;`<2`3130/0_a8>0<=AD03TZZ/0dJFT0;MfL`2U;2T0/a<B
0;d>2`323P/0aQ0=0<H@30375100aAPF0<4G60336aT0WAXF08UOD@3MeLh0g][J0>;Qh03ShnD0i^KX
0>GUi`3Ti>H0g]gM0=gKfP3Of]P0g][I0=_If@3KemL0f]SG0=WFe`2iUY80TA@A09L:202T@S40bkR[
0=CCe03KcLT0R3dg09072@2A0`T0S@<808X210290`<0R08308L10P240080Q04308@11@280080Y0L9
0:d82@2_2@d0[PX>09/82`273`h0XW1`0<g;c@2X/kD0_L_B0;K6d02hb=80OHfC07IdL@0V^0h2003o
00Wooooo00@00?l00:0Pl02P8?00d51h4@3oP000103@D7P0X23`0:0Pl02P8?0;0?n00080d51h3P3o
P0000`3@D7P0oh000?n000020=1@N080oh0000<0d51h0?n0003oP0004@3oP0000`3@D7P0oh000:0P
l0030:0Pl003052@N000o`000?l000Sooooo01l0P:iH096MX`1TOX@0M8jE06:0R027XjX0R:6Y0:fm
`P2HXZ<0SY6;096@RP2BSh<0UI:309ZDQ02LUhD0X9V60:FIQ02[VH40/IYn0;:MOP2dWh@0^j:70;VU
Q`2mZ8/0aJjE0<B/T@34[i80a[2F0<NbVP3:]id0b[ZO0080c[bT02X0dL2[0=G3[@3K`:X0bEA:0=DL
5@3::2<0Q65l05=aU`33^kH0cKZ[0<n]WP2lJ640]R0N0<L@40323Q00^@d@0;DD5@2?AE80Kg620:fW
Y@2iTXh0Yd0o0:L<3@2O7b<0GD5N03=BOP1INYH0DGF=0;W?gP2UOhT0Q`lE05LjCP2[aM<0^/OB0;_;
e@2kb]<0/[k70;>n``25Th00WJ1L09B;5`1iR@l>003o00Sooooo1@2P8?00102h>;@0X23`0=1@N03@
D7PK0:0Pl0030=1@N03oP000j6Pl0080X23`00@0^3Rd0:0Pl02P8?00d51h1@3oP0020:0Pl0050;Ph
]02P8?00d51h0?n0003XJ3`01P2P8?002P3oP000X23`0:0Pl02P8?00^3Rd0>QX?02P8?00d51h0;Ph
]03@D7P20:0Pl0h00?l02oooool000[ooooo04<00?l005:28@1BHE/0BEQG00420@030P400@0000<1
0@0L0@80;`8303D10P110PD0D`<506P4201_2Pd0M0L;08862P2I1`L0]`h;0<4=2P363``0a1HB0;TN
702`8Ah0[QHC0;T?3P323`d0``h;0<D?303540d0a0l<0<HA3P374@h0_aDB09dF5@1_;RH0bKV`0=kJ
f@3Mg=d0i>CT0>CUi`3UiNL0in?V0>[Ng`3M^;L0`h>20;1YJ@2]Kfl0dkbh0=WHeP3FeMH0fMGG0:b1
O@2A4Ph0U`h;0:QC@P3>`[L0d]?C0=K:a`2:@c/0TPP909@42@2;0PH0RP8708T210280PD0Q`440080
QP850140Q@8608820`2K20P0[@P90:h8302_2Pl0[1XL08<;302ADE80b<?40;O2``2mb]<0`<oJ0:>c
_026UYd0Lfm_03BQ4`02003o00Wooooo00@00?l00:0Pl02P8?00d51h7`3oP0000`3XJ3`0^3Rd0?n0
00060?n000@0d51h00D0j6Pl0?n0003oP000oh000=1@N0020?n00080d51h0P3oP0000`3@D7P0oh00
0?n0000?0?n000050=1@N03oP000j6Pl0>QX?03@D7P00`2P8?000`1@T7P00?l0003o0008ooooo`1<
06Ve?02EXJ40N8jI06^8TP1mV9h0NiJO08^SZ`30c]@0VZ:S08B7PP2;RX40TY:409FCQ@2LUXL0X9V:
0:2JR02WW8T0Zi^60;6MQ02cWhD0]j260;RQR@2jY8P0_:N;0<2[TP31[980`ZbB0<N^V036/YX0b;NN
0<^iX@3>^j@0dKjV0=C0Z@3Fa:d0hK^Y0<8d:`3C7QD0^EQQ04iHPP2iR980bWM_0=FVV@3;RX00Zb@Q
0<HE5@2o61L0Wd9=08=6EP2X;2l0ZaLF0<5eJ02cJ5d0Yb<P0:H?302F;cD0B3YL03QDO02:VZX0VJZh
09Fa`P2X`=00Vfeg08P>5P1D@5D0/LSG0;g9e02mbmL0_<gG0;;0bP2^_/X0Gg9m07f9N@2BU4h0VhdO
02;K1@d00?l02?ooool00`1hF;@0X23`0:0Pl0030:0Pl0030;Ph]03oP000d51h01/0X23`00D0j6Pl
0?n0002h>;@0X23`0;Ph]0030:0Pl0<0oh0000@0^3Rd0:0Pl03XJ3`0oh000P2h>;@00`3XJ3`0oh00
0=1@N0030:0Pl0050;Ph]02P8?00X23`0:0Pl03oP0002@2P8?000`3@D7P0X23`052@N00=003o00_o
oooo000:ooooo`1F003o0018MQD0?4Y304QEE`020@400`81000000050@008P8203d2101:0P@0E@85
06H5201g3A40Yc@g084D5`1l10T0T0@60:T82@303@/0a`h90<T@3@3330X0^PX80;L:2P2j2`X0^``:
0;/920313@X0`Pd=0<8>3`3340l0`Q8B08TE3P1_@CH0_ZfT0=cHe`3Kfm`0g]kN0>CSi@3[i>H0kLO8
0>>CUP3HGUh0aRXU0;lL6@2X4Q40WaTG0:MbJ@3Hem@0dmKF0=O>cP2AAd80VA0>09<@2`2ZIeH0dL[4
0=3?dP3HcLh0RT]408h8202B10P0S08608/32@290PH0R04408L21@270PH0R0<508821@2210L0T0@6
0:h93@2]20`0/0X>0:`=3P292``0UU]D0;>]Z02NZ:T0]LC;0;c=eP2^_lX0PI6I07QeMP0fXaL2003o
00Wooooo00@00?l00:0Pl03@D7P0d51h2P3oP0000`3@D7P0j6Pl0?n0000A0?n000030=1@N02h>;@0
oh0000@0oh0000@0j6Pl0=1@N02h>;@0j6Pl0`3oP0001@2h>;@0oh000?n0003oP000d51h0080oh00
0P3@D7P20?n000030=1@N03oP000oh0000l0oh0000<0^3Rd0=1@N02h>;@00P3XJ3`30:0Pl003052@
N000o`000?l000Sooooo04`0Dl</09RQWP2<XZd0J8J?06V6S`1cSYD0PIfU0:>f_02RZ:/0OX1k08V9
P@2ASX80ViN909bHRP2RVh`0Yin@0:fRU02cXYH0]Z>?0;NQRP2jXX/0^:::0;RTRP2lYhd0`ZjE0<:^
UP34[ID0ajjI0<NbW038]9l0c;NQ0<jjX`3A_jX0dKn[0=G3[`3P/Z40`BPP0<TU802UK7h0/EU[0<LN
8@386aP0^eeL0;Q_L02d7ah0aA<C0;/nA011@6H0P82@0<>1O@2/5140]10A0:h@402T8b@0MSa?02H_
F@1FMI00[[k6096PZ@1lTJ00@F1k09R``@2BF6<0RPlG05A9GP2ecM/0_LcI0<3<f@2oc=P0^LOC0:c0
c01eT:D0KXNC09fWV@2HTUP0>M4L3@00o`08ooooo`030830002P8?00X23`00@0X23`0P3@D7PK0:0P
l0080?n0003XJ3`0X23`0:0Pl03XJ3`0oh000=1@N02P8?020?n000040=1@N02P8?00X23`0:0Pl0<0
oh0000@0j6Pl0;Ph]02P8?00X23`0P2h>;@40:0Pl0030?n0002P8?00X23`00H0X23`00@0^3Rd0:0P
l03@D7P0J:Pl3@00o`0;ooooo`002_ooool0EP00o`00@Fh<05AQF01=FE/0108200D20P030@004041
030210170PD0B`4504h1101H0`H0PPT;09`82P2;2@X0MPD708h5202I0`H0/`X:0<8=2@363`/0aPl<
0<4>2`2i2@T0^@/:0;P:202l2`/0`@d;0<8>3@313Pd0`A0@09`D4P27Ge<0c<Bi0=cHeP3Jf]/0g=gM
0>;Ng@3YcLd0fWn30=8g=P3G7ad0g1hK0=<K5@3=6QH0^1LD08DJ5@2GP7@0emSE0=?De02fUiD0S1`J
09T>2`2<4@X0/GUZ0=G@c03@d=80e]7A08iRG0262`X0T08508h31@2;0`L0R`8608D10`230@<0PP45
08D21@280`L0R0<808/21`2X20`0/@P;0;<;3P2`30d0S@`<0:EiL@2DU8/0RYFA0;S5b`2da<`0^<O?
08JFW@1_Jf`0>:DI0P00o`09ooooo`04003o003@D7P0X23`0=1@N1d0oh0000<0^3Rd0:0Pl03oP000
0`3oP0000`3XJ3`0^3Rd0=1@N0060?n000040;Ph]03oP000oh000=1@N0<0oh0000D0X23`0?n0003o
P000oh000=1@N00A0?n000<0X23`00<0j6Pl0;Ph]03@D7P00P2P8?000`1@T7P00?l0003o0008oooo
o`1304O67P2GVY<0P9NR07FBWP1FN7d0Hh2308fU[025VJ40Yk:e07UmN@25QGh0SHb209fHSP2UWY@0
ZjBH0:nVVP2cYiX0]JNI0;6QS`2cWh/0]Z6:0;RTRP2jYXd0^ZJ<0;fXTP30ZI<0`j^D0<F_V037/IX0
b;BM0<biY03?_:H0cknY0=70[@3Ea:h0h;VU0;ha9`3>;2T0egEm0<DT9@3B5aH0`2<P07YDJ`2=N8X0
Z3ln0;PK6P2m6al0]T980;I0?@2`8Ad0]Ph>0;@<302E=SP0?CAA03Y6KP1oN8@0Y9B>0<G1`02i`<<0
W[2j07ZFZ`22VJd0RdM@08/C6P1ECfL0]/kK0;c;eP020;k>f0070;_=fP2_`/l0LX^L07NBW`2GY:L0
V9bF056Z@`0=003o00Sooooo00<0J:Pl0:0Pl02P8?00102P8?000`2h>;@0d51h0:0Pl00J0:0Pl006
0?n0003XJ3`0X23`0>QX?03oP000j6Pl0P2P8?000`3@D7P0oh000>QX?0020=1@N0<0oh0000<0d51h
0:0Pl02P8?000P2P8?020?n000<0X23`00<0d51h0>QX?02P8?001@2h>;@30:0Pl0030;Ph]02P8?00
N5Rd00d00?l02oooool000[ooooo05H00?l004Ac4`1LJF<0BEMH00<10@070@402P0001l10`0o0`H0
A`4404H310120@<0BP8408H:402E2Pd0M0D706/3102;10H0TP850:@51P2l30T0`0/90<@=2`323P/0
^@X80;X<2`2k2@P0``d>0<<=30323@`0_`/:0;HA401f9b00bKje0=SHeP3Jf]/0f]WK0>?JfP3O];<0
be]K0=HW9@3N7aX0eAD?0=<F4P3@5a@0aQTF09dJ5`1R;R<0b<:h0=KFe03:_;`0T4U809H@3P2H30X0
Q0l50;J6M`3Ed]00d=7C0=?Dd`2>Mg<0N0h@0944202?0`D0RP8408D10P220@<0OP0307h110230PH0
R@<908/42P290`L0X@L<0:h82`2b2P`0]0d=09d;3P2>AT80Xi><09:HU@2X]kX0_/cE0;2maP2?X:H0
MWIg03ZX7P800?l02Oooool01000o`00X23`0:0Pl03@D7PM0?n000030=1@N03oP000oh0000<0oh00
00<0X23`0?n0003oP0001@3oP0020=1@N080oh0000D0d51h0?n0003oP000oh000:0Pl00E0?n00003
0=1@N02P8?00X23`0080d51h0`2P8?000`1@T7P00?l0003o0008ooooo`1<02KK3@2GTXD0Ujbf05Yg
P01OOH<0FgUn05]eO@1jSI40/;Vl07IiM`21PGX0S8Uo09RDRP2TWiP0[JNP0:bSV@2`YIH0[J>A0;:U
T@2aX8`0/in70;VTR`2jYH`0_jN?0<6[U031ZYD0`j^D0<B^V036[iP0b[BM0<VhX03;^Z40c[jT0=;1
Z@3B`:L0f<>_0=9kK`38:R40c2LT0<PS7@32@d40R6=l03MHQ02`/k<0d;:T0<>2M@2gA3h0/S@d0:Pk
?P2G@d/0/SXk0:/>3P2HBeL0Q49E0:Tk@`2Q7R40XAhS0:0k@@2TMgP0PhbF08^P/P26UZX0QcDk08/E
7@1IFW40^]3L0;[:e@2hc=L0^<_G0;[<f@2hbMH0N8jS055^P`1nTid0SibP07UcK@d00?l02?ooool0
0`1@T7P0X23`0:0Pl0040:0Pl0030;Ph]03XJ3`0X23`01X0X23`00D0^3Rd0?n0003oP000oh000=1@
N0020:0Pl0030=1@N02P8?00^3Rd00D0d51h00@0oh000:0Pl02P8?00d51h0P3XJ3`00`3@D7P0X23`
0;Ph]0020:0Pl080d51h00@0X23`0;Ph]02P8?00^3Rd1`2P8?000`2h>;@00?l0003o000;003o00_o
oooo000:ooooo`1F003o0013La80EVIP04QEE`040@40404101X10@0Y0@80@`8504L21@0k0@80?`42
03h21@1J1P/0H`D804l10`1`1@T0S@D709<41P2M10@0^@`;0<0;2P333@/0`@`90;h:2@303@`0_``<
0;d<3@2m2``0_P`<0;d@3P2E5100Xh9g0=WEdP3JfM/0fm[M0=kCe@3<QXH0a3`j0=4Q703H6A@0eQTA
0=4G403@5Q<0aaXH08dI4`1P;R@0[J6D0=[Gd`36_[d0Q59@08TI6@2I30d0W0d?08XG3`2lTXD0dm;A
0=3Ad`3Ad]40[:BQ05H>3@2<1`X0R`8508T21@260P<0PP8307d10`200@@0Q08408D31@2910L0R@@5
09L52@2]20`0/`T;0;@<302Y3@l0O@hA06<U9@2KTHh0[KZn0<7?e`2nc=L0RYbS06IYJ`0jZB02003o
00Wooooo00@00?l00:0Pl02P8?00d51h703oP0000`2h>;@0oh000?n000020?n000030;Ph]03@D7P0
oh0000H0oh0000D0d51h0;Ph]03XJ3`0j6Pl0=1@N0040?n000050:0Pl03oP000oh000?n0003@D7P0
4P3oP000103@D7P0X23`0>QX?03XJ3`30:0Pl003052@N000o`000?l000Sooooo04d07^@909nCQ@2:
WZX0I7n805aiOP1iTiP0P9RM0:^k_`2g`<H0NGan08:1N`2;R7l0VI>:0:6MU@2ZYYh0Z:FI0:fUUP2`
Y9H0]ZJE0;>QSP2eX8T0^JB=0;bWS`2lYXl0`:RA0<6YTP31Zi<0`ZfF0<FaV`37]Yh0bkVR0<bjX`3?
_ZL0d/6Z0=K4[P3Fa;@0g<Jd0=fZW02`MWD0PVb0055WRP1SP9h0/;>g0<Fj[`35^JX0aKJW0;FSVP1o
NXH0G6Aj06EUN`2R?T@0/`/=0;8B5P2`2Pl0/`H<0;862`2_10X0ZPD:09h>4`2XL7P0I7J805QQM025
9bl0SAHQ05UMM@2jdM/0^L[E0;[<f@2kcMP0_<gI0;W;f02I/LL0Oib`096V/02KZk40QHB400[V100<
003o00Sooooo00<0D91h0:0Pl02P8?00102P8?020>QX?240X23`00<0d51h0:0Pl02P8?001@2P8?00
0`3@D7P0oh000?n000060?n000030;Ph]02P8?00X23`0080d51h00<0X23`0=1@N02P8?002@2P8?00
0`0Xb3`00?l0003o000:003o00_ooooo000:ooooo`1F003o0012LaH0JGYg04MCE00B0P809P8302L1
0@0`0080A@8504h21P1>0@@0E08604431P1=:b`0P5=C05D;30201PX0T0D909H41`2M1@H0[PP80;h;
2P332``0`P`;0;l;2P2j2PL0]PP90;T:302l2Pd0_Ph@0;8Q702;Bd80em3;0=_Mg@3MgMh0emKF08E[
J`1m7ah0^1dK0=HK5`3F6180daLB0=@I5P346aT0N1LC07mWGP3<a;d0gmcJ0<_=b`18C4L08Pl:04/:
2P2=3Q00VPh@08`O5`31VXh0dm;A0<o@dP3AdMD0bLW804H^;01_2``0R0D608P30`280`@0P`410801
0@1o0@<0O`4408811@240`L0R0@908h21@2]2``0/PT:0;<:3@2_30h0T18B068D4@2ORhX0]l?:0<3@
f@2b`l/0UJF/05iRI00k[242003o00Wooooo00@00?l00:0Pl02P8?00d51h2@3oP0000`3XJ3`0d51h
0?n0000?0?n000030=1@N03XJ3`0oh000080oh0000<0d51h0>QX?03oP0001P3oP0000`2h>;@0d51h
0?n000020>QX?0D0oh0000<0X23`0?n0003oP0000P3oP0000`3XJ3`0oh000?n0000@0?n000030:0P
l03@D7P0j6Pl00<0X23`00<0D91h003o0000o`002?ooool06@00o`00WHYc08fOZ`1YQXl0KhZ?069n
P`1NO7l0RZ:W0;G4b@1nPh@0P85k08b;P02KUX/0Y9fE0:JQV@2XY9X0ZjFH0;2UUP2fYIH0]j6?0;NO
R@2iXX`0_:F>0;ZTS@2nYi000P30Zi<0<P32[iP0a[:M0<RfX03:^J<0cKbY0=2nZ`3A_jX0e<:_0=W7
]`3EakX0e/Rl0<c2^`2j^;T0`knm0<[0]P39_Jl0a[Z/0<6gZ@33^J/0`;JX0;^aXP2gZI/0^X5i0:TH
5`2f2@/0/`P90;D72P2f1P/0]0L90;46202`1@L0[0D909DG7`2FSj40Y:>^08PN9@2>5b80G6Am0;W?
f`2lcMP0^lcH0;g>f`2kc=X0^/_H08RO]01dTZD0Q9RR092OYP22Q8P05kl<3000o`08ooooo`03003o
002h>;@0X23`00@0X23`00<0^3Rd0?n0002P8?00702P8?00103@D7P0X23`0;Ph]02h>;@80:0Pl0T0
oh0000<0j6Pl0:0Pl02P8?000P3@D7P00`2P8?00^3Rd0:0Pl0090:0Pl00306RX?000o`000?l000X0
0?l02oooool000[ooooo05H00?l004Uo9`1JKFl0Ce=G02T4100e0`@0:P4102l10`130P<0C@450502
1P1D0@@0G@/?07=4A@26D4l0O1/K08H51P2A1@P0V0@709`51P2T1@L0^``<0<8<30313@/0^`/70;P:
202j2`/0_0/;0;l<3@2d5a80_fUK0<2YWP3KfMT0gMkP0=;FeP1YLVh0GUiG07]UG02?=2l0bR0K0=/K
5`3?71X0ZQXI06PI5@2AOgD0fMC<0=kNfP3JfMP0alS20;:aYP2PVhl0IeM?06/A4P2H3A00SR0I0<BO
U03CdM80c]3C0<oBeP3?d]@0TI:<02P91`1R2@X0PP@608D20P210@80P04207h10`200PH0R0L808D3
1P2610P0Q0450:@:2`2a2P/0/PX>0;4>3`2/<S00Q3Tg09anOP2a_<80_/cE0<;?f@2CXjd0HV=T03NW
70800?l02Oooool01000o`00X23`0:0Pl03@D7P90?n000030;Ph]02P8?00j6Pl00h0oh0000<0X23`
0;Ph]03oP0000P3oP0040=1@N0D0oh0000P0^3Rd0=1@N03oP000oh000>QX?02h>;@0X23`0=1@N0<0
oh0000<0X23`0?n0003oP0000P3oP0000`3@D7P0oh000?n0000>0?n00080d51h00L0^3Rd0=1@N03@
D7P0d51h0:0Pl02h>;@0D91h00800?l02?ooool0C@00o`00Z8i]09JW/P24WjX0I829055`M@1WQXP0
KhZ>0:bl`026Rhh0P81l08b<Q@2NVi<0XIfF0:JQW@2ZY9d0[:FJ0:nVV02eYID0/j6>0;BRS@2fXX`0
^JB<0;^WSP2kYXl0_jZD0;j[U@30[IL0a[6L0<ZeX@3=^JL0ckb/0=2nZP3A`:/0e<>`0=G5]03FbKX0
dlRh0=38^03?a;T0b/:d0<W1/P37_K80`k^^0;^gZ@2l]jX0^K6U0;R/W`2lR840ZRDW0;D;3@2d2@X0
/`P:0;D92`2/2@`0YA<E0:8L802U3180Z`@809T63@1G>eX0Kg>808PF7@2?51h0H6Il0;[?g02caLl0
^lgH0;[<f02kc=L0]lWG09b_a@1DL8H0MhfG08ZKW`2;U9L09IhJ00`00?l02?ooool00`00o`00d51h
0:0Pl0050:0Pl0030=1@N02P8?00X23`02H0X23`00<0j6Pl0?n0003oP000103oP000103@D7P0oh00
0?n0003oP0020:0Pl0030>QX?03@D7P0X23`0080X23`00<0^3Rd0:0Pl02P8?001P2P8?000`20`000
0?l0003o000:003o00_ooooo000:ooooo`1F003o001=PRh0P96E061OH`0`10@0<@4302D00@0b0PD0
B0@504T20`1;0@@0D@450602201[2Q40LPX?07/420281@L0TPD709T31`2M1@P0W`@70;L<3@333@d0
`P`<0;`;2@2h2`T0^`d>0;T;2P2g2P/0]2/S0<NAP@3EbL80f=SJ0=CAc`1VJF80O89h0=;=aP3Od/d0
hZbU0<4b;03?71/0S1LG03`<1P2;OG00fmKA0=oPg`3Qhn80h>3P0=cLf`3Dem80e=C>0<o5_P26@Sd0
T`h?08lO6034WiD0dM7B0<gAe03>dmD0d=CF0<[:b00m>CD0704006@72P210@<0O`4207l00@1o0P<0
PP@60847201j0@@0O`<:07`31P2G1PT0[0P90;4;302a2`d0W0d?07d?402EGel0ZK6c0;g:d`2]^lL0
XK6k05eOH@0gYad2003o00Wooooo00@00?l00:0Pl02P8?00d51h6P3oP000102P8?00d51h0?n0003o
P0020:0Pl080oh0000<0X23`0?n0003oP0000P3oP0000`2P8?00oh000?n000050?n00080d51h0P3o
P0000`2P8?00oh000?n000030?n000030=1@N03oP000oh0000l0oh000`3@D7P30:0Pl003052@N000
o`000?l000Sooooo04d00?l008FcG@2DY:h0RjBb05IbO00_Be00GgQl06=oQ02X^;`0SiBF07amN@2<
RhD0V9V?09fMT`2UX9L0[:BL0:nVW02^XiP0/jFI0;BPT@2fXXd0]j6>0;NSS02iYHh0_JR@0;bXTP2m
[9D0_jjI0<>dWP39_JX0bkZ/0<jnZ`3>_jX0cl6/0=;4/P3Aa[H0d/Vh0=;8^P3?a[T0cLBj0<W2]@37
`;<0b;jh0<>j/P2o]jh0^kBZ0;Z`Y02nShX0Z2HW0;P=3`2h2Pd0/PP:0:T?3P2N:c40LSeB04E0H`12
BVT0Qe9N0:4:402E20d0ED1K07f2V0274aX0SP`G06EQN02hcm`0^l[F0;S:e`2fb=H0^<[G0;C6e@2S
]/`0Mi2V08jS[P2HZ[00V:>X03mc;P0<003o00Sooooo00<00?l00:0Pl02P8?001@2P8?000`3XJ3`0
^3Rd0:0Pl00O0:0Pl0030?n0002h>;@0X23`00<0X23`00<0j6Pl0?n0003oP0000P3oP0000`3@D7P0
X23`0:0Pl0020:0Pl080oh000P2P8?000`3oP000j6Pl0:0Pl00<0:0Pl0`00?l02oooool000[ooooo
05H00?l0066JBP2=X:P0JfQ`03X51P0f0P80:P4103<20`140`H0?P4303l10`180@@0G`8807442P1g
0`X0P0<908T52P2A10L0V0@809`31`2O1PL0[`T:0;h<302o2``0^@X;0;@82@2f2@/0]@T90;H:2`2d
?380^YB60=SAc`3Fe=D0UXF008=_I03>b<00fm_K0=oMg@3UbLT0[DE307`F4`1M@3T0Yj:I0=KDc@3O
hN40g>3R0=_Ph03MhN80fmgO0=GHf03AeMD0eMCD0:f2OP2<5140RQXC0;jGS`3Bd=<0cm;E0<kAe03?
d]D0cm7D09nMV@0j8Ql0H@T908420`220@<0OP4307d10`2:4180PaDD07821@1Y0P@0QB0Q090:302^
3@h0/@/;0;8<3@2U4100SQHG08@m?P2h^;/0]Ko80<;>e`2JZ[<0KG1d03b/8`800?l02Oooool01000
o`00X23`0:0Pl03@D7PI0?n000070=1@N02P8?00oh000?n0003@D7P0X23`0>QX?0030?n000030=1@
N03oP000j6Pl0080d51h203oP000103@D7P0oh000?n0003@D7P50?n000030=1@N03oP000oh0000P0
oh0000<0j6Pl0?n0003oP000103oP000103@D7P0j6Pl0=1@N03oP0020:0Pl003052@N000o`000?l0
00Sooooo04d00?l0086WB02JYJd0NiNS03UGH01DK740IGn607^EVP2DYZX0UinR07anNP25QGh0UYR=
0:6PUP2VXi/0[:JN0;:VX02aYI`0/ZBI0;>ST`2cXHd0/j290;NRRP2kY8`0^jN?0;fZTP2o[9H0^J^H
0;:`Y03;clh0cLW10<blZP3<_jP0c<2/0<k1/@3<`k80d<Ff0=35]`3<`kH0bL6i0<Vo^039`;P0aKfe
0;jh[`2l^:d0_;FZ0<:SV`2Z<S@0^0hA0;T;3P2a3@l0X2da06]8H00[?6L0@UQg07Z8T`2NWih0YgAd
09h<402F82@0=3IC09:@X0264AT0SPH?06IAI02gd=`0^l_D0;[<e@2jc=P0]lWG0:g0c@2DZ[h0C6j4
07^FX@21U9`0PXnI04=L>P0<003o00Sooooo00<00?l00:0Pl02P8?001@2P8?020=1@N180X23`00<0
^3Rd0?n0003@D7P0202P8?00102h>;@0j6Pl0=1@N03@D7P40:0Pl0050>QX?03oP000oh000?n0003@
D7P01P2P8?002P3oP000j6Pl0:0Pl02P8?00j6Pl0?n0002P8?00^3Rd0>QX?02h>;@80:0Pl0030;Ph
]000o`000?l000X00?l02oooool000[ooooo02h00?l008YjGP2Y_<P0JfUb03`51P0m0`<0:@4202<1
0P0f0P<0<`8203<10@100@<0F`460783201l0`T0P@8:08<3202910H0U@@709P31@2O1`P0Y`H70;P<
302h2``0W@D609H51P2^20/0/PL80;88202a@3<0_J2B0=OCdP3<b/X0JfUL0<o6_@3Ge=@0e]OH0<c=
c@29OG`0B2LS07ibJ@3:b/<0fMWH0=WKf`3Jg]l0f]_M0P3IgMh09P3Jf]`0f=WK0=GIf`3Cf=P0^jBR
08LH5@2:5Q00^hn70=?CeP3=d]@0cm?E0<oCeP3=d]@0cLo?0<Fg/P2CDDT0P@H408D210240@D0O`45
07h21@1i0P@0M04206@20`264aP0UP/@0:0:2`2b3Pd0/`d<0:LH5`3MNgh0KbLZ0;R^/P2d`LL0_<WB
0:Je`01VK780@;<]0P00o`09ooooo`04003o003@D7P0X23`0=1@N1T0oh0000H0d51h0:0Pl03oP000
oh000:0Pl03@D7P30?n000040:0Pl03XJ3`0^3Rd0>QX?0X0oh0000@0d51h0?n0003oP000^3Rd1P3o
P0020=1@N0P0oh0000<0j6Pl0?n0003oP0000`3oP0001@2P8?00j6Pl0;Ph]03XJ3`0d51h0080X23`
00<0D91h003o0000o`002?ooool0C@00o`00E/Da09NNX`1`RYP0@UmW03]CFP1ILgL0H7b108bRZ@2O
ZZd0OX>008b?R02GVHh0X9jH0:RRW02]YIh0[ZBN0;2UV`2]XIH0/J6A0;BQS`2eXHX0]Z:90;ZUS@2k
Z8l0_JZA0;f/UP2SVX/0a<Fm0;Vm^P38`K@0b[bY0<fnZ`3<_j/0c/:a0<k3/P3?a;L0cLBh0<c5^@3:
`[P0blFl0<K0]P32_;<0_[Ra0;fg[`2n/JT0]61N0;PC5@2j3A00[ALG0955C`0g?6H0?UYn08NCV02M
WI<0XZ2A0:fHS`2L<cD0X@T=07XiBP0L?6D0Ngf8088B5`2F1@h0JCI60:o9f02jbmL0^/[G0;_:fP2j
bML0]<OC0:Bib@1SP980OYRP08JIW`1nSYT0>3Xj00`00?l02?ooool00`00o`00D91h0:0Pl0050:0P
l0030;Ph]03@D7P0X23`0140X23`00<0d51h0>QX?02h>;@02@2P8?00102h>;@0X23`0:0Pl03@D7P2
0:0Pl0050;Ph]03oP000oh000?n0002h>;@01P2P8?000`3@D7P0oh000;Ph]0020:0Pl080oh00302P
8?000`3@D7P00?l0003o000:003o00_ooooo000:ooooo`1F003o002?OfD0MhfJ06EVK00i1@@0>`<2
02410@0J0@40=P8302h10P0`0000A`4405/10`1a0PD0NP0508842P250`P0R`@708h20`2C0`D0V@@6
09l41P2^2@/0/`X:0:D92`2B0`@0Z@L80;48202a1`H0[RdU0<BERP3IdLl0d<k=0;:^Y03Ed/d0eMKE
0=7Dd`1hQX4052<H07QiK@3@c/D0f=_J0=OLf`3Fg=/0emgL0=OIfP3FfmX0em_K0=[Jf`3HfM`0e=SK
0=;Ge`2aTI00Ra<C090D4P2cOgL0dmCE0<gAe03@eMH0cM;D0<gBd`3;c<d0[IRH08@k=`241PP0R086
08L110230PD0O`8507X2101g0@<0I`4207d5202Q2@h0S`430:X=3P2b30`0[0dA09X@5`1d4aL0a;Fj
0;6l``36dmd0UJJc07AkP`10/R`2003o00Wooooo00@00?l00=1@N02P8?00d51h6P3oP000102P8?00
oh000?n0002P8?030?n000040=1@N03oP000X23`0=1@N0/0oh0000@0d51h0?n0003oP000X23`1P3o
P0000`2P8?00d51h0?n0000?0?n00080d51h00@0oh000:0Pl02P8?00D91h0P00o`08ooooo`1>003o
001F`BP0X::R06j4T`1>JW@0AV1U05IbN@1jUIX0RIjR0:Re^P25Rh`0TY>@09VJU02RXIT0YJ>K0:VS
W@2]Y9d0[j>J0;:QU@2`Whl0/Yn>0;BNRP2cX8P0]ZF>0;RWTP2jZI80`JjH0:nPT02VWi80]ZnO0<bm
ZP3<_J/0cKf^0<^lZP3=`Jl0c<2c0<c3^03=`kX0c/>k0<_2^@39`KT0a[ne0<Bm]02l^[40_KVa0<V_
ZP2Z:Bd0_@lB0;4L6P36JF@0SdIC08MOKP2OViD0Xj:F0:6PT`2[Wi<0Y5UG0:0=3`2H:c<0;c1K076@
Z02SZ:l0P1PN09P32P1m7b`0Wjbk0;_;f02gb=D0^<WG0;S8eP2dam@0W;7206n;WP1iTY`0TjR]092R
ZP0lA4H02^H42`00o`08ooooo`03003o0020`000X23`00D0X23`00<0^3Rd0=1@N02P8?006`2P8?00
0`2h>;@0X23`0=1@N0050:0Pl0040=1@N03oP000oh000;Ph]0H0X23`00<0^3Rd0?n0003@D7P00`2P
8?000`3XJ3`0oh000=1@N00<0:0Pl00302S8?000o`000?l000T00?l02oooool000[ooooo00H00?l0
07QWB@25W:@0KF]b03P51@0a0P8201d10@1>03P2100g0@80@0<304d2101N0`@0L@8607`220220`L0
Q@<708/31@2A1@H0T`@709/5202I0`H0X`D80:h92@2^1`L0ZPD60:h71`2b1`P0]@P:0:h@3P2gDD/0
djfZ0=SBdP3Hd]00e/k>0<fj^`1kM780@4a109JIS@3=cLH0f]_J0=KJf`3Gg=`0fM_L0=[Mg@3Jfm`0
f=WK0=OIfP3IfM`0emOL0=;Gf@3Bd=40TUAC09@@4@2D4Q00XfAM0=;@d03?dmH0c]?F0<oBe@3@dM80
ZXf>07h[:P2430d0R0<808<110240P<0O`4307`10P1j0@@0N@4306L20`1j10H0X0L;09051`2K2`d0
/Pd>0:l;3P2R30l0RbHW0;:VZ02e`LP0_/gG0:Vjb01[MG/0F80c0P00o`09ooooo`04003o003@D7P0
X23`0=1@N1X0oh000P3@D7P30?n000050>QX?03@D7P0j6Pl0:0Pl03XJ3`0303oP000103@D7P0oh00
0?n0003@D7P50?n000030;Ph]03@D7P0oh0000l0oh0000@0j6Pl0;Ph]03XJ3`0d51h0`2P8?02003o
00Sooooo04h00?l002[O4`2EUHl0T:Ne041LI@13G680Af5U07B?T`1fSY<0]l;808F:SP2@T8h0VYRE
0:6OVP2WXY`0ZJ:J0:fTW02^XYX0[j6C0;:QTP2bX8d0]:2;0;BPR02gYXh0^jNB0;fZU`31/Ih0aK>P
0<FcX`39^ZP0bkVW0<fn[03;_k40b;b/0<[2[P3:`[80blBg0<W1]`3<`k/0b/:i0<S1^P34_[L0`[fe
0;jj/02o^;40aJFR0:XO8`2g4Q40bEA>0:HO802^3A00Va/N08amOP2OXY/0[9bD0:MLF`2S41@0Y@X=
09e0B`1VBf@0ZJJ[09>DW0249Rh0V@8908/74@2HMh@0_/gG0;S9e@2ibmP0]/WD0;K8e@2U^l`0CVYn
06f6S`1/PHD0MHR>03]8C`0I`Pd;003o00Sooooo00<00?l0052@N02P8?001P2P8?000`3XJ3`0X23`
0:0Pl00I0:0Pl0030;Ph]03@D7P0X23`0080d51h00P0^3Rd0:0Pl02P8?00X23`0>QX?03oP000^3Rd
0>QX?080oh000`2P8?000`2h>;@0oh000?n000020:0Pl080^3Rd00<0d51h0?n0003XJ3`0302P8?00
0`1XZ3`00?l0003o0009003o00_ooooo000:ooooo`0L003o001oKU40WK:o06aYL`0d1@L09@4101`1
0@0S0@40=@8403020P0d0040BP8405h21@1c0`L0OP<708D52@2610T0RP@608l31P2E10P0V@<609@2
1@2G0PD0Y@D80:l6202`1PL0/PD70;852080]@L;00/0/`/>0;0W9`2iFE/0]UmR0:M:C01^:RP0He99
0<6o]`3Hf=D0f=[K0=WKg@020=SJg00[0=gHg03La//0`Y6F09e_L`25NG/0dM?D0=OGf`3AeML0Whj>
084M7`2J3A00VPh?09Y1?03AalD0cM;C0<kCe@3?e=D0bLG607`c<P2;2P/0RPD708@210220@<0P041
07h10`1l0P80N`4307L10`1W0P<0MP@60:<:3P2F2`l0QPH90:l<4@2`30l0YP/>08PE602RRH`0/;k5
0<3@f`2U]Kl0Lgf105R3=@02003o00Wooooo00@00?l00=1@N02P8?00d51h6`3oP0001@3XJ3`0d51h
0;Ph]03@D7P0j6Pl0080d51h1P3oP000103XJ3`0d51h0:0Pl02h>;@30?n000050;Ph]03oP000oh00
0?n0003@D7P01@3oP0000`3@D7P0oh000?n0000?0?n000040>QX?02h>;@0^3Rd0=1@N0<0X23`0P00
o`08ooooo`1>003o000Xf``0TXYj086FX01PNh@0?5AJ055_M`1eTIL0OYBI0<C>eP29S940SXf=09JF
TP2NViL0YIjL0:ZQWP2^YI`0[Z:I0:bOT`2^WXl0/Ij<0;>PR@2hX8T0^:B<0;fXU02mZYP0_J^L0<:a
X036/j<0b[NV0<ZjZ03<_jh0bkna0<Nn[P35_Jh0al2a0<K2]@3:`KL0b<2g0<W3^P35`KP0`knf0<2m
]02n_;<0_KJ^0<N`[@2X=CP0]A4B0<0/;02c3Q40ZA4B098mC@0^>V40XY6E0:96A@2W3a40Z`H90:X4
2@2U1@T0WPT@09Pc=P2WT940RCTn09P32`2I10`0QR4Z0<:f`02ibM@0]lWD0;G8e02fb]L0Xk_?04aY
QP0kEG<0;TMR03Q@I`0aB540:Z@K2`00o`08ooooo`03003o001@T7P0X23`00D0X23`00<0^3Rd0>QX
?02P8?008P2P8?020=1@N0050?n0003XJ3`0oh000?n0002h>;@00P2P8?000`2h>;@0oh000?n00003
0?n000030=1@N02P8?00d51h0080oh0000<0j6Pl0:0Pl02P8?002@2P8?000`1@T7P00?l0003o0009
003o00_ooooo000:ooooo`0N003o0021KeH0WK2m06eXL`0_1@H07`4101/10@0R0@40:P4201l10@0Z
0@40AP8305h21@1b0PP0N`8608<420271@P0SP<709<41`2C0`D0TP<709021P2D0PP0WP<70:`62@2`
1`P0/0H80;862@2d1`T0]@X<0P2h30d0=P2h3a<0X1DE05lA3P1`Fe40bLRn0=OHf@3If]`0em[J0=[L
g03Me=H0e;:f0<=hOP2Y>T00Jb0N05Hj=P2[Z:80e=WI0<g=d02e][D0E4m:064A4@2H3Q00W0`@098N
7`38/Jd0cmCE0=3Ce@3Ce=L0^Jb]07PE5@2<0`H0R`<608L20`260@40Q@8308410`1n0@<0O04307L1
0P1Y0`<0E04207/73@1e1P/0L`D70:X=402`2`h0ZPX?098;3`2<EeT0Z[>j0<KCgP2V]Kl0LWZ005V3
=`800?l02Oooool01000o`00d51h0:0Pl03@D7PO0?n000030;Ph]03@D7P0oh0000@0oh0000@0d51h
0;Ph]02h>;@0j6Pl0P3@D7P30?n000030;Ph]03oP000oh000080oh0000D0d51h0?n0003oP000oh00
0=1@N00C0?n000030=1@N02h>;@0d51h00<0X23`0P00o`08ooooo`1>003o000DkPD0XiN009JY]014
H6X0EG5j03AFF`1aRhh0NI2F0<?@f02=TiP0T96A09VIUP2MViL0XYnJ0:JPW@2[YIh0ZYnF0:ZMT@2]
W8h0/Z2=0;2ORP2eX8T0^J>=0;RWU02kZiP0_Z^I0<6^W036/j@0bKNV0<NhZ039^jh0b[n`0<[1/`34
_;40a[jd0<C1]@36`[L0al2f0<S1]`36`;P0`[nf0<30^P31`;X0_[Vd0;ff/02lT8l0ZCdm0:HU:02P
<c/0NdYQ03i3KP1fCV/0XRDZ0:/:302^20T0Z@D70:L21`2W0`P0ZP@:09l73@23C5L0SEQQ09<63@2H
0`X0S`@=08Tg@`2j^/<0]<OC0;G9fP1oVkX08Ceb004EC`0144<00@hk004>=P0J;T<0>8D/2`00o`08
ooooo`03003o000Xb3`0^3Rd00H0X23`00<0oh000:0Pl02P8?00702P8?000`3@D7P0X23`0>QX?002
0?n000030;Ph]02P8?00d51h0080d51h0`2P8?000`3XJ3`0oh000?n000050?n00080X23`0`3oP002
0;Ph]0X0X23`2`00o`0;ooooo`002_ooool0@@00o`00QgQS0;S9e`1_Ig80<0@602@10P0M00008P41
02X10@0W0@40<@8204<1101G0@D0L@<707d520221@P0R0D908l41P2@0PD0S`8408l41P2@0`L0TP<8
09<21P2S10L0[`H:0;472P2c1`X0]0L:0;D92`2i3Ph0^Ph?0;8A501P3Pd0Je]>0<:n]@3FemD0eMSI
0=KIfP3Ef]/0fM;B0<:4Q`2[=S/0YRH[05L@401NDdX0_Kjc0=KHd`3EfMX0dmCE0=?@c`30^[H0MC/g
09D?4P2J2Pl0TQ0A0;N;R03>d]80d=CG0=;Ef02fXjD0N14A08`31@2>1@D0R0420080Q@4101<0Q@84
07h20`1k0@80N042078310150@40D@H80504201O0`L0XPdC0:/;3@2Y2Pl0U`XA08e>D`34b=40`/kK
0;2mbP1hP8H0EH<h00800?l02Oooool01000o`00X23`0:0Pl02P8?0N0?n000030:0Pl03@D7P0oh00
00@0oh000P2P8?00103@D7P0oh000=1@N02P8?040?n00080d51h0`3oP0001@3@D7P0oh000?n0003o
P000d51h01<0oh000P3@D7P40:0Pl0800?l02?ooool2003o000S0:^DLP2=WZP0I7j:03MHG@1DLgP0
FGEm08bQZ02mbm80UIfP08nDU02FUi@0VYbG09jOV@2RWYX0Z:2H0:JMTP2ZVhl0[IZ<0;2LR`2]VhL0
/Yj60;FQRP2hYY40_:RC0;fZU@2nZiT0`:nN0<BeY032]jD0a;ZZ0<Jn[`38`;<0`[^a0<:l/@34_[80
0P37_kH09`35`KP0`l6h0<;1^@2o_kP0_[jg0<2m]P2n^[80_;>^0;F[Y`1lNhP0Be]j05=EO@2>@5D0
Z1<I0;493@2^1`/0[0L<0:P42@2W1@X0Y`@90:P31`2L1@T0ICA:07QXN02931@0UP8809@12`291A00
RF9/0:_3e`1@K9T011iM008GF`014U400@i3004=?P0133D00Q8^03eL=P0;003o00Sooooo0P00o`00
0`3@D7P0X23`0:0Pl0040:0Pl0030>QX?02P8?00X23`01/0X23`0`2h>;@01P3XJ3`0d51h0=1@N02P
8?00d51h0;Ph]0<0X23`00<0^3Rd0>QX?03oP0001`3oP0020:0Pl0@0oh002P2P8?000`2h>;@00?l0
003o0009003o00_ooooo000:ooooo`1F003o0026Mf40X;;006UTK@0/0`@09P4101l0000S0@40<083
02l20P0d0P40A@4405P11P1/0PD0N@8607l31`250`P0SP@708l11P2?10H0SP<708`31P2>10H0SP85
09l51`2^20`0/0H:0;451`2d1`T0^0`=0;X>3@2h3Q00SQ8D075BB@32_K<0e]CC0=GHfP3EfM/0f=[K
0=O8b@2lL7@0XBd^07TI6`1961L0LfaS0<O6_P3GfMH0fM_J0=KHf@3Gf=X0e]SJ0=KEeP2]QhH0SA<G
09P93P2H3@l0VeE@0=7Ac03=e=D0cmCE0;JVY`1e4A80R@<608X310280P<0QP4208@10@200P40O042
07X10P1h0@80N0L705TD502LKfl0ISHg05831@2K30l0ZP/>0:H7302J2a40VUiR0;NmaP34dMl0/Ko;
07^2RP1FQ3T2003o00Wooooo00@00?l00:0Pl02P8?00d51h7@3oP0020=1@N0@0oh0000<0j6Pl0;Ph
]03@D7P00P3oP0000`2h>;@0d51h0?n000050?n000060;Ph]03oP000oh000?n0003@D7P0j6Pl0P3o
P0000`3@D7P0oh000?n0000:0?n000030>QX?03@D7P0oh0000@0oh001P2P8?02003o00Sooooo0P00
o`00C@27/eh0UJB/04UWL`1BL7D0>e=G08FMX`2R]/00^LO?09jW[@2;TI80UYNF09^IUP2OWIX0XIjI
0:BMU02SVHh0YYJ<0:RERP2/VHL0[Ib70;6NQP2cXXX0]ZF=0;NWS`2jZI@0_:^F0;bZU02n/9d0_;:O
0<>gX`31^ZT0aKn`0<No]030_:l0`[fb0<Jo]P36`;/0`l:i0<;0]`30`KH0_l6h0;fo]`2i^[<0^[Nb
0;Vf/P2a/ZX0[ZfY0;2AUP2P<CX0/@hD0;D93`2c1`h0[@X=0:4>502E9bl0RC@n09XJ802U1@T0UA@J
03lbE`21S:<0Pb@[09L32`2D0@/0RP<;058WA@0VAGl00AUN004EF@026EX032=E02@hE`0^@E`02Q/i
00`Q=P0c=cP02ND300X00?l02?ooool2003o00H0X23`00<0^3Rd0=1@N02h>;@06P2P8?000`2h>;@0
j6Pl0;Ph]0030:0Pl080d51h00<0j6Pl0?n0002P8?000P2P8?000`2h>;@0oh000?n000030?n00080
d51h00<0j6Pl0?n0003XJ3`00P2P8?00103@D7P0oh000?n0003oP00:0:0Pl0030=1@N00Xb3`00?l0
00T00?l02oooool000[ooooo04<00?l008n3K`2od>00HUaV03031@0^0P<09@8202010@0^0P80<P83
03<10@170P@0G`<606d41`1f0`T0O08908832@2>0`T0T@@909051`2;0PD0RP<608d31`2A0@H0W0@7
0:072@2_20`0/PH80;<92P2e30`0]Ph>0:@C4`1a?S/0b<>n0=GFeP3EemP0f=SL0=O;c@2oSi80YTY<
07LL7P1491l0J6AM0:j_YP3Ee]80fM_L0=KJf`3Gf]`0eMWI0=?HfP3BfMX0dMSI0;ZYZ@265aT0V@X?
09T:3P2871X0aJfZ0<kBd`3?d]D0`[:d07LH602:10L0RP<608L20P250@80PP420080O@430140NP43
07D10P1a0P40PBl[06Xf=`1`<C@0K`H;09/83P2N1P`0X@P>09d;4@2EBe00a<?=0<;?fP2hb=80NH>:
05R5?002003o00Wooooo00@00?l00:0Pl02P8?00d51h703oP0020>QX?0@0oh0000H0d51h0;Ph]03X
J3`0j6Pl0=1@N02h>;@80?n000030=1@N03oP000oh000080oh0000@0d51h0?n0003oP000d51h2`3o
P0000`3XJ3`0d51h0=1@N0050?n000040=1@N02h>;@0X23`0;Ph]080X23`0P00o`08ooooo`800?l0
04d0LZXo09FNX@1EL7/0?5QL06N2R01hTId0KHJ@0;G5c@2W[kH0Ri2A08f@S`2GUY00WI^E09nMV@2P
VI00XYJ=0:FDS02XUh`0[9V:0:nKR@2cWhX0/Ij80;6PR02cXX`0]JB?0;NVT@2eYHh0]ZNB0;6QSP2f
ZIH0]ZfM0;njZ`34_K<0_[Z_0<2m/@32_k@0a<6k0<?3_@31`;T0`<:k0;g0^@2m_kT0^K^d0;Zi/`2h
]k40];>/0;VJUP2V;S<0/``C0;D:3P2c2@h0Y1<G08hjB01D@6L0:CMV0511HP2D7RP0XP@:09le?`18
B6T0MYN_08EEGP2B1`h0T`4908@43`0m74D00QEK004HF@0B;f80FW^P0622W023WJ/0AEed01leB@1>
HfD0;cPm017;200:003o00Sooooo0P00o`070:0Pl0030>QX?02h>;@0X23`01X0X23`0P3XJ3`00`3@
D7P0oh000=1@N0020?n00080d51h0P2P8?001P3@D7P0oh000?n0003oP000j6Pl0;Ph]0<0X23`00<0
d51h0?n0003@D7P00P2P8?00102h>;@0oh000?n0003XJ3`;0:0Pl003052@N000o`000?l000P00?l0
2oooool000[ooooo00H00?l009^?O033d]l0F4mF02P20`0^0P<202810@1>02/10P0^0@40?`8304l2
1@1N0PD0J@<606l11@1l0`P0Q@<608l4202<0PD0R@8408T21@2=0`L0SP4709831P2M1@P0W`@70:`6
2P2`1PT0]@/>0;H>3`2Z4Q40MB0L0;^b[03De]H0emOI0=WGfP3C_/40WUMK07DT9`156QP0IfAM0;fo
]`3Fe]00fMcI0=[Mh03Gfm`0em_M0=GJg03DfMP0eMSK0=GIf`3Df=X0YX23090C5@2J2@h0V`X>09D;
302LEU@0dLK50<oBdP39`<40NBHU08T30`2:0P<0Q`4308<10P230P<0P@8507`10`1i0P80M`8207@1
0@1d1`T0PR0Q07hG5P2210P0V`P=09T5302I10`0WPT@07dD6P2j[[L0_lcI0:job`22Ri@0EH@n0P00
o`09ooooo`04003o003@D7P0X23`0=1@N1/0oh0000<0j6Pl0=1@N03oP0000P3oP000103XJ3`0X23`
0=1@N03oP0020=1@N0X0oh0000<0^3Rd0?n0003oP0000P3oP0000`3@D7P0oh000?n000020>QX?0/0
oh0000<0j6Pl0?n0003oP000103oP0000`3XJ3`0X23`0:0Pl0030:0Pl0800?l02?ooool2003o001=
056o:P2SZJ/0GGN205mkPP1FM7X0NI>M092W/035d]/0[KJm07Z0PP1kOW/0U96=09bFT@2RViH0X9N?
0:2ER`2PTHL0YiJ;0:ZHR02ZVH@0[9Z30:bLP`2_WHD0/Z290;6OQP2]W8<0[Ib10:^JP@2/WHD0[9n8
0:jUT@2_YiL0^k>W0<2k/030_K@0^;Rb0:b_[@31`l40_;jj0;6f/P2l_kP0_Kjk0;^m^`2i^KP0][Jb
0;^]ZP2U@4@0]@hC0;L;3P2]2a00WC0k05U6JP0Q?700EV6608]MKP2C6B@0Y0D=0:L42P2Q1Ph0T2df
0:NT[`25PY<0PQDM09822`1V2B<04A9C00<KGP14I8l0WKO<09Z_`@1mUZH0>UA_00PS@P0mF6<0DVAN
03e8B`0Bc`d02P00o`08ooooo`800?l000<0J:Pl0:0Pl02P8?00102P8?000`3@D7P0^3Rd0:0Pl00H
0:0Pl0030;Ph]03@D7P0d51h0080oh000P3@D7P40?n000030=1@N02h>;@0oh000080oh0000<0d51h
0:0Pl02P8?000P2P8?001@3@D7P0oh000?n0003oP000d51h0080X23`00<0j6Pl0?n0002h>;@02`2P
8?000`1@T7P00?l0003o0008003o00_ooooo000:ooooo`1F003o002OTX00[:jk03LL8P0T0@40:082
01l1000U0@40:`8103410@170`D0C`4305/1101Y0@@0M@<607`21`240PL0R`D:08X31`270P@0R0<4
08/3102>0`H0T`@809/41`2[1@T0/0L90;072P2d2Pd0/`lA09`T8@23Fe@0emCB0=CGeP3Ff=P0eLS<
095HG@1:61L09APD08:5OP3;c/L0fmcJ0=[Mg03GgM`0f=gM0=WJg@3Hf]`0emWL0=GIf@3Df=T0e]WK
0<k;cP28@4H0V0lC09d;3`2L30h0V0T:08TO7`2bSHd0d];A0=7>cP1g>cX0PPD708X20`2:0`D0P@05
07d00`1n0@@0N`4307X10`1i0@<0MP4307D10P1b0PD0KP4407d21P2G1`X0UP<:09H3302I1`l0Q14G
0<B_]`31bmL0`<gJ08B<UP1HR482003o00Wooooo00@00?l00=1@N02P8?00d51h6`3oP0000`3@D7P0
oh000?n000020?n000050:0Pl03oP000oh000:0Pl03@D7P02`3oP0000`3@D7P0oh000?n000030?n0
00040:0Pl03oP000oh000=1@N1<0oh0000<0d51h0:0Pl02P8?000P2P8?02003o00Sooooo0P00o`00
>01C_bP0W9nO08JLZP1AKWL0Ggb5076<U@2S];h0aM3K0;Nna`1cMg`0QXR809FBT02MUY<0W9N@09RD
S02MTh/0XI260:BAQ02WUHD0ZIR40:ZHQ02ZVH00ZiZ00:^GO@2_W840[9ao0:^JO@2[Vh40ZY^10:bL
P`2[XH`0ZZ6?0:nXU`2d[Z80_kbc09bOVP2MXj00]KRh0:2SX02`]:l0UYjL0;Rm^@2l_;P0^;Rd0;Jc
[`2dO7l0[ADK0;L<4@2]3a@0ST1A030lKP13Eh@0SFYj09H_=P2Q3180YP<:0P2T0`T04`2V10T0T`H>
071HK@1YOi@0QTeD08D84P0e3Sd011YO05Z0Z@2`bMX0/lKE07ZCZP1?LIL02BE>03IDJ01TOH40EVIO
03i;BP0P_Q/02P00o`08ooooo`800?l000<0P<000:0Pl02P8?00102P8?000`2h>;@0X23`0:0Pl00H
0:0Pl0070;Ph]02P8?00^3Rd0?n0002h>;@0d51h0;Ph]0030?n000030>QX?02P8?00oh000080oh00
00D0^3Rd0:0Pl02P8?00X23`0=1@N0060?n00080X23`00<0^3Rd0>QX?02P8?002`2P8?000`1@T7P0
0?l0003o0008003o00_ooooo000:ooooo`0Y003o002RR7H0Gcm703L72P0U0@808`8101h10@0U0@40
;P8203X20P190P<0E@8506<31`1[0`L0L`8807/22@1n0@P0P`<808@21P250`@0Q`4308d31P2>0@H0
T@8809X41`2[1`X0[`L90:h82@2d2`d0ZATF0:iVG02fZ:80eMGG0=CGf037`/<0QFIY03hP801RH5L0
ZZfT0<k?bP3Jg=T00P3Ig=d0:`3HgMh0f]gO0=7Ef02e`<<0YJn_0=GHf@3Ef=/0d];D0:^<S`266Qd0
V`dA09l;4@2L2a00V0T<08/<3P2<>c/0a:n^0=;DeP1cEUP0K`d@08L51`280P@0P@4207`00P1m0@@0
N`4307T10P1h0@<0M@4207D10`1b0@D0L@4307d21P2G1@T0V0D<09@42`2G1`h0Q10E0;2HW@31bmD0
]<7?08N?V@1MRTL00P00o`09ooooo`03003o002P8?00d51h01/0oh000P3@D7P20?n000060=1@N02h
>;@0j6Pl0=1@N02P8?00j6Pl1P3oP0000`3@D7P0j6Pl0?n000020?n000030;Ph]03XJ3`0oh0000@0
oh000P3@D7P00`3oP000d51h0?n0000B0?n000030;Ph]03@D7P0X23`0080X23`0P00o`08ooooo`80
0?l004d0:=hB09JET024W:P0G7Z3069oQ`2L/[/0`=3K0;k:e@2AVj80NWj208f=S02BT8h0VI>B09VC
T02<Qh00WI6809j<Q02QSh40YYB40:NDO`2TTW/0Z9=l0:VFO02[V7h0ZiUn0:JCN02XU7H0ZYQn0:VL
Q02XWXP0[J:A0:ZNSP2[XiD0X9f@0;2`Y`2e]Zd0[[>Z0;jo^P2UYjD0_L2l09VPW@2h_;L0^KRe0;Fd
/@2j/Zl0Z4a@0;P?502_41@0TTIH03I1L@1/F7/0VSM40:<?5@2Y1P`0Z@D;0:D42@2V10X0YP<:0:P5
2`2C3QD0B3eN06N;Z@1kO900K1db01h@B@0X8eD0LHnY0;79e`2dbM/0JHJY00//FP1FNHl0QIfS06j0
P@1EIEl0=DM702j_;00:003o00Sooooo0P00o`000`1@T7P0X23`0:0Pl0030:0Pl0030;Ph]02P8?00
X23`01`0X23`00@0oh000=1@N03oP000^3Rd0`3oP0001@3XJ3`0d51h0?n0003oP000^3Rd0080X23`
00<0^3Rd0?n0003oP0001@3oP0000`3XJ3`0X23`0:0Pl00>0:0Pl003052@N000o`000?l000P00?l0
2oooool000[ooooo02L00?l0071?:01E3Ph0=`8201l10@0N0@407@8102L10P0d0P80>`8204P10`1H
0P<0H0850601101W0@H0KP8607@21P1m0PH0P@@708@31`280`D0S`<809<3202B0PP0VP<70:X82`2a
1`/0/@P<0:l92`2X=Rh0]iN=0=?@c@3Be]P0Xjf_02hi>00k?SL0VifF0<o@cP3Gf]/00P3Hfm`0;@3H
g=`0f]cM0=cGf@33Zk40GeII04aKF02e_KP0em[K0<g6a`2IKFh0R2DV09L=402K2@d0WPX@09T83@2E
20X0T@P;08X<3`2BBDX0clO909VDT`0j20H0M`L808H20`1o0@<0O00207h20`200P@0N`8307<10P1e
0@80M@8307<10`1d0@<0O@8509D42`2E10`0T@@;09<93@2H:2/0[8bB0<;:e02kb=L0QXnH05j<BP02
003o00Wooooo00<00?l00=1@N03oP0006P3oP0002@3@D7P0X23`0?n0003oP000j6Pl0=1@N03XJ3`0
^3Rd0>QX?0060?n000080=1@N02h>;@0X23`0>QX?03oP000j6Pl0:0Pl03XJ3`70?n000030;Ph]03X
J3`0d51h0180oh0000<0j6Pl0=1@N02P8?000`2P8?02003o00Sooooo0P00o`00C@0Ni0X0VI>609N^
_01MO8D0TZR_0;70c@2Y^LL0O8JB07Z0Q024R8/0RXZ;096@S02GTHh0VY:>096;P@2IT8L0Vh^30:6>
PP2TTX80YI1l0:RDN`2[U7`0ZYEo0:BAM`2XUGT0ZIUn0:JBM@2WTgP0ZIV20:^ORP2ZX8l0YYn<08F5
NP25RX80K7Qd0;Fk/P33`kd0`/:j0;2b/02VZjT0/;B`0;Zi]`2j^[L0]kNd0;^d/02YBe00^10C0;Te
=`2?FF`0TcU=0:DC6`2_20h0[@L;0:/52P2X1Pd0V``>0:T[:P2R1`d0Y@D:08d^?P0^A700RJZn09fg
a`1mJ880715:04lG>P1XL8d0SJc;03YJRP0?<640CFZ30729T@1VNGd0H79`04UMG@0J;c/0@XM200X0
0?l02?ooool2003o0003052@N02P8?00X23`0240X23`00D0j6Pl0=1@N03XJ3`0d51h0>QX?0040?n0
00060=1@N03oP000d51h0:0Pl02h>;@0j6Pl1@3oP000103XJ3`0oh000?n0003@D7PA0:0Pl0X00?l0
2oooool000[ooooo05H00?l005TZ1`1?10@0=@4201d10P0N0@80700102X10P0a0P80>@4204P2101<
0@D0E`4606021P1U0@L0J@870702101k0@D0P@4608D31P280`@0R`450903202>0PP0Q`<70:D82`2_
20T0/PX;0:l;2`2V@CP0^Z>L0=KEe03=d=40J7=]08>:P02n`KP0e]KD0=KHf@3Gf]`0em[M0=SLg@3F
c<h0bZ:V0:=RJ01C9bT0P7eg0<S=b03HfmX0dlK90:aIG02T7R00W10A09d<4@2O2`l0X0P=09h93P2I
20h0TP@:08h52P243@d0XW5a0<K2`P1:>cX0D`P:08431@240PH0PP44080210210PH0O@8507810P1e
0P@0MP8507@11P1e0@L0N@4709@53@2G10`0T`@:098630293aD0YGUn0;>ja@2kbMD0QXjG06B2CP80
0?l02Oooool00`00o`00j6Pl0?n0000J0?n000070=1@N02P8?00oh000?n0002h>;@0X23`0=1@N005
0?n000050>QX?03@D7P0X23`0>QX?03@D7P00P3oP0000`3XJ3`0^3Rd0?n000090?n000030=1@N03X
J3`0d51h0180oh0000D0j6Pl0:0Pl02P8?00X23`0;Ph]002003o00Sooooo0`00o`00C02LSG`0U:Rh
08FNZ02daM00VjNg06iMJ@1cHFL0OWn308:7R02:RXT0TI2<096?R@2CT8P0UI2709R>Q02KRX40WHZ0
0:6<OP2URgX0Yi9l0:NCNP2VTWD0Xi1`0:F@KP2RT740Yi9b0:ZDLP2WUWX0YYYo0:VMQ02VWXP0J6aT
06YgL`1HJ6D0[[F/0<;2^@33`K`0`/:m0<;2_P2o_k`0^k^g0;Vj]@2f^;@0][Ja0;MnO`2`5QT0]a8E
0:lB6@2`2Q00/PT=0;<93P2Z20`0V`dC08X_?01dB5H0UCi50:083`2H72<0CSaU03aTT`1EOid0LiJZ
0;BocP0g=5h071=8018PF@0=;F<0C6^B07fN^01iUJL0PiZT07R=V01=J7L03bI3004B<@0cG40:003o
00Sooooo0`00o`020:0Pl080^3Rd7`2P8?000`3@D7P0oh000?n000050?n000030=1@N02h>;@0oh00
00L0oh0000D0d51h0:0Pl02h>;@0oh000>QX?00B0:0Pl0X00?l02oooool000[ooooo05H00?l005/F
10190P@0<@4102400@0R0P80804102P10P0[0@40>@8204410P110040D@4605d21`1S0@P0I`4406h1
1@1k0PL0P04508L21`290`<0R@4208l21@2?0`P0PP860:4:302_2`T0/0P:0;092`2V<2X0^IF@0=KD
e039c/h0/kF_0=;DcP3Cem@0e=OH0=KHfP3Ff]d0e]WL0=K8c@2cJg80TS8h04dC4P1bK6H0dM;>0=SI
f03Jd=<0]Ve_0;<L7@2e4Q@0XP`@09d<402O2@h0X@P>0:093P2J1Ph0U`L=09@82`2<1@L0QR4U0<fc
]02HUI<0=Pd>07T62`230PD0Q08308@21@220`L0O@4507`21P1j0@D0MP4507P11`1i0@P0N`460984
2`2E0`/0T08809052P291``0U5eO0<K;dP2iaM40R92J07MLE0800?l02Oooool00`00o`00oh000?n0
000J0?n000050=1@N02P8?00oh000?n0003@D7P01`3oP0020:0Pl0030?n0003@D7P0oh000080oh00
00<0X23`0?n0003oP0002@3oP0020=1@N0030:0Pl03oP000oh000100oh0000D0d51h0?n0002P8?00
X23`0=1@N002003o00Sooooo0`00o`009`2UTgT0YkO40:ZnbP2N[k`0IT]G06`B6@1h=3L0P7j00865
Q`2:Rh/0Shj<096?R`2BSXP0TXb409N;Q@2JQh00WXQo0:2;O@2QRgT0Z95m0:><M02SRg00YY5c0::@
LP2SSg40XY5_0:JDL`2VV7l0Yif70:BKQ@2SW8H0SXin07Z0M`2<T8D0ZZ^P0<30^P35`[h0`L6o0<6o
_@020;bl]`0S0;Zj]`2g^K<0]KJ`0;RATP2[6Qh0^0/>0;H:302e2@h0/PX@0:DB5@2>=400ET9P04Y1
I@1l<D<0T`XB09<R:@1F@fD08D=e09F_`P2D[/40VKG70<;Bg02QUZP0FAdl04@O@P2B[L<0[lOF07NB
YP1iTZ@0LHRI01<ZC`0254D00Q0n004?=P0W<D802P00o`08ooooo`<00?l000<0d51h0:0Pl02P8?00
0P2P8?000`3XJ3`0d51h0:0Pl00K0:0Pl0L0oh0000<0j6Pl0=1@N03@D7P01P3oP0001P3@D7P0X23`
0:0Pl02h>;@0oh000>QX?0D0X23`00<0d51h0:0Pl02P8?002`2P8?0:003o00_ooooo000:ooooo`1F
003o001=5P<0@P<303410@0R0@407P4101l10@0V0P809`4104020`1<0P<0C`<40582101H0@@0G`46
06P11@1_0P<0NP8407h110250PD0Q`4308d21@2C0PP0U@<909P52P2S20/0[0T;0;0:2`2`2@X0Y1PD
0:]^I`30^kP0d=GE0=;Ee@3Df=H0eMWI0=GIf`3GemT0f]?F0<fZ[`2cDUT0RQlP04PG501cJV80bL_3
0=_Jf@3JaLT0`WMk0;HR9@2o4Q@0]Q0C0:D=402N3100W`X?0:493@2O20`0WPP>09L7302D20`0TPH;
08h:3`2KDUD0e<3105lm?P1]1@P0PP<7084210230`@0Q0D707/1101i0@D0M`4307H2101f0@D0N004
07d11@2F1P`0U0<908d32@2<0`X0R0D;08I8C02_/KL0_l[E08ZBW@1cFE42003o00Wooooo00<00?l0
0?n0003oP0006`3oP0000`2P8?00j6Pl0?n000060?n0000:0=1@N02h>;@0j6Pl0?n0002h>;@0j6Pl
0?n0003@D7P0^3Rd0>QX?0`0oh0000<0^3Rd0?n0003@D7P04@3oP0030=1@N0040:0Pl03@D7P00?l0
003o00Sooooo0`00o`00C@2BX6L0Z;W50:Rfa`1^Hfd0GBd`07doA01[:Rl0PWYl07f0P@26RX/0Shn=
09:@S02CSXT0THV209N;Q`2JQX80WhN00::;OP2PS7T0YI1j09n=L`2UT7@0XHa`0:6<KP2STg@0XI9c
0:>CM@2UVX@0XIb70:>KQP2PVhL0Wi^909nMS@2RX9<0ZJVO0;Zk]@32`Kh0`/:o0;jm^`2o_[/0^KZg
0;Vk^02c]k80/[Ja0;JFUP2V5a`0]`/=0;D:3P2U3aD0U3A005U5J`0R?G<0HTm`08TK:`2@3AD0Oblm
03LhI00XBgT0TZVm08>GZ@1fS:80Pj:h0;oAg`33cMP0UW>006HL;`1mRId0Yko@051]S`0L>6L0FgR?
00/QA`014D@00Q4l018W?`0W>TL03M`;00T00?l02?ooool3003o00070;Ph]02P8?00X23`0:0Pl03@
D7P0^3Rd0=1@N00L0:0Pl0030>QX?03oP000oh0000H0oh0000<0d51h0?n0003oP0000P3oP0001`3@
D7P0X23`0:0Pl02P8?00^3Rd0?n0002h>;@01`2P8?000`3@D7P0X23`0:0Pl00:0:0Pl003052@N000
o`000?l000L00?l02oooool000[ooooo02800?l004`J0`0j0P80;P4201h10@0P0P807@4102D10P0_
0@80B0450542101<0P<0C@4205L10`1Q0@<0JP4606l21@1h0@<0O@0208@10P2;0P@0T@@709L6202E
0`T0VP@90:<82@2]2`/0[@T:0:l:2P2R61@0_H5i0<Jm^@3De]L0e=SI0P3HfM`08`3Hd]H0aYNN0;EC
F02f:2/0_2l/0:agL02i]jh0e=GB0=cAd`37RXl0/cTo0<0L8@3451H0^A<E0:/D5`2B4AD0PQ0C07X=
4P1k3A40PPhA08`>4P2A2`h0TPX<09D8302I20d0RP/B08lk@02/MgL0KPX<08031P1n0@<0P@8607h1
101l0PH0N@430080MP4200d0N@4407`11`1o0@L0U@@<09H4302>0PX0R`8908P52P1n>3/0]K2e0;_6
d@27SiT0M5eE00800?l02Oooool00`00o`00oh000?n0000K0?n000030:0Pl03@D7P0oh0000@0oh00
00@0^3Rd0:0Pl03@D7P0j6Pl0P3@D7P01@3oP000j6Pl0;Ph]03@D7P0j6Pl00h0oh0000<0d51h0;Ph
]03oP000403oP0001@3@D7P0X23`0;Ph]02P8?00d51h00800?l02?ooool3003o001=086_F@2X/[h0
PgR6060I701Z@440L5eS064V;@1mL780NGj008F7Q`2=SXX0T92=09>ASP2ESXX0Uhj709Z=Q02LRX80
XHj309n;N02SRWD0WXI[09n:J`2PS6/0WhaZ0::AL02UUWX0YIIm0:JKQP2RVXL0WYR40:2JQ`2NVXP0
WIf<09jNT@2UYid0^[bd0;no^`32`Kd0_[nl0;Zn_02h_Kd0]KZj0;>h^02`][<0_:JW0:4O9@2^4QH0
WC@m06]=I`0_A740@fB<08JEY@2:E5/0Qb4/05diEP0J;f00@F:308BIWP2W/kP0XkO308ZX_01eVZl0
_=?Q0;k@gP30am<0PF9`05eNLP2T_Lh0BfF9008HDP1AKHX073MA00dTAP0bC5/0Bf5N03Y<CP0IbAP0
2@00o`08ooooo`<00?l00`2P8?000`3XJ3`0^3Rd0:0Pl00M0:0Pl0030;Ph]03oP000oh0000H0oh00
0P3@D7P00`3oP000d51h0:0Pl0040:0Pl0030=1@N02P8?00X23`0080X23`00<0^3Rd0:0Pl02P8?00
3`2P8?000`1XZ3`00?l0003o0007003o00_ooooo000:ooooo`0F003o001;5`<0=04202P10@0K0P40
7P4101h0000V0@40>`4404D1101:0@@0A`8304/10`1H0@40GP0206D20`1]0@<0O@8508<11@260P<0
S04609011`80U`D800<0V@D80:D92P2]2P/00P2^2P/0:P2P5aD0_HAn0<c4a03Ee]X0eMSK0=SHg03J
cm<0_8B:0:hZ;P2m5aL0`aDF0<19AP3Aa;d0fmcI0=cEeP37Q8`0^2D/0<0F6P2n5aT0Z1TJ07`F6@1?
2`d0;@@701P41@0B10D04`<201d30`0c10L0F`hB07X>4P2@2Q00VPP>09H93`2=2a80TS<e084J6P21
10L0O`4408421@1h0@80M`4207H10P80M00200d0N@4607`2201l0@L0U0D;09H22@2?0@L0SP8808P3
2@1i:2`0[:6V0;o9e@1nQi40L5mH00800?l02Oooool00`00o`00oh000?n0000K0?n000030:0Pl03o
P000oh0000<0oh0000@0X23`0=1@N03oP000oh000P3@D7P20?n000030:0Pl03@D7P0oh000100oh00
00<0d51h0?n0003oP0003`3oP0001@3@D7P0X23`0:0Pl02P8?00d51h00800?l02?ooool3003o001=
06C3@023Q8L0GC8g07@W:@1P8BH0L5EL068V;@1kJF`0M7Qj08B4Q@2=RhX0TXn=09>>S@2AS8P0UX^6
09j>Q`2OS8D0Whb109n=NP2PRg@0WHEY0:68JP2QS6d0WXa[0:>@L`2QTgL0YIZ60:6HQ02/YIH0WIJ6
09nHQ@2LVXH0XZ>F09nOU02UYYX0`<2i0<70_P2o_kh0_<2n0;c1`@2g`;h0]Kjj0;Fn^`2a^KL0_K:d
09Q<D01mDF<0HEMe07Y7G02IPHX0UZ2T09ROWP2CS8`0EUQ^02Q5K`1UNhX0QY>@09VRXP2DV9h0Ui^U
07b5U@2IXJl0`<gJ0<3@g02mcm`0]lC@06MgQ`27YKH0BfJ000hWE@0gEFd0Dfe`05=ZK@1BJVP0CFAM
03=6B`0XZBT02@00o`08ooooo`<00?l000L0N5Rd0:0Pl03@D7P0d51h0>QX?02P8?00d51h01`0X23`
00<0j6Pl0?n0003oP0001P3oP0000`3XJ3`0^3Rd0:0Pl00:0:0Pl0030;Ph]02P8?00X23`0100X23`
00<0D91h003o0000o`001`00o`0;ooooo`002_ooool0EP00o`00CaP303820P0U0P40704101d10P0R
0@00<P83040210140P80AP4204P10P1?0@80F04205d2101T0@D0L04607l11`240@L0R0<408/21`2C
0P/0UPD:09T72P2K1PT0YPT;0:h:302a2P`0/P/>0:<J6@2nQh@0cLK60=GGfP3Gd]L0d;Fl0;M]L`2b
9bT0`QLH0<TF5P375AD0_TY90=O4``3L`L@0`gMm0;HY;P2_6Ad0S1@F060?4@0_2P/0:b8N03/n>@19
DD`0H6MS06]`K01YK6H0DUI?03a0>P0M61@080H605<;3`2;3A40T0L:09462P2:2@h0Sa@H08<31P22
0`H0O`4507L10P1e0@80L@8107820`1c0@<0M04407D11P1j0@H0U0H;09T42P2?0PT0S0<808<22@1d
82D0]JNY0:jh`029TI/0JeiL0P00o`09ooooo`03003o003oP000oh0001/0oh0000L0X23`0?n0003o
P000oh000=1@N02P8?00j6Pl00<0oh0000D0d51h0>QX?03@D7P0^3Rd0=1@N0040?n000050>QX?03@
D7P0d51h0=1@N02h>;@00`3@D7P70?n000030>QX?03oP000oh0000h0oh0000D0d51h0:0Pl02P8?00
X23`0;Ph]002003o00Sooooo0`00o`00C@17`b40MVIR05`h>`1Y?3d0I20Q06`[<`1X7R80MfQ[075g
NP1oOH40RhN708Z8Q02;Q840SX60095oO@2JQh80VhQo09f9P@2RSX40VhIa09j5J@2LQFP0WH]]09f>
KP2RUGX0XIEl0:>KQP2TWXd0[JNK0:6LS@2LV8@0ViV60:6QU@2WYI/0YZ^R0:>[Y`2_][D0_L6m0;k1
_P2j_Kh0^Kjm0;Nn_@2f_;`0][Zj0;Ff]P2kZZh0TeM/09hS<P2U3QH0Nd=D07J;UP2JX9d0UIZG08N@
T@27S8l0THB308iYJ@2>BU40TC@m09@U<02A7BL0SAl/0911C`2TQ980_LK@0;O<f02]`/h0Oib]08>P
[P1cRi`0J7j7065dM01IKV/0DVUT04QPH@0O=T<0>9dk00T00?l02?ooool3003o0007052@N02P8?00
X23`0;Ph]03XJ3`0d51h0>QX?00L0:0Pl0030=1@N03XJ3`0oh0000L0oh0000@0^3Rd0:0Pl02h>;@0
oh00202P8?000`2h>;@0d51h0=1@N0020=1@N080X23`00<0^3Rd0:0Pl02P8?002@2P8?000`1hF;@0
0?l0003o0007003o00_ooooo000:ooooo`1F003o001=5P<0<P4201l10@0I0P407P4102<10@0c0P80
A@4404<10P120@80A`4205410`1H0@<0H@8206P10`1d0P@0P08608H72P250`H0S04609<22P2G10/0
W0H:0:07302X2@d0/0X<0;8:3@2d30h0Y1`L0<:>RP3?b<P0dL;709YXL01X82T0V1dO0<4F5@3551D0
b1DE0<LD5@38@T<0bG1c0:dc>@2N7B40H@l@030D4`10?SP0IVaV09bQW`2l`;/0al[50<c@b`3?d]00
cmCB0=7EdP3;clX0`lW20;6d[`1kOgT0?3Xg03T92P1o2a00S@L:08d420280`L0P04307l1101n0`D0
M`4207@10P1b0P40L@8207810`1b0P80LP4407T11P2B1P`0UP@;08d1202:0`P0P@46078J7P2UTI@0
YJbc08:;U01XGel2003o00Wooooo00<00?l00?n0003oP0006`3oP0001@2P8?00oh000>QX?02P8?00
d51h00D0oh0000@0d51h0:0Pl03@D7P0j6Pl0P3oP0000`3@D7P0^3Rd0=1@N0020=1@N0D0oh000P3@
D7P00`2P8?00d51h0?n0000D0?n000030>QX?02P8?00X23`0080X23`0P00o`08ooooo`<00?l004d0
9]T<07MQCP1H?CT0J4m<06Hh>01O3A40NSXl06iFF`1]MGD0P7n208J0P02;Ph40R7mm08EjMP29MgD0
TGmi09N4O@2KQgl0W8Uk09Z6KP2MR6l0Whic09f@M@2QTWT0XIAo0:BMRP2ZY9D0Z:BG0;2ZX02SXY@0
WIb<0::RU02XZ9d0[:bT09JOU`2h_KP0U9jM0;Ro^`2i_;X0^Kjk0;Nl^P2i_Kd0^;bk0;:h]@2d]K<0
YV]b0:`D7@2a2Pl0Z`P@07dcBP1PNHl0VJ:Q09VFUP2HNWd0T4A;08XI802A2140U`@<09d42`2N10/0
WP<809T32`2C0`d0R@PE08HiBP2f]L40^<[F07J;V`1bS9L0P9FM06b1P`1LKfh0FFaZ04YTI@0D9ch0
11@b03UcAP09003o00Sooooo0`00o`001`1@T7P0X23`0>QX?02P8?00^3Rd0?n0002h>;@0702P8?00
0`3XJ3`0^3Rd0?n000070?n000040:0Pl03XJ3`0oh000?n000D0X23`00<0^3Rd0>QX?03oP0001P3o
P0000`3XJ3`0^3Rd0:0Pl00:0:0Pl0030;Ph]000o`000?l000L00?l02oooool000[ooooo05H00?l0
04hE0P0e0`80804101P10@0M0@809P8103<10P1;0PD0A@4204@10P170@<0CP4306021@1Y0PD0K044
07821@1d0P@0R@lC07X3102;0PL0U0<:09T52`2M1P/0X@P;0:L9302`3@l0/P`>0;<<3`2V6Q`0dHj?
0;N>TP1[>3d0@BLX07e]K02fK6/0_QPI0<HD5P354QD0a1<E0;/I7@2761/0C0`?03PR801_LVd0]KZe
0<K=b03@e]<0em[L0=OIg03EfM`0e=SK0<oCe`3Ae]T0d=KH0=;Ge`3Ae]L0dMCG0<oBe02l`<00HF9N
048;301n2Ph0Q`H808<21`200@@0O@4207X10`1d0040M04207820`1X0P<0L08407<10`1d00D0NP86
09052`2E0P/0SP4:08H220210PL0MQTO0:fBUP2@UI`0QHfD06YSH@800?l02Oooool00`00o`00oh00
0?n0000K0?n000060:0Pl02h>;@0^3Rd0>QX?03@D7P0^3Rd1`3oP000103XJ3`0d51h0=1@N03@D7P<
0?n000030>QX?03@D7P0oh0001<0oh0000<0j6Pl0:0Pl02P8?000P2P8?02003o00Sooooo1000o`00
C01cGC00H3df06@l>`1XC4`0EbLX0794B01/@D@0M7Ee07UjO@1nO7/0Q7el08ElN@1oMg80PGA^08]k
MP2EPg`0UhAk09V6O02MRWT0VhQa09f=M@2PT7/0XiJ30:JJQP2VWhh0[:NI0:bWW02/Z9h0[J^Q0:^Y
X@2/[Z<0];bc0<O?c@33cL`0[KJe09:LV`2d^kT0]kbk0;Fm_@2d_K`0/[^h0;Jl^`2a][D0/[Fd0:]`
MP2_3QH0/PTA0:L94`20=DT0C65k0:69SP2I@TT0U0lI09P53P2E0P/0U`8:09T22@2L0P/0WP8:09d2
202H0`T0TP8909<230290`d0P3E10;FjaP1QOXh0J8B?07::T01OMGP0G6m_05Y[K00R>4d00@dd004?
=00X=dH9003o00Sooooo1000o`001`2P8?00d51h0;Ph]02P8?00j6Pl0:0Pl03@D7P0602P8?001@2h
>;@0oh000?n0003XJ3`0^3Rd00P0oh0000D0X23`0?n0003oP000oh000;Ph]0020:0Pl0030;Ph]03X
J3`0oh0000X0oh0000<0^3Rd0:0Pl02P8?002@2P8?09003o00_ooooo000:ooooo`1F003o001@4`80
>04102@10@0L0@806`0102@1000i0@<0B`8504810P160@80B`8304T10P1F0@80J@8606`2101a0PH0
H`8206@51P1V0@80R`8709D2202K1@`0VPD909L62@2R20/0/0`@0;8<3`2e3140[aDH0<QGF`1^92T0
<B4O0:RXX`3LemD0^Wmn0;`K70334aH0`a8F0;/I6`1g41@09P`;05aKF@2[[ZT0dMC?0=[KfP3Hg=d0
eM[M0=CIg03Ef]d0eMSK0=CHg03?eMP0dMCH0=;Ff@3Cf=X0dmKJ0<kDe`3>dmH0bm7D0;o3`013;bh0
H`lA07l62P1o0PT0O04407P00P1g0080M@4207L21@1c0`D0F`820642101b0PD0LP4607P11`2>0`T0
T04908h13@270@T0PP4806`82P2AKfl0RXnC06mhO01^If@2003o00Wooooo00<00?l00?n0003oP000
6`3oP0001P2P8?00d51h0?n0003@D7P0oh000=1@N0H0oh0000<0X23`0=1@N03oP000403oP0000`3@
D7P0oh000?n0000B0?n000@0X23`0P00o`08ooooo`@00?l004d0FV/C0796@01P6a`0ISLi06I?DP1W
B4h0JSHk07A^L01dMGH0N7Mf07ikN`1lMgH0NgAa07ibK`25LVl0TGYe09N2NP2JR7h0VhUm0:6?O`2O
SW/0YIB40:FGR@2XW8d0Z9n?0:ZUU`2[YY`0ZJJM0:^ZX`2][:@0[[F/0;_4`02//k00_/[90;>o`@2[
/Jl0];Vg0;Fg]`2b^[T0];bm0;>j_02c^[T0/KJf0;Bf]@2cQ8/0Z1<K0:4D6P2:?4X0H4aX07U6GP2J
5b<0Z@P@0:@32`2L0PX0V08909L2202H0PP0W08:0:032P2L0@X0U`<809822@2>0PX0RP8907d43@23
E5`0P9FP08fV[P21V9`0JH6205U]K01CI6X01QDh004==@024C806bi500_J2P08003o00Sooooo1000
o`00102P8?00d51h0>QX?02h>;@20:0Pl0030=1@N02P8?00X23`01D0X23`00@0^3Rd0>QX?03@D7P0
oh000P3XJ3`80?n000040:0Pl03@D7P0j6Pl0;Ph]080X23`00<0d51h0?n0003oP000303oP0000`2h
>;@0X23`0:0Pl0080:0Pl003052@N000o`000?l000H00?l02oooool000[ooooo00T00?l0058C0P0n
0P409P4101l20@0O0P808`8103010P170`D00P0n0@80:@1:0P<0C`8305T21@1V0@@0J@420702101`
3`l0Qbh^07L6202=0PL0U0<809D31`2G1@T0T`@80:4:3@2_3A40/0/?0;<<4P2`4aL0YcDc0714?`2V
YZ40e]OG0=[Hf@2fPGh0^1TJ0;hE6@2T5QX0I0h@04@c<02AUI00blg;0=SJf03NhN00g=gO0=WMg`3F
fmh0e=[M0=GKgP3DfM/0e][L0080d]KI0200e=OJ0=CHf`3AemP0d=OG0<oEe@3=d]D0c=7B09:?SP12
3`l0N@T<0803201m0@D0N`4407T1101j0P@0N04307D10`1^0`D0H@4307@21P1d00L0N@4609042P2E
0@P0T08:08T320230@L0K@T<09ilO@21Q8L0KGAh071XIP800?l02Oooool00`00o`00oh000?n0000?
0?n000030=1@N03oP000oh0000T0oh000`3@D7P20?n000030=1@N03oP000oh000080oh0000<0j6Pl
0;Ph]03oP0004P3oP0000`2h>;@0oh000?n0000B0?n000@0X23`0P00o`08ooooo`@00?l004d0AYDC
0753?P1L5aH0JB0T06<c=@1YADX0Ic0b071YK01^KVl0LFm_07]hN01oO7T0NGE`07a_K@23KF/0S7E`
09J1N`2HQG/0X8j00:BCQ02RTX<0XiF60:6DQ02UVXX0ZIjA0:RPUP2ZYI`0[:VP0:n_Y@2][J@0/KF_
0;g4`P2c]k<0`lg>0;O2a02a^;H0];Vh0;Jj^`2c^kX0/K^i0;2i^@2d^kX0[kFd0:jf]@2bVYd0TD99
061>KP1BBg80QS1509l<602V1@d0Z@H<0:D42`2N0`X0V`<909L2202C0`T0S`P@08lI8`25:CH0M2`g
07LZ=@1j51l0P`D<08@22`1d5Ql0MgJ106AkQ01]QHL0HW]k05]`KP13EV800Q0i00`P?P0jEEd0:d9<
017B4`08003o00Sooooo1000o`000`1hF;@0^3Rd0?n000020=1@N0030:0Pl03@D7P0X23`01H0X23`
00<0d51h0?n0003oP0002`3oP0020=1@N0<0X23`00<0j6Pl0?n0003oP0001P3oP0050=1@N080oh00
00<0d51h0:0Pl02P8?00202P8?000`1@T7P00?l0003o0006003o00_ooooo000:ooooo`1F003o001D
4@80?P8202L10@0O0@407P8201`10@0W0@40>08203@20P0f0@80C@<505810P1M0PH0HP4306P20`1a
0@@0O0L908<;30270`L0T08709<3202D0`P0V0@:09/72`2F1`X0W0P;0:`<402c3100YQTM0<N>RP36
`Kh0em[K0=SJgP3IfMX0]X:00:TN7@1U4A00>B4K07EeL034bLH0f=cL0=oQh@3NhN@0fn3S0=_Oh@3H
g=h0e]_M0=GIg@3DfM`0eM[M0=GIg03@e]P0dMSJ0=GGg03BemX0c]KH0=3Ff@3?eML0bm;D0<_@d`3:
c<d0Rg=^074B4`210`L0OP0507h11@1l0@@0M`4507P1101g0@D0M08607<11`1k0PT0N@4707P1102>
0`T0U08808l32@280PP0Q`8806h42@2;GV<0PWj306=UJP1bJFP2003o00Wooooo00<00?l00?n0003o
P0006`3oP0000`2P8?00j6Pl0?n000020?n000060=1@N03oP000oh000?n0003@D7P0j6Pl5@3oP000
0`2P8?00oh000?n0000A0?n000@0X23`0P00o`08ooooo`@00?l004d0>Id:06m5?`1X?c`0GR<U06lZ
<01R5a`0JSho061OH01UIVL0JVQZ07AbM@1jMgL0OgQe07]`K01oKFP0RgMa09R4O@2JQW`0XHn10:>A
PP2PT800Whmo0:2FQ@2RVX/0YYjB0:ZQV02_ZZ40/:nV0:n_YP2_/JP0[;6Z0;6h]@2naLL0^L730;2g
]@2g^kT0Z[6c09RTYP2Y];40[[Vf0:ff]@2_^;L0[;Jc0:Vd/@2^/[80X9jX06YCM02D8C<0YPTA0:T6
302X10X0YP@:0:832`2K0``0T@L?08HQ;@1Z=D`0AS]O02/eI00Q<V00A5Ik05UYR@1YKH@0MCQ80805
401h1@l0K5MT086GX01dS8h0HW]j05]aK`0lEF001AXl03aIG`1?IV40=TaA026V:008003o00Sooooo
1000o`000`20`000^3Rd0=1@N0020=1@N0030>QX?02h>;@0X23`01L0X23`00<0d51h0?n0003oP000
0P3oP0000`3XJ3`0d51h0>QX?0050?n000040>QX?02P8?00X23`0;Ph]0L0oh0000<0d51h0;Ph]02P
8?001P2P8?020?n000X0X23`00<0D91h003o0000o`001P00o`0;ooooo`002_ooool0@@00o`00E0`1
04D20P0a0@80904101`10P0K0@409`4203L10P0e0P80;P4104<20`1K0`P0H08606D20`1/0P@0L`84
07X2101o0@@0R04608h21P2C0`P0UP@:09T52P2K1PT0WPT:09d72@2^3@l0]@dA0:@K6`2oS8T0cLW8
0=KHg03If]h0f=KJ099hNP116AL0MWE^0<?9`P3DemD0fMgO0=[Nh@3RhnL0g^7T0=[Ph@3Lgn00f=cN
0=OMgP3DfM`0eMOK0=;?d`3>aL/0`;6g0;VRZP2hW:L0^Z:Z0<Fl`@3AdmH0d=GG0<[Be03;dM@0b]3B
0<:j^`1f;S40P0@90080OP4600<0N`4506h20`1a0PD00P1h0PH03P1j0@H0NP4707`2201k0PD0T0@;
09<22@2>0PT0Q`4808<3201_10P0R5MK08>1Q01AEEX0KFIU0P00o`09ooooo`03003o003oP000oh00
01/0oh0000<0X23`0?n0003oP0000P3oP000102h>;@0oh000=1@N03@D7P<0?n000H0d51h1P3oP000
0`3@D7P0oh000?n0000@0?n000<0X23`00<0d51h003o0000o`002?ooool4003o001=03bN201gBT@0
ISlo06Dj>`1P20X0IRh^05mDEP1IFe/0HV1R06]XI`1aJfh0M6i`07ifL`22MG<0PW1/08mhLP2FPgX0
V8El09b<OP2NSgh0Wi>009b?O`2LTX00XiZ;0:NMTP2[Y9`0[:VR0;6_Z02/[J@0ZjfU0:^_Z@2W[J/0
[K:a0:fb/02//[00];Ri09nVZ02IYZH0VjRV0:jh]`2/][L0[[Jh0:jd]P2Y/K00/;6a0:mlQ@2Q6bH0
/0TA0:X5302/1`h0Z0@:0:@53P2F2Q40PbTg050gFP0M;fD0:T5b05MDMP1iBf40QCE608Ta?P26>TL0
QWEn0;:d_@1j9c@0O@@?050U=P1fSYD0LHR605mfL`1JLW00@UaT020jCP1AIfL0CfEU01hfB00>JRH0
2000o`08ooooo`@00?l000H0P<000;Ph]03@D7P0d51h0?n0003XJ3`I0:0Pl0050;Ph]03XJ3`0j6Pl
0>QX?03oP0000`3@D7P30?n00080j6Pl00<0d51h0:0Pl03@D7P01P3oP0000`3@D7P0X23`0:0Pl004
0:0Pl080d51h00H0X23`0;Ph]02h>;@0oh000:0Pl02h>;@90:0Pl0P00?l02oooool000[ooooo05P0
0?l005D:0@190P80>@4102/10@0O0@406`4102P10@0j0P80<04201l1000[0@80B`4505l10`1V0@40
KP8307010@1f0@80O@8308D10P2<0PD0T0@709L52`2H0`P0W@D:0:472P2Y2@`0/0/=0;<<3`2T7Q`0
aYB>0<k;b@3Hem`0d/G;08UeO00V9BD0NH9j0<_?c03Lgn00f]kQ0=cPhP3OhND0h>?W0=gRi03LhN40
fmoP0=SJg`3Mfmh0e/C<0;^=V@2KG6H0Qca407dX<`1i8Rd0NQTU088K9`22<SX0]9JJ0=7@e03;dMD0
bM7C0<_@dP3?blh0P4A808052`220@P0P@0507h10`1j0P@0N08507T11@1g0@D0NP8607/11`1o10X0
P08809<32`2C0@L0SP<908H11P200@D0K@<708AADP1hMWL0EEMK06MPG`0OS@P00?l02Oooool00`00
o`00oh000?n0000K0?n000070:0Pl03oP000oh000=1@N02P8?00d51h0:0Pl00;0?n000030=1@N02P
8?00X23`00H0X23`00<0d51h0?n0003oP0000`3oP0000`3@D7P0oh000?n0000@0?n000<0X23`00<0
d51h0:0Pl000o`002?ooool4003o001=03^^1`1lCd<0IS4`06H_;`1K<C40G51C051@E01EEeP0GemQ
06IVJ01`Jfd0MFi^07]fL@26NWP0QW9a095iMP2DPG/0UHAm09N:N`2PT840XIB409fAOP2QUX<0YYb<
0:VQU@2[Yid0[:ZR0;:bZ@2YZZ<0ZJVS0:VYY02/[j`0Zk2[0:fa[`2[];40/kRg0;6g]`2R[:d0Z;>c
0:Ze]02X/[<0ZKBd0:Zc]@2][K40[gZ20:LJ902b2Q40[PH>0:X43`2[1Pd0X0L=08dS;@1N@6006RiV
02]9M@1SKH<0Q4aH08dC7P2F1@l0V@8=09L43@2082l0Be=d09^jc`1oCEl0N`DA04hQ<`1IMh00IWil
065fM@1MLG40E6]^024lC017H6T083A<008C>`049C402000o`08ooooo`@00?l000<0J:Pl0;Ph]03@
D7P00P3@D7PJ0:0Pl080^3Rd00H0d51h0?n0003oP000oh000=1@N03XJ3`40?n000030;Ph]02P8?00
d51h00D0oh0000<0d51h0:0Pl02P8?000`2P8?001@3XJ3`0oh000?n0003oP000^3Rd00<0X23`00<0
oh000:0Pl02P8?00202P8?000`2h>;@00?l0003o0006003o00_ooooo000:ooooo`1H01K]1P1N6@h0
BP<204420P0_0P80804101X10@0W0@40?P8403T82P1I8bP0=@D603h21@1P0P@0J@4306l2101b0@<0
M`4307l110260@<0S08509<42@2E0`P0V@D909d72@2S20`0[@X?0;8;402e3A40XahN0<:CT03?bLT0
bK6g075;DP0a92<0MGag0<_Ac`3Oh^@0f]kQ0=_Ph`3Qh^H0g]oS0=cPh`3NhN@0hn?V0>3Af03BZ[@0
`GR10:Q1B`268BP0IQDI04X?4`0a3A<0;@P;05d?4@284aH0TA0D08XU:P2WO800b<O:0<[Be03;d]@0
c]3B08=@D`201``0P`<708811@200PH0P@480802201l0@D0NP4607X1101o0PP0P@D;07l32@2B1``0
U0<809432P2:0PP0O`4406`31@1nBT/0Q7n104Y<CP1QEeH07hd7003o00Wooooo00<0:<Pl0?n0003o
P0001`3oP0000`3@D7P0oh000?n0000A0?n000060:0Pl03oP000d51h0;Ph]03oP000d51h2@3oP000
103XJ3`0d51h0:0Pl02P8?020=1@N0H0oh0000<0j6Pl0:0Pl03XJ3`00`3oP0000`3@D7P0oh000?n0
000@0?n00080X23`00@0^3Rd0=1@N02P8?000?l02?ooool4003o001=02CD1`20EDH0GAPG06@U9@1L
CU40DdmD051=D@1DDeD0FEYM069RI@1]JFT0M71_07egL`23MWH0QW9a08ihM02AOWP0ThEl09V:O`2O
SX00XYB40:FIR02TVXL0Z::@0:fUV02YYI/0[ZZS0;6_Z02OXIT0UiR?09BFS`2TYZ40ZZbW0:nc/02^
]kD0/KJh0;Fi^P2`][X0ZkJg0:Vd]02[/[H0[;Bg0:b`/`2_OhL0YA`V0;8;4@2c2A00[PH<0:/83@2L
41L0OSaA02/gJP0UBG`0IGjB07mkP`1o<3`0T`PB09`3202L0PL0V@8:08/A6`11=ET0AgFN0;;8f`1j
@U40M`D?04@V?`1UPi80L8J6065eM01OLg80F6i^01lgC0086d@00@ll004>>@066CL02000o`08oooo
o`@00?l000@0D91h0:0Pl03oP000j6Pl6`2P8?000`2h>;@0X23`0>QX?0030?n000080=1@N03oP000
oh000=1@N03XJ3`0d51h0:0Pl02h>;@40?n000030>QX?02h>;@0X23`00<0X23`00<0^3Rd0?n0003o
P0000P3oP0001P3XJ3`0X23`0:0Pl02P8?00^3Rd0?n000/0X23`2000o`0;ooooo`002_ooool0F00Z
f@X0JRlN04440P0o0`80;@4202420P0L0@40:P4203X30`0/0@80A@<40443100/0@80F`8606D1101W
0@80KP4107P10`1n0P80Q@4208/2102A0`P0V0D909H4202M1PT0Y0P<0:d93P2c2`l0]``?0:TK7@3K
UIH0_h6706l[;`1WFEP0a<O40=kQh@3OhnD0g>;T0=[OhP3Kgn80gn3T0=_Mh03Ng>00hLcC0<j6T@2j
?DX0YR</07/D6P0k2Pd0;BDQ04A9@`1MIV00OHJ109>CS@2ZTh`0ZVe[090I702?2a00O24S0:nKV`3<
dmD0b]?D0<k?d@1l@dL0PPL:08H51P2510P0P`@80802201n0PP0NP4607T21@1j0PH0OP8607T52@1]
0P@0TPhB09L42`2F0`X0S08708411`1[0`L0NTI707efN01BD5@0F4M5026<1P00o`09ooooo`03052@
N03oP000oh0001/0oh000P2P8?020=1@N0T0oh0000L0d51h0;Ph]02P8?00d51h0>QX?03oP000j6Pl
0080d51h00D0^3Rd0=1@N03@D7P0X23`0>QX?0020?n000050=1@N03oP000oh000?n0003@D7P04P3o
P0030:0Pl0030=1@N02P8?000?l000Sooooo1000o`00CP0Yf0P0O5<l05lm>P1WD4h0G5AG04]8C01:
BD/0EE=E05IFF`1MGF40I6AU07=_K`1lM7@0PWEd08UfL@2>NgH0TGii09B2NP2JRGh0Whio0:6DQ02V
VHT0YIZ90:ZRTP2^YI/0ZZ>K0:ZVX02/ZJ@0TiB;08^>P@2<SX80UIJ=0:FXY02V[j`0Z[>b0:nd]P2b
][P0[KBf0:^e]P2Z/K<0/;Bh0;6c]P2eTYP0Xb8/0;0;4P2a2A00/0L=0;8;402K8R/0GT5W01LfL@1;
Ki80OYJO08R=T01n>dD0S@D@09H32P2H0PP0V0<908d53P1c<T/09dYi0:[=h@2ZYK@0MQPV07H?6P0Y
9D@0GGN306AjM`1PN7<0FW5^05Y^K00O<TX00Pi0004>?P0353L0<4UF00SH20L00?l02?ooool4003o
0003052@N02P8?00^3Rd01h0X23`00H0d51h0>QX?03oP000oh000>QX?03oP0020=1@N0030>QX?02P
8?00d51h00@0oh0000<0j6Pl0:0Pl02P8?000`2P8?000`2h>;@0oh000?n000030?n000060;Ph]02P
8?00X23`0:0Pl03@D7P0j6Pl2`2P8?000`1@T7P00?l0003o0005003o00_ooooo000:ooooo`1H02WI
201N9A00?00103h30`0^0@809@4102@10@0_0P80>@<302<10@0n10H0=@<402<10P1F0PD0G@420601
0`1Z0@80M04207T10P200@80Q`8408l3202D0PP0U@<809P62P2R20/0[`X?0;P=402o4180`1HH0<<b
<`1h6a`0MVMS0=GJf03QiNH0i>SY0=oTiP3Jgn80fmoR0=cOhP3Ng>40d;2g0;m^M`2m=d00_ahT07/@
4`0h4180EE1=09bSW`34cLT0c]KD0=CHf03CemP0aL3509AWK`2:8RT0T`L>09083@1m6QX0U7mm0<gE
e@3=e=H0^k>f07D[;P261PX0Q@@808<11P220`P0OP8807P3201i1@/0N@<708032@240`T0O@T=07@7
1`2S4QD0V`T?09X52`2@0PT0PP4706h4201kA4H0Q7eo04E2@@1D@S`08Hh6003o00Wooooo00<0D91h
0>QX?03oP0006`3oP0000`3@D7P0j6Pl0=1@N0080?n000040=1@N02P8?00^3Rd0>QX?080oh000`3@
D7P30?n000030>QX?02P8?00j6Pl00<0oh0000<0X23`0?n0003oP0000P3@D7PB0?n00080X23`0P3@
D7P00`2P8?000?l0ooooo`07ooooo`@00?l002`03?L307mF>@1TG5T0HUmN05YEF01;ADP0AdE805AB
E`1@E5L0FEeN069SI01_KFh0O7=e085eM@2:NGH0S7]e091nN02FPg`0VhYn09^=P02NT800XYB30:>I
R@2ZXiD0ZZFJ0:VUW@2YYYh0Z:VQ09FHSP29S7l0RXio08bAQ@2IXIT0YJn^0:Na/P2]/KH0/[Jj0:fb
]@2V[:l0Z;2b0:Z]/P2hYjh0Wc@o0:l<4`80/PP@0200ZPX@09T^?P11?W808TV006b;WP26VYd0Q9FD
08McN0203AL0T@<<08P63@237RX0KRm305PhE00Z=VP0NZ;30;:lb`24AUH0P0LB06<V>P0/@V@0JhN=
06IiN@1SNG<0G7Ea05Y`L00]@5<00A4l00`R@`0dD5`0DVYY00g>3PL00?l02?ooool4003o000302S8
?03@D7P0X23`01h0X23`00L0j6Pl0=1@N02P8?00oh000=1@N02P8?00^3Rd0080X23`00<0^3Rd0?n0
003oP0000P3oP0000`2h>;@0X23`0:0Pl0040:0Pl0050>QX?03oP000oh000=1@N02h>;@01@2P8?00
0`3oP000^3Rd0:0Pl00:0:0Pl003052@N000o`000?l000D00?l02oooool000[ooooo01L0;=/;054D
10110@00@P8302h10P0W0@408`0002l10P0h0`<06`4102L41P0M0@80:08305/41P1F0040G04206X1
0`1d0@<0N04207h10`250@@0S`4809H42`0209L52P0o0:08302[2@h0]`d?0;/=3`2l51H0R1DE05<f
<`3;d/l0gnOW0>;Wi`3Tj>X0gN;T0=SNh@3Jg^80h]oS0=>W[`2`=Sl0_aTO0<LG6`254Q@0?bhZ0:6W
X@3?e=<0f]oO0=CKgP3Cf]`0e=SK0=7CeP2EJG00Q1TP09<9402C0``0SPT>068B4`1hL6d0b]?B0<_B
e02LR8T0M1PK08H42P220`P0P04708022@1m0@T0I@4305`00@1h1@X0Q08808L42P1l10P0J`<409P@
4`2710H0TPD;094220220@D0L@@807m5A@20MgP0CD]804Xj=00QS`H00?l000Wooooo00<0D91h0?n0
003oP000703oP0000`3@D7P0oh000?n000060?n000030=1@N02P8?00oh000080oh0000<0d51h0:0P
l03oP0001@3oP0000`2P8?00oh000?n000030?n000040=1@N03oP000oh000:0Pl1<0oh000P2P8?02
0=1@N0030:0Pl000o`3ooooo00Oooooo1@00o`00C@1YNcD0I5aK06ARH@1IEED0BTA404M5A`1DDUD0
DU9E05UIFP1RH640KVYZ07Q`L021M7H0Pg=b08mlM`2CP7T0U8=m09J8O@2IS7`0Uhai09N;NP2ITGh0
XIZ90::OT@2TXiT0ZZNP0:^[Y@2UXih0S8n408V=O`2<T8D0TYVB0:>]ZP2Y/[40[[Be0:jf]`2W/;@0
YZna0:^`]02jZk00Z5aU0:d@602e2a40/@T@0:X<4P2?=dX0<3]e03MPT@23WJT0T:2Q08nNW@23TY00
PEUL08d74P272100HC9;028aIP0?;6/0DgJR08NM_`2UW[D0QD1@0849501f7RX09bQ@04YZPP1cRX`0
GWAc06=hMP1MLg00FVm^03]CFP0V@Dl0BVQ[04mYI`1>IfL07Z8R00L00?l02?ooool5003o0200X23`
00H0d51h0?n0003XJ3`0oh000:0Pl02h>;@30:0Pl0050>QX?03oP000oh000?n0002h>;@01`2P8?02
0?n000L0X23`0P3XJ3`<0:0Pl003052@N000o`000?l000D00?l02oooool000[ooooo05P0:MP:04X;
0@100@40@08203020P0V0@40904102`10@0f0P80608200L10@0@10@0=`8405X10`1E0000F@4106/2
0P1f0@<0NP4307l10P270@<0SP<809842`2E1@/0T0D:09H7302V2Ph0/P/?0;P?4P234180CR`[0:na
[P3Nh^<0hNGX0>7Ui`3SiNP0hN;V0=oPi03Od=H0f9VR0;lf?@335Q/0_a8E09TD5P1L?3T0^L2i0=KM
f@3Jgml0f=kP0=CKg@3CfM/0dmOJ0;JNX`298RP0U@/?09<6302B1P/0L@`?03HH5`2OXj40c=7B0;^b
]@1c>C`0O0`A08422`1m0@T0OP88084320220PP0O`@:06h3201b10H0R0@:08P320261PX0K0P:06@:
3@1]10L0S@D;094320260@L0MP@80896B02>QhP0BDM604Te<P0QS@D00?l02Oooool00`1@T7P0oh00
0?n0000K0?n000030=1@N03XJ3`0oh0000D0oh0000<0d51h0;Ph]02h>;@00`3oP0000`3XJ3`0d51h
0?n000050?n000030;Ph]03XJ3`0oh0000@0oh0000@0d51h0?n0003XJ3`0d51h4`3oP0020:0Pl080
d51h00<0X23`003o0?ooool01oooool5003o001=06N>>`1ZH5l0JFIQ05YDE01;@4<0C49505E>D01A
Ce00EeIH05eKFP1[IFD0MFi]07icM02;O7d0TWem09:1NP2BP7/0T7id0962M02AQ7D0THAa09>8L`2F
S7P0UY2309fJT@2YYZ40YjJS0:^YYP2TXih0VIfF09^NV02MXYh0XjjZ0:Fb/P2/];D0Y:f_09n[Z`2Q
ZZ`0/9nV0:ILJ02T72@0/``B0:h83@2T2a40RSY?02DkN017KY/0TJ:^09>OXP2AWj00SYfN08BCTP26
JF`0RPXC08LG8@0c:U80Jh6T08jD[@2BOY@0STQN08LD90262140N2Dd03<^F00WAV/0PIVQ06b0P`1Q
MG<0HGMe05eeLP1GLF`0EFaZ04mXIP1@K6T0@f5U018]@P0RO3801`00o`08ooooo`D00?l0802P8?00
103@D7P0oh000>QX?03@D7P20;Ph]080X23`00D0d51h0?n0003oP000oh000;Ph]0080:0Pl0030?n0
003@D7P0X23`00@0X23`00<0d51h0?n0002h>;@03P2P8?07003o00_ooooo000:ooooo`1H02KD2015
1`40?@4103X20`0Y0@808`4202/20@0b0@80>@4202820P0l<C40FCe104l31`1F0@80E@4105h20`1/
0@80M`8407`10`1o0P80QP8208X21P290@H0SP8808l32@2E1P`0Y0T>0:/;3`284A@0Je9@0<K9b@3I
gMh0g>3S0=kSiP3Mhn@0h>GT0=gHg@37SIP0_T5:0<`R9`3E5aX0aQ@H09/H6@1bB4D0blk<0=[Og`3I
gml0f=kO0=OLg`3DfM`0eMWL0<c5b02==S/0W0`A09462@2:1@X0K`X?03XT8P2DVID0bLg=0<W8c@26
E5/0N@dB08042P1n0PT0O@8:07d12P1o0PP0PP8908<320200PT0OP<708D420260PT0QP<9094T9`20
?Ch0I@D909@63@2@0PL0Q@4707X42P27BD/0QGam05=<CP10;BX07h/4003o00Wooooo00<0D91h0?n0
003oP0001`3oP0020=1@N140oh0000<0d51h0?n0003oP000103oP000103XJ3`0^3Rd0:0Pl03@D7P4
0?n000030>QX?03oP000oh0000@0oh0000<0j6Pl0=1@N03oP0000`3oP0001@3XJ3`0d51h0?n0003X
J3`0^3Rd00d0oh000P3@D7P50?n00080X23`00@0^3Rd0=1@N02P8?000?l02?ooool5003o001=06R:
;P1]HEh0K6QV065JF`1C?D40BBHY05I8C01CDED0EEAF05eKFP1/IVL0NFi_08AfN02=Ng/0RgQf095m
NP2?N7<0SGA]08YgJ@2>P6h0U8Ma09R:MP2DRWL0TXil096>P@2KVi40Z:VP0:VZY02/[J/0XZNS09jT
X02PYJ<0XJVX0:J_/02X/k80Xk2^0:F`[`2SZJX0X69[09lI8`2_3Q@0[@X@0:8<4@27=TL09CQa04a^
V02JT9d0WFih09]HI02KJG80Uh^>08VEU@2IUiX0O2/d08H74P267c00QRTh08@F9@2821H0S0TB08@M
9`1P=Dl07RQO02e>O01mUZ<0P9:F06f0PP1TMgH0HgQe05ieL`1GLF`0DfeW04iWJ00]BET01Q]0004C
?00RDCh01`00o`08ooooo`D00?l01@2P8?000`3@D7P0X23`0:0Pl00I0:0Pl0070=1@N03oP000d51h
0>QX?02h>;@0X23`0=1@N0030?n000030;Ph]02P8?00X23`00L0X23`00<0^3Rd0?n0003@D7P00`3@
D7P00`3oP000d51h0:0Pl00?0:0Pl0L00?l02oooool000[ooooo04808m4504@5000l0@80<@4102H0
0@0Q0@00:@4103<10@0l0@40>`@603`G7P154aX0E08505@20`1@0@80F`<306P2101e0@D0NP4307h0
0P240@80Q`4408/11@2>0@H0U@@;09P21`2S2@`0V0dA04LH6@2i_K`0f=[L0=KJg@3HgN00g>7T0=_O
hP3Ogn<0aI6L0;HV<@3A6R00f1TJ0=HF5`2c5aT0G1HG0;be]03JgN00fMcP0=OKgP3Gg=l0em_M0=KI
g@3Ff=d0/H^C09@A6@2L1Pd0S`L;07H=400V20L0OXJ00=7De03=d=<0ZiVM07LJ80261`h0P`<:07l1
201n0@T207l22P0D088120200@P0O`88080220240`T0R0<908T32P2<2a00[Sm109P@5@2O1P`0T046
08D11@1l1@X0OCa009F;SP1DCe00=B<O01j:0P00o`09ooooo`03052@N03oP000oh0000P0oh0000<0
d51h0?n0003oP0003`3oP0000`3@D7P0oh000?n000040?n00080X23`1@3oP0000`3@D7P0oh000?n0
00050?n000030:0Pl03oP000oh0000<0oh0000<0X23`0?n0003oP0000P3@D7P>0?n000030:0Pl03o
P000oh0000<0oh000`2P8?000`3@D7P0X23`003o0008ooooo`D00?l004d0KhHR07=SGP1]JFX0I4mB
05DR9@197Ah0ETI<05MEF@1BDUD0FeUK06eUJ01jKg00RGak095mO02>NWL0SgUg08adKP29KVH0RWAV
08ekJ@2EQW00Vh]d09VAO@2DT840T92209>DR02RXI/0ZjbX0:^ZZ@2[[:`0Yj^[0:>[[02PZJ`0Y:j`
0:Rc/P2T/Jh0WjZZ0;FWZ`2N;3<0/@dD0;<;402_2a00V3=103I2N01FFh`0TdQI09@E8@2D31D0T10K
098?6P2;9C00ThR=086CUP2ASY40NDeB07<T<P1i7Rl0NbHd06/aA01?=eD0;c9P03<cI01HB6T0Meib
08]jPP1jP8<0K82006EiN01UNGL0GG=b05Q_K`15HFX04b]9004@?P023d400A0l024c@`07003o00So
oooo1@00o`040:0Pl0030>QX?03oP000X23`01@0X23`00<0^3Rd0:0Pl02h>;@00`2P8?000`2h>;@0
oh000=1@N0020:0Pl0050=1@N03oP000oh000?n0002h>;@00`2P8?001@3@D7P0oh000?n0003oP000
^3Rd0080X23`0P2h>;@30=1@N0030;Ph]02P8?00X23`0100X23`1`00o`0;ooooo`002_ooool0F00R
d0D0A`H103/10@0_0@80:P8202D10@0[0@40>04204020P160P@0B0P;04L31@1F0@@0D`8404T20`1J
61T0HADF06H2101g0P@0O@8308<20P260@80R@4308`1102B0PL0W0L:09d>3`1R30d0NW9^0=OIfP3I
fmh0f=[M0=OLg`3IgN00fMCI0<NHX@2i<C/0baHK0=PH703J6AX0dQTI09L/:`2YTY40fM[J0=_Mg`3H
g=h0e]WM0=SDfP3=]Kd0/H><0:IUL02N=3d0X``E090;4P1P2Pd0;@d=06=XI@33b/T0dM?F0;je_@1n
?4<0Q0TA08P32P260`/0O`8907l12@1n0@P0OP8808422@220@P0O`8808021`220`P0Q@@:08T22@2I
2@h0YPdA0:T<3`2R1`/0U0<808P21P1k1@P0Rda>08=gN`1NEUP0:ALB01f80P00o`09ooooo`03052@
N03oP000oh0000`0oh000P3XJ3`;0?n000030=1@N03oP000oh0000@0oh000P2h>;@40?n00080d51h
1@3oP000103@D7P0^3Rd0:0Pl02h>;@40?n000050;Ph]03XJ3`0oh000>QX?02h>;@05@3oP0030:0P
l0030?n0002P8?000?l000Sooooo1@00o`00CP1;/Qd0O6aX075TI@1Q;Bl0Eb<T04dj>@1AAdP0G59I
05]EFP1MFEd0KfM[07Y`L@29OWl0SWak091kN@2=MGH0PfaX08=[HP29LEl0RgQS09:3JP2BPVL0VY1j
09NER02AThP0TY><092@R`2HWIX0ZJb/0:Z][P2Y/[80Zk6d0::YZ`2S[Jh0Y[6^0:Ze/P2V[jl0/HJ>
0:XD7P2g3180]0`B0:0L:01B@g40GT]m09DN=@2N31P0Qb4]06<nG011@6H0MceB08T<5P1TAEX0K8ZG
09NY[P1aQ8`0Ef^601/dI@10FH@0=TId04TiH01e;4H0P@lP08P54P271100OPLA07LU;021LW@0JWUi
06AhN01JL7L0=4]S00LIB@013D<00Pho004A?@0E;dX0@UML00KU1@H00?l02?ooool5003o0006052@
N02P8?00X23`0=1@N03XJ3`0^3Rd5P2P8?001P2h>;@0X23`0=1@N03@D7P0X23`0;Ph]080j6Pl00<0
^3Rd0:0Pl03@D7P00P3oP0001P3XJ3`0X23`0:0Pl02h>;@0j6Pl0=1@N0<0X23`00@0oh000:0Pl02P
8?00^3Rd1`2P8?001@3@D7P0j6Pl0?n0003oP000d51h00/0X23`00<0:<Pl003o0000o`001000o`0;
ooooo`002_ooool0F00Rd0D0B`H203h20P0^0@409P4102L10@0^0@80>08204420P100@80@P4204P2
0P1@0`@0AP8206XL801k82P0Na<I05X2101S0`D0N@8308<10`230@40QP4208/11@2B0PP0T`T@064:
3@1NC4P0aL[70=SIf`3Gf=`0e]SK0=GIg03:/KP0Z5IO0:dR:@325AH0caDE0=@E5`3F5QP0aRd]0<jW
YP3HemP0fmkQ0=[Nh@3Gcm@0`IZT0:mDH@2Y82/0W`hE09d=5@2F3QD0J@X?02/>3`0o@cl0R9:<0<W>
c@3<cM40/9^S080h@P242A40Q`D:08L42@2810T0PP4608821P200`L0OP8708022@200`P0N`4507h3
1`210PL0P`<:08L11`2L20d0[0X?0:d:402R1Pd0UP8808P11P1i10P0PD=40923Q@1LDE@07@/701^7
0P00o`09ooooo`03052@N03oP000oh0000/0oh000P3@D7P00`3XJ3`0oh000?n000080?n000030=1@
N03XJ3`0oh0000<0oh0000<0d51h0:0Pl03@D7P0103oP0000`3XJ3`0d51h0?n000020?n000040>QX
?03@D7P0X23`0=1@N0D0oh0000H0d51h0;Ph]03oP000j6Pl0=1@N02h>;@F0?n000<0X23`00<0oh00
0:0Pl000o`002?ooool5003o001>05:k8`1nKfP0IdE406<b<01?>3X0BCi00595BP1MDUL0H5IN06AJ
H01bIV/0OW=f08]nP02>OGd0SWaj08QbL01nIf80OVII08MaH`28MfD0T89_09J9M@2MTX00U96409FF
RP2EU8X0RhZ208Z;P`2LWiX0ZJbZ0:B][@2/][L0ZK6d0:Na/@2[];H0Yk2b0:V]/02RFV@0/@hH0;H<
502/3aL0O4MS07AJP02L6b`0WQLR06diF`0S>WH0;U>606]iU023=TD0S0/F058cE`1PP9P0RJ2W07fE
X`2N^l`0HGbD09^EYP1o=TP0Q`TG08l23@2?0@`0SP4:08/22@250PT0P0<:07@S:`1bMGP0@e]^010W
C`024TT00A5;008?A0024Ch07cmC04IWI`1<HV803<`;1P00o`08ooooo`D00?l000@0P<000:0Pl02h
>;@0j6Pl6@2P8?00102h>;@0d51h0?n0003@D7P20>QX?0040=1@N02h>;@0X23`0>QX?080oh000P2P
8?000`2h>;@0j6Pl0:0Pl0040:0Pl0050?n0002P8?00X23`0=1@N02h>;@00`2P8?000`2h>;@0j6Pl
0?n000050?n000030=1@N02P8?00X23`00P0X23`00<0D91h003o0000o`001000o`0;ooooo`002_oo
ool05P0Pc`<0BPH104010P0c0@80;04102h10@0^0@80=@4204010P110P80?@0104@20P130P80E`84
06l21P1j0PT0Q0<806P41`1;0040LP<508010P240@8208L10`0/08d51`1O2`h0EDE10;^l^@3De=P0
e=KI0=KGg03Ie]/0aJ6X0:H_>02d5A`0^A4G0;`@4`334140cQ<E0=0D5P3=Fed0e<_<0=cMgP3Lgn40
d<;:0:M@F`2Y72H0[a<L09hA601_2a40A`P;02H:2`11@d80UJ6P0<7:b`3CfM/0aLC;08eOIP1o82P0
P`dD08L83`250`X0R0<908P320240`L0P@8707l1201l0PL207l22@0B07d21`1n0PP0P`<808@2202:
0`P0W`T=0:X8402[2@l0YPH=09/42`280@L0N@@908U9C02APX<0Cd=301/71@0IQ@400?l02Oooool0
0`1@T7P0oh000?n0000G0?n000030=1@N03XJ3`0oh0000<0oh000P2h>;@60?n000070=1@N03oP000
oh000?n0003XJ3`0X23`0=1@N0050?n00080d51h0P3oP0000`3XJ3`0X23`0=1@N00G0?n00080X23`
00@0d51h0?n0002P8?000?l02?ooool5003o001>02[M4@29HeX0IcDc06M?C@1;>c/0BC]00554B`1J
D5L0HEMO06ELH@1aJ6/0OWAh08EjO@2;Ngh0SGUj08E]J`1mHE`0PFMN08E_H`29MVP0UXAe09R9MP2M
TH40U92309NGR`2LVY00TYB;08j@R02;ShP0XjRS0:^c/@2/][H0[KNh0:Zb]@2Z/;@0YJja0:6RZ@2H
?TT0/0dE0;@?5@2[<3H0UV1c0:4O;`2S7R`0GTA_01Y4PP1QQJ<0SiJP08i<E`2C2QH0Qad]02P]H`1b
U;00Ni:L09BZ]`19Hgh0PW2207hH9@2;0``0T`<<09412P2?0@X0RP8:08H32`240PT0Q04906l74P10
>UH00aY@004CD0014D`01AQ;00PLBP0@:DL0BVa[04eXI@1BJVH04=8A1P00o`08ooooo`D00?l000<0
D91h0:0Pl03XJ3`06`2P8?030?n000050=1@N02P8?00X23`0:0Pl02h>;@00P3oP000103@D7P0X23`
0;Ph]03XJ3`50:0Pl0030>QX?03@D7P0X23`00D0X23`00<0^3Rd0?n0003oP0001P3oP0000`3XJ3`0
X23`0:0Pl0080:0Pl003052@N000o`000?l000@00?l02oooool000[ooooo05P08<d304X40@0n0@40
=04102l10@0_0P40;08203410@0m0@40?P4103`00@0n0P80?`4206@31P1b0@D0O04608<21`1X0`L0
@@0006l420200@80Q@4108L20`2<0`D0Q@P<04/W9@2[ZjL0d]?E0=?Df@3Ee]T0f=OL0=>m``2P=Sh0
]1<H0;T@5@2i3aH0^PhC0<4?4P3941D0cADH0=1_L03He=H0gMkR0=WNg`29N7d0KadT06dA5P1B2@d0
:@4200`71`0K9240KGUf0;2i]`3Bf=/0d]WN0;o;d`1RHfh0?A8H03`72@0m1@P0E0T>07D83`261@`0
R@<:08<2201o0PP0O`8907h21`1o0PD0P08907`22@200`T0P@8807l1202:10X0X0X<0:P83`2Z2@h0
Z0P>09/32P290@L0N@@807De=`21LgD0Bcdn01T40`0YB@800?l02Oooool00`1@T7P0oh000?n0000F
0?n000030=1@N02P8?00oh0000<0oh0000<0d51h0:0Pl03oP0002P3oP0020=1@N0D0oh0000H0X23`
0=1@N03oP000oh000=1@N02P8?0I0?n000<0X23`0P3oP0000`00o`3oooooooooo`06ooooo`D00?l0
02008ND;08MB?@1_D4d0Ge9B04Xj>01;>S/0D4=505U=DP1OEU/0IUeR07EYKP22MG/0Q7Ql08QjN`2:
MgP0Q6]Z07UNF@1nIUd0QfmR08]dIP2AOg40Vhel09jBP`2FU8L0V9R?09VITP2@UHd0UIfC08^@RP2G
X9`0Yk2`0:^c]`80ZkFg02`0Z;:d0:Jc]02_/;<0Wc]60;<=502]4AD0aE9G0:LV;`2U72D0HdMa01i9
QP1jUZ/0VHbE094nC02C2QH0SAHS050iH`0`DX<0Li6P09ng``2;Xk<0Nfao07HC8@280PX0S`8908l2
2P2:1@`0OaLS06`^?@1N;3l0MaHT07l23@1?22D02Q9<004DE0015U805S=J041NLP0:8DD0949F051_
K017HfD0=4iG026W:0H00?l02?ooool5003o0005052@N02h>;@0^3Rd0:0Pl03XJ3`06@2P8?00203X
J3`0d51h0?n0003oP000j6Pl0?n0002h>;@0X23`0P3oP0020;Ph]0030>QX?02P8?00X23`00<0X23`
0P3XJ3`30:0Pl0040=1@N02P8?00X23`0>QX?0@0oh000P3@D7P0102h>;@0d51h0?n0002h>;@:0:0P
l003052@N000o`000?l000@00?l02oooool000[ooooo04807ld304X50P0j0@40;04103020P0X0@40
904103020P0m0P80>`4003`10@0g0P80@@8406P21@1a0@H0M`4607T2201E0P@0?00006l41`230@@0
R08308X2102=10H0H@/;089kM@3=dM00c]?E0=?Ff03Fe=P0c[Rm0:YDFP2`5AT0^14D0;TA4`2j41@0
_0lC0<4@503641D0bQ@H0<MUIP3GdmD0g>3R0=WNg`1LI6L08AdO02<Q8@0a=380D5QE08>?S@2[][@0
`l[;0=?Ig02mb]80QiVS03Y>EP0E8bH09bd_02lf=`0Y;bh06ADD02T41P1S2A00P@D<08<22@200`P2
07l2200D084220210`L0M`8407/11`240PT0P04908L12@2O2@d0Z@T>0:T73P2X20d0VP<708`21`1g
10T0SeEH081aLP0m;c005@<303T<0`00o`09ooooo`03052@N03oP000oh0001H0oh0000<0d51h0?n0
003oP0000P3oP0000`3@D7P0^3Rd0?n000070?n000050=1@N03oP000oh000?n0002h>;@01P3@D7P2
0?n000040>QX?02P8?00^3Rd0>QX?0<0d51h5P3oP0020:0Pl0040=1@N03oP000oh00003o00Sooooo
1P00o`00C@23DcD0M6IT05eCDP1>=C<0BBd`05A5B@1GC500HEAL06QIHP1fJ6l0PWIl08=gN`2;NWd0
RgMj08=]J`1fG5D0OFAH08]bIP2<NVX0TH5b09R;O@2HT8<0UYB509NHS@2?Th`0TI^G0;g9bP2UZj`0
TY^F0:Na[`2X/k<0YkBd0:bf]`2Y];H0Yk>d0:Z`/@2SCE80^10G0;H>5P2m72H0/QHN07i4H`0WA800
PhJP09QNJ@2B7RT0U@/G08DV=`16>fT05cag07jN]01nUj40S:N^08>6TP1l8c40S@<=08/2202?0PX0
QADL05XeCP0V;Ud0635P03mCM@1W=DL0I0HL01L=AP0255X05c1M03mNL01HMG/0:DAJ01hhF00R?e<0
BFI^01<[B00253L08ghe00H00?l02?ooool6003o00050=1@N02P8?00X23`0?n0003@D7P05@2P8?00
0`3XJ3`0d51h0:0Pl0060?n000060>QX?03@D7P0oh000?n0003@D7P0oh00102P8?000`2h>;@0oh00
0;Ph]0040:0Pl0030;Ph]02P8?00^3Rd00<0oh0000<0j6Pl0:0Pl02P8?000`2P8?000`2h>;@0X23`
0:0Pl00:0:0Pl0H00?l02oooool000[ooooo05P07/`204P50P0e0@40;@4202l20P0Q0@009@830381
0P0m0P80>P4103`10P0a0P80?`<507432@1i0PX0M`<:068320170@<0E08307P210220@<0Q`8508h4
2@261``0DbXV0;o1_@3>d]@0cm?G0=3De`3;/;H0VCm30:dI702b4A<0W1<G088A501n4aH0VQ@H0;hC
6P323Q<0a10E0;He>`3H`LH0f]kP0=_Ph030bLP0/[bh0:Vf[`2/]k40a<g<0=;Ig03AfM`0b=3H08nP
Z00mEE`0<TQ;06MiMP2GY:00YK2_0:Ve]02V/K40TYfF04I:A@0R0`@0K0P@08822P2410T0P`@80801
1`220@P0P`<807@10P1l10T0Q08908<22@2<0`P0W`T<0:H93@2W2100X`@<09/32P2?0PP0M0@9085=
C`1dHVH0=2@V01<10@0m30D00?l02Oooool00`1@T7P0oh000?n0000E0?n00080j6Pl0`3oP0000`3@
D7P0X23`0?n000080?n000030=1@N03XJ3`0oh000080oh0000<0j6Pl0=1@N03@D7P00`3oP0001P3X
J3`0^3Rd0:0Pl03@D7P0X23`0;Ph]0<0d51h0P2h>;@D0?n00080X23`00@0d51h0?n0003oP0000?l0
2?ooool6003o001=08QM>01ZEU@0HU5B04/L7P1=7R80E3i505Q:E01REUl0J5UP07MXL020LWX0PgAi
08YhNP2;LWD0QFaZ07EHE@1kH5T0S7A[0961LP2HR7X0V8]k09VAP`2GU8H0VIbB07b6P@2e`<00[kc2
0:2X[P25SHX0Xj^/0:Ra/P2W/[80Yk:d0:Jc]@2Q[k00XZb_0:MWJ`2d4Q/0]`XF0;P<5@2d92`0TfEo
08UDL`2E9CH0X10L09P>6@22=4H0>3a]00heM01RQJ00PYJN0:Fha020VJ/0T7F308L:5@2B0P/0T@4:
09032`1l7bd06B1?03=FN`1`S9X0PGb406dL9`191bL01a9H00/SGP1AKgd0EW9a05A`M`067d40>UEZ
00HK@00?9d`00@m0004>>@0JIc@01P00o`08ooooo`H00?l000D0d51h0:0Pl02P8?00oh000=1@N00D
0:0Pl0030=1@N02P8?00d51h0080X23`00@0d51h0?n0003oP000oh000P3@D7P01@2P8?00oh000?n0
003oP000d51h00<0X23`00<0d51h0?n0002P8?001`2P8?040?n000030=1@N02P8?00X23`0080X23`
00<0d51h0:0Pl02P8?002`2P8?06003o00_ooooo000:ooooo`1H01g;0P121040;@0102X10@0[0P80
8`4102H10@0j0P80@08203T00@0n0@80<@8402T1101>0`P0E@8:04`22@110PH0G@@907l62`2410P0
Q08708T21`2;0`P0I@d?0928Q@3=dM80d=;F0=3CeP37][X0WS]10:LF6@2B4QH0C0T=02TI6@0h>3L0
?C`n02hK70254AH0_0hD0<4>4`2l4aL0^TeG0=>V[P3Kc=80gM_N0=cKg`3Jf]d0f=?G0<G5c@2>WjX0
EFYe04MMH`1[Ngh0[;Nh0<38b@3=eM@0d=OG0=3Ff@3?eMT0cmOH0<kGe@30alD0PG]i068H70210`/0
Q`<:08H220250`L0Q08708D31`220PL0P04908022@240PL0UPL<0:89302T1`h0Y@T@0:873@2K0`X0
S`8807451`2DIFD0JUIJ024B500D0P40?PX3003o00Wooooo00<0D91h0?n0003oP0005@3oP0001P3@
D7P0oh000?n0003oP000j6Pl0;Ph]0<0oh0000@0j6Pl0=1@N03@D7P0j6Pl103oP0000`2h>;@0d51h
0>QX?0030?n000030>QX?03@D7P0^3Rd00<0X23`00<0d51h0?n0003oP0001@3oP0000`3XJ3`0X23`
0>QX?00B0?n00080X23`00@0j6Pl0?n0003oP0000?l02?ooool6003o001=09=S?01XB4H0I4Y;04d>
3P1>6AX0E45305M:D01RE5h0JEYQ07MVKP20KWH0P71f08EfM`27Lg@0QF]Y07QKE`1mHEd0Qg9Y0960
LP2DQGD0UhUj09ZAQ02GU8H0V9^?07V2O02MZJX0W:V_092HW02AUYD0Y:V/0:Z_/`2Y/kD0ZKBf0:Fa
/P2X];@0ZK>e0:b9S@2T5R00]@hJ0;H>5@2^4Q/0WR8d09lF902V4AX0VQ@Q088iC`13A7@04cMd05Ij
VP2BZk80S9nY0;73d@1/Oi80P4]H08d73`2?0P/0RPH>08D53@2131P0Je5V08BLY`2DWJ<0O4UB07D8
5P0c23400a9H020lI@1MMgX0G7Ef03IBIP0<:4L0BfQc00HH?P0144<00@e0004?>@0KBCT01P00o`08
ooooo`H00?l00P3@D7P00`2P8?00oh000?n0000D0:0Pl080^3Rd0`2P8?000`2h>;@0j6Pl0?n00003
0?n000070:0Pl03XJ3`0oh000?n0003XJ3`0X23`0=1@N0020>QX?0@0X23`0P2h>;@30:0Pl0@0oh00
00<0j6Pl0:0Pl02P8?000P2P8?000`3oP000X23`0:0Pl00;0:0Pl0H00?l02oooool000[ooooo01<0
<[T703H30@0S0@009@8201l10@0V0@40:P4103T10@100@40@04004D10@0e0P@0604302T31P0`2@/0
<@H904D3201m1Q00R@890080S0@904<0SP<608<;2`1E9R@0_/700<_@d`3>d]D0dLoD095DFP2G61h0
LPlE02T3100k?c`0XJfX0;2l^02a^kL0Z:b[07lb<`2d4aD0_P`C0;h=4@2j4aX0ZalZ0;==F@38Phd0
bhbJ0<9jR`2QFF/0BRhn00dP:01BIfT0UJ>P0<kCe03EfM`0dmKJ0=7Gf@3@emT0cmKH0=3Ff@3@eML0
c=?E0<oDe`3@dM80OT]>07X52`210`L0Q`<808T320250`L0PP8607h11P210`X0O04808811`2I20h0
X0H<0:<7302T2@h0X@L<09T42`2:0@P0K`P:09IYJP1C?Cl03P@401@10@0n2P@00?l000Wooooo00<0
D91h0?n0003oP000503oP0000`3@D7P0oh000?n000020?n000040:0Pl03oP000oh000?n00080d51h
0P3oP0020=1@N0@0oh001`2P8?000`3@D7P0X23`0=1@N00;0?n000030=1@N03oP000oh000100oh00
00<0X23`0=1@N03oP0000P3oP0000`00o`3oooooooooo`06ooooo`H00?l004h0MW/[06m9A01S>cP0
E@l>05<Y:@1EA4@0Fd]@06IEG@1`EUl0L4A>07E@F01iJFl0OVi`08IcM029Kfd0OV1K085VHP2:M6`0
T7ib08j0L02CR7L0UY2309JDQ`2IUhl0R8Z507j5Q02:Shh0QHV509jSX@2X[jl0YZf_0:Vc]02Y];D0
ZK6e0:N_/P2P[:h0[:na0:A?F02`5R80]`hE0:XJ8@2N:C@0T39307A2G@16AG@08D5g04M]U@1nVZT0
Y;Rn08ZNY@2L[[L0RInY09:OZ`1k:SX0RP@;07`R;P18=ED0DCQA07LE801m7RP0XWR507d`@02021<0
L`lN01/@A0078EP0Cfmn05adN`0bCF@022A:03UJJ@1EL7007cI?004@@P0244003bI302@hA@03lP<5
003o00Sooooo1P00o`001@2P8?00d51h0=1@N03oP000j6Pl01P0X23`00H0oh000;Ph]03oP000oh00
0;Ph]02P8?020=1@N080X23`00@0oh000>QX?03@D7P0d51h2`2P8?001P3oP000^3Rd0:0Pl02P8?00
j6Pl0=1@N080X23`00<0oh000=1@N02P8?00302P8?000`0Xb3`00?l0003o0003003o00_ooooo000:
ooooo`1H04RW3P0c1040700001X20P0?0@408`8102/00@0j0P80A04104X10@1=0@80BP<801h2101X
EEL0[9^P06E2AP1e5a`0R0D>08`32P2<10P0T@H9098:3@1^5Q@0M6AN0<_Bd@3;dM<0d]?G0;FJX01o
8RD0C`/=02dL701VK6/0_LO20=KIf@3KgMl0f]gO0=OLf`2kT8d0YAhM0;h>4`303a<0`PlD0<<A5`2o
5A`0^ATQ0;DJ902V72P0GA0H03D_<P23TI00]l;10<oFe@3Bf=/0d]SL0=3Ff@3>emP0cmCG0=3Ef03B
e]T0cmKI0<cEe`3>e]T0cmGH095fN01g20l0O`8608P42P2;1@/0PP<708022@1m0PT0OP<807`32024
0`L0V@L=09d7302P1`/0Y0X=09h52@2F0`X0Q`47070<3`2RNW`0DSi000T10@0I0P40@@X4003o00Wo
oooo00<0P<000?n0003oP0002P3oP0000`2h>;@0X23`0;Ph]0070?n000060>QX?03oP000oh000?n0
002h>;@0j6Pl0P3oP0020=1@N0@0oh0000<0^3Rd0?n0003oP000103oP0040=1@N0030>QX?02h>;@0
d51h00`0oh0000<0^3Rd0?n0003oP000403oP0000`2P8?00d51h0?n000020?n00003003o0?oooooo
oooo00Kooooo1P00o`00CP1RRah0MTY705ll=P1D<R/0DD0n0553A`1MCUH0JdUC06hf?P1/51d0M3@j
075MH`1fIFP0OVQ/08=YJ`22IV@0OVAP08YbK02=NFh0SWa_09:6N@2FSX<0V9B;09RGS`2GVi<0V9jG
08j@R`2;ShP0Uj2N09ZSY02HXZ<0Yk2`0:Rb/`2X/kD0Xk2`0:>^/02IXJ@0Ye=L0;0A6P2`41P0PE1c
03QFR@0lG8X0B6^E06J6X@23WZX0SjBX09JXZ`2CYZT0TJV^0:JmaP1IMX/0TjB_07Xa?@2:1Q00KRY1
04aCO02>SJL0Pd5=08<53P241Q00O0TB06LP;P0d9dT011I>039DM`1@KH4063=L00@PC00gEFX0FWAg
05QaK`1@Ifh062m:020lD`16I6T0<TU>00k@3`D00?l02?ooool6003o0080X23`00<0d51h0?n0002P
8?00102P8?000`3XJ3`0^3Rd0:0Pl00B0:0Pl0030;Ph]03XJ3`0j6Pl00<0j6Pl00@0^3Rd0:0Pl03o
P000j6Pl1`2P8?030;Ph]0<0X23`00<0d51h0?n0002P8?000`2P8?030?n000030=1@N02P8?00X23`
00`0X23`00<0D91h003o0000o`000`00o`0;ooooo`002_ooool0@@17YPh0<`@101`10@0H0P804041
02820@0/0@80>08104020P180@80DP0205X31`1H8bL0E3U106PmB01a8B/0O@D=08P22`290`T0S0D:
09@72`296QT0Cb`V0;Jh]039d=80c]3C0;:JW`1c;c@0=`d=06IXI`2^]K<0cM?D0=SCe`34VZ<0[VYf
0:21RP3Ff]d0d[o009P];P2o51L0`@hB0<D@5P333Q@0aa8F0<4C5P294180>``<05UJEP2f`;d0d=WH
0=7If@3DfM/0d]WK0=3FfP3AemT0cMKF0<kEf03>dmH0cMCF0<gGf03>e]T0c]KH0=3Gf@2FNGd0N`/A
00<0P08901@0OP8:07`22@1k0PP0N@8707d3202:0`T0V0D;09/62`2M1``0X@P;09d52`2E10/0QP48
07TE6@2RNWd0<AlT00@10@0L0@80A@T3003o00Wooooo00<0P<000?n0003oP0002@3oP000103XJ3`0
^3Rd0:0Pl03@D7P70?n000030>QX?03oP000oh000080d51h00H0oh000=1@N03@D7P0oh000>QX?02h
>;@20:0Pl0030?n0003@D7P0d51h00P0oh0000<0^3Rd0>QX?03oP0003@3oP0000`2h>;@0oh000?n0
000?0?n000030>QX?02P8?00d51h00<0oh0000<00?l0ooooooooool01_ooool6003o001>04BT301^
<2<0KDm:05M6@01A@400ETE706=9C@1R8bT0IaPM06dQ9@1X>Sl0J59J079PHP1jIFL0OFAW089XJP26
JfX0QfeY08]gKP2=OW40UHQi09N>P`2IUHd0VIN@09NJU02DViH0PhR308B;Q01lQWl0NhF208J@T`2H
XjD0Y;2a0:Fa/P2T/k<0Y;6c0:FSZ02Q>D<0^0lG0;D?601l@fP0Eh2V09FZ/`2GZJd0U:BY09BUZ@2D
Z:X0ZKbo08jSZ02BZ[80PIjV07nL/@1/RZD0SWMo07hA6`201a<0NPlQ07X=7`1m2180P@<:080D701@
<dl04B5=02A0HP0jEG802R=<00PQCP0T@F@0CFik05iiN`1SNGX0Fg=c05UaLP1?JVT0EW5_055]J`0W
@TP07J@P1@00o`08ooooo`H00?l000@0P<000?n0002h>;@0^3Rd0`2P8?00102h>;@0oh000>QX?02h
>;@E0:0Pl080j6Pl00@0oh000>QX?02P8?00^3Rd0P3oP0060:0Pl0040;Ph]03XJ3`0X23`0;Ph]0@0
X23`0P3XJ3`20=1@N080oh0000<0j6Pl0:0Pl02P8?003P2P8?000`1XZ3`00?l0003o0003003o00_o
oooo000:ooooo`1H04JT3@0a0`408@0103HB4P0I0@406P4102@00@0e0P80>@4104H10P1D0PD0F@43
05T42@1L2A80H`D<07432@1o0PT0Q`8:08P32P2;10/0S`L;074Y9@2NV9@0cM;C0<cBe@2aWj80I2/_
03XH5`1nPX00c<o@0=GBf034YJl0ZDA@0:`K90285QX0MEIF0=WKg@3;YJX0YBDY0<4D5P3241@0b14F
0<XC5P334QH0R10B054m>`2PYZ<0b]?@0=GKg@3DfM`0d]WK0=?If`3BfM`0d=KK0<G6b`2bZ:l0W82<
09MmR@2a[[D0bm?G0=;FfP3BemX0c<_@07m9D@221Ph0P@<807d1201n0PT0P08907T2201d0@L0M048
07@21P1n10P0T0<909T52@2L1@X0W`L=09/3302A0`X0Q@4707HJ7@2HN7X06a0C00810@0K0P40@`P2
003o00Wooooo00<0P<000?n0003oP0004`3oP0000`3@D7P0oh000?n000020=1@N00;0?n0003@D7P0
oh000?n0002h>;@0X23`0=1@N03oP000j6Pl0?n0003@D7P01`3oP0000`3XJ3`0d51h0?n000060?n0
0080d51h0P2P8?000`3@D7P0oh000?n000020?n000030;Ph]03oP000oh0000l0oh0000<0j6Pl0:0P
l03oP0000`3oP0000`00o`3oooooooooo`06ooooo`H00?l004h0A;L=06DZ5`1_D4d0EdQ205Dg>P1O
<ST0IcXo060e>01YADP0Id]B069?E`1PCEH0JEAI07AOHP1lHVH0PVMZ08Q[K028L6/0Sgae0963N@2F
RG/0VI:509RES02KVY@0RHf607n7P01`Ng80Lgef07R1O@1eP7d0OHV908^JVP2JYjP0Y[2c0:6/[@2T
/[<0[ZV^09d/=02i3A@0^0/A0:0V>P1CGH@0V:nh09b/[P2M[;00VZV^09FVZ`2AY:L0YkW00:BlaP1B
M8`0NYV^04]`RP2_a<X0W8J@06Hd@`1R9CT0GRXo05PdA`1g7b/0Ob0[04<^CP1JCFD0IUAM06A@E01Q
GfD0Ffic05McLP1IMW80G7Ue06=lN`1PN7P0Fg=f04aYI`1>K6L0Cfa/020lA00XXR`5003o00Sooooo
1P00o`000`1XZ3`0oh000:0Pl0040:0Pl0030;Ph]02P8?00X23`01H0X23`0`2h>;@00`3XJ3`0^3Rd
0=1@N0020?n000080;Ph]02P8?00X23`0:0Pl02h>;@0X23`0;Ph]02P8?020;Ph]0<0X23`00<0j6Pl
0:0Pl02P8?000P3@D7P00`2P8?00d51h0=1@N00@0:0Pl00307QH]000o`000?l000<00?l02oooool0
00[ooooo05P0@Z<<0303000S0P<0E34b01d20P0G0@408@8103410@0h0040A`4304`00P1?0080D`02
05h01@1V0@D0KP4707P12@220P/0Q04808X42P272@`0NE5<0<S<b`3=e=D0d=7B07ICE`0Z20/0I6AO
0<[>cP3Dc=80/H>=09h`>@2h5A/0Ta<F03h>3`2_[:/0gMcO0;YdO02h6B00`a4E0<DA5P374QH0bA<H
0:/B5P146QX0/;Rf0=CMfP3Eg=`0e=_M0=;If`3Df]`0d][L0<oAf02LPY80PDYF07HS;`1l5240KAXV
050mA02i`L@0dMOJ0=;Ef@2TTYX0LAhX08@52`210PP0O@8807d21`1o0`T0M`8707411P1c0@L0N0<7
07`21@2>10X0U@@909`52`2L10/0V0D;08`120240@L0PRd]08Q]K@0=1@L00@0001T1000n1P400?l0
2Oooool01020`000oh000?n0003@D7PA0?n000090=1@N03oP000oh000?n0002P8?00oh000=1@N03o
P000d51h0080X23`0`3oP0000`3@D7P0oh000:0Pl0070?n000030=1@N03oP000oh0000D0oh001P2P
8?001@3@D7P0oh000?n0002P8?00d51h0140oh0000<0d51h0:0Pl03oP0000`3oP0000`00o`3ooooo
ooooo`06ooooo`H00?l004h09]D706H_701Z?c`0HTA005`O8@1R7R@0GSHl05m9D@1MBeH0I4mJ061>
E`1LBU<0HD]B06QAE@1eFeh0QVa/08]_L025LFd0S7]c09>2N`2HRgh0VI>609ZGR`25Pg/0N7ee07=j
L`1cOGH0Mh5j07V2O@1gPWl0N8>3082>SP2AXJ80Wj^_0:2[[P2Q[K40][2e09TZ=02f3QD0^PdC0;4>
601o@5l0N8jX09^//@2IZ:`0WJj`0:Nj_02F[K80W;>j08NP[@2K]<D0F7^K05Z4W02ie^00_m?N0:Jk
bP1WOIX0>dQ/04XhEP1d4B00Q0D>07T75@1c1@l0K`@<06X32@1T2Q40I3Tl065/K01KLg40GgQe05]f
L`1NNWP0B6=X02m>D@15Hf<08CY=00LK=@0`OS`5003o00Sooooo1P00o`00101@T7P0oh000;Ph]02h
>;@20>QX?1d0X23`00<0^3Rd0:0Pl03@D7P00P3oP0000`3XJ3`0X23`0:0Pl0020:0Pl0040;Ph]03@
D7P0^3Rd0;Ph]0@0X23`00<0j6Pl0;Ph]02P8?000`2P8?000`3@D7P0oh000=1@N0040?n000030;Ph
]02P8?00X23`00T0X23`1@00o`0;ooooo`002_ooool0AP12X``0=PX704d`<@1I@dD04`4101H10P0N
0040<08203/10@160P@0B`4304d10`1F0@D0H`4606X11@1b0PT0NP4:07d21`1o0PP0QP@908PL7@2=
NgL0b]?C0<gEeP2e/;40?2DV05aKF@2f^kT0d<g@0:U[M`2M82`0/A<I09`A5P1@7b00ViRG0=CFe`3J
ald0[cPo0<DD603641@0bQ8G0<PA5@2n5AX0Ka4D09:>S03EfMT0fMgO0=SNgP3Ffmh0dm[M0=7Df@2o
[[H0TUIQ08DO:P294AX0R0`D07/<4`0m3100ADU:0;c7a`3?eMP0]Zje07<i@`1k3AH0P08;08832`1o
0PT0N`8607T11`1b0@D207411P0@07T11P260PH0S0<80903202E0`X0V@@:09@32P2<0PT0QP8808@d
=@1hG5l0208400810@0N0P40?`D1003o00Wooooo00@0P<000?n0003@D7P0^3Rd403oP000103XJ3`0
^3Rd0?n0003oP0020>QX?0030=1@N03XJ3`0j6Pl0080X23`0P3oP0001@3XJ3`0d51h0?n0003XJ3`0
^3Rd00H0oh0000<0d51h0?n0003oP000103oP000103@D7P0X23`0=1@N03@D7P30?n000060=1@N03X
J3`0oh000=1@N02P8?00j6Pl4@3oP0000`3@D7P0X23`0?n000030?n00003003o0?oooooooooo00Ko
oooo1P00o`00CP0Qi0T0HBT;06ho>@1R9R@0I1HF068a=@1LAdl0F4Q?05e;D`1PBe80GDI@05]7DP1O
Be80HdmA06mGF`26K6l0Rg=b08QdL@2=Ng80TX=i09F9P02HTXL0RXMl081mM@1jOGL0JG=_05e^J`1I
JfX0IGIf07F1P@1fPX<0NXJ707j>SP2GYjT0V:JY09VW[@2WZ:d0VSQ10;0;4`2h2Q00^0/A0:8H9P1Y
EgT0UZjn09ZZ/@2I[[D0SZFX0:Rn``2P^L40IHVQ072B[@0jI8L0VKc:0<3Eg`2kb=L0W9:U07Q6F`1a
6BT0NPLC08H33@270PX0P`4:07T12@1d0@T0L04706l1201T10T0I4A605]^K@1GLW00EG=_05IcK`1?
JV`06cI7014W?P013C<00@l_02M6=`D00?l02?ooool6003o0006052@N03oP000d51h0>QX?03oP000
d51h7`2P8?001@2h>;@0oh000?n0003oP000d51h00<0X23`00@0^3Rd0:0Pl03@D7P0^3Rd0`2P8?02
0;Ph]0<0X23`00<0d51h0>QX?03oP0001`3oP0000`2h>;@0X23`0:0Pl0070:0Pl0030;Ph]000o`00
0?l000<00?l02oooool000[ooooo05P0?Z0;048H4@19:R/0:@lC01D10P0H0P80704102`10P0l0P80
@`4204/10P1A0@<0GP8606D11@1Z0PL0JP@:07442`1n0`L0P08708D42`2<>c`0/Jn/0<gCe@3<dmH0
EeIF06U/I`36c</0d<_@09eMIP2P5Q/0ZQ0F08dA5@106AT0WjFS0=;JfP3Ke]X0]61Z0<0G70384180
bQ4D0<dB5P356A/0Na4A08QbL03@fML0emgO0=KLgP3HgMl0e=cM0:2[]01NCUd0ORHd09L@5`2H3Q80
S@dA06h=4P0Z2PX0CU]F0;6o_03@emT0`Ko407Pm@`1n2a<0P`@:07h3201m0@T0O`8:07d2201j0PP0
L@8506h10`1`0@@0N@4408<110230@<0RP8609832@2G10/0T`4909022P250`T0Ue=F03/T:0060@80
104102H10P1110800?l02Oooool01020`000oh000=1@N03XJ3`@0?n00080d51h0P3oP0020=1@N004
0?n0003XJ3`0X23`0>QX?080oh000P3XJ3`00`3oP000j6Pl0:0Pl0060?n000030=1@N03oP000oh00
00<0oh0000<0^3Rd0:0Pl02h>;@01@3oP0001@2h>;@0d51h0?n0003XJ3`0^3Rd01<0oh000P3@D7P4
0?n00003003o0?oooooooooo00Kooooo1`00o`00CP1[<P`0LCdg06HO6`1V<Bl0GTU>05E5C@1HADh0
FTMA05Y5D01L@dh0GDMC05m;DP1SCE<0KeIJ081VJP2>MG@0S7Ec095oN@2EQ7`0T8Ik0969P@1gM6d0
IfiX06ifM01LKVd0Kgej06EgM@1<HfD0K7ek07=oO`1cPH80NXZ9082ATP2>Wj40U:FX09^VZ@2QF600
[1@O0;P;5@2g2Pl0/`/B09T[?`1cN8l0UZ^b0:2e^02_a<X0V;6j07^HY@2<Z;P0Ih^Y062<Z02[amT0
XYZ[08M5FP224R00P0@>07l12@200PT0PP8908D22@240PP0O08907<22@1a0PL0L04706X11@1I6b80
ADeE05=`K`1CL6`0D6m^02m:G00243L00@`c004:;`013bd07Rdd00Cc0`@00?l02?ooool7003o0004
0?n0003@D7P0oh000>QX?240X23`00D0d51h0?n0003oP000oh000;Ph]0020:0Pl080d51h00<0^3Rd
0:0Pl02P8?001@2P8?000`3@D7P0oh000?n000090?n000030=1@N02P8?00X23`00P0X23`00<0:<Pl
003o0000o`000P00o`0;ooooo`002_ooool0F010Y0T0Aal@02440`0G0@805@4101`20P0O0@80:`42
03/10@160@80DP8205P20P1O0@H0I`8606D21P1;00@0C`8407d4202310L0P@@808eCD033a<<0c]?D
0;c5a`0b@cd0]l2i0=7De@2]R8l0UQTN09h@4`1i4AD0;0H608>:QP3?f=P0e]OL0<NJX`2b8BP0a1<F
0<@@50383aD0bQ0E0:HO7`1O>SP0dM?A0=KMg@3Gg]l0emcM0=WLg`3Bfm/0UJBV02LS:`1N4QT0U`lC
08TB5P1J31007@@403i>A`2c_kX0c=KF0<S>d`26HFT0P14H08H42`230`/0OP8807h120200PT0P@<:
07`22`1`0@D0K0020781101l0@D0PP45084010260PD0S`4609D22@2D0PT0S`4908@32@25A4T090hD
00H10`070@40;04103l20000o`09ooooo`030830003oP000oh000140oh0000@0d51h0?n0003oP000
oh000P3@D7P00`3oP000X23`0=1@N0030?n000050=1@N03oP000oh000:0Pl03@D7P01@3oP0000`2P
8?00oh000?n000040?n000030=1@N02P8?00oh0000@0oh000P3@D7P20?n000030:0Pl03oP000oh00
0180oh0000<0d51h0?n0003oP0000`3oP0000`00o`3oooooooooo`06ooooo`L00?l004h0K4L>05hP
5`1`>SD0JeEF05A6BP1C@T/0ET=<05Q8D01JAdh0ET5:05Q1C01MBU00I4mE07=MH020If/0S7=b08mg
M@2?OgT0TXEo0926O`23OW80L7A[06UbK@1RJfT0EFQZ061`M01DJF`0CfAT0761O01`OWh0Kgj107N6
Q`1lSHd0PiFF092PX`2IYjT0[8^C08hN:P2_3aT0^0`A0;@;402^3AL0SCY@092O]02EZ:l0WK6i09Zb
_026Ykh0IXVZ02U;N`1kRJ<0SUY`08<E:@2?1A80SP8;08H12@200@T0O`8808D22@211@`0Ma/U06DZ
?01@:Cd0FbLf06D63@1X0PD0EaPU010H;@1>Jfh0C6UY01PaC@013cl00@Th008:<`076S809dM=028g
=`0BdPl4003o00Sooooo1`00o`000`3XJ3`0oh000>QX?00S0:0Pl0040>QX?03oP000oh000>QX?0<0
X23`00<0^3Rd0:0Pl02P8?00102P8?000`2h>;@0j6Pl0?n000050?n00080d51h00D0^3Rd0=1@N03o
P000oh000=1@N0090:0Pl0030;Ph]01@T7P00?l000<00?l02oooool000[ooooo05P0@jT=03/F2@0M
0@405P4201L10@0J0@406P4002X20P0l0P80AP4105@20`1K0@D0H@4606P11@1X0PH0I`@:06831P21
10X0R@@:08@:3@2CJ6D0b/k?0<_Be@26U9H0N8J20<oCd@2fWJ@0S3<j08P@5@1=2@/0;1/K07EkN036
cl`0e]3F0;n@VP2[=Sd0_Q<H0;d?4@2n3a40a0hB0<4D5P28>c`0/Jn^0=OKg03Gg=h0e][L0=CAe@3D
cmH0em[N0=3KfP2R[JX0ABl`05dC5`0_20T07a`J05=QFP2/^K<0cmKG0<33b02;KgT0LaLP08D53028
10/0PP<907l2201o0PT0O`4808032P1l0@X0L@4606T10@1`0@<0O04408821`1j0@@0P@8508`21`2E
0`X0U0<:09822@2310T0T5UM01031P030@402P4003H30`0o0`403M812Oooool00`20`000oh000?n0
000A0?n000030:0Pl03oP000oh000080d51h00<0oh000=1@N02h>;@00`3oP0001@3@D7P0oh000>QX
?02P8?00^3Rd00D0oh000P3@D7P40?n000050=1@N03oP000oh000=1@N03XJ3`00`3oP0001P2h>;@0
d51h0?n0003@D7P0X23`0>QX?1@0oh0000<0X23`0?n0003oP0000`3oP0000`1@T7Soooooooooo`06
ooooo`L00?l002L0DfD605TU601bGUT0IU]J05Q7B@1A9bl0ES<j05E3B`1IATl0ET1905M1B`1MBU00
J5=H075NH01mIVT0RG9b08ihM`2AP7d0SX5m08^1NP1oN6d0NGY^07QkL`1cNgH0AUUK04=LG`17HF40
HgEd079oO@1ZNW/0Kh2308>@TP24Ti@0QYJE08nPX@2GZJX0[:V_0:ilQ`2M8B/00P2d2a809@2a2A40
X``H09QCHP30aLX0WkFm076AXP24Wjl0UZJf09QnT@289cP0TPLD0942302@0P/0S`8<08/3301n1@`0
P@/B07l32`1/;T<07RQI01DaHP0Y@F@0AS]@05h73`1R10L0?24e00XQ?@1<JW00CfQ[00DF>`023D00
0@/g01D]A00dF5L0?emG02Lo>P0O/AT01000o`08ooooo`L00?l000<0d51h0?n0002P8?000P2P8?00
0`2h>;@0X23`0:0Pl00K0:0Pl0040;Ph]02P8?00X23`0=1@N0<0oh0000<0j6Pl0:0Pl03oP0000P2P
8?020;Ph]0030:0Pl02h>;@0j6Pl00L0oh0000<0^3Rd0:0Pl02P8?000P2P8?020?n000030;Ph]02P
8?00X23`00L0X23`00<0d51h06RX?000o`000`00o`0;ooooo`002_ooool0F012ZPl0:@H101/10@0F
0@40708201H10P0D0@00:`8203d20P1:0@80F04305d21@1S0@H0K08806l0201g0@X0O@<:08@32@2:
10/0P@/>0:21O`3=d]<0b=7C07F3P@34bl/0ZIjS06D[<P1>3a808Pd>05MPG02X][80c]GE0=?4b`2[
Ef@0ZQXQ0;/B502k3a80_0lA0;d>40314100]bd]0<B][03Hg=`0f=cN0=KAeP2`Mh40W3Y409`b@02P
Hg80cLcB0=GKg02OYJP0;SLh06imN02U]Jd0am;?0<g?e02NPX/0O3Dn07TA601i0`P0OP<808@52@22
0`P0P0<:07h2201m0@L0OP8807/22P1d0PH0KP4307@20`1n0P@0O`4607/2101o0@D0R@8709<32P2E
0`X0T`890849301`A4D02@0100810@0?0@40=`8303d2000A`P49ooooo`030830003oP000oh000140
oh0000D0X23`0?n0003oP000X23`0?n000020=1@N080oh0000H0^3Rd0=1@N03oP000j6Pl0:0Pl03@
D7P50?n000060>QX?03@D7P0oh000?n0003XJ3`0^3Rd0`2P8?001P3XJ3`0oh000=1@N03@D7P0^3Rd
0=1@N080j6Pl00<0^3Rd0=1@N03XJ3`05@3oP0000`2h>;@0oh000?n000030?n00003052@N?oooooo
oooo00Kooooo1`00o`00CP1HJP/0GR`N06YAC01/Fe/0G3<g05@<4P1H92T0E3m805M6C`1F@4P0FTA;
05e9CP1_G600N6AX081VJP26K6l0RW1b08ilN@2@QWd0RH9i07eiK`1jNFl0O7ie0823O@1cNgP0JWMc
06ajM01aO7L0U:>O0<3<c@2DXJ@0Ohf>09NXZ02?XJ00S9fP08nRY@2IZ:X0ZJZ^0:A]L`2Y4QX0]@`C
0;494@2]1`l0X`hJ0:MRK@2PYZ`0V;;208bEZP2DEf/0SA0Q09L4402H0P`0U@<=08/22`222A40NBXc
08M4C01j3QP0KQh/020TE@11HH`0IGb;06iHH01R3aT0J@8806<V;@0C73/0<e=X04i/KP1CK6l03R0n
00`Q@`0E;4H0?V1S04=SG010GUL08S/k02RO9`@00?l02?ooool7003o00070=1@N03oP000d51h0:0P
l02h>;@0oh000=1@N00E0:0Pl0050;Ph]03oP000^3Rd0:0Pl02h>;@01P2P8?001@3XJ3`0oh000?n0
003oP000j6Pl0080X23`00@0^3Rd0:0Pl02P8?00^3Rd1@3oP000103@D7P0X23`0>QX?03@D7P40:0P
l0030>QX?03oP000d51h00X0X23`00<0d51h07QH]000o`000`00o`0;ooooo`002_ooool0B00kWP/0
:P<101/10@0F0@805`8101<10@0B0@409P8204820`1<0@80E@4205/1101V0@P0K04807812P1m0`/0
Q0<=08H32`250`T0P``A0:R9RP3:d=80/kbn0:^d]032b/d0;cLj01dN700oAd@0Qi>@0<K=cP3Fe=P0
b:Zc0:8kAP2`4QL0]`lA0;H=3`2g3A40^`dB0;l?4P2n4180_eMH0=3:b`3Jfmd0fM[N08a`N0217BL0
OQ4G068=4@0b3AD0FfA]0<WDf03Af]/0^LC10<oHf03=dmH0]:V`08I?G01e5R00M`hE07@:4@1c2@l0
N0<907l42@1o0`P0O04707/21`1n0@L0P08907h32`1e0@L0M04407`21@80OP8400h0P@4408811027
0PH0T08:09<22P2@0PP0PAPK05Pf>@070@400`8201P10P0m0P80?@8001720@Wooooo00<0P<000?n0
003oP0004@3oP0002@2P8?00oh000?n0003@D7P0j6Pl0=1@N03oP000d51h0;Ph]0020?n00080^3Rd
00<0j6Pl0?n0003oP000103oP0001P3@D7P0oh000?n0003oP000X23`0;Ph]080oh0000D0j6Pl0;Ph
]03oP000oh000>QX?0020?n000030=1@N02P8?00d51h01H0oh0000<0j6Pl0=1@N03oP000103oP000
0`1@T7Soooooooooo`06ooooo`L00?l004h0=IL405XU5@1`BDD0JcLi05hB501B51L0Ec@f05=0A`1G
@d`0FDA=05U3B`1PCE@0LF1S07aYJ`1kHVH0QFY/08AZK027LW40SH9k08YoN@1nMg00MWI^07QiK`21
PGX0O85l07R1OP1hQ7d0Lh5k0;74a037f=l0Wk2h07b?T023UID0QiVJ08:BU`1nTYD0V:R/09fZ[`2X
Yj/0Ud=:0:X<502a2@h0/@T?0;094@2Q3aT0XemZ08aiR027<4D0V@PF09/43P2H0Pd0U0<=08P74@1a
8cH0ASMQ04lkH01h5bP0LQ@Q03@YE00ZAWH0SIR[07A2E@1b2AH0M@880783201V2a@0DR`h05aUJ01C
K6T0DVYZ03UEFP16IFH0<deF03IFG@17IV00@EiK01Da<P0bOc<4003o00Sooooo1`00o`001020`000
oh000=1@N03@D7P20?n000030;Ph]02P8?00X23`01<0X23`00<0j6Pl0?n0003@D7P0202P8?000`2h
>;@0oh000?n000020?n000050>QX?02P8?00X23`0:0Pl03@D7P0103oP0001@2h>;@0X23`0:0Pl02h
>;@0j6Pl00@0X23`00D0j6Pl0?n0003oP000j6Pl0;Ph]0090:0Pl0030=1@N02P8?000?l000<00?l0
2oooool000[ooooo05P0=YT702L2000I00005P4101P10@0E0@40300002000@110P<0C@4205H10P1J
0@@0I@4706X11P1c0PT0N`8:08012P250PX0QP@:08@;4P2UOh80bLoA0;[3a034bld0VjBW05QVHP24
T8X0[kRd0<oDe@3<`LP0[Gb709/`?02`4AL0]`l?0;H=402e3Q00]0/>0;P>4@2f3@l0^0hA0;mOH`3A
d=<0em_N0<kCeP0c=cX05@L:00l51P0A5AH0DF9Q09BUY@2obl/0e=gN0=?Lg`2d_/H0MW1j05@_>`11
31H09`4601/00P0K0@80:@8405<6301`10/0N`8907P21P1f0@D0NP4707d1201l0PT0N04807/11`1o
0PH0O@4307l21@220PH0Q04608P11`2<0@P0T08808`21`2?=CH0@B`]00<00@0200406`4104830`0n
0@004L412Oooool00`20`000oh000?n0000A0?n000050:0Pl03oP000oh000?n0003@D7P00P2P8?00
0`3@D7P0oh000=1@N0020:0Pl0P0oh0000D0d51h0?n0003oP000oh000=1@N0030?n00080X23`0`3o
P0000`3@D7P0X23`0:0Pl00H0?n00080d51h1@3oP0000`1@T7Soooooooooo`06ooooo`L00?l001T0
>Zl805HR3@1e?c`0Ja`M06L];@1B<CD0DCa305=1C01G@dd0ET9<05Y5C`1NBU<0KeeS07]XKP1jIFT0
PfMZ08ERH`27KfT0S7mh08InM`1lMW40MGI^07MkLP1bNg<0N89l0080MWmk03<0MhJ208BDUP2DYjd0
LhJ;07V;S@1nT940OI:E07N=T01kSi@0RinR09^][`2EY:P0Vi6D094Y<@2Z2Q80/`/C0:d8402U3A<0
[CQ109TN:`2K1Q80W@<;09/43@2C1Q40Na`/04leF`0F9V<0A3U_07TE;P1k41h0B2eF01<SH01ZFWP0
L1h^07X44@1n0PX0N`8:07@1201]0@H0H`@705LT9@1JHV00CVMU04eYI019If80>eML02e<D@17IUh0
A69L02m=B011GCl01000o`08ooooo`L00?l000D0J:Pl0?n0003XJ3`0oh000>QX?00G0:0Pl0030;Ph
]02P8?00X23`00H0X23`00@0d51h0:0Pl02P8?00^3Rd103oP0020;Ph]0@0oh0000H0d51h0:0Pl02P
8?00X23`0;Ph]03XJ3`30:0Pl0030;Ph]03XJ3`0oh0000@0oh0000<0d51h0:0Pl02P8?001P2P8?02
0;Ph]0@00?l02oooool000[ooooo00<0<iH602X50`0I0@400P0H0@40700E0P80404202410P110P<0
CP8205P1101N0@D0I@4506/11`1a0@P0NP<:08022P250`X0R`H;08T9402HGV@0b<[>0<S@dP3<d]@0
Z[Bc0;W3`03;d]80cLkB0;^MY`2MAU00WQXS0:dA5`2c3A420;<=400e0;8=3`2d3Q00/PdA0;L@4`2j
4AD0^4aB0<o8c03Eg=h0d]_J08NGU@1[NgT0NhZ809f]Z`2kb<L0cMSH0=;Lg@3Cg=h0XZjd02/mAP0=
5QX04Q<E020T9P0_>CT0=D4o038n>`0R:BT050P:03/52@1Z1@/0N@4807T2201j0PT0N@8707`22@1m
0PT0O`8807h1101m0@@0O@0307h110250@L0R04808/2202=0PL0R@@808`m?P0/7Ah00`4200H10@0Z
0`D0A0<404010@0B`P402Oooool00`20`000oh000?n0000A0?n000060:0Pl03oP000oh000?n0003@
D7P0j6Pl0P3oP0020;Ph]0030=1@N03oP000oh0000L0oh0000@0d51h0>QX?03oP000oh000P3@D7P0
0`2P8?00d51h0?n000030?n000050=1@N02h>;@0oh000?n0003XJ3`0103@D7PC0?n000030=1@N03X
J3`0oh0000@0oh0000<0D91hooooooooool01_ooool7003o001>02?C1P1M9A00J1dH07@]:P1W=cL0
CQ/N05Hg?01D@d`0ED9=05I3BP1PBU<0HDUA06eIG`1nJ6l0O6EY07i:DP1n;S00SFMS08QmN026OWH0
NgQ_07QhL01`N6h0LGUd07V1O01eP7`0Mh=k07n;R@1kRXX0P92?07>5QP1cQHL0Q96E08:EU`20U9@0
NHb?07N<S`2DZJX0W;2`08nQXP2RSi80UR8[0;<=5@2X3a@0^3]20:<D802Y2180X@<<09T33@2<5B80
IcQJ01h^IP15HiX0JUEk088F:P263ah0E3=J01hQH01M:Th0M`TI088330210``0O@4;07d22P1f0PP0
K`4606P2101D1P`0@CY304YWIP1;JFD0BFIQ04MTH@15I600AfAN04QSG00oFE00@U=71000o`08oooo
o`L00?l000L0D91h0?n0003oP000j6Pl0;Ph]03oP000^3Rd00T0X23`00<0d51h0:0Pl02P8?004`2P
8?00102h>;@0X23`0:0Pl03@D7P20?n000030;Ph]03XJ3`0oh000080oh0000L0j6Pl0:0Pl02P8?00
^3Rd0:0Pl02h>;@0j6Pl00<0X23`00<0d51h0?n0003oP0001P3oP00:0:0Pl0@00?l02oooool000[o
oooo05P0<9H403TF3`0D0@40504201L20P0?0@403P4102810@120@80D04305L00`1N0P<0I04406d1
1P1b0PP0N08907l32`240PX0R@@908X62`27;2l0/JZ[0<K=c`3<dMD0b/S=0<2^]`2ZP8T0VDUD09DF
802S3140[@/@0;0;402b3100/@`A0;4=4@2c3Pl0/PhA0;<=4`2f3A@0^@hE0:lI8P34Qi<0fM3H0=OL
h@3GgN00e=cL0=CMg03Bg=l0`m3F09FX/02J[[40d=cM09BTY01KKFd0N8V709RXY@2/^[T0]l?30;_7
a02ka/@0Z[Ve07V7QP0^;c40A0P;07L32@1g0@H0M@4807H1201k0@H0Q08708D21P210PD0P`8407h1
101m0@D0P@8808L120290PH0RP4808832@2BD5<05PH900400@0<0@40>P<504d210130P004/812Ooo
ool00`20`000oh000?n0000A0?n00080d51h0P3oP0020=1@N080X23`00<0j6Pl0?n0003oP0002@3o
P0000`3@D7P0X23`0=1@N0050?n000060>QX?03@D7P0d51h0?n0003@D7P0^3Rd0`3@D7P01P3XJ3`0
oh000>QX?03@D7P0^3Rd0=1@N140oh0000<0^3Rd0?n0003oP000103oP0000`1@T7Soooooooooo`06
ooooo`L00?l004l0:]T:05`N1P1M71D0Odm:05dN7`1H7R00ECXn05I3C@1D@4/0F4E;0619D01Q>dL0
K4==07ICF@1kHfP0Q5MM07PT902;HUd0Q7Ib08ElM`1gLf/0MWE^06idK@1^M6l0MG]g07^3P@1gPGd0
OH^907J6QP1lRh/0KX:106f1P`29VId0Sj6T08RJWP1dR8/0T:BW08FJW@2K[k<0WJnc0;70`P2aUId0
WBL_0;ll@P2Y6B@0[@TA0;094@2P1`l0QBHf03/fI`0XCXH0QjK709=bS02<52H0R@hJ05dgG`0`<6X0
J2=0084540240@T0QP4808832@1d1@`0J`/B06lC6P1_0`X0J@8505<<4`0V8SL0AVMY04YYI@1;If@0
B6IO04QWH016I5h0AV9K041NE`0]Ach04M4=00<00?l02?ooool7003o0007052@N03oP000oh000:0P
l03XJ3`0oh000;Ph]0090:0Pl0030?n0002P8?00X23`0140X23`00D0^3Rd0:0Pl03@D7P0X23`0>QX
?0040;Ph]0<0oh0000<0^3Rd0:0Pl02P8?000P2P8?001P2h>;@0j6Pl0:0Pl02P8?00^3Rd0>QX?0@0
oh0000<0j6Pl0=1@N03oP0000P3oP0090:0Pl0030>QX?01@T7P00?l000800?l02oooool000[ooooo
0480<i`403PK4@0B0@403`4101410P0<0@003`4102L20P130P<0D@4505P0101L0@80IP4506`11P1c
0PP0N0<:084430250P`0RP@<08X63@29>c`0[[2^0<SBdP2QUY`0SCI209XL8`2O4AD0YP`B0:P8402Z
2A00[`/?0;0;402a2a40/P/A0;D>4@2e3A00]`h@0;P>4P2i3A80^a0C0;PA5P2Y62@0Z45A0;AbPP2o
T9l0[H^G08R1R`1?GfX093Y304MNH@2`_l00emgO0<W@dP3Af]X0d][J0=?Kg@3AfM/0dMSK0<oHfP3?
emX0cmGH0<_DeP2f`Kl0H41007062`1d0PH207<11@0D07h31`290`P0R08508<21@250PP0PP4607h1
1P1o0@L0Q@0608X120290PP0N@X<07Q>D@0<0`@0104201810@110P@0B@420441000B`P49ooooo`03
0830003oP000oh000140oh000P3@D7P0103oP000d51h0;Ph]03@D7P?0?n000050;Ph]02P8?00X23`
0:0Pl02h>;@00P2P8?000`2h>;@0X23`0?n0000;0?n00080d51h403oP0000`2h>;@0oh000?n00004
0?n00003052@N?oooooooooo00Kooooo2000o`00CP1R8@L0HBPO07</:P1V<2`0FChn058oA01A?TL0
Dd1905U1C@1R?dT0HATT06HF7P1]<SL0Ic]1081NHP20EU@0QfYW08AeK`27OGL0NW9/07YhL@1aMW00
KgE`07AkMP1dNWL0MX5m07F2P01cPH40NXV807>4P`1/Oh00PiJH08RKW`29Vj00NXnD07R<TP2HZk00
V:Z`0<GIg`2[_L@0]lG:0;>1S@2]7BT0/`XD0;8:3`2X3Q40[3@h06I1H01=N:L0[l?I091PN@2@4R80
TA4M05hhG@0Z<Vl0LRI508H43`240@T0P`8:07`53P1^7BL0CRm602`/D`19>eT0H`PD06@83@1::CH0
4B4i045TI@18If40C6MU04YXH@18JF80AfIQ04ASG010Ge<0;4]101K950<00?l02?ooool8003o00<0
oh0000<0j6Pl0;Ph]02P8?00102P8?030=1@N080X23`00<0^3Rd0:0Pl02P8?004P2P8?001`3@D7P0
X23`0?n0002h>;@0j6Pl0:0Pl02h>;@00`3oP0000`2h>;@0X23`0:0Pl0020:0Pl0030;Ph]03XJ3`0
X23`0080X23`103oP0001P3@D7P0X23`0:0Pl02P8?00j6Pl0?n000X0X23`00<0d51h06RX?000o`00
0P00o`0;ooooo`002_ooool0=@0gW`L09@T100h00@0;00403`8100d10@0>00009`4104410P1>0P80
F04205`10`1S0@H0J`4507011`1f0PX0OP<;080120281P`0P`H:08YBD`2j`L40am3B08YoP@285AT0
YPX>0:L;3@2X2@d0[@TA0:/73P2b3A<0/0XA0;4<4@2`2Q00/0X?0;@=402i3Q40_0dB0;d@4`2k4180
/`lC0:l=502[3QL0Y18M08lM:P1741`04@XC01PW:P28UiL0`lo=0=?Kg@3Gfmh0emcN0080eMcM0P3C
fmd04@3Cf]d0d=[L0<kGfP3>e]T0b]?F0<WCe@2BQXH0I@P=07D3201b0@H0L`0708<32@290PL0Q@85
08011P1j10L0P`<80080OP4500`0Q`8608T11`270PL0Ma<F075FEP070`@0104101X20`160`<0BP82
04820@0B`P49ooooo`030830003oP000oh000140oh0000@0d51h0?n0003oP000d51h4`3oP0001P3@
D7P0X23`0=1@N03oP000d51h0:0Pl0h0oh0000<0d51h0?n0003oP0003P3oP0000`3@D7P0oh000?n0
00040?n00003052@N?oooooooooo00Kooooo2000o`00CP1a=0h0FadB06l`:01VBD<0DTA104m0A01?
?TH0F3e705dX=01V:340IATP05lR9`1ZBD/0J55B07QVIP20KFd0QW5`08MgL@29P7/0PW]c07MdJP1c
N740MG]g07IlN01gO7P0MWml071kN@1]O7X0KGmm07>5Q@1`P8<0PY:E08FFV`21U9P0TZNZ08NNY02Q
]kl0V:bc09ja^02lcM<0^;Bo0:@jC@2i3AT0]PXC0:/C5`2f>Sh0X1HO07XaBP1bPZ80RTaT094=7`2>
5R<0ESMP01DaL`1S>F40R0HF08/22`210PX0L1@N04laC00J9UL07S=Q04I0H01Q6bl0K`<=06D83P1@
72D0?Si504ITG`18IF00BFMS04QWH@1;JV@0BVQR04QVG@10Ge@09T@m02:Y8@<00?l02?ooool8003o
00<0oh001@2P8?00102h>;@0X23`0>QX?03@D7PF0:0Pl0030=1@N02h>;@0d51h0080^3Rd00@0j6Pl
0:0Pl02P8?00j6Pl0P3oP0000`2h>;@0j6Pl0:0Pl0020:0Pl0030;Ph]03XJ3`0X23`0080X23`00@0
j6Pl0?n0003oP000j6Pl102P8?00102h>;@0oh000?n0003@D7P90:0Pl0030=1@N01@T7P00?l00080
0?l02oooool000[ooooo05P0;iH401h20@0@00006@D501@20P0>0@403`4102H10P110P80B`420541
0@1J0@@0H`4506`21P1a0@L0N08;07d32P2110`0P`@:080:3P2@IfH0`lc=0<SCd`2DV9T0IA0D0:H=
4P2W2`h0Z@X>0:`9402^2100/@XA0;0:402a2`h0]0dA0;H?502h3a@0_0dC0;d=502m3Q<0^a4F0;0>
4`2/3a<0XQ@G07`?500f2@`0=cLj071nO@2^^kX0cmSH0=OMgP3Efmh0eM[M0=GKg@3EgMl0eM_N0=KK
gP3EgMl0dmcM0=?Kg@3Afm`0cmWJ0<cDf039d]D0YJ2S064<4P1d0`P0M08807P21P280`T0R@8708H1
1@250PL0K08407H320200@H0P@4508H21P260@L0PP<7084X:@19;2d00`4200@10@0L0P<0BP<504D1
0P0n0@004L412Oooool00`20`000oh000?n0000A0?n000040:0Pl03oP000oh000=1@N1D0oh000P3@
D7P00`3XJ3`0oh000?n0000=0?n000030=1@N03oP000oh0000d0oh000P3@D7P60?n00003052@N?oo
oooooooo00Kooooo2000o`00CP1DJ@H0Eb<A06Pk<P1R@C/0ETA3054l@01?;SH0EATS05`D6@1X=CX0
ICm406=6C`1UCUH0GTaD07YYK01oJVd0RG5d08ajN02;PGh0QX5j07mmM@1eN740MW]f07EjM`1fOGX0
LGak06ikNP1bOgl0LX9n06QkO01[Oh40PYJH08bPY028Vj00TZF[08VMX`28Vj80_]3F0:Ni_P2d_<@0
XEe[0:hB7P2j3AD0[AHL0;XoAP2X51l0Z0PA09da?`22:d00T`dJ08TP;`15>6T09Dj:08FD]01h52P0
T0<?08P43@1_8S00;RUB01@YG01@DG00L3M806d:601e0PX0L@4806d21P1T0PD0E1dM04]OF015IEh0
BfUQ04UXHP1=JFD0BfMT04UVHP14HEP0;DY302af;0<00?l02?ooool8003o00040=1@N03oP000j6Pl
0=1@N0<0X23`00@0d51h0?n0002h>;@0^3Rd5@2P8?000`2h>;@0X23`0:0Pl0020:0Pl00>0?n0003X
J3`0^3Rd0:0Pl03XJ3`0oh000>QX?02P8?00j6Pl0?n0003@D7P0X23`0>QX?03@D7P40:0Pl080oh00
00<0^3Rd0:0Pl02P8?000P2P8?000`3XJ3`0oh000?n000020?n000030>QX?02P8?00X23`00H0X23`
0P2h>;@3003o00_ooooo000:ooooo`1H02jD0@0U1@40:`l>05<j>P0>0@402@4100d1000Y0P40@`82
04`20`1B0@80F`4406D11@1/0PP0K04607D42@201P/0P`D<08D5301k2Q00Vgmm0<[Be038dm<0/[nn
03hJ7@2K41D0Y`P=0:L83P2/2Pl0/0X?0;0:3P2b2a00]@X>0;P=402f3140]`dB0;d?502n3Q@0`10F
0;H=4`2O3a@0K0lC03<82P0d;Rh0QY>A0<KAdP3Fg^00e]gO0=CMgP3DgMl0eM_N0=OKgP3CfMh0dm_N
0=KLh03DfMh0dmOL0<c@e@3;dmT0d=WN0=7Jg03?f=X0c=?F09J7R`1W2Q00M@8707@11P1l0@H0Q`87
08T2202:0PT0S0@908D4202410P0S0<:08T120290@H0Q`8807`62@28@D40@bP[00@10@070@808@42
04l410170P80>`4100o10@Wooooo00@0P<000?n0003oP000d51h403oP0000`2P8?00oh000?n00002
0>QX?180oh0000<0j6Pl0=1@N03oP0002`3oP0020=1@N0@0oh0000<0d51h0?n0003oP0003@3oP002
0=1@N0H0oh0000<0D91hooooooooool01_ooool8003o001>05Q]2@1K:1X0F1<?06Ll=P1C@T40DSLj
05DT;01I92T0GcXo06E=E@1WDEL0JU=L065<E@1D@T`0NVU^085[KP2:MGL0R7Yk08^4PP25Pgl0RXZ5
07UkM01cMg80JgMe06EeM@1[NGH0LGah06agM`1]P7d0IGYi06YnP`21UYP0OiBE08jSYP2?Yj/0//G<
08^MYP2DYjh0/L3509V1RP2J62H0]PlF0:@M8@2cBU80Y`lM0;<:4`2Y1a00Z2/d08/A7P1l;D@0<CI^
03UPV@2]c><0UhRI08P?7P2@0`d0NbDe02XUD@0b;U/0IC5:07<>7@1m0`h0N@4:07D2201`0@L0J`45
06@10P1C3aD0;ca404=TH@18If<0B6MT04UWH`19IV40B6IQ04ASF`0cCTP0;6`a0`00o`08ooooo`P0
0?l000@0d51h0?n0003oP000oh000P2P8?020=1@N0030;Ph]02P8?00X23`01H0X23`0P2h>;@02P3X
J3`0X23`0:0Pl03@D7P0X23`0;Ph]03oP000j6Pl0:0Pl03@D7P20?n000030=1@N02h>;@0^3Rd00@0
X23`00<0d51h0?n0002h>;@00`2P8?000`3@D7P0oh000?n000040?n000030>QX?02P8?00X23`00H0
X23`00<0^3Rd0=1@N000o`000P00o`0;ooooo`002_ooool0A@0aU`<0?1H@05lo?`1QCe402P4100T1
0@0>0@00:@8104@20`1=0@@0EP8505`21P1U0@H0K08906L21`1`10T0P0L=08@52`261@X0N@dC0:69
S03<d]@0am3C0<OBd`1?D540I`hB0:8<4@2/2Q00[@T?0:l:3@2b2Pd0]@/>0;P;3`2k3A40^@`@0;X=
402l3a40`0lE0;P@5P2A41D0?0T;04E6@`2=VYD0`/c:0=SNh03Gg^00e]gO0=GMg`3Fg^00eMgO0=KM
g`3Df]d0clkE0<2]^P2/RIL0UfAe08M2E01f>d/0ASQ508VGWP3?f]`0d=WK0;^j_`1^>3l0M`D;07P2
1`1n0`X0Q@<908X3200208T2200A08X32@2>10L0T0@909412P2C0`X0UPD;09<83P1l5AL0UfEX01<4
1@010@402@4202X20`1?0P80A@4103L0000>`0402Oooool01020`000oh000:0Pl02P8?0@0?n00005
0:0Pl03oP000oh000?n0003@D7P0403oP0020=1@N0030>QX?03oP000oh0000H0oh0000<0j6Pl0;Ph
]02P8?000`2P8?020=1@N080oh000P3@D7P?0?n000030:0Pl03oP000oh0000D0oh0000<0D91hoooo
ooooool01_ooool8003o001>04>B1P1I7Ph0FA4;06M1>01F?c/0CB/]04lP9`1J?4<0FDI<05m=E01V
DeP0K5EP06]CGP1VE5d0N6U^08=]K`26L7<0Q7Ee08AlN@28Q840SXj:08>6O`1bMW80B5]O03IAEP1P
Lg<0LGYg06akNP1VNWX0Igb104ITL`23VI`0U:NY09j`]`26V:80Vjbd0;c:dP2V^;l0^Kk708hkBP2W
3QP0XQl[06=7K@1nAV80Y`XG0:h73`2X2140W3E005hoHP0K=780HXZf0;WEi`30eN00WiVV07lF9@28
1Q00P3Y=06HX@`1f2ad0P@<?08<2301l0PX0LP8506/41P1/2Pd0K08606H2101A5b0072hn049TH017
IV40AfMP04YWH@19J5l0BVIO04IUF`0oGTl0?UA10`00o`08ooooo`P00?l000@0Z8Pl0?n0003oP000
oh000`3@D7PI0:0Pl080^3Rd00P0X23`0;Ph]03@D7P0d51h0;Ph]02P8?00oh000>QX?080X23`00@0
d51h0?n0003oP000d51h0P2P8?001P2h>;@0X23`0:0Pl02P8?00d51h0?n00080X23`00<0d51h0?n0
003oP0001P3oP0000`3@D7P0X23`0:0Pl0080:0Pl0<00?l02oooool000[ooooo05P0:Hl104h/9@1U
AdT08`lC00T10@080@40404102P10@150P80C@4205@0101J0@L0IP4706l1201d0P/0M`<<08<73`25
1P/0Q@L;07H;4@2SRXh0b];E0<OAd`38e=D0QI:?02l72@2B51X0ZP/A0:l:4P2c3A<0]0X?0;H93P2i
30l0^P/@0;X;3`2l3Q40_@dB0;8B6@234aX0;`@5059KFP2nb/T0fMoO0=_Nh@3Hg^40f=kP0=KKgP3F
g=l0eMcN0=CLgP3Gf=d0aK:k09QMK0289SH0SaPT08hA701f41X0;`L<01dS9P2DY:<0cm_K0<C8cP1j
FF80LA8I07/3201l0PP0PP<808H21`2;0`T0R08808P1202>10X0SPD:09@63@2E0`/0U@<:09l73`2J
3Q<0Y4e?07E9C@0@0@<01`8100T0000]0P80F@@404P20P0j0@407h@22Oooool00`20`000oh000:0P
l00A0?n000050:0Pl03oP000oh000?n0003@D7P03`3oP0000`3@D7P0oh000?n000080?n000@0X23`
103oP000103@D7P0oh000=1@N02P8?0?0?n000030:0Pl03@D7P0oh0000H0oh0000<0P<00oooooooo
ool01_ooool8003o001?04BU2@1D5@@0HRdS0696>`1D?SH0Cc/j054o@P1CA4`0ETU>05i=D`1YDed0
KeEP071HHP1XF5h0IUYO07i[K`1jH6D0Q7=d08AlN02;Qh@0Rh^708f>RP1mP7/0EFAS04eUI@1ZN7L0
KgYj06QfN01YNgl0?Ua^06F5TP1kTI@0R9fR08FIWP2odMP0TjB^0:Rj``2]_lH0Z9BN09/H9@2L6bD0
FciY02/kO`25@el0XPXF0:H74@2K2180ISAD02M>Q02E]mH0_=KT0;cDh02odn00^<7=0853D@271100
QP@>08H23@270@X0Q04:0842301b0`/0H1HO04X[=`1V;CH0J@<805h51`0n7S008C]=04ETHP17Heh0
CFQT04aVHP18Iel0AFAN04=RF`13GUH0@EM700cL2002003o00Sooooo2000o`001P20`000oh000?n0
003oP000j6Pl0;Ph]1X0X23`00T0^3Rd0:0Pl03oP000X23`0=1@N03XJ3`0X23`0=1@N03XJ3`00`2P
8?030?n000040:0Pl02h>;@0X23`0;Ph]0@0X23`1`3oP0000`3@D7P0^3Rd0=1@N0020?n000030;Ph
]02P8?00X23`00P0X23`00<0D91h003o0000o`002oooool000[ooooo05P0>H`405<`:00^5QL02`42
00D20P050@80304002P20P150P80C`4205<10`1F0@@0I04606d21`1c0PX0MP<;07l63`1m0`X0P0@;
07@73`2OQ8P0bm;E0<SBe038dmD0^<G302dZ:P1;2`d0Ua0D0:h:4@2`2Pl0/PT<0;L:3P2i30h0_0dB
0;/<402k3Q80Z18H05H;3`0]71`0JW9a0<;=c@3Hgn80fMkQ0=[Nh@3Ig^40f]oR0=ONh03Hg^40f=gP
0<_2a`2FHF/0UC0l09PC7P2H3A<0T0lE06/=4`0Z30h0@Te908nNW037dM80a=7E06=[L`126240L`XA
07/21`241@T0Q`<808`52@2;10P0S0<:08d32`2>10/0P`4508X2202E0`X0V0@;09h84@2F7200diFH
06m7B`0M0`H04@8201`20`120@80G@8304P10P0i0@007h<12Oooool00`2XR3`0oh000?n0000A0?n0
00040:0Pl03oP000oh000?n00080j6Pl3@3oP0000`3@D7P0j6Pl0?n000070?n000040>QX?02P8?00
^3Rd0=1@N0@0oh000P3@D7P0103oP000j6Pl0;Ph]03@D7P>0?n000030>QX?02P8?00^3Rd00L0oh00
00<0P<00ooooooooool01_ooool8003o001702c71P1F6`L0Fa/A05d[901J@Sh0CD100511AP1GATh0
G4UC06I;DP1`@4T0Kce4079LHP1/GF<0HUAJ07]VJ`1^E5L0NfY/08EnN`23Og/0PH1k08Z:R01hOG`0
LgYf08nHU@2@VIT0LWn006UjNP1IL7h08TQW06Z7S020UIL0Vk2c09>U[@2CYjl0Vjff08>FX@2kcM@0
YWf80:<F8P2MCUl0JdU]08@W@P2U:SP0XPXF09l84`2=3a/0@3AP07VS`P2oeMh0`MGM0<3Bg@2od]d0
/Kc807LeA@281100Q@4:08H12@220PP0N`D=06hK9P1;;D@0:2Q:04LY@`1T21@0HPX>050X=`0C63T0
=EQS04QVH`19IV800P1:J6<01P19J640AfEM04ISG@14H5P0?5Q601K84@800?l02?ooool8003o0005
052@N03oP000oh000?n0003@D7P04`2P8?020;Ph]0H0X23`00P0d51h0;Ph]02h>;@0^3Rd0:0Pl03X
J3`0X23`0=1@N0@0X23`0P3oP0001@3XJ3`0X23`0:0Pl03XJ3`0oh0000<0^3Rd00<0X23`0?n0003o
P0000`3oP0001P3@D7P0X23`0:0Pl02P8?00j6Pl0?n000`0X23`00<0J:Pl003o0000o`002oooool0
00[ooooo02X0DGh<03@C300H0`805`X:00@10@080P402`4002D10P160P<0C@4105800P1I0@D0I048
06d22@1a0@X0M`<;07`4301m10X0P0<;07P73@2@JFd0c=7D0<WBe03:dmH0bmCE08^ET`0C4A00DPX>
0:H<4@2a2Ph0/`X=0;H;3P2h2`h0^PdA0;D?4`2A4QD0?10A06mfM@2iaLD0d]_L0=WOhP3Hg^420=WO
hP0/0=KNh03Bf]d0`L[>0=?Kg@3FdmP0VeEO09/F7P2Q3A40U0lD05d;3`0Z1`T09bTV06j1N`2jal@0
cmWJ0<_Ef@2GYZh0DV=U02<T9P1520d0NP<:08D3202;10T0SPD808/3202:0PP0SP8708h32@240@H0
S@<709P42@2I1P/0V``A0:eGF@2ILWL0DRld03T=400P0P<0;@8305d41P1Y0P@0B`4203X0000OP`49
ooooo`030=1@N03oP000oh000140oh0000<0X23`0?n0003oP0000P3oP0000`2h>;@0oh000?n00009
0?n000030=1@N03oP000oh0000P0oh0000<0j6Pl0:0Pl03@D7P0103oP0000`3XJ3`0d51h0>QX?002
0?n00080^3Rd00<0d51h0?n0003oP000303oP0000`3@D7P0X23`0=1@N0070?n0000308300?oooooo
oooo00Kooooo2000o`00C`0Xe`X0FR<:05DK401V?3<0FD<m05A3A@1GAT`0GDE<06@i@`1Z;CH0NRle
080nA@1fGfL0LF9W06iQIP1cH6D0LUUN07]ZJ`1kLFl0N75^07MfKP26Qh40PXR609VUXP2`^l40WJ^a
09NTZ01XNWh09TEU04a^Q`1gS8l0Ujb^07J9S`2ba<T0UJRa09bc^`2DZk@0V:fc0;2GX02J72L0XQ`W
09@K9`2P?TL0Xbll09T84`2F1a40PBXn01`aIP2Xbml0`=GN0;gDg@2oe=d0_];J0;C3cP1b?Dd0Q@DC
08@2302010d0LQLS058_C00O:5@0:2eF05TR>01[1a80H@lF03`W?P075SX07ceE04UYJ01;JF@0AfMR
04MWH@1:JF@0BFQR04ATGP16I5d0@f5F03mJBP0SZ1d00P00o`08ooooo`P00?l000D0D91h0?n0003o
P000oh000>QX?0050:0Pl0030;Ph]02P8?00X23`00X0X23`103@D7P40:0Pl0030;Ph]02P8?00d51h
0080^3Rd00<0X23`0;Ph]02h>;@00`2h>;@01@3@D7P0X23`0?n0003oP000^3Rd0080X23`0`3oP000
0`3XJ3`0d51h0:0Pl0030?n000050=1@N02P8?00X23`0:0Pl02h>;@00P3XJ3`=0:0Pl003052@N000
o`000?l000_ooooo000:ooooo`0k05Yc3@0h5@h0604101<20P0700001@4000X1000Y0P<0A0010502
0P1D0040F@850642201Z0@H0K`8:07422`1f0`X0OP@:0884301o1Ph0ReEI0<K9c03<dMH0bmCG0<gD
e`32blX0Hfi[01X6202<3a@0[PT>0:h8302b2@d0]``?0:d@50233QH0;PL707F0N`3Bfm`0fN3S0=KN
h03Hgn40emoR0=ONh@3Fgn80b=KJ0:6a]@35cm40e]gP0;NKX`2C6R@0X0/A094B5@1720/04a4B04iO
G026VI@0a]CA0<kHf@3<e]P00P3<emX06`32clh0RiNE04HT9`1l1`h0Q`8808L11P280PH0RP<908L2
1@2<0`H0S`@809042P2C10X0U0D:09D6302B3Q80_7n108]XKP1VBdl06@8602P;300e0`D0G@@406`2
0`1B0P<0?`4101j20@09ooooo`030=1@N03oP000oh000140oh0000<0d51h0?n0003oP0000`3oP000
0`2P8?00oh000?n000070?n000030:0Pl03oP000oh0000H0oh0000<0X23`0?n0003oP0000P3@D7P4
0?n00080X23`1P3oP0000`2P8?00d51h0?n0000<0?n000<0X23`1`3oP0000`20`03oooooooooo`06
ooooo`P00?l004l05nh605dS1@1M=2@0H4Pl05a7@01LADL0HCm606<V;`1[7RH0Jb/b07Q1A`1hD5D0
Lf5Y071QJ01_HfL0MVU/07eYK@1nJf`0MfaZ07A^J@1kNgD0QXZ508F=S02mbLd0NX>906ikNP2GYJ/0
Aeac00lcGP1ZQi<0MHN<09>XZ`2O/[P0TZN^08jSZ`2V^/80a]WQ09bd`@2?Z;H0[9JL07EGM016Bg/0
HEQn08@D9@2=1`l0R0`G04hbG013JiT0_MOT0<?Fg`2oeMh0_=?L0;kCg02lcmT0K4UH07<84`1^5B80
F35=028[FP0S?fl0KhjZ06=AH`1Q2aD0GBDc02TVB00<9dh0<5EX04UYK01=JFD0BfQT04YZI01;JVH0
BFMS04EWH@14IV00@F=K04=RF010GDl0;hHV00800?l02?ooool8003o000502S8?03oP000oh000?n0
003@D7P00P2P8?000`2h>;@0d51h0:0Pl00=0:0Pl0040?n0002P8?00X23`0=1@N0@0X23`0P3@D7P2
0:0Pl0050=1@N03oP000X23`0:0Pl02h>;@00`2P8?000`3@D7P0oh000>QX?0020:0Pl0090=1@N03o
P000j6Pl0=1@N03oP000d51h0:0Pl03oP000d51h00D0X23`00<0oh000=1@N02P8?003P2P8?02003o
00_ooooo000:ooooo`1H059]3@1>:b@0604001810@0:0P401P4000T0000W0P80B`<405@20P1F0@40
F@440641101X0@H0I@8605P3201N10P0NP@<084430211@d0QcPn0;Re^P3;dmH0bmCG0<gCe`3>e]H0
][no03i2@`1?2`h0YPlC0:l:3`2b30l0Z`lD06H<4@0_5AT0KgIg0<_Ee@3Jh>80f=oQ0=ONh03Ggn40
fMoR0=CGg02W/[/0GgIn0;C4aP3Fg^00clK;09<nBP2F4aX0M0dA03T92P0b=c@0QIFB0;;0^`39eM<0
c]WI0<gFf@3=emT0cMKH0<gFf@3;eML0bM7C08]gN`1i2a<0Q`<908D21P260PL0R`<908/4202<1@L0
SP<809<42P2@0PP0SP8809052@2;7b40ZH220:21QP0^6b005PD;02@52@0h0@<0H@@406/30`1A0@40
?`4102630PWooooo00<0d51h0?n0003oP0004@3oP0020=1@N0D0oh0000<0d51h0?n0003oP0001@3o
P0000`3@D7P0oh000?n000050?n000060=1@N02P8?00j6Pl0?n0003XJ3`0X23`0`3oP0000`3@D7P0
^3Rd0=1@N0080?n000030;Ph]03oP000oh0000X0oh0000@0j6Pl0;Ph]02P8?00d51h1`3oP0000`20
`03oooooooooo`06ooooo`T00?l004h0JCH>05m2;01OBCT0I4E1064]<P1S7BD0KAdS06PW:P1`Be40
LeYR079RJ01gIfh0LV5W07ASJ01jIf`0Q5mU07]>D@1kJVH0NgMa08B3O`2<Sh/0OHN70:^j_P2CY:D0
UJ>T06j1S@0E;eh0;e=f06EnP`2_`/P0Kh>;09R[/@2AY:/0]<[A08JJXP2M/[X0/LOA09Ngc02S`=T0
6TB404UcZ`2@DfX0U@dJ098>5`1g;TH06C5W09_0e`31e^00`]KO0<3Eg@2ne=`0_M;M0<3BgP1dK7X0
E3Q901dUDP0>;F00=Uen07^M[01fTid0NXB;04m<GP0=8Td08T5S04U/M01<Kfd0CVaZ04]YI@1?JVL0
C6YU04m/J@1<JfD0AVMQ04MVG`15I5h0@V5I04=NE@0ePSD2003o00Sooooo2@00o`000`3oP000^3Rd
0=1@N0020;Ph]0<0d51h3P2P8?020=1@N0030;Ph]02P8?00X23`0080X23`00H0j6Pl0:0Pl02h>;@0
^3Rd0=1@N02P8?020=1@N0D0X23`00H0d51h0?n0002h>;@0X23`0;Ph]03@D7P30?n000030=1@N02P
8?00X23`01P0X23`0P00o`0;ooooo`002_ooool0F01IM0l0@AlH01/00@0C0P802@4100P20@070@40
9@8204X2101B0@80E04305`2101T0@D0J04906011@1G0`L0AP8507042`1o10X0PP@808LD6@2YSY80
bm?F0<_Ce@3<dmH0cMCG0<kEf02Y]K<091dL07L?502W2a40WPlE05493P1ADE00/[jl0=;If`3Ign40
f=kP0=WNh03Hgn40f=SM0;BCX01_C5/0=cTo0::a/@3Gg=l0bkk609Q?FP225Qh0>P`<030_;@1]OGT0
/l;10<oIfP3@fMX0dMSJ0<kGf@3=f=T0bmGF0<gFf03:dmL0c=GG0<WBe@2h/[D0MQPO08/52P270`L0
QP8608X3202910H0RP8509<42P2E10X0S`4908h2202?20d0]71_099jO@2VUYT06`X?01P31P0/0PH0
D0@806/41P1Z0`<0D0420441000RQ089ooooo`030=1@N03oP000oh000140oh0000<0j6Pl0;Ph]03o
P000103oP0020>QX?0@0oh0000<0^3Rd0=1@N03oP000103oP0002P3XJ3`0^3Rd0:0Pl03@D7P0j6Pl
0?n0003@D7P0X23`0>QX?03oP0020=1@N0030>QX?03oP000oh0000P0oh0000<0d51h0>QX?03oP000
2P3oP0000`3@D7P0X23`0:0Pl0080?n0000308300?oooooooooo00Kooooo2@00o`00CP1/DA00G48/
0655=`1T:2D0IaXN05lJ7`1Y=CP0Id]?06MFGP1]GFL0Lf=[07YVKP1iH6T0Ne5K07`oA@1o:Rh0P3Hf
07mZI`20NGL0PhF008bAR`2?UI80S9>F08>;T@1^NX00@eMb00<NFP1LNi80LXV>06n6R@2J[[40V:jd
09>V[`2CZ[40]/_B09R`^P2]aM40JXZ]05V9]P2=ZLD0VhRP09/K:`2I3AD0N2<f02`eI`1ZSk@0`=SP
0<;Fg033e]h0a=KN0<;Dg02odmd0_M7L0:job02J[[d0;e1k03QRQ01KPIH0NIb/07BBW@22W:<0GGN2
06>0SP1eTYL0Dg1`04e/JP1@KVh0C6YY04]XI@1>KFP0Cfe]04i/J@19If@0AVAO04ERGP16HUX0AF1E
04MHB@800?l02?ooool9003o00030>QX?02h>;@0oh0000<0oh0000<0d51h0:0Pl02P8?001P2P8?00
0`3@D7P0^3Rd0:0Pl00<0:0Pl0030=1@N02h>;@0X23`0080d51h00<0X23`0;Ph]02P8?000`2P8?00
0`2h>;@0oh000;Ph]0020:0Pl0030>QX?03oP000oh000080oh0000@0d51h0;Ph]03@D7P0d51h5`2P
8?02003o00_ooooo000:ooooo`12059^3@0L0P40604201820P090@402@8100T1000V0@<0B08405D2
1P1I0@@0G08406411@1Y0@P0L04;07422P1^0PT0N0<:07h2202710P0U@X@0993B`2eZk40bm;F0<_D
f03<eML0c=?G0<_De01dOG/0Da0C08DE6P1530h0HVQV0<[De03Gg]l0emcO0=SNh@3Ig^40fM_Q0<Ve
`@2IDF80FQ/T04Hn?`2R[Z`0emgN0<>X/@26=T80KAHO03@M7@1iQh<0//6o0<_Ge`3Af]`0d=WK0=;I
g03@e]T0c]KI0<kGf@3<e]P0bmGH0<[DeP3:dmL0a]3C0;J_]@1h5b40RP@:0P2:10T0502>1P/0T0H;
09<52`2F10/0T@8909<32`2B0`/0Qa`L0<ZY[02@O800I5EI02lJ7`0Q10X0=P<705@21@1b0PD0KP83
04h10P1000408H<12Oooool00`3@D7P0oh000?n0000B0?n000030;Ph]03@D7P0oh0000@0oh0000D0
d51h0?n0003oP000oh000=1@N0060?n000080;Ph]02P8?00d51h0=1@N03XJ3`0oh000;Ph]02P8?02
0>QX?080d51h303oP0020=1@N0X0oh0000D0j6Pl0=1@N02P8?00X23`0>QX?0070?n0000308300?oo
oooooooo00Kooooo2@00o`005@1JN@l0Gd4Y05hY7`1T5@h0HRTT06M7B@1TDeX0GU9I06AFG`1]GfX0
M5eW07Q:E@1m>TH0NB8[078N8026@Cl0LC`k07aYIP1hMG40PXAn08fBS00208nGT00i07UoN`1ZMgd0
5ReO01PkL01LN840WJn`07V<TP2K[kH0SZ6X0<?Dg02=XZ`0X;Fn09ffa@1mWk00^m?T059mZP2<V;L0
WSM80:HA7@1n9SX0<3QY04mhX02lfN@0`MSO0<?IgP32emh0`]CN0<7Dg@2kdm/0_M?K0;kBf`2id=T0
RJFi03=GM`1cUjT0EgZ709Fb_@29YZh0PI^T07ZBV@1QN7h0G7Ag05AbK`1@Kfh0D6iZ04]ZIP1<K6X0
BF]W04e/J@19IfD0AfAQ04MVH@18I5d0B6=H04UKCP08i`H00?l000Sooooo2@00o`020=1@N0<0oh00
202P8?00103@D7P0oh000=1@N03@D7P;0:0Pl0070=1@N02P8?00^3Rd0;Ph]03oP000X23`0;Ph]003
0:0Pl0050;Ph]02P8?00X23`0=1@N02h>;@00P2P8?001@3XJ3`0oh000?n0003oP000j6Pl00@0oh00
00<0j6Pl0:0Pl02P8?000`2P8?000`2h>;@0X23`0:0Pl00?0:0Pl00302S8?000o`3ooooo00[ooooo
000:ooooo`1H04]U3P0G0@00500101H4100700001P4000P1000Y0P<0B04305@1101L00D0H@880601
101W0@H0L08;07H2301j0P`0O@4:07h120280`T0W@T>08`E7P2]PXT0alW<0<SBe03;e=H0c=;E0<oE
e`2h_K`0ERLY02h51P18BTL0a<k<0=GLgP3Gg>00eMcN0=SNh03Je=d0]HfL09DhA`1e6240@cXf09n_
[03Cg=d0dlS@0994D@1W5al0:A8D08bIV03:e=H0dmcN0=7Kf`3?fm/0cm[K0=3If`3@f=`0c]KJ0<kF
f`3<em`0bMGF0<WCe@39dmL0a/oD0:6<U@1m3QX0R`@:08l52`2:0PT0R`<:08d32@2D1P`0T@<:08`3
202=0`P0R`H:09]<C@2JQH/0/:2V05iBF00]5aX09`D<03`3201Q1@T0N`@506h20P1?0@<0A0410262
0@Wooooo00<0d51h0?n0003oP0004P3oP0000`3@D7P0X23`0?n000040?n00080d51h00<0oh000=1@
N03oP000103oP0000`3@D7P0X23`0:0Pl0020=1@N080oh0000D0d51h0:0Pl03oP000oh000=1@N00>
0?n000030:0Pl03@D7P0oh0000T0oh000`3@D7P00`2P8?00oh000?n000060?n0000308300?oooooo
oooo00Kooooo2@00o`00<01<SPX0GcXP05/H3@1W9A`0JD]505i=CP1PEEX0Ge=L06QEH01_AU40LS8n
0852A`1k<cT0ND1507aKG021K6d0MV=T085eL`1nOGP0R8^408jAS02AV980SiRB07j4P`1AH7<00A]J
03=DMP2<XJH0MXR>08^MXP2BYjd0XkW208^NYP2V^Kl0Y;[10;W=eP2C[L40M9^m07><[`2MHG`0YQ`Z
08m1G@0X=W80EGjY0;gGi`36fN80`mSQ0<CHh080`]KP01h0`=GN0;_Eg@2he=/0^=?M0;KBg01nVZ`0
Dg>F04EZS01NPY@0KXbM06>0S025XJP0OYVM07R@U@1eS940G7Mf05AaK`1BL6`0BfUV04QYI@18J6<0
C6YY04YYI`19IV40AfEP04MVH017HU`0B5mC01O84P00o`08ooooo`T00?l000D0Z8Pl0=1@N03oP000
oh000;Ph]0070:0Pl0030=1@N02h>;@0X23`00`0X23`00<0^3Rd0:0Pl03@D7P00`2h>;@00`3@D7P0
^3Rd0=1@N0090:0Pl0@0oh0000@0j6Pl0?n0003oP000oh000P3XJ3`60:0Pl080d51h0P2h>;@=0:0P
l00306RX?000o`3ooooo00[ooooo000:ooooo`1H03mL2`0N0@40;P`=04HU9`0=0P401`4000X0000/
0P@0BP830581101K0@L0HP8806<11`1X0@L0L0<:07L32P1g0PT0NP8907l2202=0`X0W`P?09T;4`2B
=Sh0^jJ[0<_De`39eMD0b]GF0<gEe`2`_;l09bl_04QCD@2__KX0d][J0=GKgP3Dg=h0emgP0=?4c@2/
HW00W2@a08HH7`109BD0WJbW0=7Mf`3He]X0XVUd05hJ8@0l;Bl0RI>D0<[De@3Dg=h0dm_M0=7Kg03@
fm`0cmWK0=7Hg@3;c]H0/JFa09J1TP1aM880X:jb0<cEe`3;eMT0_kk80817D@262100R@<:08X12@2<
0PX0R`<:08/3202?10T0S`<808`31`281@P0O0l?0;R;S021L7L0[:>Y02XT;01[Gf<08`H:03l4201X
10P0P@<506l20`1@0@40AP4102:20@Wooooo00@0d51h0?n0003oP000j6Pl4P3oP0000`3@D7P0^3Rd
0?n000030?n00080j6Pl00<0d51h0>QX?03oP0000`3oP0000`3@D7P0X23`0:0Pl0020>QX?0070=1@
N03oP000j6Pl0:0Pl03XJ3`0d51h0;Ph]0070?n000050=1@N02h>;@0X23`0:0Pl03XJ3`00P3oP000
0`3@D7P0^3Rd0?n0000:0?n000030>QX?02P8?00^3Rd0080d51h1`3oP0000`20`03oooooooooo`06
ooooo`T00?l004H0@JH705h/3`1V:Qd0JBhU068f<@1TC4h0I5AH069:E@1/@e00LCa706`/=01gDEH0
OF5V07aYK`1mLGL0PWEi07]YJ`1nLg80OG]g08Z:Q`2>THh0SiJ@08bIT`20SI0093UV00TZK@1;KX00
P9FG08:GVP2Q]k`0Ign40:_0a`2U]kh0[l7908bT/02^b=D0^<oN09B]`02]RY/0WD9H06mBP00TAhL0
N9o60<;KiP34f>40a]WP0<KJh@36fN80amSR0<CGh030e]d0_mKN0;_Eg@2ie=l0^=?L08ZV^`1=M940
CG:=08JV]P1NOhl0U[>n082KYP1XPh/0N96H07VAU@1XPH@0FgMf05IbL@1?KF/0BVYX0P1:JFH0201:
JFL0BfUT04YWH`19Iel0AVAJ04IPD`0UZB000?l02?ooool9003o00030830003oP000oh000080oh00
1@2P8?000`2h>;@0X23`0:0Pl00>0:0Pl080^3Rd00D0d51h0:0Pl03XJ3`0^3Rd0=1@N0020:0Pl003
0;Ph]02P8?00X23`00@0X23`00<0j6Pl0?n0003oP0001`3oP0000`2h>;@0oh000:0Pl00F0:0Pl003
052@N000o`3ooooo00[ooooo000:ooooo`1H03aI2P126ah0HSDk05/e>P0A0@402@4100h10@0X0P<0
A@8305010`1L0PD0H08506D12@1Z0@T0L0@907<22@1f0@T0N08808412@2D1@h0VPH<09h73P2H3AD0
WEEM0<O8b`3:eMH0b=GE0;;3a`0/@dT0H7Ea0<3>b`3?fMX0d]SK0=CLgP3Hf=d0`Z6]09Xc@@2Q5al0
L0lB048X:02R/:`0eMkN0=C<d`2SJ7D0G1TP06ASH`2haLD0dMcL0=CNg`3Cg=h0e=gM0=7Kg03Aem/0
`K>m09iaP@2:?e40IaXX030@600]=CL0UJBS0<_EeP2W][h0@dA@05XB6@291@/0S0<;08`33@2;0P/0
R`@908T2202;0PL0SP<808d32@242@`0U51>0<Zf^@1`F5`0VI6G03<M9`0d72806P@703H20`1^1@T0
Q@<706h10P1?0@80@`4102210@Wooooo00@0d51h0>QX?02P8?00d51h4`3oP0001`2h>;@0j6Pl0?n0
003oP000j6Pl0;Ph]03@D7P01@3oP000102h>;@0X23`0>QX?03oP0020>QX?0050?n0003@D7P0X23`
0>QX?03@D7P01`3oP0001@2h>;@0X23`0:0Pl02h>;@0j6Pl0080d51h00@0oh000=1@N02P8?00j6Pl
2P3oP000103@D7P0j6Pl0:0Pl02P8?020=1@N0L0oh0000<0P<00ooooooooool01_ooool9003o001@
03Bl1`1O:100JC0Q06HN501Z?SD0IE1>06M1A@1U92d0J2H]06Q0AP1YDUH0Lf5V07UYK`1dIFd0Ng5g
085dN`1oKW80O6m`085kO024Q8@0SI:=08nFTP2CWIX0MhND00LPH@0;:6H0SZRb09V//028W:80QYfQ
0:o3a`2GZ[40[Kk50:k0b02kcmT0V;?409Nda02a_lH0/:Rb0724/009@Y/0Sl3T0<?Mi038fn<0b=[R
0<KHh032fn80aM_S0<GJhP32fN80`MKQ0<7Gh02meMl0_=?O0;[CgP2^a=L0:51e03MNP`1MPI/0L92N
07jMY`25XZX0Uk6j08NQZP1_RY00JXF805ikO01GLg<0DVe`04eYJ`1=JfT0BfYV04UXI01;Jf@0CVaW
04YWH018IUd0Af5I02fF:`00o`08ooooo`T00?l000D0J:Pl0?n0003oP000oh000=1@N0020:0Pl080
^3Rd4P2P8?020;Ph]0030=1@N03XJ3`0^3Rd00<0d51h0P2P8?020;Ph]080X23`00<0^3Rd0?n0003o
P000103oP0020>QX?0050=1@N03oP000d51h0:0Pl02h>;@01@2P8?000`2h>;@0X23`0;Ph]00?0:0P
l00307QH]000o`3ooooo00[ooooo000:ooooo`1H045L2P1[@TD0CR<[03<D6@0<0P401`4000d10@0/
0P<0BP8504l1101G0@<0G@850682201Y0@P0K`8707432@1c0PT0N@4708P32@2D10/0VPD;09l7302Q
2@l0U1PN0;2DU`38e=H0]LG;03aBF01ML700a=3=0<kGf03?fMX0d][M0<>_]`2LDV40VQhZ09`D701=
3A40C4U90:2][03Eg=`0`:J_09A0CP1]6b80JfIV0<KCd`3Egn00eMgO0=CMg`3BfM`0eMWO0<_0bP2O
JGP0Qb@`07/D7P1=2Q409QdM065bK`2T/k40bM?C0<?>d02;WJ80FfU]03lR90212@h0SP@;08/3302:
0``0RP<808`32P2:0@T0R`8908T32@29;Rh0eK^l08j0Q02APX@0QX>902@E7P0M1``0:0/>04L4201d
10P0PP8507420P1>0@80A`4202>10@Wooooo00@0d51h0:0Pl02P8?00j6Pl4`3oP0001P3XJ3`0^3Rd
0?n0003@D7P0^3Rd0=1@N0@0oh0000<0d51h0:0Pl02h>;@00P3oP0020=1@N0050?n0002h>;@0X23`
0>QX?03@D7P01P3oP000203@D7P0X23`0;Ph]03@D7P0oh000>QX?02h>;@0d51h0P3oP0000`2h>;@0
X23`0>QX?0090?n000050>QX?03oP000d51h0:0Pl02h>;@02@3oP0000`20`03oooooooooo`06oooo
o`T00?l005009MD7064X3@1W8QD0IR@J06i6@@1Y>Sd0J2<Z06d_=01YAdl0IUIM06MIH@1bH6T0NFU`
07]/L`1oLGP0OFaa08=^LP1lK6d0PGUh08F4P@2<THd0TINE09NOWP1?I8T01RIe02A8N01dSIL0NH^B
0;O;d@20UYl0W;>g09V]/`2ibm80Xk>m0;W=e`2<Z[/0R:^m0;[DhP1GSKl0EiS@02IS[02MbnT0a]oT
0<_Mi039f^40a]WQ0<SLh`39g>@0b=cT0<GKh`33f^80`m[Q0<;Hh030e^80_]GO0;_Ch@11Ji00M9ji
05R0W02F^<`0MIFW07ZFX`1nVJ80LhnE07jIW021Vil0JhJ:05ejO01BKg00CVi[04i[J01;JVH0Bf]V
04e[IP1>K6L0BFQS04AQF`14H5L0=H4d003o00Sooooo2@00o`00201@T7P0oh000?n0003oP000^3Rd
0:0Pl03XJ3`0^3Rd502P8?001`3XJ3`0X23`0;Ph]02h>;@0d51h0:0Pl03@D7P00P2P8?000`2h>;@0
X23`0:0Pl0020:0Pl0/0oh0000<0^3Rd0?n0002P8?00202P8?000`2h>;@0X23`0:0Pl00<0:0Pl003
003o0?oooooooooo00Wooooo000:ooooo`0N04]W3P1O>S/0:0L:01P00P090@40204100h0000]0@80
B@8304`10`1D0@40E`4305T01@1W0@L0K@4706l3201e0`T0N@4608h52P2J1P/0W@H<09d73@2O1@/0
X0dA09M>E02i`<H0AUUS02U0A02fa<@0c=GG0P3>e]T0>039^L@0SCA30:0D7P2P4QP0F@`?05EDE02Y
][H0d]_M0=34c02A>4P0SQhX05La<@2oblT0e=gO0=KNh03Eg=h0dm_N0=CEfP2jXK80T4II08/H9@1L
3a@07P4401/P801hRhL0^l[50<SCd`3:eMD0b=GE0<ODe@37dm@0S7an07/>502?1@/0R`<:08X32@29
0@P0S08808h22P2;0PT0PPD80:E]J`39`L<0JUQL0:6JVP1]JVl06`/@02/<4P1K>3/0C@@807L31`24
0@H0M08405000@140000;6<12Oooool20=1@N1H0oh0000@0X23`0?n0002P8?00X23`103oP0000`3@
D7P0X23`0?n000020?n000040=1@N03oP000oh000=1@N080X23`00<0d51h0?n0003oP000103oP003
0:0Pl080oh0000<0d51h0:0Pl03oP0001@3oP0000`2P8?00oh000?n000090?n000<0X23`0P3oP000
0`3@D7P0oh000?n000040?n000030=1@N?oooooooooo00Kooooo2@00o`00D00Qi0L0HbD606DS6@1_
?C<0K34^06DR8P1Y=CH0JU1E06MIHP1[H6X0Kf5[07=QJ@1mI6d0PEIQ07LhA01oEe`0OU]N07eXI`24
OG/0Q8>108R:R@2<Ti80TI^S01`fM0018GL0@VF:07nFW02EZK<0KXVB0:k6b`2=Y[00Tjbc0:_0a02n
dMH0a=CL0<kQjP2E`M/0NkSN07:Xe@2Zenl0/Mga09o@j@3Ai>/0dN7X0<kOiP34f^40bMoT0<cOi@38
g>@0amcU0<SLi036fn80`]SR0<7Fh`2oen80_MGV03MPV@16NZl0@Vj@08:T^025Wjd0Y/3;09V`^`25
X:P0PIbR06b7S01/R8`0HWj005QhM@1BLfl0D71/04a[J01?KFP0C6YV04e[I`1<JVD0A6AN04=SF@16
EdD00?l02?ooool9003o0007052@N03oP000oh000?n0003XJ3`0oh000=1@N00C0:0Pl080^3Rd00@0
X23`0=1@N02h>;@0^3Rd0P3XJ3`20?n000060;Ph]02P8?00X23`0=1@N02h>;@0X23`2P3oP0000`3@
D7P0X23`0:0Pl0070:0Pl0030;Ph]02P8?00X23`00h0X23`00<00?l0ooooooooool02Oooool000[o
oooo05P0Eg<F048P7`0N0@4070<200`10P060@402`4002`20`150@<0AP4204l10P1G0`D0G`8806T1
1`1Z0@H0K04507<22@1n0`L0U@L=09h63@2K1@d0W@L=09d7302O2@h0SAdU06aOIP0M<C@0R9VJ0<OC
e03;eML0cMSL0<2f`@2G@U40Wa@M09`@601W3180@cTk0;2j^P3Dfmd0dlcB0:9DHP2G7BP0DQDH09NG
UP3Fg]l0eMgP0=KNh03Eg=h0d/gD0:A^OP27;3/0MADR03l93`0V8B80CemP08bMW@30c<T0b]GE0<SC
e@36dmD0am;E0<OCe037d]@0_KZm074K8P2:1PX0Q`8708/4202:0PT0S@@:08l5202>1``0O14C0<6W
Z@2g/;H0GdU>0;6a/@2ATiH0;R<V01h73@0/3180C0@707L320260`T0M08405010@130@40=4@22Ooo
ool00`2P8?00j6Pl0?n0000E0?n000040>QX?02h>;@0d51h0;Ph]0<0oh0000<0^3Rd0:0Pl03XJ3`0
0P3oP0020>QX?0060?n0003XJ3`0X23`0=1@N03oP000j6Pl103oP000203XJ3`0X23`0:0Pl03@D7P0
oh000>QX?03@D7P0^3Rd1`3oP0000`3XJ3`0d51h0?n000070?n00080d51h00H0^3Rd0=1@N02h>;@0
d51h0?n0003XJ3`60?n000030=1@N?oooooooooo00Kooooo2P00o`00;P1W:PL0JSDY068S6P1]>Bl0
K4Y506MDEP1REel0HeMO06YMIP1eGVP0MTUC07HP;@2:9S80O0lJ08A>D`22IfP0P71`07igL`1kNgT0
Rhj?08VBTP1eR9/012A`008VN01jVkT0KHJ<09B//`2?Yk40VkFm09F^]P34f=h0e^?T0>;[kP38gNP0
c^Oc0<cUm03Jlo`0loko0=KXkP3CkOH0eNcg0=k[lP3Hj>d0e>GZ0<oQi`3@h^T20<_NiP0O0<SLiP34
fN@0aMWV0<?Ii034en<0`=KQ0;kEhP25Z<`0HI;107fWaP29[/L0Tjbn09J`_P2;YJl0TJZ`0:Bma01i
TYX0QIjU06n8R`1aSHh0Gg]k05UgL`1EM780DG1/04i[I`1=JfL0CfYW04aXH`18IU/0AUe>00SW1@08
ooooo`X00?l00`3oP0000`3XJ3`0d51h0:0Pl0050:0Pl0030;Ph]02P8?00j6Pl00`0X23`0`2h>;@0
103@D7P0oh000?n0003oP0030=1@N0050>QX?03oP000j6Pl0=1@N03XJ3`0203oP0000`3@D7P0^3Rd
0;Ph]0040:0Pl0030;Ph]02P8?00X23`00<0X23`00<0^3Rd0=1@N02P8?003@2P8?000`0Xb3cooooo
ooooo`09ooooo`002_ooool0>P1=JA008@8101h20P0D0@803`8200@10@050@009`<304X82`180`H0
CP4505l:401T0`P0J04506T1101X00@0LP8:08T52`2G1Pd0V0@;09L5302G10/0UP@:09P73@1a3AD0
?cPh09n^Z`37dM80b=;D0<C@eP1oTI/0Cce809@H7`294AL0@@P=04i8B`2d`L80e][M0<^b_@2QBUT0
YaXP08e5A`2HVIH0d=[K0=WOh@3Eg=h0fMgQ0<fja@2ABEX0IADP03L;3P0W8200GVe/0:Vh]`33c]40
c]OI0<kEf03<e=T30<WBeP0K0<SBe037d]@0aLO<070T:`271@/0Q@8708L31`2;1@X0TP/809HA3023
1@H0U5AD0<:m`P1JAdh0N6=V09BJW@18AD/0810G02063@0R0PL0DP@:07L320250`L0N@<305@10@12
0@00=4@300Wooooo00<0^3Rd0?n0003oP0005P3oP0001@3XJ3`0d51h0?n0003oP000j6Pl0080X23`
00T0j6Pl0?n0003oP000^3Rd0>QX?03oP000d51h0:0Pl03XJ3`00P3@D7P40?n000070=1@N02P8?00
d51h0?n0003XJ3`0^3Rd0=1@N0090?n000030>QX?03@D7P0oh0000H0oh000P3XJ3`0102P8?00^3Rd
0:0Pl03@D7P90?n000030=1@N?oooooooooo00Kooooo2P00o`00B01V@@h0G2DF06<Y6P1[DTH0JUaL
069EFP1QEE/0G51H06M?E`1^=T40ORli07`K8P29<3H0Qd9708=SI`22M7H0PWMg085lO01nOgh0Qhb;
08fFU`1;HXL00RB000TbP`1dU:X0/lC:09J[]`2W_<P0]/W@0=GRi`3/m?H0j^ob0?KinP3`moT0nOoo
0?Gmo`3>jO40a>C_0?SmoP3]m?H0hN_c0=[VkP3Gi^/0e^GZ0=;Rj@3=h>P0bMkV0<[Li@38f^H0a=SU
0<;Hi@31en@0`mKR0<7DhP2odn00P9k101M9PP1iY<00PZJk0:O1d02S^lT0TJjh08fW/P2:XZX0Rj2X
09R[/P2?Y:H0P9NJ06b7R01PNg/0FgQi05=bK`80DG1Z00D0DFiZ04m[H`1;J5d0Af5B01G74@08oooo
o`X00?l000@0j6Pl0?n0003oP000^3Rd1`2P8?000`3XJ3`0^3Rd0;Ph]00;0:0Pl0040>QX?02P8?00
X23`0>QX?0L0oh0000<0j6Pl0=1@N03oP0002@3oP0000`2h>;@0X23`0:0Pl00>0:0Pl0030;Ph]02P
8?00X23`00X0X23`00<0J:Plooooooooool02Oooool000[ooooo01@0=UH702020@0M0P80404100l2
0P040@40200002/210180P@0DP4305D10`1N0PL0H`8706D11P1X0PD0J04506l11P2<10/0T`<:09H5
2`80T`@:02L0U0@:08@:400g6Q/0YK6_0<_Ee@3;eMH0_/g@055YLP0lDeT0W9nP06<Z;P0h8B<0JgMg
0;_7b03Fe]`0/G^909`U<P2_51X0ZBX/0<B`/@3CgM`0fMoQ0=WOhP3Df=`0[iRT06lgA`0b3aL0@4E6
06j0O`2W^KH0am?B0=3GfP3?e]X0d=OK0<kGf@39e=L0bM?F0<[De@38d]D00P36d]<06@2`Zk00M1@P
08X430260PP0QP<;08T71`2I6A00P`<507LA4P2oZjX0VYBJ03/P9`2SVil0XZ^_04m0A@0R1`d0;0XA
02L4201A0PH0O@@;08H2201n0P@0FP4104H10@0fA0802Oooool00`3@D7P0oh000?n0000E0?n00080
j6Pl0P3oP0000`3XJ3`0X23`0:0Pl0020=1@N0060>QX?02P8?00j6Pl0>QX?02h>;@0X23`0`3XJ3`4
0?n000060:0Pl02h>;@0j6Pl0=1@N02P8?00j6Pl2`3oP0020=1@N0L0oh0000H0j6Pl0=1@N03@D7P0
X23`0;Ph]03@D7P90?n000030=1@N?oooooooooo00Kooooo2P00o`00C`1FJ0T0DQ`;06]:?01ZG5D0
JV1N06=FF@1WBE40GSDn06Y6C@1e>400N30f07PnA@2;EUh0RdQC07m7DP24Mg/0QWal08AoOP25QhH0
R92@096LWP1BJi000R^=01I7V@2Q^/d0]l380<;?eP3Dh>L0i>kb0>S_m03YlOD0inc`0?cno`3_mOT0
g>cf0<kSk03/n_h0h_Wo0=odo@3BjO40eN_f0=KUkP3Ah^/0b]oY0<SMi`36fnP0a]cW0<7HhP30f>@0
_mKR0;oFh@2oe>00`]CO0;oAg`2id=d0Sjg006VA]@1WT;40>fR907BIZ`22X:`0QZB]0:C0b`2?Z[D0
SZNa08bS[028W:40PYNL06j8R`1TP840GGYk05MdLP1JLg00F7Aa05AaKP1EKFX0DVYT04YUF00QYad0
2?ooool:003o00030=1@N03oP000d51h00H0X23`00<0^3Rd0:0Pl02h>;@03@2P8?000`3@D7P0j6Pl
0?n000070?n000030=1@N03oP000j6Pl0080j6Pl00L0d51h0?n0003oP000oh000>QX?02P8?00oh00
0080d51h00<0X23`0=1@N02P8?002@2P8?000`2h>;@0X23`0:0Pl00>0:0Pl003052@N?oooooooooo
00Wooooo000:ooooo`0l031A100P0@407`8101P10P0=00001@4100P0000]0P<0A@4204l20`1C0080
G@4705011@1D0PH0I04506L11@1`0@H0R`<808l21P2C1@T0S`880903202>1@X0FPP=061UI037d]80
b=;C0<WEf01bRY40C6M[0;C4``37dM80=ci108FEUP32d=40f=_N0;RAWP2N7BX0^1HL0;TC602cA4T0
b/C70=WRhP3Gh>40en3T09jY/P0_9c405a<F05Q[J@2/_;`0b=GF0=3Lg03Bf]`0d]SK0=7Gf`3@f=/0
c]SJ0<WFf036e=P0aM;G0P38dmD06P37d=@0SFii07d;5@2;10d0R`<:08D31`2I7Q<0Q@X507h52P28
@T00`L?2071PIP1^DUH0YJRY08F@TP0b:Rd07@P>02<5300c1@/0H@H:07X11@250PH0O`4306800@1>
0@40=T@22Oooool00`3@D7P0oh000?n0000E0?n000060=1@N03oP000oh000?n0003@D7P0X23`0P3o
P0020=1@N080oh000P2P8?020?n00080d51h0`3oP000103@D7P0X23`0?n0002P8?0>0?n000030:0P
l03oP000oh0000D0oh0000L0d51h0?n0003@D7P0X23`0=1@N02P8?00d51h00T0oh0000<0d51hoooo
ooooool01_ooool:003o001?05Ek2P1E:Q@0JE=306]NEP1_H5h0JDM:06XM901U4AT0M4]C079>E@1o
F5l0OSU408<V;`2<8R/0PBP`08aiO@2<QHL0RHN708fCT`2GW9h0XJBX08JG/@05>Y/06UN[0<SLj`3I
gnH0eMkW0>3Xk`3Hh>X0j_7e0>odmP3hoOh0f^;X0?Kjo@3amo/0g^gi0:S>jP1`/=h0VM3_0:kCjP2a
e>/0b]kW0<WMi@34g>@0`m[S0<GJi@31f><0`=OR0;kEh@30eN40`=?P0;oCg`2md]h0^m7M0;[Af`2M
^/X0<eV103QRQ`26[;h0QZVi07fMZP21WjX0Mi>O072<V02<Zk<0PYnW082JX@1_Qh`0IX24061mOP1F
MGH0EG=c05YeMP1LMg@0FgMb05UdK`1AJV<0CfYN02^E:P08ooooo`X00?l000<0d51h0?n0002P8?00
0P2P8?000`2h>;@0j6Pl0?n000050:0Pl0030;Ph]03@D7P0X23`00P0X23`00<0d51h0?n0003oP000
203oP0001P3XJ3`0^3Rd0:0Pl02P8?00^3Rd0:0Pl0<0oh0000@0j6Pl0=1@N03oP000d51h0P2h>;@3
0:0Pl0030;Ph]03@D7P0X23`00P0X23`00<0d51h0:0Pl02P8?002`2P8?000`1hF;Coooooooooo`09
ooooo`002_ooool0F00`C`808P8101`10@0E0@80304100H10@080@00:`8304H20`1@0@<0E`4305d2
1`1@0PL0C@4406411P1Y0@H0M@4808h32@2@0PH0T@<909012P2C1Pd0O`lD040O7`2Z][D0am7C0<SD
e02^`L80DFa^0;72`@3?fMT0b]GG08nQX`34dM40f=cP0<n]]`2X<3`0`1DK0<@B5`3451P0`E5E0=7<
c`3Kh^<0fn?S0<[Gg00dCED0B5iP092SX@31d]40d]gM0=COh03Egn00d]_M0=3Jf`3AfM`0d=OL0<_B
f02HYk80EVij07jCW039e]P0b]?G0:nV[`1k;c/0Q@L=08T42`2;0`X0S0d809TP4P211@H0L0X<0:j8
QP2n`L@0D38h09=oOP2SZj/0Xjna05=@E00I2@l0:a4H03<42P1K0`D0N@4508421@1n0P@0I`420581
0@0h@`89ooooo`030=1@N03oP000oh0001@0oh000P3XJ3`20?n000030>QX?02P8?00j6Pl0080oh00
00<0^3Rd0?n0003oP0000P2h>;@30?n000060=1@N03oP000oh000?n0003XJ3`0X23`0P3@D7P80?n0
00040>QX?03@D7P0X23`0:0Pl080oh0000<0X23`0;Ph]03oP0001P3oP0020>QX?0070=1@N02P8?00
d51h0=1@N02h>;@0oh000>QX?0070?n000030=1@N?oooooooooo00Kooooo2P00o`00C`0kX0D0FSTI
06EB@@1/ETl0M4m<06/Y:P1/4QD0JRPZ07U=EP1j?TT0P3e7084V<@22:Bl0RD=908iHGP2@M7/0WIRL
09VIW@2MWZ80[:f_0;bj_033amH07eJV025Y^`36g^d0g^K[0=[Tj`3Ah>L0en?Z0=OQjP3?gNP0b]cV
0<WLi@2^a=/0W;OD0:g;j@1m[mL0/M[f03Uh^@1UXM80ZlkS0<WLh`38f^80am[R0<KJi034fN@0`]ST
0<3Fh`31en<0_mKS0;oChP2me>40_=?Q0;[Bh02fdMh0]M3O086V_P0fH8l0G8FU041YPP1hUjD0RJJa
08JV/027YZh0QJ6Z06j9T01SPHH0IX:606V6Q`1ROh00DW5^055_K`1BL6l0F7Eb06B1O01SOG/0EVm[
051[H@0iQCP02?ooool:003o00030830003@D7P0X23`0080X23`00<0j6Pl0?n0003XJ3`00`2P8?00
0`2h>;@0d51h0:0Pl0050:0Pl0030;Ph]03XJ3`0^3Rd0080X23`00<0d51h0?n0003oP0000P3oP000
103XJ3`0d51h0=1@N03XJ3`20:0Pl0030;Ph]02P8?00X23`00<0^3Rd103oP0000`3XJ3`0X23`0:0P
l0060:0Pl0030;Ph]02P8?00X23`01H0X23`2oooool000[ooooo05P0;dd202820@0L0@405P4200h1
0P040P401`4102L30P150@80C`8405H10`1N0@H0H`8706021P1W0@H0J`4607d2202C0`X0T`8909L4
2`2I1@`0RP`?04092P21QH<0am;C0<WAe02Y[K<0UZFX0;[:b@3>fMP0dM[K0<oJg02ob/`0hm;I0=>8
V039=d@0hB4T0>XV8`3_;BX0kBlZ0>IRH03cj^/0j>g^0>W]kP3Pi^L0dM[K0>3Zj`3QjNX0hnWY0>;X
j03Oi^H0h>KW0=cQh`3GgN00f=ON0<F/^@1^Cf80:38m06f5RP2ib<X0c=GI0;6NZ`1m:c/0R`/E08`4
2P2:1@T0RP`50:H_6P231`D0MPT;09MPG@36`<40X9RL06A3A02]ZZT0VZZY0:6`/@0O8BH050X>01X7
300/0`L0H`@:07X11`1o0PH0MP4306<10P1C0@40>4822Oooool00`3@D7P0oh000?n0000D0?n00006
0=1@N03oP000oh000=1@N02P8?00j6Pl103oP0000`3XJ3`0X23`0:0Pl0040?n000030:0Pl03oP000
oh000080oh0000<0j6Pl0?n0003oP0001P3oP0002P3@D7P0^3Rd0:0Pl02h>;@0X23`0>QX?03oP000
^3Rd0:0Pl03XJ3`30?n000050=1@N03oP000oh000=1@N03oP0001P3@D7P90?n000030=1@N?oooooo
oooo00Kooooo2P00o`00C`16[0X0FcdI061:>01O:bD0M2XW06`Q8@1]=3L0IR`c070O:P1l6RD0NB`d
08A>E029EUh0RDeI09A@G@2GE5/0]JBX0:NX[02^/[H0^ko30;bna037b=80F7bf01EI/@32fN`0d]_S
0<cHhP2od=T0^<_D0;W>g02F[kd0[<G@0:C0c02[amX0VKO=0:k;gP1RT/40GYk?07jbf02=bN/0`^3_
0<[Oj`35gnh0`n?a0;SOl`2[fOD0WM?d08c9l`22__80Mk?/06nZiP1XXn40HYcL05nEeP1JSm40Eh[@
031W]@07>IL0?G>f05N7^01^U/80G8>[05R2XP1mXkT0KY6S08^[^P1mVZ@0H7f3069oP@1WPXH0E79a
04m/JP1>K6X0EG=_05QeLP1ZQXD0P9NF05QbJ`0mRT002?ooool:003o00040830003@D7P0d51h0>QX
?080oh000P2h>;@00`2P8?00d51h0;Ph]0070:0Pl0040=1@N03oP000d51h0=1@N080X23`00D0d51h
0?n0003XJ3`0d51h0>QX?0020:0Pl0030;Ph]02P8?00X23`00<0X23`00D0^3Rd0:0Pl02h>;@0^3Rd
0>QX?0020=1@N080^3Rd00<0d51h0;Ph]02P8?001P2P8?000`3@D7P0X23`0:0Pl00E0:0Pl0_ooooo
000:ooooo`1H04@n200P0P407@8101T20P0>0P40108000@0000V0P80@P4304h1101C0@<0G04605l1
1@1S0PH0K@8807<32@2710/0U@@909T42P2O1`/0XPT?07HB4`1EAdH0_<G50<WDe035^/40K41<0;>X
[@3Bfm`0d]cM0=GOh03GhN80hn;T0>6?VP3M>440mS8d0?hj=@3m@SP0oda10?iCA03fM6/0onSZ0?gn
o@3nooh0o_kn0?[ko@3^l_@0l_Cf0?3cl`3[k^l0jNg^0>K[j`3Ri^L0lMgX0=VEZ@2>?U40;QLQ08nS
Y033eML0d=SM0<g6d02E@E@0VP`J09/53`2D0`/0SPT50;A08@2E7@X0Q0@707`Y:03?_kh0_/C907YU
JP25K6`0TYZK09j`/@2X]KL09R0U05]:C00J1@X0<P/?05@11P1_0@@0N`4507<10P1Q0@40D@0003Y2
0@Wooooo00<0d51h0?n0003oP0004`3oP0001P2P8?00oh000?n0003@D7P0X23`0=1@N0D0oh000P2P
8?00103@D7P0oh000?n0003oP0020:0Pl0`0oh0000<0d51h0:0Pl02P8?000P3@D7P20?n000030=1@
N02P8?00oh0000<0oh0000@0X23`0=1@N03oP000d51h0P3oP0020=1@N0050:0Pl03@D7P0d51h0=1@
N02P8?00203oP0000`3@D7Soooooooooo`06ooooo`X00?l004l08]D5060n6P1B<b80DQhB064Q5P1X
=C40H2L/06@C6P1_7bD0LSDl08IPI`23A540RS0o08lM;@2[Ff@0S49:0;NTY`2e_L40^<350;Rj`@2i
];T0^Jf_07^6ZP0;?Y<0YlKP0:Zob@2jcMD0[l7<0:Fia02F[KL0/<K@0:[0c@2ic]H0`mSQ0<;Ol02R
a=D0f?3i0<odo02eiO<0V]k`0:?Tn`23e_X0El?g03^em`0PWNl058S^00f1lP07Mo403fCQ031>_`0m
AJd0@SbQ04PiW017<Y00@Bb703XSNP0e7g@0<R=j02`PN@0W8WL0821c01PRM00C8gH052ao014^O@0J
>hH08D9o02i@O010HGd0EWN:05alP@1@L6l0Cfe[04m^J@1EM780M9:@08VRY01HLW00BeQ;00Sooooo
2P00o`000`1@T7P0d51h0?n000020?n00080d51h00<0oh000=1@N02P8?001`2P8?001@3@D7P0oh00
0;Ph]02h>;@0d51h00@0X23`0180d51h0:0Pl02P8?00^3Rd0=1@N02P8?00j6Pl0=1@N02P8?00^3Rd
0=1@N03XJ3`0d51h0;Ph]02P8?00d51h0;Ph]03@D7PP0:0Pl0030;Ph]02P8?00^3Rd00_ooooo000:
ooooo`1H05T[400P0P40704101H10P0:0@40108000T1000Z0`80@P8204h10P1G0@<0G04506421`1[
0`T0LP4907L12P2?1@h0V@@:09l62P2T20d0XPdA06l_;`2TZ:P0bmCF0=7DeP2`LW/0R2Xf0<^a]P3H
gN00fN3S0=WRi@3Si^X0lkW20>a6D@3k=CX0oSLg0?i1?03lB440nde40?aEA`3dLVP0oNCT0?oooP3n
o_h0n__j0?Win`3cm?L0l_?f0>k`l`3_lO@0k>g`0?3/l03bamL0cG2708@[?01D<ST0Z[>e0=3MhP3E
gN80fm;N0;U[O02`6B<0/P/A0:h:402Q20X0[C0D0:P]4`2A2@D0Q`X<0:UiN035a//0`/?<05Lb>P2[
W9/0R9FG092RY026T9<071@H01T:3P0E0PD0<@h@04h2101]0P<0M`4307420`1K0@80D@4103]30PWo
oooo5@3oP0020=1@N080oh0000<0^3Rd0:0Pl03@D7P0103oP0001@3@D7P0X23`0:0Pl03@D7P0oh00
0080d51h00<0^3Rd0:0Pl03oP0002P3oP0001@2h>;@0X23`0:0Pl03@D7P0j6Pl0080oh0000<0d51h
0:0Pl03@D7P00`3oP0020=1@N080oh0000<0d51h0?n0003@D7P00P3@D7P0102P8?00d51h0:0Pl03X
J3`90?n000030=1@N?oooooooooo00Kooooo2P00o`00C`0Yf`X0HS<=04dQ401F;1T0JB`N05hD4P1/
8bL0IbHZ07Q5C@1bEEh0PfM_07LQ;@2E:S40QbD[09aXJ`2MPhL0[jJ[0:f//P2/[[40Zj^`0:JW[02C
UYP0N8VO00P_M024X;L0/lG;0;c?f02Y_LP0_=7J0<7HhP35gnl0_n?c08k=m02:d_@0P/_a07o?l`1M
_o<0<Z_a01fOj`0KVn<07Z7U01ZUk00EZoD03JSj00VQn`08UO/028[k00UkmP1DFL@0aBUI0<`M?P36
5SD0a1@`0;lE;@2/3240Y@dR09/:7`2=1Q`0TPTR08@<8P27;T@0LAdj07<<;P1^33D0IPhk05@=?`10
3dD0:@i;01XDE@0@6eh05RmZ02Y=MP12I7X0E7Ag05IdL`1UQHD0S:JZ059/K@13OT@02?ooool:003o
0003052@N03oP000oh0000<0oh0000<0j6Pl0;Ph]02P8?000`2P8?000`2h>;@0j6Pl0:0Pl00:0:0P
l0090=1@N03XJ3`0X23`0=1@N03XJ3`0X23`0;Ph]03@D7P0j6Pl0080d51h00<0X23`0;Ph]02h>;@0
0P2P8?020;Ph]0/0X23`103@D7P00`2h>;@0d51h0:0Pl00?0:0Pl0030;Ph]02P8?00^3Rd00_ooooo
000:ooooo`1H05HZ4@0M0@406`4101H20P060@400P4100P0000[0P80B04205010P1H0@@0H08706H1
1P1a0PX0N0<<08423@2K1Pl0X`H=0:P73`2/2@h0XaHI0:5oP03>e=H0dMOH0=:j_`1g:C40;PL<0;Jh
^P3Eg=l0fMkR0=SNhP3Zh>H0fDmI0?`];`3m;Rh0oC@`0?dn>@3oC4P0oTm90?iBB`3iOGD0oo;a0?kn
oP3mo_h0oOgn0?Win`3fmoT0l_Cf0>g_l@3gkOH0o=?Q0?2=W@3=A5D0KSM109bJW03Dg^00f>3T0>3K
i03F[;h0^e9W0<DJ9P374QL0`@hE0;X>4@30<Q80^S4B0:H;2@2P2@h0V3hl0<o7aP35b]40YY>L05XY
;@2d/kH0SYjS0:Zh_02QZZd050lC00l31`0E0`D0<@<505`31P1e0`H0N04406d10P1G0@40C`4103a2
0@Wooooo5@3oP0001`2P8?00oh000?n0003@D7P0^3Rd0?n0003@D7P0103oP0000`2P8?00d51h0?n0
00020?n000@0X23`203oP0001P3XJ3`0d51h0:0Pl02P8?00^3Rd0=1@N080oh0000@0j6Pl0:0Pl02P
8?00^3Rd1`3oP0002@3XJ3`0oh000?n0002h>;@0j6Pl0=1@N02P8?00j6Pl0;Ph]00:0?n000030=1@
N?oooooooooo00Kooooo2`00o`00CP1V:0L0GbTI060Q5P1S3`T0I0l>06Xc=01^@dL0KRDa07Xg@01n
GVH0PeEM08I=D@2JOh@0VY2F09jGW02WWJ<0YJ6V09jNY02HW:40U9^P08^GV@22UZ<053Yb092`bP2l
cml0]LoX09O1j@1f[>T0C9WY02^8j`0FOn/01h?d00F>n005TOD019Gf00bSn00T]?D0ClSg07gFn@1`
co@0@;Wf01jMm00?RNh027;V00YSg00BE=005Cnh05X`R`2d4Bh0/`TJ0:T55@2W2AL0T`lH090O;024
2a/0P@TD07HC701^2A@0Q3@o0:5nRP2dUJ80MA/Y07l43@1o0Pd0OP8=07`33P1g0a00L`DH06H89P1?
2cH0<AA;01HLF`0F<VL0?V5k06^:T01jUYT0CfYW03^D>`Sooooo2`00o`050?n000040=1@N02P8?00
^3Rd0;Ph]080X23`00<0^3Rd0:0Pl02P8?002P2P8?001@2h>;@0X23`0;Ph]02P8?00^3Rd00L0X23`
0P2h>;@20=1@N0030:0Pl03@D7P0X23`00L0X23`0P3XJ3`02P3oP000d51h0=1@N03oP000d51h0?n0
003@D7P0^3Rd0:0Pl02h>;@40?n000030>QX?03@D7P0^3Rd00T0X23`2oooool000[ooooo05P0CbD=
01d10@0L0@005P8200`20@070@402@0003<30`1D0@@0F08505h1101U0@H0L@<908@;4P2>41H0V0/A
0:d:3`2c20h0]@X=0;`=402e:bh0g<340=GFf03Fe]P0SX>303ll?P2JY:D0cMOK0=;Kg`3Ggn40emgP
0>?6c@3=<3L0jB0S0>dR8P3^92<0kbLV0?<];@3d;c40lbla0>U7C03jfml0kNoa0>W]k`3Xjnl0i^[]
0>CVjP3^hnX0ijfl0=aJL@3Q>4T0fDA:0=JXZ03AeMT0f^;V0=KKh@3Ga=80_fEg0;LS<P355b40b18G
0<4A502g40l0_C0A0<4l4`2a3P/0[PT>0:0Q8`3B/k<0algA0<W1bP1^>T@0ZXB50;c5aP2AY:H0Xk>f
08jHW00C2`l050D801D31@0W0P<0F@`?06h21P1f0@@0K08205d20P1?0@40>4812OoooolD0?n00004
0=1@N03XJ3`0oh000?n00080j6Pl00<0d51h0?n0003oP0000P3oP0000`3@D7P0^3Rd0?n000030?n0
00050>QX?03@D7P0d51h0:0Pl03XJ3`01@3oP0000`3XJ3`0^3Rd0:0Pl0020:0Pl0050=1@N03oP000
oh000?n0002h>;@00P2P8?000`3XJ3`0oh000?n000050?n00080j6Pl00D0oh000=1@N02h>;@0d51h
0?n000020=1@N0030;Ph]03oP000oh000080oh0000<0j6Pl0?n0003oP0000`3oP0000`3@D7Sooooo
ooooo`06ooooo`/00?l004h0K2X=06TS6@1W3``0Ha4<06hh=@1[CD/0GQdS07hQ:@1b82L0SWAn08Mj
P`27NH40SH>;08n8T@2CRY80TXZA096=U02BTIL0TYRM09JNY02AX:P0Pj2k01m=W00bIkl0=6k801iN
b007A<400dgC00AZl@05LoL01W[j00R3o008Q_T028Sg00R5mP08O^d047KT01a^gP0^J=L0@5g:04e@
^P1N@jL0KCN>07D]P@1m:WH0ObE/084SI`2775H0[Q0[0;<9602^2AH0W18N0=jU[@2hUJH0_9fY091X
L@2mYk80^jJ_07UJJ02aVjP0[jJd07mSK`2JLGD0REUL07Lh?P1g9Bd0K08907811P1g0PT0N@8;07X3
4@1]2B80AP`e020GCP0]Ch80LiV^05E^K00XZR<8ooooo`/00?l0103oP0000`3XJ3`0X23`0>QX?002
0=1@N2P0X23`00@0d51h0?n0003XJ3`0^3Rd0`2P8?000`2h>;@0X23`0:0Pl0030:0Pl0040;Ph]03@
D7P0d51h0=1@N0@0oh0000<0j6Pl0=1@N02P8?00102P8?000`1XZ3coooooooooo`09ooooo`002_oo
ool0F0198Pd0704102<20@0I0P403@4100P2000>0@40=@8305L1101L0@<0I@4506h2201k1@d0T18H
090=4P2M2Q00/0T=0;P:3P2k2`l0`@hC0;Pa=P3MaLT0dmGJ0<_Ae01BGUd0Y[Jf0<WDe@32c=80cmWK
0=;Lg@3Bf=/0aIRP0;XK8P3;4aL0ba8E0<XB5@3:51T0d1<H0=DF603I6A/0dBD/0>Rk`P3QiNT0hNCX
0=oSiP3ThnP0jLgI0<YcQ@35:CT0cQTS0<XG6`33C540c<W>0=;KgP3Ffn00a;Fn09e5F02]4b@0]0`F
0;@<502a2A80[0/<0:8K0@38FAl0WA040:L7302M3Q80]fi^0<c;d03:b]40RfIc064T:02bYjP0]lC9
0:Ne_@2X]k`0V:>V04He>P0X31007@8503441`1D1@X0KP8707810`1Z0@40G04104h10@0e@@09oooo
o`030=1@N03oP000oh000140oh0000H0d51h0?n0003oP000oh000:0Pl03@D7P50?n00080d51h1`3o
P0020=1@N0@0oh000`2P8?000`3@D7P0oh000=1@N0030?n000030=1@N02P8?00X23`00`0oh0000D0
X23`0=1@N03@D7P0d51h0:0Pl0020=1@N0030:0Pl03oP000oh0000L0oh0000<0d51hooooooooool0
1_ooool;003o001>05aJ3P1O40L0JB0H07Ln=`1]?3H0JdU506X_;P1j?Ch0NemR07a`M`1lLW/0Og=l
07ibO@21NX80RGn709B8S`2KUIX0VIfU096Q]01_S;40?fV^00i8Z`04>:h00BBQ00<j^`07CmP00d3?
00EBh006I_001V;V00]De@0EAl00;4Be03TmY`1C?j80L3fH08/gR`2P?hX0Xcj809e5S`2;DYH0LEZM
069PY`1<I[D0>fg002e^aP0UIl`0;Uk70:0dL`3H7R/0caDP0<4J:02Y<4<0VUEV0=2obP2TSi`0UfIm
0:5_PP2NU:80UgZ>08iSMP2FPi<0VHJD08YjQ`2;OXX0X7n>06@54@1Y0@@0JPX=08Hc>P1h1Pl0N0@<
07d4401i2B40BaI802PlNP1IMHH04m<A2?ooool;003o00060;Ph]03oP000oh000?n0003XJ3`0^3Rd
0P3@D7PY0:0Pl0030;Ph]03@D7P0X23`0080X23`00<0^3Rd0:0Pl02P8?002@2P8?00103XJ3`0oh00
0?n0003@D7P30?n000050=1@N02P8?00X23`0:0Pl01@T7P02oooool000[ooooo05P0B1l<01l10@0U
0P806P8200/10@080@403@0003H31@1M0@D0I`8506l3201n3Q@0Q@lD08D73@2:10d0WPL@0;493`2f
2`h0^0X?0;`=4P2/:2X0bkRj0<kEeP2mbLX0Y;>c0<7=c`35d]L0[kg30<kHf@3@fMX0d]CG0:9MI`2g
51X0_10C0;l@5@2o41H0`1<F0<TD5P3A61X0e1LL0<`S:03W^[l0hNKY0>?Vj03]g^<0hYFU0<a6E`3D
9S40eaXN0<lF6@3<61X0_TQ>0=;>d`3Bbm<0_YFR0:91D02Y4ah0Z0PB0:D73`2T1`d0XPH<0:0L1`3<
JBH0X2h;09D6202F2@h0RR`/0<ni^036c=80[i^U05/J8`2KKFh0][Zm0:Vf^`2HYjh0U:BZ0826S@0g
82T0?alV03LD6P0`0PD0F08507011P1a0@<0J@4205`20@1@0@40B@<22Oooool00`3XJ3`0oh000?n0
00080?n000030>QX?03oP000oh0000H0oh0000D0d51h0>QX?03oP000oh000>QX?0020?n000050=1@
N03oP000oh000?n0002P8?00203oP0020=1@N080oh0000@0j6Pl0;Ph]02P8?00^3Rd0`3oP0000`3@
D7P0oh000>QX?0020:0Pl0030=1@N03oP000oh0000L0oh0000@0d51h0>QX?03oP000^3Rd0P3@D7P0
203XJ3`0d51h0:0Pl02h>;@0X23`0;Ph]03@D7P0j6Pl203oP008ooooo`/00?l004h0GFd<05hK2P1a
=2H0I1P@07DW7P1gBd80NVMR07U]K`1`JW40L6U_07EZL`1dIW00MF]d081hO`2=QY00Ti2S07V7[00n
I:D054FP00@gX@03<j8013>[00Di]`03<KD013Ro00U?e`05@LT013>d02XcX`1M9Wh0Lb9Z07hXJP1l
=7L0Mcj3079<TP1QJ;40E8;:05:KfP1]]^00Pl_Z06c?mP0n_oP0:[Ok016Mn@08U?X01H?f00=`l007
Gmd0LC>40<TD:@333AX0]A8M0=NAU`36XK40VTm[0;YiS02QFFh0^W>209ijSP2gVZP0[8jI08eRM@2C
Kgd0/:>^08emRP2UQY@0K0TF07811@1P3A80Vfmh07d_?026@dd0ObPa084>602?31T0Gae=01ldHP0E
b1P8ooooo`/00?l000<0d51h0?n0003oP0000P3oP0000`2h>;@0X23`0:0Pl00M0:0Pl0060=1@N02P
8?00d51h0;Ph]03@D7P0^3Rd1`2P8?020>QX?080^3Rd302P8?000`3@D7P0oh000?n000020:0Pl004
0;Ph]03@D7P0j6Pl0>QX?080X23`00<0J:Plooooooooool02Oooool000[ooooo05P0B1`:01l10@0N
0@405P4201L20P0B0P404P4103T31@1V0PH0L0<707<21`2?4a`0S@`C07d32P2:1a00W0TA0:l;4`2/
2@h0Z@L<0:`:3P2M4AL0]8nF0<[Be036dm@0b<kC0:jT/01DFFH0Wjjc0<cGe`3Cf=/0cjnf0:@Y<@39
51L0e1LI0=XK7@3M7Qh0iBLU0?0]:@3`;2P0mCD_0>]=A@3lh>40m_Oi0?O/k`3VTYH0kU5<0?Q4?@3j
@CH0mSHZ0?4_903[:bD0hVY/0>g1c03<E6H0bR4^0<`F7P313QD0]@/B0:P7302U20X0W1450<IX7@2J
<PL0SPT608d42`236al0d:j_0<O;c@36b]40MDI@06<O8`2fYJL0/;o20:bl`02gb<`0Vjb^06MSJP0f
72P08Q@M07ERJ@101@X0K@@907T21P1d0@<0J04205/20@1>0@40A`<22Oooool;0?n000030>QX?03o
P000oh0000L0oh0000L0^3Rd0?n0003oP000j6Pl0;Ph]02P8?00d51h0080oh0000<0d51h0;Ph]03o
P0001`3oP000102h>;@0oh000?n0003oP0020:0Pl080d51h0`3oP0020;Ph]080X23`00<0j6Pl0?n0
003oP0000`3oP0002`2h>;@0oh000?n0003oP000j6Pl0=1@N03oP000j6Pl0;Ph]03oP000d51h0080
j6Pl00<0oh000;Ph]03@D7P00P3@D7P00`2P8?00oh000?n000060?n000Sooooo2`00o`00CP0nRP@0
KCPP06`P4`1h5@d0OblQ081MD01bIfH0MVmf06]TK@1YHFT0L6I_07AVL01fKGP0LgR>04aTU00J@8l0
1C6G008_X002<ZL00SF[00Hi[@07;Z005C>U01hLQP0d4VT0BAe^00`GN@026Gl0<bZ4050jS00jE:d0
9fk:01R5i@0JWoD06:Ci01BYn`0JYOP05IOe01J9k00DQn`027W/009ckP01LNd00FWZ005Ui`01H^H0
0EcP00=Ff@1I>iT0aaD_0=0A6P305b40jZbi0;b?W`3NSZ80/2Y00;4K<02g9CX0YQ`f0;M9G`2`DVX0
T2Tn0;A/O02bMHH0RdQK0<2JYP26=4<0N`89070N8@2]Uih0NE5K07mHI02WRYH0U69^09TlA`1f7dD0
52=L01>X6PSooooo2`00o`001@2XR3`0d51h0?n0003oP000j6Pl01h0X23`00<0^3Rd0=1@N02h>;@0
302P8?000`3oP000d51h0:0Pl00=0:0Pl0030;Ph]03oP000j6Pl00D0X23`00@0^3Rd0:0Pl02P8?00
J:Pl2oooool000[ooooo05P0AA/902810@0T0P807`4102420P0K0@805`420342101R0PD0K`860701
201d2`l0QRDY06h4301o1@`0TPL?0:0;502L1a00WPH<0:062`2S2100WbTe0;9/O@2cOXd0ZEMW07PS
<01<?4<0`lg?0=3Jg03OdML0]eIP0=@S9`3_9R80nRhX0?P/:03m=Bl0oT0h0?m;@@3nDdP0oUY:0?ah
K03oe]h0nmKS0?[>g03i[K@0nh9g0?i^G`3mHE40nUI60?Q`H`3fLF`0keeT0?19E03i<3<0nBLZ0?<U
9P3V7Qh0eaLK0<XB502k5@d0c64E0;A93P2N3@H0X0H<08l:3@2XL6l0c<c<0<C>d02l/[P0EA@N08mY
J@2o`l<0]<;609V[[P2CYjT0SJ2R07A_M`0U21@080XG03dZ=@1f=C`0MP<908421`1j0P<0J04205h2
0`1@0@80A`@22Oooool<0?n000030>QX?03oP000oh0000H0oh0000/0^3Rd0:0Pl02P8?00X23`0;Ph
]02P8?00j6Pl0?n0003XJ3`0X23`0>QX?0050?n000040>QX?03@D7P0X23`0:0Pl0@0d51h202P8?00
0`3@D7P0oh000?n000040?n000030=1@N03XJ3`0oh000080oh000100d51h0?n0003oP000d51h0>QX
?02P8?00oh000>QX?02h>;@0d51h0:0Pl02h>;@0oh000=1@N02h>;@0d51h1`3oP008ooooo`/00?l0
04h0>:d506hl701g=b40MbXF08iNC023LVT0L6UU075YKP1QF600HU]S06mXM01TIg`0=DQg00X/NP03
;Hl00R^D004ZV003;Yd01bnN01P/U`0a8Gd0Ba9D064DCP1J44X0@Pi@03@TN00?;j001CFf00M;d00:
I^P01g?`00EajP03JnP00fcY001Xj001Jn`006W[009`kP02M^l01Gka00Z4k`0AT?0049[c01>OmP0;
W?X01YKj00J@n`07P_P0C6CA0=TYC03Z82H0h1/T0=D]@@3DBV@0a2M30<PC8`323AP0_@/F0;`<5`2g
31L0/`/H0:44402J1Q<0UPHD09044P2:31d0Q@TG08@32P2ECE40RF1a09MZN02?Mh80/J6/0:bNZP2V
M8@0NR9601`QEP07b0d8ooooo`/00?l000D0J:Pl0;Ph]03@D7P0oh000;Ph]00]0:0Pl0030>QX?02h
>;@0X23`0080X23`00<0^3Rd0?n0003oP0000`3XJ3`0203oP000j6Pl0=1@N03XJ3`0d51h0>QX?03o
P000d51h202P8?000`1@T7Soooooooooo`09ooooo`002_ooool0F01460P08`4102H10@0X0@40:@83
02810P0J0@809`0105X31@1/0`D0JP4506LD5`1b=CX0I`@<07H11@2>1@`0TPD@08P5302H1P/0XPL<
0:P93`2a31D0[a8O0:lF802l51`0La0E0:>NX03?f=X0e=cN0>:ma@33=Sh0jBHV0?DU903k:RH0oBXV
0?/]:@3j<b`0mSPb0?M2>`3hAcl0kdi:0>=[M03PMX00hGR10>MXJP3_GU80l4m20?A<@03`JF00lJJW
0>bUZP3cQh/0lS<g0?//:`3i9bT0lR8Q0>HK6`3M6AX0e1/H0<Xl303SQQh0]1l70;H<3`2c2a80U1PH
0<ni]`35cm00a/k@09n2R@1Q6R40Sg]n0:6]/@2V]K/0[[g30;;3b@2HYZh0<2@_040Q9P0e4a`0;0HA
064:501o0PH0P`0507d2101^0P80H@4304`10P140`49ooooo``0oh0000<0X23`0?n0003oP0001`3o
P0001@2P8?00d51h0?n0003oP000X23`0080oh0000<0d51h0:0Pl03oP000203oP0070:0Pl0030?n0
002P8?00X23`00<0X23`1`3oP0000`2P8?00oh000?n000020?n000060=1@N03oP000oh000=1@N03o
P000X23`0P3@D7P20?n000030:0Pl03@D7P0oh0000X0oh002?ooool;003o001>02OF1P1^:`P0QE@h
08]YD@25LF80MfQP069ED`1WGV00LF]b05mSM00d@W802B9[00@RO@028hD00RJ>00@USP0>8880;1]a
05LHF@1_64h0HaU@03dQH`0I:8@02bfK00DWW@06=k001Snm00<a]002=;P00TS;009<c`02F=T00F;Q
009]k003N?800hGc01BKm@0j]OH0KM7e09CPn@2QjOh0R>;l057=nP0^_?T03Z;k00FDo003Qo`00g?f
021Pg02P:FP0caD[0<T?8P344B@0_0hR0;P<8@2d2al0/0XJ0:`9602Z21D0Z`LE0:P7502H0Pd0U@@=
08L11`250@L0PP4707l11`1l0`X0UDaD0;J9V01n:3d0UdiS0<NN[`2fWJd0^HVH08dM=@0gAR`00o43
2?ooool;003o0003052@N03oP000X23`0240X23`00H0^3Rd0:0Pl03@D7P0oh000;Ph]02P8?030;Ph
]0/0X23`0`3@D7P00`3XJ3`0oh000?n000060?n000030=1@N02P8?00X23`00H0X23`00<0:<Ploooo
ooooool02Oooool000[ooooo05P0AQP902P10@0^0@40<08202X10@0T0P407`4202H20P1@0`L0I`<6
06@11@1/4QP0MRD]06d32P1m0PX0Wa0I0:4>5@2F1``0Y@X?0:`:402e31@0_a4C0<HC4`3<5A<0dQlM
070S9@3:bld0dmWL0=OGg03<OHT0dRL[0>/T803f9280nbPU0?d]:P3m<Rh0oS/c0?i2>@3mC4<0oUE;
0?aVGP3jQXT0nZJ_0?bga03lWJ80oGic0?eZFP3jHED0nJ>O0>nh_@3YZJl0ljB]0>U1A`3j;Bh0mRHZ
0?8T8`3X7al0fA`E0<H^1P3NOAH0`DX;0;`@3`2k2Q@0]PlD0;EKFP3Bcm00am?C0<c?d01oB500SE5D
0:fYZP2/^kd0X:nc08JHWP2=X:H0TInU02dO:01072<0>A0I05DA6`1e1@h0Q`8908D11P1m0@<0LP44
06H20`1C0@80A@<22Oooool00`3XJ3`0oh000?n000080?n000030>QX?03@D7P0oh0000/0oh0000H0
j6Pl0?n0003oP000oh000:0Pl03@D7P70?n000040=1@N02P8?00X23`0:0Pl080d51h00H0^3Rd0:0P
l02P8?00X23`0=1@N03XJ3`30:0Pl080d51h103oP0000`2h>;@0j6Pl0?n000020?n000050>QX?03o
P000oh000?n0002h>;@00P3@D7P20>QX?0<0X23`00<0d51h0>QX?03oP0002@3oP008ooooo`/00?l0
03D05nd507H^1`23FCl0QFiJ07i^H01lK6@0LF1I06]OI@1<Cfd03b=R008HK0026WP00a]j00<@JP0B
5V/0=11D05h@@@1T5dH0AR5N01lVO00:;9<01cFU00@e[P05=k800AjJ004PW@05?/000BZ`00<f_005
FMh01G?a00N:nP09Uod02j7m00VVo`0D[o`0:K[i03Zjn00j[oH0:9_`01N=kP09QO<01H?f009glP02
K>`00FGY009SiP03FM/0153@02U0Z@1C;Gh0DBah04T/M`0204@XM@0G03lTLP128fd0AR9V04`PG`1E
75H0FaQ=06LIA`1Z5cX0Ha0/06497`1T1A80I0<906H21`1b10l0M`/K08@54@2C1QD0U10T0:Y>H@2a
EVX0PQD`01Bf3`00o`002?ooool;003o000302S8?03oP000X23`0200X23`00<0^3Rd0:0Pl02P8?00
0P2h>;@F0:0Pl0040;Ph]03@D7P0d51h0>QX?080oh0000D0j6Pl0=1@N03XJ3`0d51h0;Ph]0030:0P
l003052@N000o`3ooooo00[ooooo000:ooooo`1H04`I2P0^0@40=@8203@20P0Z0@80;08302@10P0M
0P80=@8505000P1I0@80I04507412@1n10`0T``F0:lG7P2`3Q<0/0X?0;@:402g2Q80_`dD0<PA4`3>
5180dA@C0;lL7P1dCE40eM_N0=?Hg03C`<H0/SHm0<XK7P3G6A`0hadN0>`M703`81l0lb4Q0?DV9@3^
8b<0lRTY0?4Y9`3b;Bh0kRdg0>X_?P3X;d80ib`l0>HW<03Y:2`0gbT/0>1nQ@3HX:`0b8^G0>>JY@2f
92d0baPL0<`D703<4AL0aa<B0<@h2`3QSAH0b6`A0;DG302l3a@0^0lD0:PY:03K`;h0c=;E0<W@d`2i
WZL0LQTP0:J9S02FXJT0]L?:0;c8c@2__l<0Z;Vn09:SZ00Y6200Ba<L02d53P102Q00LPH>08X22P2?
0`X0S0D807T20`1]0P80F`<204P30PWooooo00<0j6Pl0?n0003oP0005P3oP0001@3@D7P0oh000?n0
003XJ3`0^3Rd00X0oh0000<0j6Pl0;Ph]02P8?000`2P8?020=1@N0@0X23`00<0^3Rd0?n0003oP000
0P3oP0000`3XJ3`0X23`0;Ph]0030?n00080j6Pl0P3oP0001@3@D7P0j6Pl0;Ph]02P8?00d51h0080
j6Pl00@0d51h0;Ph]03@D7P0j6Pl2P3oP008ooooo``00?l004d0Ke/A081SA01dHT/0Lf=A07IUF01Z
GUX0<SUI00@GF`025fX00QEZ00@FJP0C45X0?0]105P==P1:44@09aQR00dWQ@05<9X00RnR008]XP01
89<001^=00@e[P02:Zd00S2k00QDgP03BMT01D_L00Q[m003No/01H3i009im`02N?L00W[g009jm@02
MO@00GOf005alP03Lo<00fg/009Vi`03H^<00UcM005He@02EM@00UG@009@bP03C<H00TRo00A3^004
?k@013n`00@o/P04>jl013VZ00@gZ@04<jD00c6O00@aV`05;IL01bbC00PYR@0;9h<042Em01TQK00K
4TL090X^04X<:`1T1b00P0HB08l43P2M2140WPPB09/>6P1/8TT054Le003o0008ooooo``00?l000<0
j6Pl0:0Pl02P8?00?`2P8?030;Ph]0080>QX?03oP000oh000?n0003@D7P0X23`0;Ph]000o`0;oooo
o`002_ooool0F01B7`/0=0<203<10P0i0P<0<@4202/3100J0@80304102T20`1A0P<0G04106/2101i
0`X0P`D=09<8402[3140[`P=0;483@2d2@l0^0TA0;d;4P313Q80``lB0;h@4`1]2`l0R8R;0<[Ff@3>
cmD0Ve9M0:4B602Y3A<0/`dB0<0>4@3F5QP0eA4D0=`E6P3J51H0hATJ0>DK703V6a/0iQlM0>@Q8@3V
92@0ib@W0>DS:03W92L0kBLY0>HT9P3E>D40i8>B0>66U`3:Ef@0^1LL0;PA502b2a00^0hB0:hM1`3B
QQ@0c8TH09DO102J0`T0V@@9098@4P2cNWP0bm3B0<K?e03=bLl0Od=<08Q1@`35a<@0ZKFj0;O2a`2a
_l@0UjN^09BU[@2FXjX0<QTP03X94@0/1@l0@@XC06h73P1i0@<0O`4408D21P1o0P@0LP4205`10@1=
0`49ooooo`030=1@N03oP000oh0001H0oh0000@0d51h0?n0003XJ3`0X23`3P3oP0020>QX?0<0oh00
00@0^3Rd0:0Pl02P8?00X23`1@3oP0000`2h>;@0X23`0?n000030?n000080=1@N03oP000oh000?n0
002h>;@0d51h0?n0003@D7P20>QX?0<0X23`00<0j6Pl0?n0003oP0002@3oP008ooooo``00?l004d0
IW/@07YO>01[Fd00JU]306aJB@0j?DX00aI;008FH@024fD0111L01X9AP1>2S00E`dd02L>B`0:6W<0
0bF;008ZU@01:iT00BbR008`Z001:j800BnU00=7aP06BM001D7?00MJh`07E^800C[<00=@g@02HNX0
0V?Z005Qj@00G^H00VCY005RiP01H><00EoO009Oh002H^800UkK009Lf002GMH00US?009DaP04E<H0
25K300MA^009Cj`034fT00i;W00ABID064jF01I;TP0FB8l054R=01A5R`0@@8P033^600PfQ@06=8L0
13:600@^Q`02:h/00R^?008XS0038Wl011a`00/IJ00S65P0D1@o07P;902M3AP0X`T=09H;6P1;9F80
4b99003o0008ooooo``00?l000<0d51h0:0Pl02P8?00A02P8?020?n000040=1@N02P8?00X23`003o
00_ooooo000:ooooo`1H05HQ300i0P40>P@403`3100`0P<0804201400@0:0@80;@<405X20`1U0P80
K0430781101j0@H0R@460:P83@2a2@h0/0T=0:d8302^20`0/0P=0;89402^2@l0WP`C03L?4P2]^[`0
bM?E0;fS[@2D6b@0Z`lC0;0?502g3Q<0aQ4E0=<E5`3G51H0h1TH0>HP7@3]8b40lbTS0?</9P3f>2h0
lT8e0?1;A03/CT`0kTe90?54?P3gACh0mClj0?0f=@3T=cl0hcQ30>0/<P3D71d0bQLJ0<<B5@2i3``0
`E@<0=BH4@2S@@H0V``809X32`2A10X0M1@G0<fh^@34cm40aLgA0;bZ/P1L5Ah0OeEK09RW[@2^_<00
`Lk@0<3>d02mbLh0TZ6U09JUZ01]JV`07`L>02<1301@4b00L0D=07L10`1c0080MP4407P20`1g0`@0
H@41058300Wooooo00<0d51h0?n0003oP0005P3oP000103@D7P0oh000=1@N03@D7P=0?n000<0X23`
00@0d51h0?n0003oP000d51h0P2P8?000`3@D7P0oh000?n000020?n000030=1@N02P8?00oh0000@0
oh0000D0d51h0?n0003oP000X23`0=1@N0020:0Pl0@0oh000`2P8?020?n000030=1@N03oP000oh00
00H0oh002?ooool<003o001=046i2@1lGC00K5Xn06aKA01>ADD01aDh00<HD`024UL02@eA02L7=P15
22L0>0`h01DBF@057GL00bJ900<ZU@01:9T00RbO004aY`03>[D014C100A7a@03D=<014[?00@e_P02
@<P014C=00<f``02A<d00USN009Ig002F=X00EOI009JfP02F]T00U[G00=Jd005F/T02E[4011M_00I
HKD09FZe031[Z@0hKYl0A76N04YdV01EOI/0EgnF05b3T`1SQIH0KHfJ07BCW`1dTYh0Li2L06n=U`1h
UJ40NiRU07RGXP1/RiX0GWjA05QiSP17J880@FB3035GOP0NAWH04SQa00T]L@02974012=d00dRK`0Y
7f80GQU1098?7`2J4bL0>B]_00UJ?@00o`002?ooool<003o000306RX?03@D7P0X23`03@0X23`0P2h
>;@00`3@D7P0X23`0:0Pl00<0:0Pl0050=1@N02h>;@0X23`0:0Pl000o`002oooool000[ooooo05P0
H2/>03`50P0d0`80<P@402020P0H0P80508100l10@0e1@H0H@<506@10P1Y0P<0L@8507T11P290`P0
YP/?0:l@502X3100Y@P:0:D72P2X1Pd0[0P?0:@83P1a2`l0A4520<G@dP3?`l/0VDME0:`C6@2h41<0
a1DH0<lG6@3M6ad0k2<S0?@Y9`3i<B/0o3T`0?e1>P3k@Sd0oTm60?mTF@3nQG`0o:VZ0?fka@3mZJ`0
oH>00?m_J`3oJF80oeQD0?mDE03nBT`0o4950?Pi?03_:bl0j2HV0=Dd403RUaL0d7lC0:/M1@2b2`d0
Z@D=09@;3`2[KFh0dLg?0<G@d@3<cM80PEaU05/=5P2?OX00SJ6T09f_/02M[K80Y[Nm0;K4c02R/KT0
VJF]05]CG00^31@0;04904H4301_10X0N`8607<10`1/0@<0H0<306l51`1U0@80E`D12OoooolH0?n0
00040=1@N03oP000d51h0:0Pl0T0oh0000<0j6Pl0=1@N03@D7P0102P8?000`2h>;@0X23`0:0Pl006
0:0Pl0050=1@N03oP000j6Pl0:0Pl02h>;@0103oP000202P8?00oh000?n0003oP000X23`0?n0002P
8?00^3Rd0`3@D7P01@3XJ3`0d51h0;Ph]02P8?00j6Pl00X0oh002?ooool<003o001=00_g0`1^OAh0
J4d^05iAA00<5S400QA600<DD`0B2d40?0PY03/8:@0D34800aIU00<RPP029h`00BJ>004/VP03<ZL0
0cZa00<l]P02@;`00dG400<m_@02@<400cZn004VZ@03;[<01TW;00A<b`03CL/00U3=00=BbP06E<80
2EBm019I^@0OHk00<V^Y04EdX`1GOi`0HXFH06b;UP1`S940MXnC07bCU023VIT0SJ6R096SY02J[Jh0
XKBc0:Nj^02]_l00/LG50;_=c02mc]00_<o@0;o?d@2hbL`0]lK90:Vk_P2I/;80RJ:V07ZDV@1/RHX0
IH6305ijO`1@L740AFEW03YLH@0]DU`08dIM01<hG`08;F/032aj03PZL01`8eH092ig00mK>000o`00
2?ooool<003o000302S8?03XJ3`0X23`02X0X23`00<0^3Rd0=1@N03@D7P00P3@D7P70?n00080d51h
4@2P8?000`00o`3oooooooooo`09ooooo`002_ooool0F01:CPL0@@L202h10@0Q0@404@4101<10@0O
0P<06@4102X30`1K20T0H0@508h^<`1b2@l0M08708D22P2R2a40Y`hC09l;402S2a00Y@H<0:P7302Z
2`l0S`hC03TA4@2MYZL0e<790:Y>F`2g6b40cQXK0=HL703Q8R40ib8R0?8T9@3j:2@0nR`U0?he;P3l
=Bl0nC<]0?/e<03j>cD0nT8k0?A2@03bATh0ldaI0?53C@3f?T<0mSDh0?Ld=`3b;300k2T/0>TW;P3Q
7bT0gB4Z0=XM8P3@:Q40hWdD0>2U5034@0X0c1XD0<PB503041@0/D920>38b@3;dm<0a]7B0<:b^P1U
6280K1dT092AV@2L[kH0]/K:0;K3b02]^l40X[:i09FV[P1WJgL0:`lL03`?6@141P`0G@D908XY;P1d
0PP0LP0206@20P1E2``0KaLH06440`1H2@49ooooo`030=1@N03oP000oh0000P0oh0000<0^3Rd0?n0
003oP0002@3oP0001@3XJ3`0d51h0>QX?02P8?00j6Pl00/0oh000P3XJ3`00`3@D7P0X23`0:0Pl002
0:0Pl0D0d51h00L0^3Rd0=1@N03XJ3`0oh000;Ph]02P8?00j6Pl00<0oh0000@0d51h0?n0003oP000
oh000P3@D7P0103XJ3`0X23`0;Ph]03oP0020>QX?0030;Ph]02P8?00X23`0080j6Pl0P3oP0000`3@
D7P0oh000?n000020?n000030>QX?03oP000oh0000Sooooo3@00o`00C00^c`/0HdDJ02XX:0025CL0
0aE201/>=@0m21d090P]00L?DP026VX00R9m008WR`02:9400R^F008`X@02<jP00C>Y008g[002>K00
0SVc008f[@02=Z`00cVe004WX`019j@01dFi00]>/P0JF:P0<fNS04acWP1LOiT0I8BE06Z6T@1`Rh`0
Ni2A07jBTP23V9H0TJBR09f^[@2a`/00^l[;0<SBe@3:dmP0aLgA0<C6bP2i^Kh0[Jje0:BUZP2MWJ00
TY>D08f<SP28QXT0Q82007mjN@1hMgD0N7Ac07=`K01/KVL0J6aV06=ZIP1IIf00EfAP05ARH@1<HEh0
B69L03mMF00kFU<0>UMA03MED@0`DU<08TAG00deJP0C=hD03S=i00Z]6000o`08ooooo`d00?l000<0
D91h0?n0003XJ3`08P2P8?040=1@N080oh0000<0j6Pl0=1@N03@D7P00`3@D7PI0:0Pl003052@N000
o`3ooooo00[ooooo000:ooooo`1H04Mo2@173080;04102@10@0V0P809`4103020P0T0@406`4204<2
0P1/0`H0OP@;07P22@1_0@H0QP@;0:4<4P2Z3a@0ZP`C0:P73P2[1Pd0/`/?0:h=4P1k1P/0W75d0=W?
d032Hfd0aahU0<dE5`3D61X0eAPK0=LG6@3P6AX0l1lN0?TW8@3k:R<0nRhW0?Y4@03i>c40o4@f0?Y8
>03hE480mfYH0?=cJ@3dN7<0mWE]0?]TF@3iD4@0oDe30?]7?`3i?c/0m3Dd0?0_;P3Z9RD0eS4@0>F2
6`3QZA<0dG4?0<4H2P313A00_``B0:`F6@3AXj40cm7C0<_Be03>dMH0W6Md07XA6@2PJF/0W:V`09>V
[@2K[k@0TJ>X09VZ/@2JZk<0XK:j09NIX@1J>480=@dG03/42`1[2@l0Q`T?0843201c0@<0G`830542
0`1L10@0F0D105HP0`Wooooo00<0Z8Pl0?n0003oP000503oP000103@D7P0oh000:0Pl03@D7P90?n0
00030=1@N03oP000d51h00<0d51h0`2P8?000`2h>;@0d51h0=1@N0030=1@N080oh0000@0j6Pl0:0P
l02P8?00^3Rd103oP0001`3@D7P0oh000?n0003oP000X23`0?n0003@D7P00P2h>;@01@3@D7P0X23`
0:0Pl02h>;@0d51h0080X23`00<0j6Pl0?n0003oP000203oP008ooooo`d00?l004`02oL307UE9@0D
6R000QDd01D99@0i2AX05@HS00@DE@027G800RAo00<VQ@029HT012RC004WT001:9H00RRI008/W@02
=:<00CBV00<gZP03>jh00cZY00PmX`0K@Y80=5>;04a^S`1TPY80KhR<07F;S@1gS8d0Ni6@08NLV@2D
Yj@0[;fi0;g;bP30bld0_lG90;Fi_`2/[;40X9ZQ08j8S@23NWP0OGA_07YaJ01kKV40NfaJ07]]F@1l
KEH0MVE<07=VBP1cJ4d0L6I<07EZD@1eJe@0Lf]E075XD@1aIdd0KVA:079VC01bJDl0L6I;071VC@1/
ID`0JV9606ERAP1LH4L0Dee704eKB`12ETX0>eE<03YHC@0ZBD@05Se@014j@`03lP<00?l02?ooool=
003o000302S8?03oP000d51h0080X23`00<0d51h0:0Pl02P8?00602P8?020=1@N0030>QX?03oP000
d51h0080d51h00<0^3Rd0:0Pl02P8?007@2P8?001@2h>;@0X23`0;Ph]00Xb3`00?l000_ooooo000:
ooooo`1H03>k2@123@40;@4102T10P0_0@40A0D304d7200`0P<05@4103H20`1/0`P0O04607`21`1d
0@L0R`H<0:H=4P2X2Q00ZPT@0:l:3P2c20h0^``B0:d83@2B51P0bYVM0<fLY02j7bX0c14G0<`A4P3G
5AL0gQPJ0>HJ7@3`81h0oBhS0?hg:P3o>bl0ncXa0?mDD03lCdH0of9D0?mcH@3oTh<0ol[50?oWk03o
k?H0on7U0?nXYP3oO7@0ofeP0?m[GP3oEdl0oTM40?m5@P3l>c40lFhM0>N/703U[Q/0dD<90=XJ603@
4aD0ca@H0;]2@`3Ld=00bm7D0<WAd`3Ab]00NbHb07P?5P2[SI<0YkO00;;2a`2mc<h0^<O70;2n`02F
YZh0NhjG061WM@0[5B@0C3Q104h[<P1R1Ph0T@H<08T31`1i0PD0F@8204l20`1A0@80D0T3041?0PWo
oooo00<0D91h0?n0003oP000503oP0030=1@N0X0oh001@2P8?001@3@D7P0oh000?n0003oP000d51h
00H0X23`00D0oh000=1@N02P8?00X23`0=1@N0030?n000030=1@N03oP000oh000080oh0000@0d51h
0?n0002P8?00d51h103oP0001P3@D7P0X23`0:0Pl02P8?00d51h0:0Pl0P0oh0000<0d51hoooooooo
ool01_ooool>003o001;05>J5`0M71@03@hO03475@0B1al00Q5300<MJ`018Gl00B:4008OP0028XH0
0R:=004RRP018hX00RB>008YU@02<9`00cJJ00/nU00UDY@0AFZB06=nT@1fRi40LHF607N:RP24UiL0
V:VY0:Zi^`2/_;l0Z;Fj0:B//02PXZD0RhR807]dL01eK680Mf]M07IZF@1iL5/0Ng9N07E]F01`Je<0
KF]B06]XC@1YIT/0JFE:06YVB@1ZITP0IF5206ER@`1SHD<0Hf5406=PA@1THd`0IVMB06MWEP1WJ5@0
IFE?06EXD@1TJ580HVA?05iPBP1MHDT0G5Xm05UG=P1HEC<0FUHd05QE>01CEcl0D5M404=E@`0eCSl0
:4Pi02AK;003l`800?l000Sooooo3P00o`001@2P8?00j6Pl0=1@N03XJ3`0^3Rd01D0X23`1P3@D7PV
0:0Pl0050;Ph]03oP000d51h02S8?000o`002oooool000[ooooo05P02_H305@P1P0a0P40<@8204@5
101K20L0E@L902h20P0>0@40;04306/41`200PL0P0@707@21@2>1@/0Y@P=0:/73@2Z1P`0Z`D;0;06
2@2f1PX0/@X>0:@c=@3X/[P0_TQA0=HL803K6a/0gA/K0>4K6`3Z81h0lR<O0?`[903n=BL0oSXZ0?`h
;P3i=2l0oTDo0?Hi=@3lAT40ne1;0?UHEP3fJ6l0mGF30?MkS@3dL7T0n5mT0?eBEP3kBDP0oDY50?i1
?P3m>cT0ncHe0>hm7P3_W2<0hK@I0=^B6@3?:0h0faXL0=HF6@3>71l0dhF70=7Be@3;dmD0bM7C0;nQ
Z@256280UdQ:0;:Z[`2KZk<0WZjf0:Bb^P2a_<00]lC60:Rg^`2`_l<0LW9j02X@6P0h8bl0@1hY05/6
30291@`0P@8507P51`1G20T0C0D604P20@1C40H0?U412Oooool00`0Xb3`0oh000?n0000C0?n00080
d51h00<0^3Rd0?n0003oP0002@3oP0000`3@D7P0j6Pl0=1@N0090:0Pl0050;Ph]03@D7P0d51h0=1@
N03XJ3`00`2P8?040?n000040>QX?03oP000oh000?n00080d51h00<0X23`0;Ph]02P8?000P2P8?03
0>QX?0030=1@N02P8?00j6Pl0080d51h203oP0000`3@D7Soooooooooo`06ooooo`l00?l004X0ACl?
02<=400K2AL00a8e00<LGP027WD00R5o008RQ00177h00QUm004KP`028HX00B>800<WQP08<H<09Tj9
04Q[R@1[QI40NHjB082BU@23UI@0UJNT0:>e]02T/kH0W:BW08R;RP1bL6d0JFAG06UVDP1^Ie<0Jf19
06QO?`1/ITH0JF1406aTB@1]JTh0KFe=07=`D`1/K4l0KFe@06aVB`1XHT40IfA506ERA@1XI4H0JFA8
06QTA@1UHd@0I6=506=PA@1RGD<0GEe105mN@P1VIDd0HVE<06=VC@1TIe40I6ME06AXEP1QIE80GV=@
05aPBP1IGD<0Ee/n05MJ?P1FFd80BE<o04QA?@0oBC<0@U<k03Q?>`0]B3<05KTA003o00Sooooo3`00
o`000`3XJ3`0oh000>QX?00B0:0Pl0050;Ph]03@D7P0j6Pl0=1@N02h>;@0:P2P8?001P2h>;@0X23`
0;Ph]02P8?00D91h003o00_ooooo000:ooooo`1H003o001>J0h0>PT203/40@1J2PL0H@X904H51P0Q
0@802@4101l10P1U1@X0PP<907T31@1Z0@<0Q`870:452@2X0`P0Z`@90:h5302c1Pd0_P/?0;PE603Z
PHT0aeAM0<HG6P3>5AL0cQDH0<hE6@3>4QP0fAHJ0>XL6P3j9Ql0oRhR0?d^8P3h9b<0hQdL0>L];P3G
7Ah0lc@b0?/h<03m?CD0oCdf0?Xk=@3n@S/0oClh0?`j<@3k;BT0o2l/0?db:P3m;bT0o2hW0?H`7`3V
KAL0fZX>0=2Q2P2mE`h0^Q@@0;l>5@2k3180ZB<T0=[2``38d]@0aM;B0<W?dP2JGFL0Pa`R0<2OX`2/
^Kl0`]7G0<gJg@2jaLP0^/K80;[4a`2[^;`0YK:e06iXK@0k5ad0<0D=04P43@1X1P`0O0@:07@21@1S
1`T0NTA703h4101I1`@0E0l102b>00Wooooo00<00?l00=1@N03oP0004`3oP0020:0Pl0`0oh0000<0
j6Pl0?n0003oP0000P3oP0000`3XJ3`0d51h0=1@N0070?n000050>QX?03@D7P0X23`0:0Pl03@D7P0
0`3oP0020>QX?0<0oh0000@0X23`0>QX?02P8?00^3Rd103oP0020>QX?0030:0Pl02h>;@0j6Pl00H0
oh0000D0d51h0?n0003oP000oh0008300008ooooo`l00?l004X0<k0903<G2@0:52@00Q]8008RK`03
97d00R:0008NP0027X<00Qeo004QPP0297h05CQl041OP`1[QI00Nhn@08FJUP28ViX0X;6_0:6]/@2H
X:80PhJ607=dL01bKF@0MFmQ07I`FP1eKUH0LFeE079aF01aKUL0M6mG075]E01aL5P0LFiI075_F@1_
KUH0KVmC06e_EP1[Je40IFA706QRA@1WHCh0I5lm061M?`1QGCh0He`o06EP@P1SHD40H60n061P@P1P
H4<0H5m0061P@@1QHDD0HF5:06=UCP1RHdd0HF==061VC`1NI4`0Ff=;05UQB@1KGdX0Eea605EJ@P1C
FD40CUe;0395>00[?bd0@4li04MC?00mCSP0:G<R003o00Sooooo3`00o`000`2@L7P0oh000;Ph]00?
0:0Pl0040=1@N02h>;@0d51h0;Ph]2d0X23`0P3XJ3`40:0Pl003003o0?oooooooooo00Wooooo000:
ooooo`1H003o0010O`P0?`L104h7101P30T0F0X803810@0L0040304001810@170@D0J`8406L20P1R
0@40O`030:852P2Z10T0/0H;0;<72P2h2Pd0^`X>0;hL8`31<c/0]Q<J0<0>4P2o3A80_`hE0;h>5@33
3QD0fAHI0>`M6`3j:2<0o2`R0?d[903j:bD0hRl]0>ETI`3871l0m2l_0?`d;03l>B`0o3P[0?/f:P3j
=R/0ncL^0?dg:`3l;RD0o34X0?`b9`3j:b80n2TL0>Tc3P3f[BX0f;8=0=JL5@2[:`<0/@P;0:d63P2P
1P`0X4=40<k=c`31c]40_lo@0<c?dP1m<3X0PS0f0:>LXP2;XJT0[<390<cMi03<f^40bmOL0=CMhP3;
f=`0]L7408IjOP1L<ST0@0H=06/:4`284QT0PP/A06d1101I0`D0EaDI06071`1X1P<0F18302nA00Wo
oooo00<00?l00=1@N03oP0004P3oP0000`3@D7P0X23`0?n0000<0?n000030:0Pl03oP000oh0000d0
oh000`2P8?040?n000030=1@N03oP000oh000080oh000P3@D7P30:0Pl0H0oh0000<0X23`0=1@N03o
P0002@3oP0000`20`03oooooooooo`06oooooa000?l004T0@dP>00TJ<P027e/00R=b008UO@039XD0
0R>4008QQ0038GP07Ceh05AaR021U9L0T9nO09:TX`2M[jd0UjBV08F>S@1`L6`0J6=K07akKP2DThH0
Z:RT0<K3``31_L40[jf`0:6QW`2>THX0RH]o08V9N`26QWD0PX=_07eoK01jNF`0MGUY06ieH`1^M680
KG=R06]cHP1YKe`0IF]G061UC@1NHDL0H69805mPA@1MGdD0G61505UPA01EG3h0FEe005ULA01LGT@0
Fea405]NB@1JGd`0Ff9@05iSC`1MHTT0Ff=:05aUC@1PIe80GF9<05]PBP1GG4L0D5E1059LB@11DdD0
;T@e03mC@01>Gdh0D69@051H@@0oB2X00?l000Sooooo4000o`000`3XJ3`0X23`0:0Pl00:0:0Pl004
0;Ph]03@D7P0^3Rd0;Ph]0<0X23`00@0^3Rd0=1@N03@D7P0^3Rd:@2P8?000`2h>;@0oh000;Ph]004
0:0Pl003003o0?oooooooooo00Wooooo000:ooooo`1H003o000dV@H0A@T105@<1`1A2@D0A0L502X0
000Q0@404`4100l20@0[0@80C`8505L20`1T0@D0P0450:852P2^1`/0[`T<0;0;302c2@`0]0T<0;4;
3`2_2Q40]@X?0;`=40303Q40`PhB0<XC503I6AP0jRDQ0>lZ8@3`<2H0kcH]0>`m<`3V?SH0gFIT0>2P
Y@36DU00e4a20=9>@`3>DdH0be=50<aFA`3<EdP0ae=40<YGAP37DD80b5130<Q<?P3<BCX0dDPf0<YI
;`3EZd40d;8d0=2A<02h=1D0_QlL0:@A4P2C4Q@0[g=d0<O>d@30cm80aM;E0<K1aP1]6200P3m40;>h
_02N/kT0`M;J0<CEg@2ocmH0b]KN0<[Ih`34e^00`loG08UeO`1F41T0GPL=06L42P2220h0Q`@906`1
0P1F0@80HPT;07X:1`1X2080EQD102^R0@Wooooo00<00?l00830003oP000803oP0000`2h>;@0X23`
0:0Pl00?0=1@N0030:0Pl03@D7P0oh0000<0oh0000@0j6Pl0?n0003oP000oh000P3XJ3`20=1@N003
0;Ph]03XJ3`0oh000080oh0000D0j6Pl0=1@N03oP000X23`0>QX?00:0?n0000306RX??oooooooooo
00Kooooo4000o`00B@0lQ`h03a`a008QH@04;8800BN200<]T0029X804C5d04]TO`20T9D0TZ2O09RU
Y@2CWj00PHV806Q]IP1WHe@0K6A<06mUBP1gLEH0M75K07QdI`1mNW@0Ui6D09ZCV@29Q8H0PGik07Yj
K`1jNV`0NGYY07EiI01aM6<0L7AT06ieI`1`NF/0LWa^07F3MP1_OW80I7Q^05meK01JKVL0D6MP04]R
E`1<GeD0CV5F04]OEP19GED0BEmF04IKC`18Fdl0B5Y@04QKC`16F4d0B5UD04]OF@1?HeX0EV=E05mU
E`1VK5`0HVeK06=^G@1WKUh0FfAA059LB01@FDH0BUY>03I<@00lE440D6AD05IWF@1IK640FfMD03]^
9P00o`002?ooool@003o00030:R8?02h>;@0X23`00T0X23`00<0^3Rd0:0Pl02P8?00<@2P8?000`2h
>;@0j6Pl0;Ph]0050:0Pl003003o0?oooooooooo00Wooooo000:ooooo`1H003o000XaPL0Ca@004H:
100c0P40;@4202/10@0Z0P808@8101810@0J0@00BQhO07Lo@P1V0`T0P@4609d62`2/3100]1<B0;@A
402e3Pl0^`h=0;d@3`3051@0a1/G0<HV7P31<2P0`3de0;e9?@33GE00_fiM0;MfI@2dOW00/8Mj0:j>
P@2ZThT0X9NA09VLV`2ETh`0UY6709>AR02>SXL0S8b308^<P`27RH00QXZ008F9O`23RH40PHIl0824
N@23Q7P0PX9b07inKP1jOVX0N7iS07ihG`27LV40QfQI07iNC`1jFTh0QGYf096JW@2KZ:/0YK6e0:>G
VP1j8B80WgAh0:bk`P2/`Ld0]LSD0<CFh03<fnH0d]kX0<kKi@3<g>D0c=GP0617E@1X3aH0Q1HG08H?
4P2U4AD0X0P;07h3101T0@40I@8307850`1V3`<0GAd101_<00Wooooo00<00?l0052@N03oP000203o
P0020>QX?0d0oh000`3@D7P00`2h>;@0X23`0:0Pl00I0:0Pl080d51h00L0X23`0;Ph]03@D7P0d51h
0;Ph]03oP000^3Rd00<0X23`0P3@D7P01@3oP000j6Pl0?n0003@D7P0X23`00/0oh0000<0D91hoooo
ooooool01_ooool@003o001902;F2P0Y9R400R5L00DkVP04=i/01SB802Y7L01WMgl0PHj:08FAS`1n
RXL0Jg9/06ASDP1_J4l0KVa@06i[D01_JDl0L6Q;075YB01]ID80Kf=307EXB01iJe00Og1G081cF`1n
ME`0NWAL07YcF`1cLEP0LG=K06icG`1WLFD0G6aU04]RG@0lEe@0<Di<039@C00aDTd0>UUD03QED@0]
BdL0:DI102Q3?@0U?cX093di020j=P0M>SH07C`h02@n>P0bA3/0>TTl03=6>00O>S@063Hb03QAAP1?
GTh0H6]M05iWF01OJ5P0H6UG069ZF@1HHU40Cem>04UKD00oETT0Bf5C05MZF`1MK680GVeR05][G`1O
Ie@0:ZTH003o0008oooooa000?l000<0D91h0=1@N02P8?00802P8?020=1@N0030:0Pl03@D7P0d51h
00D0d51h0P3oP000203XJ3`0d51h0>QX?03XJ3`0oh000>QX?03@D7P0^3Rd402P8?000`1hF;@00?l0
ooooo`0:ooooo`002_ooool02@00o`002oL405];1P0o2`40;08202`10P0c0@80;`4203020@020241
0P1=05P]<022B4d0K`H:08<31`2U3Q00`R8S0<<Z:02n:bL0]BXU0:db:@2O@cP0VU=909ISF@2?NVh0
SHZ009:DRP2GW9<0XJVO0:NcZ@2e`[T0]/2i0<37`@2na;l0];fh0;S4`@2ga<<0^L?00<37a@2laL@0
_<?50;k5aP2ob<L0^lK50;S2`@2d_kl0[KZj0:Ne]P2U][80V:RT09>SW`2;W9P0PiJD07Z>R@1eRh@0
LhN006n3N`1ZOGL0K7mi06]lMP1YNW<0IWQe06=fL01XLfT0LfYM071cL@1kRY40QiNP09R[]P2`aM40
^LoJ0;O<e`30dmd0_m;N0<GBg02<MGh0FalT0;>5R01h82H0Y0lC0:`=3P2D1PP0O@8306l20@1Y1@80
I1P306l_0P0Pd0402Oooool00`00o`00:<Pl0=1@N0080?n000030=1@N02h>;@0oh0000L0oh000P3@
D7P00`2h>;@0X23`0:0Pl0040:0Pl080d51h00<0oh000>QX?03@D7P00P3oP00>0=1@N1<0X23`00T0
d51h0:0Pl03XJ3`0^3Rd0=1@N02P8?00j6Pl0;Ph]03@D7P0203oP0000`1@T7Soooooooooo`06oooo
oa400?l004P0CgXM010VC@07AJ@023^?03=9IP1MHf40MGQe06acK`1PI5P0Hf9:079XB`1]I4D0KfM<
06eYD01ZITX0Kf]=06mYB@1bIdL0NF]<07QYAP1eId80MFI4075T@01cI4D0N6Y?07E[D`1[J5@0HfQF
06I/GP1MK680?e=?01/g=00`CdP0J8=k0:6d[P36dM00c=;D0;:e/P2AT8T0MGMY071`G01]JeL0KfQF
06]VD@1/Je@0JVYK06=VE`1PI5<0IFIB06ASD01QHTh0DUU504AC@P0eB3P0D5m?05mYG01LIE@0GfA@
061SCP1LHE40E5mC04]NE`1@I5d0GG5W06AeJ`1WMFd0I7A/069cJ@1PKF00HV9501SD2000o`08oooo
oa400?l000<0d51h0:0Pl02P8?006`2P8?000`2h>;@0j6Pl0=1@N0020=1@N0040>QX?03oP000d51h
0;Ph]0d0X23`00<0d51h0>QX?02h>;@03`2P8?000`1@T7P00?l0ooooo`0:ooooo`002_ooool2003o
001F04jc50144P00>0D303h40`130`@0=`4103X20P0Z0@408`41050?4`279BX0P@H;08d83P2`6a`0
/B/Z0:51@02CDD`0R65G081cJ01jOgH0N8=m07N9P@1gSXT0NiFB08:IU`2?XZ40Wjn^0:nn_P2eaL@0
a=7B0=7Lh03Jh^H0hNO/0>?ZlP3Mhn/0gn;[0=WLi03DeN00c/gI0<k?f@3>cmP0blcH0<O7e039b=D0
bl_F0<[;eP3?dML0emSK0=gNg`3Kg^40f=kQ0=7If@39d]80^/S60:2a[`2>X9h0P9BA07F;Q@1/PWd0
IGej061jM@1PNG80HgU`061dL01NLg00GW=^05e_KP1RLWP0LhJ>09^^^@30e^80Zl;?0:Noc@2JXZl0
?0lL09=SLP1Z41/0Y1LL0:hB4`2L1`L0R`<607/20P1]2040I20108541000o`09ooooo`800?l000<0
X23`0?n0003oP0001`3oP0000`3@D7P0oh000?n000020?n000/0X23`00<0d51h0?n0003oP000203o
P000103@D7P0X23`0=1@N03oP0050:0Pl0P0oh0000<0d51h0:0Pl02P8?004@2P8?000`3@D7P0X23`
0?n000080?n00003003o0?oooooooooo00Kooooo4@00o`00B00Bk0H0BCdd01Q1OP0`A5`0EUU@069T
EP1NH540HUi506]R?@1^ID<0LVM906YTAP1[JD/0KfY=06YUA`1`K4`0KfI406iR>`1ZI480KVI706mU
@`1aI440Kf<l079W@@1`ITH0K6E:06IWD`1LHeD0?4a501Tf<00nFeD0P9F?09BQWP2>U940S8V808n8
Q02FRX00QGMV07maEP1lKe40Kf9206mR?P1jJ400PVTo08A/@P22KT`0Of]=07][C01oKU00O71H079Z
D@1bJTl0KFQ<06AVC`1GH500HVEE069VD@1PIe<0GfQM05a]J01NLVl0HWQa06inN`1bPWl0KX1h0720
N`1/NgH0J7A]06IXF01]JRh04^d6003o00Sooooo4@00o`000`0Xb3`0d51h0:0Pl00I0:0Pl0040=1@
N03XJ3`0d51h0:0Pl080d51h2@2P8?000`2h>;@0d51h0:0Pl00G0:0Pl0030=1@N00Xb3`00?l000_o
oooo000:ooooo`<00?l005D0EC<904@70P1N30P0H0T704/20P180P<0>0<403831P1F1``0QQ0C07HA
4@1f92D0Ocdl07iKE@1gLV/0LGYb07>0N@1eQGl0MhV307N9Q01fRXH0OHn<082BT@20U980QiRG08NC
UP28TID0RI6C08N>S`1oQHH0Nh1n07j0P01dMgT0LWEf07AcL`1bLW<0LW9b07=aK@1fM6l0Mg9_07Id
L@1bLVh0N7Md07elN@1mNWL0Ogij07]jM@1mO7L0OWml08R6Q@2UY:@0_kc10<?4b02b]kX0X:6O09nN
V@2QXI/0Uj2I09>NVP2<ViT0Q9RF07Z@S01/QH00Hgeg065kM01MMW40GWIa05ieL01LLg40Igb308>G
XP2CZ;L0HfIe03T=601L5B80O10I0:@M7`2V3`l0WP`;08/410231P@0MP/206d^0P0b_@<00?l000Wo
oooo0`00o`000`3XJ3`0oh000?n000090?n000030=1@N02h>;@0X23`02<0X23`00@0^3Rd0=1@N03@
D7P0^3Rd0`3@D7P30:0Pl0030;Ph]02P8?00X23`00X0X23`0P3XJ3`00`3oP000j6Pl0?n000050?n0
00030:0Pl000o`3ooooo00Oooooo4P00o`00A@0hYa<0@C`b055>>P1MG4D0G5m005UI>01NEc00IEP[
06MN=01/HC/0KfI406eXC01/J4h0JF=206eWA@1`IT@0LfQ4079WA01eJDL0MFU:06eSA@1/I480KF@n
06MP?@1_J4T0DUM204YGC01/OGP0C69H06]dJ@1dLfD0MgAS07QdH01_LUh0TYN909RJS01lOFl0I6eT
04QIE@0^ACd0;dHd05EK?`1hKD`0M6M607EaF01TJeP0F6AD05MTE`1JJ5/0EfAF05mRCP1fLU/0LVmJ
06a^GP1UKE`0JgY_07>4O@1hRXP0N8b;08>EU01oU940P96@07jAS@1hSXT0M8J506ejMP1TJ5T0Jf`c
01[S2002003o00Sooooo4P00o`000`1hF;@0X23`0;Ph]0030:0Pl0040;Ph]03@D7P0d51h0;Ph]0l0
X23`00<0^3Rd0=1@N02h>;@02`2P8?000`3@D7P0j6Pl0:0Pl00I0:0Pl0040=1@N00Xb3`00?l0003o
00_ooooo000:ooooo`<00?l005<0A5h604l<0`1`4P`0LA4<068:1`1O2@P0B`P703@71`0j5140F3L`
065LD`1QJf<0IWIa06n0O01dQh00N8Z707V9Q`1gQX00Mh5j07=iL`1cMFh0LG5U06m_H@1`L600LW9Q
07QdIP1kMfL0Og]W07agI01gMV80M7IQ07=fI01fMfH0MgEQ07AbG`1dM6<0MGIU07IeH`1fN6D0NgYZ
07akJP1hNfH0N7YY07IkK01gOFh0Oh5c08B6N025RG`0T9>;09RKV02PY:L0ZZV`0:>TZP22QhH0Mga^
07IgIP1jNFD0O7YW081hJ020N6X0OgU]08N2M@2@Sh<0SY6508bCR@26U8h0NXj:06j6P@1RNgL0GgMf
05ieM@1EJf/0DeeL04Tm>@1D8RH0Ma4F094D5P2]>SX0WQHE08l91P2=30L0NA0305=A0P02003o00Wo
oooo0`00o`000`3@D7P0oh000?n000060?n000030=1@N02h>;@0X23`03d0X23`0P3@D7P20?n00003
0>QX?03oP000oh000080oh0000<0d51h003o0000o`002?oooolB003o0014036^1@1H@Qh0HeLi069L
?P15BRh0Be<g05MD;P1UEbH0JETY06MH9`1/G300L6<k075ZA`1]J4D0KVQ8071ZC01`JDX0KF8o06eN
=@1^H3D0MFDl07AR>@1aHS@0LVDg07IYA@1JFCd0O7aZ07MeJ01ZKEX0LgES07UeHP1UK5h0AEM?049F
C011DDP0=d]403E8A@0/@T40:4=003MAA`1HJE/0L71I07I_E01hOF/0MH=i06AjL@1KL6H0GVaS05MU
F01PJEP0MGIQ07YlJP23RGd0RiN?09RVXP2N[Jd0Xk2a09^YZP2AX:40TZ6Q08nPW`2@X:40R9RH07j?
S01dPG/0KFeO07E`=00aeA03003o00Sooooo4P00o`000`1XZ3`0d51h0:0Pl0030:0Pl0050;Ph]03o
P000oh000?n0003@D7P0202P8?030;Ph]080j6Pl202P8?001@2h>;@0d51h0=1@N03@D7P0X23`00<0
d51h3@2P8?001@2h>;@0d51h0;Ph]03@D7P0^3Rd00P0X23`00<0d51h06RX?000o`000P00o`0;oooo
o`002_ooool3003o001C04J2201F4@<0KQ<;06/A2P1N30P0B`d604PV7@15@3T0C5UA05AXG`1QLf`0
J7Ye06^0N`1/P7/0J7I`06MbI`1YL5l0Kg1K07=`FP1iMF00O7IP07efH@1lN640NgYQ07UgH@1kMV80
NgEQ07YcG`1jMF40MgEP07IgH01fMUl0MgEN07IdG`1fLel0N7ER07MfHP1hNF@0M7MV075gJ01`MfP0
LWY[07YlK@20Ofl0QhId08J5L`1mOfh0O81_07UmL@1eNW00Mg]a07amM@1oOG@0PX5]081kIP20O6H0
NgUT07AbG@1`KEP0L6eF06eXD@1bKEL0OGIR07mgHP1nM5h0PWIP08AlJ`29QWP0RHYn08:<QP1gRhL0
IWil05]dL`1GJfT0E5iK05A2?01/9RH0TalU09dA3`2A2P@0VAD:07<B1@0fL@000P00o`09ooooo`<0
0?l000<0Z8Pl0?n0003oP000103oP0000`3@D7P0X23`0:0Pl0110:0Pl0030=1@N03XJ3`0j6Pl00@0
oh0000<0Z8Pl003o0000o`002?oooolB003o000g05Ii2@1XEBT0JE/j03m3:`0S>BL0<4De051KA`1I
FCP0HE/c06AN=P1YH3`0JV0k06]R?01^IT80LFa<07A^E01dKU<0MW1C07M_D`1aJ4T0Lf]:079XA@1`
Id00LF]607A^D01dJdX0L60k071P>01`KU<0OGaX07mlJ01=FTd0>U5803UAB019Ge@0OHj70<S=c`2m
_L<0QhZ307QgH@1aLEX0Ff9@06=`HP28Uhh0ZKBb08fLVP1_OgP0LGYa0828M`2MXi40]Kfc0<K>bP36
c/d0`L[:0<39c0020;_4aP0:0;K0`P2]^;/0[;Ni0:6_/02CXJ80RYRI07YoNP1fK580Ji<]00_g10@0
0?l02?oooolB003o0080d51h00@0X23`0;Ph]03oP000j6Pl0P2P8?000`3@D7P0^3Rd0:0Pl00;0:0P
l080^3Rd0`2P8?00102h>;@0X23`0:0Pl02P8?020;Ph]0030=1@N02P8?00X23`0080d51h1@2P8?00
0`2h>;@0d51h0;Ph]0040:0Pl0030=1@N03XJ3`0oh0000H0oh0000<0j6Pl0=1@N02P8?000P2P8?02
0;Ph]00302S8?000o`000?l000800?l02oooool000[ooooo0`00o`00D`14Y`d0EQ@206dF2`1X4`X0
Ea8:04D_7`1=Dd<0DEaC051SF`1HKVH0IGUa06EfK`1NKF40Hf]K06mdG@1dN5l0MWQM07UdF`1jM5h0
NGEM07egG`1jMEh0NWIN07]fGP1lNF40N7IN07UdH@1kMF80NWAP07YhH01gME`0MWEK07MfGP1fM5h0
NgIR07]hI@1dM640K75O075hJP1^MfL0L7MV07MjJ`1hNf/0MWUV07UkJ@1fMfH0LWMS071dH@1cM6L0
MGEW081oK@23OF/0P7UT089iG@27Med0Q7AK08QkH@22N600LfaE07=ZDP1aJE80MVmH07A`G@1kNFD0
MWAN07UdF`1lME/0OGEN07acFP1mM5d0Pgi^08:6O@1jRXH0HgQh05E^KP1CJF<0F5MB06HV8P2?5Q80
R`P309LI3P1P40@09hX100800?l02Oooool3003o00030830003oP000oh0000<0oh00A`2P8?050?n0
000308300000o`000?l000Sooooo4P00o`00@@1LP0`0LEl^05=C=@0jCC/0<DPg0317=`0dB3T0BUQ4
05aRC01RIDh0I6E>06QYC`1/JDh0KVU?071[DP1dKUP0LfmD071ZBP1dJT`0MF]=07=^D01eLU@0MgIG
07UfF@1hM5/0NW5G07i`DP1mKTP0MV]707Q`DP1oMU`0PWUK0921G@2?OEX0TWmM08miF029LeT0QWYS
089iG@1jK4P0MW5D06E[E@1kNV<0Vi:00:jWX@2f/jl0c<[30>KWh@3en?40l_Gc0>S[k@3Pi>P0f=kQ
0=WOh@3NhnD0f=oQ0=;JgP32bm00/[c00:Rc]P2NZj`0RYBB07]hI`1fPC/0<mHD00H00?l02?oooolB
003o00040=1@N03oP000X23`0=1@N080j6Pl00<0oh000:0Pl02P8?004P2P8?000`2h>;@0X23`0:0P
l00?0:0Pl0@0d51h2P3oP0001P3XJ3`0^3Rd0:0Pl02P8?00^3Rd06RX?0H00?l02oooool000[ooooo
0`00o`005P0Cj`@0I24406`I3P1N6a00Dc4S04Y@>`1<FdX0E69F05e]HP1OKf80HfeJ06U^F@1aLe`0
NWIL07UfFP1iMed0NWUP07eiHP1mNF40NgMO081fG`20N60207YfG00E07IcF`1hMUd0OGQS07ehH`1i
Med0OGUQ07agH01hM5h0MgEO07IdH01cMF40KgES06]bH@1YLF40L7EW06edHP1bMfH0MgUY07EgI`1e
MVH0LWIT0080KWAR02@0LGAS07AdI01iMF40NG=M07E[DP1eK500MFmA07YaE`1jLUX0N6mD07I[C01j
L5D0LFU?079[D01cKED0N7EP07YgH@1fLe/0N7AN07YcG01kM5h0LW1D07IcEP1kL5D0OG1I07adH@1k
OG80Kh1k061gM01HKVT0FUaF06DX8P256Q@0Qa`@04d<0@0UR`42003o00Wooooo0`00o`000`0Xb3`0
oh000?n000020?n000030;Ph]02P8?00X23`04H0X23`00D0j6Pl0?n0003oP000oh0008300002003o
00Sooooo4P00o`005@1YRQ@0JE`]04eG@`0mETH0@UY<049HB`0nED80@eE104]FA01GG4X0F5m=05eS
D@1WJeL0Kg9M06ebG@1aLUh0M7AO07=cG@1cLeh0NGQS07QiHP0207MgH@0X07UjJ01nPFd0N7UT07ak
I@21PFX0S8ad08Z;M02:RW00Si5d09BEN@2IVh00WY^20::OQP2VYXh0[:nL0:ncW`2e]j80_/2]0<_=
_03Qgm40n?G[0?knn@3oo_`0o_on0?knoP3mo_d0moSk0>[/l@3KhNT0d]_R0<kIh@3>eml0am7E0<3;
c`2g`/H0ZkNh09bTX@2:PW00II@h03_=60P00?l02?oooolB003o0080d51h:02P8?000`2h>;@0d51h
0=1@N00>0?n000040;Ph]02P8?00X23`06RX?0P00?l02oooool000[ooooo1000o`003@1<P`H0IS<I
05Y6<01=C3D0DEa505UWE01LIUH0H6ID06i_F01dLEH0MG=J07QfGP1eLUX00P1nN5h00`20Nf40OWUL
07ihG@0207]fG@0n081gH01mMeh0OWQM07agG@1lMEd0NgEM07]eGP1iMeh0OWYX07]eH`1lN6D0N7MU
07EiJ@1]MVT0J7AU06UfIP1aNfd0MX9d07b9NP20Rgh0OHQl07^8NP1fPW<0K7IX06IbH`1ZMVL0JG=U
06ecI01dLel0LVaB07E]C`1bJT/0MFa@07E`E`1bLE/0LVmF071ZB01jLeL0Mg5F07A_E01mNF80OgeW
07AaF01gMEh0O7MN07YbF01iLUP0N7EK07AaF01dKe<0L6]?06aUB01TGT80KfUD07AeI01[MVX0FfaY
05QLF@1?;240DQL903h>0@0Aa002003o00Wooooo1000o`000`2XR3`0j6Pl0=1@N01;0:0Pl0<0oh00
00<0D91h003o0000o`002?oooolB003o000Z03nl301[FR/0BEI204QQD`15GU80CVEK05I]GP1IJe`0
G6MI05mWD`1JHdh0Dei=05ERE01KIeX0HFmT06IaI@1[LfL0K7QY071lK01eOW40Mh1`07Z2L01nQWL0
PH]n08:=O@23SWd0QI6008VEP`2@VHX0Ti^=09VRT@2R[Yd0[k^[0;o7^`3AeLd0iNOQ0?3bk@3emo@0
n__i0?kno03mo_d0o_on0P3no_h04@3loOh0n?Wk0>c`l`3Sj^h0fn?V0=KMh`3Cfn40d]_Q0<gHg@37
d]P0a]3D0;k9b`2e_kl0Y:RS0966KP1[VCP0:MlA00X00?l02?oooolB003o000306RX?03@D7P0X23`
01h0X23`00@0^3Rd0=1@N03XJ3`0j6Pl503oP000103@D7P0^3Rd0:0Pl01@T7P:003o00_ooooo000:
ooooo`@00?l001T09m/;05m<8`1?Bbh0FUi206=UCP1JGTP0E5U6065TDP1aKeL0N7EK07]iHP1mNEl0
O7QL07eeFP1jM5X0NgMM07]fF`1lMUd0OGQN089jH@1mMU`0O7IJ07]fF@1lMU/0O7IL0080NWIL02X0
NWMO07YjJ01jO6/0NGa[07EiJ`1]MV`0JWYa06=fK@1GKVH0DfYS04mYI01:IV40BV9Q04QRG`1:I5l0
CfMS059YI@1PMFl0Jgaf06MgLP1WMVd0Jg=T06maG01cLEP0M75F079`E`1^KeP0KVaD07E]D@1iLeD0
NgIM07YiH`1mO6L0OgaY07EdG`1hMf40NGIM07YeFP1kMUX0N7=L07McG01eL5H207EaF00:07=^E@1Q
GdH0EEQ304M=>@1GFDD0KfeL05YUF@1EGE00>RHE03XQ0@<00?l02Oooool4003o0003052@N03@D7P0
X23`02@0X23`0`3@D7PQ0:0Pl0040;Ph]02P8?00X23`0:0Pl080oh000`00o`08oooooa800?l002@0
2oL307Y/801AE3D0BUm@059YG01FJf80FFmV06=gK@1[Ng00LGe_06aiJ@1WMVD0IgEV06EbI@1UM6X0
IgM^06]kL`1ZO7@0LhN107R:Q`1kT8X0PiVB08^NV@2DYZ@0UjZV0:Nk]02ca[d0`M760=GQe`3/lN/0
n?[g0?conP3nood0o_on0?knoP3no_d30?knoP0D0?gnoP3gn_`0l_Kg0>c_lP3TjNd0g>7V0=cRj03D
g>00d]gQ0=;Lg`3?f=d0bMGI0<OBe035d=80`<S90:^WX@2QSWL0LIe504no:00Fl0T<003o00Sooooo
4P00o`000`0Xb3`0j6Pl0;Ph]00C0:0Pl0030;Ph]03@D7P0d51h0080d51h00<0^3Rd0=1@N03XJ3`0
0P3XJ3`F0?n000050=1@N02h>;@0X23`07QH]00Xb3`03000o`0;ooooo`002_ooool4003o000@03C5
3@1FBQd0IV8m06MWA`1ADCP0GEm605MMB01MIU@0Kg1I079aE01gMUX0O7QN07eiG01kM5T0NgIL07]f
GP80OWQN03l0OgQN07ifFP1lMET0NgAG07]eFP1kMUd0NWEL07MfG`1fN640N7YW079hI@1YL640I6iQ
055RF@1KLfd0?5QD02A0?@0WA400AV9K069oM01]Qg`0O96706j6N`1GLVL0;de201hl=00E;b`06C0a
02i7A`1=I600H6aS06Y]GP1`L5h0IFE@06a_F01hM5X0OGAG07]cE@1lMEL0NWAL08:0J`1mOFT0Lg=N
07MfGP1jM5`0NW=I07QbF01kM5d0OGMR07QbF`1bK4l0MW1E07I`F01bKEL0GV5<04QE@`0Y@3809SX^
05EG?`1ZJe80F6AA04<n:@0^C`400`00o`09ooooo`@00?l000<0D91h0=1@N02P8?00:02P8?020?n0
00030=1@N02P8?00X23`01X0X23`0P3oP0030:0Pl080d51h0`00o`08oooooa<00?l001d07><606]V
8P1?F440CfEG05eaI`1QMF`0IGM_06YlLP1]OWD0LX5g07B2N01eQG/0MhMo07Z<Q@1nTX`0QYNC08jQ
WP2DYZH0Vjj]0:>f]@2]_/00]lO80;W;c@34e]L0cmkN0=[Wi`3Uk^l0m?Sh0?ooo`020?kooP0H0?kn
o`3moOh0nocm0?OinP3em_P0lOCe0>cal@3Tjn`0h>OY0>7ZjP3MinP0g^GY0=cTj03KgnD0cMKJ0<gF
f@3:dmH0b]7D0<;6a@2b[:00WY]d06:a?@10d1l03?P53`00o`08oooooa<00?l000<0:<Pl0=1@N02P
8?003`2P8?000`3@D7P0j6Pl0?n0000L0?n000060>QX?03@D7P0X23`07QH]01XZ3`0:<Pl3`00o`0;
ooooo`002_ooool4003o001A042M201YG2l0JVLo05MJ>`13BS80CeDm05YRC@1IIE@0JG1I079bEP1g
MU/0N7EK07ajG@1mN5`0O7MJ07afF`1lMEP0NWEF07egF01nMUT0OWEI07agF@1kN5/0NGUQ075dH@1_
M6<0J7=P06A_G`1AHE<0?59702m7@00[ASd0<Tm5059XGP1QLVH0MX=i086>QP2DXIh0[KFe0;k2a@33
a/X0a<W;0;:l/P2GX9@0SIJ;065cJP0dCd/0Fg=b02`o>01EGDd0Lg1M07YcF`1mN5X0OGII07eeF@1j
ME/0NgUQ07elI@1dMEl0LgEM07IeG`1lMeh0OWEJ07idF@1jM5X0OGAM07mfH01lME`0NG=I07IbE`1a
L5L0KG1M05AOC`0cBS/08T0b02E0<00gB3@0IVI906eVC01FB38088d100<00?l02Oooool4003o0003
0:R8?03@D7P0X23`01X0X23`0P3@D7P00`3XJ3`0^3Rd0:0Pl0030:0Pl0D0d51h0`2P8?001@2h>;@0
d51h0>QX?03XJ3`0^3Rd01L0X23`00@0j6Pl0?n0003oP000^3Rd0P2P8?000`2h>;@0P<00003o0002
003o00Sooooo5000o`00<P0Ck@D0GX/S069O?P1NJe/0J7Q^06QjL@1^PGH0LH=l07Z7P@1jRXD0Oi:<
08JGU02<X9`0TJBS09NZZP2R];80ZK^l0;S8b@2kb//0amGG0=CRi03Sk^d0l_Sg0?Gin@3cn?L0n?[k
0?Ghn@3bmoL0lOCf0>obl`3_m?D0j_3`0>gdm03YlO40jo;c0>cbm03Vk_00h^c/0=kWi`3HhN<0eMoP
0=;Kg@3Cf]/0eMSL0<S8b@2k]:`0[in:08JPF01B`Bl0;N8E4`00o`08oooooa@00?l000<0:<Pl0;Ph
]02h>;@02`2P8?000`2h>;@0d51h0>QX?00K0?n000060>QX?03@D7P0d51h0:0Pl01XZ3`0D91h4`00
o`0;ooooo`002_ooool4003o001A05j54P1dIc/0Kg1A05MSC017Ed<0AUE304YIB01@GTl0HVaK06Y^
E`1bM5/0N7IN07ijH@1jLeL0OGQI081jG01oN5X0NgED07YbDP1kLeL0O7UP07AiH`1ZM640FfYI04eO
E@13ETh0<Ta202=0=P0]BCh0?5=4059RC`1OJ5<0JfY@079XC01dIdP0MfY607Y[AP1eK4l0OWY[09ZI
SP2NWi<0Q7i`08EgG@2=N5H0TWaN09J>N01`LV<0Qhb106E/F@1DEch0MVa>085eEP1oN5X0O7QP07ek
I@1jNfD0MgIR07EdGP1fME`0OGQM07efG`1lM5X0OG9I07idG01jLe/0OgUS07YeH@1iM5h0LW1J06]_
F@1TK5X0EfAG03=;@00/Acd0<T`n03M??`0oF4T0GfYE071UA01aFc<08;4100<00?l02Oooool4003o
0080d51h5`2P8?001@2h>;@0d51h0>QX?03XJ3`0d51h00H0X23`00<0d51h0:0Pl02P8?002P2P8?00
0`2h>;@0X23`0:0Pl00D0:0Pl0040>QX?03oP000d51h0=1@N0<0X23`00<0^3Rd06RX?000o`000P00
o`08oooooaH00?l002`09=/;05JH9`1cJDH0Jg1K075lKP1eQG/0NhR107b:Q@22Ti00QIRD08^OWP2A
Y:D0VJZ/0:Zk^`2faLD0`Lo@0<SGf@3Ch^@0g^_/0>[alP3]mOD0k_Ge0?3fmP3am?H0lOGg0>gcl`3^
m?@0kO;d0>ccl`3Wl>l0i^o^0>G^k@3Tk>`0gnKX0=[Ti03PiNH0g>;O0=3Bc@36`[P0_K2P0:6`NP22
Ze@0E<8`02kS5QL00?l02?oooolF003o0003052@N02h>;@0^3Rd00T0X23`00<0^3Rd0?n0003oP000
5P3oP0001`3XJ3`0d51h0=1@N02h>;@0X23`06RX?01@T7P05`00o`0;ooooo`002_ooool4003o001A
06:96@1aJD40MWiW061aG@1CIE<0CV1>04mOD01DHUH0Gf]P06I_GP1WL5X0KW9L07QfG`1mN5/0NWEF
07ehF@1nMeT0OWUM07mjGP28Q6T0O7iW06QcH@1<HE@0=4m702=1>@0K=b`09Chc045GB@1KJ5D0JfeA
075/B@1gIcl0QFdn089^@01hJ480MVI208UhD020MUD0PX5]0:JSU`2g]jd0Ti5n089gF02AOEP0U7eG
099kF02@OEX0OVe;07EV?`1iKdh0OgAL08Z4K@26Pf/0OGaW07UjH`1eMUh0NgMM07ihG01mN5/0OWUM
07mhG`1nMed0O7EM07efG`1lMf80NgMT07McH01eLEd0JViK06E`H01BGe80@553039>?`0gDd@0?5I7
049MC@1=IET0HW1P06EQ@01hIBl07mH400<00?l02Oooool4003o0080d51h5P2P8?030?n000D0X23`
00<0oh000=1@N02P8?009@2P8?000`3@D7P0X23`0:0Pl0040:0Pl0030?n0001@T7P00?l000800?l0
2?oooolH003o000F00[g100fbA<0DZDX06J=?P20N5T0OgYW0864M`22SHH0Q9B@08fLV`2DYJ@0Wk:b
0:Zl^`2faLH0_lo@0<SHf@3@hN40fnKU0>3[j`3Rk>/0ino_0>O]kP80j?3_00h0ing^0>[/l03Yk>`0
inOU0>7Nf`3Id/`0d/Nn0<ZlZ`2/^XT0S[QX0672@@1:c2/0;N<H00ch1Q/00?l02?oooolH003o0005
02S8?01XZ3`0T71h0:0Pl02h>;@01@2P8?000`2h>;@0j6Pl0?n0000@0?n000<0d51h00H0^3Rd0:0P
l01hF;@0J:Pl052@N00Xb3`K003o00_ooooo000:ooooo`@00?l00540I8`K079/B01fOfh0KGY^069c
IP1NKf40GfiR069^IP1`O7@0OHQm07J3LP1TKeX0IVU?06eZC01`JdL0M6e807U`D01mMed0OW]R07mk
HP1iNV00IG1I03U??@0Q>bh0>4lm059OA`1QJ4`0KFa<07a`BP2;N4T0RgDn08ea=`2>MT40GeHb05EB
=01QFch0IV9506i_E`1iNVL0PX1_07alK@1^LV00JF]H05IJB016CSX0LFU<08AcCP2:MTh0RG5008A/
?P22LE<0PGaU07]lI01kNF00OW]O081lG@1oNed0OWYL07miG01oNUd0OWUL081jH01nN5l0NWAJ07A`
F@1]JeD0IfA@069UC`1IIED0C5m>04EGAP18FTX0A5e<04UTE@1@Ied0CFIK05A/H`1QKV80Hf9307mY
;@0Ni@L00`00o`09ooooo`@00?l000<0d51h0;Ph]02P8?00502P8?000`3XJ3`0d51h0:0Pl0020:0P
l0030=1@N03XJ3`0oh000080oh0000<0^3Rd0:0Pl02P8?001`2P8?020=1@N0<0X23`00<0oh000>QX
?02P8?00702P8?000`3oP000D91h003o0002003o00Sooooo7@00o`006P0/hA809M`B04Zj9014^BP0
KYa206VPB@1ZY580NjES09nENP2WWHL0[jBC0;>XU@2m/9/0_k6N0<>bWP34/ih0`JnH0:RiQ`2=`G<0
SKa]08bgH`1TaDH0FLTh04o?;`0^i1`09>/C8P00o`08oooooad00?l00P1@T7P00`20`000D91h0:0P
l0030:0Pl0030=1@N02h>;@0d51h00D0d51h00<0j6Pl0?n0002P8?000P2P8?000`1hF;@0D91h06RX
?002052@N2800?l02oooool000[ooooo1000o`00D01HXQP0KfI007QnJ`1hPgL0N8Mm07>4N`1bPWT0
MXIk07V9O@20T8L0O8f207V:O@1[Mf@0J71G06]_D@1^K4`0LfmC07QhG`1jOFH0OX1[0864K@1/Jdh0
If@o06mYA01jKTX0Ng5<081eD@29NeH0RWQ<08miB@2BNDL0Sg@n08mgAP1mLDd0MG1B07EbF01^MEd0
GVmQ07B0NP1nRH@0DF5L02Q0=@0Z@380<T/k04AKA`1YJdh0S7]C091hBP2;M4D0T7iC08IjFP22O680
PWaQ08J0H@24Of00QGiP08=nHP21O600OGQH07efF01gKU40LfY=075WC01ZIDT0HF=705YPB`1BHD`0
BEi=04]QE01DIeP0FfaK05][G`1IKV@0EfmU05U_J@1NLV/0G6mX06E^GP1_I3d0HY/P1000o`09oooo
o`@00?l000<0Z8Pl0;Ph]02P8?004`2P8?020=1@N0<0X23`00<0^3Rd0=1@N03oP0000`3oP0040:0P
l0030;Ph]03oP000oh0000@0d51h00H0^3Rd0:0Pl02P8?00j6Pl0?n0003@D7PM0:0Pl0030=1@N000
o`000?l000800?l0cOooool000[ooooo1000o`00D00Ni@P0OVLa08B1IP24SGh0Pi2907nAR`22UI00
R9^E08FFS`1oTH/0Oi:907^>QP1fQG`0Mh9h07R4N`1gPgP0MGm^07=nJ@1dNVL0MWUX07UkJ01lKTD0
S70g09=d?@1oJd<0KViE075hI`1fO6d0N7iZ07EkI@1jOVH0Q8=V08f6I@2=P5l0SX1M09J1HP2RSgD0
Z9j>0:ZUW02WXj00T8f108EjH028MU80PGA>081cB@29N4/0TGiC0960F02?QF80S8EZ08b5K028PVP0
PWaR07iiG01lMUH0NW9D07MaE01cKU00LFa=06a[C@1[J4h0IfQB061TDP1JIE80DVED059YG01CJUl0
EfmS05mfJ`1WNVl0J7Ua06IhL`1QMW80GgQc05mgK`1UNg00IGEZ06]VA`1eNRP05>h61000o`09oooo
o`@00?l000<0:<Pl0>QX?02P8?004P2P8?00103@D7P0oh000?n0003@D7P<0:0Pl0030;Ph]03@D7P0
d51h00<0X23`0P3@D7P00`3XJ3`0d51h0=1@N00M0:0Pl0030;Ph]03@D7P0:<Pl00@00?l0cOooool0
00[ooooo1@00o`00CP1EXAP0OFe608bAP02:VI80PIJA08JKV029WI/0Q9RE08>FU02<WIP0QIRD086C
SP25TXd0PY6<07^<P`1iRgh0OH]l07n<O@1kPgD0NWi]07mfE@25KSd0TG@k08idA01/Hd<0Hf9;06YY
F01kO6/0PHUj08>@P02;V8P0Tin?09NPS`2LWh/0XZ2809:5I`2DOeD0VX=F09b4GP2KP5X0VGm@09Ag
@@2ENdD0XI1Q09nFL02ITg<0U95e09:>M@2@S7D0SHI`08AlI01nN640N7=H07EaD@1fLU40M75D07Ad
E`1bLeT0LWER06icIP1PK640EfQQ05e_J01HKV@0HGI/06MlLP1[P7L0J7id06UoM`1ZP7T0Igeg06In
M`1QO7@0IGac06aoM01[L5h0PFXd02cP3`D00?l02Oooool5003o00030=1@N02P8?00X23`0180X23`
0`3oP00<0:0Pl0040=1@N03oP000X23`0:0Pl0@0oh00802P8?000`3oP000X23`003o0004003o0<go
oooo000:ooooo`D00?l004d05>h606V?9024MUL0SiN>08NKUP25ViL0Rj6O08^PWP22V9D0Qi^F08^N
W028WIX0RijM08^OWP24VI80PiJ>08JFS023ThX0Qi:<08VCQ`28Sgh0R8Y_08b5G`2?OU<0R7A;08Ma
BP27L4/0RgIC07eeG@1mP6h0SiN70:nh/P2X/k40NH^505QYGP1JGdX0Q7A809=jA02FO4T0YHmQ0;NU
NP33/hX0`;:=0:ZRPP2GUGL0Si9d096CNP2DUH80TIF408R:M`23Q700Oh9^07j4K`1oQVl0PHA_08Z9
M@2KTh00RhMg08:2N01gO7@0L7]c06]jM@1YNg@0J7ie07F9O`1cQWl0MhZ50766P@1^QWh0KXR006n7
P01/QG`0JWmf06ikKP1^LUl0NVTo03[=5@06003o00Wooooo1@00o`000`0Xb3`0d51h0;Ph]00C0:0P
l080d51h00@0^3Rd0:0Pl02h>;@0^3Rd0`2P8?020=1@N0<0X23`00<0d51h0?n0003oP0000P3oP002
0=1@N200X23`00<0d51h091`N000o`001@00o`3=ooooo`002_ooool7003o000:03S95@1nNTP0PH5e
08jKU@2@Xj00Sj>Q08jRX02@Y:80TJFT092TXP80T:BT03h0T:BR08fPW`2FY:40Tj>N08nPV`2<W9H0
UjFN096PW02HYIl0WJJL09VNSP2MVhP0WYQo09nBL`2MSF/0V8UW0968K02<Qgh0PH5i075fH`1iO640
TXi/0;2XPP3<`j80jN?:0?cij`3elnP0k>[O0>7Pe@3De<H0b<^k0;k5]02e_jl0/[b`0:bk/@2T]:/0
Xk6[09f/Y`2EYj40Tj>M09RPU`2TWi<0]:>E0:NHR02HTh<0SY2608>=Q`1nSHD0OXn707R>Q`1mUHl0
N96<07R@S@1eRhP0MXb60725OP1_P7P0Kgec06YaG01_J4H0K8T^01gV2PL00?l02Oooool7003o0003
091`N02P8?00X23`01l0X23`1`3@D7P01@2h>;@0X23`0:0Pl02P8?00^3Rd00<0d51h00<0^3Rd0:0P
l02P8?004`2P8?020=1@N00302S8?000o`000?l000D00?l0cOooool000[ooooo2000o`008`0Ek`P0
FJHX08QeCP26PVh0UJ2K09^[Z@2L[Z`0VZj]09^_[P2I[J/0Wk:a09b^[`2K[Jd0WJj^09V[ZP2GZJH0
XK>`0:6b/02N/Jh0V:^Y09Z/[02J[Jd0VZb[0:Ff]@2]^kP0_<C20<79a033clL0d]kF0=[Sf`3Oiml0
jNoW0?Oil`3ooo/0o_kl00<0o_kn0240oOgm0?knoP3no_h0o_km0?Khm`3Wk>/0e^;Q0<SEe@2nbl`0
]lC50:^i^@2R];80YKNa0:JaZ`2VZjD0[ZfT0:f]X02XZ9d0X:JQ09:RWP29WIT0R9fH08BKU`24ViP0
OiNC07nETP1fRXH0KX1f06ahK01/Lf00M6a:056T9@0Xga002@00o`09ooooo`P00?l000<0:<Pl091`
N03@D7P00P2P8?001P2h>;@0d51h0>QX?03XJ3`0^3Rd0?n00080d51h00D0j6Pl0=1@N02P8?00d51h
0>QX?0020=1@N080^3Rd00@0d51h0?n0003oP000j6Pl203@D7P>0?n00080j6Pl0P3@D7P00`2h>;@0
X23`0:0Pl00=0:0Pl0030;Ph]02@L7P0D91h00T00?l0cOooool000[ooooo2`00o`007`1fW2l0QWQH
09FHS@2PZjT0XK6`0:6c/@2R]K@0X[Bd0:6c/`2N/[80XKJf0:2c]02Q/k80Z[Zi0:Be/`2b`l80Z;^i
0:6d]02P];<0YKRg0::d]02Y^k/0^/K80<SFe`33dm<0bmcK0<oLg@3MinT0i^k`0??gm`3moOd00`3n
o_h40?gmo@0L0?kmo@3no_h0nOWj0>7Xj@3Fh^40c][J0<KDe02jblT0^<W60;k<b@32c/X0]<:n0;K2
^P2g`KX0/kZc0:Vd/@2JZZT0TJBQ08^PW@2;Wi/0R9^H08:HU01gS8P0IWE^06Q`G01/I4L0QFdl02WO
4@/00?l02Oooool;003o00040=1@N02P8?00X23`0:0Pl2h0oh0000@0X23`0?n0003@D7P0d51h2P2P
8?000`3@D7P0D91h003o000:003o0<gooooo000:ooooo``00?l00280:=lB05f/<`22TED0Uhmi0:BW
W@2X/k40YKBd0:bm_@2Y^k`0Z;fl0:Rk_@2/_[l0[Kno0:Fg]`2Y^kX0Zkfn0:jn`02_`/00/l?30;?6
a@2kcL/0_lg=0<CBdP3;f]L0cMcJ0=SUi@3Ihn@0f^CV0>CZk03]l?40l_Gd0?gno@3no_h0oOkm0`3m
oOd20?kmo@0I0?kno`3hnOT0k_Gd0=cWi`3Ii^H0enGU0=3Mg@3Dg]h0c=OH0<;@c`2lbLL0]l?00;Bo
_@2Y];<0Wjj/09VYYP2AY:00RIbG07b8Q01`NW00JViJ075gA01AYBP0>/hI01Oa2P0<003o00Wooooo
3000o`001`1@T7P0T71h0:0Pl02P8?00d51h0>QX?03@D7P0;@3oP0000`3XJ3`0d51h0:0Pl0050:0P
l0040;Ph]02@L7P0D91h02S8?0`00?l0cOooool000[ooooo3`00o`004P0Fl@X0A<LQ06Z[A@2SSW80
YI^;0:b]Y`2c_[/0/;jn0;31`P2ca/L0/L?30:Zn_@2[_kl0/<710;S<bP2kcL`0_Lo>0<SFeP80c][J
00/0dmoO0=CPh03Ki^L0fn;T0=cVi`3SkNd0jNo^0??hn03jno/0n_ck0?gmo@020?knoP030?gno@3n
o_h0o_gm0080o_kn01<0nogm0>ofmP3Yl_<0f^OX0=ORi03>fM`0c=OJ0<C?e02ha<L0/kfo0:jd]`2Q
YjL0SY:<07n1M@1eMf40MGa>05VL<P15^B40<mPG01000?l02Oooool?003o000702S8?01XZ3`0X23`
0=1@N02h>;@0d51h0>QX?00Y0?n000030=1@N02h>;@0X23`0080X23`00@0^3Rd0:0Pl020`000D91h
4000o`3=ooooo`002_oooolC003o000K01Sb300cf1`0Lji507^[DP2?XVT0[J:=0:bZW02_/JX0^Kbh
0<38a@38dm00b]KD0<OEe@37e]H0c=[K0=CPh@3Ii>D0gnWY0=gXi`3SkN/0hn[X0>G]k03]mO@0loOg
0?KinP3hn_T0o?gm00<0o_kn01<0o_oo0?kooP3moOh0moSj0>_`m03QjNh0f^3U0<SDe@2mb<T0[KJe
0:J[Z@2IV900T8Ug08n3JP1jRU80G9hf04Nh8P0Sfa008NX@01@00?l02OoooolC003o000402S8?01X
Z3`0X23`0:0Pl080^3Rd0`3@D7PN0?n000<0d51h0P2P8?000`2h>;@0X23`06RX?002052@N1@00?l0
cOooool000[ooooo6000o`005P0ej1X0Gl/_05?2;01kXdD0XXQU0:FBN`2`XY<0^[JZ0<S8`P3Ef]H0
f=oL0=kTh`3UinT0i^c]0>gal`3/k_40k?3c0>ocmP3fnO`0nocm0?[lo@3lo_l20?kno`0>0?cmo`3e
mOP0kNg_0>7Qh`3Bd=80^[Vi0:RXY02IU8`0S89b08aiG`2CNeH0WH1C052o:@18f28J003o00Wooooo
6000o`000`1@T7P0X23`0:0Pl0050:0Pl1H0oh001@2P8?000`3@D7P0X23`0:0Pl00J003o0<gooooo
000:oooooa`00?l001h03OX703;W6`0^haX0=]/O05K5<P1j]D/0Qk5F08RcGP2;]fD0V;Ic0<JYS@2i
/8X0aJjE0<F`UP36/IH0`k2G0<:_U`30[9<0_ZR>0;>^QP25^6/0P;5O082^F01n[5<0LZi704o2<01A
`Rd0?]4Q02cS600Il`dN003o00Wooooo7000o`001@0Xb3`0D91h052@N01XZ3`0D91h00@0X23`00<0
^3Rd0=1@N03XJ3`01`3oP0000`3XJ3`0X23`0:0Pl0030:0Pl080D91h00<0J:Pl052@N00Xb3`07P00
o`3=ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {180.75, 0}} -> {-0.106847, -0.0454574, \
0.0105606, 0.0105606}, {{10.0625, 98.1875}, {176.438, 4.25}} -> {-17.4879, \
-6.49014, 1.7365, 1.7365}, {{107, 195.062}, {176.438, 4.25}} -> {-185.905, \
-6.57348, 1.73742, 1.73742}, {{203.875, 291.938}, {176.438, 4.25}} -> \
{-402.835, -31.6328, 1.97589, 1.97589}, {{300.75, 388.875}, {176.438, 4.25}} -> \
{-593.828, -31.5061, 1.97449, 1.97449}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1T, pdf1, pdf2, {Green, Blue}, 
          255. ];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2T, pdf1, pdf2, {Green, Blue}, 
          255. ];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1T, class1, obj2T, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44639 
%%ImageSize: 400 178.555 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0106283 0.238095 [
[ 0 0 0 0 ]
[ 1 .44639 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .44639 L
0 .44639 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0106283 0.245293 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0063C92C62C62962C62893AA3CC38F53
C39053C59055C48E55C58F57C48E55C58E56C18C53C28E5591AB3F61C52861C62961C72A
60C72961C82A60C62960C7295EC62800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC223
5AC1215BC1225AC12158BF20B58345B88146B7834AB47E46B58044B67F41B88141B68041
B27F40B47E43B37E43B57D42B67F42B47E42B17D42AF7C41B17E40B47E41B58043B38042
B38042B58243B68346B68346B68547B9894D5BC1245BC2245DC4265EC4265DC42700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDF1159C02356BD20829D31AD7E41AC7D40AC7D41AC7C43
AF7D42B37F46B38144B28146B28147B28048B5814DB3804DB17E48B68049B77F45B88148
B6824BB6814DB37E4AB6804AB7824BB8844EB37F4AB5834DB38048B58148B68248B38045
AF7C40B27F44B28045AF7D44AE7C43AF7D44AD7B41A9763AAA793AB07E40AE7C3EB07E40
B18143B28344B0834683A23658C0242CE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002EE11300FF0000FF0000FF0058BE2256BE22
54BC2156BD23829C32AF7C45AF7E43AD7D43AE8046AE8048AE8149B1824DB0834DB38251
B88452BE8757BE8958BE8A58BC8654C1885AC1855AC4885DC6865CCD885ECE875BCF875D
CE885ECA835BC88259C98259CA845BC8845CC8845DC9875FC7875DC5875BC08558BD8355
B98352B48353AF8051AD8052AE8252AD824FA97D48A67941A67940AC7D44AE7C44AA7840
A37338A37436A57538AA783DA9783CAD7B3F819C2F56BD2056BF2054BD1E809C2D56BD1D
2BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0058BF22AD7A3FAC7A40AB7941AA7941AB7D47
AA7E49AB7D4BAE7E4CB38050B4814FB98454BE8659C2875FC68761CB8861CF8960D58663
DD8965E08767E08566DF8363E17F5DE47B5CE5785BE4755BE57158E36A53E0654DE2644E
DD6149DF614ADF624AE1644DE36651E26651E26854E16B57E06C58E2725CDF755CDA775C
D47B60C27A5EBE8266BE896BBB8969BB8C67B78962B3865DAE8359AF8357AE8154AC8052
A77D4DA57C47A57942A4743CA27135A47335A16F33A27033A47335A87838A87738A97839
A978367F9A282BDE0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0054BB1F7D9A2EA9773DAB7940AB7943AB7B48AF7E4FB48255B98458
BD835AC5855ECD8660D78766DB8665DD7D60E0765FE0705CD9624DD75741D44C38D44232
D53E2FD43829D23224CF2B1DD32B1AD42716D42716D52419D52117D71F17D51E14D72018
D82017DA2117D92014D81E14D81E14D92116D61F16D41E15D11E16CF1E17CC2015C52015
B420158D130A8118137C1D167F251A85302290402F974D3B9B5744A66651AF735BB37E61
B58464AE825EAD815BAC8055AB8051A57C49A27944A1753FA27239A27235A07130A37230
A57434A77736A8783654BC1929DD0B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
29DD107B9831A77743A87643A57443AC7747B27A4DBB7D53C17D58C87B5BD1795BD97459
D5664ED0543FCE4634CB392BCB3123CE281ED0241BD11E16D61F15D71B12DA1C13E01C15
E31C15E61B14EB1F15EB1E14EC2015ED2014E81C0FEB1C11EC1C12ED1B14EC1C13EE1C17
ED1D16ED1B13EE1C12EB190FEA180EF22015ED1B12EA1910E8180FE91A12E71A11E21912
CB120EA3030395040895080C950A0C8E07088B0A0A8409097C07087B0D0B77100C771912
78241A83382B924E3FA0634FAB725CB27F63AE8160AA7D59AA7F54A77D4CA27941A07339
9E6C30A16F30A16E2F9E6E2C9F712BA0712900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0029DD0F53BB1F52BB21799932A17544
A57647AD794DB1774FBB7653C47758C97052CB664BCC5943C44332C23427C6291DC92116
CE1E14D21911D71913DA1712E01914E11611E61911E6170EE91A12E91913E81810EC1B14
EB1A10EF1C11F22012F22014EC1B0FF42116F11F12F42015F31F13F41F14F62116F51F16
F21E14F21D12F62115F41F13F42013F41F13F41F13F11D12F21D12F11C11EF1C10E91C12
CC0E09AD0204A40205A30105A60408A001069D04089B03089703079002068F040A8C050A
8304087B060876070A710A0B6D0F0E721A167C2D258743369B604BA77357AA7C59A87A53
A7774CA675449F6F379A6A2F9A682C9665249E6D274FB61100FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0028DC0E7B9930A97A47AA7B4DAE7B50B87955
C17656C56C51C65D48C14737BE3526BE2518C21D13C7150FCD1511D2130FDA140FDF130E
E2140FE41610E4130FE4140FE51610E71610EA1A10E9160EEA1A11EF1C15EE1C13EE1A11
F01C11F11D12F32113F42114F01E11F42116F52215F72317F72116F92217FB2419F62016
F62114F92317F72314F31D11F52111F82313F62114F62215F41F12F11C0FF11D11EB1D13
C90907B20203AE0306B00507AE0408A70105A60207A40207A002079E02079D0209990107
9601079302088F040B88030B81020A7B03097A070B71070A6A090869110D6F1F1880382A
914F3B9E634BA77451A374499E6E3F9A6A3597662A97662296661C4CB30B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DD117B9A34A87948AF7D52B67C5ABE775DBF634EBC4A38
B73024B61E15BB150FC4120FCD110FD3110DD7100DDA0F0DDC0F0EDE110DE1110DE2110E
E41410E61611E61611E51311E41511E5140FE91912EB1811EE1A12F11C14F42016F41F15
F41F14F31F14F62216F72317F42115F42116F22013F92519FB261BFD281BFE2A1CFC271B
FD291AFE2919FE2A18FB2616F92312FC2514F72012F62112F62012F62113F41F13EC1D14
C90806BD0809BB090ABC090BB8070AB00106AF0309AF050CA70106A70208A70108A20105
9F01059F04089701069101088A01088601078403088001067E01077D030C76030A730609
6C0707630A0764170E712D1D884B369C6448A06B44A16E3C9A69309565229260146B8307
47AB0300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029DC0D
50B81B53BA1F7F9931A97747B07B4FB97854BD6F50B459419C34249A1B15AF1B15BE1511
C7110DCE0E0DD30E0FD60E0FD90D0EDA0D0CDD0E0EDF100FDF100DE2120EE1120FDE0F0E
DC0D0DDD0E0DD90A09D9090BD70A0BD90A09DE0E0BE71610F01C13F41E14F72116F82117
F92217FB2519F92317F72117F92519FC281BFC2A1AFC281BFE2A1DFE2B1DFE2B19FE2D1B
FF2D1CFB2716FA2514FB2314FB2313FA2212F92214F92312F82211F82114F41E13EB1D14
C40502BE0908BF0908C30B0BBE070AB80509B40409B00308AE0308AD0309AA0206A70206
A60106A301059D02049500059001088B0008890107870105870006870109840107820207
7E01077901077604086E0506690808660F0A70221586422B9F6645A07245996B34936222
824E0E7B470542A90400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DC0A7594219F7337
A67944AB7749B6784FBF7250BD5C42B43B2AB12518B0140EB3100CB90A0BC80F0FCD0D0B
D20C09D50B0BD70C0EDB0E10DD0D10DF0E0DDF0E0CE4110EE61410E3130FDA0D0CD30608
D20608D30609D30709D6080AD40708D80B0ADC0C0AE0100BEB1910F31E16FA2117FB2318
FB2517FB2415FA2515FA2619FB281AFD2B1BFD2E1BFC2C19FA2A19FF2F1EFD301BFE2C1A
FD2B1AFC2919FC2818FD2616FD2616FB2315FB2316F92112F92213F72014F31E12E51911
C20602BD0908C20B0AC30A09C1090CB70407B20408AD0207B2060BAE0307AD0308AA0209
A70106A80206A402079D01069801089301099002098B01078A00068B01078B02078B0208
86010787010889030988050A82040A78030776070A6B0805610D05702D1A915739A16C44
97653683531D6C3E047B4A074AAF0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0028DB0C9F7234A77D43AC8247
B4804AB46840B0462CAC2716B41A0EC0130DC30C09C50909CA0B0BCD0A0BD00D0CD10C08
D60F0AD60C0AD90D0DDE0D10DF0D0EE51211E5140FEA160FEA170FDD0D09D00402D20608
D30709D5090BD4080ADA090CD90A0ADC0D0ADE0E0BDD0D09E10F09EF1912FC241AFE271B
FD2A19F92816FC2C1AFB2E1EFA311FFB3521F93721F93522FB3522FD3321FE321FFF301E
FF2F1CFD2B1BFE2B1AFE2918FC2717FD2718FC2416FB2315FB2315F82212F52316D9130C
BB0404BC0A09C10C0BC30B0CBE090BB7070BAF0409AB0309B0070CAD0408A90207A80208
A8020AA80206A70308A20106A1030A9B01089501069101058C01058C02068E02078C0208
8801078802078B05098C04098A04088503087F02087C040A77050C70080A660A056E1F11
85442B99643C9163317D4E156F3E0260780525D70500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002ADE0FA67B3CAB8145B0853CBC8F37
D0913CA23709AF1807BF100BC40B09C80A09CA0B0ACC0A0BD00C0DD30A0DD60D0CD60E09
D8110CDA110ED8100DDE1111E31411E81511EA1811EC170FEB180DE10E07D70A05D50806
D30706D40708D60A0ADA0C0CDB0C0ADD0D0ADB0D08DE0F09E3110AF21C13F92619F62C1E
EF3826EA3D2AE94331E84837E9503FE75544E85D4BEC6051EB4C3DF43628FD3121FD2F1B
FE301BFE2E1AFE2C1BFD2819FD2819FD2718FD2415FA2314F62513EF2A16E62C19CA160C
B60605BB0D0DC00E0DBF0C0DB80A0CAF080CA60307A20307A50408A70408AA0509A60207
A40107A60309A50207A102079C02079A0207980205910104880004850004890107870106
8201057C00037F01058202058604078202077F02087E02087F020A7F030A7B0409750609
6A09056A1A0A87482999643B8C5C2A74410C76400345A90400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0049AE049867197D9A2BAA7942AF7F3DBE8F33C39822CD9D18
DF9922AC3201B71001C10A07C10606C40707C90B09CC0909D20B0BD70C0CDB100EDC120E
DA120ECC0D0AEB2F2CD3100EDE120EE71410EA170FED190FEE1B0FF11C12E7160DD70803
DA0B08D80A06DA0C09DA0D0AD90D08DB0D07DE1109E01008EB190EF82418F4281DC41C12
EA7B6CFBAC9FFEB5A8FFC0B5FFCCC2FFD3C9FFD7CCFFD8CEFDADA3E24437F83522FF321E
FD2F18FD2C18FE2B19FE291AFE291BFE2719FC2615F72A1AD82312E45945F17F6DB53126
AC1711B5130EBF1311B80C0DAF090DA6060A9E0409980307980407A00609A40507A50205
A40206A20105A60308A00206940003930004970305940307870105820105840005850005
8101057700017700027900027A00027700037601057601057A01057C01057D01067F030A
7C050B720807660A026C210F8C533398643B834E1D6E370260740326D60300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB00A9B6A29AD7644B26F48A05127A96218D0991ACD9F08D2A306
E49D19AF3300BC1504C20B07C00607C40807CB0D09D00B08D40B0AD80E0CDA0E0DDB0F0E
D40F0EB70302C21210C00402DF1610E8180FEE1B10EF1C0FF01C0DF21D11EF1B0FE9170D
EE1C13ED1C12DC0E06DA0E08D80E06DE1108E7170CEF1D11F92518FD291CF22B20A6110F
B6766EFFEBE6FCEDE8FCEEEBFAF1EDFBF3EFFBF3EFFCF0EBFFDFDADF6258F23927FC311D
FE3019FE2D18FE2B17FE2918FE2918FD2818F82616E62D1E941206E0A193FFE0D3F6BCB2
C86A5EAF3328AE1D17AB1411A4100E9C0A0A9408088C0A098A0D0B870A0696100BA51311
A10707A20407A6060B9F02089801089201078F01058F0205870104840004860004890206
8601057F01037C01037D01047A00037701047300027200027501047A01067F0207800207
7E02087B03077703076D07065908026B2B189259398C562B7339087D420224D40300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00728E1A9E703AA56E499F4C35952614901600B85A13D79B10D0A303D3A405
DF9D17AD3500B71102C00907C00607C60A08CD0C07D10D09D50B09D90F0ED90E0CDC0F0F
D50F0EC6110FEC3C39D61814E51911EA180DEE1B0FED1A0BF01E0EF01D10EE1D10EC1E12
ED2316EE2618E22215D5190DDC2516E22719EC2C1CF32D1DF62C1DF92A1CF52E21C42721
833E3BFAE9E7F3EEECF5F1F0F1EFF0F5F3F3F3F0F0F7F2F1FFEDEBE98884EC3E31FC321F
FC2E19FF2C18FF2C18FE2A17FE2A17FC2A18F12E1CBE291A944437F4D9CEFBF0EAFEEEEA
FFE3DCF9C4BBDE8D85BB5750A1372D8E23188620157C20157422167E2F22B05A4DCC6158
96110E9B05099F040B9C020999010A9202098900058900058902058902048701038A0306
8901058701058502058301047F01047C01047901037601037600047B00067F0106810106
820308810107800209770307660103580400540C0371331A8E5631774011733901708109
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25D806996B299E7044854D30702011850E07A40F09A81103BD5313D89B0FD1A403D0A303
DB9D15AC3B01B71403BE0906C20807C90A08CD0B07D30C09D80E0CDC100DDB0F0BDF120E
DD130FDD1A16E52621E31A13E9180EEB170DEF1B10ED1B0EE81B0DE62113DC2718D32D1F
D33A2DDA4A3CDF5A4CE66C5CEC7867EE796AEB705EE86353E55444E34333E43C2CD33D33
711F1BDCC3C0F6F0EDF8F4F4F4F2F3F5F4F3F4F3F2F4F2F1FDEFEFF4B3B1E2443DF83222
FE301DFE2D19FD2B17FC2A17FB2E19EE2F1DCB301E9F3F30EAC3B8FBF1EBF4F2EFF6F3F3
F7F2F1FAF0EDFDEAE5FAD6D0E1B3A7D7A495CF9E8DCDA190D3AB9BDAB2A2E4AD9FAF5951
8209099203089802099600099400099002098C00078C01078B02078A0105870003870003
8A01078901078601048400048000047E01057F01067F0106800208810108810007840208
84020886020B82010A7500046800015E01005A02005405005A15087F44267B4116723700
6E7F0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310
9870338C633E5E2B185B130A700B07930709AF0D0BAF1102BB4A0FDB9D14CFA302D4A805
DB9F14AE3D02B61300C30B08C70907CE0C0AD00908D50C09D90E0BDD0F0CDD100CE0110E
DF130DE1160FE31810E8180FEC1A0FEB180DE7180DE21C11D42015BE291ECC584CEC9589
FBB8B0FFCBC2FFD6CDFFDFD7FFE2DAFFE3DBFFDFD6FFDDD4FFD4CAFFC1B8F5A499E2877D
8E5048B9A19CF6F0EAF7F5F2F5F3F3F3F1EFF3F1EFF3F2F0FAF0EFFED5D4DF5952F33628
FB311FFB301DF83320F03423E23727C03728BC6356F3CBC0FBEEE8F7F3F0F3F3F3F2F3F3
F3F3F3F3F2F2F5F3F2EDE7E3ECE0DAEBDBD3E9D8CDEBD7CCE9D2C6D2AFA4A2645D801A19
8B060A95040B9A020B9900099401079000069101089001078C00068901058901068C0107
8C01088A01078800078601078001057E00057F01077F0207800105810206830107850108
86020B8502098303097601046700006001015F02025C020155020050090174361B7F451A
7237016F7E0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718C16976E38
704B294317094007024D0305620102890307AB0A0AB11004B6410DDE9D16D2A602D8AB05
E1A414BA4708BD1703C90D08CE0C0ACF0B0AD10B08D60C0AD90E0ADC100CDB0D0DDC0E0F
DF130EDF130CDF1209E5160CE7170DE6170CDE1B12C22015AC342AE0938AFED3CCFEE6E1
FAEDE8F8EFEAF7F0EBF7F1EFF4F0EEF5F1F0F6F3EFF9F1F0F7EEEBFAECEAFDEBE7FFE8E2
F8E0D8EDDFD9F1ECE6F4F2EFF3F2F0F3EFEEF4F0EEF0EFEDF4EFECFEE6E4DF7E76DF4437
E73F30E03E31D34536CE5346D27064EBAFA6FFE4DCFCF1EBF6F2F0F3F3F2F1F2F1F3F4F4
F1F2F1F3F3F4EBEBECE4E1E0E6DFDCE6DAD9E8D9D5E6D1C9CAA89E91564E6F121085080C
95040A9A02099F040B9D03079903099501089802099301088D01078B02088E030A8D0108
8D01088B01078C01088900088401068001067D01067801047701037700027B01047F0107
8101098202088003077B02056C00006400006101015E01005B0202550201500600692911
81441B77370122D10100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00718D178F6330593115
3B0F033805044005074802065D01057D0206A30909AD0E02B03608E49F1AD5A803D9AB04
E6AA14C3530ABE1601CC0C09CF0B0AD10A0AD00A08D70D0CD70A09DA0E0CD90C0DDC0F0F
DD120EDD110BDF130BE61710E3150DDE1812BC1A13932A20E7ADA3FADFD9F7ECE9F1EBEA
EFEDE9F2F0EEF4F0EDF4F0EEF5EFEEF6EFEEF5EFEDF6F0EEF5EFEEF6F1F1F5F1EFF4EFED
F6F0EDF8F2EFF3F0EDF3F2F0F4F4F2F2EFEEF2EFECF1EFEEF3F0EFFCF0EDF5C5BEE9978B
ED9B8EF3AEA4FDC9C1FFDDD5FFE7DFFDEEECF7F0EFF6F4F3F3F3F2F2F3F2F3F3F3F3F3F2
F1F1F0ECEDECE3E2E1E4DCDBE5DAD7E6D5D0DDC1BCC3968E88453D6F0F0B7D06078B0208
9702099A01069D02079A00049701069500079702089301098E00088C01088D01098B0108
8901088A01088C02098801078502087F0106760002710001720102730101750002790006
7C01077D01057E02048004077902047102036901016501026000015A0101550201510500
651F0C7E3C1678380124D30200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075901D9F76484C260E3A0D03
3806033601053C0206490105650408800307990505AB0C02AC2D02E39819D6A605D5A701
E2A810C75C0DBF1A02CD0C09CF0A0BD10B0BCF0909D50B0DD50A0BD90D0DDA0F0DDB100C
DB0F0DDD100CE0140EE1120CE0140DD018167E0504BA827CF9E0DBF8EEEAF4EDEAF7EAE9
F3E1DFF6D8D8E9C2C1DDAEAED3A09FD09B9CCE9B9BD7A8A8DFB5B6E6C4C3F1D7D5F4E4E4
F6ECEDF4F0EEF2F1EDF1EFEEF0EFEFF1F0EEEFEEECF4F2F3F3F1F2F4F0EEFBEFEBFDEBE6
FDEEE8FDF2ECF9F1ECF8F1F0F4F1EEF5F2F2F2F0F2F5F4F5F4F3F4F4F3F3F3F3F2F3F2F2
EDECEAE4E0DCE8DFD9E6D7D1DFC5BEC99F97AA6A64862D2A7508078105078601068C0106
9501069E02099F02099C01079801079600079502089200069101088E01088E0209890106
8600068600068802088200047C01037501027000016F0001710101740101760103790107
7900067901037901027B01047D02057C06097402046E01026901026200015A0000550101
530400671F0A75340D7E3F0327D60300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00759222B19065BFA59233140D340808
3504053601053F04084A00046C0509890508990202B10E07AC2300E5911AD5A304D3A601
E1A90FCA650FBA1801C90C07CB0A09CA0707C90506D1090BD40B0AD60A0AD70D0BD80C0A
DA0C0CDE0F0DDF100CE2120EDE150FBF15145F0606D6B8B5F9ECE8FAEBE8F0D0CCE3ABA8
DB8E8DCC6A6AB03A3BAD2A2BB02626B22527AC2325A92628A62C2DA33433A14241B06365
CA9093D4B2B3D9CECBEDE7E5F3F0F0F3F1F2EFEFEDF1EFF0F2F0F1F2F1F0F5F2F1F4F2F1
F4F3F0F4F3F2F4F4F2F4F2F3F4F3F3F3F2F3F3F2F3F3F2F3F4F3F3F1F0EFF4F2F2F6F3F2
E6DEDAE1CEC6DCBDB0C5978BAF6E64842E277C0E0C87070A8C030890030A8D01078E0205
9401059E0309A000099E010A9C010A9800079500059201079001078E01078D0106890106
8701058701058601067F01047501016F00016E01017001007401027702037801037B0004
7D01057A01037701017501017601027C04087A03077601047001026B01026501025B0101
5601005304006A230B702D0465710300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0050B717B89770D3C1B1C7B8B5321B1A31090C
3205083502083D03084801056C070A8D060CA10507B10B09AB1A01E28717D7A206D6AA04
E0AA0ECD6D11B51801C60A06C90B07CA0909CB0909D00A0AD40E0BD50A08D70D0BD70B0B
D90B0DDE0E0DE00F0BDF0F0BDD140FBB1514520202C8ACA9FDE8E2E5B7B1C06660B3302D
B81F1DC21817C81413CD110FD21311D0100ED21313D11315D21917D01C1ACD211DCF2B29
CA3A39952E31613837E3D6D4F2EDECF0EEEFEFEEECEFEDEEEEECEDF0EDEEF1F0EEF5F2F0
F5F2EFF9F2F4F5F2F1F9F2F3F6F0F1F7F1F2F8F1F2F7F1F0F8F0EFF8EEEDF9EBEDFDE7EA
DAB6B5BB827CA0524988261F8712108E0D0C900406930205930105930107910108900207
9201079A020AA1020CA1030D9E030C9901079702079302088E00068C00058D01068B0206
8800058801078301067C01037301016E01016C01016E01017201017501027A02047D0204
7F02057F02057A02037600037602067702077C040A7A05087100026D02036B0204630201
5C01015601005709006B22077731014AA70500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028DB0DB39065D5C4B3D4CBC7C8BFC13A282A2D0B0D
2E05083101063702063E00015B010484070C950104A90908A91703DF7F15D9A208D7AA04
E0AA0ED07310B11A01C40C09C50907C40708C60606CA0807D10C0AD20A08D40A0AD70B0E
DC0E11DF0F10E0100EDF100CDE140FC81717690304A46E68EEB6AABF5B52B61E19C8120F
CE0D0AD50C0CD50C0CD50C0AD60F09D70F0AD8110DDB110DDB120DE01510EB1F16F7261D
F22B22D2302C620D0BBDA6A4F3ECEAF3EEEEEFECEBECEAEBF0EFEFF1EEEFF3F0F0F5EBE8
FDE3E0FFDDE2FFDEE3FFDFE3FFDFE2FFE0E3FFD9DDFFD7DAF2C3C6E6B3B5DB9AA0BF7279
8D313688191B8C0D0C930708970507970306960305940102920103930105930208910108
9201099801099E010AA0010C9C010B9701079400069201079002078F0106910107900107
8E01078801077D01037400006F00016C00006B00006E01016E00017001017401017A0202
7C00027C0104790004760005740106750106750509780C106F060A6A0104670102610202
5E02015C02015704005B0E016D2403833C0327D50300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0028DB0BAC8559D2BFAED2CCC9CDCCCDD3CFD1463B3D24090C
2E070A3403093B03094202075301047404098A03069D0504A61503DA7915DAA209D5A802
DAA70BD47A12B11D00C00C06BF0604B70001C50608CA0709CD0708D20A0BD30B0BD50B0E
D70C0ED90D0ED90E0DDB0E0DD80F0CCE11129C0708AE3F38E47263B82016CA100BCF0A08
D20C09D40C0AD30A08D70F0AD40D06D80E0AD8110BDB120CDC140BE0160DEF2215FA291B
F72A1AEB34288F191489605BF4E8E4F2EEEBF1EEEBEFEEECF0F0EFF1EFF0F4F1F0FFEEEC
D19594D57274DE7276E17377E07375E07273D9686AC15356A23A3D9F3234A42C2FA12123
961211990D0A9E0B089D06049C04029A0403960202950303910102900104940409900107
9200069901089F030B9C010A9A020A960006930004920106920107940208940206910105
8E02068702067B01037100006F01016D01016E01016F01016E01016D0101710201770202
7902027A0204790105770106730004700003680305C1666AA549506A060B6201035B0000
5C01015B0201580201530400621302762A0145A00100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007A9A35CBB2A0D2C9C6CFCDD1CECFD3D4D3D65D5657250D10
2C08093503093C02064703085402086901077E0206990809A01303D37215DCA30CD4A804
D6A508D37D11AE1D01C10C07C50A08BF0405C70609CB0709CF080AD1090BD10B0ACF0A09
D30C0BD00A0AC90404CA0303CD0606CB0706BF0806BE1712D22C22C71009CF0C07D10A08
D10B06D10C07D20F07D41107D31005D31307D21608D31807D31C08D51F0DE2301CE63624
E53B28E04636AE4035815249EDDFD8F1EDEAEFEEEAF1F0EEEFEFEDF0EEEFF3F0EFFBEDEB
EBB8B3E18A84E78881E7857FE8867FE68379E47E77D87570CD6D68C96760C65E57BE544A
A73C2C9E2D19A028149D210E981907941404900E01900C008F09018D06018E0403910205
9301069800079D030A9801079601059803079702069802079802089501079000048F0104
8B01048001037801027100007002006D01016D01006F01006E01016C01016D0101720101
7401017601027801037A01077500056E010467020591373EB05C64AF565D7115185C0303
5901005802025301025101005B0800701E033C940000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004DAF119D7551D3C2BCCFCCCFCDCCD1CFD0D3D4D4D77C76771D0A0D
2503053502084003074501075201066D040B7D0206930406990C01C66314DCA00FD3A603
D7A407D38111AF2001C20B05C80909C7050AC70408CA070ACF090DCF090CCD0909CD0A0A
CA0807C50303C30201C40101C60302CD0707CE0B09C80806C80A05CB0B06CB0C03CD1005
CB1203C71505C51905C41F08C2230AC42D13C7371CCC4529D35539DA654CF38C78F79C8C
FAA798FCB3A5F9C3B9EDD0C7EFE5DDEFEAE7EFEEEAF0EEECEDECEAF1F0EFF3F1EFF4EFEC
FAEBE5FFEAE2FFE8E0FDE3DDFEE5DDFEE5DBFFE4DCFFE6DFFFE3DBFFE2D9FFE1D7FFDBCF
F1C3B1E3AC97E1A489DA9A7CD48F71C87E62C17257B55F46AA4D35A4402A9D2F1F8D0F0A
9105089501079B0309990106960105970308980208980208970106950106930208900008
8902077B01027501017201006D00006A01006B00006E01006F01016C00016C01016F0001
7101007401027601027801047501057001056C020667070BA851589B464F9F4B528A3638
5803025701035001015001015D07016E1604585A0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0063720B8A6049D8C9C7D0CED1CCCDD1CDCFD1D3D3D69F9A9C251114
2C080D3604093B00054301074F010570070F7F020696060AA11104C35714DC9D10D2A202
D6A206D68513B02401BF0C03C60908C6060DC3050AC3060BC6070BC7070AC60506C60506
C60405C30101C20201C40203C60303D10B0DD30F0FCB0A09BE0A05BD1608BB1F0BBF2E15
C33D21CA4F35D26548DA7959E38D6EEA9F82EFAC92F6BAA2F8C4AFFBCFBFFFE2D7FCE6DF
FAE8E2F7E7E2F6EBE5F4EBE6F2EDE9F1EFECEFEEECF2EEEEEDEBE9EFECECF0EFEEF1EFEF
F1F0EFF1EEEEF4F1F0F2EFEFF3F1EFF2F0EEF2EFEEF4F0EEF5F1EEF4F0EEF2EFEBF2EDE8
EFE3DDE9D7CDEBD7C7EAD6C4EAD3C0EBCFBEE9CBB9E9C7B4E6BEAAE7B7A3E4A693A6493E
840707920308980209970209930107920108920007920007950106960107950108910009
8601067700017200007402016E00006900006D01007101007101007001016F01016F0101
7001007101017201017200027001026E01026C0104700C0FC3676D711A23A858619B4E53
7523235C05065100024B0101570400690F03711E0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00742C057C4C3FDACBCAC9CACBCBCCD0D0D2D6D3D4D8BFBCBF2C1B1F
2A080C3302063B02084303084C01046502077C02068D0305A41403C25112DE9C13D2A103
D5A107D68512AC2300B90A01C10604C3060BB60306AB0003B50407BD0305C00304C20304
C10203C20101C30202C40203C90506D30D0FCF0A0DC0090B920402B34733E28769ECA184
EFB299F2BFAAF1C8B5F1CFBBEFD4C1EDD5C6EBD8CDEADBD2EEE4DCF5ECE7F2EDE9F0EDEB
EFECEBEBE9E7EFECEAF1EDECEEEDEAEFEDEEEFEEECEFEBECF0ECEBF2EEEFF3F1F2F0EEF0
F0F0F0F1EFF2F1F0F2EFEEF1F3F2F3F0F0F0F1F0F1F1F1F1F0EFEFF0EFEFF0EDEDEAE7E7
ECE6E7E5DCDAE5DAD6E3D8D2E2D7D1E0D6D0DFD5CFDFD4CCE1D5CCE4D4CAECD0C6B3746B
7B0D0C8B020794040A8E01068B01078C0009910108920008950108980208970208930109
8601067700017200007300007101016D00006E01007002016F0201700101720201710101
7101007101006F00016F01026D01006D01026A02047310118C3034AD5760A5576074292E
994A4C7320235305084700014F0201640D056C18013A950000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0053B11A6C20096C332DD7C2C0A7A5A4CCCCCFD2D2D7D3D3D8CFCDD1372C2F
27090A3104083802074303084E010662030877050A8300029A0C00B7450EDE9C15D1A203
D5A107D88511AB2200BA0903C00604C20609B80407AA0103B00003BA0103BF0205C00106
BE0102C10103C30203C60405CA0808CF0B0CCD090CBA0A0C7202027D4134DCB69DEED4C1
E8D6CAE5D6CEE3D8D0E3D8D0E3D9D0E5DAD4EAE2DEEEE8E6F0EBE9F2EDEDF3EFEDF3EDEB
F2EAE9F3E8E7F2E5E4F7E9E9EFE9EBEDEAEAEEEBE9F2EEEFF2EFEFF1EDEEF2F0F1F1EFF1
F2F0F1F6EFF0FBEBEEFCEAEEFBE8ECFAE7EAFAE8EBF8E7EAF7E7E9F8E8E9F4E4E6F0E1E3
EBDCDDE4D3D4E4D2CFE5D3CDE4D4CDE3D5CDE1D6CFE2D7D0E1D9D2E2D8D4ECDAD5CA9994
7E1E1C87090B8C0B0C961A1B8D121586070D8B030A910208940108950108960208930308
8601067B00027702027501027302016F00016E00016D01006A00006D0001700001720101
7301017302027302027001026D01016A00016601029035359F4C4FBA6F75AB656E9B565C
A15A5E883B426E21284A02074A01015E0B06671301555B0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF002EE012B27A54621B0B62201AAF8D89918583CFCECFD1D1D6D2D1D7D6D6D84F4748
23080A2F050B3502084002074E04095901056C0306860708980D04A93809E09A16D2A104
D39F05D98612AA2100BC0B05C10607C5060CC3070DBB0409B80105BB0104C10408C10206
BF0303C00104C20405C80707CC0A08D10B0CD10B0DC10B0E8407085B2420D4B6A8E8D6CC
E4D8D2E5D8D3E5D7D0EBDAD0EAD6CDEDD6CEF4DCD8F7DDDEFCDFE1FDDCDFFDDADAFFDBDC
FCCBCCFFCDCFFCBFC1E3A3A6875E62BCAFAFEEE9E6F1EEEEF1EFF1F0ECEDF0EEEFF2F0F1
F2EFEEFAE5E7E8ADB3EC9FA5E79298D3828AD0838DCE848DD78D94D38B92D28E96CE9197
CE959AD0979CCE9696C48F87C69489CA9C91CFA69DD4B2ACDABFBBE1C7C7E5C9C9E1B0AE
8A2F2D7F0D0BCB605CE88280C35D5DCB62658812168A030B9102099101079301068E0105
8300037B00027701017601017301017000016F01016D01006D01016E0101700201730201
7301027401027301017001016E00026B0002670103721A1DC1777AA5626764232BCA8A92
9C58608A3F498A414B530F1447010158060569110570200000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0059C229AC80665D1C115D130D91625D8E7C7ACDCACDD1D3D6D1D1D5D5D5D7696367
21090C2C040B3302083C01074703075202076002047601038E0801AA380ADE9715D3A104
D4A005D98912A92300BB0B04C20709C6050BC3040BC2050CBB0106BA0105BE0206C00207
BF0205C30207C40407CB090BD00B0DD70C0FD90F10D00F0FAF1111690907E0AAA2F9D5D0
EFCEC8E6BDB6E6B4A8E4A99DE5A096E79B94EF9C98F59DA0F18F92E98081E47776E37172
E06162E35A5CDD5151D14C4A903432886663F1E7E3EFECECEEEEF0F1EDEEEFEDEEF0EEF0
F1EEEBFEE4E5CA7A7BC64D4FC63C3DB7282CAA1D25AE2027B4252BA91F27A2252D952B30
8C2E319033368B2D2C892C2481251A83291D822D22803229964C4AA55E61A86364AF6262
9732318C201EDC7B7AC56A69953A3CC96F72C15C637F040C8E040C8D00088F01088C0207
8301047A01017701017701017501017302027001016E01016D00006F0101700101700101
7201017201017100016F00016F01026D0102690204620408600E14934C539E5A6397545D
8A454E9F5860954E585B161C4801025704046910086E1C0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE8351A07C6761241A60120D87524FB5A1A1D7D2D7CFD2D6D0D2D6D2D3D6878286
200B112B060C3303083901073F01064C01085C03076D00018C0903A63509E09A18D6A404
D6A206DF9118AA2700BB0C04C40809C6050AC5070BC10308BB0105B90005BC0104C00207
C40408C6040AC9060ACC070BD20A0DD70C0EDB0F0EDA120FD31915B91D1AE87471F99997
E68580C55F55BB4F41B64234B63D31B83C33C1423ACB4A45D04F49D55751DA645DE16A65
DD524FD33733D5463EE1695FD38177C8A59EF2E6E2F2EDECF1EFF1F2EEEFF1F0EFF2F2F3
EFEFEEF8EAE8F5C4BFEA9D96E17A72C14039B61E1DBE1717BD191AA81A1B90211F9F4B45
C27F78DA9993DC958DD58C80CA7C6FBB695CAE5A4DA24A3F9C41399335308624217E0F10
870E10901F21CC6C6EC46E6FD986899B464DC3656E8B19228A030C8C01088C0208890107
8401057D01037601017401007401017201007001016F02026E02026E01016E01016F0101
7302037401037301037101017001026E01016A01016401035F020658070C6C2129C07883
752E38BF7982AC6570671F274D02045905046910096D18003E970000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC875C997B696C332B62140F814A4CDBC9CCD3D1D7CDD2D5D0D2D6D2D4D8AAA8AB
1C0E1225050A2B01043501063C01074B01085A0204760405940E07A02F05E19C1CD6A505
D7A405E0931AA82700BB0C04C10506C7060BC8080AC4050ABD0104BC0106C20308C9070B
CA080CCB080DC90709D00A0CD40C0EDA0E0EDC120DDE1810D6180DDB2319D82924CF2D2C
C5302BB02C22A93426BC5140CE6C5CE78A7FF4A39AFCB4AAFFC1B6FFCBC3FFD6CDFFD8D1
F2A9A59B2E2A9B4840FFD7CBFFE7DEF6E7E2F4EFEAF0EEEBF1EFF0F5F0F2EFEEECEEEEEF
EFEFEFEEECEAF4E8E4FCE9E2FFE1DAF8BEB5BF554FAC1D1BA21B1B6B110CB68178F3D1C8
F7E2DAFAE7E0F5E0D9FAE1D8F4D7CEFBDBD2F7D2CAF5CAC1EBBAB3ECB4ACDB948C98312F
911113870B0FD56E71C97277BA6A6ECE7A82C96B74901D2689020B8F010A8E0108890006
8501067D00037600017300007201017201016F00016D00016A00016800016801006C0101
6F01017201027501047401047001026C01016901026501026402045F02065B050D73202B
74242F6C1D28994F5A6F232C5A070B6006066A0E076E15003D930000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B918A0805DA88F817140395F14117E464BDFCDD3D0CFD4CDD1D5D0D1D6CFD3D6BABABC
1B14161901042501043203083D06094902086106097A0608940E07A02D03E29B1CD7A407
D6A505E0961AA92801BD0E07C00607C5050AC50509C5060BC30509C3040ACA090ECC090D
C90708CA070ACB0806D20C09D70D0CDA0E0EDD150FDF2016F24636E43123D42016BE1F17
A2271FCE796EEFB5A9FBCEC2FCDCD2FDE1DBFAE5E1FAE9E4F8ECE5F8EDE9F5ECE9FAEAE9
FBD9D69F56545C2A21DFCCBEF5EEE5F8F4F0F3F2EEF2F1F1F2F1F1EFECEFEEECEDF0EEEF
EFEFEFEEEDEDEEEDEBF2EEECF4EDEAFBE9E4F8C5C1AA45437C1B19633530E9D8D1EDE4DE
EAE7E4EAE9E7ECEBE8F0EDEBEEEBE9EDE9E7E8E2E1F1EAE8EDE5E2EEE1DCF9DAD6BA7372
8A1417920A10981C23D87179CD717AD5767FC45963870A128D02099101089201098E0107
8400047D00037901027601017401017401017201006E00006B0001690101670000690000
6C01017001037301037301027001016B0002680103640002620104610105630109660610
6707116509137B263077242D650A0F6807096C0C087115033C910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC226A98E719D8B818059555A1817652C34D8C3CACCCBD0CBCED3CED2D7CCD1D4B5B8BA
201C1D0F00011700002701063402054501065600046D01048B0C079C2D03E39A1DD9A607
D5A605DC9315AB2C00BB0C04BE0506C30709C5070AC6070DC40409C7050ACB080DCE0A0E
CD090BCD0809D30C0CD60E0BD90E0CDA100EDD1510DF1F15F34638D02318AF18108A241A
CF9489F2D3CCF8EBE5F2EAE6EFEBE7EEECEAF0EDECEEECEBEEEEEBEEEBEBF3EFEEF6EFED
F8E0DCAE746D531E13BDA391E8DBCEF1EBE6F3F1F0F1F0F2F3F2F3F6F0F1F9ECEDF8E2E6
EBDDDFEEE9EAEDECEAF0ECEBF0EDEBF0EBE8FDE3E0CC8A886C21215B3835E6DED7EBE6E3
E9E9E8E8E9E8EBEBEBECECEDEBEBEBEAEAEBE5E5E6E7E7E7E9E9E8EAE9E8F2E5E4DDADAE
86202394080D97080F8E0A14991E2B9D242F8E0E168C030A900107930208940208910209
8701067E01037900017700017701017501017100016E00026C00026A01016B02016A0101
6B01026C01016E01017001016F01016D020468010561010460000661010865010967010A
6C040C6C070E7D2027832A3166080D660507680A086C11033A8F0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC82EB7A08B92847F9C7E7B551A1C5A1F26C9ADB3C5C2C7CCCED3CBD1D4C7CBCFB4B6B6
322F2E0900000E00002001052F020541010755050A6503077707048E2803E19B21D8A506
D5A505DE9515AB2D00BC0D04C20807C30709C6080BC6060BC9080CCC080CCF0B0ED10A0F
D0090CD20A0DD40A0CD80E0FD70C0DD90F0DDA130EDD160ED91812C71B177506059F6E65
EFDAD1F1E8E4EFEAEAEDEBECEEEEEDEEEEEDECECEBEDEBECEEEEEDEEEBECF0EEECF5EEEB
FBE8E3D19D91612315886353E8D5C5E8DDD7E5E1E0E6E3E3E7E4E3F5E9E9E5BCBFC57980
85494DCCB7B8EEE9E8EDEBEBEAEAEAEBE8E9F3E5E5EDC0BF7E3B3B461818CCBFBBE8E4E0
E6E6E5EBEBECEBEBEBE9EAEAE9EAEAEAE9EAE6E5E5EBEAEBE8E8E7EBEAE9F0E7E7EDCBCA
9C46449710109E05099C040B99040D94030C9202089201079300089301099101098E0108
8801068001047B01027A01027800017903037201026D01016D01016E01016E02026B0102
6900016900016B00016C00017001026E01036600036101055D00055C00046301076B030A
6C040B6D050C700D1274121869090D630407620606680F0277270000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
88A943B29C8CA296948B706F541A1C521317BE9CA1C8C2C7C9CBD0C8CDD1C1C7C7B5B5B4
4A43440C01030F00002101042F02073B01074801055A02076903018A2901DC961ED6A306
D4A406DF9618AA2B00BC0E05C00705C6080BC30709C8070ACA0A0ACC090ACC0A0BCE0A0B
CC0707D1090AD40B0CD80E0FD80E0CD80E0CDB120EDB110BD9120EBE1616570101AA9089
F2E8E1EEEBE8EDEBECEDEBECEEEEEEEBEAEAEAEAEAEDEDEDF0EBECF1E6E6F3E1E0F9E1E0
FCDAD3F8BAAC7E3325572A1FE4CEBDE8DBD1E7E2DFE8E5E4E9E7E3F9EAE9F0BEBEC24D50
A33333916262F1E5E3EDEAE9EBEBECEAE9EBF0E8E9FADCDC9B5A59651E206E4A4BE0D6D5
EAE9E7EBEAEAEAEAEBEBECECEDEDEDEAE9E9E6E4E5EAE5E4E0D8D7E8DDDDEDDEDEF0D2CF
B067628C0E0BA1070AA30308A202099C00079A02099702089401079202088E01088C0106
8901048401037D00017C01017D01027A01027601017201017101017001016E00016D0001
6C01016C01016D01027102037503057202056A01046401055E01045C00036501076A0207
6802076903086D070C6904096B070C68090B610605630D0074260100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78F5DB29E929B929199818056211F511011A47E81CFC6CBC1C3C8C7CBCFB6BCBBB1B1B0
655E600B02031201012401053001073D0108480207590207720803842100DB981FD4A205
D5A507DF9519A92900B90C03C00705C50809C60A0AC70808C70807CB090ACD0B0BCF0A0B
CD0A08D20B0AD40E0BD70E0ED90F0CD90E0DDC0F0EDC100DD8110DC51818650403836260
E9DFDBF0EDEBEDEDEDEEEDEDEEEEEEEDEBECEBEBEAEFEDEEE9DDDDE3C0BFEEAFADF3A2A3
ED8F8DE7786FA93930500E06C3AB9AE7DACBEBE6E0F3F2F1F7F5F3F0E7E5FED7D5CA5A5A
BB3935702E2BEFDDD9F1EAE8EBEAE9EBEAEBEDE9E9F7E3E3CA8E8D81222368191C8B6669
E8DDDEECEBEBECECEDE9E9E9EBEBEAE9E9E9E8E6E5DAD0CED1B5B4D2A5A8D29EA0DEA5A5
E5928F981A18A20609A9040BA70309A101079B0208980106B41C20C22D3195060B8B0003
8B01048702057F00017E01027F02027C0102790101760201740101730101710101700101
7001017001016F01017000027200026F01026C01056701046001045F0105630105650105
64020566020768050965010769050B6B090C650908631205742A0700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9363BBA79E928A89AE9D9B5A2E2B511011885B61D0C2C9C0C0C5C4C7CBAEB3B3B3B2B3
7D7A7C09010416010329050C34020A40030B4601075F030983110D801A00DB9820D6A406
D6A607DF9319A92800BB0C03C10906C50807C50907C70908C80809C90708CA0607CF090B
CF0B0BD00A09D30D0AD60E0ED70D0CD80D0DDA0E0DDC110FDB120ED41816A414145A0D10
BB9E9EDFD8D7F0F0F0EFEFEFEEEFEEEEEDEDEEEEEDEFECECEEDFDEDDAFADBC605DC94341
CD2F2DD02821C42B26680C08947567E3D5C6E9E4DCF2F2F1F0F0EFF3F0EDFEE8E7C97776
AE32306D1D1BCAB1ADF2E8E6EFEBE9EAE9E8ECE9EAF3E5E5E8B8B6932B2B9B1E2172151B
8F6268E3D7D9ECEBEBEAEAE8E9E9E7EBEBEAE9E9E7EADFDCCCA5A494484990292D9E2E31
B4383CA31315A7060AAA0308A80208A10006980105980104B21418C22327B41E248E0105
8E01078C01068501027E01007C00007B00017A0002790202780202730000710000710100
7201017101017202017101017101037001056D01056700046000035C00045E0005610106
61010662010566040866020867030A69060B650A0A6E21157E381400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9063B9A69EA69E9E8D807D734A49500E116E3A43D2BCC6C3C1C7BFC3C7AAACAFB0AFB0
928F8F0D050717020426030B30020B3801083F0007550209760D0B821D00D8951ED6A507
D5A605DA8F16A82600BA0B02C10705C70908C50807C80808C70607CC0A0BCD090ACF080B
D10B0BD00A09D20C09D60E0ED60D0CD90E0DD90F0CDB110DDE130DDE1410D41B19A41417
69161BAA888EE5DDE0EEEDEEECEEEEEDEFEEEDEDEDEDEBECF2EBE8FCE3DFF9BEB8D76E65
C53125D7261AD0231C96211D643930DCCCBEE9E3DAEFEFEEEDEDEDEEEBEBF8E8E6D89A9A
A332308729259F7A77F4E7E2F1EBE9EDEAEAEDEAEBEFE7E6F8D4D2A84746AD1C1CAD1A20
7E161E86565CDDD1D2E8E6E5E7E6E5EBEBEAE8E8E7ECE8E5F3DBD7D89C989A35319F1718
A90E13AB080DAA0408AB0408A90208A6020AA10309980305B11E23A8161D990A118E0209
9001089202068C01038100017C01017A0102770001760000770101760102730000720000
7101007000007101017101027201047301057002066701035E00025A01035B01035F0106
63030961020664030765010767030A66050B5F08096D2218CBA99C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE976BB6A89F9A9898968D8C8866664E0F13582028CAB1BBC0BDC3B8BBBFA9AEB0AFB0AE
A2A29F140D0C19040624040A2E030C38020B40010A4700075F0604761901D0901BD6A708
D6A807DA9017A92700BC0D05C20806C60809C40606C8060AC80708CB090ACA0607CE070A
CF090AD10A0AD20B09D60D0DD60D0BDB0F0EDB110DDF130EDE120CE2120EE11612D91A1A
B71E2175121B9A6A72DFD0D7E7E5E8EDEFEEEAECEBEDEDEDECEBEBEEEAE6F7E7E1F8CDC2
DF8676C53B2BCF2A20AC221E53140DD1B9AEE8DFD7F2EFEDF0EDEDF0EDEEF5EAEAEDC4C4
B05B58A5524D9A726DEFDDDAF0E9E7EEEBEBEFEDEFECE6E7FAE0DEC0706CAC1E1BBF1618
B3191E84191F79434AD5C4C7E6E3E2E8E7E6EAEAEAE9E9E8EBE6E3F5DFD9DDA59EA43C38
A41312AE0A0DAE0509AB0307AA0207A80109A50209AB151BCC4C50D65F6382080A850004
8F01069200059001048701037D0001790001780101780102780102770201730001730101
7201007101007000007101027201037101036D01036802035E0101590101590103580003
5B01065D01066102076101056605096505095C0507641B11C6A59800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BE9B6FBAAEA58C8D8DA5A0A27C6363470F13451014B69BA2BDB8BEB7BABEAFB5B4AFB1AF
B4B7B32723211C0A0C26050C2D01093E040E46040D49020A5905046B1600D0911FD5A609
D4A506D98D16A52300B60701C20806C50707CA0A0ACB090BCB090ACE090BCD090ACE080B
D10B0CD20A0CD40C0DD60C0DD80D0DDD1010DC110CDD110CE0140DE2120EE41310E51512
DF1A18CA212492171E77343DC1A6ABE0DCDDEDEDECEAEBECE9EBEAEAEAEAEEEDEBF5E9E3
F3CEC2E89686C13D30BB2A24610E08A98C84EBE0D9F1ECEAEFECEDECE9EAEFEAEBF7E6E6
F9D5D0FBD5D0F3DCD7F3E6E5F2ECECEDEAEDEDEBEDE8E4E5F5E3E2E4A4A2A52422BD1211
BF1111B1161A881B2169393AC9BDBAE8E4E0EAE7E8E8E6E7E8E7E7EBE6E4F3DEDBDCA39E
A0342EA30F0FA60205AE0508AE0508A80106A40107A1070DBE363DC5494E9D1B1E910409
9201069301069401078E01058400037A00017801017900017A0200750100730001740102
7201017101007202017301017301037001036B01026802035F0102590003560003550004
5500035900055D02075E00056102066105075E070763180FC5A29600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB986BBCAFA799999B8A87889E8A8A4314163F0B0BA4878AB9B3B5B8BABEBEC3C5C3C8C9
CBCFCE3D3B3D1E0B0F28070E2D02093F060D430309480108610B09691300CC8C1DD4A309
D5A307D98A18A62000B50802C30B08C40705CA0A09CA0808CC0909D00A0CC70305CD090A
D00B0CD10A0BD30B0CD60B0ED80C0DDC0E0FDA0F0BDB110BDE130CE21310E41412E71712
E81812E51B16D7201EAD21236C1B1F967A7AE1D9D7EBE8E7EBEAE9EAE9E9E9E8E7EDEAE8
EFE2DCF4CEC3DF877AB632297D16107C5552EBDEDBEDEAE7EBE9EAEBEAEBECECEEEEECEB
F0E9E6F1E9E6EFEBE8ECE8E9EEEBECEBE9EBECEBECEBE8E9F2E5E5F1C2C3A83939B61715
BA1410AF18149A252262231E786059DCD2CDEBE5E4E8E5E7E6E5E6E6E5E6EEE6E7F1D8D6
D5928E961F1BA50C0BAA0507AF070AAB0409A70308A4020A9E040D99050C9C060B980206
9200059502079701089602088D01068201037C00017C01017A0100760101740101760101
7301017101007301017401017501037301046E0104680203610103590103560103550102
5300025801045C01065F000563030863050860070767180FC9A59900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BC9667B5A89F9897968E8A8AA08F8F4B1F1F41090A8E6B6DBCB4B5B9BBBFC1C6C9C6CDD0
D2D7D95152551B0B1124050C2D060A38060A3F0307460004610A07691301C68619D29F08
D3A008D78515AA1F00BB0A05C40907C80908C80909CA0A09CD0909CF090ACE0909CD0809
CF0A0BD10B0CD10B0BD60C0DD90E0EDB0E0FDA0F0CDA110CDA120EDC1211DC120FE21610
E91A11E61710E11E15CE271FA12E2863312BBFAEA9E4DDDAEDEAE9EAE7E7E9E8E6EAE9E8
EBE6E4F4E2DDFAC1B6BF4941A0241F5B2220E7D6D3EDE8E6EAEAE8EBEBECECEDEDE7E5E5
F2EAEAF2E6E6F0E7E9EBE7E8EBEBEAECEBEBEDECEBEBE9EAEEE7E7F6D5D5B8615FA5201C
9A1A12811D14AA6358C3998FDCC7C0E6DCD7EAE5E4E9E6E9E5E4E6E8E7E8E7E4E5EDE2E2
EDC8C6AE57529B1511A30508A60308A60308A60107A40107A10107A00108A00108990106
9100049301069802089902089301068B01048300037D0100790001760101760000790202
7702027301007301017501027702057401046E01036701026100025B0004570103550103
5601045801045D030761020663030665040863070966160ECFAA9E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99262C2B5A99897939B97968F7F7E552928480B0B794F51C1B6B7BFBFC4C9CED1CDD1D5
D3D8DB7072741B0F12280B0F2B04083505093F02084F050A5E0908641100CB8B1ED4A10A
D4A008D68315AA1E02BD0B07C30606C9080CC90B0CCA0A0ACE0C0BD00B0CD10B0BD0090B
D10B0CD20B0DD30C0DD4090AD80E0DD80D0DD90F0FDA1312D61313D20D0DD00B06DE140D
E21912DA1C15C72519B03327C27165DCB6AFE9DCD6EBE4E1ECE9E8EDEAEAEBEAE8EAE7E7
EEE7E5F3E0DEFDC5C1C84E49BC2C275C0C0BBCA3A0EBE2DDEAE9E6EAEAEAE9E9E8E7E3E1
EAD5D5D1A5A9A6777C7D6164D6CBC9EFECE9EEECEBECEAEAE9E6E4F1DCD9CD8E8B862522
530602B4897EF1D7CDEFDFD9EBE1DEEAE5E3E7E5E5E6E5E6E5E4E7E3E1E3E4E1E4E5DDE0
EDD4D3BF7D778A120F9905089C02069F0107A10108A000079F01059E01079B0106960005
9000048F01049300059600069300068F01068801038100017C00027A01037A0103790103
7600017300017300017400037401057301046E01036900026401025E0103580004540004
5200045100045300055A01046103066303085F0407621107AE756000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B99161C3B5A99F9D99858281A99C9C5E37364C0E0D64363AC7B8BBC6C7CCCCD0D4CFD3D8
D5DADE86878B1B1112280C0F2C050A34040B40030A53040B5705045B0F00CD8F1FD6A209
D7A30AD57F15AD1F01BF0C08C30607C9080CC7090BC80708CD0B0BCE0A0BD10B0CD20B0C
CD0707D20A0CD40C0ED60C0CD60C0CD70D0DD90E11D40D10D00D0ED00D0BD20C08DA140F
D51B17A81612A14036E9B1A6F8D8D1F1E5E1EFECE9EAE8E6EAEAE8E8E6E7EBE7E5EDE4E1
F2DBD9F7C7C7F09191CE3533CD28237A100F8A6763E8DBD6EEE9E6ECEBEAEEEDEBF1EAE9
F0D1D09C4B4F9C393D561415A88886EFE5E2EBE7E8E8E7E7E9E7E5F0E3DFE0B1AF7B3130
420F0BD9C8C0EBE3DDEBE5E3E7E5E5E7E6E7E4E4E5E2E2E3E1DFE0E1DCDCE3DCDCE4D5D5
DDBEBBB8726C840D0B9303059401059600059901079C0209990006990106980107960107
9100058F01059101049401059301059101058D02058601038001047A0002780102780102
7500007501027501027501047300047300047001016D0203660102610104590104560105
5400055001054F00055401055A01045D03065A0101620D0384351400FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BB9060C0B1A69E9B98908D8DA2989A6A4648490E0E522226D2C1C5C9CAD0CDD3D8D2D8DE
D5DADE9C9CA11E1415280B0E2F080D35050C3E020A580A125B07085D1200CE9120D6A409
D7A109CD7411AE1C00BF0C06C40606C8090BC8070AC9060ACD0A0BCE090BD10B0CCF080A
CE0808D20A0BD30B0CD60C0ED50B0BD80D0ED70C0ED90F10D8110FD9110DDE1510D61411
B31413630C0BD9B0A8F3E2DBF0E6E5EDEAEAE8E8E8EAE8E8E8E8E6E6E3E3E3D6D5ECCAC8
F2ADADE07174D13839E02624DB231F9D19175E2B29E3D4CEEFEAE7EDEBEBEFEEECF2EBEB
FDE0DFBE6668AC3132791B1A7F4D4BEEE1DEEAE5E4E9E7E8ECEAEAF0E7E6F5D2D3995353
4B0F0CAA9590E5E2DEE7E6E6E8E7E7E7E6E8E5E4E5E3E0E1E1DBDADBCECBCEB6B0C79E97
BF7D7696312C8E0807950204950104930002950004950106940105940106930007930108
9201069001059001039301049503069001048A01048601058001047A0002780102770102
7500017300007400017601037702057501047201026C01026401025D01025A0103570104
5300044E01044C0004500106550004570103570101650D0286311100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
BA905DC6B7AC969593A4A1A5897F84856769430D0D48161BC7B2B7CACAD1CFD7DDCDD6DD
D6DCE2B0B0B51F181A22080B2D060B33030B3700074600085806095D1100D09320D7A60A
DAA40DC76D11AD1900C00B05C50706C50709C70509C90609CC0808D10B0CCF090BCF070A
CF090AD40C0ED40C0CD60B0ED40A0AD80C0FD70D0DD90D0EDB0E0DDF120FE1140FD71613
A10F0E4A1313D8C7C1EFE8E6EBE8E8EDE9EAE9E7E8E9E8E6E8E7E5EBE6E3E4D3D0D19B9A
B94C4BD03130E42722EA211CE5221CC02323560D0ACAB7B2EAE6E2EEEBEAEDECEAF1ECEB
FAE5E4D08585A82E2E96292862211FE3D1CEEEEAE8EBEAEAEBEAEAECE7E9F7DDDFBD7876
7F27265C2827CFC1C1E8E7E5E5E5E5E7E4E7E1DDE1E1DCDDE2D8D8CBB5B0AD8074913F34
8B1C158E0907950303990102990103970203940003920004920005910006910108900108
8F01078F01059001049000039001048C01048600038200028100028A0A0C840C0D730101
7402027401027401037300027801057902067501046C01036300025D00015A0002590003
5400034E01044900024D0004580207580206550001620A028A341600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B78D59C3B5A8A5A6A589898E9E989C836B6B411211420D11B79EA4CCCAD0D0D7DBCCD5DA
D7DCE2BFC1C5201D1F240C102E070D33040C33010640010858090B651700D49722D7A608
DCA40FC56712AD1701C10C07C40607C60609C80508CA0608CB0808CE0A0BCE070BCE070A
D00A0BD20C0BCD0705D40B0AD50C0BDA0E10D80E0DDA0E0EDD0E0EE1100EE41412DD1512
B71613520203A7908FE9E2E2ECE9EAECE8E9E8E6E7EBE8E8E6E5E3EAE7E4EFE3E1F1CBC9
E28E88CE473DDD2E20E8241AE7221AD428256B0B0A9D837EEAE4DFEEEAE8EBEAE8EEE9E7
F5E6E3E7AFAC9E352EA3352E6C221ABFA79FECE6E2EAE9E8EBEBEBEAE7E8F5E4E4E8ADAB
9B302E7B1819733E42CDBBBDE6DFE0E3DEDEDFD9DCDDD8DAE0D8D7E1D0CBCDA295A04D3E
8D12099304029701019902039701029501029201029101039201069302089201098F0009
8E01088E00059101048F01048F0106890004840003890002980407B11E21D14B4EBE4647
7A0A097101037001027101007A0304870B0F7600036C00026700026201035E00035B0104
5401034D01014900014D0003550207590208550002610801903A1F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B58D57C3B7AAA2A5A4909497979697806F6F3E14143D080C987D83D2CFD5D0D6DAD2D9DF
D5DCE0C6CACE282628220B102C060E36050F3502083C0109570A0B691C00D79924D8A90A
DCA410C06010AF1601C10A08C30708C60609C9070AC90608CB0909CD090BCE090CCE080A
D20C0CD20C0AD10C07D50E0AD80E0CDA0E0EDB110EDC100CDF120EE31210E31310DF1310
D218159710115F1A1EC4ABB0E7E0E3EBE8EAE7E5E6E8E6E7E7E5E5E8E7E6EAE6E5F0E5E2
FCDDD7F2AFA4D66152D73226E1251BD524208B16176F4743EADDD9EDE8E6EDEAE9EDEAE8
F1E8E6F2D2CCC17F73C07468AA7164BFA69CECE4DEEBE8E7E7E8E8EBEBEBF3E9E9F8CCCB
A73F3AA71E1D86161B74353CC7ADB1DFD5D5DFD8D8DBD6D7DBD7D7E0D6D5E6D0CAD6A598
A850428C0F079404029601029501029201028F00018E000290010390000691000891000A
9202099101069101058E01048D01068802078400039A0207AD050CAF060BA5080AAB1A1E
AA272C7300017000027201027A02038E11157601046E00036B0204670103630204600307
5602054F01034A01024B00035100065600075A01026408018F361D00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18954CABFB2A1A6A59EA4A6808181A193934824263B090B765A5DD4CED4CCD0D5CDD4DA
D5DDE0CCD1D52A2A2D1E090F28030B35030F37040C3A01074B0506621800D29823D4A608
DCA513BD590DAF1400BF0907C4070AC30408C50608C60506C80708CB0709CD090AD00A0A
D00C0AD10B0AD10C08D40D0AD70D0CD80C0CDB0F0CDD100BDB100AD80B08DF110EE21212
DD1212D01919A014196B1720AD868EE0D3D9E7E3E6EAE8E9E9E9E9E9E7E8E9E9E7ECEAEA
EFEAE7F7E3E0FBC6BDDE736ACE2F27CC1E1BA21D1E4F1717D9CBC6ECE6E3ECEBE9ECEBE9
EEEAE7EDE2DEF6DED9F9DDD7F7E0D9EDE1D9ECE6E2ECEAEAEDECEDEAE9EAEDE6E6F4D4D3
BD625FB21B19B4151A8D131A651F25AD9194D7CDCCDCD8D6D8D5D5DCD8D8DED5D4E7D3CE
D7AB9DA852458D120B9303039100029000039001048E01038E01048F0106910108910108
9301099302089102058C00038802047F02048000029D0408B10208B40406AE0203A90307
9F050A8401037400027602057D07098F161A7300046E01056C01046701026201025C0003
5501044F00034900024800024F01055502055A00026407018A2E1500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B18651CFC2B5B6BABA8B9394999B9C8C83834D2F2E3C0A0A694B4BD8D1D5D3D7DBCAD1D7
D5DCE0D5DADD393B3F1C0A102A040E33020C3702093D0105520706641A00CF9825D1A40A
DAA114B8500AB01300BC0604C4070BC30409C40608C5070AC80708CD090BCF0B0CD00B0A
CF0C0AD10C0BCF0A08D20A0BD40B0CD70C0CDB0F0DDD100BDA0F09DD120CDF120EDD0D0D
E11111E01315D71919B91C207C111A864A56D0B8C1E1DBDDE6E4E4ECEAEBEBEBE9E8E7E8
ECECEBECEBE9F6E7E4FECBC5CB5C57BF211EB42121590A09B9A09CEDE5E2ECEBE8EBEAE8
EEECEAE8E6E3E9E5E4E9E4E4ECE8E6EDE8E6EFEDEBECEBEAE9E7E8E7E5E7EBE7E6F2DCDB
DC9390AB1F1EBF1214B20E149212195D1217957776D3CBC6D9D7D3DAD7D5DAD6D6DCD4D2
E5D2CBD7AAA0A44D448C0D0B9102049202059101058E00038C00038D01058F0106900006
9201089302098F01058A0103840205750102760001980409AF0309B10104AE0002AC0102
A802059403057C00017601047E0A0C9B282A7101046E01046D01046601025F01015B0102
5401025101044C02054701024A0103500104550001640802862C1100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8DAD49D3C3B7AFB2B1969B9E989B9B8881804B2F2D400C0D603C3EDDD3D8D6DAE1D5DCE3
D1D6DDD5DADF4042471D0A122F081037040E40030C4E070C600F0C681B00D39A26D2A50C
DB9F15B24708B21202BE0706BE0407C4060AC50709C4050AC70608CC090ACC090ACD090A
CE0B0ACF0A0BD00C0CD40C0DD50D0ED70D0DDA100ED90D0BDB0F0CDE120DDE110CE11110
E11110E31212E1130FDD1817CD1F229D17206E1D28A38083D8CDCCECEAE7EAEAE6ECEBE8
EBECE8ECECEBEDEAE7F9E2DFECA5A2B62B27C52423871110935957F3DDD9F0E7E4EBE6E5
ECE9E8F0EBEAECE8E6EFE9E8EFE9E8F1EAEAF0E9EAEEE8E8EFEAEBEEEAEAEAE5E6F5E6E4
F7C4C2A8312FB70E11C20E13B60F15941115570B0B81625FCDC4C1DCD8D4D9D5D4DBD6D5
DFD5D6E7D2D1CC9B9592302B8B05059201049101048E02048C01048B00028C01028E0103
9102079001098B00058700048302056F0103690001890308AA060CB00307AC0001AA0101
A902039B03048100027902057801047702047301036F01036D01036701026000015A0102
5501035101044C01044801034600024A000256000165060281260C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B68853D2C1B6A7A9AAABB1B58A8D8F9A95966147483F0A0D542A2DDACCD1D6DAE3D6DEE7
D1D8E0D5D8E14D4F551E0A132C040D39050E43050D4F060D510302681D00D49B22D2A308
DCA017AD4006B21103C00908C00609C2070AC30607C3050AC50609C9080ACD0B0CCC0809
CC0A0ACF0B0DD00A0BD10909D40C0DD50B0CD40B0AD80C0CDC0F0FDE0F0EE11211E2110F
E2120EE61411E71712E61612E31916D91C1EBB1F227A1517875858D9CBC9E9E6DFEDEAE5
EBEBE6EBEAE8EEECEAF8E9E8F6C0BFB43532CC241FBB221EA93E3AFDC2C1FCD8D8FAD7DA
F8D6D9F9D6D9F9D3D6FBD4D6FAD2D5FAD5DAF9D2D7F9D1D7F8D4D8EFCDD2F3D4D8F6D2D5
FFC8C9BD4849BA1315C20D11BB0A0EAC090E8F0D11580A0C795959C8BDBBDDD5D4DDD8D8
DBD5D8DFD6D7E1C8C4AC6661810B089003068F01038D01038C01038A01018A01018A0001
8C01028B010687000487010483020572020560000072010395050AA30306A60202A80203
A802059A03067F01037300047902087801057300047000036C0002660103610203590001
5501035101054A01034600014300014900015E02046F060384230C00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CD37D2C3B6C0C3C59BA3A79FA4A78C888A6952523E0B0E491B21D9C7CED7D9E0D2DAE1
CED8DED4DAE1575A611F0E172A060E3302093A010A44010B4C04036D2502D49C20D6A509
DCA017A73700B21003BD0805BF0607C00609C20508BD0207BE0206C8080CCB090ACB0709
C90609CB0709CE080AD00809D30B0BD30A0CD40C0BD80C0BDB0F0DDA0C0EDE0E0FE31111
E61510E91611E7160FE81711E81713E61714E21C19CC252386171966393BD4C8C4ECE7E3
EAEAE7ECEAEBEDE9E9F5E4E4F0B7B8B83636C41E1ABC2B26C7544EBD605EC46B6EC36169
CD636ACE6067C85B60C15258BD4F55CA5D63CB5D65C65C63C35E66B95B63B96168C66C6F
D76C6DC53937BF1412BF0B0CB7050AB00308A6080D88101544050679635FD1C6C5DED5D7
DBD5D8D9D4D4E2D2CEBF8A837E14108D03059001048E02048C01028A01018A01018A0101
8800018801028601038500028201027602045D00015D01017501038701039403049B0304
9C04078A02057000016C01047802077B01067901077401046E01016700016100025B0001
5300015101044D02044801024500014B000162010473040386210B46990400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DCA34D1C3B7BFC3C69EA6AA9EA4A7848485725F5E3F0F11411116CFBCC0D4D7DBCED7DD
D0DBDFD5DCE25E636A190B1425050C31030A39030E43020C500805722A08DBA225D6A509
DE9C18A83300B20C01BD0808BD0506BE0307C3060ABF050AC1050AC50408CB090ACA070B
CA060ACC080BCE0A0CCE0809D30B0BD60C0EDA100FDB0F0DDA0F0BDC0D0CE11011E5110F
E5130FE5130CE7170DEB1811E71611E61510E91B13E11D19BC2525550D0CAB9792EDE4E1
EAE8E7ECE8E8F1E7E8FADADED9878CB8262ABD1D1B820D0CEDAAA3ECADA4D17F79C05553
BE4140BC3737B83231B52F2DB5312EB3322DB23432AA322FA333329E35359D3737AB413E
B13932B32920B91D15BA140FAF0807AD0608A404088E0A0D5607054B2922BFAEA7E1D6D7
DCD6D8DCD6D6E1D3CEBE8F867F18138F03069101038E01028D01028D02028C01028B0101
8902018701018600018500018400017D02036501015200005A00006A00017601037D0003
7E01057001045D00026400027901067F01057F01067901047101006C0002690104600202
5801025101034D00024901034701014F0000670305740402801A0544960200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
60CC37D8CABFB5B9BBB2BBBE848D8F929394877878401213430E13BCA8ACD0D4D6D0D9DF
D0D9DFD4DAE07074791B0E1724050B31030B38020A3F01074E0603772F0BDCA222D9A50A
E09919A82B00B50D02BF0808BE0608C1070AC30709C3050BC20409C8060AC9060ACA070B
CA060BCC080BCE0A0CD10A0CD30C0BD70D0CD70D0BDB100CDC110CDE110EE00F0DE5130F
E61410E71610E5140EE91610E81711E5140EE4180ED81A16A618157A342DDDC2BBF1E3E1
EEE1E2F2DEE0F6D1D3F3AAB0C04348C41C1FC61C1B941416894B49F9D9D5FDE2DBFFD5CF
F9BDB6EDA7A1D88E85D1867CCE867BD18C83DF9D95E5A8A1E8B1ABEEBCB5EEBCB6F8C3BB
F6B8ACDF9284D6786BB64338A31D15A5120E9C07077D0304590D07906755D1B9ADE4D4D0
E1D6D4E4D6D4D9BDB8AC6C647F0D099202039501039101028E01028C00018E01018C0001
8A01018701008601008600018601018402037D0A096409075608077223225E0B0B5D0104
5D01045700035200016301037B02068201058402078001057701027101016B0103640203
5D01035401024D02034701024301014F00016A03047302017C160246970300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D9CDC3BFC4C5A1ABAD959E9F8486867F7271441819481015B0969CD7D8DDCFD7E0
CFD7DFD7DBE27D8086190C1326050C2D02073805093D03074A0702813A12DCA221D7A308
DA8E17A82500B80D03C1090AC00509C4060BC5070AC7060BC60508C70508C9070AC80609
C9070DC9060ACD090BD0080AD30A0AD70C0CD80E0BD80D09DA110ADB100ADD100AE1120E
E3140EE81811E5140EE6130EEA1611E91710E81B14CB14119E1C1BE9A19EF8C5C1F9CACC
FAC3C8E99EA4D26C71C0373CC72020D11717D01715C11D1E87181CAD777CF1DCDCF6EAE7
F6EAE6F6E6E3F6E5DFF3E2DBF9E9E1F6E7E1F5E6E2F5E8E5F0E6E3F1E7E5EFE7E3EEE6E1
F0E6DFF4E1D9F7D7CFEEBDB4D1877EA94039991B17800906AB5247D09181CE9D91CBA19C
CBA3A0C89895BC7B7594302C8C06049301019401029101018E01018E01009001008E0101
8C01018801008701008600018601018601018205039B37306C211CD69A97CD92935C1818
4E00025200015C00016F02047D01058302068601068702077F02057401026C0102650001
5E01025500024F02034500013F00005000026E04067403017D150245950200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
61CE38D8CCC2C6CCCDACB6B89DA5A7787C7B908684563232440D119F7F87DAD6DFD1D7E2
CED7E0D6DBE486898F1A0B1326050C2D02093301064003075107028C4312D99F1ADAA40A
D68416A71E00BC0E06C20809C3060BC7050DC6060CC8060BC70608C80708C80707C7060A
C7060BC80509CD080AD0090AD50C0CD60B0BD60C0AD90F0BDB0F0ADC100ADE110AE2120E
E4150FE5150FE6160FE7150EEA1712EB1713EA1B15DA1917E24748EF7678E76B6FDA5B62
C33D47BC2631C92228CF1A1BD61715D71414D51413D11516C31E23951E28AC6970EDCED2
F3E5E7EEE8E8EDEAE8EBE7E7EDEAE9EDEBEBEBEAE8EDEBEAEBEAEBEAE9E9ECEAEBECEAEA
EAE9E7EBE9E6E9E3E1E7D9D7EED4CFE8B7B0BB69628E211B971F1BA0302CA33B3AA64343
A441419B31318E16168E08079603049601029401029100009101009102018F02018C0102
8B01018A0100870000860101870101860101820202851613AA534E85423D995C596D2525
5F06076802057502077E02068201058B050A8E050B8B01088502067800027001026A0001
6201015901025101034801024200015401017104067401017F150547950300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
8AAA45DACEC4BEC5C7C2CCD1838E90888F8F9894924C2E2C440D108E6972DDD6E0CFD5E0
CED8E1D3D9E38F8F981D0D182B071030020B3401073F0206580F058E4612DAA31BDCA30E
CF7712AA1B03BA0C07BF070AC20509C5050CC6050BC9060CC70508CA0708CA0809C9060A
C70609C90708CC0809D20C0DD1090AD50B0CD90D0CDB0E0BDD100BE2130FE3130DE71611
E51510E71611E1120DE5140FE7170FEB1812EB1A13E71814DF1D1BDE2323DE2325DB2026
CC1118D1131AD71718D61213D61312D51313D51314D71416D7181BCD2025AE222BA13F48
CA8890EFC1CAF7D8DEF7DEE3F9E4E9F8E5E8F6E3E6F7E1E5F9E3E9F8E3E7F4DDE2F6DCE0
F7DDDFF4DADEEAD4D7E2D1D3E2D4D3EAD8D6ECC5BFC0736E9019179C0C0F9E070D9B060B
9E080D9C06099A03069801039801029701029601029300019301029201018F01018A0002
8A01018B02028802018600028702038701048601048104078212139C3C39A34846A34140
9727287F04088301078601068901068E030A91040C8E02088801067E01057501036D0102
6401015901015300034B01024800005D01027502047702028014064D9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
B0814ED7C8C0C3C8CDA9B4B98B999B8992948483825E42424911127F585FDED6DFCED1DB
D0D8E1D2D8E191939C1B0C172A050F31020B35030A3A01054504008C5017D8A51BDBA30F
C66A11AB1903B90B08BC0509C00609C4060CC6060CC7040AC80609CB0709CB0909CB0909
CA0909CE0B0DCF0A0BD10A0CD40C0ED4090CD90C0EE01011DF100CE0100BE3110DE5140F
E51510E51410E00F0DE71511E8170FE7160FE91810E91813E71612E81816E31715DA1212
D40E10D30F11D91516D20F10D31011D71515D31112D51213D91615DA1919D41C1ECA2126
B8262EB43844BB535DC96B77DE8791E897A0DA8691DC8693E38998DD8491DC7F8CD97B86
CB6A74C76A73C57279B06D73B27F84C5A0A2E1C3C2EBBFB9A54C46950B0AA60309A60107
A40006A100049F00049C01039A01039700029601029600029400039401039200048D0101
8C01038A01028701018600028601038600038700048600068201077E04077E0507840609
8603088802088A02098C020891040B95070E94060B9003088A01078101057801046E0102
6501015C01015501014D01015000006701027B03057D03047F12064C9B0B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5EC935D6C6BDCDD0D5ABB5BAA1AFAF7E87887B7B7E84696C47101371474EDDD3DCCED1DB
CED3DCCED5DD8D9298160A1426060D32030C37010B44060D490A039A601AD6A516DEA412
BF5E0FAD1604B90807BC0508C1070AC3060BC20409C7070CC8070ACB090ACB0909CD0908
CE0A08CF0909D10A0AD2090AD60D0DD70B0DDB0D11DF0F10E0110EDF100CE1110CE61512
E2120EE2100FE41211EA1613E5140FE81711E6150FE91813E81713E61815DB110ED10D0B
D00D0DD4110FD51311D31111D41313D41211D71514D81312DC1814DB1513DE1A17DE1B1A
DB1C1FD11C20CE2126CC2329CB272DC6252EBF1E2AC3212EC21E2CC41F2DC31F2BC11B25
C21C22BD1B20B2181E9F141B8E131D7E1B2489464AC89694D58E868E1510A00406A40003
A20102A00003A001049E00049B00049A0105960003960104970106970107930003900102
8F00038F01058B01048700028500018501028701048601058601078501068700058C0208
8E02098E020991050B91030A91020A95030B96050C8F01078A0107820005790003700102
6601015D01015702015201015901016E02037D01037E03037B0D034D9C0C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC733D9C9C0C6C8CDBFC8CD8B9799858E90929296654E524B141864353DDBCDD5CCD2DA
C8D1D9CCD5DD90979E18101729081034030D39020D3B0105480A01A36A1BD8A414DEA114
B64F0AB11503BC0807BD0407BE0408C2050AC20509C20308C30408CA090CCC0A0AD00A0B
D00A0BD20A0AD50D0CD50C0AD90F0CDC100EDC0F10DE0F0FDD100DE0100EDE100EE11111
DE110EE51311E71512E61510E71611E4130FE3140EEA1711E91814E41614D70F0FD00D0C
D00E0CD10F0ED71513D31111D21110D51311D81511DC1614DD1713DE1716DD1715DF1917
DC1916DD1916DD1A16DB1614DA1717D81719CF0F14D21217D31115D7151AD31114D31214
D11113CE1012C30C0FB4070CAE0710A00811890C13761417C36461A42624A10408A50106
A101029D00029E01039F01049D01069C01089A0106990105990106970006940003930103
9100039101048D01048901028802028601028601038500048601058701058800038C0005
90010890010890020A8D010792030C96030D99070F93030B8B01088401067D0204740101
6901015E00015801015700006502027503037D00027D0203780B0149980800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5DC832D6C4BBC7CACFAFB8BD8E999C8E989A888A8D7C696C43101358282ED7C9CEC9D0D6
C3D1D5C9D3DA9AA1A61B111826070E33040C37020A390205400701AB7318DAA714DF9F16
AC3F04B51303BE0A07BD0307BD0408C3060CC4060BC5050CC6060BC60408CA0809CE0809
D10B0CD1090AD30C0AD60E09D80F08D70C07D90F0BDA0D0BDE110EDD0E0EDB0D0DE11111
E41412E41310E4140FE61511E71712E71713E61612E91813E51612DB0F0FD40C0ED10C0E
D40F0FD20D0ED41110D10F0FD00E0FD61414DA1714DE1816DE1816DC1514DB1615DE1818
DF1B1AE01A18DD1914DE1815DD1816D41211D41212D61413D71414D71314D21011D20F10
D10E0FD10F12C3090EB8070DB0040AAC0208A5040999070B960B0EA30E11A30207A50106
A101049E01039F0104A001059F01089D01099C02089A01079A0106990106960004920104
9100049100058F01058B01038A01038801028600018501028500018601028701038B0105
9101089101098F020A8B01088F030B95040D96040C94040C8C01088401057E0103770103
6E02036201025900005D00016D01017801037F01047F03057A09006B600A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59C42CD8C7BACCCFD3B2B9BFA5ADB17F888A8083859A8B8E3F13154B1C21CEC1C3C7CED3
BFCDCFC8D2D69DA3A71A121727090E2E030838040B3D050A450B01BC841ED9A510E29E1D
A83400B71104BE0808C00609C00709C4070CC50509C60308CA070BCA0709CD090AD10A0C
D20B0DD50B0ED50D0BD70D0AD70D08DB0F0DD70C0BD70B0CD90C0DDC0E10DC0E0FE41213
E41312E51313E2110FE61413E61511E71413E71512E51413DD100FD30A0AD30D0ED40C0F
D60F10D40E0FD71313D00F10CE1010D31113D71415D91415DA1515DB1515D91614DD1717
DD1717DC1615DB1513DD1716DE1817D61111D61314D81514D91415D61213D10E10CF0C0E
D00C10CF0E14C1080FB4030BAE0108AC0107AA0106A50106A50208A30007A50108A40107
A30106A10106A001069F02069D01069C01069B01079C03089A0107990106970106920105
9000049001069002078F02058D01028700018500018400018400018400018600038B0106
91020991010A90010B90040D91040B94030B94020995040C8D03098400057D0004780003
7001036702036101026801027201017801017E02037E0204780700902D0F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C22ADAC9BCBFC1C7C5CCD58F979C7A82849497987B6D6F3B1214431317B9A7A9B4BBBF
B4C0C2C6CFD19EA4A81B141926070D2F030937040B3C0508470D00C28A20D9A410DF961D
A42900B70F06BD080AC2080CC3070AC40608C70606CA080ACD090ACD0A0AD00D0BD0090C
D20A0CD60B0ED70D0ED70B0CD70C0BD90D0FD80C0DD60A0DD80C0DDA0D10DC0E11DF0E10
E31111E41213E31110E20F0FE51410E81411E61412E41314DA0F0FD60F0FD81111D80E11
DA1214D50F10D61314CF0F0FCE100FD01111D31313D41313D71415D81415DA1716DC1816
DD1715DC1715DA1714D81412DD1917D71413D81515D71414D41112D20F10D10D0FD31012
D10D11C9090FBC040BB10208AD0107AB0106AD0309A80109A9030BA6010AA5010AA30008
A10108A3020AA101079F02069B00039A00039A01049A0105980004980003970103940104
9100049101058F01059101059002038B02018601018400028401028401028500038A0106
8F000891010A93030C95040E96050D95040A94040A93050B8C02098500078101077B0106
7200046A00036A00027602047901027701017A01017C02037407008F321500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
5AC32CD8C5BBC5C8CFB3BDC48A95988C94967E838584797B3B13153F1013A99698B3B6BB
B6BFC2C9D1D4A0A7AC1810182C091331010B3703093902054A1300CA9525D8A50FD78A17
A62303B90F0ABE070BC1060CC5080DC30506C70807CD0B0CC90608CB0808CF0C0ACF0B0C
CF070AD50C0FD60C0FD3090CD50B0DD60A0DDA0E10DB0D0FDA0E0DDB0F0FDC1010DF0F10
E21010E21011E2110FE61313E81511EC1914E61612DF1210D80F10D81112D60F0FDA1314
D60F11D00C0FD10F10CF100FD11312D31514CE1110D11312D41415D21214D41514D51814
D71D1AD1201BCD251CCC241ECE251FCD221ECD1F1DD11E1CD31817D31313D51112D71112
D71114CE0C11C1080EB40209AF0208AC0107AB0209A9010AA8020BA50108A20107A30107
A10107A00007A10207A102079E01049C01039B01049A0105980104980103980204940104
9200049000068F01069000059001038B0101860000850001860102850102870004890006
8E010992020B92010B93020B93020A96050D94040B93050C8B01088700088100087E0108
7600057200037A00058401068201047800017801017802037007008F361700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BF29D0BEB3CBCED5ACB5BA9CA7A9777F826C7072A59C9E3E1C1E380B10A59295B8BABF
BCC5C7CDD6D9A2AAAE16101828071231030C35020A3601044B1800CE9E26D8A711CF7D15
A41B02BA0D0ABF070BC0060AC5080BC20406C20403C70507C9060ACD090CCE0B0CD00C0C
D20B0DD20A0DD20A0DD30B0DD30C0DD50A0DD80D10DB0E0FDA0E0DD90D0CDA0E0DDF110F
E1120DE41311E2130FE81612EA1611EC1A14E31711D80E0DD20C0BD30E0ED3100ED71213
CF0D0FCC0C10CE1011CD1012CD1010D11315C90E0ECD1212D01717C81516C41C19C0261E
B22A22AB362FBA554DCE6D65E5847CE6817AE47872DB635FCA3F3CC52420D01A18D81716
D31011D21012C80C11B9040AB10209AC0209A80107A60006A70106A50105A30105A40105
A101049F01039F01059F01059F00049E01059C01049B01059901049500029101058D0206
8F02079002068F00058F01048D01018A01008700018601028701028801048902068A0106
8E010992010A92010B92020B92020A94040C92020A8E020A8701078400088101087D0107
7701047A00038A02089403088C01037D00007800017803036E040092381A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C028CEBDB1C4C7CEC1CBD1929E9F727C7C969B9B7C75773D1E2031060B9C8B8FBBBDC1
C4CDCFCDD7D9A0AAAC1411161F070C29030A300208370706502103D0A126DCA918C26D15
A11601B90A08C00809C2070AC30608C90A0CC60808C70609CC0A0CCE0A0CCF0B0CD10A0C
CF090AD30B0DD10A0BD60D0CD50C0CD60B0DD90E10D80B0BDB0F0DDB0F0DDA0E0BDD100D
DE120CE2140FE51610EB1812E91812E1140FD80F0AD20C0AD00D0AD20E0DCF0D0DD41213
CC0C0FC90C10CA1011C90D10C90F0FCE1414C61112C01816BC201CAB241F9E332CAE5D53
DA9E95F3C8C2FCDCD7FBE1DCF9E1DDFCE1DDFDDFDCFED8D6FCC3BEE88E89C2403BC41F1A
D01514CF0F10CD0E13C0080DB5060CAC030AA80209A80208A70105A40104A20104A30105
9F01029F01039E01049D00049E01049C01059B01049B01039900039401038700047B0002
7F01048B03078E02058F01048D00028B01018700018701028600028901048A01058B0107
8E020992020A94030C92030B94070E93040C94050E8D030B8600068301067E00067A0104
79010285010497030A9C01089501038701017B00017702036F040090331800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C027D2C2B3C6CBD0C5D0D88B999B8E9898868E8D7671713E2022370B0EA18B8FC7C9CE
CCD4D7CDD7D9A0AAAC1515181A060B2703092C03082D0202532605D2A225DDA61AB65C11
A51404BC0C0ABF0708C10609C50709C9080BC80A0BCB080CCD0A0BCE070ACD0809CF070A
CF090AD20A0CD60E0ED60C0AD60B0CDA0C0EDB0F0FDC0F0BDE110CDE110DDF120DDC0F0C
E0130EE41811E71812E71410E51712DB100ED50E0BD10E0CD3100CD81412D41112D00F11
CB0D0FC90C0FCC1213CB1213C81312C51715BD1D1AAC231E9022199C4A42DAA59DF7D7CF
F6E5DFF1E6E3EFEAE7EEEAE9EAEAE8ECEBE9EDE9E8ECE5E5F5E6E4FFDCD8F5ABA5BC3E38
C71E1BCF1414CC0C12C3080EB6050CAA0107A70108A70108A60007A20103A000039F0004
9F00049C00039D01059D01049C01049B00059800029800029A0002940003890105780001
7300008301058C01068E01048E01038C01018800008600028700038901048900048C0107
8E010791010995050C8F020891060D91050D9407108D030B8600068200057E0105790002
7C00008F02069D0208A102079C03068E01047E01027602026C03008C2F1600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55C025D1BFAFC7CCD1ABB7BE95A3A68D99986771709795954224253E0E11A68D91CECFD4
CDD6DACDD4DBA0A9AC1211151A03092B040B2C02062B030162340ED29F21E1A61DAE4E0C
AA1303BD0B0CBF080AC10609C5070BC5050AC40608C9070ACD0A0BCD0708CE0809D1090B
D20C0CD30B0BD20B0CD60B0CD90D0DDB0D0FDC0E0EDF0F0CE3140FE3120EE3130FE21210
E3140FE61711E71712E71511E31510D9100FD40E0DD6100FD50F0DDA1516D41211D21111
CF1111CE1213CE1616C71615BE1C18AF211D9A27209F4B44C89187E8C6BFF1DFDAECE3E0
EAE6E4ECE8E8ECEBEAEAE9E8EAEAEAEBEAEBEBE9EAE9E7E8ECE9E8F0E7E5FADCD8DE908B
B5302BC81919CB0E13C60B11B9050DAF040BA60007A50007A60108A20105A001059D0104
9C01049A00049A00059C02069D03069900039800029900029C0204990104930205870306
7A00028302068D01078F01058E01038D02028A02038902048901048C01038B00038D0105
90010792010892020892030A8D020992060D92060E8D030A8701078402087F01067C0003
8601059A050AA10207A50308A00408910306800103730102680200862A1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C127CCBAA9C9CED2B3BDC59AA8AD768485798484888989452A2B3E0D10A4878BD2D2D7
CCD5DBC6CFD79AA1A7140E1422080D30040D34050C310402784816D5A21EDF9F1BAB4004
B01206BC0A0DBF080AC2080BC4070BC20609BD0205C5060ACB0809D10B0CCF090AD20A0D
D30B0ED60C0CD80E0ED90D0EDA0F0FDB0E0FDD0F0FE1100EE41410E4130FE51410E10F0E
E4130FE51410E61611E51511DF1411D50D0ED30D0ED71212D51211D61213D41310D11312
CE1513CB1A19BD1D19AA241D972E26A1564ED1A29AEDD3CCF2E5E0EAE4E3E9E8E7EAE9EA
E7E7E9E8E8E9E6E7E8E1E1E3E7E8E9E7E8E9EBEBEDEBEBEDECECEDECECEBEDE7E5F2D4D0
E49793B62829C61317C80D13BC070EB1060CAA040BA50108A7040AA30208A001059B0002
9A00029800039701069900059801039701039902049B02059B01039B0105990206910205
8701038801048F01059001048E01028B01018B01028B00048B00048A01048A01058C0106
90010792020893020995040B90020993060C92060C8D030A8901088300077F0106800004
92020AA2040CA20209A402099C02058E01048201037101026301007E250E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
56C026C6B4A3C6CACECCD4DC859398808E907985856C6F704D3434400E129F8186D2CED5
CDD3DACDD4DD9A9FA5170F1623080E2B030B2F030B2F02028C5C1ED6A41BDA981AA32F00
B10F06B80508BE070BC00609C00607C0070ABB0302C5080ACC0A0BCD090AD00B0CD40B0E
D60B0FD70D0DD70D0BD80C0BD90F0CDA0D0CDB100DDF100DE3130FE31110E51410E61312
E61511E3120FE41611DF140ED70F0CD30E0FD00C0ED20F11D41212D21211CE1711C21A14
B8221DA92B23A03F36B7766CDEB7AFF0DBD4F2E8E3ECE7E6E9E8E8E7E6E8EBECEEEBECEE
E8E9EBE9EAECECEDF0E8E8EAEBECEEEAEBEEECECF1ECEBEFEDEDEFEEEEEEECEDECF1EAEA
FBD6D6BF5C5DBB1C1DC71012C10C0FB3050AAA020AA70308A60208A50108A000059C0104
9B01049A01049700049700059A0105980004970105970104980003990005990106950106
9301049302069201059001048D01028900008901028C0105890104860002860003890006
8C000790010892010996030B96040996060A94060B8F040B8901098100067F0005880106
9C040DA3050E9D00089C02089602058A000281000273010264010081250F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57C025C8B4A2C1C5C9BAC4CC9EACB0909EA05A67669397974F39393E0F148D6F76D3CED5
CAD0D6CED5DD9A9DA21C111822070E2702092C0307330704976A1DD7A61BD38E1B972000
B10C08B70307BD060ABF0708C00607C10609C10607C40608CA090ACD090AD20C0DD30B0E
D50D0FD70D0FD40D0BD80F0DDB110DDA0E0DDB100CDF120FE2120EE3120EE51511E3140F
E3140FE2130FE21913D40F0BCF0D0BD01010CE1010CC1311C91713C6231BB2271DA53A31
B2645BDBA59DEACCC3EFDED8EDE4E0EAE6E5E6E6E6E5E4E5E6E7E6E8E7E7E8E7E7EAE8E9
EAE9E9EAE8EBE5E7E9E5E5E7EAEAEBECECEDEDEDEFE5E5E7EAEBEDEBECEEEAECEEEEEDEE
F5E4E5EEB0B0B02D2CC31414C30D0EB50609B0060BA70308A70409A50308A101069D0105
9B01039A0103990105980106980106970004950003930104960106970106960106930104
9401049402059301059102078F01068C01048C01048B0004880003870102870102870104
8800048C010791020994020A95030A96050C95050C90030A8B020A850006880106940106
9F030A9B040B8E02088B01058F02068C01048302027301016701007F200A21CA0200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD22C8B3A1C3C7CBBBC5CEA8B5BB7A8588818C8D9296984F3D3F3A0F157B5F66D5D1D5
CCD2D7D0D7DE91969B170F1423080E28030B31040A3A0702AB791ED7A51BC278159B1B01
B20C09BE080DC0070CC0060BC3060AC40409C50709C8070ACA0809CD090BCF090AD20A0C
D30D0ED40D0FD31010D91716D81211DB1011DB0F0DDF120FE1140FE0130FDB1811D61B14
D81C14DC1D15D51A13CC140FC81610C61B16C3241DB4251CAF3328BE5B51D7948AF1CCC5
F6E2DCF3E7E3EAE6E3E8E7E5E7E7E5E7E5E6E7E3E7EAE6E8E8E5E6E8DFE2EDDDE2EDD5D9
E8C9D0B595A0B2A1AAD4D0D6E2E2E4EBEBECEBEBEDECEBEFECECEFEAECEEE9EBEDEFEFF0
EFE8E7FBD6D5B95353B61616BF0C0EB9080BB3060BAD060CA50208A50309A20107A10109
9D01059B01039A0103990103990105950105940105910003920003920005930006920105
9100049201069000058E01058D01068D01098C01068B0004890103880102850001850002
8901058C000790020992020994030A96050C97070D8F02098A00078B000795010A9F010A
A0030B8D01077700038914178504088B04088202037501016A01007C1D0843950300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
59BF24C3AE9DC7CDD0C5D1D998A5AB8A949891989B6F7174564448350B1483686FD3CFD4
CBD4D6D3DCE1889193110D1220070F27020B2B0205431102BD8A21D8A31AB35F11A21602
B40909BC060BC0060BC4070CC5060BC4050AC50709CA090CCC080BCC090BCE070AD20C0D
D20D0DCC0A0BC90F0EE62E2FCA090CD90F12DC0E0EDF120EDE1310CD0F0DBC1F19E96E66
D35A4FCA4B40C74639C6463DC85348CC665BD57D73E7A399F4C4BCFAD9D4F7E6E2F2E9E8
EDEBE9E9E6E5EAE9EAE9E8E8EBE9EAEDE4E8ECDDE3F2D9DFEEC9D1E8B1BDE69DABD87B8A
C35765A63D4C601C2A61454ED1CBCFEDEDEFEAEAECEDEDF0EFEFF2EBECEFEBECEEEDEDED
E8E7E5F6E0E0D28487B02022C41316BD080CB5050AAD040AA8040CA5010AA20008A10108
9F02069A01039A01039A01059600059001048E0104920206910102910102910005920106
9202069001058C01048901028A0104890105890104880003880004860102820001850203
8B02078D02088F020894040C95040C98060E97060F90030B8D010895010AA0010BA5010B
A0040B8401057402058B181D7901058203077C00037001016701007A1C0843950400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
57BE22C2AC9BC6CBCFBAC6CEA4B1B59BA4A969737592969A58494E320B13836870D6D2D8
CDD5D9D3DDE280898E140F1421050F2B030B280001411300C79525D9A01AB0530FA61203
B7080ABF070DC3090CC6080CC40709C4060BC4090CC1070BC1080CC4070BCD0B0DCF0B0C
D20F0FC00808B91010BA1313C2080ADB1012DE0E0DDF120DDD110FCA1010870202B66C68
F1BFB9FED4CCFFD4CCFFD6D0FFDCD3FDE3DBF9E4E0F6E7E3F4EAE9F0EAE8EFEDEBECEBEB
EAE9E8E9E5E5EDE4E4EAD8DBE8CBCFE3B2B9E6A1ACDB7F8BC3525EB6303EBA2634C3212D
C81E26C32026901B213D050DAA999FEEEDF0EAEAECECEDEFEBEDEEECEDEEEAEBEDE6E7E9
EDEDEDF6E9EBEBB2B6AE2C31C7161AC80D12BE080DB20308AB030AA6020AA20007A10107
9F02069A01039701019901039701068F01038A0005900208920106930106930205910104
9100058F00058C01058800028800028700028901038800048801058601048001017F0101
8601048A02068D010791020894030B98051096050F94040D97010BA2020DA9030CA70108
9C030A7D00027702077A02077500047802078413166E010266010076190843970600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
53BB1EC6AE9DC4C6CABAC3CAA9B4B97A85898A9598989FA35C4F533A131B80646DD8D2DB
D2D8E0D5DCE57D838C1810182707102F030A3305054C1C01CE9E29DA9E1EA13B05A30901
B70809BF090DC2090DC00508BF060ABD060AB7090CA502089D0106A80407BD090CCB0B0D
D20F0FC30D0FC32828DD4646C91512DA0F11DE0E0DE0100CDF100CDA1614B61112750B0E
965B60DFC1C6EEDEE0F2E6E8F1E9EAF3EAEDF1E8EBF1E9EAF1EBEBF3E9ECF3E9EBEEE2E4
F1DCDCEEC8CDEFB5BEE897A1CD656CBE4048BC2C36C3222DCB1E27CA151EC91318D1171A
D11818CD191AB022235B090D644649E4E4E6E7E8EAEBECEEECEEF0EBEEEFEAEBEDECEDEF
EBECEEF3EBEEFCD3D7B84B4EC31B1ECC0F13C40B0DBB080BB2050AA80209A30006A00005
9F01059B0004980002980102980103960207920209920108930107920006920004910104
9101059001068E01068C01048C01048D01058C0206870104880106880105840103820102
8400048801058E020690030795060C97050E95020B9A050CA3040CAB050EAB020AA50108
9603097700017602067C040977010777030876070D6F03066701026E120542950500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
55BD20BEAA97B8BCBCC6CFD6A1ADB488959B9DABB06E757A675A5F3811197B6068D9D3DC
D5D9E2D7DDE7767C85140E1625070F2D030B3406055B2B0BD2A22CD59622972A00AB0D08
B50709B9050BBF070EBF070CBB080CB1070A9D0104BB2E34D5585DB027299C0405C30E12
CF0E10CC0F10E1373AE23A3ED21516DD1112E11110E21210E2120DE11411D81414C1161B
95111A882937B56F7CD198A4DFB0BAE2B7C2E4BBC4F4CBD1FACED5F5C0C9EEADB9E49AA5
D67B85C4525EC13944C62935CE232ACE1C22CF191CCF1418D21518D4141AD41518D21516
D31716D3191BBD1C1D8A1A1D441113C8C5C6E7E9EBEAEBEDEAEBEDEBECEEEDEEF0ECEDEF
EEEEF1EFEAEDFADFE2D07A7DB92023C81014C50C0FC0090CB6060BAD0209A60007A30109
A100089C0106990103960001950001960105960107940109920108910108920107910006
9000069101079001078F01068F02048D01038C00038A00048B0005890105860004830103
83010387010490040A8E01088F020A93030B97030BA40710AB050DAB0209A90209A30108
97030C7500036D020578050B7600057B04096E02076B01046901026C0B0142930400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52BB1EBFAB97BABEBFBBC7CEADBAC2A8B5BC6D7C7F91979C695E62331117785E64D6D1DA
D5DBE4D7DFE9696F78160D1621060E2C050D3106046D3E14D2A129CF8C21901C01AB0909
B6080ABA060FBB060FBA070EAF060A9F0103A00308C82C35C63038B524288B0000AF070A
CB0D0ECE0B0DD00E12D31116D81012DD0F10DE110DE21210E1140FE0110FDB1111D20E11
C81115C01620B71F2AAF222FB02D38AE2E3BB13642C84C5AC44654C13846C02F3BBF2530
C5222ACA1D23D41E20D5181DD5161AD41517D01312D31315D71618D81519D71619D7161A
D41416D01317C7191CAE2225580A0C948889E4E8E8E8EBEBEBECEEE9EAECEBECEEEBECEE
EBECEEEBEBEEF4E5E7E3A3A6AC2327C81416C60D0EC0080ABA080CB3060AAA0108A50108
A101069C01049900029600019701029601039501059301078D01068B02088E0209910208
9000069101079001078E01068D01038C01018D01028D01038D01058A0107870005850004
8500048800068D020A8E010A91010A99060E9B020AA8060FAE060EAC040BA702099F0007
98050C7501045D00026A060C7302087B050B8E24286802036F0305700B0142920400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
52B81BBFA893CED1D3BFC8D2B2BFC88493998291939DA5A96C6368341218775C63DBD6DF
D1D9E2D7E0E95D626B1B0E1627070E2E050C34060589571AD5A325C1771A8E1301AA0A0A
B5080BB8060EB80811B207109D03079C0104B50710C00A13BD0912B10A0F8F0000A90609
CA0E0FCF0C0DD30E0FDA1014DA0E11DF0F11DE110FE0130FDF120DE01410D7110FCD0B0B
CB0B0ACD0E10CD1114D01417D11618D2161BD2191FCF171FD01921D2181FD51A1ED3181B
D11718D11515D71616D81918D51817D81D1AD31915D31C18D31D1AD31917D71F1CD6191B
D41518D21419CB1618BE1D227B1216614547E1E3E4E5E8E7E7EAEAE9EBEDEAEBEDEBECEE
EAEBEDEBEBEDF0E8E9F3C6C9AB373CC11719C60E0EC20A0BBD080CB6070CB0050CA8000A
A301089D00049900039801039802059400029301029201058801037C00018301038E0207
9102068F01058D01058D01058B00038A00018C01028E02068B0106880004880004870103
8600038701038E020890010A98040CA70B13A7050CA70309AD050DAA030AA301089F0007
99030A7C040A5C090C4C00046301067C050D810E156F0004700203720C0243930600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
29DB0DB59A84CBCDD0C6CFD89EABB3839297A6B4B7747D826A616836141B7A5E66DED9E2
D3DBE3D7E0E950555E1C0D1527060C2D0508360904A4741ED7A525AE5C138F0D00A60708
B1050BB3030BB0070D9F040B8D0002A8060CBD0710C4060FC0070CAD070A8C0000AC090B
CD1011CC0809CD0708D80D11DC0E11DC0E10DB0D0DDF120FE0140FDC1210D00C0BCD0E0E
C90C0CCB0B0CD00F10D21010D61411D61414D61918D21817D31D1AD31D19D61C1AD51B19
D21715D11513D01918C9211DC62D25C9372FC5382DC63E33C8463AC8493FD14F46D2433F
C61F1FD4181CD2171BC7171BA21F22451114D3CFD0EAECEBE9EBEAE7E9E8E8E9EAEAEBED
EBECECE8E9EAECE9EAF6DADCB65B60B81C20C40D10C30B0DBA0409B5050BB3050EAD030A
A702099E00059A01049701049400049100029200019200029002058501028501028C0103
8F01028E01028B00038E01068D00058C01048D02048D01058B01078900068C01058B0003
86000187000290060C93030AA30811B00811B0070FB1080FAB040BA80309A40109A00107
9B020981030AAE5C615D23255903077E040A86060D7C020674010370070044920700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00AC8F74C7C6C6C3CCD5AEBBC1AAB7BD7D8C91868F956C656A32141B7B626ADDDBE4
D6DEE7D9E2E94A4E561D0E1427060C2C0508340800B48421DAA5279B4009970E02A70608
B0040CB0040CA9090E8A0205880203B10A12BE060CC3050AC1090DA60407890000AE090A
CD0F10CF090CD10B0CD40D0ED80E0EDA0D0EDB0F0EDA0E0EDF1514D30D0EC9090AC8090D
C70B0CCC0E11D01013D01112CE1813C9211BC52D25CB4339CF5247D2554BCF4B41C73830
C52A23C9231EBA1F1D7D0908D98A83F5B4ABF1B4AAF3BCB0F5C3B7FCCDC4FECDC6FDBCBA
BA3E3ECB1C1FD11518CE171ABC22245608099B8B8CE8E8E7E9EAE9E7E8E8E9EAECEBECEE
EBECECEAEBECEAE8EAF3E2E4D28E90B12528C51215C1090DB9050BB4040BB4050FAF030C
AA020AA200089E02089901059500049401049400039500039201038E02048C01048E0303
8D01018C00008D01028F01069202089101078E00058C00058C00068C01068B00048C0105
8B01068900048E01069E060DAC080FB70B14B4060FB30810AC050CAA040BA60108A10108
9C01088C040C85232B954F565C030883040D86010881010678010371050044910600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00947452CCC9C6C2CBD1C0CBD492A0A884939896A1A76C686C31161B79626ADFDBE7
D6DEE7D6DFE63C3F471D0C1429070E2F06083E1000C6962CD79E278D2C019B0C03AB060A
B2050EAE050F9F080F790001890205B1070EC1070DC6070CBD080BA003048E0000B80C10
D00E10D50C0ED50B0ED60E0ED70F0DDA100EDB100ED60E0FD61011CF090DC8080CC80A0E
CC0E10CD0D11C71113BD1918A7211AAE493FD99085FECAC1FDD4CBFFD6CEFECDC5F9BCB6
ED9F98D17068A6453F4B100E98817DEBDFDBEEE2DFEDE4E1EFE6E4F0E7E5F4E8E7FDE0E0
C46C6FC5262BD3191BD11617C71E1E7911136D4F51E8E7E8EBEBEBECECEDEDEEF0ECECEE
E8E9EAE7E9E8E8E9E9ECE4E4DEACADA32B2EBC1316BD0B0EB8070CB4050BB3050BB1040B
AD030BA70109A201069D01059A01059800049702049601039201028F0202890001870101
8C01018D01008D01018D01038F00049101059201069001068F02078C01058A0004880103
8901038C0002960105A50409B1080EB5070FB1020CB2060EAC0209AC020AA70108A00106
9C010895020A91151D710C1473040B89030C890108810004790103730600655B0700FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0084623CD0CCC8C5D0D5ACBBC2819299A8B8BC7681896A676C31151B816770D3CED9
D6DEE7D3DCE52E3038210C1429050C320604512000CA992BC98E26741500970A07AB060C
B1030CAE071193050C710001890307B2090FC3090DC5090FB9090E970103950102C10E13
D10E0FD40C0ED70D0DD90F0FD40D0ADA100ED9100CD91211D00C0DCD0A0EC9080CCD0C0D
CD0E0EC91010B41416780B08A86960F1D0C9F7E7E3F2E9E7F3EDEBF1EBEAF4ECEBF5ECEA
F6E6E2F7DBD5E6C5BE8D7671766D69DCD7D6E5E3E5E7E6E8E6E5E7EAE7E9EBE7E8F6E4E6
D49295B72A2FCE181AD41719D11E20991A1D4A1C1FDBD8D9EBEBEDEDEDEFECECEEEAEBED
E6E6E8E8E8EAE7E8E9EDE8EAEFCFCFA7474AB0161CB6090EB3040CB60711B3060EAD020A
AD040BAA0209A70208A203079B00049800029600029100028E00018D0101890000880101
8800008B01018B01018A01018E00029101059100059201078F02068C0104880104880001
8C0001950103A00105AB040AB40810B4060CB5070EB3070DB0060CAD040BAA030AA30207
9F01079B010991040BA5262C8F0E178B010A8B010880000476000173060085220600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F6C46C6C2C0BBC6CDAABAC1ADBDC4798990808B90716E7133151A816970DAD6DF
D8DDE8CDD6DF2B2C35210C152B060C360803693810CE9D2DAC721F6B0C01900708AB080E
AF050CA908118904096D0003810206A7060DBA0A0DBC0B10A8060B8E00029D0506C60C10
CF0C0DD40E0FD20C0BD0080AD40C0CD50C0BDA130FCF0B0BCB080BCB090CCC0B0CCE0E0D
CA0C0BC213148A0D0E612A28E4CFC8F2EBE7EFECECECECEDECECEDECECEDEAEAECECEBEF
EBEAECEDE9EAEBE6E4E6E2DDD8D4D0D3CFCFE6E5E8E7E7E9E7E9E8E8E8EAE8E7E8F3E8E8
F6C8CAB53D41C91B1ED11318D2191DB620274F070CADA3A4EAEDEDEDEEF0ECEEEEEAECEC
E5E5E8E9E9EBE9E9EBEAE6E8F2DCDEAC6266A41C1EB40D11B60910B4060EB2060FAB020A
AC030BAB0209AB0309A702069F00049900039701049302068E00018D01018B0202880001
8901028A01018B01018E01029001049101069301099101088D00048B00048C01048E0002
980104A20208A80208AC0209B40510B5050FB6060FB2040DAF030BAC0309A90308A70209
A30107A001089A030992030B8D020B8A00088902077E010373000073050089230900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0093714CC7C4C2BEC9D0BAC9D19AA7B07D8B9195A1A475737432151A866C73DBD8E0
D6DEE7C5CBD32220292007102C060C33050481511BD7A5349A5B1B760C02940407AC070E
AF060EA6060F820207650001760105920309A10409A1040A9002078300029E0607C90E12
D00C0ED40C0ED20C0BD20C0DD50D0DD50D0ED10C0FC60408C6060CCA090DCD0D0DCE0C0C
CD0E0FBB13156907077F5F5DEAE0DDF1EFEEEEEDEDEEEEF0EAEBEDEDEDEFECEAEDECE5EA
DECFD7E2D2DCEBE3E9EAE8E8EBEBEAE2E1E2E3E3E5E6E6E8E7E9E8E7E8EAE7E8E8ECE7E8
FBDEE0C4656AC12023D21A1FD3171AC51E226E0E147A6368E9ECEDECF0F1E6E9E9E7E8E9
E8E8EAE8E8EAE2E2E4E5E2E5EBDEE0CA92949A1F22B21014B1070CB0040BB0050EAB040E
AA030CAC030AAE0209AD040AA501079C01069701069400049100029001008E01018C0103
8A01028A01018B01018D01018C01038E01059100099100088F0005900104930005990104
A40106AA0108A90108AA0109B1020CB5050FB60711B3050EB2050EAE040CAB040BA40106
A202079F020899020993010A8E00088901078803077F010472010070040088210900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C6B46C2C0BDBECBD2ABBABF7D8990A9B7B97784886E6A6E34161C8E747BD9D6E1
D1DAE3B0B7C119131E21060F2E040A3506069F6F20D39E2E853A0E8A10079E0609AC040C
B0060EA9051088050A6400026C02067F02088701098602087F01057E0001A3070AC50C0F
D10C0DD30B0DD20C0BD30B0DD50E10D10B0DC70709C3040AC7070ECB080ECF0D0ECC0A0B
CE0F10BA171A5C0506917B78ECE7E5EDECEDECEDEDECEBEFEBECEEEAE7ECEDE3E7DEBBC1
9D56638C3D4DA26879D4B9C4E6E1E6E9E9ECE6E5E8E5E5E7E7EAE9E5E6E8E3E4E6E9E7E9
F4E3E5D79096B9272DD42124D7191ACC1B1D93191E50272CE2E1E4E9EBEDE6E7E9E6E7E9
E8E9EBE9EAECE6E4E7E4E2E5EAE2E5E6BDC19F363BAE1318B2090FB2060EB0040DAE040D
AD040DAD030CAF020BAF020BAB040B9F01089901069500029401029301029102018E0202
8B01018901018902018C03028B02028F01049301079301079200039601059C0105A10005
A70206AA0208A60208A40207AE060CB3060FB90A13B3060CB1050BAF050BA90209A40106
A000079A02098B01058D040A8D03098700038701057F01057401016F030080190400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B6A46B0AEACC4CED5AAB7BDB1BDC27E8D8F7D878D716C6F33151B947A82D4D3DE
CCD5DFA4AAB51C141F280A162F040A3A0A03B6852AD29C30711A00910C09A4060BAF050C
B3040DAC030E8F040D6400036201066F01087A040C78030A760105880105AA0409C60A0D
CE0B0AD20C0BD10B0AD50C0ED30D0ECC0A0BC7090CC5060DC7080FCB090FCB080CCE0B10
CD0E0EC0191C610708866F6EEAE8E6ECECECEBECEEEAE9EEEAEAECEBE8EBEEDEDFBB7A81
AC2A35B8202BAB2634822735956F7BDED7DEE8E7EAE6E6E8E7E8EAE6E7E9E3E7E8E7E8E8
EDE3E3F0BDC1BA373FD2242AD71A1DD0181BB01E244A080FBBB3B6E6EAECDEE0E3E8E9EB
EBEBEDE9E9EBECECEFE5E5E8EAE7E8E4C9CBA24F52A21519AF0A10B30810B0020CB1040D
AE040CAB0109AE020AB0020BAD030CA501089E02069A01039501029100019001018E0101
8C01028B01008801008700008A01018E00039200059500069B01089F0207A40207A40106
A501079E0206900102950306A6050BB3070EB6080EB5080EB1050AAF0509AC040AA40006
A001079902098600048001048803088700058701068100057701026D01007D190500FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00856143BBB8B8C3CCD6C0CED69BAAB178888D959FA57A757A33181D947C84D6D4E0
D0D8E18F94A0150D192306122C0307411200C79735C48B2979180298090AA80309B2060C
B4050CB0040C9E08116D00055C01056B0C138A2E33882D337002089B070FBB0A10CA0B0C
D10C0BD20A0CD20A0DD70E11D30E11C6060AC10609C3060CC7080DCA090ECD0A0ED00B0F
D00E0FC2151A72090C705355E7E2E3EDEBECE9EAECE8E8EAE5E5E7E8E5E7EEDEDEBD7A7E
B02529C5171BC7181EB62029711521725761D8D6DAE4E4E6E2E2E2E4E5E7E4E7E7E9E9EB
ECE7E6F8D5D8B95257C6282CCF191CD2171BBC1B20610A0F7D6C6FE1E4E6E1E5E6E7EAEB
E8E9EBE9EAECE6EAEBE3E5E7E7E7E8EADADAB5767992161AAC0B12AF0610AF040EB20710
AE030CAD020AB0040BAF020BAA010AA8030AA502099E01079701059200048F01018D0001
8D01038C01018900008901018C02028F01039500049D0106A4030BA60109A60107A50004
A200059600038301027C0001940308AF0810B60810B5070EB2050AB00509A90105A60208
A101079C01088F01088200048401068801078600068201057901026F01007A150400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00896547BBB9BAC1CCD5B8C5CE77868EA7B6BB7D878F6D696E2F1318977F87D5D1DD
D2D7E07C848D110C1520050F2804054E2105D19F3BAB6A1F750C019D0A0AAC060BB4080C
B5060BB3040BAE0A12830307620204C97E85FEC3CAE3A1A8760F12AE1316C00A0CCB0A0C
CF0C0DD30D10D20D0FD00A10C7060BBF0308C00609C2050BC80A0FCE0C10CE090FD10A0F
D31013C815198A0E13532F32E1D9DDEBE7ECE7E7E9E5E5E7E5E5E7E6E3E6EBE0E0D09C9C
A62A2CC01619C81217C2151B9E1B243D080FB0A8AAE1E1E0E5E5E5E7E7E9E6E8E7E7E7E9
EEEBEBF7E2E2C97E80AC272AC92023CE171BC3191D8013194C2C30DADADCE1E4E5E3E8E8
E5E9EAE6EAEBE6EAEAE6E8E8E2E3E3E6DCDDCFA2A48D2327A80F16AE070FAB030BAC020C
AB020BAD040CAD030CAC030CA6010AA50109A502089D0206970109940108920104910104
9101049102049001038C00018E01019200019D0104A50107A60108A70109A60007A40104
A201059E020698050B840104880204A90A11B80C15B60610B3040CB0030BAE040AA80208
A100089C01099301078700058601068801068701048402057B010370010079130300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00967053AFACADC9D1DBB3BFC8B0BDC587969B7F8A906D676B3313199F868CD5D2DB
D2D8E267717A0F0B131C050B230203623715D7A43E9149137F0A039C0509A70207AD0305
B4060AB20108B5080F9F050B81080D8C343C934D557B2E32AE3C3BB91817C40C0CCD0B0E
C9080CC20206CD0D0EC9080EC2040AC1070AC3070BC5080EC5060ACB0A0CCD0B0CCF090D
CE0C0EC710139E13173F0B0DC6BDC0E7E4E7E5E3E6E7E5E8E5E5E7E3E3E5ECE6E6DFBCB9
9E3D3AB81C1FC41217C7151AB41B2057070C706061DCDADBE6E4E5E4E4E6E4E5E5E8E7EA
E7E6E6F0E3E6E2AFB1A03539B52024C31216C012189F1C233F080FBAB4B7E2E4E5E7E9EA
E4E5E7EAEBEDE8E9EBE4E4E6E6E6E7E4DCDEDBBABD983E42A41419AC080FAB060DAC030C
AB020BAA020BAC030DA9020BA60109A40108A10107990105940006980108980105950104
9201039101029001039101029300019C0104A50106A90108A90109A60007A50007A40105
A10103A100049F02069303078A0004A0060DB20910B70911B3040CB3050CB0040CA70109
A0010B9C010A9701079001068901058600018601038301047B01037201007A120200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956F4BBBB5B2C7CFD7C3CED8A8B6BE7C8B9097A2A8767376301319AD979DDAD8DF
D4DCE5525B65130C1420060D2504027C4F1DDAA43F8331078B0C04A2070AAC050AB0050A
B5070CB8060CB6050CA90107A41015BB4349BB5458D16464BF3333BD0E11C70B0DCA0A0C
BF0106BF0207C90C11C4060BC10609C0060BC40A0DC5070DC7090BC90809CE0D0CCF0C0D
CE0C0ECA0E13B41A1E4B020597888AE3DDDFE8E3E7E5E3E6E3E3E6E5E5E7E6E3E3E6D0CD
B26864AA2020C01616CB171ABE161B7E1017422325C8C5C5E5E5E3E7E7E7E6E5E7E9E7EA
E7E5E8F0E8ECF7D6D7B66669A62427C01419C11116AF1A2053060B88787BDBDBDDE5E5E7
E5E5E7EBEBEDE8E8EBE4E4E8E3E3E5E1DDDFE0CCCDA55F6198151AAA0911AD070FAE060E
AD040CAB0109AC020BAA020AA70209A50207A40208A3040A9F02089F010A9F01089A0106
9500039000018F00029601029D0003A50207AA0107AA0107A90108A60007A50107A30106
A00004A00105A001069E02099A0108A5030AB1060CB6080EB4060EB5050FAF030CA60009
A2010A9D01099800059401058B01038701038402048301047F02057400017B110300FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805A32C4BDBAC3C9D3B9C4CE7F8D94A7B6BA8290946464672F171AB6A2A9DADAE1
D4DEE5454D57150B131E0509250503986C24CB9234771E018A0602A20409AE060DB3050E
B8070FB9050EB6030CB00108AC050BB0151CB52529AC1519B60C10C3080DCA0A0DC8080B
BE0005C00309C3090EBE0409BE0508C1070AC3080BC6060BC80A0CCB0A0CCC0C0ACE0D0C
D00F10CB0D12BC161D67070C62494CD9D2D4E7E4E5E5E3E6E4E4E5E4E4E6E4E3E2EBDEDB
CC99939F2B28B81615C81516C5171A9D191E3906089E9999E1E1DFE6E6E6E8E8E8E7E5E8
E6E4E5EEE8E9F3DEDDE2A6A9A53638BE1A1DC21016B8181E74111851363AD2D0D3E2DFE2
E4E2E6E6E6E9E6E6E9E3E3E8E1E1E5E1DEE1E5D8D8C48F908F1C1FA60B12AD0710AE040D
AE030BAE030BAC020BA9020AA70109A70109A9040BAA040BA8030AA6020BA3000B9F0108
9A0104980103990002A00104A40004A80107AB0209AC0109A90108A70107A50107A30106
A00004A00104A20107A6020AA7030BA90209AD030AB5080EB5070DB4050EAD010BA7020A
A001089C02099701079101068A01048400048100048201057F02067600027B0E02439002
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008E643DB4ABAACED6DFBFC9D2B0BCC38A9A9D828E916763662F181CB8A9B1D8D9E1
D2DBE22F3841120B131B05092B0C02AF8330B47A27690B01900806A6050BB0060DB2030A
B6050DB7030BB9050DB40208B6040ABF0A10BE0A0FBE080CC3080BC8080BCA080ACC0A0D
C40609C5080EBD030ABD0409BE050AC0040AC4070BC50609C80A0CCC0B0DCB0E0BCD0E0D
CC0D0EC80C11BF1216830E13401D1EC9C2C3E8E4E5E6E4E5E6E6E6E3E3E5E4E4E3ECE6E4
DDBDBA9A3F3DAD1618C81419C7141AB1181E57080C655658D8D7D5E4E6E5E5E5E3E4E2E2
E8E6E7EAE7E8ECDFE0F1C9CBB05557B91F21BE0F14B812198D161C380C10B4AFB0E2DFE0
E1E0E2E3E3E5E1E1E3DEDFE0E0DEE2DFDCDFE5DDDED4AFAF922F32A61016AC060EAE030C
B1030DAF040CAC020BAA030BA70209A6020AA7030CA6020AA60209A5010AA5000BA60109
A50107A50106A60206A50004A70106A70007A80108AA0108A80106A60106A50106A20105
9F0003A00103A40007A70108A60107A70106AC0209B50811B70A11B2040DAC010CA5010B
9C00099800079200068D01058700038201047D00047F01057C0104750101790B01418D01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00855A31B8B0AFCBD3DCCAD4DDB1BDC67081868D999E79767B321A23C0B4BCCDD2DB
C7D2DB1C242E110A101F0708371500C3943D99591D6B08018F0709A8060DB1070DB5060D
B6040AB90509B90509B80308BA0308C4070DC80B0DC50809C40907C7070ACA090BCA090D
C5090CBC0308B80206BA0409BD050ABF060BC3090CC00409C10408CA0A0ECA0C0CCA0D0D
C90C0DC2070CBF0B10A1141A3C0307AEA4A5E2DEDFE5E5E5E5E5E5E4E5E7E5E6E6E7E4E5
E5D3D1AF6967A92022C5161CC71318BE181E7C11183C1C21BFBCBDE2E3E1E2E2E0E3E2E0
E7E7E7E8E7E8EDE5E7F4D8DBC57E80AA2224C21617BE1114A51A1F4403078B8183DCDBDB
E2E2E2E2E2E3E1E1E3DFDEE0E0DFE1DEDEE0E1DDDEDBC1C29D4C50A0141DAE0913B0050E
B2060EAC0109AC030BAA020BA70209A7030BA6020BA60109A7010BA7010DA9000BAF010A
B3030BB10409AD0207A90006A90105A90108AA0107AA0107A90107A60106A50105A20104
A00004A00105A30108A50109A50105A60004AE040BB3070FB3050EB0030DAC020DA4000B
9D01099801089200068D01068801078100057C00037C00057A0105720002750A02428F03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF007A4B23BEB3B1C3C9D3C7D2DA7E8D959DACB2838E94625E61301922C7BAC5C8CED7
B7C2C8151B22160A0E2206054F280BD19F46803A0D750A038C04079C030AA8050AB1070E
BA080DBC080BBE080ABD0409BC0308C6080CC90B0DC30809C20708C8080CC6070AC1040B
BA0308B50208B60409B50309B9050BBC050BBE060BBD050BBF050BC1070CC5090CC3080B
C40A0CC0070CC10810B2141B570709796769D7D7D4E5E5E5E4E4E4E3E3E5E5E4E6E6E2E5
ECDFE0CB9998A32E2CC21B1CC81517C315199B192039030A8F878ADCDADCDFDDDEE0DFDF
E3E4E3E4E5E7E7E5E4F4E4E5D8A7A8A12B2EBE1819C01113B3181D610A0F584548D1D2D3
E0E2E1E1E2E2DFDFE1DFDFE1E0E0E1DEDEDDE1DFE0DECDCFA5686D92171EAA0A12B20810
B2060EAD030BAD040CAE050CAA040BA6020BA6020CAB050FA7010CAC010DB2020DB7020B
B9040AB8040BB3020BAD0109AA0108AA0108AA0107AC0309A90108A60006A40106A20006
9F01059E0004A10106A50108A50106A50106AA0108B2050EB80A13B0030DAA020CA4020A
9B01069700069300068D01068801088001067D01067C01067C0306740103730801438F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00956A42AFA49FCDD3DBBFCCD3AAB9BF92A0A57B84885A5555341C23CEC3CCCED4DD
A5B2BA0F131D18090F2205046E471ECD9A437025047A08058E03089300059C0105A60107
B5070EBA060DC0090DBE050AC1070AC90C0ECA0C0DC90B0EC40709C7070CC5070CBC030A
B6020BB1020BB0030AAE010AB2060DB9060FB7020BB8030BBB050DBE060CBF070AC2090D
BF070AC40A0DC50D12BC141B790C1346292AC5C3C1E3E1E2E2E0E1E5E3E6E2E2E6E5E3E7
EAE3E3E1C1BFAA4B49C02322CA1618C9161AB0181E5A09125F4E54D5D2D5E3DEE0DFDEDF
E0E1E1E0E4E5E1E3E3EAE3E2E9CACAA54549B41A1FC01217BB161D7F11173A181BC0BEC1
E0E1E1DFE1E1DDDEE0DEDEE0DFDFE0DDDDDEE0DFE0E3D9DAC4979B8C2126A90E14B20810
B0060EAC020CAD050DAC040BA9030AA3020BA3040EA6010CAC020BB4060EBA040EBB030C
BD050DBC040DB8030DB3010CAD0109AB0209AA0107AA0107A80007A70108A60209A4020A
A10107A00106A10207A00107A00109A40108A80108B1060FB20810AB030AA60108A00006
9C00069800069301068D01058601078201077D0107780104780102750202740700418D02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF009B7048A79B95D1D7DFC3D2D9B6C7CE75858C8A92976D6869372228D2C9D0CDD4DE
8F9AA611101C18080C2106028B6529B48538530901800B0D93040B9C030CA3040BA90108
B4040CBA050EBF080EBD0409C1070AC80B0DC90B0BC9080BC6080AC50608C3080CBA050A
B5020BAE010AA702099F0108A00308AE060FB5040FB9040FB9040DBD050DBF080DBD060B
BF080DC0080DC20A0EBD0F16921016330506A5A09EDDDDDDE2E2E1E1E0E2E2E2E3E5E3E5
E6E4E2E8D4D3C07A7AB22627C7191BC51014BA171C7A0F1838191FBCB8BCE1DFE2E1E0E2
E1E1E3E0E1E4DFE0E1E5DFDFECD8D9B56D71A51D23BC1119BF141B9C181F3B0307A59C9F
DEDDDFDFDFE1DFDFE1DCDDDFDEDEDFDFDEDFDDDBDDE3DCDDD1B0B294373CA71318B2090F
B1070CAE050BAF050EAC020BA8040B970004950106A5040CB2070FB8070EBA040CBB030C
B90209B90209B9030BB4020CB1030BAB0006A70105A70105A80107A60108A50107A30007
A10106A00105A001079801069201089A0109AB050DB1060FAD040CA70107A60108A00107
9B00069901079502078B01058301067D0106780105740002740101740101750700418E03
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00805328C9BBB4C6CCD4CAD7DF80929A95A5AC818A91534C513B242BD4CBD2D3D9E3
767E8A130B1919050C1F0501A37B37905E245707057D0509900007A3040BAB0309B3040E
B7050DBA050CBD060BBC0309C0080AC7090DC9080BCB090CC8080AC6080DBB0509B20207
B0030AAB020A9D00048F00028B00019C0107B0060CB5040BB8030BBC050DBC070DBB060B
BD080DC20D12C00B10BE0C14A7141A4704067F7576D4D7D6E1E3E2E0E2E1E1E0E1E2E0E1
E2E1DFECDFE0D0A1A2A23032BC1B1CC51719BD181A951A1E3B070C978F91DCDBDDDEDDE1
DFDFE1DFE0E2DEDFE1E2DFE1EFE1E3C49193972429B11119BB0F17AE192254050A6E5D60
D6D6D9E0DFE1DFDFE0DDDDDEDDDDDEE0DFE0DCDCDDE0DDDDD8C3C2A3595A9C1419B00B10
B2080DAF050BB0050EB0040EAE050DA3040A9B0206A8050AB60610BA050DBA030BB9030B
B90308B90509B70208B5030AB20409A80004A20004A00004A60208A40006A20006A20107
9E01059E00049F01059802068900038C0003A9090FAE050DAC030BA80208A501069E0006
9900069401059101058901047F0004770104760205740103730101740202760A02418F04
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00825021B5A59DD0D6DEC2CED7ABBAC392A1A97F878E51464D462F37DAD2D9D2D8E3
5F6571180C1820080D2A0C00B28841743C1A63080587050D9C050DA8030BAF030BB4040E
B6050DB8050AB90409BA0308BD0508C7090DCB0A0DCA070BC6080ABE0409B20207A70004
AB020AAA010BA40208A003099E0408A20206B3080BB40408B40309B6040CBA070FB8060C
BA070CBD080FBE0912BB0913B01119660A0D493234CACBCBE2E4E3DEE1E2E1E2E2E3E2E2
E4E4E2E6E1E2D8BEBEA55756AA2D28B62D25B12F289B342E5E2B2780706ED5CFCDE3E0E1
E2E2E2E0E1E0E0E2E1E1E0E3EAE2E4D5B1B2973538AC141DB90D16B5131E710D15402729
C5C6C9DFDFE1DFDEE0DFDFE0DFDFE0DEDEDEDEDFDFDEDEDEE0D3D4BA838591191DAF0D13
B50910B3070DB1050AB00207B7060CB90910B1060BB00308BA070CBC050CBD050DBB0409
BB0409B90408B50207B20306AD0205A501049F01049C0003A10207A10005A10107A20207
A100059F0004A001059E02069A050A920107A5070FAA040BB00710AA030CA602099E0107
9600049301058F01058700047F01047500027201027100036F00036F02027B150C46960C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00814B1AA08D83D2D5DDC3CED9BCCAD676868E838C936C6369533F49DCD6DED0DAE5
424A56170B13230706472108BF90465C1F0967050591060FA7060FAF050DB3040DB7060C
B60509BA0609BB070ABC060BC0080AC8090DCC0A10CC0A0FC3080CB70309AE020AA70007
AB0209AD020BAD030BB0040CB3080DAF0407B7080AB80509B6060CB3040DB5060EB8070E
B8070DBB080DBE0B13BB0914B40E158B141832090CB4AFB2DFE1E1E0E1E3E1E3E2E1E1E1
E1E2E1DFDEDEDFD4D3C49F9BC58B80DA988CD99E91D2A296C7ABA2C8B9B5D1C9C5E5E0DF
E3E2E0DFDFDFE1E2E4E0E0E2E5E1E3E4C8C9994347AA1820BA0E16BA131A8A151A310A0B
B4B4B4DCDDDDDFDDE0E1DFE2E0DFE1DDDDE0DDDDDFDEDEE0E5DCDFCDA3A7922930AF1118
B70911B9080EB9080BBA060ABD070CC0090EBE080EBB050CBD060BBC040ABD040CBD040A
BA0208B9030AB60409B30409B1050BA90208A201059B0001A10206A10006A30107A60108
A50208A20005A10106A00006A2040B9F010AA8050EAE050CB0050EAC040EA6020C9E0007
9800059201068D02078601057E00047701047402056F01046A010369010273140D44980F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00834F1ECBB8ADC4C9D0CCD8E28898A18F9EA5899297544B525D4A53DAD6DECBD7E0
2E3741180C132107056A4421BC8B4454110070050790020AA8060DB0030CB3040AB8070C
BA070ABD0709BD0809BE070BC2070AC8070FCA0910C8090EBF070BB40209AE010AAB0209
A90007AD020AAF040BAD0208B20509B20407B6070AB60609B3040AB3030DB1030CB4030B
B8070DB7060CBA0B11B80812B50912A5171E4B020778636ACFCDCFE2E1E2E0E1E1E1E1E2
DFE1E0E0DFE0E3E0DFE7DEDBE9DDD6EEDED9EADFD8E9DED9E7DFDBE6DFDEE3DFDDE2E0DF
E0E0DEDEE0DFDDDFDEDEDEE0E2DDE0E5C7CBA0484FAD171FBF0F16BB0E149B1419380002
888284D7D8D9DEDCDFE1DFE4E0DFE4E0DFE4DEDDE2DDDDE0E1DCDFD7B7BC9E444CAA131C
B7080FBF090EC50D10C2090EC3090FC0090EBB050DB8050DB9050EB7040CB9030DBB040D
BC040DB7020BB5030BB2030BB1040DAB0109A501079D0003A10106A40007A50107A70106
A90108A70108A50106A40007A30109A6010AAB040CAD0309B0050CAB020CA6010C9F0109
9901079201088801077F02067A01057501037301046D01046800036401026B110C4D520C
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008B5323B8A49CC9CFD6C3D1D9A4B3BA9AA9B07E868B41353D6B5962D9D7E1C0CAD5
1A222D180C132007068E68309D692F5E0A017C040798060FA9080FB1040DB5050CBA060C
BC060ABF070AC0090BC1080CC1060AC6080FC3060DC50A10BA0409AF0006AC0109AD020A
AE030BAF020AAC0208AB0106B10408B10207B4050AB2050AB0020BB3030EB3030DB8060E
B7060CB5040CB80910B70711B60910B01017820E174B161FAE9AA3E0D9DEE2E0E3E1E0E3
E2E0E1E4DFE2E4E0E2E4E1E1E6E2E1E4E1E2E2DFE1E4DDE0E6DEE0E5DCDFE2DBDEE2DADE
E0D9DAE0D7DBDDD4D8E0D3DADFC9D0D89FA9982630B1111BBE0D13BC0911AA101955050A
5A4B4DCFD0D2E1E1E3E1E1E4E3E2E7DFDFE2DEDDE0DEDDDFE1DEE0E2CCD1B86F77A2161F
BB0A10CA1114C90D10C6090FC2080FBF090FAE0309A40207AA040CB3060FB2020CB5030D
B6030EB4020CB5030DB2030DAD020AA90108A502079F0104A30207A50107A60007A90207
AC0309B1050BAD0209A70007A50107A70208AD050CAD040BAD040BA8010AA6010AA00109
9901069001088100057601057600087601077101066A00046701026300016A0F0D5B0F0D
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00905323AD958ECFD4DBBCCCD3C0D2D974858D6A7379493F46786972DAD8E3B3BBC7
13182214070E1F0602AB8243743C1971120888060A9A040CA50209B1060EB4040CB9050B
C0090EBF060CC0080BC1090BC0090BBE060BBA0209BC080FB3040BAD0109AD020AAE030C
AC0109AD0208AB0205AD0208AE0107B00209B2050BB2050BB2050CB2020CB3040CB6050D
B6050CB7070FB5060DB80A12B5080EB60C13AB131A7E0D186C232FB1838FDBC1C7DECAD1
DECACFD6BFC8E0C7D1D9BCC7CEAFB8CAA7B0C9A1ACC89CA8CF9FABCA96A1C68F99C38793
BC808BC0808BBD7987B97080B76271A63540AB1721B60C13B9080FBD0A0FB40F15710B10
3A2122C6C8CAE3E4E6E3E2E5E0DFE4DFDFE3DFE1E4DFDFE1DFDEDFE4D8DACE9A9D9D2125
C11416CA0E12C6090EC6080FC3070EBE080FAF050C9D0106A00006AB020AB0040CAF010A
AD0009AE010AAC0109AB0109A90109A70107A40207A00005A40107A60107A50107A60005
AC0208B4060DB2060BA70104A60105A80208AA020AAB010AAA030BA80209A50108A10107
9901049303088302067600067801097300066E01066B01036501015F00016309095F100F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00874B1AB2978EC4C6CDCBD7E08FA1A8768A8E7884883B373C837680DBDAE599A1AD
0E101B1304092D1001B78B4A5B220A60060285030A9E050DA60309B0050BB4040CB7030C
BB060CBE070CC1080CC1080BBF0709BC060AB60308B4050AAB0108A90007AC0209AC010A
AB0208AB0307AA0407AA0208B0050BAC0109AF040AB2050BB4050BB3030DB3030DB6050E
B6070EB6070EB3050AB70A0EB70A0EBA0E12B70E14B0111AA21621931F2DB65864BD6775
B45F6CAB5160AB4E5CA84556A03A489E3140A330429F2A3AA02836A22735A62534A7212F
A81F2DA71D2AA71D2AA91B2BAF1A27B3141CB80F15BD0F12C00D11C51114BF12168F1217
310508AFB0B3E5E8EBE2E3E5DFDFE2E1E2E6DFE0E4DEDFE3DBDDDDE4DFDFD4AEB09F3537
BD181BC50E12C20A0DC2080CC0080DBA040BB3030CAB030BA70209A80108A90108AA0108
AA0108A80007A60006A60007A40006A50107A30107A10107A50109A60109A60108A70107
AB0208B5070DB4060CAD0106AB0207AB0209AC030BAD050CA90309A60108A70208A20106
9A01069201078901087F00077F02087802067001046D010467010260010261080664130F
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00894A178E6C62CFCDD4CAD6DE9CAEB493A6A6828B8A292324978B92DBDCE67E8691
100D19170407492913B78A4B4D12015D010287060E9E030EAA050AB0040AB4040AB6050D
BB060DBD060BC1080DC1080BBC0406BC060AB8070AB20409AB0109A70107A70108A80108
A90209A80208A70208A70309AA0308B0040AAE010AB3040EB3030DB2040DB2040DB4040F
B60610B80811B4070EB5090FB70A0EBC0D14BB0C13BC0D14BD131AB5111BAE131EAC1623
AC1723B11926B21722B51823B3141EB2101BBC1823B91722B7131DBA131EBC121DBC121E
BB111BBA121BB61218B81019B70E16BB0F14C01315C11213C71417C91115C81518A6171B
4102058C878BD8DCE0E5E6EADFE0E4E2E3E7E3E4E8E2E3E5DCDDDFE3E0E1E5CDCDB15E60
AE191DBD0D0FC00C0EBD070ABF0A0EB7030AB20108AE010AAB0109A90006A70004A80005
A80007A70007A60107A50107A40107A10006A20107A30107A60209A70108A60108A70108
AA0209B1030CB4060DAF030AB0050CAE030AAE030BAC030AA80208A80309A60207A10106
9A01059200078B01088601078001067900047201036B00026800036201026103025F0A06
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008C4816886256D8D1D7BEC9D0C0D1D87E8E92767B7D2C2024A79AA1DADCE5626975
120B141B04046845259A69364D060174050C8F030DA0020DA80209B1050DB3040BB7060E
BC070EBF070DC0090CC0080ABB0405C00B0DB40407AE0107AC030AA90108A60104A50006
A70208A60208A001069F0004A60208AF0309B1020CB5040DB3030DB2040DB0020BB4030E
B4040EB80611B70711B4050DB60A10B5090FB70A13BD0D16BD0F15B80C13B80F15B20C14
B71217B61116B81317BB1418BA1316BB1218BD1318BB1319BA1318B91117BD1519BC1317
BC1517BB171BB61719B8181AB61415B81515BA1615BC1415C11517CA191BC61717B11D1C
5E0C0E5F4E51CED0D3E0E2E4E4E6E8E5E8EAE4E5E8E3E3E6E0E0E3E1DEE1E7D9DBC48589
A42123BB1010C10E0FBC090BBB080EB4040BB1030CAC0109AC020AA90107A60103A80104
A80007A70007A40004A40105A40207A00006A00005A30106A70208A60107A40007A50008
AB030AB1050EB1040BB0040BAD020AB0030CB1040DAB0108A80007A80108A70209A10108
9B01079400058E01068701067F00037701037001026B02026601026202016001015C0502
00FF0000FF0000FF0000FF0000FF0000FF00
00FF008F4A18A27A70C6BFC6CCD6DE96A8AF7E8D9384848B2C1D25BAADB6D8DBE5444A56
180C15200404916B3B784322620C0485080E9A040DA6030CA90109AE0209B3040BB8060D
B9050CBD050EBF060BBD050ABC070BB60409AC0106A80107A90209AA0108A80206A90209
A80309A70208A40107A30108A70209AF030BB4040BB4040AB20309B3040DB2040DB4040E
B60610B70510B80711B5070FB1080DB0090DB30D10B71212B71112B61213B61514B41513
B11712B01714AE1914B5211CAF1D19AE201CAD211DAE2320AB261FA6251FA82A21A92B25
A82E28A32D27A23029A33029A4312AA6312DAB3631AC3730AE342EB53531B83733AC3B36
732D294B3633C3C2BFDFE1E0E1E4E3E5E6E6DFE0E2DFDFE3E2E0E5E0DEE3E2DADECFA5A8
942829B31615B80E0DB90E0EB2070AB0040BAE040CA90108AA0209A80107A50004A80106
A80007A60007A50106A40105A20106A20107A40007A50108A50107A30006A30009A6010A
AA0209B0050BB4070DB2040CAF0209B1030CAE030BAA0108AA0209AA010AA9030BA4010A
9D01099401078A01078402067F01047C01037401036A01016100005F01015E02016C1813
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00934E188E655CCCC7CFCDD9E28D9EA58B989F82818A2E2028C2B8C2D2D5DF2C303C
190B12270902A87E475C230D5F070184060B9D060EA7040DAA040BAE050EB40810BA0811
BD0810BC050DBF070DB80209B6050CAF020AA70007A30005A60006AB0209A80106A90209
A90209AC0107AD0108AE020AAC0209AC020AAD050BAE0407B2060AB3060CB3060CB5050F
B3040DB70810B4080EB10C10AC110FA81610A51A12A41D13A22116A3261AA62E23A9372B
A63E30A44538A74F42B9655BB7675CBF736AC87F76CC867CCE8E84D4998FD79E92DAA59A
DFAEA2D2A69BD9AEA2D9ACA3DFB3ABE4B8B2E8BCB5E7BBB4E9BAB3E9B7B2F1BEB9ECBFB9
DABDB6CABFB8D9D7D3DDDCDCE0E1E1E1E2E2E1E2E3E0E0E3E0E0E3E0E0E2E3E0E2D9C1C1
975451992B27A1211BA11A15A117139F100FA00A0CA20409A30107A60107A70107A80109
A80108A60007A50106A40008A5010AA5000AA50009A40008A40106A40107A6020AA50108
A80308AF0609B30509B3040AB2040AAE020AAA020AA90109AB010BAC030EA8010EA4010C
9E010A9300088001057701027C01057C01047600026D01026300015E01015B02027E2E29
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00944D17895C50D1C9D2C1CED6BCCBD36C7A8168666E30202ACDC5CFC3C9D2191F27
17090A381707B185514B10005B03027E030899040DA3060EA1060B9C0207A20408AE070D
B7090FBC070DBD0810B2020BAD0109AC010AA80209A50106A70108AA0009A80108A9020A
A90006AD0107AF0207B1020BAC030AA601089B0103A00105AF070DB0030CB3060CB60610
B2040DB40A10A10A0E88100FA23F35AE5648B56858C47F71CC9080D59F90DDAB9DE5B7AC
EAC4B8E8CABDE9D1C6EDD6CEECD8D1EBD9D3ECD9D6ECDBD7ECDCD8EBDEDAEBE0DAE7DFD9
E3DFD8E4DEDAE5DFDBE4DEDBE5E0DDE4DFDEE5DFDFE8E1E1E6E0DFE4DFDEE6E1E0E7E2DF
E1E0DCEAEAE6E6E6E6DEDEE0E5E6E8E3E4E5E1E2E3DFDEE2E0DFE3E0E0E2E3E2E4DAD3D3
D3BCB6C99F97D09891C0817AAE6961A1544C9B3E3A9018179A0509A50108A50007A60007
A80108A70107A40005A50108A50009A50009A6010BA40008A70308A60107A50109A40109
A60308AC0509B20409B5060CB3050CB00309AF040BAD020BAC020BAB020DA8010DA4020B
9D010994010A8102057100017701057A01067601037001036701026002015A03027D302B
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00954D1883534ABDB2BCCDD7E0A1B0B86F7E836B6C71332730D4CED7AFB7C110161D
18080654301C98683B4806006305067F020898040D99030B9100068E00078E0005990005
AA040BB8060CB9070FAB0109A50009A9020CA8030AA70107AC030AAB0209A9020AA80108
AB0207B1040AAF0207B1020CAD040BA8030B9C01069E0006AE070EB1040DB4070DB4040E
B3050EB10911920B0F450201AE8B82E4C8BEECD7CEEBDAD5E7DDD3E6DCD3E6DDD7E5DBD9
E4DCDAE3DDDBE1DDDBE3DFDEE3DFDFE4DFE0E2DDDEE2DBDDE5DFDFE5E3E2E0E1E0DEE1E1
E0E3E3E2E1E5E0E0E2E0E1E2E1E3E2E0E2E4E2E3E6E0E1E4E1E2E5E0E1E3E0E1E3E0E3E3
E1E5E5E3E6E6E5E6E9E2E2E5E4E4E6E2E3E3E1E1E3E2E0E4E0DFE4DFE0E4DFE0E3DCDBDC
E4E0E0E1DADAE4DADAE2D6D6E1D2D1DECBC8DAB8B5A55C5C890A0E9E0108A60109A70108
A70007A60107A60107A40107A30108A50108A50009A50109A40208A50108A3020AA0010A
A4020BA70108B1050EB2040DB0040CAF030AB0030CAF040DAD030CAE060FA8020BA5010A
9E01099201088601087A01037801037C02067600046E01036500025F0101570100792A24
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0099511C78473DB2A7B0CFD6E0A1AFB78C9CA06E70743E373ED7D3DC9099A20B0F16
1706047650317746274D0A015E020483040D9A050F98020B9101088F01098F00059B0108
AB030BB6060DB5060DA70008A10008A50107A60108AA0208AD0208AB0109A70107A80108
AC0308AF020AB0010BB2030CAC0208AD030AAC040BAB020AB3060FB4040EB3050EB4060C
B5060DB50811A11117430103786767D3CBCBE4DFDFE2DFE0E1E0DEDFDEDCE2DEDDDEDCDE
E0DEE0E1DFE1E0DFE1E2E0E3E1DEE2E4DDE3E1DBE0E0D8DFE3DADFE0DAE0DCD9DDDAD5DB
D9D4DADCD3DBDED7DCDCD6DBDFDADDDCD6DADAD2D8DCD3DADDD5DCDBD4DADCD5DBDED8DD
DDD9DEDBD7DCE0DAE1DFDBE0E0DDE0E2DEE2E4DEE5E6E0E7E3DFE3E2E1E5E1E0E5DCDCE0
DFE0E4DFDFE3DCDCE1DCDBE0DAD7DCD9D4D8DDD0D2AB7A7C7E10159C030AA60109A70209
A60108A50006A50106A40107A30108A2010AA3010AA40109A40008A400099F010B980009
9D020AA40109AD030CB0050EAC020AAD010AB2040EB0050FAF050FAB040CA70209A40107
9C01069000068801088201067D01047B01057501036C01026301015E01025801016E1E17
2F880200FF0000FF0000FF0000FF0000FF00
00FF00954A165B291EB3A6ADB3BBC4BAC7D08B989F4E4F54494349D8D8E06A737D0B0A14
1B0705936B454F1F0C4807015B000180020B98040D9701089200069400089C020AAB040E
B5070FB90710B3050BA80107A50107AB020BA70107AA0107AF0309AC0209A90108AA0108
A80108AB0109AB0106B0040AAA0108AE030BB0030AB4050CB3050BB3040BB2050BB40710
B4060CB7060FB2121967070D503436C9BFC2E8E2E4E6E0E4DFDADDD9D1D5D9CDD2D3C6CC
CDBFC4D0C0C5C4B0B7C3ABB5C7ABB2C4A2ABC19FA9C29AA7C89DAAC799A7C0929EBF8C9C
C18C9BC78E9CD599A8D699A7D697A4CE8C9AD593A0D5909FD995A5D592A2D695A6D092A1
D69BAAD09AA8D39EADD1A1AED5AAB5DDB4C0D8B3BFD4B2BCD1B2BBD6BDC6D2BDC6CEBFC7
D0C4CDD4CBD3D3CED5D8D3DADCD5DCDBD4DCDCD2D8B591947E1E239A060EA60109A8020A
A8010CA60008A40006A40107A40007A3020AA3000AA3010BA3010CA4010CA3030D980109
980009A1010AA60108AD050CAE040CB2050EB2060EAF060CAD050CA9030AA7030AA30108
9A00068F00058801078301067D00057A01077400056C01026201015D01015701016F2019
2E870100FF0000FF0000FF0000FF0000FF00
00FF00924A185C2B23AC9DA2ADB5BC929FA8808B914F4D525F575FD5D6DF3C455007050D
1F0B019B724A400F014B030169020686010A99040C9C01099B0109A1010AAB060EB00610
AF0810B20912AD060BAB040BA90209AC020BAC0209AC0109B0010BAC0109AC020AAC020A
AC0208AC0109AD0208AE040AAE0509AF020AB3040BB3040BB3040AB3040DB3050EB4060F
B5060DB80711B40A14900A13520B0FD9AFB5E6C4CAE0BBC4D1A5B0C68F9DC28490BE7A85
B56A77AA5A69A34F5B9E4351A03E4B9F39459B343F9F31419B293A9B25379C24359E2133
A12133A51F30AC2233B22233B72433B61F2EBC2432B82130B92233B71F32B82134B21F31
B22233AF2332AF2638AC2A3AAE323FB23B49B54152BD4B5EC25465C55D6FCA6C7EC47183
C3798AC88495C18897BA8B98BA909DBA97A2BEA2AAB48A8F8F343996070EA6020AA7020A
A6000AA60009A50107A30006A50108A40109A2010AA2000CA1000DA3010CA3010B9F0109
A0030BA00008A40007A9020AAF050DB2040DB3070EB1070AAD050BA60108A6020AA2020B
9B02099100068901078001057B00047800057401036D01036501025D00015701006C1D13
31890200FF0000FF0000FF0000FF0000FF00
00FF00944C1A4D1B11A09295A5ACB06A767B838B91605D636E666ECFD1D9252C35050205
351F137F59373B05005903077D040C90030B9C030CA1010DA5020CAC040FAE050EA4030F
940107970309A10409A70308A90209AA0108B0030CB1010AB20309B00208AE0106B0020B
B2040AB00108AE0108AD0107AD0107B1040AB1040AB3030DB2020DB2010DB4060FB4040E
B5060DB60711B60811AF0D1699111AB84752B64A55AC3A49A42838A62132A51B29A81928
A61322A5101FA50F1CAA111BA90E17AE121CAF141DB1131CB1111AB2111BB5121EB40D1A
B70E19C2111CC9121CD0141FD3151DD31319D6151AD4131AD3131DD2121CD3131CD0111B
D0111BD2141ECB111BC60F19C20F18C2101BC41121C41122C91724C11221BA1425B11324
AE1526AE1B2CA61C2F9E20309927369C35459F414FAD515DAB343F99030DA6020AA60108
A50108A40007A30006A30106A30107A30109A2010AA3010CA3010BA4010AA40009A30009
A20109A20108A00005A50107AC020BB2050FB3060EB1060DAD050CA70109A301099E0109
9A01089201078900058000047A01047801047401036D02036301015B01005601006E1E14
31890200FF0000FF0000FF0000FF0000FF00
00FF00964E1B4D1611A492988A8F968F999D7A82853532397B777DC1C4CB14181F0C0102
593D286A432B3D020164030886050B95010A9F030EA5020DA7010CAE040DA9050E95010A
85000584000498050DA5020BA50007A80107AF0309B2020AB50309B30308B20208B5020B
B4020AB70309B60208B3020AB00106B20408B00509B1040AB3030DB3010DB4040EB4030D
B5050DB60610B60610B50710B40A14B8111BB9131DBB111DBD0F1BBF0E18BF0F17BF0D19
BB0A16B80813BD0E16BA0D13B80B13B70A13B70C14B91217B71115B71014BA0E14BF0C15
C40D14CD1017D21118D20E15D50F14DA1315DA1113DB1318D40D14D60F15D70F13D50E13
D30E14D00B12CF0C14CC0B13C90B12C60812C80914C80A13CE0E15CA0A11C50911C40913
C10712C10B15BB0714B50715AF0915A80915A006159D09179D0511A3020CA70209A60008
A40006A20005A50108A40107A20105A00005A00007A4020AA30109A20109A30109A4000A
A4020BA10007A00105A20004A70007AE040DB2040FB2060FAA020AA9030BA5020A9C0106
9601059101068A00058001037900027501027200016B01026001015A0100570100701D15
31890200FF0000FF0000FF0000FF0000FF00
00FF00974E184F170F927C828F9097727B7F5D65672221268F8B92AFB2BA0C0B11170403
805B3D471A104904046B020786000798030C9E010CA4010DA7020CAB040EA3050B8C0006
7E000380000591020B9F010CA20108A80207AB0004B20207B50208B40109B50309B7030C
B7020AB70208B70207B60209B10107B2040CB1040AB3040BB4050CB6050FB5030CB8040F
B8050EB90711B7070EB8050EB90810BA0A12BA0911BB0712BD0913C00B14BF0B13BE0A13
C00D18BC0811C20D15C00C15BF0E16C00E16BA0B13B70C13B70D12B60B0EBF0E12C91115
CB1113D21118D41217D40F13D71113DE1718DD1416DB1217D50E15D30C12D71014D60F13
D50F15CE0B12CC0913CA0811CE0C15C90913C70610CB0911CA0810C6040DC80811C50811
C2060FC3080FBE060EBA060FB1010AAF040BAA030CA9030BA6020AA7010AA70108A60107
A30007A40107A50108A50108A30108A10007A10108A3020AA10109A0010AA2010BA2000B
A20109A00107A00005A20006A70209AB010BB0040EB2070FA9010AA7020BA200099C0005
9801059001068A01078001057801027401017201026C02036301025C0100590101711D17
388F0800FF0000FF0000FF0000FF0000FF00
00FF00964E19481108947D8295999D596464535C5C26232899929B92929C0B070D1D0602
8F66463C0A0254060A73040C8A040A97030B9C0109A3010BA9020CA9040F9B040B860106
7E00068300088F030B99010A9E0108A50107AA0107B1020BB3020AB7020BB70209B8030A
B70408B60309B6040AB40409B2030AB2020CB3040BB20109B20208B5020DBA060FBC0510
BB060FBE0710BB070EBB070EBD0910B8050DB90710B90510B8070FBA0912BA0A11BB0C11
B70910BC0A14BF0B14BD0914BE0D15BF0B15BD0C14BB0B15B6080FBF0F12C71113CE1214
D11013D31017D41116D60F14D71113DB1415DE1718DB1317DA1217D70F15D60E13D20B0D
CF080DCD0810C8060ECC0813CC0915C80611CC0812CD0911CA0810C6040DC70711C40711
C1080EC2090EBE060CBA060EB4040CB0040CA80107A60107A80209A90109A90109A50108
A50007A50108A50107A50107A10007A00109A00007A001079E00079F0009A3010BA30109
A20106A00007A00008A10008A40109A9020AB0050EB40811AB020BA60109A201099D0107
9600068D00068700077F01067600037301017101016E02036702035F00015B020168120D
3A910A00FF0000FF0000FF0000FF0000FF00
00FF0067720E4610059881837375796A747562686A141115A29BA2636369070207260F09
82573E3401004D00046C010788020A9401099E040CA5030EA6010AA7030F920107800004
7F010883010A8A0109A3101AAD151D9D0007A8020AAE010AB2030DB3020BB50209B70209
B70408B40309AE030AA20207A00207AE020BB7060BB60309B30208B5020CB9050EBE060E
BD050DC1080FC20A0FC40A10C30A10BE050DBE070EC10A12BE0B10BE0D13B90B11B80B13
B2040DBA0A15BD0C14BD0912BE0C14BF0B16BC0914BF0A15C10D13C40D11C70F11CF1116
D21017D20F17D41015D71015DA1315D91214D81114D71014D91116D70F15D91116D71012
D40D0FD40D11D20C13CD0911CC0912CC0912D30E15D00A10CC0910C6070EC1060EBD050E
BB040BBD060CBB060DB6030DB0020BAC030BAA030CA70008A80109A80109A70108A50007
A50007A50106A50107A50108A10109A001099D0108A002099F0107A00208A5010AA50109
A30107A10107A00108A00009A10109A4000AAB020DB10512AB020CA50109A000089C0007
9600088E01088700078001087601046F01026F02026E02036701025F00015A0100610905
388E0800FF0000FF0000FF0000FF0000FF00
00FF0066700E490F07886D6D7472756C7275525757141113A9A3A8434348040102351F19
653D2A3B05034E00066D020A87050C8B010797020BA0020CA7020CA7040D8F0005800004
80010880010A7E010695061099070F950106A5030AAB020AAC0109AE020AB2020CB6040C
B7050CB30309AB03099A0103920000AC040AB9070AB90509B70308B7040AB9050EBB060C
C30B10C90C13C6080FCA0C12C90C13C5080FC50B11C50D12C00D10BC090EB90A0FB7080F
B80911B80712BB0712C00B14C10A14C10A16C10C16C60E18C60E13C90E12CA1013CB0E14
CD0E15D3111AD41016D81317DB1416DA1313D61112DA1417D81015D60E12D60E12D60E10
D81013D70F13D20B11D00B13CC0810CD0911D30E15CD0912CA0810C4060DBD040BBA030C
B9030BB70209B7030BB5030DAD020AA80109A8010BA8020CA60108A60007A70107A60007
A50106A50107A40107A10107A00107A00107A00008A001089E02089D0106A2020AA20109
A100089F00089D010A9D01099E010AA00109A5010AAE050FAA020CA6010AA2020A9B0109
9501098D01088700078101067301036600006901016D01026A01026301015C01015D0501
378B0600FF0000FF0000FF0000FF0000FF00
00FF003995015318107F63628B8788595D5D4244421C1717A5A2A526262A05000150392A
3F1B1337000359030C7A050F88030B84000492020B9F030DA5030CA2040D8F0107840005
8001077C020970000482071085050A880005A1020AAB030BAD030BA90108A60006AA0108
AF0308B5050AB2050CAC030BA60308B3040BBB050BB90308B90409BA060DB50109B50106
C30B0FCE0E13CE0C11D31016CD0C13C6080EC50C11C30C12BD080FBD0912B8050EBD0A12
BC0A11BD0C15BD0914C00912BF0810C40B16C70F17C70E15CC1216CD1114CC1011CC1215
CB0E12CE0D15D11116D41215D31012D91516D71213DB1618D91415D81113DB1416D91013
DA0F13D81013D50D11D30D14CC0810CD0B13C8050FC7050FCB0913C3050EBB030CBA030D
B9010AB7020AB8040CB3020BAE020BAB0209AA030BA6000AA7010AA60107A60004A70207
A40107A40008A20108A00005A10006A30107A201079F01099901069701069D02069F0105
A102089D01089B01079B01079B00079E0008A20109AB050DAB050FA6010BA1010B9A010A
9300098E00098800088101067802046B01016B01026D01016B01016602015E00015B0200
33870200FF0000FF0000FF0000FF0000FF00
00FF003B9701430A038163636B66675A5B5C6362612D2727A8A7A91212140600005E4433
2706013901055E010A8003108C030C8C000895020B9C010AA0020A9C020A8F0107870006
8501067D0106670103620104690001830105A2030BAC020BAA0308A10004A00004A40005
AC0207B5050BB30209B30109B5040ABA050CBE050DC0070DBE060BBF0810BA040BBE070C
CA0C11D10E12D51114D50F14D51118CB0B12C3090FBF0910BD0910C00D12BC090EC00C12
BC0B0FB90B0FBB0B10C20B12C70F15C80F15C71015C81115C81113CB1215C91014C81215
C51413C71517C71517C71416CA1616CE1816D21B18D41B19CF1513D01512D71919DA1719
DC1317DB1014D90E13D40B11CD060FCC0811C90712C6040FC80712C2050FBB020BBB020B
BB030BB7010AB5020DB2020CAF030CAD020AA90108A70108A60108A60308A50207A40107
A40108A20108A10107A00006A10106A10107A101099D01089401059200039700049B0004
A001099F01089E01079C01069C00069E0108A1010AA7030CAC0710A6010A9E0209900107
8C02098D020A8801088101057A01037202026E01026F01026D01016801016101025B0100
65100300FF0000FF0000FF0000FF0000FF00
00FF00399500460A027251536E68696A6A6C4544443E383A9B9B9D0708090B0401533D2E
1C01003A01065F030A7F010E8D010C92000A9B040D9D020A9A000997020A9101098E0108
8D01088A020A7A060E9F3B4295282C93060DA4020AAB020AAC0408A70104AA0306AC0308
AD0306B5060CB60409B8040BBB040BBC0309BE050DC0060DC0070DBE040DC0060CCB0D13
D00D13D41013D00E0FD20E12D41014D00E14C90E14BF0810C10F14C11214BD1111BB1212
B71412B71613B81614C11617C31415C51215C81316C70F13C91113CA1217C1121AAC161B
AF2C27B23631B13835B43B38B63D39B9413BBE443EC54842BF3F3ABE3D3AC33C3AC52A2A
CD161CD10B11D60D12DA0E16D30B15CF0913CD0912CB0811CA0710C60610BF040CBE050C
BD040CB8010BB3010CB1020CAD020AAD030CA9010AA70108A50007A40109A20008A40007
A50108A30107A00106A00007A00108A1010AA1010B9C00099902089401049601059B0106
A0020BA1010B9E01079D01079C00089C00099F020B9D0109A1040DA1030D970209820004
7D00048301098001067D02067A01047400027200037100026F01026901016302025A0100
64100400FF0000FF0000FF0000FF0000FF00
00FF003A95004A0B04714F51877F7F5E5C5C3835324D45477C7B7E0201021C130E432F25
1800003601045D02087F030E8E020D93010B99020B9C010C96010A93000B92010B92010B
93010B93020C950F1AB73B46A31D269F040BA60208AC020AB10409B20308B20308AF0208
B00209B30309B70409BA040CBA020ABC040CBE070CBE050DBE050BC4070EC70810D00C12
D20E13D41014C8070CCE0B11D00E11CE1113C41013B81015B4191BAF221DA92C25AD3C35
AA4138AF473EAF433BB03B35AD2C28B12320BE211FC21817C71515C81518A70D13590001
AC7774E1B6B1E5BCB6F0C8C4E9C2BDEFC7C2F3CAC5F2C8C2F3C7C2F3C4C1FBC4C4F1999B
B92A2DC60F14CE0A0FD50C12D60E15D00910CF0910D00C10CF0C11CA0A11BF040BBA0308
BD070DB5020CB0010BAE030BAB0209A8020BA7010BA6010AA50009A5010AA40009A40008
A50007A30106A10106A20208A2010AA1000B9F010B9D010A9C01099B01099800079A0108
9C01099E010A9D00099D010A9C000B9C010C9C000B9501099100089C061195030E840308
7A00057C01087300046F00037402067501047100036F01056F0105680103620202590100
630F0300FF0000FF0000FF0000FF0000FF00
00FF003B96004B0B017C58596D656452514F4742405952556160630401022F211C2A1714
1900003700015B00047C010A89000A92020B97010A99010D92010A91000A8F010A91010A
91010A93010B91010C95030EA1060FA40208A80307AC0209B0040AB2040AAF0307AF0209
B4050CB5020AB60309B6010AB9040BB90109BA0207C0050CBF050BC60910C6060ED00D12
D20E10D40C0FCB080BD00D11CF1215BF1314AB1B1A8B1A1B933E38BE7E75DBA9A1EEC5BD
EACAC0EAC9C0E5BFB9E7BCB7DCA8A3D08B85C06962B1413BB62A26BF2120A71B1C450204
665A5EC8C8CAE7E3E1EBE5E5EBE6E5E9E5E4E7E3E3E4DFDEE9E4E4E5DFDFEFE3E4F5CCCE
B5494EC1171CCB090FD50D12D50D12CF080ECF0B10D00D11CB080EC5060DBD040AB9040A
B9050DB2010AB0030CAD030AAA020AA7010AA7010AA70108A70109A50109A20009A10109
A10107A10107A10108A20209A20109A0010B9F000B9F010A9C00089A0106990007980007
9A00069C01089C01089C00079C01089C01099E020A9C010C96020D95030F88020A790104
7C02077F01077B03086C01036B00027301047001026E01046D01046801036202025D0200
67120600FF0000FF0000FF0000FF0000FF00
00FF003B96004B09006F4D4D6961636B6A6A353331706B6C404043040001402E26190503
2200024502056002057701078201058F020B94020A95020C8F00098D01088F020A91010B
8E010B91010B91000A98020BA00309A20106A60105A80106AB030AA80107A40005AA0106
B20409B7030CB20107B6020BB8030ABF060CC1060DC2060DC2080EBE030AC2050BCC0B0F
D00D0DDA1214D40F11CF1415BD191B8A13117B322CB68D86E0CBC3E7DCD7E9E1DFEAE4E4
EAE5E4E6DFDFE6DFDDE9E2E2E6E0DDEADDDAE8D4CFE1BAB5D2918CBD5D599F3835521215
2E252BB9C0C4E0E3E5E3E2E4E8E7E9E3E3E5E3E3E5E5E5E7E8E8EAE4E3E5E7E3E4F0DADC
C67478BD2128D41219D50D10D30C0FD10B11CD0910CB0810C5060DBF040BBA030ABA050C
B6020BB3020BB0030BAB0208AA0209AA030BA9030AA60107A80209A40008A10108A00008
A00007A001079D01079F01079E01079E010AA1020CA2010B9D0109990005990106990007
9A00079900059B01069D01089C01089D01079D01079C01099B030F91010D810108760001
82020789020A85030B7B02097300067503077001046C01036B01036902046201025F0301
6F190D00FF0000FF0000FF0000FF0000FF00
00FF003C97004C0A01664142857C7E605F601E1B1A8B868728282A070000412F26150100
2901014A02066101047101047C00038B010893020993020B8E01078C01098E010A91010C
90010E92010C94010B97010A9C020A9F0106A20106A90309A90209A50108A10004AB0209
B5070CB6040AB40309B7020BB9040CBD040CC1060DC2050DC2070EBF060CC40B0FCC0E0F
CD0B0CD30E11CC0F11B61418760A0C7B4544D9C5BFEBE5DFEAEAE4E2E3E1E2E4E3E5E5E7
E7E5E8E6E2E5E4E3E4E4E4E4E3E3E3E2E1E1E2E1E0E6DFDEEBDDDAEDD1CED7AFAB614242
131216A4ABAFE1E5E7E7E8EAE3E3E5E6E5E7EAE9EAEAEAEBECECEEE6E5E8ECEAECEFE3E5
D2969AB1292FD81C20DF1418D50D11D00A10CB060FC5040DBF030ABB030ABC050DBB040D
B9040DB4020AB2030BAE010AAC010AAC020BA80209A8020AA70109A50007A20108A10008
A10107A001079F000A9E010A9E0008A10109A1010AA0000A9C0108970005990106990005
9A01079B00079B00069B00079C01099B00079B010798010996020D8D020B820207830207
8B040A84010681010880030A7501066F02066A01046701046A01056801055F01025D0301
74201400FF0000FF0000FF0000FF0000FF00
00FF003F98004C0900754F50736A6B4F4C4D251F1F928D8F1413140E0806362520160000
2C00034E01056703077201047B00038A02088E02088B01088A00078B01098C010A8F010C
91010D92000B96030D97010B9801099B0006A10107A8020AAA0209A70108A50207AB030A
B1030AB6040CB7030CB6020DB8030BBD040CC0060CC5080FC3080EBD050ABB0407C70C0E
CB0C0FCF0F14BE1014820C0E4B1919C7B5B5ECE7E4EBEBEAE2E3E4E6E5E7E1E1E3E4E2E5
E4E2E5E6E4E7E2E4E3E3E4E6E2E1E2E0E0E0E2E2E0E3E3E3E3E4E2E7E5E4E9E5E3D5D2D0
6E72718A8F91DFE1E3E9E9EBE4E4E6E1E0E3EBEBEDEAEAECE9E9EAE8E8E9E8E8E9EAE6E7
E8C1C6B04149CB1A22DC1219DA1016D20B11CB070FC3020ABF030ABE040DBA010BBD060F
BA050EB6020BB4020AB10109B0030CAB020AA70108A70109A70109A60108A40107A30107
A20006A10007A0010BA0010CA10009A3020BA1010B9F020C9A0209940005970106970005
9900079C01099D01099D010A9B01099A010798010793000596020A90020A810004850208
8B030A8301067B00027F02067600046D00046801056501046902056501025E0101590100
66120700FF0000FF0000FF0000FF0000FF00
00FF003D98004D0A00744F4D655D5C5854552C26288D888C09070919100F241311190101
3101035001046902067401057B000484000784000784000785010988010A8800078B0009
8E010A92010A92000A94010A9600089B0106A10209A7030AA60207A40107A30106A80206
AF0108B5040CB3030BB5010BBA050BBE060BC2090BC5080EC6090FC1070DC2090EC4080E
C6080FC60D13B0181E4E03048E7877E0DAD9ECEAE9E8E8EAE0E0E2E6E4E7E4E4E4E1E0E3
E0E1E0E3E3E5E1E3E2E2E2E4E3E2E5E4E2E4E3E2E4E4E4E8E4E5E9E5E8ECE5E8E9E6E7E8
E6E8E7DDE0DFD2D6D7E7E8EAE7E8E8E4E4E5E9EAEBE9EBEBE6E8E8E6E8E8E7E9EAE7E6E9
F0D8DDBD6871B91B24D6131BDA0F18D70E14CE090FC6060BC3070CC0050DBF060FBD050E
B9020BB8030CB6020AB4010BB1020BAD020AA80108A60108A7010BA6010BA50109A30107
A40108A30108A2000AA1000BA10009A2010AA2000BA1020D9B030B920006940106980006
9A01089E010AA1010A9D00089C02099B00089A02099701099B030B9C040E93040B8A0107
8B00088D020A8701068601068202077301056601036301026401026402035C0202540100
5F0E0400FF0000FF0000FF0000FF0000FF00
00FF003F99014B0A00613C39756B6A6D69692B2428827C810501022A1B1B1B08071D0000
3300015401056C02077100057701057E01097C01077B00097E000B85010A8903098A010A
8B02098E010A90010A97030C9A010A9B02069E0007A40208A101069E00059B0003A10003
AE040AB4030DB2020CB5020CBA060CBE060CC0060CC5090FC1060CC3090EC60A0FC4070C
C80C13B90A10880C11360E0EC3BCBAE7E6E5E6E6E6E8E8EAE8E8E8E8E8EAE6E7E7E2E2E4
E0E1E0DFE0E2E1E3E2E6E2E5E6DAE1D2BAC5C7AAB9D0B9CADACEDEE4E1ECDEE1E7E2E6E9
E6EAEBE8E9EADDE1E2E0E2E1E7E9E8E3E5E5E6E8E8E4E8E8E3E7E8E5E9EAE5E7E9E7E7E9
EDE0E4D597A0AD242DCB1119D71119D70E16D30E14C9080FC2050DC10610BD030EBB010C
BB020DBC040FB6010AB6020BB4030DAF010AAA0109A60109A50009A5010AA6020DA5000A
A6010BA5010AA4010BA3010AA3010AA2010AA2010B9F01099A0209940106960208990108
9A00089E0009A000099F01099E010A9D01099D010B99020B9302079C050CA0050C9E040C
9B030C94020B90030A8E02088602087702076802036002035B00015B01025602034D0100
5D120800FF0000FF0000FF0000FF0000FF00
00FF004099014A09006E4A47766C6A534F4C392F306D666B0500002C1919140101230102
3D01025E03076B02047001047402047601067702077800097D010B83010B87020C86010B
82000681000788000895010A9B010A9B02079E0008A7030AAA040BA60108A10006A30005
AC0208B6050FB0000AB3040BB9060CBD060DBF050CC3090FBF060BBC040BC1080FC1060D
C1070EBA12186C080A3C2727CDCBCBE3E3E5E6E6E8E8E9EBE9E9E9E4E5E7E8E8EAE5E3E6
E2E2E2E4E3E5E7E4E8E8D8DEC38F9AA34659982A3E91294286354C925E74B09BACCACAD5
DBE0E5E4E6EAE4E8E9E5E6E8E5E7E6E3E5E5E5E8E9E3E6E8E4E7E8E4E6E8E7E8EAE5E5E7
EAE2E6E1B6BFA7343FC71821D7131BD40F17CF0C14C90911C2040DC1060FC0060DBE050C
BA030AB90109B8020BB7030CB5030BB3030BAD010AA70008A50007A40109A4010CA5010A
A7010BA5010AA3010CA1000BA2010AA2020BA000099C020A9203098801078F030A96010A
9A010A9C010A9F010AA1010CA1010DA1000CA1010C960108850002900206A80810AB060F
9F040E8801078402078E030B8101056B01026502045B00015400015800025802044E0000
62160C18C50100FF0000FF0000FF0000FF00
00FF003F9A014A0A007553516A625F5854514A42444C474B0801023522220E00001F0001
4705066003046A020270010271010373000574000779010A7C020A7D010B81010A82000B
80000680000689020896020B9D010A9F020BA00108A8030AAE040CAC030AA60107A80208
AC0208B3040DB10309B00309AC0106B30309BC070CBC050AB50105BA050DBD060FC20710
C60A15B40E175D0305493638D4D1D4E6E3E6E8E7ECE7E8ECE5E9EAE8E9E9E7E5E9E6E4E7
E5E3E4E6E4E7EAE3E7D1AFB79E3946BE1F2DCA1823CC1827C6212EA61D2E6F11226B394B
A89AABCECEDBDBE0E5E2E6E8E1E4E4E2E3E4E3E4E6E4E5E7E7E8EAE7E8EAE7E8E9E4E4E6
E6E3E5E9CED3AE555EB81A23CA0E15CC0C14C80910C5080DC3060EC4060DC4060BBC0208
BB0409B8030BB7020BB6020BB50209B10109B0020BAC0209A80108A7030AA40108A50009
A50009A20109A20109A3010AA3010AA2010A9F00099A01088500046C00007301058D030C
9801099B01069C00089D000AA0010CA5010CA6010D9F020D920208940208A70710A9050E
98050E78000372000188050A8503096D01026402036002045B00035B0103590202530100
61120A318A0200FF0000FF0000FF0000FF00
00FF003D9900460A006847477269696965675E595B2F2C2E110807251313100000250001
4000015B00016900016D02026D01037001077201077301077101077400077F020A84020B
8401078300058A01079A040DA2030DA0010B9F0008A50109A90209A90108A80206A90209
AA0106AF020BB0030AB4060FB0020AB30209BA060BB90308B70207BF0810C1070EC60A13
CB0C18BB101A660509412E2FD6D4D7E8E6E9EAE9EBE9EAECE9EAECE7E7E9E8E8EAE6E4E7
E8E8EAE8E6E9EAE1E3B5858CA82A33CA161FD01016D61215E01D1ED81B20C11922981625
5D0D1F69485BA7A7B3C4C9D1DEE3E6E2E4E6E4E6E8E2E5E6E5E7EAE3E7E8E4E8E9E3E5E7
E4E5E6ECDDDFC28089A91F27C10C14C70B11C6090EC70A10C3040CC8060DC7080DBF040A
B80109B7020BB7020BB6020BB3020AB1020AB5060FAD010AAA010AA7010AA7020BA6000A
A50008A50108A50108A50008A4010BA2010CA0000A9C01098F04097703056A0001800207
96020A9B01059D01089F010CA3020DA6010CA6010CA3020C9E030B9A0108A1040DA3050E
96050A7F01047A020584010889020A7802066B01026A0205630001590001550202510100
5D0D0632890200FF0000FF0000FF0000FF00
00FF003F9C03440B006C4B4B83797B4440466C676B1F1A1C180B0B1906071A0101350304
4B02025F02026A02036D00036B01056F01067201057201076D00037201057C010984010A
8201058500078B010897030C9F030E9D01099E0007A20008A40106A60107A60107A60006
A80007AC010AB0010AB3030AB5040BB8050AB9070CB4040AB8060EC20A12C1080FC10810
C1040EC0121975090C31181AC5C1C5E5E2E8E4E4E6E8E8EAE3E4E6E7E7E9E7E7E9E7E6E8
E7E7E9E9E8EBEFE6E8CC9CA3A82731CB161DD21014DC1417E01819DB1417D71618CA141A
B117227310203615256F6B78BFC3CADFE3E5E1E5E6E1E4E5E4E5E7E4E5E7E3E5E7E5E7EA
E2E3E5E7E1E3D1A5ABA02B33C3161CCA0F14CB0C12C90A11C4060FC3050EC4070EBF050B
BE050CBA030AB70409B60309B20209B1010AB0010BAF020BAC0009A90008A80108A80109
A70108A70208A40107A00007A0010BA1010CA0020C9B01099401078701057A0103840106
9602089C02059C0106A0010AA2010BA40109A4010AA0020A9801099B040C9E030C9B0107
A00A0E8F04098803098801078802097B01057100047101046D03055D01025000014D0000
580C042E880100FF0000FF0000FF0000FF00
00FF003E9A01460A007E5A5B7166673E393B767072100A0B2517151302021D0000390202
5302026503036C01026D00036C02067101077602077502087101057400057C0107830109
82000588000989010892000A99010B9C01099F0006A30106A50004A50106A50108A50008
A70209AC010AB2030CB5020CB3030BB00309A90206A40005A80107B80710B5030BB5010A
BE060FC01019890C122A0507B1ADB2DFDEE3E8E9EBE8E8EAE6E7E9E8E9EBE8E9EBE8E9EB
E9EAECE6E6E8EDE5E6E4B9BFA52E37C6141BD41216DF181CDC1519D60F13D30F12D20F14
CC1319B11A235306101D070F9D9CA2D8DCDDE2E4E4E4E4E7E6E5E9E3E3E5E5E6E8E5E5E9
E3E3E6E5E2E5DDC1C7AA4D54B7171FC60E13CB0D13C60910C0050FBB000BBC030DBF060D
C0070DBF060CB90308B70309B5030AB4010AB3010CB1010DB2010CAF010BAA0109A80208
A60107A60108A30109A00108A00109A0000B9F000A9C01099702078F00048901048F0106
9801089B00079C01089D0109A2020CA2000BA2010A9D01098F00069102099D060E9B0309
A0090F96040C8F020A8D02098403087903077402077302066F0205660304590100510100
580B0430890200FF0000FF0000FF0000FF00
00FF003F9B02480B00795455625657534B4E726B6F080102180A0A1101011F01003B0002
5802026802046B01036A00046C01057402087802087400087501087501067C010781010A
84020A8B010B8B010891010A96010B9E010BA20209A60208A60107A30107A20106A20109
A50107AB010AB1020BB4010CB5050DAF020BA80309AA040AAD0309B8050CB8030ABC030C
C1050CC30A12A6141A3A0102847A81DBDADFE6E7E9E8E8EAE6E7E9E6E7E9E9EAECE6EAED
E6E8EAE4E4E5E7E1E0EDCACDAC424BC71922D41118D8141AD61317D00C13D31016D41016
D01017C4171D7E0D142A00046B6269D0D3D6E5E6E8E6E5E8E5E5E7E6E6E7E2E2E5E4E3E8
E4E3E7E1E0E3E4D3D7B56F77A81B23C30F14CB0E13C1040BBE040CBC030DBC030DBD050E
BB030BBF060EBE060EBC040BBC060FB7010CB5010CB5020EB3020DAD020BA8010AA6020A
A60209A50108A10107A20108A20108A001079F010A9C0109990107940104900003950106
9901089B00089C01099C01099F010AA0000AA1010A9E020B96020B90010798030C99050D
91020995070F8B01088802097401066401026800036E01036C0103680203600201580100
5C0C05328B0300FF0000FF0000FF0000FF00
00FF00409C034809007B56548074743B31356A5F62090302180C0C110000280101460102
6003046901056901036801046A01057202077600067500087700097801097801077A0008
8401098E020B91020A9100099500099E030B9F0009A10109A20008A10006A30208A40009
A50108AA0109AE030BB0010AB2020CB2020DAF050DB0040AB7050CC1080DC90B10CB090F
D30E13D8131AC41C215B050748363CCFCDD3E6E7EAE2E3E5E5E7E6E5E6E8E8E9EDE6E7E9
E9EAECE5E5E7EBE7E7EBD3D4B75E63C31F26D11319D4121ACF0F17D10F17D20F15D31016
D31115CB131A9E131A470005382328C9CBCFE4E5E8E4E4E6E7E8E9E3E5E5E4E5E8E6E6EA
E3E3E7E4E4E6E7DEE3CD9CA2A12A2FC1161AC80D11C80B12C2060DC1060EBF070EB9020B
B8030DB9040DBA030CB9050CB60209B7030DB5040EAB020BA4040B9F050E9A040D9F0610
A2040DA4020BA4020BA50207A30106A101089F010A9D020A9A0108960006920004960207
9A02099B02089A01079B01069C01079F01099F010A9F020C9E020D96000A8D01088F060C
8F050C91050C92040C8A020A7702086001036401037104076B00026300006002025A0100
600E07338C0500FF0000FF0000FF0000FF00
00FF00439C044A09008B6663776A6A372C30584E4F0601010902021702023704054F0202
6102016701046302026201026701036E0104730105750108760107750108740005790105
8302098A010A8E020B91000A9400089A010A9C00079D0107A001099E0007A00105A4010A
A60108AA0109AB0109AF030CAC010AAB020AA90108AB0108B00109BC050ACD0D11D30D10
DB1013DF1318D1191D7E0A0E2B1013B6B5BAE1E2E5E6E7E9E8EAE9EAEAECE6E7E9E7E8EA
E9EAECE9E9EBEAE8E8EBD9DAB36E72B6252BC91319CF1118CF1118CF0F16D10E13D20E12
D31013D01218B6161D6D07102C050AA7A6ADDBDDE2E5E5E7E9E9EAE7E7E8E3E3E7E4E5E8
E3E4E6E0E0E2E5E0E4DEBEC3A34147BA181EC1070DC50710C50811C0060EBE060EBB030C
B8030CB6030CB5020BB2020AB2020AB0030BA7030B8B02057A0102A12129CC4B57A6252F
8C030B9E050EA4020CA40107A10207A1020A9F010A9C0008990106970007930006910106
9502089A01099D02099C00079D01079D01079E00079F010A9E010B9A020B8D0106880104
970A0F9703089F070E95040D85020A7101066B00027301066E02056100005E01015C0201
5E0C06328B0500FF0000FF0000FF0000FF00
00FF00419B034A0800886061604F52463B3F3C3437080101080001180000380101530203
6103016302035C00015F01036601046C00057102067301087300077401077401067C0108
83010A8701098B010892010A9401089800079C02079B01069C02059C01079C0006A00108
A50108AB010BAE030CAD030CA60006A40005A70107AF040DB10208BB050ACC0B10D91114
DE1215E01318D314189D12172D0002928F95D9DDDFE9EAECEAEAECEDEDEFE8EAE9E6E6E8
ECECECE6E6E8E7E5E6EDE2E2D5A4A7A92D34C3161BCA1116CC1116CD0D14D10E16D30E14
D10F11D21015C4171C95121A4201076F676DCDD2D6E4E8EAE6E7E9E5E5E7E3E3E6DFDEE2
DFE0E1E0E0E3E4E1E5E9D4D8B2666CAA181FC00B12C2070FC1060FBF0510BD040EBC040E
BA050EB6020BB5020DB3020CB0010BA9020B96060C7000017302069008149A101EAC2B37
7B01078B02099F030BA40209A100099E010B9F020D9D010A9A01069401068C0005850002
8C00059A01099D01089D00089E010A9E010A9D00099C00089E020A9F020B9A020B930108
9A080E9E060CA0060D95020A8600077B02067201027301057202056602025D01015B0201
5B050032880300FF0000FF0000FF0000FF00
00FF00449D054A0800855B5D7C6A6F4E41452A25260F05050F00001B0000380101530101
5F02025F01025B00005B01016201036B01076F0107700107700006740106780106800108
8601088801088A00078F010A9201079500079701069801069700059A00089D01099F010A
A4010AAA010CAE030CAC020BA90109A70108A60006B4050EBC0810C4080FD00D12DA1115
DD1317DA1014D31015B315194602035A5358D2D6D9EBEBEEEAEAEAE9E9EBE8E9EBE9E9EB
E4E6E5E7E7E9E1E1E2E8E2E1E2C0C4A64249BD1921C91218CD1218CC0D14D01018D00D14
D20F14D31015CA141AB1161F61050C3E2C31C1C5CAE6EBEDE2E4E7E3E3E6E6E6E8DFE0E2
DEDFE1E0E1E4E2E2E5E7DDE1C692979E2029BD0F18C30A12C0070FBF050FBC050DB9040A
B9060CB7030BB6020DB7030FB5030FAA040E8403096800018B09129F030EA1020E9E0614
87030B81010799050DA2030AA2010AA1020D9E010C9C010A9A01089400059101068C0205
9001069901089C01079D01089C00089C01099C01089C02099D010A9B010A9A010C9A020D
9C060F93010899071090030B8101067902056F02056C01056E02046801025F01015B0100
5E070234890400FF0000FF0000FF0000FF00
00FF00449D04510B00875D5F705F635045471510100C0101130101280202430202580202
5D01025C01015901005A00025E01016901076D01066D01056E01047301057A0105810108
8401078701088800088D010A9101099201069400069601079700079A00089E030AA0000A
A3010BA7010BAB020AAC020BAC030DAA020EA60009AF020BB40309BD030BCD0D13D41013
D71112D60E12D20F14C0151A680A0C2C1C1EB9BFC2E6E9EDE7E8EAE6E5E9E3E4E6E0E0E2
E0E2E1E2E3E5E1E2E2E5E3E2E4D3D4B86D73B01D24C8131BCD1017CE0C15D10F17D10F16
D10F16D00E15CA0F17BE141B820F1328060AA5A6ADE1E5EAE3E4E8E4E5E9E3E4E6E2E3E6
DFE0E3E1E2E5E1E3E5E6E3E5D3B1B5963139B20F19BE0811BE0811BD060FBC060DBB070C
B6050AB3030AB5020BB7020CB7050FAA07107301055B0002880910A0040CA5020EA2030F
91070E73000287040A9E040EA2020CA1010B9E020A9B00089B0008990108960106940106
9A02099B00079C01079C01089C01089B00079C01099C010A9C030C920008920109960109
9A050F89010785020988030C7900046F01026701035D00016403056402045F01025D0102
60080466140800FF0000FF0000FF0000FF00
00FF00459E03520D008B61615648495247480A07070400011000013002044C03035C0204
5C02015A01015801005900025C00016700046B00066B01056C0103730107780105800009
8401098700078801078C00098D00099100099200079500089801089A00089E020CA0010A
A10109A00006A60207A90108A60108A5000AA9020CAD010AB40207BA0207CD0C11CF0C0F
D00D0ED20E12CE0B13C00E167F0A0F200305888B8FD1D6DADFE2E4E2E2E4E2E2E2E2E0E1
DFDFDFE0E0E0E2E4E3E3E3E3E8E0E0CB969AAA292EC8161ECE1018D10F17D41219D10F17
CF0D16D00E17CE0F16C40E15A3161C3B00066C676FCDD1D7DFE3E5E4E7E8E4E5E7E2E3E5
E1E2E4DFE0E2DDDFE0E0E0E1DDCBCE9C5257A4141CBA0B15BA0611B9050FBB060DB70309
B6040AB3040CB3030DB3020CB6040FA90A126B01044700006C060B90050E9B040C9A020B
8B080E640001730307990510A1020DA0010B9D01099D01079B00069B0207960006950108
9801099B00089B00079C00069E01089E01099C01099C010B9A010D920109910007960109
9A050E8A02097C00048302097F010876010673030A6101035B01025B00016001015F0102
61080566160A00FF0000FF0000FF0000FF00
00FF00469F044F0B007953506A5C5B483D410402020600011401003201014B0201580201
5802015301005101005401015A01016701066B01066E01066F01047300077B010881000B
85020B88010A8801088C01098E010A90000992000A9301089401089700079B010A9E010A
A10109A40108A60107A90209A60107A70008AE030CB8040DC60C0FCC090FD10C10D00D11
CC0B10CB0B12C80B12BD0B139711163101025C595DC1C5C9E1E3E3E1E3E2E1E1E1E1E1E1
E1E1E1E0E0E0E1E3E2E1E2E3E6E3E2E1BDBFA73D42C51921CD1117D20F17D00F14D00E16
CF0D16CD0B15CF0F17CD111AB7151D5B040A3F2E35C1C6CBE7EBEDE6E6E8E4E5E6E1E2E4
E1E1E3E1E3E4DEE2E2E0E2E1DFD8D8A67477931A1FAF0911BA0812B8040FB9060FB6030C
B7040CB6050EB4040EB1020CB2020DA907107403073E000044010366030B7B050C7D060B
6A0408500101680207910410A0030FA0020D9E020B9D02099B0106990208930107910006
9501079901089B01089D01089E01079E01099E010A9D010C9A010C97010A97010A97010B
9D041096040E85000786020B84020B7E02087903096A0003630103630203610101610102
60080467190D00FF0000FF0000FF0000FF00
00FF0046A0064C090086605F695A5D433A3D0200010800002002023D0303500201560100
5201005101025000015101015800006400036C02066D01066E01047201077A01087F000B
84010C87010B8600088A01088E010A90000A92000A92010A9500099800079C020A9E010A
A10109A50109A9020AAA010AA70007AE010AB9050DC2060ECD0C11D20C0FD10B10CA0810
C3070EC40A12C30A11C00B12AA11174F030734272BB6B7BCDDDEE1DFE0E2E3E3E5E2E2E4
DFE1E0E1E1E1E2E4E3E3E3E5E5E3E3EAD1D3AF5B62BA1C24C91217D10F17D10E15CF0C12
CF0E14D00C15D21019CE0D17C2111C7D0A1329080C9EA1A6DEE3E5E4E6E8E3E4E7E3E4E6
E0E3E4DFE3E4DEE2E2DDE1E0E0DFDEB9999A8E2B30A80D16B40710B6060EB70610B6040D
B4030BB5030DB3010EB1010EB1030EAC050F8A060D4D01013400014200044C00034B0002
3F000240000367020B9405139F020E9D010B9D020B9C01079A01069600089001068E0004
9400059900079C01099C01089D01079D01089C010A9E020D9B000B9A010B96020A900107
91010A94020D8901088302097E02097901077501067001026D0103670102620001620202
5E020162110900FF0000FF0000FF0000FF00
00FF00459E054B08009169664E393B372A2C0300000B0101230100400201500202530201
5100005101025201005501015901006300036801056800036C01037100047A02087E000B
82010A86010A86000989000A8D010A9000099100099201089601089900089C0109A0010A
A20109A6000AAA020CAB010AAB0209B4030CBB030AC70910CC0A10CF0C11CB0A10C5080F
C0060DC10610C30913C00910B50F17700A1020080B9C9EA2D3D7D9E2E2E4E2E2E4E1E1E3
E3E4E6E5E5E5E1E3E2E3E3E5E4E3E4EDDEE0C5878DAF242DCA161DCF0E16D20F17D00D15
D00F14D00D15D20F16D41018CF131BA0141C380107747177D4DBDCE5E7E8E2E5E6DEE2E3
DFE3E4DEE3E5DEE3E4DDE2E2DEE0E0D1BEC191454D9E131EAF0711B4050FB3040CB4040C
B3030CB3030EB30111B20312AF040EAD040C9F060D7503094800026124276427293E0507
3300033D00016B020A9604119E020B9C010A9B01099B01099B010A9601099101068E0003
9300049800069B00079D01089E010A9E010A9D01099C010B9C010C98020C8F01098B030A
8C020A90020B8802087502076801066801056B01037202037303066601025F0001600202
5D030062100700FF0000FF0000FF0000FF00
00FF0047A006500900734744553F3D271A1B030000090000240203420202500101520100
5201005100015101005801025B01016200036A01066B00046F01017300027A02067E0109
80020B85020D84010A87000B8A000A8E00099101089502099801089B02079C0109A00008
A10008A6010BA9010BAB0009AF040DB3020CBA050DC50A10C90A0FC90910C3070CC2070E
C0070CBF060CBF070DBE080EB90D14890D132B00036B6A6EC0C5C8DFE1E3E1E1E3E1E1E3
E2E4E3E0E0E2E1E3E2E1E2E4E2E1E1EBE1E4DCB2B6A53138C51A1DCC0E13D21116CF0D15
D11015D20F17D10F14D20E14D11117B7181E55030941353AC2C7CCE1E5E7DFE3E4E0E3E5
DFE3E6E0E2E6E0E4E7DDE1E3DDE0E0DFD4D5A26971911723AD0C17B1060FB1020CB3030C
B4050EB1030FAF0211AB000EA9010AAC030BA70409990C10811E208D4B4DCD90937B3C3F
42000159010584050D9C030D9F010A9B00079800079B000A9B010A970109930107930106
9601079800089A01089B01089D010A9D010A9C01089B010899020B8D010A7E0005810108
8A030C8C030B8503096800025100015C00056D02057401047303056502035B01015D0201
5C030165140A00FF0000FF0000FF0000FF00
00FF0048A206520C0071433D5C4643160D0D0100000700011D0000410203550303550101
5302015401035302005700015E00046501046B01066E0105700103730105760207770109
7201077502097A020A83010B89010B8A010A90020A9501099801089A01069B00069C0108
9F0008A40009A60009A90209AD020BAF010BB00106BF070CC4080DC60A0FC1070CBF060B
C0070CBF080CBF090DBE0A0EB90B119F11194202063C353AA6ABAEDEE1E4DFDFE3E3E3E5
E1E2E2E2E2E2E2E2E4E3E3E3E4E3E4E6E1E2E1C6C7A74C52BC1E23CD1318CD0E13CE0C14
D00E16D00D15D10E16CF0C14D00F16C1131A780B11290C11A7AAB1DCE0E4E1E4E6E1E3E5
E2E4E7DDE0E2DFE0E3DEE1E2DEDFE1E4DCDDB98E9389202BA70C17B10812B1030DB2020D
AF020CAD030DAD030FAA010DA9020BA80109A9030BA2060CAB2E32B1565C8F464D7E2F36
811D2386070F9B040EA4010CA1000B9C01099B01099B0109980108950108910006950007
9800089700089900089C01089C01079D02099B01079A01079402098201077600057F020C
7E01097C010584040B77050A5D01045A00047004087501037002045F01015801005D0201
5A03016A1C1100FF0000FF0000FF0000FF00
00FF0048A3094E0C008E615F4029270F04040100000A0000210101410203530202550204
5201005201005201005701025E02056501056A01056C01066B00046B00046C01067A0E14
A33D428220296501057B020A86010A8A00098D01099301099701069A01069C01079D0009
A10109A50108A50007A90208AE020AB4050CB5040ABF070CC3090EC2090EBE060CBE070D
BD050DBE060FBE080FBE0B0FBC0C12AB121A5D080C1F1012868A8DD8D9DDE0E0E0E2E0E1
E1DFE0E4E2E4E4E2E5E4E2E5E6E4E5E3E1E2EAD9D9BB797DAD2025C71315D11317D00F14
D31018D30E15D20D14D10E14CE0D12C8131999141B33000579787FCDD2D8E3E4E8E2E3E5
E1E2E4E2E3E5E1E2E4E0E0E3DDDDE0E1DCDECFB4B88B3840A0121CAF0811B50812B1030D
AD020BAA020BAD030EAA020CA6010BA5010AA5020BA7040FA30815981321A12A39A12836
9B131E9F0610A5010CA6020CA101099B01079A01099A010A97000995020A920006960107
9901089A010A9B00099E020A9E01099F020A9D01099A00069703098701078100058B030F
88040F7800067D020A7B02096E05085D00026904086D03066702045C01015900015A0100
590200681A0F00FF0000FF0000FF0000FF00
00FF0047A2084F0D017C4F4A361D1C0C02010400011101012601004001014E01024F0101
4F00015101025201005500025A01026301066801056A010666010363010266010289151D
89161F760C165D000571020B86030A8C010A9000099301089601079701079B01089E010A
A20109A40107A50107A90108AE0309B8050CBC050BC1060DC3090EBD040ABB050CBC070F
BC0711BD0713BD080FBF0A0FC00C11B410157C0D132001046B6B70C4C5C8DFDFDDE2E0E1
E1DFE0E3E1E4E3E1E4E3E1E4E6E4E5E2E0E2E9E1E1D0A3A5A42C2EC6181BCE1314D01015
D00D13D10C13D20E13D00D11D10F13CB0F16AF151C4F020A494147C2C9CEE2E4E8E3E3E5
E1E2E5E2E3E7E0E0E3E0DFE1E1DFE2DFDCDFDACBD09B5E6696171EB00C14B3070FB2040E
AF050DAE040DA9010BAA030DA8030DA4010BA2010BA4000DA5010FA505159F04139F0313
A40211A7030EA7010CA5010BA3020C9E02099C01069B0008970009940109930007970108
9801079900079C01099C010A9E0209A1010AA1010A9F01099C010995010991010997030F
93030E8600097F020B7600057103066501045E01025D01015D01025D01015E01025D0101
5B020164130900FF0000FF0000FF0000FF00
00FF0048A3084F0D0171453C2813100801000500001701013202024702034C01014C0102
4C00015001015501015701025801015F01056501046801056201035A000163000382040E
8A040E83040F6401056401067E020B8A010990010994010997010A9600099901089C0009
A00108A10108A3010AA7010AB1030DBC060DC1080DC80D12C2090EBC040ABA040CBD080F
BA0610BD0811BD080EC20B10BF090DBD1117950F163401034D484DB2B6B8E1E2E1E3E0E1
E4E1E2E0DFE2E2E2E4E4E3E5E5E5E7E5E3E5E8E3E3DEC0C1A74548BE1A1ECD1317D11218
D21017D31019D10E15D31116D11015CE1016BD131A730B122A1218A5AAB0DDDFE4E2E2E5
E1E2E4E1E2E5E1E2E5DEDEE0DFDFE2E1DEE2E2DADEB1878B8D2127AC0E18B50B14B2070F
AF050DAF070EA80209A60009A8020BA40007A5010AA5010CA4010CA3010CA4010DA5010C
A6010BA8010CA8020EA5010CA4010CA2010C9F01099B010798010898020996010898020A
9801089800079B01079D01099F0109A10009A1000AA2010CA2020B9D020C99030D960510
90010B8E030B8A030B7E01087701076F00066B03076101025F0102640204650303600101
5B010063100717C30100FF0000FF0000FF00
00FF0049A4094D0C00825A5121120F0601000901011800003903034D03034D01014D0101
4F01015201015801015901005701005B00036201056701085C02054D000069020885020D
8D020A87040B6B02065C00047A020A8901098F010893010797010798010A9801089A0008
9E030B9E010AA4030BA80208B4040ABC060BBF060BC1070CBE050BBC060DBA060DC00810
BF0811C10A13BC070DC20B0FC00A0FBA0811A710194F04092F22279D9EA3E0E0E2E1E1E1
E1E1E3E0E2E3E2E5E4E3E4E6E4E5E7E5E3E5E3E2E2E5D2D5BB7076B51F27CA131AD2131B
D3111AD00C17D31018D00E16CE0D14CF1016C5111995131B30000875757DCBCED4E1E1E5
E4E4E8DFE0E3E0E0E4E0DFE4E0E0E4DEDEE0E4E2E4C9AFB18D363DA5131FB00A14B10710
AF060EAB040DA9030CA7010AA9030DA5000AA20109A3010CA2020D9F010AA2010CA3010C
A5000AA6020AA7030CA4010DA2000DA0010C9D00089D02099C02099A0108970108970109
98010A9900099C01089D01089F0109A2010AA2000BA6020DA7040FA1050E900108860108
89020A90030C8C01098601088102097C02087A03097001056C02056401035F01015F0203
5901006C1A132E860000FF0000FF0000FF00
00FF004DA70C5310037A4F491709070400000800001B00013901024B02044900014B0102
4D00005300005701005901005701005B000062000363020654020444000169040980030A
86020A7F040B6302055A00047B040A8C020991010A93010A94000898010A9701079A010A
9C01099D0008A10107AC040AB4030AB9040ABC070CBB040BBB050CBA060FBA050EBF0610
C0070FC00711C0080FBF080DC00B12BD0A14B1101A6B070F21070E8B8A90D5D5D8E1E0E2
E0E1E1E0E3E4E0E5E4E2E6E7E4E5E7E5E5E7E4E3E6EADEE2CF989EA7262EC6171DCE1017
D10F18D40F19D31018D00E17D00F16CE0F16CA1119AC161F4902084C424ABABEC4E2E5E7
E0E1E3E0E1E3DFDEE2E0DFE4DFDEE3DDDDE1DFDFE1D8CACD97585E94141EAC0A14B10812
AE0610AC0510A7000CA6010DA6020CA2010BA00009A1020DA0030E9D010B9D01099F010B
A1000BA5020BA50109A3000AA1010CA1010B9F01099D01099B00089B010A9A000A9A000A
9901099900089A01079B01079F010AA2010DA4010DA9040EA7050DA6081397040E870106
8C030B91010A8A01088601088601098002087E02097801057301046702035C01015E0202
58000075251E2E870100FF0000FF0000FF00
00FF004FA90D561303683D381204030300000800002401013B01014A02014800014B0102
4F01025702025902015C02015B01016202046500056202084C020437000057030773050A
73030A6302075101065601047A020B8B010992010891000995000998010A9B01099D020A
9F010AA00008A50208B1050DB8040CBA060DB8050BB8040DBA050EBF0A12BC070EBC040E
BE070FBD050FC10911C20911BF0A13BE0B16B50E18870D172A000769646CC4C4CAE3E3E6
E3E4E4E0E1E4E1E2E4E2E3E3E5E5E6E5E3E6E4E4E6E7E2E5E3BFC3A43A40C11A1FCF1319
D31319D31019D20F15D20F17D00E16D00E17CE1019BD17216A0810291217A8ABB1DCE1E4
E1E3E4E0E0E2E0E0E2DFDFE2E0E0E2DDDDDEDEDDE0E1D8DDAD7F85871A22AA0C16AD060E
AC050DAB040CA9030DA6020DA4010CA2010B9F00099E01099D010A9C010A9C000A9D010B
A0010BA4010BA4020AA2010AA0000BA1010C9E00099F020B9D010C9C010B9A00099A0008
9901089900079A01079B01079E0009A2010BA8030FA8030DAA050EA90512A2041095020B
90010991020B89010886000786020A7900057401057701067301046B0205630103610101
5A01007020182E870100FF0000FF0000FF00
00FF004DA80D521202754E4B1006050300001001003303044902035003034A01024B0102
4D01015402015801015C01025A000063020568020864030B4703062800003801014D0205
4E01054400034100025801037D020B89000790010892000A95010B9700099801079C000B
A0020BA3000AA8030AB2060FB6070FB8080EB6050CB6020CBB0710BC070FBD080EBB060D
BE090FBD080FBE0A10BB060FBE0912BF0A15B609149F121D45020C3A3139B9BAC1E2E2E5
E1E2E4E2E3E7E3E2E6E4E2E5E6E4E5E5E3E4E5E5E7E5E3E5E6D0D3AA5C60B81E25CE131B
D01218D31117D11014D10F15D41318D00F15D01219C313198D111A2E0109858389D1D3D8
E0E1E4E1E2E4E0DFE1DFDFDFDEDEDEDDDDDCDCDCDCE1DDDEBEA0A4842831A5101AAC060E
AD060EA9020CA7020CA5030CA5020DA3010C9F00099E02089D01099F020D9D000C9E010C
9F010CA2010BA3030DA0000B9F020D9D010C9E010A9F020C9E010C9B010A990108970006
9801089901089A00089C01099F0109A5020AA8020CA9040EAA0712A3020DA60611A0030D
97020C87010783020988030A88020A7B02087200047401066B01035F0102630305620102
5C02016D1C132F880200FF0000FF0000FF00
00FF004FAA0F521406724E4C0802020300001601013B03044C02024E01014C00024D0101
5001015400025801005D01015B00016201036701046302074C0206260000260000330102
3901043A00044600026803078101098A01088F010892000A95010996000997010A9A010B
9D0109A5020BAC080FA20309A10409B30912B70611B8040FBB0510BC0710BC070FBC070F
BB080EBB0710BB080EBD0912BD0912BD0814BB0C15AC111C640811231017A3A6ABDDDEE1
E1E2E4E1E2E6E3E4E8E3E2E6E5E5E7E4E2E6E4E3E5E3E2E4E7DCDEC28990A9252CC8191F
CE151ACD1418CE1519CE1519D0181ACE1518CD161AC6181AA91E2546040B594F55C6C9CD
DFE0E3DFDFE1DEDEDFDFDFE0E0E0E0DDDDDEDFDFE0DFDCDDD0BDC19148529B131FAE0A13
AD0610A8010CA9040EA7030BA5020DA3010EA1020CA2040EA0010D9F020D9D010C9C000B
9C010A9C0109A0030D9E010C9D010C9B010A9B00089C010A9B00099A0108980007990107
9A00089B00089B01089B01069E0007A40109A8040CA7030EA807139D010BA50712A6040F
9D030E8402067700048202088301077B01077A0208740205670203550000570101620204
5D0001600C0430880200FF0000FF0000FF00
00FF004FAA0F551709623D390900000400001600003901024B01024D01014C00024F0101
5301015900025900005E01025F01016301036501036301035803053401012901015C3033
8355583E05085D03077A03098701088D010A91010A92010A920108930108960208980108
9A0106A7050DA8050C9702038D0001A7050FB4040FB7030EBA0611BB0713BC0611BA0510
BA0710BC0812BB080FBC0811BB0A12BF0B14BA0A12B40F18810F162101047D7D84CDD1D5
E2E3E7E3E4E9E1E2E6E3E2E7E2E1E6E1E0E5E3E3E8E2E2E4E7E2E4D5B5B79A4042B32D2F
B72A28B72A26B52B28B42B28B22B27B32C29B5312CB02F2C9D2F2E5C222345393CB3B5B9
DEE0E3DEDFE2DCDFE1DBDFE0DDDFE0DFDFE1DEDEE0E0DEE0DED3D7A06A728C1520A90A15
B00812AD040EAB040CA9040CA8030EA5020DA3020FA2010EA2010E9F010B9D020A9C000A
9C010B9B00089D020B9E010C9B000A9700079900089B010A990109990109990109970108
9A010A9B00099C010A9F010AA10108A3020BA7040FA90411A8091499020B9A050EA20611
9B030D8F050C7C00047E03087901047300047803097201056B0204610305580000630203
630203630C082F870200FF0000FF0000FF00
00FF004FAA0E551607542C250D00000B00002202014103034F03024E01014D0101500102
5401005A01045B01035E01025E00016201026201026201026304064B0203380309996B74
8E6269621D24760A1285020B8B020A8D01098E0109920108910106900106940008980009
9D000AAA050EAA040CAA080EA40409AF060FB70610B90410B90510BA0612BA0410B9030F
BB0711BB0812B7060DBA060FBB0A14BB0712BF0C16B90E179C161D3701044C464EC2C5CB
E1E2E6DDE1E5DFE3E6E4E5E9E0E1E5E3E2E7E1E2E6E0E1E5E2E2E5D9D1D0BB9996CC9491
D89B97D59B96DFA8A1DBA39ED69F9AD8A39ED7A29CDCA9A3D1A6A1C2ABA8BCB8B8C0C0C3
DBDADEE1E1E4DDE0E2DCE1E1DBDFE0DEDFE2DEDDE1DFDDE0E1DBDEBD999F87222DA50B16
B0050FAF030DAC030CAE0911AB050FA8040EA3020CA3020DA1030E9C01099E030B9E020C
9C010C9C000B9C010B9C010B9C010B9A000A9B010A990109970008980108980208950006
9901089B010A9D000BA2020DA4020BA2010AA4020DA7040FA807129C060F8F0109980911
9101088D03097C00047A02077C030A7300066F01056B0204690204680405600102630103
63010268100B31880300FF0000FF0000FF00
00FF0050AD0F591D0D5E3C370900000D00002C02014904045002024B00004D0101510002
5601015901045801025D01045E00015E01015F010262010266030461070C752D377C414F
8D4C5B7D202D7E030E89010C8C010B8E010A8F01099100089002068C00059302099A010C
A0010CA8020AAE030CB0040DB2060EB5050FB9060FB8020EBB0511BD0713BB0712BB0712
B90611B80711B80810B90611BA0913C00C18BB0914BA0B15AB131C56060A2B1C21B1B2BA
DFE2E6E2E3E7E1E5E8DFE3E6E1E2E6E3E2E7E4E4E6E3E1E6E4E4E6E3E2E4E2DEDEE7DFDE
E7DFDDEAE1DFE7DFDDE9E0E1E8E1E1E4DEDDE5DFDEE8E2E1E5E1E0E4E2E2E3E2E4E2E1E2
E2E1E3E1E1E4DEE1E3DCDFE0DDDFE1DCDEE0DCDDDFDEDDDFE0DDDFCDB5B88E3940A20F1B
AF0512AD020BAD050DA9040CAB050FA8020EA6020FA2020DA10611A20C159B020C9D010D
9E020D9C000C9C010C9B000B9C010C9D020D9C010C9A000A9A00099B010A99010A990009
9A01089C01099D020A9F020BA1000AA3020AA5030CA6030CA9060EA70A1292040B840208
90080F90030A8201057A00057E02097B020A6D01066200025F0001630103650102670203
6501016C120E358C0700FF0000FF0000FF00
00FF004FAB0E6026175B3C380800000E00012A01014601015002024B00014B0100510102
5C080A5B080A5201015901025C01035E0105630206640104640103620105680B16721827
6F0E1D7A051386020E8C010D8C000A90010A91020892010A8E01058C000592010699000A
A2020DAD040CB1040CB3050EB2050EB40911B90910BB0710BC0612BB0713BB0712B80711
B60610B70711B70812B60610B90911BB0A15B80712BB0A13B7111B7A0A142402098E8D97
D1D4DAE0E4E7E0E4E4DFE3E5E1E2E4E2E2E6E3E3E5E4E2E5E4E4E5E3E3E5E3E3E5E2E2E4
E4E3E3E3E1E2E3E2E3E2E1E2E1E1E3E1E0E3DFE0E2E3E3E6E4E3E6E3E2E5E2E1E4E0E1E4
DEDEE3DFE0E4DDE0E2DBDEE0DBDEE0DCDEE0DDDEE0DFDEE0E2DDE0D8C1C494444BA1121C
AD040FAB020BAC030DA9020CA7000DA90310A5020EA2020DA106119E05119D030E9C000B
9C000B9D020B9D010B9D010C9C010C9B010C9B010C9A000B9C020B9C010A9C010A9B0009
9B01099B00089C01089E020BA1010BA5020DA8020DA9030CAC070EA8060E9D061087020A
86020994040B8E02088501098002097402086B0309600106610204660103690103690102
6703016C120E358C0700FF0000FF0000FF00
00FF0051AC105A1D103F1E1C0800000F00002C03014604034E01014C01034900014D0002
5002064A01025202025701015A02035D020561030761010564010464010369010770010B
77020B82010F8A020F8E020D8E010C91010B8E010991010A8F01059100059601079B0109
A4020BAC040BB1060BAF050BAA0309A80309B40710BA0810BB0610BA0612B80711B7070E
B4060EB3050FB30811B4070FB5090FB3040EB6060FBD0B11BC0F179D111B4302094E404D
B9BCC4E1E4E9DFE3E3DEE2E3E0E2E2E0E1E3E3E3E4E3E3E5E4E4E5E3E2E5E3E3E6E3E1E4
E4E2E5E2E1E3E2E3E6E2E3E6E3E3E5E1E1E3E2E2E4E1E2E3E1E1E3E4E3E5E1E1E5DFE3E6
DDE1E4DEE0E3DDE0E3DADDDFDBDEDFDCDEDFDCDCDEDFDEE0E3DCE1D5B9C1903B44A3111B
AF060FAE030DAC020DAC030EAA020DA7020CA2000BA3030D9F020C9E010D9E020F9D020D
9D010B9E030B9C010A9B010B9A000A9B010B9A010A98010998010A9A010A9B01099B010A
9A00099C010A9E020DA0020DA2010EA3010DA6030DAA050EA8030BA8070EA507109B0810
8C010992040D90020A8A02097E03076400015801055701055F02056602056901046C0203
650200640B074B4E0600FF0000FF0000FF00
00FF0052AE125C1E1042221F0B00001300012B01014201014A01014B02024A01014D0102
661B1F530A0E4F01035002034E03044E02055303075702075F03066802066B0004740008
7E010B89010F8D010E8F020E90010C93010B8F010990020A9001079301069802089C0008
A60309AF040CB2030BAE010AA90208A50208AE040CBA0A14B6040FB80511B80711B5040E
B2030DB1030EB40812B0050DAF050DB60B13B80A0FBD0C12BD0C13B4111B820F19390310
7C6B79C6C0CDE0DFE4E1E1E6E2E4E7E2E2E6E2E2E5E3E2E7E5E4E9E6E2EAE5E2E8E5E0E7
E3DEE2E3DDE4E0DEE4E2DDE5E4DFE6E5E0E6E1DBE2E1DCE2E2DDE3E1DCE2DDD9E1DBDBE2
DBDAE1DCDBE2DBDAE1DCDBE1DDDCE1DEDCE1E0DCE1E2DAE1E0CBD7BD8693901F2CAA0D16
B1060EB0050FAD020EAD030EAA010AA7020CA2010BA0030B9F020B9F030E9D010D9F030E
9D010B9E010A9C010A9B010C9A000B9B010B9A00099A000999010A990109990107980108
9900089B0109A0020CA2010BA4020DA4020DA3010BAA050FA7040E9F010AA5060FA2050D
97030B8A01098703098101057C02066D02065B00035301025801025D0103600102680202
660201600702600F0400FF0000FF0000FF00
00FF0054AF136528194225220C00001800003402024B04054C01014D0101510201500103
5F10145404094C01054300023C02035B1F226223274C080C4C01036001046D0002790109
85010E8C020F8E000C8F020F8E010B8F01098D01078C01088D01089201079501079E0107
AA040CB2030DB4030EB40410B1040EB2060FB4060FB1030CB60710B80612B70610B60611
B0020CB1050EB3050DB0040DB0050DB60B12B70A10BB0C13BB0A11BD0F18B1121D890D1D
5B081C773F56B389A0D1B2C6C7B3C1D1BFCBD9C4D0D5BDCADBBECCDAB8C9DAB7C6D7B1BF
D5AAB8DDADBDDAAABFD7A7BDCE9CB1D7A4B7D19EAFD6A3B3D9A5B5D8A5B7C596A8CB9DB1
C095A7BA92A3B78FA0C59EAFC9A4B4CAA4B4CDA2B3CC98A9B66B7D9C2C3DA50F1BB20710
B2030DB0030EAF0510AA0109AB030AA60108A5020CA4030FA0010C9E010A9D000B9D010D
9E030D9D010A9D020A9C010A9C010B9D020B9C010A9B010A9B010B9B010A9A00079A0107
9A01089E0308A2040CA2010BA4020CA2020BA2010BA6030EA60510A0020CA5040FA6040D
9E040D8701057E01037F01067C01067302066B0006660205620003620306590001620203
6704046A100C691A0F00FF0000FF0000FF00
00FF0054B011672D192F14100D01001A00003801014E03044C01014B00024F0202500104
5102045103054A01024901038030389B4854A4505E9C48554C01035900036F010682020D
89020D8B010F8E020D8D010E89000A8800088B01088C00098D0209910109940106A20208
B1060FB4030EB50510B50512B50510B5040FB80711B70610B70711B80711B6050FB0030B
AD0209B0050DB3070DB3050EAD020CB50710B80B11B80910BB0A10BE0C12C00E17BB121D
AE14239D142A9319349E354FB1556CBA6076C05F75B9546ABF5268BD4A5FB84458B53D52
B6384EB7374EB33149B33049AF2C44B12E44B02C3FB02B3EAF2A3DAC293DA9273DA7273E
A6273FAA2D44A52A40A62E43A73246A83248A83047A8253CA81729AE0B1AB60811B80610
B4040EAF020BAF040DAE030CAB030AA60109A6020BA6020DA4010DA1010C9E020D9D020E
9A000B9B010B9A010A9B010B9C010A9D020B9B010A9B010A9A01099700089A01079D0209
9B00089E030B9E020BA1020DA2020DA3020DA2010CA4010DA90710A7050FA8040FA7040C
A0020B92010A8A020889030A7E02057200037503097303076F01066B03075A01025C0102
640304650D096E211600FF0000FF0000FF00
00FF0054B1126229122A0F0A0D00002101014304044D01024A00004B01024B00014D0103
4B00014901014E000262040871040D7804137A06167A05156D040D6001046E000781010D
87010C89010D8C020F8D020E8800088901088C00098C00098C0108900007960005A40208
B0050BB4050DB3030EB4020EB90611B8040FBC0712B9050EB7070FB4050CB3040AB2060C
AF0709AF060DB1060EB1060FAF040DB2040DBB0D16BE0F16BE0B11C00B14C20B15C30E19
C00E18C0101BBE111FBB1322B91528BD192AC2192AC71A2BC91928CD1828C91825CA1725
CC1725CD1724D01926CD1524CC1522CB1421C91420C9131FC8151DC5141DC2101CC00E1C
C00F1EC00F1EBE0E1DBF0F1EBC0E1CBB0C1BBA0D1CBB0B1ABB0915BB0612BB040FBA0610
B3020CAE030BAC020CAA010CA9010DA6020BA4010BA4020BA4020CA0000A9E010B9C010C
9D020F9C020E99010D98000B9D020B9C01099B01089901079700079A02079D03099C0108
9C01099E020C9D010AA1030DA2020CA3020EA2010DA4020DA8040EAA050FA7040FA4030E
9F020B9801099402098F02098501077801047401047501057502067102056201035D0001
660405660A07701F1600FF0000FF0000FF00
00FF0056B2146C3219260B070E00002702024703045002014C00004D01034D01014B0102
4701024500015A02046E02057401047D01097F010A81010B7C030B6C02066C010881030E
86010D8A020D89010B8D030D8800078B00098D010A8A01088C00059300079C0108A80309
B3060BB4050BB5050FB5040EB6050EB6020DB90510B90510B4040CB5080EB5080DB1050C
B1070EB20710AD030CAE030CB20610B5050FBA0A12BE0E18BF0D13C30C14C20A13C40D16
C20E14C30F14C00D12C40F17C51019CB141BCB1217CC1017CE1119D0111AD01218D01217
CF1218D11218D3141AD3121AD2121AD11119D01016CF0E15CE0F16CA0E14C80F14C90F15
C60914C70A15C90C16C30912C30912C10911C10811C00712C00714BF0614BB0411B6030D
B2030DAD020DAA020DA6000CA6020EA5030FA3020DA1000BA3000CA1000B9F010D9C000D
9E020F9C010E9A010E98020D99020B9B01099B01089A01079701079701089A020A990008
9A01089C010A9D020BA0010AA0000AA3020CA1000AA2010AA6050DA90710A6040EA4030D
A3030D9E020B9901099301078C01078202077701047201056F01046D0205670204630002
6501026506036C191000FF0000FF0000FF00
00FF0054B2137E482B1F0B070C00002801014B04045303024C01014B01024B01014C0102
4501034801026302047402057801037C000681020B84010982030A6C02066401057B030D
84030D87020D88010B8A010B8801078C00098D010A8C00089101089601079E0008AF080F
B1040BB2020BB4040EB90912B4040DB7030EB70610B60410B4040EB4040EB60610B4060F
B0040FAE020FAD030EAE030BB3050EB70711B70711BB0B15C00D16C20C14C30C12C20D13
C10E13C11017C00F16C10D16C61118CA1116C70E13CA0F16CB1117D1151BD01317CE1115
CD1013D21318D6151AD31017D41119D10E16D10F15D00E14D00D15CE0D15CB0D14CD0F16
C80911C80813C80A13C50910C2080FC20910C10711C00711BE0511BA0310B90410B4030D
B1040DAB010CAA010EA8020FA6010FA3010FA40410A2020EA5020EA5010CA1000D9C000D
9B010D9C020E9B020E97000C9A020C9B010A9A000899010998020C97010A950109940008
9700089900099E040D9F0109A2000BA3010DA2010DA3020CA5040DA6070EA60D11A50D13
A1060E9D030C99010A9701079000068700077E0106730105680003640103640103680103
680102650200630D0500FF0000FF0000FF00
00FF0053B3136B381A1905020F00002C00004E03035302014A01014801014B02014B0204
4001024A01036703047702067800037D000682010885010C81030C6802055D000376030C
81010D84010E88010D8B020D8A01098C00089000099202089201089300069B0106AC050C
B0040BB3020CB6060EB5030EB6040FB8040FB70610B5030FB70610B4020EB50410B2030F
AD020BAE020EAC010BAF020BB2040CB90914B70712C1101AC5121CC30B15C50D15C20E14
BF0D13BC0B15BA0A14BF0D18C40F18C91019C70E15C70E16C80F15CE141AD01317CF1216
D01215D41316D41115D61319D41117D20F15D20F15D41218D20F16D00C15D00D16D00E16
CB0B12C90A11C6070FC60A11C2080EC20910C0070FC10911BA040CBA050EB9050FB6050E
B3040CB1040DAC030DA8020DA3010EA1000FA2020FA5030FA6020DA5010CA0010C9B000B
99000A98010B98010B99010A9B010B9A020A980109970108940108930108920208920109
95010B99020C9C020B9D020B9F010CA1020CA3020DA2010AA2060D9D1213A12F29A63E3A
932222900B1295030C9601099200098A01088301087A02076F0104670103660104680104
6A03046A030169110800FF0000FF0000FF00
00FF0054B314622F121C04001800003B03045403035402014D01014A0002480101440202
3600014601026703057601067B010681020683000881010B78040C5E01055A010477040D
83030F89031188010F8A010D8E010B8E01099201089401099401079201069D0108AA030B
B0040CB5040EB6050DB5050EB5050DB8060EB5040EB60410B5030FB60410B5050FB0020B
AC010AB0020FAD020BB2040EB3030EB40610B60611BA0913C00F18C00C13C00B14C20D16
C10E17BB0B15BA0A14C1101AC20E17C50D16C70F16C80F15CC1218CF1218D11217D11118
CE0F14D00F14D00F12D00D13D51217D20E13D20F15D41118D31018D20E17CE0B14CD0B13
CE0D13CA0A11C5070EC60A11C3080FC3090FC20910C00811BB060FBB050EB9050FB7050E
B6060DB0020AAE040CA7030CA1010DA1010DA3020EA3020DA3020CA4030D9F010A9B0009
9B010A9A00099A010A9A010A9B010B9B010C98010A96010894010A92000992010894010A
96000B98000A9B010B9B010A9C020A9D010AA3040DA2040C9A0C10A53F3CE5A9A3E8B4B4
E09AA1A24249870B1290050C8E030A8701088300087E01087600066F0105670102610001
6702026A050379231C00FF0000FF0000FF00
00FF0055B4147341201C04001E01014303045704035401015002024C01014601023E0102
2E00014002036304057301057A01057F01087C020875030960020649000155010672020B
7F010C84010D86000E8B02108D010C8D00089201099201089401079500089E0108A80209
B0040DB6050FB4040CB3040BB3050CB90912B4040EB3030EB3030DB3020EB3040EB0030C
AD020EAD010DAC000CB0010EB3050FB50711B50710B80812BC0D14C00D13C30E15C40D17
C00D16BC0C16BC0D16C01118C10F13C40E12C70F12CB1116CB1014D31318D21116D10E16
D21114D31016D11015D21015D41116D51216D20F13D41118D10E16D00E17D00E16CF0F15
CA0B10CA0B12C70910CA0D14C70B11C4090FC1080FBF060FBC050FBC050FBB030FBA040E
B9060EB10309AE040CA9040EA3020DA0020D9D010A9C00089D010A9E010A9D01099C000A
9C010A9C010A9C010C9C010C9C010D9A010D97000A940109920008910008910107940109
96000999010A9C020B9B01099A00089D020AA1050CA2080F8E1115C98486E0BEC3A67380
802F42C86C7987252B89212383191B79050B7E02087E01077901067300036E0104640002
66010168040175201900FF0000FF0000FF00
00FF0056B4146A35141E03001E00004002035201035100024E0101480102410101390203
2300002C01015003036803066E030571040A6A04095B01074500023F000159020777030C
7E010B83010D87010E8C01118D010D8D010A8F0109920007950006990008A2030AAB030B
B2050FB3030DB2020CB3040DB3060DB50610B2040DB4040EB7080EB1030BAF030CAF030E
AD030CAE020EAD010DB2040EB20310B50711B3050EB4060FB90B12BE0D13C20E16C10E18
BE0E18BF101BBB0D16BE0F15BF0D11C60E13CB1115CC1215CB1012D51318D41116D41117
D41115D61319D31017D10F17D21317D31418CF1116CD1119C91218CC1519CC1318CE1418
CB1015C60B12C60B14C50A13C50A10C3080EC30810C30A12BD050CBD060EBB040FBA0410
B9050EB2030BAD040DA9030EA4010EA0010D9C00099B00079B000A9B00099B00089D020A
9B01099A01089B010A9D020D9D020D9A010A96010792010791000793010893010896010A
97000A9B010B9C020B9B02089A00099B010A9E020A9F0911841318DAA3A9DDBBC67F3747
8B15298C1D2BBE6F75D4999ABD7E8197444872070C7D050A7A01057800037601056D0103
6B0202680201741C152C860000FF0000FF00
00FF0057B4145B22031E01002201014203035001035001024C00024300013D0000390204
2001011E00003701014A01034F01035200074C01083F010535000244000567030B7C020E
80010C84010D88010F8C02108E020E8D000B8F01099301099701079D010AA6020CAE030D
B1010BB0010AB4040EB1030DAF010AB2040DB0020BB3040BB4070CB2050BAF030CAD010D
AE030CAE020EAC010DB0020EB2040EB2030FB0030DB40711B60C13BB0E16BD0D15BB0B15
B90D16B90E17B50912BB0C13BB0B11C30C13C90F14C90F13CE1014D10F16D31117D41217
D11115CE1015CE1219CC141CC8181EBF1C1FB01B1EA81D20B2302FB5332EB22C28B42421
BB1D1EBD1218C10D14C40B11C60B11C50910C1060FC0070FBE050CBD040DBB040FB7010D
B7040EB2030CAF040EA8020DA3000BA2000CA1010A9E01099B010A9A000A9C010A9D020A
9B01079A01079B02099A00089C020A990108950107920006930007940006970108980109
9801099A00099901099900089B01099F010AA1010A9E070F831319DCA6ACDAB3BC792432
94101D8C0F18AF6168DCB2B9683A42B8797F7427297D2023700509780206790104720103
6E01026901006C130B2E870100FF0000FF00
00FF0059B6145A24021B00002600014602035001024B00004601014301014001013D0303
2201011800002501003505033905043903083601092F000436000254010772020C7D010D
80010D83010D86010C8A020C8B020B8D010C8E00099301089801089E0009AA040CAE020A
B00108B1020CB5060EB50510B2040DAC0109AF030BB3030DB5050EB1020AB40610B1030F
B0010EAE020EAC010AAB010AB20710B1040EAE030CB0050EB50C13B80E17B90C15B60711
B70912B80C15B90E15B80A10C31118C50F17C50E14CB1116CF1115D3121AD11318D11419
CA1619C2191CB31C219F1B1E8D1D1F8B3434A46160C38C8AE2B1ACE8B7B2E4AFA8D79992
C77571AF4341AA1E1FBB1518C30D12C30910C0070FC0070FBE050DBC040EBB030FB9020E
B5020CB3040EAE030CA9030CA3010BA1010BA1010A9F00099B01099801099A010A9C0109
9B01089A00089B01099B010A9C010A99000997010A960109960009960108960107970208
96010798020997010999020A9D0109A00109A3040D9C040B881319D79CA2DDB4BD7C2331
950D19900B13974148DEB0B85F2D37935960A37273C48E8F691C1F6D0A0C720305710101
7101036A0001660C052F870100FF0000FF00
00FF0059B7155D28061D00002B01014C04045202014F0102490102460102460101440305
2C02011901003A2120A9908DA9929032161A2902092E00044701056B040D79020C7D010C
7F010C80000C84000B8C030D8A01098A01098D01089101099500089D0008A80109B0040B
B10208B3030AB60610BD0C17B3040EB0020CB1030CB4040EB6050FB5040EB4040FB1020F
B0010EB0020FAE030CAB010CAF0510B30811B40A12B60B13B60D14B50A13B70912BA0C15
B70912B80A14B90A14C00F19C20F19C50D18C60F16CD1419CB1217CA131AC4151ABB1B1F
9F1A1E841B1F883C3DA87173C9A5A4DFCCCAE5DBDBE6E0E0E5E1E0E7E3E1E7E2DFE6DEDB
E6D4D1E1BCB9C37D7BA83334B01217BE0B14C00710BF070EBE070FBC0610BD0612B7010E
B9040FB4020DAE010BA9020BA3010BA1010B9E00089D01089B01099701099A020C9B010B
9A00099800089900099E020B9E010C9D000B9B010A990109990109970108950107920107
9301079401079601099600089700079E030C9F020DA005118B0C17C67E86E4B7BF802B38
920C189309138F3038E4AFB768323D7E464FBA979BB4979B6F4447B5777A6716196B0509
7102056B010270160E2E870100FF0000FF00
00FF0059B8175726071D00002F01014B02025101005000024C01004A0102490201490102
3E02022501025A4247CCBDC6C3B7C038242D2D010844010762020B76020D7D010B7D010B
7E000B80010C83000B89010C8A01098C00098D010A92010B9500099C0009AA030BB4040E
B4030BB4030DB5050FB4030EB3050FB2040DB4040EB6050DB7060EB3030CB3030DB1010C
B1030CB0020EAE030CAA000BAD030EAF040EB1060FB40911B60C13B50812B50710B50A13
BA0E16BB0B16C00D19C3101CC20D19CD1420C81019C8151BC0181CAE1A20921B1D7F2626
8D5654C9ABA9E1D1D0E6DFDDE6E3E2E6E6E6E1E3E5E0E2E5E1E3E6E1E5E7E0E3E5E3E3E4
E2E1E2DFDBDAE2CFCED29D9DA2383DB0161EBD0C16BE0811C00812BB030EBB0410B6010D
B5010CB2010CB0020EAB020EA6020CA2010A9E00099D010B99010A94010995000997000A
9A020C9B010B9A00099C010A9D010B9C02099B00089B010A990109960106940007950009
9601089601079601079501089300089B020D9F020E9F020F950917A44753EFB9C28F414C
900F1B960611841721E09FA9773E497A434DC9AAAFAD9B9E8A7577BA9C9FA97D81722C31
69090E690204741A122E860000FF0000FF00
00FF0058B8175120031E00003201024F02035201004D01014700004800014B01014D0102
51060B481215290811462D3F371D2E37101D601C2463050C70020979010A7D010B7E000B
7E010980000A84000B89010D8A010B8C00098E010A92010B95000A9C000AAC040FB4030F
B3030DB3030EB60811B3060DB1030CB0030BB4040EB5060DB4060DB0020BB1030CB2030E
AE020BAD020BAD030BAA0109AC020BAE040DB20810B60A12B70C12B90B14BA0C15B60B14
BE101AC10F19C41118C30E19C5111BC01019B9161AAA1E21881C1B7E3534AA7F7CD4BEBA
E1D9D5E4E1DFE4E4E4E3E3E4E4E4E6E2E3E6E2E3E6E1E4E6E1E3E6E1E3E6E3E4E7E2E2E4
E0E1E3DFDFE1DFDDDCE4D6D4C29191982B2FB21118BE0912C00612BE0510BA020CB8020E
B4010CB3020EB00210AB020FA6010BA3020A9F020B9B010A99020B94000A94000998000B
9B000D9C010D9C000A9B00099B020B98010898010999010A970108940105940108950109
97010A94010994010995010993000A9A010E9F020EA3030EA009148D1924E49FA8AF6772
87111E970813870C19B6636F985C657C4A52C8ACB1A5949AB9A6AC8F777DB598A0AF8089
782B306203037319112E860000FF0000FF00
00FF005ABA195828092000003701025504055601024F0101480102490102480100500103
550108681D267B424F7341547D46577D34436D0D1971020C7501077901097E010C7F020C
7E010881000A86010C8C03108D010C8D000991010B92000B95010B9C010AAD040FB2030D
B4040EB4040FB4060FBD0E17B1050EB1030DB4040EB4060EB3060CB1040BB4070EB3060F
AD020BAD020BAD040BA90209A80109B00610B30811B40912B50A10B60912BC0C14BB0C15
C0121BC31319BE1217B9161CB51F2495181881231F864740B28E87D8C7C2E4DFDBE5E4E2
E4E4E3E2E2E3E2E3E5E3E2E7E3E2E7E5E4E9E0E1E4E3E4E6E2E3E5E2E3E6E3E4E7E2E3E5
DFE0E2E0E0E2E0E0E0E1DFDDDECECEB172749B1A1FB70D14BE0712BD040FBD050EB9020D
B8040FB2010CAF030DAB020CA8030BA6020CA1020C9C010B9C010B9A010B99010D9C020E
9C000D9D010D9C010C99010A9601089500079701079A0109980208920004910005920007
94010993010A92010993010993000997000B9E010DA3020DA30711940B16A4434FE59CA6
7D1E27871118A83940791B26BD747FA4717BBC9AA4A48C96B69CA5705158BC98A16E3A44
7F2F37610203670C0630880200FF0000FF00
00FF005ABA195E2D0E2500003E03035302025601024E01014601004800014B0001520102
5A02045F030C620D1B671626680D1D6F041376030E7500077400067801097A010A7B0009
7C010680010A86010C8C02108B010A8E000892010994010B98010A9F000AAE050FB3040E
B3040EB3030DB3050FB1030CAE030CB3050FB2040DB4060FBC0E17B5080EB2050BAE030B
AB0209AA010AAA030AAA040AAE040DB20612B10610B30912B20A11B10910B50C12B81117
B31316B11C1A9D1E1B87211E853934A27169C9B1A8DFD6CFE5E1DCE5E4E2E1E2E2E4E4E7
E1E1E2E3E3E7E3E4E7E2E1E6E5E5E9E4E5E9E1E3E7E1E4E6E1E5E6E1E3E4E2E4E5E1E3E6
E1E2E5E0E0E3DFE0E2E0E1E2E3DFE0D1B1B4993740B0111DBE0814BD050FBB030CB7020C
B8030DB4020BAE0109AA020BA8020CA5010CA2010E9D010C9C010A9B00099C010D9C000D
9C000A9C000C9D010D9B010B9901089901079B01099D020A990208940207910106930208
93020A92010A92010992010993000997010B9D010DA1020DA3030E9D0510900E1AB7535F
CB757F924247DB8C9273121E7E1726A24A5C7D3A4AAA7E8A9A76806F474EBE929B6D2F39
610A1066020366080331860100FF0000FF00
00FF005BBC1C5624092A00004503025602035201014A00014601004800014E0101530101
59010162020564010867020B6F010A77010A7A0109760006740107770109790208780107
7B010780010B86010C8C020E8E010A8F000993010B99010C9B020A9F0008AC030CB4040E
B4030DB4040FB1030CB1030CAF040DB1020DAF010AB50510B50710B70911B0050BAE040C
A7030BA4050DA0090CA20C0EA60A0DB10F16AF0E15AD0E13A60D11A81417A418199B1C19
90221C8B382FA16E63C8A9A2D9CAC4E3DFD8E4E4DFE2E3E1E3E4E4E2E4E6E1E4E5E4E3E8
E5E3E8E4E3E8E2E1E6DED9E0DDD6DED3CAD3C3BDC9CACBD5D8DEE3E1E5E7DFE3E5E2E4E8
E1E4E7DEE0E4E0E1E4DFDFE3E0DFE2DBCBCFAB676EA31823BA0914BE0610BB030DBA020C
B9040DB1010AAC010AA70009A6010CA6010FA2010DA0000B9E020A9C000A9C010D9B010A
9C01099D010A9D010C9D010C9B00089C01089D020A9B010A9B030C970108940006930107
93010892010891010890010791010795010A9A000B9E010CA3030EA0020CA00913940C1A
992736B65867C86E7C80111E8604138406176F091AAE717D8E666E895E67AA7E858B545A
5C0A1065030571130D33870300FF0000FF00
00FF005CBE1D4D1A042B00004703025603045001004A00014A02024E02024F0101530002
5A01015F01026001026400036D00077600087B02097500087400087900097A0108790109
7901077E010B85000E8C010D91010A94000B97010B9B010B9D010A9E0008AC050EB4050E
B4040CB1010CB0020CAF010AAF040CB1030DB1030CB50510B5040EB3040EAE030BA9030A
9B030A810409903230953F3B902F2B95292592241F942822912D27963E39984E48AC7269
C59D93DDC9C0E3DDD5E4E3DFE1E4E1E1E4E4E0E4E4DFE3E5E0E4E5E1E4E5E1E2E6DBD8DF
DCD2DADDCAD4DFC0CCE4B7C9E0A5B6C67F93652A414A3445ACAFB8DBE2E5DFE3E5DFE3E5
DFE1E5E1E1E5E0E0E4DFE0E4DDDEE1E2DBDDBD929695232CB20B16BC0710BD070FB8020D
B80410B2020EAB000BA7010CA6000DA6010FA2000BA0000A9D01079C01079B01089A0008
9B01089D01089F030B9D010B9D010A9C010B9B010A99000999030A980109970108960008
9501099401099201079402089301069701099B020B9E010CA2030EA0020CA206119F0511
9706158C06188905178D04128C010D8A020E76040EAF6A72956771A6727F96656F8A5860
722C3260050772150F4B4D0500FF0000FF00
00FF005EC01F4D1C072900004302015301025201005002024C00004E01014D0000520002
5800015C01015F000164010370010878010A78010A7400077400087D020C7C0109780007
7600077E000B85010C8C010D92000A97000B9B020B9D01099D020A9E010AA50109AE020B
B2050CB1020BAF010AB2040EB0020CB0020DB1030CB2020CB2020CB40510AC020AA70209
98050A6401034517178E7576D2B7B6D8B7B2D5B1A8D7B2AADDBDB4E4CDC5E7D8D1E8DFDA
E5E0DEE5E3E1E2E2E1DFE3E3E0E4E6E1E4E8E0E2E7DFDEE5D8D3DBD8CBD5DEC5D3E2B6C7
D792A5C86B80BE4D62B7364DB5253BB51E2FA11F2E44040F686066D2D8DBDFE4E5E2E5E7
E0E0E4E0E0E3DDDEE1DEE0E2DDE1E2DFE1E0CFB8BA9B434CAA111DB80811B8030CB8040E
B5030EB0010DAF020FAD0311A80110A6010DA4010CA001099C00089C01089B0108990007
9B01089C01089C01099D010B9E020D9B000A990009970108970008990109970108960108
95010B9300099401079702079800079B00099D010C9E010CA0030EA104119C040D9A040F
94030D8E030E91031092010C92010A8D010A79030CB66872A86B787429397C34429C666E
8A4B515A040671151061120700FF0000FF00
00FF005EBF1F501D072E00004503015502025401015302014D00004D01034E0101530102
5A02015D01016402046A01057101077501087500077401087400097A000A7E020C7A0108
7800067F010A88010B92030D95010B9A010B9C010AA1010B9E01089D010AA30109AA030A
AD020AAD020AAF010AAF010DAF010BB1030CAE0108AE0207AF0409B0020BAC0209AB030A
A1030A84060D4B010442202A887B88BCB8C2D8D7DBE1E0E0E2E0E1E3E2E2DFE1E0E0E2E4
E3E4E7E2E4E7E2E4E7DEDEE3DAD7DDD9CFDAD6C2CFDCB7C9D69EB1D4869CBB546CB6364F
B91F38C4182EC81225C80D1DCE111DCD1018BF161C70090F351D1FC3C6C9E0E4E5E2E4E7
E0E1E4E0E1E3DFDFE1DCDFE0DCE1E1DCE1E0D5CCCDA867709E1421B70A14B9060DB7050C
B4030CB0020CAF010DAE030FA8010CA5010BA4010CA2020D9D010C9B00099C01099C0109
9C01099C010A9C010B9E020A9D010A9C010A9B010A99020998020899020A970109960108
94000A9201099501089801089800089B010A9D010C9E010C9F020D9E020D9401098E010A
8701087D000481010A8A020B8F020A8B010982040C8D2532AB4B5B7507176E0613A3535E
9347505E04086B0F0A63130800FF0000FF00
00FF0030E0104E19053200004B03025903035901005601014D00014B01024C0000550101
5C01016101016701036C00057102057500067602067500077400067A000B7D010B7D010A
7D01058401098B020A93020C96020C99010A9C01099E010A9E010A9D010AA20209A9030A
AF040CB1030DAF010BB0020DB1020DB1030CB0020BAA0105AC0207AF010AAE030BAD020B
AA030CA2050E8F06106C0714520D206B3F5794778DB19EB1BAACBDCABFCCCDC7D0D1C8D0
D6C7D2CFBCC7CEB8C5D9B6C6D9A4B6D2889EC86982B8435BB3293EBC1D33C71A2CCB1424
D21422D6121FD20E18CE0913D00D13D00E12C91217971017320106939298DADEE3E2E4E8
E0E1E5DFE0E4DFE1E4DDE1E3DBE0E1DCE1E2DDDADBB78A90921C27B20D15B7060EB5040C
B3020CB2020CB0010CAC010AA80108A50009A4020EA1010E9D000C9C010A9A0107990106
9C010A9D000C9D010C9D020A9C01099C010A9B000A99010897010897010998010A960108
9301089301099701089600079500069800079A00099C010C9D010B9D020D95020C8B010A
8A060F7C01097A01098201098602097C020777030979030D8003108803107F030D71060F
700C136A030665060263110600FF0000FF00
00FF0030E0104A16033500004F02035C02035B01015901015101014E0101500102590203
5F02036302046500026A01056F01067601067800057800057801077C010B7C010B7F010B
81010887010B8C020A93020B96010A9B010B9C01099D020B9B01099A00099F0207A70208
AE030BAF010CAF040DB1030DAE020AAC010AAC020AAC030AAD0307AE0208AD020AAD020B
AA0108AC020CAC050DA50813960C1A840C207911297D213A7E2A448F4059AC627ACD8097
C8738AC86B82C15B71AE384FB0273FB61A30C1172CC91526CD131FD4151FD2121AD31119
D51219D30E17D20E17CD0A10CF0C10D10E11CC0F14B0131B50030964575ECACDD3E0E3E6
E1E3E7E0E2E6DFE1E4DDE0E2DCE0E2DCE0E2E0E0E2CDB2B68F3039A80E18B3030EB6030E
B6020DB3020DAF020BAC020AA80108A50109A4020D9F010C9D010C9C01099B02099B0008
9C010A9D000C9D010D9E010C9E010B9F020C9B000997010795000696000998010C940109
9100079201089401089601089600089701089801089B01099E010C9E010E96010C850005
87040B81020A7F040B83030C7C03096300015A00017003098101098A020B830108780105
7201046E0103640100600B0300FF0000FF00
00FF0000FF00521C073A01015202025E01025E01025A0001530000500102500100560101
5E01036000026401046500036A00027700067C02077A01087802087D01097D010883020B
83000888010D8E020D92000B96010A9C030B9E020B9E0209980008940008980008A8030D
AC010AB0020DAE030BAD020AAD020AAC020BAB0209A90107AB0207AA0106A90108AB010A
AA0209AB0109AD030BAF050FA9030CA70410AA0A17AF1422B11728B1182CB2192DB61A2F
B9192DBE182DC11628C81525CB131DCD121CCD0E19D21019D11016D21018D10E16D31018
D10F15CF0C14D10F14CF0B11D10D11D00D0ECD0C10C4171C73090F391D21C5C7CBE0E5E7
DEE2E4DFE2E4DEDFE3DFDEE3E0E0E4DBDCE0DFE0E3D0C0C49A535A9F121EB20512B6030F
B6020CB4010DAD000AAA0009A70108A40108A0010A9C010A9D010C9C010A9B02089C0209
9C01099C01099C01099E020C9F010C9D020D97020B94020892010797020A97020A920108
92000892000A93020A9301089600089600079700069901079D0109A0010D9D030E8F0108
8F050C8001067300037C030A7701076C03065B010264010579020981030A800308780204
7201026D0201640200610B0300FF0000FF00
00FF0000FF00511D073B01005D05046402025F01015A01015301005301024F0000520102
5D01056301046401036700036900027501067B02097500057300077E020A80010A84000B
83000A89010F8F011092000E95000A98020A9C01089C0109950007920009950008A4030D
AA020AAE020BAF040BAF040CAB030AA80208AC030AA70007A60107A90007AA030AAA0009
A80108A60107AA040CAC050CAD040BAF050CB60B14B70D15BC1018BE0F19C5121CC7111B
C8121AC8121AC71016CF1519CD1016CF1118CC1015CA1217CA1517CC161ACB181CCB171C
CA171CC71418CC1A1CCB1617CD1316D01014CF0C11C911179613183203069D9BA0DADEE1
E0E1E4E0E0E4E1DFE4DEDDE2DFDEE3DCDCE1DDDEE1DBD3D5A8747B901723AE0814B4040E
B4030DB2010CAE010CAB010DA8010BA6020CA2000C9F020D9C010B9B01099B01089B0107
9B01099A01099C01099B010B98030D8E030C83030A7E010687030992030C94020B940108
9200069201099201099101079300079601079701069901069C010A9E010C9C010B99010A
99050E90050E7F01067D02077D01057D03087004086000026A03076C0104710205720103
6D0101690201620200630D0400FF0000FF00
00FF0000FF004C15014100016907086702025E01005A0101560000560102510100520001
5B01036101036501036801046900047501067E020A7B010879000780010A84010B86010C
86000989000C90021095011099020E99020B9A010898010A92000991000994010A9D010A
A4010AAA0209AE050AB1060EAE050CAA0108AC0309A70107A70208A80007A70007A70008
A70209A50007A70209A70108AE050CB50A12BB0E14BB1016BA1217BC141BBB171BBC1C1E
BA1D1DB91D1DBD1B1AC51819C9141AC91319BB1113A71717B03630B6423CB64440BA4949
BE4F4EC05450C55A53D15D58C63B3CC4181ECC0A12CB0C13AD131A490204645B5FCBCED2
E1E1E6E0DEE4DEDDE2E0DFE4DDDDE1DCDEE2DADEE0DFDDDFBD9DA188262FAA0E18B3030E
B3030DB1010CAF020DAC010CAA000AA8020AA4010D9F000D9D010A9D020A9D020A9B0109
9800079801089A010B95030D84020973000693262C9C353971060A83040B900109930107
9301069300079301099201099201079401069801089901099C020C9D020C9D020B9C0109
9C020B9A050F90020A8E030A8401067E0206790408660002650104650203620101660102
670101680102630200630D0500FF0000FF00
00FF0000FF005216044E01016F06076801025C00005B0000590100580100540000570003
6002076101036602046800036E00047A010883010986010A84010983000B85020A85020A
8600078A010B90010D97020E9B020D9C010C9A020994010991010791010A90000A99010C
A3020BA80208AE070AAE030AAF040CAA0009A90209A60006A60105A60104A60107A60107
A70109AB040CA80108A90009B0070EB50A12B60F17AF151AA11A1B941E1DA7433FBF6761
BE6F68BC6B66B15451AB3B3AAE2929B11E21971415510303CBA19CE1BFB8E1C2BADFBFBD
E3C3C1E3C5C1E8C9C2EBC1BDE4989BAE2029CB121CCD0B15BE141C6B090E372125C4C4CB
DEDEE3E0E0E3DEDEE2DEDFE3DEDFE3DCE0E3D9DDE0DCDEE0CBBABE8D4048A0121BB0030D
B4020EB3010DB0010DAE000BAD020BA9010AA4010D9F010C9D010B9C01099D01099C0109
99000896010895020B88030A710002760108890D18A22D37A2343B7901078E030B940209
9501069401079301089100069301089300089601099801089E030D9C010A9C010A9C030B
98060E95060E99040D98030B8703077A01047F04097501047201056C02055D0001570001
60020266020263020165100700FF0000FF00
00FF0000FF005415045402016E04046701025E02015F01025901015301005601015C0103
6503076401036601036A00047201057E010786020A88000C88010C82010B800109830108
88010A8E030E8E010A95010C9D050D9C010B9801089401099101079001078D0006950109
A10309A90207AA0404AD0409AC030AAD030BA80108A70007A60106A80108A80107A90108
AB010AAE040DAC050CB0060EB0060EB00B159E1219720F116A2825AA7E78D2B7AFDCCBC5
DDD2CADDCECADAC3BED6B3AFD7A39EBA736D85433F270A0B7A7A7AD9DBDAE1E2DFE0DFDE
E1E0DFE3E0DFE3E0DDEBDFE1E7BFC4A83942C3151FD00F17C6111A8C10162D0307A09EA4
DDE0E4DFDFE2DFDFE3DCDEE1DEDFE3DEDFE3DCDFE1DBDDDFD2C9CD9A626B931420B00712
B4030EB2010DB0010CAD010AAC020AA70009A4010DA0010E9D010C9B010A9B00079C0108
9A010997020A8D030C7601077501068B040D92010D91030E8C08117B0005890309920108
93000794000695010795010897010A96010A9300079600079C010C9C000A9B0008950108
8200037C010490030B99040E8304086B02037604067E03057C0103760205630203510000
560000610302620200630E0500FF0000FF00
00FF0000FF005413025703016D03016601025D01005C02015701005300005600015B0101
5E01025E00016601036F01067401057E010786020C8A020E86010C81000A7D000682010A
8A020D8C010B8F010A96010C99020B9A000B9701079401069101079001078F0107950006
9F0107A80407AA0608AE090DAC050CAC030AAB0209AA0109A60007A80108AA0108AD020A
AC0109AB020AAA030AB30811B20711A10C1962060C442121B0A39EDDD9D4E0E0DBDFE0DE
E1E2E0E2E1E0E1E1DEE3DFDEE3DED8E2D8D1CBBEB8817D7B6C7273D2D9D9DEE3E2E0E2E3
E0E4E3E2E3E4E1E3E2E5E2E3E4CDD0B7626BB51922CB1018CC1319A7131B440206716A70
D0D5D9DEE1E4DEDFE2DDDEE1DDE0E3DEE0E4DADDE0DADDDFD9D6D9B08991881C28AB0B18
B30510B2020FAE010BAC0109AA0209A70108A3000AA0000D9F010C9D010A9B00089A0107
9A000895010A8002096400017D080E91020B96010B96010B90030B7F0105820206900209
9401099501099502089400089401099401099601089701079901089B010A9C010A98020A
8C030B7B010587030A92050E7601045500005A000077020688050A800307680002580000
5901006002025F02006310072C860000FF00
00FF0000FF005311005803026F05046802025D0000580001550101550101580101590100
5900006101026901027201057300007E010683010888000A86010B81000A81010884000A
8C010C90000C94020D99020C9C030C9801099702089300069101078E01088D0005930105
9B0206A50509A50207A80208A90209AA0108AB0209AB0009AA0108A90007AA0109AC010A
AE050CAC040BAB030AB40A12B00D15870C152F00027D7578D3D3D1E0E1E0DFE1E1E1E1E2
E1E1E3E0E0E2E0E1E2DDDEE0DFE1E2DEE1E0E1E3E1DEE0DFC9CECCC7CDCBDDE3E1DFE3E2
DEE4E2DFE3E4E0E3E4E0E1E1E4D9D9C98D92A42028C41218CC1217B5131A61080E3C2B31
C4C9D0DDE2E6D9DBDFDEDFE2DCDFE1DBDDE1DBDDE1DADCDEDDDBDDB99FA3872E39A20E1C
AF0613B20411AE010BAB0109A90108A70209A4000AA2000CA2010C9F010B9D010A9B0008
98010896020C7B050B59000175070C8F030C96020D96010B91030A7B01047901048E0308
9300069401079300069101078E02098E02099302099601079901089B010A9D010B9C020B
98020C8B030A8601068F050C82040A6802055700006E01068A050D850308710102680202
6502026101015B010067160F2A850100FF00
00FF0000FF005514015D04026F03026601015C0000580100540100530002570102590101
5C01006400026C020373010677010480020685020689020989020B85010C84010B87000C
8C010C93020F95010D9B030E9A030B9801089701059400069101098C01088B00068D0004
9401049D0207A00004A50107A80108AA0108AA0108AC010AAB0209AC010AAB0109AD020A
AA0008AB030BAA0108B10710A80A13700810200707A09EA2DFE1E1E0E0E2DFE0E2E0E1E4
E1E2E5E1E2E4DFDFE3DAD7DFCDC3D1D7CDDCDFDEE7E0E4E9DFE3E5D8DBDEDCE2E2DEE2E3
DEE4E4DDE1E4DDE2E2DFE1E3E3DEE1DCB5BB9E3239BE181ECA1215BB11157D0E1526070D
9EA1A8D8DDE1DCDEE2DBDCE0E0E1E5DEDFE3DBDDE1DCDCDFDDDCDECBBCBD934F5695101D
A90613AF0412AE020FAB010CA80009A60109A5010BA3010DA0010DA0000C9F010C9A0009
9B010B97030C79040A5000015D020681050D8D020A9001098A03097101036F0104890209
9201079501089401088F020980010575020481030791020999010A9D010D9C000D9D000B
9B020C91030A87020884010687020A82050E6801046C010484050B7F02067402046E0303
6B02026301015B010066160F2A850000FF00
00FF0000FF005A17016003027003026701015E02015902015401025101014F0001590101
6502026901046D01047201057601057F010884000788010884010B7C020C7B020C83020C
8B010B92010C95010D98000C98010A9B01099701089402078E01068A01058800028B0103
9301069C0107A10006A70209A70208A80108AB030AAE030BAE020BAF020DB1040DB1040A
AD0208AC0209AF040CB30711A6091469070E220C0EA7A6AADDE0E1DFDFE1DEE1E3DCE0E3
DBDFE2E0E1E6D8D1D9C39DAE904A63782F4D8C617AC2B7C8D9DCE5DDE0E5DFE3E6DEE2E5
DDE1E4E0E4E7E0E4E5DFE4E4E2E4E5E0CACEA55158B31A21C61114C00E139A151C330005
6F6D74D0D6DADDE1E4DADCE0DCDCE0DEDFE4DBDCE0DCDDE0DADCDCD6CED1A4727A891624
A60917AB0310AB020FA8010CA8020AA6010BA5020EA1010D9E010C9D010D9C010C97000A
9A000B98020C7C030A4A000143000362030A79030B82040B7A070C5E020463010485030B
91020994010896020A9102098202076C01026D01018802089601099C020D9B010D9C020E
97020D8A01088303097E010685020889030B7B04097301057D0408710001640001600100
6801026702015E010067160F2B860100FF00
00FF0000FF006119016503017604046801015D01005900005501015001014E0001580101
6702056B01066E02066F00027300057E010A84010A86020B7702086100035D010477020B
8A020D93010D96020D9A010D9B010B9B010B9601099001078A01058800068801058B0103
9101039B0006A60209AA020BA9020AAB010AAB0209AC0108AF010AB4030EB5060EB5050F
B10309B1040DB1070FB10711A609156E08111F070C9B9BA1DADEE0DFE0E2DCE0E3DBDFE2
DEE2E3E2E1E6D9C7D09B4D5FAA2035B11C358C1730601F38907E93D5D6E1DDE2E6DFE3E6
DEE3E6DEE3E6E2E6E7E0E4E7E0E4E7E4DBDEB77A82A72029C41217C40D12B0151C520308
4A3F45C0C8CEDAE0E3DADDE1DBDDDFD9DCDEDCDDE1DCDDDFDEDEDFDEDBDCB2919882212E
9E0A18A80410A7020BA7010AA7010BA6010CA4010CA0010C9E020C9C010A9B010B9B010B
9B000B9B010D8B060F5402053100013F00055201075802084E02054000005B010584020D
91010A91000794020896020A93030B86040A79000489020897020B9A010B9C020D9B010C
98020E8601087D01068304098702068D03088001057E030589080E7801046601015E0001
630101690203620201620C062D860100FF00
00FF0000FF006C1F066E07027703026800005D00005A01005601015201005201015A0103
6502056A01066A01046C010375000680020B87020B89040D7602085D01055200026D0109
89020C96010C98020B9B020A9C01099A010B9601078E01068801078900078A0206880002
900104970105A3030BA9020AA80108AB0209AD030CB0030CB2020CB70511BB0A14B4020C
B4050DB4050EB30911AD030EA808137E0D17210004838489D5D9DBDFE1E3DBDFE2DBDFE0
DEE2E3E3E2E4DECACFA6545FB31825C5121FBF1621A0192C4E0B206F6475CFD5DCDDE2E5
DDE3E3DFE3E6DFE4E4DFE1E5DDE0E3E2DFE1CFA7AC9C2931C3161CC80F15B91016750C10
291013A6ACB1D8E1E3D7DDDDDADEDFDBDEE0DBDCDFDCDDE0DADBDDDBDADDC4B1B7873B46
960E1BA4030EA9050EA7010DA7000CA7010BA4020AA1010C9E010C9B000B9A010B9A020C
9C020A9D020B92050E6704093801014212153A070B2E000429000233000160010789030C
93010B9100069201059501069501069001078B01078F01079601089801099C030D9B010B
9A020D90030D7E00048102068A02078702048002048102058B070C8002057202016A0101
680101670001630201610A052D850100FF00
00FF0000FF006C20066F08017704026A01015E01015A01015701005400005301005B0101
6301036601036700016D000177000381000887000A8B020C85030B7B040D6F0208770108
8D020C97010D9B020C9D020C9C020A9D020C9602098C01078700048901078D02058C0104
9002069300069D0107A6020AAA030AAC0209B0040CB3030EB5040EB5040FB60410B3030E
B3030EB2040EB20710AD030EAC09118D0E18310106625F67C8CDD0DDE1E3D9DFDFDEE2E5
DDE1E2DDDEE1E0D5D8B26F78AC1B28C40F1AC9121ABD151F8711212D0918A7A9B4E0E4E9
DFE3E5DFE3E6DDE3E3DFE2E5E2E3E6E4E2E4DEC3C7A3444DBA1820C70E13C00E13971419
3100037B7B7FD2DBDCD9DFE0D6DADDD8DCDFDADCDEDADDDED8DCDDD8DADCD2CACD945E66
8C1421A50715A6020EA4010CA6020BA50208A2010AA0010C9D000B9B000A9A0009980108
9901089C010A96030C800B10540B0DB58689A4808424070923000041000270030A8C0109
9101099000059301069501069401049301059401079601079701079A010A9B010D9C010E
9A020C94020C8401068001048602077E01027900027B0104770103790305750203710202
6C0101690101660202650D082B830000FF00
00FF0000FF00631B027108037A03026D01015F01015A00015500015301005301005B0101
6101026501026901027101027A01038000078601078D020D8B010A85010A82020A85010C
90020E99020E9B010D9B010B9C000B99010A9201098B01088801058800048A00028D0006
9101089400089A0007A60209AE030CB0030DB2040EB4040EB80410B8040CB7060FB4020E
B3030DB2030FB1050FB50B14AF0A11981019430207413940B9C0C4DEE3E6DCE0E1DDE1E2
DCE1E4DBDEE3E0DCDFCA9CA2A42833C5141ECD121BC8121DAB172243020D635A68D7DCE3
E0E4E6E0E2E6DDE3E4E2E6E9E1E4E6E3E3E5E5D6D7BA7278AD1C25C60F17C30B12AC121A
4F020853494EC9CFD2D8DCDFD9DEE1D6DADDD7DBDED6DCDFD7DCDED6DADBDAD6D9A9838A
811926A00917A3010EA4010BA30109A3010AA1010C9D000B9D010A9D020A9B0108980006
96000799000A98020C8B0710A2434B793C4585555F420F154901046C030887030A910109
92010890010790000694000696010696010597000597000598010799010B9B000C9C010C
99010B95020B8402067D02048102067C02047900047F03097401047302047102026D0201
690101680100630100670F092C840000FF00
00FF0000FF00681C037006017B03026D00006100015C00015701005401005201005A0100
6101026401026901027002057601037E01078601078C020C8D010A8700078600098A010C
8F010C97010D9C020E9E010E9F010D9B020B9401098E01098C01068A01048800048E0209
910009940109980007A6040CAD040FAE020EB1030DB4040EB8040CB90509B5030AB2010A
B1010BB1020CB3050FB2040FB0080FA20D175D060F24141BA3A8AEDBDFE2DDE1E2DDE1E4
DAE0E0DBE0E3E1E1E4DCBEC3A8454DBE1B24CD121CCE111CBD161F6B0A133A2430C8CDD4
DFE5E7E1E4E8E0E4E7E3E4E8DFE2E4E0E3E3E6DFDFC49296A1252CC5141CC70D14BB131D
6F0912321B21B1B4BADBE0E3D9DDE0D8DBDFD7DBDED8DCDFD6DBDDD4D9DBD9D9DBC0A7AD
7F2B36990C19A4020FA4010BA4020AA2010A9F020A9D010AA0030D9E010A9C00099A0008
9901099A010C9A010C95030E90121EA3404CA44A588825327C050F8C040C910109920108
91000591000693000793000695010797010899010898010998010A97010B9B010C9C020D
98000A9201078001047300027902057500017E020584020A7E0108710104650102630101
660100660100620100660E092D850100FF00
00FF0000FF007223057909017E03016F00006201005E01015900005800025801005E0101
6501016701016800016D01037200047C01078501088C020C8E020B88000A8700098C010A
91010B98010D9D020FA202119F010F9D020C97020B9100098D00068B00058B00058E0008
910107930109950107A0020BAA040DAF050DB2040DB4030DB8030BB8050BB7060CB2040B
B1010BB4050FB3050FB4040FAF030DA3061175091421020A84878ED2D7DBDDE1E1DCDDDF
DCE1E1DDE2E5DDE0E1E5D5D8BC757AB22029CA131AD01219C6151B8F121A2F0610A8A7AE
DBDFE3DADFE3DDE2E3E1E3E7E0E1E4DDE0E1E4E2E4D7B6BB9C343CBF1821CA0F16C01017
870D162A020984848BD4DBDEDCE0E3DADDDFD8DADDD7DBDED8DCDED7DBDDD8DBDEC7BBC0
89485191101CA30511A5030EA2020CA1040C9D010A9D01099D020A9D010A9D01099C010A
99010A98010A98010B99010D95020F8D05138A08178D061492030E93010B93010B930109
9300079300079501099301069200059501099801099901099A000A9A020B98010A9A010B
98010A93010A8A030A7901037C03077901037C02048202088102087603065F01025C0202
6903026A0202620100630A052E860200FF00
00FF0000FF00701F047B08018104017301026200005D01005B01005C01015D0101640101
6902036B02036801046B01047101067C01078501098C010C8C000B87000988010A8F000D
93000C98010CA00311A0010F9F020E9A000B9401098F01078C00058C01088C0108900107
92010A95020C94010A9B010BA6050CB0060EB3040EB70410B8030CB7030CB4030BB2020C
B3040DB2050EB1050EB20610AC030EA706128B0E1732010850505ABDC5CBDBE2E2DDE1E2
DDE1E2DADFE2DDE2E3E3DDDED5A9ACA62D35C81B21CF1218C81316AC1A1D4503096F676F
D4DADDDBE0E2DDE3E3E1E5E8DFE1E5DFE0E4E1E1E4E4D0D5AD5D66B31A26CC141AC61117
A4161F3E0107625C62D0D7DADADFE2DADDE0DADDE0D5D9DCD6DADED7DBDFD7DBDFD3CED3
996B74861520A20814A60611A3050FA1030DA1020DA1020E9F010B9C01099C010A9B0109
99010C97000998010A99010A98010B95010B95010C95010B96010A95010993000894010A
92000893010895020A9201088B01058C020893000999010899010797010797010998010B
97000B9300088E02098201058002068003067702057001067603077503065E0102550000
6602026A0202660101610702550A0100FF00
00FF0000FF00701C037C09018102027000006301015E00005C01005C00015F0202620202
6802026901026501016900047200067E020885020889010B8B020C8B000B8D010C93010E
93000A98000B9E010B9E020D9B010B94000B9101088E01098D02098E01098D000691010A
92010893000A94020C97010C9D020BAD050EB3050EB5030DB6020BB7030EB3020AB3030D
B1030CB0040AB0060CAD030CAD040FAA0411970B164A050C2F262EA3ABB3DAE1E4DBE0E3
DBDFE2DCE0E3DFE4E5E3E2E4E0C8CCA94D54BF1E25D0131ACF1419BF1A1E6D0C13402A34
CCD3D8DCE4E5DCE2E2DFE3E6DEE2E3DFE2E3E1E2E5E7DEE2C88F99A7242EC6141BC71015
B1121B5B050C403035C0C5CADBE0E4DBDEE0DCDDE0D7DBDED6DADDD8DBDED9DCDFD8D7DB
AA8C9380212E9D0C19A30611A2050FA2030EA3020FA3010EA1010C9D010A9B0109990109
99020B9901099A00089B010A98010994000793000895010A94010B93000A950108960107
9401089401079200059002088200027E00028F020999010A98010796000597000897000B
98010B9501089002088101057A00047D03086B02045300005A01016D04056602035B0001
650203690102660001640904590B0100FF00
00FF0000FF00771F028009018203037300006500006301025D01015B01015900005D0101
6501036600026300006801017201047D01078200068700088D020C8E000B8F020B92010C
93000A9B020CA0020B9E020D97010A93000A9102088F010A8D01088F020A8B0005900209
91010894010897010A96020C970009A20209AE030CB5040EB4020AB3020BB4040BB4040E
B2040DB2060EB1060CAC010AAC020DAB030F9A061064070D1E080D8B9099D7DCE1DCE0E3
DBDFE0DDE1E4DEE2E5E2E2E4E4D8DAC68589B32429D0161ED11219CB171E97151E310510
ACACB5DCE3E6DEE4E4DFE3E4DEE2E3E1E4E4E0E3E4E5E3E5D6B2B7A0343DC21923CB1219
BC10197F0E172D0C11A5A9B0D8E0E3DBDFE2DADDE0D8DCDFDADCE0D7DBDED9DDDFD9DBDE
BBA7AD813340970D1DA40613A2030EA3050FA0000FA1010E9F010B9C01099C0109970009
98010B99010B9A020B98020A97020993000794010A94010B94010A940209930007940107
9401059200049201059101058C02078601058D0106970109970108960107960107970109
98010A97010A8F01058301047500047201057206096204075500016303056A0306630102
6802046A0103660101660B065D0E0400FF00
00FF0000FF00792003830A028403027500016901006802036202025C01025B0101610102
6701046B02046701016800017000027D000687020C8A000C8E010D90030C8E010A91020C
93000A99020BA0040D9E030E95010992000990010891010A9000098F00098F0107920007
94000799020B9C030D9A020E98020B9B0007A7030AB2050EB1020AB2030AB2030CB0010A
AF040CAE050CAB030AA90109AC040CA70209A1060E83101826000563626EC2C8D0DADEE2
DBE1E1DEE2E5E0E2E3DDE0E1E1DDDDDDB2B6AB333ACA1921D4141AD2171CB71C234D030B
726771DEE2E4DFE5E5E0E4E7DFE3E5E1E5E6E0E4E5E2E4E5E8D2D6AE5862BB1F2BD11620
C8121C9D141D36000784858CCED8DBDBE0E3DADEE1D7DBDED9DDE0D4D8DBD9DEE0D7DADC
CDC2C791545E901321A50615A5030FA5030FA1010DA4040F9E010A9B00099B000A9A000A
98010A96000A93010994000895000895000795010B920009920008940006940006910006
9100069100059101059101069001078F0107900107930108930007930006930106960107
9801089701079201068C02067C02046E00027301057505085F00015B0001640103690004
6C01026D0202680202670D0860120900FF00
00FF0000FF00792104830C028603027801016B00006701006200005E01015F0101660103
6900046D01046B01026C000375010680010A8A020C8C010E8C010C8F020D8E010C90010B
92000B97020C9B030C99010D92000A92000A91000A93010B92000B93010B93020993020B
96010A9A010B9E020D9E030F9D050E9D010AA5030BAF050FB1030CB1010BB2020CAE020B
B0080FA9030BA60108A40007A50107A70208A203098D0A123B0207322C38A6AEB7DBE1E6
DDE1E3E2E4E7DEE2E3DBE0DFE0E0DFE7CED1B75962C5202AD6161ADB191ACE1F237A0E16
4B333BD8DADFE0E4E6E3E7E8E0E4E5E4E6E8E1E4E5E0E2E4E7DDDFC48690B32833CD161E
CF1219B81A2254040C61565EC8D0D5DCE2E5DCE1E4D8DDE0D8DDDFD9DEE0D6DCDFD8DBDF
DBD4D8A47981841624A40918A70310A6020EA5020EA4040E9E00079C01089C000A9D020C
98010896010995000A97010B98010A97010A95000A93000A9100089200089200078F0005
910006920106910105900106910108910107910208900209920209920107950209970108
9802099401079101068B01038303057A01057C01067E04066F01016502036602036C0304
6F02046E01016A010266090663120A00FF00
00FF0000FF00782403850D028A04027E0103700100690101650101600001600001670105
6A01056D01056F02057101067400057D020985010C87010C87010A8C020E8C000B8E010A
91010A95010B98020D94010B91000992000A92000A93010A92010A93010B94030A92000A
95020C98000C9C010C9D030D9B010B9C010B9F0109A8020CB30710B2020CB4050EAC010A
AC040DA9030CA40208A40108A80209AC030CAA050DA00D165D070F201019929AA4D9DFE5
DEE3E5DEE2E3DBE0DFDFE4E5E0E2E2E9DBDED49197BC2A33DC1E21E51C1EDC2025A61923
3F0A15C2BDC2DFE3E4E2E3E5E2E3E5E3E4E6E5E7E9E2E6E7E6E2E4DFB4BAAA343ED01E25
D9151BCA191F770C133D242BD0D6DBDCE3E5DEE4E5DBE0E1D8DDDED9DEE0D9DEE1D7DBDE
DDDCE1C2A4AD872936A30D1AAE0814AA0310A6010FA3010CA2010BA0010C9C010B9A0008
9A00089801099700099B010C9B010B98010A96000A94000B930109920109910107920005
9201069201079000068F00048F01059000088D030A83010586010691010A96010A950008
9400089401099203098502057601027A02048302078402087A0103700203650102630101
6D01037002036B0101640301630F0700FF00
00FF0000FF007B2304860D038903038002047301016D0101670101630102610102640003
6500036D020570030671000672010578000680010A82010B80000887010A89000A8E000B
92010B94000A94010B91020B8E010992010892010892000A92010892020B910208900109
94020C97010C9A020B9A010A9C020C9E010C9F010BA6020CAE030DB2030DB3040FAC0209
AA040CA8030AA6020AA40106A80108AF040DAD030DA909157B0812240109727682C8CFD8
DDE2E5DEE2E3DFE5E3E2E6E7DFE4E1E9E3E1F6CBCEC24B51DE2A2FED2729EA2B30D02F3A
67111DA18F97E4E7E8E6E8E7E4E7E7E5E7E9E6E7E9E6E7E9E6E5E7F4D9DDC1616AD82D34
E61D22DC1C219D161A3A0A10C5C5CBDDE4E7DEE4E6DBE2E3DADFE2DADEE2DADFE2D7DCDE
D9DDDFD3C2C7934751A2131FB10812B1030FAD0410A7010EA6010CA4000D9F000B9D0008
9C01099A010A9B010A9B000A9B000998010997010A97020A96010A930209930008930108
9200079100069000069000069101088F01078C02087F01037E000490020C9A020C9A010B
96010A9301078E01068101046D0001730103840207820105780103710304670204620001
6C02026E02016B0101660201600B0300FF00
00FF0000FF00822809890B038C03048301047601016F01026801026400036101025D0001
6101016A01056C01036C00056E00037600067E020A80010C7E000884010988010A8E010E
92020C92010C90000C8E010C8B0109900009900009910009910207910208910208900009
93010B96010C99010D9700099D020DA2020EA3010CA5000BA8010BB1040EB30610AD020A
AE050DA80007A70108A80108A90108B1030EB1020EB208159B101B45030E4D4552BEC3CD
E0E5E8E2E6E7E0E6E5E3E7E8E2E5E6E7E5E6F6E2E3DA8F91D34F51E15050E65D60DC626A
A95D65B19DA2F4F4F4E6E7E9E8EBECE7EBECE7EBECE7EAECE6E6E9F7EBEEEEACB2DD454B
F53133ED2728C9262854030CAEA2AAE0E5E9DFE6E9DDE4E6DDE1E4DCE0E3DBDFE2DBDFE2
DBDFE2DDD3D6AD6F79A11A26B70915BA0612B70511B50511AF050FA8000DA6020EA2010D
A0010C9D000A9B000A9B000A9B00099B010A9A000A99020B970109970108960009930108
9201089201089101079101079201089101079001078D02088B000894020B9C010B9B010A
9701089200058C00048702077C02067901038201057D02047001036501016903036A0002
6E01016D00006A01016605026A170E00FF00
00FF0000FF00862A088C0C038E03038502037601016F01026901016101015E01015B0000
6202036A02066A01036B01056C00057401087D020A7E010B7B00078100098401098A010B
8F020B90000C8E010C8F020E8901088C01098E010A90000990010891010A8F020A91010B
92000A94010B97010A99000A9D010BA2020EA3010EA2000BA4020AAC050EB0070FB2060D
B3070EB1040BB1030BB2020AB8050EBD0711BB050EBD0B13BA18217D132040202DC5C5CD
E4E8EBE1E5E7E5EBEBE4E8E9E7E8EBE9E8EAF0EBEBFBE7E7F9D1D1FFD7D7FFE4E4FFE6E8
FFEFF0FFF8F8FDFCFDF0F1F3EFF0F2EFF0F2EFF0F2F1F2F4F1F1F4F2EFF1FFDADEE7696C
F64340F73831E73835780C158C717CE1E4EAE1E6E8E1E6E7E0E4E6DFE3E5E0E4E6DEE2E5
DDE1E4E3DEE2CF9CA6A32230C20F1DC60916C20614BE0612BB0610B2030CAE030DA8010C
A4000CA1000BA0010B9E010B9C01099A00099B010B9B010B9901099A010A99010A970106
96000697020B93010992010892010791000693010794010996020A99010C9C020E9C010C
9A010A9600079301078F02098601068301068402057B01036C0001630102670202700203
7201017001016801016003016D1E1500FF00
00FF0000FF008125048B0C018E04018302027400016C00016901016502025F01015D0001
6101026502036600016B01046E02047702077C010B7C000A7900077E0009830009880008
8D020B8F010D8E010E8C000C8800088A030A8E020B8F010A8F020A8E010A8E0109900009
94000A9600099A020C9D020DA0020DA3010DA5020DA1000BA1020BA8040BAD030AB70A0E
BC080DC60D13C70C11CD0F15D11117D7171CCE1115D81B1FD72127B9252F651927C8B6C0
F2F2F5E7EBEEE9EDEEEBECEEE9EAECF1F2F4EDEEF0F6F4F4FAF7F6FCF9F8FEFCFCFFFDFD
FFFDFEFFFEFEFEFEFEFEFEFEFDFEFDFAFBFBF7F7F9F5F6F8F0F1F3F6F5F7FFE8EBF08383
FD5951FD4F42F84843A12029916571F8F7FCE4E8EAE3E6E7E6E8EAE1E4E5E0E2E5DFE3E7
DFE1E6E3DFE3E6BDC6AA3441CC1926D00D19CC0816C80714C10511C00712B7020DB3040E
AB010BA9010BA6010BA0010A9C00079B01079D010A9E020C9D010B9C010B9B010A9A0008
9B010A99000B95010A9201099000079101079301089600099A010B9D020E9D020F9B010C
9A00099801079500059001088400058001048302067C03057302046A02046401026D0203
7201017001016801006003006B1A1314C200
00FF0000FF008426078C0D038D03028001027101016B0101680100640101600001610103
5F01016001016401016D01017101027500067B01097900097A01087F010B83010A87000A
8A010A8D010E8D020E8A010B88010888010A8901088900088D02098E010A8F020A8F0008
9701099D010C9F010CA4020DA6020CA9000AAD030DAD030DA90109AE020CB4040DC40C13
CE1016DC171AE0171AE2161BE81D20EB2023EB2225F32A2EF33034ED3C43B03040BE8096
FEF7FEEEEDF0EFF1F3ECEDF1F2F3F5F1F2F6F5F6F8F0F1F3F5F7F6F5F6F8FAFCFBFBFBFD
FBFDFCFCFCFCFCFEFDFBFBFDF8F9F9F6F7F7F5F5F7F2F3F5F0F1F2FAF6F8FFD8DFEC7176
FA514BFC453BF43C37C332397F4451F4F0F6E2E6E7E4E7E9E3E5E8E4E7E9E2E4E7E0E4E6
E1E3E7E3E0E6F5D6DFB54A58CB1F2CD10F1AD10C19D00C18CC0915C60510C50712BD050E
B7030DB2020BAD010CA9020CA300089F0007A10109A2010BA4030DA0020CA0020D9D010B
9C010B9B010B97000993000891010791010995010A99010A9B010B9B010B9C010D9B010C
9900099901089700079301088701077C02057603066E01036F02026D0205600001660001
7201027001016801015F02016F1D18298400
00FF0000FF008D2B0C8F0D038A02017D02026D0100690101640101610101610001650105
6501056601036901037100057401047A01087B02097A010A7701097C000A85010D89010C
8D020D8C010E89010B8A00098A02088900088800088C01098F010992010A900007940006
9B0006A5020AAA040BAC030AB4060FB6030DBD050DBC050DBA030AC20710C60A13CD0B15
DB1319E71B1FEF2023F11F22F52225FA282CFD2E32FD2F34FF3B3FFC3D44F14554B93552
E39EBAFEEAF8F4EFF2F1F0F3F0F0F2F3F1F6EEEFF1EFEFF2F4F4F4F7F6F8F8F8F8F9F9FA
F7F9F8F7F8FAFAFBFBFBFBFDFAFAFAFAFAF9FBFAF9FAF7FAFCF6F9FFE9EFF199A3ED5559
F7463EFB4036F63733CB2F34692431D3D0DADFE6EAE0E4E7E1E5E8E0E2E6E0E2E5DBDFE1
DFE3E6DCDCE1E8D1DAB05363C4202ECE0F1BCD0C16CC0C14D00F18CB0D14C80B12C10910
BE0912B9050FBB0A15B0020EAC020DA9020DA6010DA5010CA5000AA7020CA8040FA5020D
A2020D9E020D9B010B97010A95010993000894000999010D9B010C9C010C9E020E9C010A
9C010B9B010A9900089501078C02077601055E00006101026D03046B0204650103690101
7201026F01016500015A00005F0E072B8601
00FF0000FF008B27098C0B018803017A01016A0000680100640101640001670102660003
6501016801026C01027101057501067C010B7901087501087001087A010A85010C89010D
8B020C8A010D8600098A01088C01078E000991010A94010C96000B9C020D9E030CA10108
A70107AF0208B30307BF080CC5090DCB0C0FD00E11D31014D00C13D20E17D31019D7111B
DA111AE71A23F11F25F52024FC2729FD2729FD292CFC292FFC3134FA2F35F9353DEF384A
D4405BE989A2FFE4F2FFF2FCFFF5FDFFF3FCFFF2FBFFF0FAFFF0F8FFEEF7FFF1F7FFF3F7
FEF9FBFEFEFFFEFBFDFBF5F7FEF2F5FEEBECFEE5E6FFDEE1F9C8CCF0969BF16C6DFC5851
FC4C3FFC4538FD423ADE373A701B26C6BDC6E1EAEDE1E6E9DDE2E5DFE2E6DEE1E3DCE0E2
DFE3E6DEE0E4E3D3DCB56675BB2132CE1321CF111BC90C13C80D14C50B13C10812BF0712
BB0511B80510B70612B50612AE020EAA020DA7010DA8010EA8010EA9010DAA020CAA020D
A5010EA1010D9E010A9C010C98000B96000996010999010B9E020EA1020EA2010CA3030D
A0020E9F020D9D010B9701088E02087F02076902056400036F04066801016501016E0102
7301027101016901025C01005F0D062D8601
00FF0000FF00822506880B028502017800006A0000680102670001690102690102640002
6401016801026B02037001047600097D010B7C01097200056B000479010885010A8C010C
8E020E8B010B8800088B000892010A96010D99010D9B010DA2020CA7010BAB030AB0020B
B5030BC00810C4080CCA090ED30F10DF1817DB1513D81012CF090FCD0812CB0711D10C16
D00A14D30A15E4161FF01C21F11A1DF82223FE282AFB2729FA2C2AFC2F30FC3336FC363B
F63A44EB495BEE7286F38EA5F497ACF492A7F290A2F292A1F295A0F8A0AAFDB0BAFFC7D3
FFE2EFFFEBFAFFEAF8FFDFEAFFC9D2FCAAAFFD9F9FF99090F97F7DFD746EFF655CFF594D
FF5146FF4940FE413BF140447E1724C3AEB8EBEEF3E4E8ECDFE4E7DFE3E6DEE2E5DCE1E4
DBDFE2DCDEE2E7DCE3BF7D8BB12232C91320C90E19CA1017C60C13C60D16C10915BD0614
B90411B70512B50411B2020EB2070FAA0009A8000AA9010EAB0010AD0210AD020EAB000D
A7010DA3000BA101099E000B97010A9202089402089801089E010CA4020FA5010DA6030D
A80611A606109F020B9A01098D01058402057B04086C01026F03056E02046F0103760203
7701027101016A0102610100630D062E8500
00FF0000FF007E2306870A008401007A01016B0000670000670001690102690102620102
6000016700036C01057000067801077F010C7F01087A01057600067E01098601098E010D
90000D8D00088D000791010797010A9D020EA1020FA4010EAA030EB1040FB5050FB8030C
BD040DC2060EC7090ECF0D11D10D0ED00A09D6100DD20A0BCB050BC4000AC6020CC9040E
CE0912CC050FD60C15E7151DF51D23F82125FE2B2BFF3030FF3530FF3631FE3838FC3536
FE393BFB3E46F84C5AF55264F35566F85B6CF75B69F45B67F7646CF5686FF36D7AF2798A
F389A0FE9CBAFC97B3F4879EF07686F26870F76567F8615FFB5B57FF5953FD4D47FC433F
FE3D3BFF3B39F93334EE383F821424997D8CE5E8F0DDE3E7DEE3E7DDE2E5DDE2E5DADEE1
D7DBDEDDE0E4E3DBE2C58B9AA72334C21221C50D1AC60E18C60E18C60E1ABE0714B80312
B80413B60511B3020EB1010CB2050EAC010AA9010BA7000CA9000EAC010EAE030EAB010C
A8010BA6010AA40009A1010C9100078500048D02089801089E010AA3000DA70210A80210
AB0714AC0C15A5080F9A020A8D00068700058202077200026A01036B0204730306790203
7902027001016900016201006811092D8500
00FF0000FF007F2204890C028503017B01026D00016A0101670101670102640102610101
6101016800036E01057300057C010784020B84010783010882010887000A8B010993020D
97061196030D9401099B030B9F020CA3020DA5010BAA030EAF040DB4040FB4040DB4010A
B8020ABE0309C0040AC6050AC90508CD0607DA1512D40D0ECC080DC9060FC9070FC8040E
CE0913CF0B13D50E18E61621F31D28FA242BFD2C2DFB2A2BFC2D2BFF322EFD3230FE302F
FD312FFE3436FD3A3FFB3B44FA3D46FD414AF83C45F93F45FA4449F64349F64651F14655
EE4B61EE4E69EE4B67F14B5FF14554F44149F64144F94342F53C3BF93C3BF83637F52F31
F42A2CF62A2DF0272CDC28308213235E4153CCCEDBDEE4E8DDE2E5DDE1E3DCE1E4DADEE1
D9DDE0DCDEE2DED9E0B18390972131B71120BC0C19BD0B17C4101DC00C19B90615B30313
B40514B20410B1040EB1020DB0040EAD020DAC020DA7010DA8010EAC010DAC010CAB010C
A8010BA5000AA40009A1020C8F01077C000185010698010B9D010AA1000BA5010FAB0513
AF0B19BC1E27A70A12A0060D9402098B02078502087A01066700016401016F0103760102
770102700101690102620101650E082D8500
00FF0000FF00862905860B018203017B01016F0100690100630101600000600001630101
6501016C00047201047A010582010788020A8701078801088A01098D010A92020CA20E19
B11D27A50D19A10610A5040DA9050DA9030BAA030BAC030BAE020AB0000AB00109AD0006
B10106B90107BC0208C80A10CB080CCC0A0DD31614C80A0CC80A10C3080DC60B12C10610
C30712C40712C90B16CD0916D80F1DEB1C29EE1E24F12024F72629F72429F9292AF92728
F82827F92A2AF62A2BF62A2EF42C2FF42C2FF42E30F63234F43333F02F32F33437ED3237
EB3539E7343AE9343DE73137E73236E83438E93738E0302EDE2E2CE02F30E02E2FDB282B
DA282AD9292ECC2327C129307E1D2A3A2030B0B6C1D8DFE3DCE0E4DCDFE2DADEE1D9DDE1
D6D9DDD7DADEDBDAE0A68590831F2DAA1321AC0915AE0813B00814AF0513AE0513A90111
A7010FA7010EA6010CA9030EA6000CA7020EA7010CA5000AA7010BAA020BAC010CAB010D
A6010BA3010AA1010AA0010B97020B8701058A010799010C9F020BA10109A4010CA60010
AA0415B41220AC0D18A60A119A040C8B02097E00047E03077403066800026F0103760103
7702036F01016700015F01006A140D2E8601
00FF0000FF00832504850A018002007901026F01006701016101005F0101610101650101
6700016E01037802067F000783010788000A88010888010B8B010991020C9F0C16B01924
BF2731AF111FA90814AA050EAB040CAB020CA90108A80108AE020AB20109B4020CB20108
B7050ABE070DBF060CC4070DC1050ABA0309B00102AB0103AC0107AB0007AB0209AA0008
AB000AAE020EB20410B2030DB90512C90A19D81620D9151DDC1B21DE1D23E02226E3272A
E32A2ADF2C2BDC3131D83234D43537D83D3CD63E3BD54340D84A47D84D4BDD564FDA5A53
DA6259DE6C63E1716BDF6E6AE0726EE57976E57B77DC746FD46F69C05B56DA736FDC7673
D26E6EC06060B55758A55051854C525F50588C9398D5DCDFD9DCE0D8DCDFD8DDE0D7DBDF
D7DBDFD4D9DDDADCE1AB99A16F293490192599141C990E149D0D15A10C15A20613A20412
A0010E9F010D9E000D9F010D9E010C9E010D9E010C9F010BA4010BA9030DA8010DA70210
A2010E9F000B9E000BA0020C9D020C9201079501089D010AA1010AA40109A30009A6010E
A60111A40111A103119C06108D030B86050E7904097702057F04077600027801047B0103
7B02037201026700015F0100650F082F8702
00FF0000FF008425058509017E02017601017002006901036202005F0101600101640100
6900027201037B01058101088601088801088701088700078A0008980510A50B18AE0F1B
AF101CA70614A90510A8030EA8010AAE020EB0030DB0030DB2020CB6030DBA040FBA050E
B9050DB20107BC0810B9060DB10209A90107A102049C00029C00049D01069C0206990006
9900079C010B9F010B9E000AA5040FA8010EB00915AC111CB2292DB53738C14A48D05E5B
DD706CE4807CEA9391EFA4A3FABCBAF7B7B5FBC1BBFDC5C2FCCBC8FCCFCAFAD0CAF9D3CC
F9D9D1F9DAD4F9DDD6F8DDD9F9E2DEF8DEDDF8DDDCF8DFDBF3DAD5EDD5CFF4DCD7F0D7D5
EFD6D6E7CFCFE6CFCEDDC8C6D4C7C6CBCBCAC6CCCFD7DDE0D7DBDFDBE0E3D8DCDFD7DBDF
D6DBDFD7DCE0D7DBDDB6B2B48467698D53568D46478B3C3D8A30348B282E8A1A22900C16
9A040F9B010C9A010C9A010B99010A97010B97000C99000B9C000BA2020DA2010F9F000E
9E010D9C010C9B000B9B010B9B010A9A010A9B010AA0010AA3010AA5010AA4010CA50110
A502119F000F9B020F8901087500027A030B78080F6A00017A03067D04067B02047F0205
7F03057501026B01016200015E07012E8701
00FF0000FF008223058108027C02007401017001006900025F00015B01015D0201640102
6D01047601047C01038301078801078801068801068A00078F010B99020EA90916AD0914
A70610A1000CA2010BA8030FAB030DB30512B50510B4020EB4030DB4030DB6040CB4050C
AE030BA80108AA010BA80008A101069D02099901079600069301059201059102038E0005
8E010692000A93000997000B9A010D9C0310950715650109864C53D0ABAAEAC8C3F4D4CE
F6DBD7F8E2E0F4E3E2ECE0E1EEE7E6EFE8E8F0EAE9EEE9E8ECE7E7ECE9E8EBE8E8EAE9E8
E9E8E7E8E8E7E8E8E7EBE9EBEAE8EAECEBEDE9E9EAE7E7E9E7E8E6E6E7E5E3E4E5E7E7EB
E7E7EAE6E6E8E4E6E6E1E4E4E2E5E4DEE2E3DBE2E3DDE4E6DADFE2DDE1E4DBE0E3D9DDE1
D9DDE1DBDEE1DCDDE0D7D9D8D3D0CDD1CAC7CDC2BEC9B7B5C5ADADC0A1A2BD8C8F8A2F37
8F08129B030C9C010B98010A94000793010894010A96010C99010C9C010B9D020D9C010C
9B010B9A000A9A010B9901099A010A9900099C01099F010AA3000AA6000DA7010FAA0312
A502109D000D97010B8A030976010578020879040A6E0105720509680203670203770305
8002057A02046B00006200005E0501444902
00FF0000FF008126067E08017801007401017201036901035A0000530000580101620102
6D01037801057F00048501078901068A01068A00048D000894010C9E0410A70612A8040D
A6040EA1020DA2020EAB0512AB030FAE0410AF030FB0030DB2050EAF040DAA030AAB060E
A1030A9B0008A1040C9F01089601079201089101079200088F01078C00038B0103870003
89000690010B94010C9A010D9C020E9F04129A0C1A5F0514442D3BCECFD7E5E8E8EBEBEB
E9EAEAEBECEDEAEDEEE8E9EBEAEBEDEAEBEDEDEEF0EFF0F2F1F2F4F6F6F8EEEFF1F1F1F3
EDEFEFEEEEF0EEEEEFEFEDF1F0EFF1F2F1F2F5F5F6EDEEEFEDEDEEEAEBECE8E9EBEBEBEF
EBEBEFE7E9ECE6E8EBE4E8EAE3E7E8E1E5E6DFE4E6DFE4E8DCE2E4DADFE3DBDFE2DCE0E3
DCE1E4DDE0E3DDDEE1DBDDDFD9DCDDD8DDDDD7DCDCD4D9D9D4D8D8D4D6D6CFC6C88C545D
8A0F1D9D020EA0010C9C010C96010993010793000896000A98010B9A020A9A000997000A
97000A99010A9800099600099501099600089A01099E010AA4020CA90210AF0515B20A19
A804109E010B9801098D01087600037502057E05087301046D03085300004D00006D0205
8002067B01036F01016501006006025B0D03
00FF0000FF007C24057B07017902017301017201016C01035A0101520000560000630101
7000027B00048101068600068901068C01078F010593010797020B9D030EA2040EAC0A11
AD0C12AC0D15AA0F17A70714AA0813A80410A5010EA7020CA7040CA1020A9D01099C040C
8F00078E00069601079601069200059100099101089200089000099100078F00048D0005
8F000797010CA10510A60411A7040FAB0510AB0C17860F20370F1FC4C1CDE7EBEFEBECF0
ECEEF1ECEDF0F0F1F3F2F2F4F1F2F3F2F3F5F4F5F6F6F6F7FBFCFDFEFEFFFDFEFDFFFFFF
FDFEFEFDFDFEFDFEFEFDFCFEFDFDFDFBFBFAFBFCFBF8FAFAF4F6F6F6F6F7F5F5F6F2F2F5
F3F3F5F5F7F8F1F2F4EBEEEFE8ECEDE8EBEDE3E7EBE1E5E9DEE5E9DCE2E8DCE1E8DDE2E7
DAE1E5DAE0E6D9DFE3DAE0E3DADDE2DADDE2D9DDE0D7DCDFD4D9DCD3D7DBD3D1D59B6F79
891424A60615A80110A4020E9B010999000999000A9B010C9C000C9C010B9C010C9B010D
98010D97000B97010A94000893000896010A99010A9E010BA4030FAC0715B6111EC01C27
B2101AA2030E9B010A90020A7801046E00027A04097201046F04066405075600006F0307
8103067C01027201016700006307025D0E02
00FF0000FF007D25067905017601017201017201007103036302025C00016301026E0103
7801038001058200058801088C01088B000791010796020999030997010AA0050EAA0B14
AE1117B41B21B62228A7121CA20814A10311A1030F9D030E9600099100089001088D0109
8700068800069101079400069600059B00099C020A9A00099901089D00099A00069E0109
A2010AA7020CAE040FB40611B70510C10D17C3111AB31C2A58091CCBB9C8F7F5FBEDEDF2
EEF0F3F9F9FBFDFCFFFEFDFFFDFCFEFFFCFFFEFDFFFFFCFFFFFCFFFFFCFFFFFCFFFFFBFF
FFFAFFFFF9FFFFF8FFFFF8FFFFF8FFFFF6FFFFF5FFFFF5FFFFF4FFFFF4FFFFF4FFFFF2FF
FFF1FFFFF1FFFFF2FFFFF0FEFFEEFEFEE8F9FDE6F9FAE1F4EDD9ECEAD8EEEADCF2D9D0E4
D9D5E7D4D3E3D2D4E1D2D5E1D4D6E2D4D7E1D5DAE1D6DCE3D4DAE2D5DBE2D4D3DAB98D9A
8C1829AA0615AE020EAB030FA3010B9F000AA0010BA1010DA2020E9F020D9D010C9D010D
9B010D98010C96000995000895000997010A99010B9C010CA20311AA0917BA1B26BD2029
B2141EA509139B040E8F030B8003087700057C030A6C00026B0103700508670002780206
8402058101017701026B0101670602610F03
00FF0000FF007B21057905017701017400017701027700026F01026A01016E0102760105
7E01058201068401058A01088D02088C01088F020792010A92010993020B9E0713A00612
A20A14A8121DB01F2AA3111E98051197010D96010B95020C8F01098C0009890107890007
8900068F00069801079F0008A40208AD050BAD040AAE0408AE0207B4040CAF010AB5040E
B8040FBC0712C00A13C60F18C60D18CF121FD0151DC91C288C1026A96A87FFE4FAFFE3FB
FFE7FDFFE6FDFFE4F9FFE3F9FFE4F8FFDFF4FFDEF3FFD9EDFFD8E8FED4E3FCD1DFF9CFDF
F6CBDBF2C5D7ECB4C8EAADC1EDABBFECA2B6EA9AAFEA94ABEA92A7EC92AAEB8CA8EA84A2
EC85A4E8829FE8809AE87B99E77797EC80A0E47898E47799E0799DD97AA1D37BA4D184AA
D28EB0D598B6D7A3BFD6A7C3D7ADC9D1ADC6CCADC4CDB2C8D0B9CFCCBBD2D0BCD1D299AD
94172AB20918B5040FB1040EAD050EA7010AA7020BA6010CA5010CA5020FA0010C9F020D
9C000C9B000B99000999010A97010999010A9900099B000C9F010FA60514AB0B19B0131F
A90D199F051191020B8000067F040C81040D81050D750106710103720305700002810206
8801048400027A01016F0001680401600C01
00FF0000FF007A20047805007701017801017E02018102037C02027501017301017A0104
7E01048200048500048A01068D02088B01088801068B01088A01078B01098F010D930210
95031299061798081796041694021293020D91000992010A8F01088E01098E010895010B
9B010A9E0008A70208AF030AB40509BB080CC61212D11918C50C0FC70C12C10710C50A15
BF050FC10712BE050EBF0711BD0511BE0512C40A16C20D1AB10F23AC284BBF517BB64B79
BE4D7CD15787D65A86DD608AE2698CE36A89E36D87E57085E37782E48086E2878CE18E96
E29CA9E5A5B6E3A0B0E398A5E59099E98287EB7478ED6B6DED6065F15B63F15562F04D5B
F14C5AF14C58F24753EF3D4EF03C4FEF394DEC3449EA3148E42D46DC2945D42445CD2645
C42443BE2444B92849B52A4CB12B4FA92D4EAE3B59AB405FAD4A6CB1597EBC678AC85E7A
9E0B1EB30513B4010CB2020DAB010AAB010AAA0109A90109A70109A8020DA7020DA5020C
A2010CA1010C9F00099D01099B000B9B000C99010B9B000C9F020FA30412AB0B19AB0E1B
A60A179C020F91020C7B00076E02066B03087201077901067C02067601037B0103880205
8A01038500027C01027201006C0401650D04
00FF0000FF007720037606007701017A01008201008801038801028001007900007B0002
7F00048601078701058700048D030A8A01088702078603098000057F010781010A85020F
85010F8D03129707159F0C1A97041298041096030D9401099301089601089C020AA6020D
AE050FB0020DBA070FBD070EBE080DBF080CC60F0ECE1614BD0407BC0309B70107B7010A
B5000AB4010AB5000ABA010EBA010EBC030FC10612C30713C60B1BCB132ACD1A36D72442
D92342E62D4EF44160FD536EFF5A6EFE626EFE6B71FF7977FF867CFF9689FFA89DFFB8B6
FFCED5FFD7E6FFD6E6FFCEDBFFC1C5FFA19CFF877EFF776BFF695EFF5C56FF5653FF514E
FF4D49FF4E48FF4542FE3C3DFE383AFF3537FB2C30FA272DF9272FF11F28EC1B28EA1C2B
E31A28DE192BDB1A2ED7172ED0142CCB142AC31225BD1125B71029B31231AC0F2EAC0A25
B30619B6020FB4020DAF010BAC000AAB0009AB0109A90008A90108A9010BA9030BA8020C
A7010DA5000AA30109A000099D010A9D010D9D020D9B000C9E010EA20311AA0B17AF131F
AA0F1BA0051295030E7E01086100014F00005F0206740308790409790205800203880205
8901038601017F01007601016E0300680F04
00FF0000FF007722027306007901027E01008701018D01029001018D0101870102830003
8101038802068601058301048903098801088000047F0007790004780106790007760008
720008840714A81D29AF1B28A20B179C05119A020E99000B9B0108A1010AAB040DB0020C
B3030DB2010CB6040EB7040DB8030CB50106B60203BF0907C00A0BBB0309B90209B50009
B8030FB6010DB9030EBC0410C20814CC101DCD1119CE0E18D8151FE51F2AE9222CE21C27
E82430E42232E32837EB3442F23E48F8484CF5494BF75451FE625CF7615AF66763F1686C
EF6C79EF6C82EB677CEE6578EE5F6BEF5356F54E4BF64742F63F3AF93A38F83636F93333
F93231F73030F3292AF02526F02425EE2223EB1D20EA1B1FE5191EE1161CDE141ADA111A
D20F17D1111CD0111FCD0E1CCB0C1AC80A18C50A16C10916BF0817BB0718BA081AB60314
B90514B70410B70511B1020EAC000CAB010CA9010AA90009AB010BA9000BA7010AA8010C
A7010CA6000AA6010BA3020A9F00089E01089C000A9C010B9E010DA20210A40413AB0D1C
A80B1AA3081695020E85010976040B5B01035801036100026200026E01047F0206870104
8801038701027F01017801017307026A1103
00FF0000FF007828077407007D01008601028E02039102029601029801039502058B0003
8401038602068202058102078101088201087F02057C01067A00057B00067D0209790109
75020A7E0410A31D2AA6131FA00A169C04119C020E9F030FA0020BA4010AAA020AB0010B
AF0009AD0008AF0109B2010BB4010AB80309C00B0BCE1814CF1A18C30C11BF0911BB0712
BC0814B90611B80510B80511B4030EB80612BC0812BE0711C50A15C80B16C70D18C20714
C40D1BBE0918BD0A19C3111DCE1925DC222EE62833EC2C37F4353DF6393FF83C41F73F42
F84046F93F4BF73C47F3363EF7383DFA3A3BF83835FB3632FA2E2EFC2C2DFC2B2AFD2C2C
F9282AF01F23EE2023EB1F20E71C1EE31A1DE0181EDA141CD31019D11018CF0F18C80C15
C60E19BE0A17BC0916BC0915BB0713BA0713B50310B20210B20312AF010FAD010CAD010B
AF030DB1040FAF040FAA020CA6010BA6010CA7020BA6010AA9030EA9020FA8010CA6000B
A6010AA6010AA30109A1020A9F02099E01089D00079E010AA0010CA0000DA20111A20213
A003129D021196020F8F000B8B040D7503076401026602046301036901037C0205850203
8701028501027F00017801017106016C1502
00FF0000FF007829097505008101008A01019001009200019902039C01049D0306960307
8701037C01037800027B02057B01057D00067B00037C000680010785010987020A900812
950E1988051295101B96071494020D95010C96010B9B010CA1010BA50007A90007B20309
B3030AB00109BB0810B8030DB5040DB7070EB6070AB40709B0060AAC0309A70109A8020C
A4020CA2000AA4020BA3010CA0010AA0010CA5010FA8000DAD020FAF0310B30815B40716
B30716B00615AF0614B40B15BC0E1BCC1626DB1E2BE7222DF02730F62D34FB3838FB3C38
FC413CFC3C3AF93936F93833FB3A34F93933FC3A35FB322EFC2D2BF82726F82724FD2D2B
F42424F12023F22225E71A1DE3181BE1191FDB161FD91621D0111CC90E18C80F1AC30D19
BD0C16B30612B10511B20711B30611AF0510AA020EA9020FA8010EA7010DA4010BA40108
A5000AA6020DA2000C9F010B9C00099C00099D00099E000AA1020DA5020FA6000EA5020E
A3010DA2020B9A01079301069701089C02089D00079F010AA0010BA1010CA20210A30514
9D020F9A000D97010D93010A91020A8203087101037303066F02046F00027A0103810204
8001017F01027D0102790201740A016C1600
00FF0000FF007B2A0D7B08018902028F01029401019501019903039E07089B0708940307
8702057700017300037601037901037C01067C01058001088601088A020C8D020B91040D
93060F8D020D85000989020B8B01098D0008910107990008A40209AD040BB00208B60609
B6060CB2030BB80911B1060EA50109A10109A000079B0007990007960007920007920008
91010790000891000794000B95010B99010E9D010E9F010EA40310A90412AA0411B10818
B20815B50815B80B17BB0C17C00E1BC81321D61A26E7262EF22F35F6383AFB4944F84D43
F64F45F54F46F45148F65149F34D42F64D41F94E41F13A2FF7382FFC3832FB3530FB3430
F8302EFB302FF72B2CF02326E91B20E61A22E41C26E11B25D5151DCF121BCC121BC50E16
C00B13BC0A13B80913B30511B10410AE040FA8010CA6010BA6020CA5010BA2010BA1000A
A2010D9F010D9B000B9900099800089800089701079700079900099C010D9F010E9F030F
9C010C9D010C9401088900039001069801099C01089C000A9C00099D01089C000B9C010D
9B020D97010A9200079101059000078501067700017601027400027600047A00047B0103
780101790101780002730201720D026A1900
00FF0000FF008231117C09018E04039502029A02049B02049705038D05057F02017F0306
7F02067500017200027701057B01047E0107800108810108840106870108890108890007
8B01098B010A8701078701078801078C00069301069B010AA5020AAE030CB7070FB5060E
AB030CA2010B9E020998000792010791000891010A90000A8E00088A0007880006870006
8800078B00088C01089100099300079A010BA1020EA4010EA7020EB30917B00412B70613
C4111CCA141CCF181DD51A21DB1F28D81F29DF262CEF3A3CF74D4BF76057F87364F67D6D
F38879F38F85F5978FF4968EF39085F48876FB846DFC725BFB5F4FFC5449FF4E46FF4A42
FD423EFD3E3BFC3A39FC3738F92F33F62A30F3262DED2227E92226E21D22DE1C22D7171D
D11319CC0F17C60B15C00713B90510B50611B0030FAF020EAF030CAC020DA7010BA6010E
A3010E9E000D9C000C9A010998000799000797010794000693000795000A97000A98010C
98010B9801099201088E000692010898010B98000999000999000999010896010895010A
95010A9201078E01038C01028D01048B02068201047F01047B00047B01057B0104750001
7200007401017401026D0100711205681B00
00FF0000FF00893A187C0B018D0201980102A005079B04058E0504800A0BAB43457B1316
7202047401037200017401037B01047E01067F01067D01057C0004810005870108880109
89010A8901088701078701068702048D01079401089D020CA4020DA8010DA9020CA80410
9A010B93000A8D00078F010A8901088801088A00078D00088D01098A00088B00078C010A
8E0008900009940208990209A00208A8040CAF020DB70612BB0711C10A14C80F18CF121B
DB1A21E9262CF02E31F7383DF73940F73F48FD4F53FF5F60FF736EFF978BFFAF9FFFBDAF
FFD6D1FFDEE3FFE1E7FFDEE3FFD6DAFFC1BEFFADA2FF907FFF786BFF6861FF5752FF554F
FF4E4AFF4947FF4647FF4446FF3A3DFF353AFF3236FE3035FB2E33F82C31EE2429ED232B
E72028E51F29DA1621D61520CE121CC20A16C00915BC0511BE0712BA0711B3020EAD010D
A9010EA5000DA2010CA0010B9F00099D00089A010697000596010797010999010B9A010C
99010B97010895010893010994010A95010C95010B98010B98010B97010C93010B910009
9000088D00058900018A01028B01038B01048901048501058001057B0003790102770102
7400017201017202016F05017216046A1C00
00FF0000FF0094471C7810018C05019C0305A70A0B9905058101019421239A29307D0C13
6E01027B02057A01037600017A00037E01057E01047900027A00027F0105840107850109
8501098701088803098B080E96141897101695061198020F9D020FA204129E020F98000C
91010A8A00078900068E030C8901088C00089000069500079700079800079A01089E0008
A1010AA3020AA50209AB030BB1030CBB0711C70D17CC0F19D5151EDD1D24E72329EE272E
F0292FF63138F7323AF7353FF63744F63948F7414DFB4B55FC5B61FA676BFB7A79F98081
F4858FF48698F38297F17B91F07285F06674F66066F14F4DF84846F43C3CF83838FA3837
FC3939FC3638F93134F92E33F92C31FB2D32F6272CF6272CF4262CED2027E81D27E81D29
E01822DF1823D8121EDB1824D1101BCC0E1AC70A19CA0D1BCA0C19C10612BF0713B80310
B4020FB1010EAE010EAA000CA9010CA50009A000079D00069D02079D01099F020D9D010D
99010B98000896000695010990010A88020B8B020C9A05129D03149B031594011091010B
8F01098C00058701028700028B01048D01048D01048A01058301047D01027C01027C0002
780103720000700200750C037117056B1F00
00FF0000FF00429D02751B02830A019A05059F05079303037C01017D030688050B810409
7000018001048803058101037C00027F01048101048300058100038001058001057F0006
81000889040E98121DA01C28AC2D37A11F29970F1B96061595000D94000C92000A8F0009
8D01078C00078D000593010A96020A9D030BA40209AB040BB1070AB70C0FB3070BBA0A11
B70811B80913B90A14B70811B3040BBD0B14C50F18CA0F1AC70A14C60914CE1019CE0E19
D1131DCF111CD31420D41323D31625D51525DA1A29E82533EF2A37ED2C38F33943F6434A
FA4C55F84B58F54453F33C4CF43948F73943F7373BF43030F82F2EFD302DF92924F92723
FB2A27F82727F42224F21E23F82429F21E23ED191FEC1A20E6161CE2151BDC131CD7121C
D00D18CF0E1ACD0E1BC70915C20512C30815C00614C20715C10713BE0511BB030FBC0411
B80410B7020FB60210B4030FB1020CAD020BA80109A50108A40108A40108A5020DA2010D
9E000B9C01099A01099601088C010A7500037B010A960617A1091DA0091D9C081995020F
9000098C00058801048700058B01058E02059002068C02058401027E00017E0101800202
7D010376010172040179150A671501349000
00FF0000FF004FAF0A9D56287C18078F08049102028902037701017A02038A0307820205
6E00008101059202058F000387000286000290030894040A90050A8602077E01047D0106
81010A8A0311970F1E9D1627A423329C1A28950E1C9106138F010C8F010B92010A93010A
95020899020A9B0109A1020AA7020AB0050EB6080FBF0E13C31214C61919BB0D11B5070E
AD040DA50308A30108A400089F00059F0108A5010CAB020EAF040FB00310B10210B50412
B60410BA0512BD0512C60B19C70B17CB0B17D8131DE1161DEF1F27F6262CF72B2FF62F31
F83736F93A3DF6393CF7383AF73637F93635F83531F7322CFC342CFB3129FB2C22FB2B22
FA2C27FB2D29FA2A28F52222F82324F72222EE1A1BEC171AE81419E61519DE1115D50D14
D00C15C80813C70B16C30814C00713BA0310B6010DB6010CB6020DB2000AB2000AB1010B
B1010BB2010CB3010CB1000BB0010AAF030BAB0109AA010AA90109A8010AA7010CA8020F
A5010BA3010AA0020C9A010992020A7F02077C00079404159D04199D04199B0417990211
96010D9101098B0107870005840105850203890004890104870102840102830202820102
7C010177010174070176170A621500369300
00FF0000FF002EDE0B7F410E6712018309038801027F0102730000750102870405830305
6E00008302069A0307A303089F04079801059902079B040A9202078501077E01047E0107
80010C8C0313950919990E1EA82331A11B29950B1A9003108B01088D000998030E9C020B
9D0208A10209A6030AAA040CAE050DAC020BAD040DAD050CA70408A10306990104970007
9400078E01038F000394010490010493000798010A9D000AA2010CAA0210AE020EB3020E
BA040FBD040FC90B14D5131CD61018E0181EE92022F22A2AF93331F73631F53834F13C37
F2463FF3504BF35955F15855F15652F4544EF65147F64A40FB4B3FF84234F83D2DFD4234
FC4036FD3E36FD3932F9312AFC312AFD302AF62823F82624F62122F31E1FEE1C1BE51517
DE1117D30C14CF0D16CC0B17C70A16C00712BC050FBB050EB7030DB4020CB4020CB3030C
AF010AAF000AAF000AAD0109AA0007AA0007AA0109A90109A8010AA8010CA8000CAA020D
AB010DA8010CA5010BA1020B9A01099101098E00099702109E04159C02169A01149A0111
99020E93010B8D01098502077501037402037E0105850104870104870102870102860102
7F0100790100750A036B1304671B0000FF00
00FF0000FF0000FF008548156312007F0B038101007E01027501017201018506087F0305
6E0001820306A5090DB1060BB3080DAE060CA202079B03088E01058101068002067D0108
83030E88020F920616990F1CA6202A9D14209206108F010C90020C92010A98010A9C0109
9B01069D00059E0004A00105A100059D00069900079600059300048D00038A0002890003
8B00048D01058A00028F00039401069D0108A6030CAA010DB2040FBE0814BF060ECA0A12
D30F15D91217E81E22EC2024EF2527EF2A2AFA3B37F94339FC5246FC5F54FB6C62FA7B72
F58881F59994FAAFACFAB4B5FAB0B0FAA5A3FB948CFD8174FE7264FD6859FD604EFF5F4C
FF5649FF5246FE4D3DFF4C3CFF4939FF4336FF3F35FE3730FD2E2BFD2C28FB2824F6221E
ED1819E6161BDC111AD9101CD30F1ACE0D16CC0D16CA0E15C30911C00710BC040EBB0510
B5030EB2010BB1010BAD0108AA0007AA0108AA0109A9010AA8000AA8010CA8020BAA010B
AC020CAA010BA70108A300079F00079E01089C010B9A010B9C010E9C011199021097010F
94010B9001098B00088201076B00026500027701067F00048401058600028A01028C0204
8702037D0201760B0467110050580000FF00
00FF0000FF0000FF004CAD0D6A1E00790E017E03018201017E03026F0000780505750304
6500007F0304A5080BAD0207AE0308B2070EA9050B9A01078D02077E00047B02067E020A
84040E880310910A1796101C900B148C040D8B02088D01098F020B91010A930208940005
9800069D00079F0004A10005A20004A100049F00069900049600039301009701029A0204
9D02059D00059B00059D0206A50209B2040ABB050DC70B15CF0E16D9121ADE1419EB1D1F
EE1E20F52727FB2B28FD3332FE3B38FF4843FF534AFF6057FF6F66FF827CFF918FFFADAD
FFCACFFFDBE4FFE3EFFFDEECFFD9E6FFD4DEFFB7BAFF9992FE7D73FF7168FD685CFF6255
FD574BFE5749FE5243FD4E3EFF4C3EFE4338FC3A30FF3830FC2D29FE2C28FE2B26FB2420
FB2322F01D1FE8181FE41722DD151FD50F19D4101BD10F19CD0C16CB0C15C30611C20814
BE0713B90410B6030CB4030AAF0008AD000BAD000BAD010BAC010BA90009AA0109AC0008
AE0109AD0009AA0008A50007A20005A10005A101089D00089B00099B010C97010A94010B
92010A8D01088A02068601077703076E00027801047F01048400048801048D01048D0204
8A0102810201780C036D15001DCA0100FF00
00FF0000FF0000FF0000FF00914C177111007C04008803028605047102026802036A0808
5F0000800304AA0F10A90407A50005A70108A9030A9E020A8C01067701036A0104720209
7E020C82010C83020C81010B8401098600078600068700058700068800068A0006900005
9C0109A7020CAF030CB2030AB7050ABA060BB9060BB00209B10709B20A0ABA0E0DBC0C0E
BA080DB8050EB80811CC2027C11018CB1016D00F15DB141BE0141AEB1C22EE1E22F72528
F62426FC2C2CFE2D2BFD312FFE3B36FE423BFA463FFB4E4DFC5758FB5B62F86169F76D7B
F4798AF6849CF2809AF17792EE7188F16F82F9707AF96668F85855FB5653FF5954FD524B
FD4E47FF4D44FD4A3FFB4037FC3D35FE3C34FE372FFC3029FC2825FB2522F31D1AF41D1A
F21B1AEE1A1DE4161DDC111BD8101CD40F1BD10D1ACE0D19C90B16C70B17C20815C00714
C10815BD0512BB050FB6010AB6010CB4010CB4010DB4000CB5010DB6030DB6020AB80309
BD060DB7020AB1010AA70107A20005A20106A301079E01069A0006990008970008930007
9101068C01058A01048901058002057B01027F01048101048301048701038900048B0103
8B02028404027B0E066F180000FF0000FF00
00FF0000FF0000FF0000FF004FAB0D751D007F09019007048F05037D04046A0D0C7E2F2E
5C06048D0C0CA6090AA70305A50006A50107A80108A8060E9402077300025900005E0002
7402097D0209830C11860C14830209820005830105810004810004860208850004920106
A30109B2030EBB040EC0030BC7070ECF0C13D21216C3080EC20C10C50D10C81012C50D11
C0070DBD060FBF0A15B3030CBA0811C30A12C3060ED10D15D00910DA1218DB131AD80E18
DF141CF12127F11E20FA2929FC322CFF3932FD3A33FD3F3CFE4142FA393FFB3C44F73D48
F53E4CF84656F64352F43E4EF63F4CF73E49F94146FE494AFE4645FB4240FC4543FD4543
FB3D3CFD3E3BFD3C37FD3733FC342EFD322BFC2E28FE2B28FA2423F61F1DF6211EF11B19
EB1517E8161BDA0D16D00A14D10E1ACC0B1AC40815BD0815B10713AC0915AA0613B10513
B6030FB90411B6020EB70410B5020DB8030EBB0410BD040DC20712C30611C70811CD0D14
D10F16C90A13BA040DAC0108A40006A50107A100059E02059A0004990106970005950105
9301058F00038E01038B0103860004860105870104850104840104840104840003870204
8B0608820604780D026F1A0000FF0000FF00
00FF0000FF0000FF0000FF0030DE0D782402800E01950D059405018E0709822124ECA8AB
6A1315930D0FA40609A70308A60208A50007A70107AE060DA7080D8500036F0103680002
7101077B01067701037B01058101068000048300058401058401038500048A0004970106
AC040CB7040FC30812CC0A13CF0A13D10C14CE0D14BF060DB7040AB5040BB1030AAF0208
AC0008A80009AA040DA5010AAD0710B90F19B4030FBC0410C30913C2070FCF0E18C80714
CA0511E71B21F21E21F92423FE2F2AFC2E29FB2D27FD2E29FC2F29FA2827FA282AFB2D2E
FB302FFC3132FC312FFD3330FA2F2EFE3333F62828F92D30FC3436FE3A39FE3B38FE3A38
FD3534FD3433FB312FFD312EFD2F2AFB2B26FA2724F62121F62121F21C1DF62222EF1A1B
EE191CE7151AD70D13CA0811C60815BF0715B40615A3030FA7121EDB515DAE26339B040F
AD0411AF010FAF020DB1040EB2020DB7020DC00711C40912C60810CB0A12D00C13D30C12
D40F14CE0B12C10510B2020BA90109A30107A001069C0104990003990104960003950103
9502059302059201049102048D01038D02058C02038700028501038301047E00027F0102
8607088009067D180854540000FF0000FF00
00FF0000FF0000FF0000FF0000FF007F3008871D099717079A08039A080B800D12701A1E
720A0D9207099D0204A00105A30105A60106A80207B3060DB6090FA20207940207870207
7B00037F00048001038402068601068901078E01099002098F01079001079802099F010A
AC060EAC010AB6030AC70A11CB0A0FC9060FC1040EB30008A90007A301089E00089D0008
9A000795000697010995000A9500089E020DA7020EAF020EB3020DBE060EC7080FCC0B14
C9030CE61A1CF01C1CF51F1EFA2523F5211DF7231DFA231EF6211BF8221FF92323F72422
F92622FB2A25F92A23FD2D26FA2B25F72824F32123EE1D22EC2023F32928FB332FFB322E
FB302CF92E2CF92D30FA2D2FFA2C2AF52725ED1E1FE91A1DE7181CEA1A1EE91A1EEB1B1F
E9171BEA191EDD1219CB0812C20512BA0513A704119000099C0A17A00E1FB126368F000B
A1020CA7000BA9030BA90108AE000AB8030FBA010CC10710C30610CE0E16D20F15D10D10
D10D10CE0C13C30812B0020BA80209A100069D0205990104980104980004970104960104
9101048901048E02069402069301049000028C00018A01018701028201047D00037C0003
7C02037B0901771804388F0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00883F0E8C2E119E23109B0A02970404901112962C28
89110C9304039902029B0002A30204A70106AC0107B5040ABC080DB30309B1060BA9050B
9801059001068C01058F02069101079501089801099C050D98020A9701089B02099D010A
A0020AA40108AC0309BD060EC4070EC4060DC70913BD080FAA00069E00049A0005970007
9300079000089101078C00078E000798010AA00008AC0109BB050BCE0E11D6100FE31718
E41615F0201DF6221EF3201CF2221EF72923F42A22EF271FED2921E82921E52C26DE2A23
DF2C24E1302AD52721D42720DB3028D32923D02723CA2220C5221DC4231BCF2C26D6322B
D42E28CD2722C11C1BC82325C82221C62120C11A1ABF1518C51B1FCA1E21C7181ACE1A1D
D51B1FD81A1ED3171DD0161EC50E16BE0C17AB0C158700088C06109A08189A071597010B
A7060EA90209AD0209B00209B9050EBF0711BE060EBE050CBF050EC60610CD0B14D00D12
D10F12CB0B11C10912AE020BA401099D0005980003950005970106960005970106980106
8E02047900018001039201089501079101048C01028B01018801018501038000047C0204
7903037D13076D170238930000FF0000FF00
00FF0000FF0000FF0000FF0000FF00965116792403901B059E1107910301870402961D17
910D079402019801019C0001A30104A90007AF0208BC070CC0090DB90209BE070DC30B11
BB0A0EA70206980004970207990109980108980108990108950107920006950107960007
9D0107AC060EAE020BBA050DC20910C50911C80C13C30911BE0B10B90D10AB0407A10007
9A0007950007920005900004970104A20307AF080AC10F10D61D1AE3261FE72920E5281E
E83024E32F24E03226DE362ED6382FD43F33D44437C63C30C9483CC85244BF5345BD594C
C66457C6685EC26A5EC77064C77165C47066BD6C60BE6E60BC7061B97061B66D61BD7165
BE6F63B6685BB06157AE5F57A85951A5554BA250489F4943A149429E423C9C39339B322C
9D2D27A029259F221DA3201CA21B17A319199A1A1A791312CF787AA240467D0A128E080B
AF1418B30B10BC0E13BF0D13C50E16C20B11C1090EC60D12C2090FC6070FD00D16D00D13
D00E13CC0D13C00910B0030CA3000A9B0108970106960008940007920006970107990107
9103077E01037F00039202099401088F00048C01028B0101890101860101810204790103
7607037E1E0E6D1F0300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0044A203762801871A03940F058B0201850001870200
9207039601029B0102A10003A90206AD0106B40408C40D0FC2090CBE050BC3090DD11013
CC0E0FC10B0DA801049F00059C01099800089300069300079201088F0007910008990109
A5030AB90B15B80710C10C14C0090FC20A10C40B11BF070DBD060CC61316C31214B50B0E
AE0D11A50C109E0E0E9F1211A81B17B2221CBC2D26BD2F25C13A2DC44033CA4D3EC65141
C65C4CC76757C56D5CC47467C47E72C3887BC18B7EC59588C39C8EC3A393BAA090C0A99C
C2AA9DC1AAA0C6B2A5C7B4A8C4B4A7C3B3A6BEAFA1BDAEA0BAADA0B6AC9FB2A99EACA398
B0A599ACA396A69C91A1968D9D93899B90859D8F879B8A8398887E948077998076987B71
96766C926F638F685A936555945E4E9256478C51447B4E44906F6AA07A785F282473221C
8C231B9218139C1613A31412AC1615AD1010B81213C01314C20E10C90F14CE0F16CD0D13
CE0E14CA0C13C60D14B7070FA5010B9C000B99010B96010B930009940108970107970005
9301068C01058D01069502099201078E01048E00038C0103890102860101800001780101
760B03751C0967210000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0028D8067A36027F2203830B03860202870200910705
9606039B0301A10102A60103B00609AD0002B30204C91111C10809BD0409C50B0DD11011
CE0D0CCC0E0FBC070AAD0306A100059C010993010995040E96060D95030C97010A9F010B
AC040DB4050EB7070EB8070FB8080CBA0B0FB80E10B10F12AB1011AD1915AA1C15A51F18
A227219E30279E3B30A14A3EA85649AE6153B16D5EAF7466AC7C6DAB8071AA8575AA8A7E
A78E82A48E83AA988DA89A91A79D96ABA59DAFABA3B2B2A9B2B5ABB7BCB0BCC0B6C3C6BC
CCCDC5D1CFC7CDCDC4D0D1C9CDCFC6CDCEC4CBCCC3C7CAC0C3C7BEC1C5BEBEC4BDB3BBB3
ACB4ABACB4ADA9B2AC9DA5A29FAAA69AA5A1969E9D9097978B93908A918C8A8F88878C85
85888281857C84857C817F747F7A6C80786880796878756776766B747166796E60806859
8763548A5B4D88524487473A8C3F33852C218F251D9F241DA51B15AD1514B61214C01417
C51316C60F14C51017B70710B00612AA06139F010E97000C94000C96020C970108980207
9702099401089401069200059100059001039202049102048B00028801028302027A0201
78100567160133910000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00925616782C04720C007F02018B0401960702
9C0702A20402A70301A80101B20808B20406B50304C81010BF0709C0070CC50B0DCA0B0B
CC0D0CCF0F0FCC0D0FC50C0FB8090DA9050B9E090F9D0E15A41418A40E14AB0D15AD0A15
AE0911AF0A11A90B0FA10E109D1310981613941F188F29228F382E964A3D9B5B4B9E6756
9F71629E7769A081709B837497847695837994867E958D8692918894978E95998F999E97
98A0989FA39E9CA39FA4A8A7A6ABA9ADB3AEB3BBB7BCC4C0C8CECAD2D7D1D6DAD4DCDED8
E3E4DEDDDCD8DFE0DBE1E2DEE2E3DFE3E4DFDADBD7DCDFDBD9DED9D2D7D2D0D6D0C6CEC8
C5CBC5C0C6C1BFC6C0ACB3B0ABB4B2A4AEAD9DA6A599A2A1969E9E939A988D938F8A928D
868F8B848D8A838B897D848178807A798279798277768276747F73767D71777A6F7A7B6D
787A6B7574667471647971637E6F617D68588262528A5B4D90514490433A91342E952723
9A1D19A41A17A61415A40C0FB9141BB80B17B50B19A705139C000E9A000C98010A950107
9602089400079301069101059001049201049403049102038C01028801038502037A0101
771206691C001BCB0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B61678390B6810017F0602940B07990200
A10401A80503AE0604AD0403B30606BD0B0CBA0608C40F11BD070ABD050AC3090BC90B0C
CC0F0DD0100FD11011D11013CE1315C51518B01113AC1A1EAE2023AD1D20A8171B9F1418
9414148F191887221E86342C8C4B3F955F54986E6198786B967F729180728F84768C8777
8A88798D8B7E8F8C808B89818C8E868F908C92928F939493929794939C9998A29C9BA49F
9EA8A2A5AEAAA6B0ADB0B8B8B5BEBDC0C7C5CCD5D3D5DBDCE0E4E4ECEDEDF2F4F2F7F7F6
FAFAF9FBFBFAFBFBFAFEFDFDFBFAFBFBFBFBFCFCFCFAFBFBF8F9F9F6F8F8F4F6F6EDEFF0
EEEEEFECEAEAE2E2E0DADAD8D1D2D1CBCDCCBFC5C1B6BBB6B5B9B6B2B5B1AEAEA9ABABA6
A5A6A29B9F9B969D9A949A978D928F868E89848C86848C857F867F7F847D7B8078798075
747D71767C75747A73737A7271796E72786C76786B787568786F617A6B607C655C846258
87594E8A4B438639358123209B2122AE1D21B5181FB7131DAB0712A5020EA0020C960006
9300059301089001068A01038A00019101049303049001018D01038A01038301027B0400
791605378E0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009056236B17028A11069B0C05A10302
A60301AE0606B40907B40707B20502C00F0CBB0808B60407B50207BB0308C80E10CB0D0E
CC0E0FD11012CF0F12CF0F14D2151ACF1B1CBC1D1CA724239F2D2E942E2D8F3330873B35
8D534998695F9A786F917E718D85768C877B89867B8B897E8C8B7F8D8C828B8D838B8E84
8B8E838E8F878F908A8E8F8A91938E959894969996989C9C9EA4A6A4ACADADB7B5B6BEBE
C4CDCCCCD5D6D8DFE0E3E8EDE8EEF3F1F5FAF6F9FFF7F9FFF8F9FFF5F3FBF4F2FBF3EFF9
F2EDF7F0EAF3EAE6EFEBE4EFE9E3EEE5E0EAE0DAE6DED7E3DED7E1DAD4DED9D3DCD3CBD3
D5CBD3D7CAD3D7CCD1D5CCCFCBC4C6D0CDCCCDCBC7CBCAC5C9C6C3CAC6C3D1CBC8CEC5C2
CDC3C0CDC7C3C7C2BEC2BEB9BAB6B2B2AEABADABA7A9A5A0A29C999D969197938C8E8E84
898D8283887F83877F7C81797B81787B83787B8277787E73747B6F767D73767B73757870
737469756C6577645E7C5D5586544B8C423D943230992122A51B1FAD151BAB0E149F0309
9B02079302068901038601028700008D01038F01048F01028C01028900018502027C0501
7D1A061EC90000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A4672D7B2707961E0BA21004AB0A03
B20A06B60907BB0B0ABC0C0ABC0C08BD0B08B80705B00203B40105C1080CCA0D0FCD0F12
CC0F10CE1113CB1314C81619C01C1DB32421A4332C94453F8E5953936D669579728D7E74
8882758B877C8B89818A8B82848A7C8B8D838A8C828C8C828E8F858F8F8791938D92948E
979B93989C959B9F9BA0A39FA5AAA5ACB2B0B4B9BAC3C8CABFC7CAC4CBCFC5C9CFC4C8CF
C0C5CDBFC1CBB5B6BDAEADB5A5A5ADA09DA99B99A79D99A69C99A4948E99948C98948898
9688969A8C99988A969487959589969B8F9B988B958F808891838895878C9284888E7F80
9583828F7C7C8E7C7A8D7C7991827F9086818D8780918983958A869185808E807B8F807A
94847D8F827B958980978B81A0918B9F918CA59891B2A29BB2A29CB2A099B2A299AEA197
A79E92A6A1959F9C8F9B968B9794899390868C8B8086877B82877A80857C7E847E767E79
757F7772787176797376756E76726A7667607B5D5883514D853C388A2C2891211E951313
9F121593090C8902058A01048801018800018700028801018A01018601018103017C0800
791A0400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0050AD0F782704901D04A41303B41006
BE1109C5140DC2110AC3100ABE0D08C30F0DBC0C09B80908C00C0CC60E0EC60B0DC90F13
C61314BF1816B01B189F241F99393298544D966E64917D738A837985837B84857C82877C
83897D888B82888C848B8E858B8E828E8F8692938A92948B9899939B9D999DA09DA3A7A4
A2A9A4A8AEABAAB1AFA8AEAAA8ADAA9EA0A19495978E8F9288898C88878A868585878485
8784858A8687918B898B83828F87858D8382887F7D90868491868191857D90837B968680
92817A9180789B8C869A8D86988D86A19590A0938B9A8B7F9485789B8C7E98897B99887A
9A8978998877988977928273988A7B9E9385A49D8FA69D909D92839A8C7D9A8A7C8B7A6B
8D7C6A8979668879658777628A78668C796A8A77678975658D78688C75658D75648E7765
94816F9586749C8C7CA29283AA998CA8988CA39689A4998C9D968B9A958D92908C8A8B86
868A8181867B7C81797C817B797F7B75787672706D70696571605A745850744A4072312B
751B1981151485080B970A0F9303068900018301028401018601018302017F04017C0E03
6E160300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002EDC0B742B018621039D1703B71509
C21508C7160BD12017CF1C16C5120CC20F0CBC0C0BC71919BC0B0BBF0E0CBB110EAD1110
A31E1B9830299B4F479E6E64987F768D837C84867D83877E848A81878E84858C7F898E84
8B918690938C8F938990928B91938C93958E9899949598939A9B9898999794969490908E
8A8B898485848C8E8C9899948A8982918F87938C85938D84938D83989287948D80989184
9D96899992849E9687958C7E9B9383988D7F9A907F9B8F7F93887590846F8F836C978973
968871978A758C826F9388759D907F998D7E958977968973988B76978B76998D789C907A
998C769A8D77978E779B907CA29585A198879D968499917E9B907B9587718F7E678C7A63
8B7A608A7A5D8B7A5E8A775C8C7B608E7B628C785F8D785F8C775E8D765C8B73588A7056
8C7259896E578B715A8B725C8E74609077658E7A6A9584759A887CA19288A1948CA0948A
9B93859590808E8C8085877D7E817B797B7975787675767373736E6C6D666A6760695A54
694A4367322D6F1C198B1716960F0E8B03048100018001018101017F01017E06017C1407
34870100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007E3C05772200982108B2190A
C82214C3160CC6180FC81611C6130CC1100CB80E0DBA1B1AAD120FAA1B149A261B913C30
8F584C9071678B7B7289837C858882818A827E8980848D858A958B8D978D8E978A8D948B
91978E90948E90938A8C8E87898A8583857F80817C7D7C777E7B7687817A8E8A808E8A7F
93908599958D9A988FA29E959894879B9587999281968D7C9C94819C94829A937F9B9381
948D7A918A7698927D978F7EA29B889E9885A19A889E938499917F98907B98907B988D77
988D77908670989179A1957F9C907D988B7B958675948671968A77998D7C9A907E9D9581
9F9883A09884A199859F9684A29888A39C8B9F988698907C9B8F789080678E7B638F7C64
8D7B60917F62927E618F7B5F8B795D8B7A5F88755B8A785E8C7A5F8A775A897458897258
8A71588B70588A70568E74598C7156927960A08C77A392819789789081718D7C6D8D7C6B
8F7E6C988877998F7D948E7E918D8187867D81817B7B7C7677787373746F6C6D6A686865
62615B60544D62423A6B2E25791B1487120E8506067E00017C00017B02017D0C02751507
2E850000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009A59187A2E04871F03A91D0E
C6291DBC1D13C3251DC11A14C1140DBC140EA7120D9F261F8C281C9247378D6151806B5E
78736880807A85878083857F878D86838C848A958B909B918E9B918F99908E958D888B86
8588827F807977776A78766A8582778B887D929084959083968F81988F8098928096917D
9693829B9788949083949183908D7E979181999581928C7899927F98907E99927F9B9281
9B938298927C96907A99917E9B94819892809E97869C9284A19786A097859C94819C937F
9C937E978E7A99917C998F7D9C927F9C917E998B789D907DA39985A096849E97849C9783
9D97849E9785A09887A099889F998AA39D8EA0998999917F948973918067907C648F7B63
89785D897A5E8B7B60897B5F8A7B60887A6085785E8479628276607D725B7F715A7D6F59
7D6E5980705A86735C89785D90806297866D9A8A76978A77958976978A7695857191816B
8B7B6387775F85755E8576628B7C6B95897A91877B8E887C8A867C7D7B737575706F716D
666B6561645D615D55614F46623A2F6A22197B16137F07087E03017C0500801406671204
29860000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029D808803B077F2708A93729
A91F18B32523E86D6CAE1916B71A11A71B128C261B985B4E8663547A6B5A727162707569
797E76848681868882888B84898E878A90898F948D8A8F87858C827E82767C7D727F7E73
8381758A86788C88748C867397907F9189799B938498928097917E958F7D9A9581958F7B
928D79928D7B958F808F89798E8B7A98928194927D9994809D96839A92809A927F9C9383
97907F958F7B96917B9C9481A095849D9583A19B899F97879D95849C9281A29886A19886
9E9784A19C8AA49E8DA49D8DA39C8CA49D8AA69D8B9E96839E9783A19A889D98869C9986
9F9A88A39C8C9E97889F998C9D9B8D9F9C8E9F9C8D9A9585968E7C8C7F6B8A7C67887A64
847962847D65827F6683816A85826E84806F817E6E83837483847786877A8E8E80908F81
959285908C7C938F7C98927D97917A968E78988E7B988B78978B77998B769B8D78998B75
978A7096886D93836A8A796187755F84725D8575618B7D6B8F8574928A7B8B87797E7D72
74766E6A6D6662635E5E5D585B52495C43375E281F6F1712810F0A7E0B027E1B0E560B01
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A6692F793717D18076
992B27A52324E06367A5201BA3281B933D2E875A4A7565586E6B5F6C70636F7969757C70
82867C8B8C848C8E86888A8384867D83827B7F7D747C796E8280708A8876948F7D96917E
9D98859A938098937E99937D9A94809C94839A93819A9380958F7A94917D99958198917E
968E7B98917F9A9382968F7D958F7C9994819995829A94819B94819E95849E96859E9885
9995819996819E9A86A19A889C95839C96859F9B889E99879F99899D95849D9584A79E8E
A09A89A09B8C9D9B8A9E9A8B9C998A9C9989A39F8FA19E8EA39F8EADA797A5A1919C9A89
9F9B8E9C988B9B988B9B988D9A9A8F97998B999C8E98998C98988B979587949584979987
949787999F8FA5AE9EA7B0A29CA499979D968E989186938E7C89857D8A877F8A877C8481
808782858A81888C818A8B7E8C8A7B928D7B948D7A9C917EA0947E9F917BA0907B9E927A
9C90789D91789B8D779687719989719180678C7B638B7B648D7E69857763897D6B8B8171
8C87797D7D726F6F686667605D5D5657524853423657291E68170C751709651204500C02
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0066CB2F91603EB1746B
A74945AC2B27A526209B32258F4C3B80614F726958706E626F736671786A767F6F7F8376
85877A86867B8180747D7B6F7C7669867E6F948B7A938B79928D7894917A95917C97907D
97917E9A93809B948198907C9B948196907D99947F98917B96907C9A94819A95829B9481
99917F9B948297907E968F7C98907D9B93839F9A8799927F9A93809A93829B95829A9583
9795819A98869A98859B97869896839694829696839795859E9A8BA09C8C9E998CA09A8D
9B978A9D9C8E9B9C8E99998A9E9E919D9F929A9C8E9A9B8EA5A398A9A79CA9A89DAAAA9F
ACACA2AFAFA5AFB1A7ADB0A8ACB0A8A8B0A7A7AFA7A7AFA7A6AEA9A0AAA597A39C9AA69D
98A39B99A49C98A39A98A19791998F848D837F89807B847D77817C727F7D737F7F798584
7C88867A868477837E80888085867B8F8B7C928A789C907E9D917C9F917B9F907A9B8F78
9C917A9E937C9D907A9E917C9C8E789989729A8B739585708F7F6A9889739384707D715F
827968857F6E8A8577827D716D6B605F5D53575247554335552A195F1E0D500E00268601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C6966D7C4030
9033299E2A1F9837278C53437862506D6A5A6A6C5E7072627379687B81707E8472808172
807C6D807869827D6A8F8876948A789387738C7F6B9B907C96907B96927B908C76948D7A
99927F97907F9992809A9280968F7C97917E96927D97917E96907E9D96859B96869B9787
9D99889D98889E9A889E9988A09A8AA29D909E9B8CA49F91A39F8FA39E91A6A092A39F91
A09F909E9F91A3A294A6A6979E9F8FA2A395A4A798A5A79CA4A59BA6A89FADB0A7AFB2A9
B5B9AEB4B8ADB4BAB0B5B9B0B3B8AFAEB5ACAAB2A7B0B7ACAFB4ACB0B4AEB0B6AFB3B9B2
B8BEB8B6BDB7B5BBB7A5ADA9A3ACAA9FA9A898A4A195A09E8794937D8C8B778580758179
7E8780868D84898D818E8F818C8C7D8081707A7969777263706E5F696A5D68685F64645D
5F645F5B65625F6E686F7B75797E778382778F8878968B7A9C907C9E917CA1937C9F927B
9F937EA0927E9D907B9A8D77948770998C76A0917BA3937D978871988B75938876827969
746D5D6B6656726D5D807A6A827C6B777262655F50574F3F513E2B572F1C460E01248601
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8BF59804527
782A18914433875645705A4C6B66556C6D60707363787C6A7C806C7F816F7B7967827C69
8A816C8E836C938871968B77978D79998E79998D78978C7A98907B908A71928D7499927F
9C95839893839C9888A09A8BA6A090A8A192A7A495A7A294AAA597A39F92A19E91A19E92
A2A0939D9C8FA5A4989E9C959999909F9F98A2A49CA3A39CA9A79FB4B1ABBAB5AFB3AFA9
A3A39C9899939B9F969D9F9793978E8F938C919590929995909895919E9992A19C9BA7A3
AFB9B3B9C1BCB5BFBAB3BABAB1B9B8AEB7B3AAB5ADAAB2ACAEB6B2A8B1ADA7B0AAA6B0A9
A1ABA5909A968189857C82817D8482727B7967726D5D69625A67605D69616B776B7E887C
8E9488A8AAA0BBBBB1CBCAC0CBC9BFBBB8ADA8A294958E7C847C688B7F6B82705D7A6754
695B49544E3F4D4F42575E566870697A7D728782749187769C917E9E927DA1927C9C8D77
9D8F7A9C8F7A9C8F79968971998C739A8E759C90789D8F78998C75958B77979080817E70
6A6A5D5D60544D5245535444736D5B887E697D735F685E4E584B3B5A402C451606248701
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003AEB1DB07D51
6C3E237F5D486E5B496D6252736C5C7774647A7A677E7D69797864726F5E76725E918874
958A7292856C988C75988D79978F7A958D799A927E968D7A9F9582A39A86A39D88A19B89
9D99889B988A9A988C99968A9C988D9D988E9A988DA5A196A4A095A5A195A6A497AAA79C
A9A69AAAA89CAEADA6B2B1ACB0B0ABB3B2AEB8B8B5BBBBB9D2D0D1E5E1E4E7E0E5DAD5D8
BFBEBEAFB1AFA0A6A4969D9D8C93938893918D9999919D9F8F9E9F8D9F9F96AAA98FA09F
92A09D949D9C96A09E989FA09CA3A29EA6A3A2AAA4979D98949996929893969D95A1A79F
A4ACA4A4ACA4A8AEA8AFB5B0BAC0BBBCC4BDC3CCC6C6CDC8CCD2CCCFD5CEC2CAC2C2C9C3
D6D8D6EFEEF1F4F2F7F5F2F8ECE7ECDAD4D3BBB1A89C8E7F9A8974A78F76A284689B7A5C
8E7153816A4E6F61495953425453486A685C888270918674958A749F937C9E90779D8F77
9E8F799E90799C90799D927B9B90799B90779E947B9C917B978C769289768E897C76766C
646961444E443A453B3E46394D4C3B6D644E8879628577636E604C59442F4E281600FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C99D68
755A386C5C42695E47766A577F7462827966827C6478735E6964526864557A7866908976
938975988C76988D77978D79938B76A199869A948198927F968F7D98907F989281979382
989385999287A29B939F9A919F9B91A7A29BA4A198A39F94ACA59AA7A095A6A293A8A295
A49F92A49F92A5A094A09B92A49F95AAA29AAFA8A2B0A9A5B8B1AFC3BABBC1B8BDB6AFB5
ACABAE989A9D8A9396848F957D89907584896E808469797E6778796373745C6D6C657571
7D8A83939F989FA7A1A6ACA7B0B5B0B4B9B5B7BDB8C3C7C2CFD1CED4D7D5DEE0E0EBEEEC
EBEEEDE6EAEAE4E8EBE1E5EADADEE1CCCFD2B2B2B6A5A2A5969093888280736F6B736E6A
7B73738C8287948990978B9294868892827B8D7A698D775F8F75599070518F6E4B8E6C48
8A69438768438368457C65496E5E4660553C75684F9182699C8D75A597809F937A9E927B
9C8F789C8F79998D799B907C998E7A988E79978C77958A75958A77938D7C88867D6A6C69
4A555039483E3C4A3D414D3F474B3C54513D6D664C82765C83735A68553B5D3E2400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007D9D33
6E57306C5D3C786A4D81725A83775F7A6F5A665F496A6451696755666557787868878272
8E8674958A769C947E928B768E8971948E7A97927E999582938C7B958A7A948B7A97907D
9A918096887B9C91849E94889D9789A19E919E9B8D9D95889E96879E95889E98869C9685
9B95849994829994829992819A91819B8F81999080988E839A9087958B83938C85898484
7B7E8161696D5A676E5062694D5C6348595B4E5F5D4F5C5966706C79817C8F9791A6AEA7
BDC6BED0D7D1DBE1DFDFE4E4E5EAEAEBEDF2E9E9F1E7E7EEE2E0E8D8D3DCC7C2CBB8B3B9
ABA5AA9D979B938D928882867E76787B6F6D7D6D677C685F7E685C836C5C84705B8A7760
907F6892806D9B8879A08F80A18F7FA18F79A18E74A08F6E9E8A689B8664967E5D8F7756
8E735095754E98764D93724B8B6E48876E4879633F8C7657A5947BA3967F9E927B9E927E
A0937F9A8D799A8E7B9F97829E937E978B769487749B907F9791828C8A816A6D6B4C5654
404E484352464755454A55454D53455355466C6D587D775E84755A826E4F6A4C2D00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6025
755A3179684584755384765A6B6248504A354F4C385A594763655565675B7A7B6E888576
8A8371978C7998917B8D88728E8C759B96828D8875807A68978F7C9C8E7B9385708F816D
91836C8F7F6993836E918572938B7896917F9590809B938498917F968F7F97917E96907D
9A94809993819994819B93819B93809C95829A927F9A928099917F958E7C888778767871
5A61604551513748483445433F4D48545F5762695E83867A98978CABAAA3C2C1BBD2D0CE
DAD8DADBD9DECECAD2BDBAC2ADA9B1948C94837881776A717B6C6E7F6E6E7F6D68836F65
8C77688E7868957F6D947D68987F69997E63977959987955987852947854917A5A988666
9B8C6C99896B9E8D72A09177A2947C9D90799F947C9F957F9D947D99917D908A77807968
7A6F5C856F509B794F9F794C9D794B9978488E6F457F6443A8947AA59680A1937DA4957E
A1917E9D8D799C8D788E81688B7C628E7D65887866877C6F8C8A83686E6C4C5758475552
46544C4B584B4E5B4C50594B535A4B596253737B6B9394817D72588F7A5B7B5B3800FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002BDE0C7D551C
81643D897551887A586C61444D4A2E4A4A33484A364B4D3D55584A5B5E5374756B818073
86816F958B799C917E8C8571928E7998927F8B8572938A7691856F84755E8E7F669F8F78
8F816790806794846E998B78978D789089758D8774908776938C79908876958B78978B77
958974928873958B77988B779A917B9C927F998F7C9D9480948C79938C7B858677686E64
535953404742444E43545B4E646959979989837F6F92867791837484776C7D70667E706A
7D6F6E7C6F6F7D6F6E80726C81716B87756C8D7A6E8E7B6A957F699B8066A185659E825E
9F8461A99072A99074AA9072AC9370A98F66A284569D7C4C9E7F51836C4882765F877F6D
8D8571918872958C779A9581ABA695B1AB9B9B96889190858C8B8282847B787B7270746A
6D6C5E7261459C7A4F9F7644A37B479F7845967344876944A18A7097856E98856D947F67
927D658C775D867257816C517D6A4C796A50756A5877756B6268644B59594857544B5851
4F5A50505C50525F525662545C6759616D5F737F7393998B95927D8774578C6A4100FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004BB310835F2B
8C6E488C785673694A5550354B4C314B4D364D4F3A4E4F3D4B4E3D5052466263597F7F75
8A877A8D84729C917F988E7C9993809D96849189759E937D958B738A7C639080669A8A71
9A8C7294846B8B7A638C7A6390806792856B968970988B7395897194876C96846999866B
99856B98856A98866B98856B99886F9D8F7A9F917D9F917D998C78988E7C8A85736D6D5C
5B5A4A6360526F6B59746F5B7B755E887D66817158826C538870548D7458977F629D856B
95836B8D7F6B948573AB9D8BC5B7A7CABCADB2A39192846B8A7A5D9A8361A289639A855F
8E81627E76627F7766867C68968971A99776A58B6098794A9C7E51816F4E69665671746B
76766B7F7E7286867A949288AEABA2BEB9B09B998F8F8E8786857D7C7C72787A6D6D6E5D
6660487C6743A68453A27A44A97F4AA37A45997342987B549C8467927B618E775A897154
877151826E4E7F6E4E7F6F537F725A7F7967707366555F584C5A554C5C544E5C53535E53
5861565961565763565B675A6570636E7A6F7480768D968BB1B0A1816F5494704400FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047B110916E3D
9477518471526E684F53523E4A4D364A4E374D503D4F51414F50415153455355495D5E57
7979708683778A85759C958496907D948D7B9C94809D937EA59A858E816B95856D9C8C72
9B8D72988A70847157978167A38D73AA977CA1927395876B95866A958564948361958161
9681619881629781619781629984699A88719989729D8C769F8E799E8E78988B73766D54
7E73598274597D6E4F7F6D4C8874519B8361A48C66A28963AB8E67AF8F6AB0926DAA8F6A
968160908168A19581AFA391BCAFA1B6ABA0A19689998F7B94896E96886C938669928B6F
91927D6D7468787F7593978A736F5F796A50AB916B9B7A4C99784A96805B544F3A696D63
84867D807F738783778E887DA0998FA49D919993868E877B81796B6E6A5A62614E66624B
8576569A7F53A3814DA37B46A77F4AA07B489D7E51947E5A8976598B785E8C795E917F64
96886C9B9076948D75898573858378666B6257615A52615B526257536153535F52596656
5D685A60695E606B616772676A746A757F77737E768D948DACA99B836F5498724200FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3742C987441
93775283755A7C7B695156474C52404E54424F54444F544550534555594B54594B515449
5659526F716A7E7F748685788F8C7B97907F938B779D9581A69A889D918090846E94876D
97896E9D8E769C8C728C7A609B8971998A71A5997DA2967D9C8F77988B6F998D6E9A8E6F
9C8D709D8B719D8C6F9B886A9B896D9B8A739A8A719B8B729D8E74A1917A9D8E74847356
8E7855896F468D70429C7F51B5996EB6966EB59770AD9069AD9069AC8D6CAB8D6CAD9170
AA9273A590789E8F7B9E92829E94839A938298917F9B957F99947C9490798F8C76949581
A5A8989EA3979DA29698978B746B5A847054AD9269AE8C5E987442A2845A78684C5D5647
736E60786C5A8776608D7F68968E79B2AB99A29E8E8C8779837D707771637E7B68857C62
8E7A569B7E509D7D499B79479C7D4FA88E66AE9C7DA89B81A69A84ABA08DAFA696AEA798
A29E8E9391838384786D71686067625C65605D69625C695F5E6B5C5F6A5A5E695A5F6D5D
626F61646F6468746B6A776D717C7376817979847E8E928B9A93848E76569F753C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004FB8169D7844
917753857C657F817462695C545A4D515749535C4B50584752594A555C4E565E4E555B4D
545A4E5A5E57686C648788819293889491838C87769B95829F9786A9A292A8A38F9D967F
988D77988D799F9581A99F8B9E937E988F7BA39B87ACA593ADA593A39A88A7A18CA69F8A
A49E89A39A86A29682A1947E9E927A9B907C9B917C9D937A9B93799F957E998E76857254
8B6F4891703FA3824EBB9D6DAF956BAB8F68B2926CAC8C66A88962A48866A088689E8568
A186699E866F8C80708F8A7E88887BA6A897A1A191A9A998BEBEADC1C1B1C0C0B0B5B3A4
A09D8E91918280807079725E8D7A609C825EAA8C5FAC89589F7944A581519F845F89775D
968771A59178AC9378B5A289D7CBBCFDF8F3DFDDDA928F8A7169606A6051746951897858
947B54967C519B8255A68F68B6A586B4A891B2A998AFA89AAFA99EA8A59D98989194958E
86898071766C646B5F626960636964636B64626C64616A61656E626971656B7569657368
63716768766D6E7B746E7A75727E797B857F878D8795928A897B6795774D7C9A2900FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051B9169B7741
8D7853827B657E7F746E7369596055585E51555C4D51594A565F50555E4F535B4D595F52
585F52585F535A615963656074756F8D8D859595899493859A97879B98899895859C9586
A39C8CA59F91A8A393AAA494A09A88A9A291A6A090A49D8F9E97879D94869992829A9382
989180A1988A9990829C93839B947F99907F98917E97917B97927C99917E9E9683AFA08A
A68F6FA1835AB4986DAB916AA68F69A58D67A98B66BB9670B7926B9F8362978265937D63
9F8368A58A727368597E7C74868882A9ADA4B5B9AFAEB0A7BBBBB4B5B5AFAFADA79B978D
817B6E7671607B745D827356967D59A4875DA78859A78552A47D49A47F4DA384589A825C
947F5E9B8264AB8F72A68E79A9968DB6A9A99A908E897E738877658B785E927E5F9F8868
A89272AD9B7BBAAE92B6AC96ACA697ADA89DABA99EA2A199A6A6A18B8C887C807C6F736F
676C65666D636A73666A7167686E676E756E6C766E6C766E6D766E6E766E6D787068776F
6879716A7A746F7D79717C7A7B8482858A858D8D858A7F718E76599C763F2ADD0C00FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BF1A9E7840
A18C67877F6A7E807270766A626A605F665B5A6156575D53596256505A4D555F515C6357
5A62555A65565B67595E635A63645E66676273756E898B82A19F97ABA89FA9A59CA39E94
979388919084918E81969284989584A09B8DA39F8FA39D8EA9A393ADA596A7A190A6A08F
B1AA99B0A69BABA195A89E90A59D8AA39B8A9D9886A29E8C9B96849A93829891809F9685
94826C8D7254967B579E845FA28B66A08965A78B68C19A77BE9776967D618F7E65937C67
9B7E67B0917A9A86768C817AC2BEBBD2D1D1C6C7C4C8C7C5C5C0C0BBB3B4AFA5A392887D
8A7F6A88785D917B599C8057A18256B19469B3986EAA8E62A68659A28356A3885BA48D62
A089639B82619C83649B856A9785719786779A89769B896F9A846AA59277B5A38AB8A993
BEB19EB1A999B0AC9EABA9A0A3A39D9C9C9794958E888C84767B7570736D70746E6D726C
6F766D6F776C767E737980767F857D79827A737F786F7D756D7B74717D766F7D76677A73
6C7F7A72817D7984807F8683888A868A8A81857D7085735B98774B56BF2000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A1773B
9C845E9187707A7C6C73796B697267646E655C655A5F655D5A6357545F535761555D655A
5D685A606C5B636D5D676D626568606668626669636669646E6E697D7B788C8A869E9D96
A3A39BA2A197A5A397A19E91A19E909E9A8D9894889994869B96869A95859F9A899F9B8B
A6A090ADA598ADA498ADA499B2AB9DAEA99CAFAD9FB9B7A9B7B2A5B4ACA0BAB3A5B1A999
A699849681648F7853957D549781589C865FA08663B08F6FAE90728F7B628A7A628E7A65
947B649A7E679D8571978679C0B5AEBBB3B0A09893958B858E807A8C7A718B7667907B63
927C5C96805A987C539B7F53A0875DAA946FA89574A99677AB9677AE9A79B0A07CAD9E7C
AB9D7EB1A386AEA086AFA289B0A58CB9AB94B3A48CB4A58BA89A82B1A593B2A99BB6AEA4
ADA79EABA79FA3A29C9899958A908A7E847F7E837F787D78747B73797F777B7F777B8077
7A8176838B7F878E84898E87868C8478827B737F7A76847F71807B71807A75857D71837C
6F817D7787837F89858589838989808B857785745D94764E7F9E3300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051BA1A
947647AA9C807C786571736570796B6C766B636F65636E655E6A5F5E6A5F5B665C5F6860
626C60656F626870646C7369686E64676A62676D63686F66686D64696B64696B646E7169
797A7489888298958E9E9B929F9E93A7A39BABA69EA4A1979D9D8DA0A08E9E9D8A989584
9994849D95889D96899B9589979385908D7F9390829690839C9486988D819A90829A9180
989078968C6F998C6A9C8C6695835C98855F9884609781619A866893836884765C8A775E
917C61957D6297836897866D9E8E7A9E8F7DA2927EA79680A89780AA977FB19B82B7A384
B8A582BCAB89C2B190BEAF8FBEB092C3B99EB7AD97B2A994B4AA96B8AF9BB8B09DB6B09C
B4AD9AB8B1A1B3AB9CB2AB9BAEA593BDAF9FBAAA9AB9AB9AB8AA9DB5ACA2ACA69EA6A19C
9E9A9693908B8A8A86878984858A8480857F82858381848283888281877E80857C868B83
848B818E968C8C938D858B88828B8876827E74807B7884817884817C87827D89827A8882
7E8B8884908B8890898B8D85807A6D87775F96754E79982D00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9F75389A7F5B8C7F686F6D5C727668787D72717B736A756D626E66646F66616D64626E65
6672686772676973696E766E6D766C6E736A6E74676F776A6E7669696F636D70646D7065
6C70676F716B76777175766F7C7D75817E79938F8B999892999C91A0A297A5A69AA8A699
A9A799A9A499A9A498A7A296A7A396AAA697AAA797AAA595A59D8DACA292A79D8CA39C88
A7A289A5A086ABA58BAEA58EB2A68DB0A389B6AA8EB9AB91BDB095BCB397BCB598BBAF93
C3B698CBBCA0C7BB9FCBBFA4D4C8AFD8CCB5D8CDB5D9CEB4D7CCB3CDC1AAC5B8A1C6BAA3
C4BAA3C7BEA9C3BBA7C3BEAAC4C1ACBFBCA9B9B6A6BCB9A9BBB8A9BFBCB0B9B7ADB8B7AB
B6B5A9BBB8AEBCB6AEB9B1A7C3B6AAC8B6AABFACA3B7A59DA699929F96909A948F938F8A
98959195959192938E8F918C8D918B9295909192908F918F8F948E8A9089888E87898F88
888F8889938D86908E828D8D808D8B7A89857C8B857F8D86828D89858D8989908B87918C
8B93908D928F94958E8C857788745B95714786A33700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
2CDF0F99713A987F5B887D687B79697E7F747E847D777F7B707B756C767063716966736C
63716868736B69766C6F7A726F7A706D7568707768787F72787F71767C70777B6D74786A
72786D72766F70766E75766F73756D74756F7979747577727C817B83878291938F91928C
9FA097A5A6A0ABABA5B1AFAAB3B1A9B8B8AFB5B7ADB6B7ADB7B7ACBAB7ABB5B1A3A5A190
B6B3A2B4B2A0B5B2A3B6B1A5B7B2A5BBB6A5C2BDABC3BDABC3BFACCAC6B2CAC6B0CCC8B2
D2CFB9D9D2BFE1DBC9E1DCCBE4DFCFE3DECFEAE5D6E8E3D5E4E1D1E1DECFDAD5C7D7D2C4
D5D2C4D8D6CAD1CFC3CACABCCDCEBFCCCEC0C8C8BDCACBC1C5C7BEC2C4BEBFC1BCBCBDB8
BBBDB6B3B4AEB3B1ABB2ABA2B8ABA2B8A89EAF9F97A69993A49B95A29C979C97929B9792
A3A39D9C9E98969A959DA09D9B9F9B939795969997959A978A928C8E97918E98918E9690
88918B87928D86949182918F82918F83948F84948D7F8F8784908B8C958E8D948D929790
93959094918A8E82728E7756A1794729DD1000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDF0F9B753B957C579A8D77908E8085898080878279837E75807B6C79726B7770
6B776E6D77726D7871707B74707D73737F71737B6C7D8377787E727E8176808378818478
84887E7C817A72786E73776F72796F7579727478717279726F7771737A76747876787975
7B7D797B7F7E7D8183828787888D8B8D94939BA2A1A6ACACAEB4B2B0B5B0B7BAB3B3B6AD
B4B6ADB5B9AFC0C1BBB9BAB3B8BAAFC0C2B4C3C6B8CDCFC2C8CBBED3D5C6D2D5C5D9DACC
DFE0D4E2E0D7EDECE3F4F2EBF8F6EFFAFAF3FAF9F4FBFAF5F6F6F0F0F1E9EDEDE6E8E9E2
E5E6DFE3E5DFE1E3DDE3E6DFDDE2D9D5DCD4CAD2CCC6CDCAC1C9C6C7CECDBCC1C2C2C6C6
B0B3B2B8B9B7BABAB5BCBAB2C3BCB3BCB3ACB7AFA9B9B6AEB7B4AFB5B3AEB1B0AAA9A9A3
AFB1ABA5A7A4A3A7A6A0A6A59FA6A59BA0A0979C9B99A09D939D99929D99939D9B919B99
8A94928894908C98948B99958B99948F9C98909C988A989386918D929792979A9396968F
958C808B796192734982A33700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE2107294289A7F57A498819898898B8F85888E87848D877C878078847C
77837A707975737D7979868076847B79857B717C707A81787F847C7E847C81877F878E85
8C91898E938D797E76767B74787E76747B73737D737682787580787C868178817E7E827F
7B817E767F7E7680817B85887783857C87898491928591938793948E999A95A29E98A3A0
9EA8A4ABB4B0ADB4B1B1BAB7BBC4BBCCD4C9CFD8CFD0D9D2D8E2D8DEE6DCEAF0E7F2F4EF
F7F9F4FCFCF9FEFEFCFEFEFDFEFEFCFEFEFEFEFEFEFEFEFEFEFEFDFEFEFDFEFEFCFEFEFC
FDFFFDF5F7F6F0F1F0EAEDEBDEE3E1D9E2DFD7E3E0D4DFDED8E2E2D2DCDEC4CDCFCDD4D5
CACECDC6C9C8D2D4D1D2D2CDCDCBC5CAC8C3CAC9C4C3C5C0C4C8C3BEC2BDB8BCB9B4B8B5
B4B7B5AAAEACA6ACABA6AFAF9CA6A59BA4A3A0A7A69CA4A2959F9D939E9E949F9F95A09F
8E9A998E9A97929E99929C99939E9B929C99919A978D948E8E938D97958E978F838F7C67
9476527A9C362DE11300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0050BC1E9B7C4DA59377A0988792908691948C8A938A848E86
838F85818B857E89867C8B867A8982808C8577817A7C837F7E85827F8883818B8587918A
89928A8C928C898F8885898380857F7A817A818C837D88808A958E929C98828C89878D8B
7A83817A83837C86877B86898693948B999A8B99998795968797968D9B9C91A09F99A5A6
9FAAA9A8B1B1B0BAB9B5C1BFC0CEC8C5D0CDCAD4D1D7E1DFE1EAE7E3EBE8EBF0EFFBFDFC
FDFEFDFEFEFEFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFEFEFDFDFEFDFDFEFDFDFDFDFEFEFD
FEFEFEFCFDFDFBFBFCF5F8F8EAEFF0E3EAEAE3ECEBDCE6E5E4EEEEDCE4E5D0D9DAD7E1E1
D2DAD9CFD6D5D6DBDBD8DADAC7C8C6CDCECBD1D2D1C9CDCBC1C6C4C0C6C5BAC2C1B5BCBC
B4BABAAAB2B1A1ABAAA5AFAE9FA9A7A2ACAA9FA9A79FA9A89FAAAA96A1A299A5A598A4A3
9AA5A395A09D99A19F979D9C9097959095928B8C868C877C8A816E88765B92744D7C9D38
2EE21400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002EE213799C359B7D55A6947AA299889A988B909488
8B958A8B948D727D757E8B8488948E87928E828E8A828B897D8786848E8B89948E8B9691
88938E8E98938C95908D938E939994949A95939C968D9794939E9B9CA5A49099989EA6A3
98A19F7D88877D898A8490908F9C9A919D9C939F9D94A1A094A1A098A5A49AA5A5A8B0B1
B0B8B7B7BEC0C6CFD0BECBCAC6D3D2D0DAD9D7DFDFDBE2E4E3E9E9E7ECECF3F7F8FCFDFF
FEFEFEFEFEFEFDFDFDFDFDFEFDFDFEFEFEFEFDFDFDFDFDFDFDFEFDFDFDFDFDFDFEFDFDFE
FEFEFEFEFEFEFAFBFAF2F4F4EFF4F4E8EEEEEEF4F4E2E8E8E1E7E7E0E5E6DAE0E2D6DDDF
DBE2E3D8DFE0D9DDDFDDE0E1D7DAD8D2D5D3D5D7D7CFD2D1BFC3C2C2C6C7B9C0C1B6BDBE
B8BFC0B2B9B9AEB5B5ACB5B4A8B1B0A9B1AFA6AFAEA3ADADA5AFB09BA6A7A0ABAB9CA6A5
9FA6A59A9E9E939395918F8E89867F8C847886776189724F95764452BF2500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF002DE113799A3498774F9C886A9E957F
9B9A8A98998D878B808A92888F98918F9793909A988F9A9888949189939286918C919B99
8F9B988F9B9A909B9A8C9695949C9A9AA29F98A19F9AA3A39EA8A7A0A9A98F9A9A949D9C
A1ABA787948F82928D8E9D9997A7A2A6B1AFA3AEABB4BEBDB7C3BFB6C0BFB5BEBEC5CDCC
B5BCBCC2C7CAD1D8DAD4DBDED8E1E3D9E1E0DBE1E1E5E9ECE4E9EAECF0F1ECF0F1FAFBFD
FFFFFEFDFDFDFEFEFEFDFDFEFDFDFEFDFDFDFDFDFEFDFDFEFDFDFEFDFDFEFDFDFEFDFDFE
FEFEFEFCFCFCF0F0F1F3F4F5F1F3F5EAEFEFE9EEEEE8EEEEE3EAEAEAEFF0DDE2E4DCE3E5
E4E9EBDEE2E4DCE0E2D5DADAD9DEDECCD1D1CACFCFC9CECFC4C9C8C5C9CBC0C5C7B4BBBB
B5BBBCBABFC0B5BABAB3B9B8B0B5B6AAAFB1AAAFB0A9B1B2A9B2B39EA7A89EA6A79A9FA1
9797978F8A858C7F788D79698D73589A78507C9F392CE11300FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050BC239E7B4C
947C589D8B71A094809B95869C9A909A9B96999D9A929995949C99969E9E949C9B919A9A
949F9D97A4A3899797808B8C949F9E96A1A19BA6A4A0ABABA5AFAE9FA9A97B87867D8889
A1ADAAA2AFAA92A19A929F9B9DAAA6ABB6B4B9C2C3C5CFD0C8D3D2C5CECECFD7D8D7DFE0
CAD1D1D7DBDEDEE3E5D4D8DCD4DADDDEE4E4E1E7E7E7EBEEE8ECEDE7E9EBF1F3F3F7F7F9
FCFCFCFFFFFFFEFEFEFDFDFDFDFDFDFEFEFEFDFEFEFDFEFEFEFEFEFDFDFEFDFDFDFDFDFD
FEFEFEFAFAFAF7F7F8F3F3F5F2F5F6EBEFEFEDF2F3E6ECECEAF0F0E9EEEFE0E7E8DBE1E3
E6EBEDDBDEE1DDE2E3D5DDDCD1D8D7CED7D4C9D1D0C8CECFC6CCCEC4C8CBC3C9C9BBC0C0
BCC1C1BCC1C3B8BDBFB8BEBDB0B5B6AFB3B6AAAEB1A3A8AB9EA1A4A0A0A19A97938F877F
8B78698F73589D79534CB9255CC52900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF004DB921A17C4D9A7C5B9D866DA1927FA2998B9E988F9A98929897969B9D9B9CA2A0
9BA2A0A1A9A88D9896818B8B9CA7A69DA8A7A4AFADA4AFB0A6B0AF9FAAA7838F8A7F8B89
A2AEACB3BEBCB2BEBBAEBAB7B7C2C2BDC6C7BDC6C9C3CCCFC7D1D3C8CFD2CFD7D9DBE3E5
D8DFE1D4D9DCE1E7E7DDE3E4DCE3E4E3E8EBEBF1F1EAEEF0F3F6F7F1F2F4FAFBFBFDFDFE
FDFDFDFEFEFEFEFEFEFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFDFEFDFDFDFDFDFDFDFDFDFD
FFFFFFFCFCFCFCFCFCFAFAFBF3F6F6F3F5F6F6F8FAEAEEF0EEF2F4E9EEEFE1E7E8E1E7E9
E1E5E7DDE2E4D5DBDCD4D9DAD0D6D5D3DBD8CED3D2CDD2D3C9CED0C3C9CAC6CCCBBFC4C3
BDC1C3B9BDC0B3B7BBB3B7B8B3B6B6AEADABA4A09D9C959091857A8E7A67967A5CA38054
52BF282FE31600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0062C92C51BB24A47D4D9A7953997E61A08B76A29184A1958AA49D95
A29E98AAA6A4A8A6A2A7A8A5A8ACA8A6AAA8A8AEADABB2B2A9B1B0AAB3AEA4AFA8A9B3AE
B0BAB7B2BABCB5C0C1B3BDBFC0CACBBDC5C8BCC6C8C1C9CDC7D0D2CBD0D4C9D2D4D6DFE1
D1DADCD5DCDEDBE4E3DFE7E6DDE6E4E7EDF0E8EEEEEFF3F4F4F6F6F7F7F7FEFEFEFDFCFC
FEFEFEFEFEFEFEFEFEFDFDFCFDFDFDFDFDFDFDFDFDFDFEFDFDFEFDFEFDFDFDFDFCFDFDFC
FDFDFDFEFEFEFEFEFFFCFDFCF7F9F8F8F9FAF4F5F7EFF0F3EAEEF0E7EBECE3E8EAE3E7EA
DFE3E5DCE1E2DBDFE1DCE0E1D8DDDCD2D7D6CDD2D0CDD1D1CCD0D2BFC4C5BDC2C5BCBFC2
B1B3B4B0AEAFADA5A4A79C959E8F7E99836A9B7F61A47F584EBC2A5DC73034E71900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC42982A23DA881559C7A559A7C5E
9F886EA5907CAE9C8BB1A397B1A89FB3ACA8B5B1AFB3B2B0B3B2AFBCBBB8B7B9B4B5B7B2
BBBDBBB8BCBDBDC3C5BABFC3B7BEC1BBC1C5BFC6C8BFC6C8C3CACBC9CDD0CBD4D5D0DADA
D0DADAD5DBDEDAE0E0E3ECEBE0EAE9E7ECEDE9EEEEEFF2F3F5F7F6F6F6F5FCFCFCFEFDFE
FFFFFFFDFDFDFDFDFDFEFDFCFEFDFDFDFDFDFEFDFDFEFDFDFEFEFEFEFDFEFFFEFDFEFEFD
FEFEFEFEFEFFFEFEFFFEFEFEFBFCFCF7F8F8F8F8FAF2F3F5EFF1F3E9EDEDE7EAECE4E8EC
E2E5E9DEE1E4D8DADED9DBDED2D6D8CDD1D3CACBCBC3C0BFBAB7B3ABA69FA0958DA19185
9A8673998067A07E5E7CA04354C12C63CC3235E71900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE315
57C1274EBB24A98151A27E59A18262A58A71AC9682B29F8EB8A598BEADA1C3B5AAC7B9B3
CABDBCC7C0BFC4BEBFC1BCBFBDBBBDC1BFC2C7C7C7C5C6C4C9CBC9D0D3D3D1D7D6D0D6D5
DAE1DFDBDFE0DFE3E4E6EDECE5EDEBEBEEEFF2F4F3F7F7F8F9FAFAFBFBFBFDFDFCFDFDFD
FEFFFDFEFEFEFDFDFDFEFCFDFEFDFDFDFDFDFEFDFDFEFEFEFDFEFDFFFFFEFEFEFDFDFEFD
FDFEFEFCFCFDFDFDFEFDFDFEFCFCFEF6F6F9F7F8FBF2F3F7EDECF0EBE9EDE8E6E9DFDBE0
DAD7DAD2CDCFCAC3C2C0B6B1B9AEA4B0A195AD998AA28B74A28666AB8A6282A54757C22F
61CB3468D03400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005DC52B54BE28BA8D5A7E9F3FAA8158AB8563B59075
B59380B49686BBA193C4AB9FC9B3A9CEBBB3D0C3BAD7CCC3D8D0C8D8D2CEDDD8D6DCD7D5
E1DFDEE7E6E9E6E7EAE9EAEDE7E8EBE6E6EAEEEDF1F9F8FBFEFDFFFFFEFFFEFDFEFEFDFF
FDFEFFFFFDFFFEFEFFFFFDFFFFFEFFFFFEFFFFFEFFFFFDFFFFFDFFFFFDFFFFFCFFFCF9FB
FCF8FAFBF6F7F7F1F2F4EDEEEEE5E5E4D9D7DBD0CCD0C2BDCDBBB5C4B0A7BAA497B39A8A
AF947FAC8F76AD8D6FB38E68BB916259C63262CC3768D1376BD23300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0037E81A6CD036
66CC345FC63159C22E55BF2D55C03052C03280A84DB3916CAE8E6DAF9075B2967FB79D87
B9A290BBA698B8A799BCAA9FC8B6ACC6B4ACD0C0B8D3C2BBD8C8C0D6C6C0D5C6C1D8CBC7
D8CAC8D6C7C4DBCBC6DAC9C4DBCAC4E0CEC8DECBC6D8C6C1D5C2BDCFB9B5C9B2AAC1AA9E
BBA393C0A492BB9E88B99B83BB9B80BC9979BF9973C0986D5BC8375DC93663CD3967D038
6CD3396CD23637E91B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0106283 0.488926 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.0842e-17 0.00671141 -0.00671141 0.00671141 [
[ 0 0 0 0 ]
[ 1 1.91946 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91946 L
0 1.91946 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00671 translate
1.00671 1.92617 scale
450 string
150 287 8 [150 0 0 287 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0106283 0.732558 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE1152FE11600FF005DC32B
5CC42D5DC52F5AC42E88A645B8895CB8885C5BC533AF875FAF895FB08C60AD895EAF8960
B0885E59C533B18860B0875EB1885F58C43359C4335AC53400FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002EE1165DC22C5CC52FBA8A5DBA8C60BA8B62BD8C65BC8F68
BC926DBC9472B89472B89676B9987CBB9A82BB9E8B988579887D73A194829889758F7E6E
A99686BDAA98BDAB9ABEAD9CC2AF9BC3AD99C6AD9AC4A9976ADD5767DC5466DB5361D64E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32C
5BC430B6885E89A84AB98F65BA9068BD9773C29F7EC6A488CEAD95D5B29BCDA991CBAA91
CDAF99C5AC9AC5B19EE0CFC1D1C6C2A8A0A1CCC4C75554632C364F76808DC7C9CCAFB3BA
9CA6B4B9C6D5BAC9D5778994CCD6D8D9D7D3D9D3CEDBD4CFDBD4CFD9D2CCD6CEC8D5CDC8
D7CEC7D1C9BDD1C5B8CFC2B49ACF8769E35F68E05B67DD5863D8525DD14957C83F51C136
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005BC32D88A5445DC734BA9168BE9977
BF9B7FC8A68CD2B298C8A992C4AA93E3CFBBE7D5C8DAC6BBDBC7BBDCC9BBCBB6A7C8B3A5
E1D2C7E3D9D2D3CAC4D9D1CCB8B4BA676673B8B4BAC6C2CBABB2C6A6B4CCC8D7E8AABCD2
223D661B3C696683A75069858D9FB3CCD5DCD3D5D5D5D6D5D3D2D4D1D3D4D0D2D2D0D2D1
CFCFD0CECDCBCFCDCBCECDCACDCAC9CDC9C7CEC9C5CEC6C4CEC7C3CAC2BCC6BBB4C4B6AB
BCAB9DB3A08EB29B8A86B36758CB4150C13500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002FE1155DC52D5DC52FBA8C62BF936DC19976C7A386C6A68DE5CBB6EAD7C5
D1BCABCBB3A3E5D3C6E7D6CCD1C1B6DFD2C9E1D5CDD1C4BCC6B6ADDDCFC6E4D9D4D7CBC6
D8CEC9DFD7D3B9B1AEC7BFB9D9CFD0DED8DDCCCACEDCDADFC0C6DA364A714A6388A1B2CC
4E6082354E766F88A7C1D2E7A5B6CBB3C5D5CED7DDD4D8DBD4D5D9D3D4D6CED2D5CFD3D5
D1D2D6CFD0D3CFD0D3CBCECECDD0D0CBCECDCDCECDCACBCCCBCACEC8C9CAC7C6C5C5C3C0
C4C1BDC4BEB9C3BCB8D2CBC6D3C9C1CDBFB6C1AEA2AE968454C43D28DE1900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE116
5DC42E8CA747BC8F64C59870CBA17DCEA68ACEAB94E2C7B4EFD9CBCFB8ACD1BCAFD7C6BC
DCCCC2D2C2B9E7DAD1E1D6D0D8CBC1D0C2B7D9CEC5E3D9D1DBD0C9DED3D0E3DADADED4D3
CCBFBBD4CAC6DFD9D6D7D3CFDBD6D3E0DFE1A9ADB7ACADB8BDB9C87276936D7996BCC8D9
C7D6E7A6BCD46F8DA8A3BFD76B85A14B6B87C3D6E2D0D9DDD6D8DBD4D7DAD0D4D5D0D5D6
D3D5D9D1D4D5D1D2D6CACED1C9CED0CBD0D2CBCFD1C8CBCECACBCFC7C8CBC6C7C9C5C6C8
C4C4C7C7C8C9CBCCCDCACBCCCCCCCDD0CECED0CECDD2CACAD0C2BDC1ACA583AF6829E11E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42E8DAB4BC0926B
C69976CCA284D2AB8FD5B295D9B7A0E2C1AFD3B6A7D8C1B2DCC9BBD4BFB1D1BDB0DFD0C7
EDE1D9E0D2CAD6C7BEDBCBC4DFD3CBDACEC5DFD5CEE7E1DCE8E1DED4C9C8DDD3D2E0D7D6
DCD2D2DBD1CFE4E0DDDCDBD9CDC8C6D2CDCCAAA7B0ADA8B2D1CBCDDAD9E2B3BFD38195AE
ADC4DB4B6580183B642B4E739AB0C9657B94AABECFCEDBE0D3D9DCD1D6D7D1D3D5D0D4D5
D1D5D8CFD4D7D2D6D9CDD1D4CCD0D3CBCED3CBCED3CACFD2C8CCD1C9CBD0C6C6CBC8C7CC
C5C4C9C2C4C6CBCCD0CFD0D2CED0D4CDD0D3CBCDD0CBCED0CECDCECEC9CBCDC4C3C8B9B6
AC979048BE3A24DD1900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC22C5DC52FBA8C5FBB9266C19B77CBA588D3AE93
D3B098D3B29DD7B6A1D9B9A1D9BBA6E2C6B4DAC0ADDAC1ADDAC5B5EAD9CBDFCDC0DCCCBE
E0D2C7DDD0C7DACBC1DFD1CAEAE0DCE9E0DCDACFCCDED6D2DFD7D4DCD2D0DED4D3E9DFDF
E9DFE2D9CECEDBD3D1D0CBC8CDC7C4D3CBC8E7E2E2DEDBDFC9C9CCD4D4DC717C9720375E
6C819DA0AFC46E7F9B6C829DC4D5E7C5D8EA87A0B6B8CFDBD1DADDD5D9DCD5D6DAD4D8DB
D3D6DBD2D6D9D3D7DAD1D5D8D1D2D6D0D1D5CFD0D4CBCFD2CACFD2CBCED3CBCCD1CAC9CE
C2C3C7C1C5C8C7CBCECED3D4D1D5D8CDD2D5CACED1C8CCCFC9CFD2C5CACFC9CBD0CCCBCF
CAC6CCA6A2A9938B8B78675A5883301BD30B00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF005AC42EB98A5FBE8F67C39A72C9A07DCDA889D0AE94D4B59DD0B39D
D2B6A1D5B9A4DABAA5D9B9A4D6B9A4D8BEA8DCC3ADDCC6B1DFCCBBE6D7C9DECFC1DECDBE
DDCFC3E9E0D7E8DED6E2D7D2E7DDDAE6DDDBE2D9D5E2DAD6E9E2DFE9E3E2E3DAD8E2D6D7
E4D8D9DDD2CFDBD0CCE8E1DEE7E3DFDBD7D3E0DBD9CED0D579808BB5B7BEB7BAC68692A8
9FADC0CBD9E5D0DEEB9BB0C75B789992AFCE28486A6989A3CCDBE6D4D8DDD6D7DCD2D6DA
D1D7DAD2D6D9D3D5D9D4D5D8D1D4D8CFD2D7CED1D6CDD1D5CCD0D2CECFD3CDCDD0CBCCCF
C9CBCFC7CCCFC9D0D3CED5D6D0D4D8CED3D7CDD0D5C9CDD2C5CBD0C6CED1C7CCD0C9CBD0
CCCBD58081933B425B3942526363637467533CAF2100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
88A44489A749B88E64BC956AC59D77CAA483CCAB8BCFAF94D2B39ACDB199CFB59ECFB5A0
D4B9A4D5BAA5DABDA8DCBEA9D9BEA9DBC3AEE4CFBCE0CDBCE0CDBEDECCBFE0D1C4E5D5C8
E7D9CDEDE2DAEAE0DCE6DAD6E3D9D4EBE3E2E8E3E2E1DBD8E7E0DDE8E1DEE0D7D5DCD2CF
E7DFDDE9E3E0E0D9D6E5DFDCE6E4E0CFCECACFCBC8D8D4D5C2C1C8C6C5C9D9D9DACBD5E0
7189A0668199ACC0D3566D8A11346454759A95AEC87490A7C5D9E7D2DAE2D4D7DCD3D7DB
D2D7DAD0D4D7D1D3D6D3D4D8CED2D5D0D4D7D0D4D7CED2D5CDD1D4CED0D3CDCED0CBCED2
CBCFD2C9CFD2CAD2D5CDD2D5D2D3D8CFD2D9D1D3D8CCCFD4CACFD3C1C8CBC7CACFC8CACF
CACCD1B7BAC6575D71838EA36F7A89878C8FA2989066944600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC42F8AA84A
BB8E6ABF9773C29E7BC6A382CDAA8DD1AF94CDAF96CBAF97CAAF96CDB399D4BAA2D1B7A2
D4B9A6D9BEA8DEC4AFE1C7B5DFC8B6DBC6B4E1CDBAE4D2C0E6D4C4E6D5C7EEDFD5EDE0D6
EADDD2ECE0D8EBE1DBE9E0DCE6DDD8EDE6E2EBE6E2E4DCD8DFD5D0E2DBD6E8E4E1DFDBD9
E2DEDDE6E3E1E0DAD7D9D2CCD9D6D2DAD9D9D9D4D3E2DBD9E2DEE0CFCED2C3C2C4B2B6C3
304668223D637D91A8B7C2D67489A88CA7C3CAE0F494AEC57091AAC7DAE8D2D7DFD2D5DA
D2D7DAD0D4D7D1D5D8CFD3D6CED2D5D2D3D8D1D3D8CED1D7CACFD3CCD0D3CCD0D3CBCFD2
CACED1C9CED1CBD0D4C9CFD3CED1D6CED3D7CDD2D8CED3D9CAD0D6C5CACECACDD2CACED2
CACFD3C7CCD1AEB6C28E9CAD90A1B297A7B6A1A9B1ABA5A26E9C521CD20C00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0059C22D86A646B58C61BA926BBE9774
C29C7EC49F82C6A386CAAB8DCDAF95CDAF98CFB29DCEB19BCFB29BD1B79ED9C1A6D6BFA8
D8C0ACDCC4B0E1C9B7E2CABAE4CDBDE1CAB9E4D0BCE6D5C0E3D6C4ECDDD0ECDCD4EDDCD4
EBDCD2EBDED6ECE3DCEEE8E2E9E0D9E6DAD3E1D8D0E3D9D4DDD4CEE4DDD7E8E4E0E4E0DD
D6D0CCDBD6D1E0DCD7D9D5D0E0DCDAE8E5E5E3DDDCD7CCCBD7CED093949B9B9CA1D0CED2
B1B6C6A2ACC1B0BBCCD0D9E4ACBED34060857191B26A85A425466CA2BBD1CED7E0D0D4D8
D0D5D8D1D6D9D0D5D8CED3D6CFD3D6D0D1D6CED2D7CBD3D6CAD1D4CBCFD2CCD0D5CCD0D3
CBCFD2CACED1CCD0D4CDD1D6CCD1D5D0D5D9CED3D7CDD2D6CED3D7CFD4D8CACFD3C8CDD1
C8CDD1CBCFD5999FAD293A513E5570364A654153677E8891958C8B8F74651ED41000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002DE117B3885EB88E68B8916CBD9876BF9A7AC29F84
C5A289C7A58CC9AB91CAAD93CFB39BCEB39DCEB49DD0B7A0D1B9A3D2BBA5D8C2AAD9C5AE
DCC7B4DAC6B2DFCBB8E1CBB9E2CCBAE4CFBCE7D3C0EAD7C5E8D9C6EBDBCCE9D7CCE9D7CD
EFDFD6EADBD1E7D9CEE7D9CFE3D5CCE2D4CBE7DCD6EBE3E1E7DEDBDAD0CBDFD7D1DED9D2
DAD3CDDCD7D2E8E5E3E7E2E2DAD1CFE0D7D4D5CCCBCFC4C3D4C9C7DAD5D7D4D0D3CCC8C7
DCDDE2BCC6D3697D948196AA7F92AC1C3B6737587FC0D2E88C9EB49CB3C5C5D8E1CCD6D8
D3D8DBD3D6DBCFD3D6D1D5D8CED2D3CED2D5CED2D6C9D1D3CCD1D5CDD1D4CDD1D4CBD0D4
CBCFD2CACECFCDCFD3CBCFD2CACFD2CED3D7CCCFD6CCCFD5CBD0D4CED1D8C9CDD5CBCCD5
CBCED6C9CCD3BCBECA5F697D7B8BA1576A7E8191A488949FA6AAAFBCB4B2A98E851ED511
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0058C12C57C12CB1885FB9926DB99574BD9B7DC1A183C1A386C5A88D
C7A78EC9A991CEB29BD0B7A0D0B9A2D1B9A5D1BAA7D6BFACD6C0ADDAC5B3E0CBB9DEC9B6
E1CCB9E2CDBCE2CDBBE0CDB6E0CBB5E2CDB9E7D2BFE9D7C4E7D6C4E8D7C6EBD8C9E8D5C7
ECDACDE9D7CAE8D6C7E6D6C8EBDED4EADDD4E7DDD4EADFDBE1D7D2DCD0C8DED3CCE8E3DC
E7E4DEDAD3CEE3DBD7E3D7D6DECDCCDACDC9E9E0DDE6DEDBD2CAC6E1D9D7D8D5D7AFADB0
C6C3C89FA2AF44516E5E6D86D2D6E6A2AAC18998B4B8C9DCB8CCDE496A8390B1C6C8D9DE
D0D6DACFD4D8D0D4D7D1D5D8CFD4D4CED2D5CED3D6CDD2D5CBD1D5CBD0D3CDD1D2CBCFD2
CDCFD4CACECFCFD0D4CDCED2CBCED1CBD0D3CDD0D6CBCED5CACFD3CACFD5C8CCD5CACBD5
C7CAD2BFC2C7CBCCD3ACB3BF8996A793A6B68494A68797A29DA5ACAAACAFC1B7B89A7F75
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0083A243B2885FB68E65B69067B99570BB9878BB997CBD9D82C0A28BC0A48DC4A68E
C9A992CFB199CFB49FD4BCA9D5C0ADD5BEADD6BDADDAC4B2DBC7B3DDCAB8DDCBBADDCAB7
E0CAB7E1C8B8E0C8B8E1CAB6E3CDB7E1CBB8E6D1C0E4D0C0E5D2C0E8D5C3EBD9C8EAD7C8
EAD7C9ECD9CAEAD8C8E7D6C7EBDDD2E8D9CFE6D7CDE1D3CBE9DFDAE7DCD8DDD1CBE5DDD8
E3DED7D6CDC6D6CBC5E5DBD6EBE0DEDBD0CDE9E0DCE7DFDDCFC6C4CCC3C2C5C6CE92939F
C9BAC3EDD7DFDCC7D5D9C2CFD9BDC6DEC6D4675F7C2E3E618198B53551724C6D8CC6DAE5
CED6D9D2D7DACED3D6CED4D7CCD3D6CCD2D5CFD4D7CDD4D6CCD1D4CBD0D4CBCFD2CBCFD0
CCD0D3CACFD2CDCFD3CCCDD1CDD1D4CBCFD2CCCFD4C8CBD0CBCFD3C5CBD1C6CBD1C8CBD2
CACBD3C2C5CCCCCBD39D9FAD2D37504C607B2B415A536779808F9B878F969C9A9FA19492
668E4500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0055C12C
86A749B68D68B8936EBB9672BF9C78BE9A7ABD9C80BD9E84BFA288C0A58DC3A791CEAF9B
D1B39ED1B5A1D0B5A4D7BCAED9C1B3D6BFB0D7C1B0DCC7B5DBC7B6D8C5B4D3C1ADDBC7B2
DFCAB5E1CBB8E1CABAE4CEBAE2CCB7E2CFBCE7D4C4E7D4C4E4D0BEE6D3BEEBD9C6EAD6C6
E6D1C2EAD8C9EAD9CAE7D3C5E6D2C5E7D6C9E5D6C9E0D3C8ECE2DAE8DFD9DBCEC6DACCC3
DED5CEE2DBD5D9D0CCE8E0DDEAE4E1DAD0CDD8CCC6D7CECAC9C0C0C7C1C771778E7F7B9C
AF7C96C47283CE7082C65F6FB74956B64C5A9F5066513B59959EB4B8C7DB8A9FB4B9D0DE
CBD6DDCFD8DACFD4D8CAD1DAC1C8D6CBCED9D3D0D6CFD0D4CDD0D3C9CFD2CACFD2C9CFD2
C8CFD2CACFD4CBCFD3CACED2CDCFD3CDD0D5CBCDD2CBCBD3CCCED3C8CDD1C8CDD1CACDD4
CBCBD1C9CCD1CBC9D2B5B0BD5E5F756C78904F60778798AA8998A5AAB5BDBCC0C7B9B8BB
B5A29F44B22B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002AE015AA8559B28E65
B8926CB7916EBA9776C0A07FC2A282C1A184C4A38AC2A48CC4A891C9AE98C8AC98CFB2A0
D4B6A4D6B7A6DAB8AAE4BBB0DBB0A4DFBBABD8BDAAD8C1ADD9C3B1DBC6B3D7C2AEDFCAB5
E1CDBAE1CEBEDECABCE4D0BFE6D2BDE6D4C1E8D7C7E9D5C5E7D0BEE6D0BCE9D2C0E9D2C0
E8D3C0EAD6C6EAD7C9EBD6C8E8D5C6EDDCCEEFDED2E3D2C5E1D1C6DCCFC6DCD1C9D7CBC6
E4DCDBE7E0E0E2D6D4DACAC7E1D2CFE1D1CFD7C7C3E2D5D3E6DCDED9D1D987849E463766
8F416CA3203CB6172ABB111EBF0F1CBA101BAB202EDC9AAC9894A8B7C5D96B839E496B89
BDD3E2CCD4DACED3DBB5BFD1464D6E806D8BCAA8BAE0C8D2D5CCD1CECFD3CCCFD3C8CED3
C5CED5C6CED8C8CFDAC9D0D6CDD2D4CACFD2CACFD4CBCFD6CACDD3CACDD2C9CED3C8CCD4
C8CBD1C8CBD0CAC9D2C2C0CA9F9EAE737C90919EB38A9BAA909EA9A1AEB5ABB5BAADB2B7
AEA6AAA68D8400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02DAC855FB18E69B49270
B69271B89376BE9D81C2A488C3A68BC3A68EC5A691C7AA96CCB09CD3B6A2D5B6A3DAB9A7
D9B1A0D5A598E1A89DCD867DBD7166E0A694DBB7A1D6BBA6D7C0ABD7C2ADD6C1ACDBC6B2
E4D0BEE4D1C2E1CEC0E0CCBBE2CEB9E1CFBCE9D7C6E8D3C2E6CFBDE7D0BEE9D4C1E9D3BE
E9D3BFE8D1C1EBD4C6E7D1C3E8D4C4E7D3C4E6D2C4E2CFC1DECDC1DDD5D0E5E1E1D5C9CF
CCB6BFDEBDC4ECBCBFEAB2B2F9C2C3FCCDD0F6C9CDEABEC1F0CDCFDCBFC4C2ABBE513A64
854673A22C4AB81425C50B14CA0B13C80C13B80C18BE4D62503056556285788CAD243F63
9AAFC7CAD5E0CCD3E08E96B138265182355A8B1F3BB0596DD8A0AFDFC0CCD6C5CFC4BBC8
ADAABD8B8AA36C6A83A9ACB7CACED3CED2D7CCD1D7CACED5CACDD4C7CCD1C7CBD3C5C9D2
C7CAD2C8CBD3C7CBD2C9CDD27E8291232F484C5D75394B6160728396A6B098A3AB9EA0A7
948F9497828042B02700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002AE017AB835EAE8867B08D6EB39274B79578
B89478B9947BC2A188B19176C2A38CC3A693C4A695D3B4A1D6B3A0DCAE9EE1AB9BD39787
DE998AB56959EC9A8DBB5E54CA6B5DDA927DDFB49CD8BCA5D3BBA5D8C2ADDBC5B0DCC7B3
E2CEBCE4D1C2E3CEBEDCC5B2DFCAB5E0CEB8E4D1BFE8D3C3E5CDBDE5CBBAE4CCBBE6CFBC
E6CDBAEAD0BFE9CFC2E7CFBFE9D0BEEAD0C1E4CFC2E5D6CCD6CDCDB9B4BFA18EA3AD768F
C16279C85062C7404EC83743CB3847CE4151D04858CF515DD76972DE838FECA4B79E6485
722B53BD5271B51A2CC50C15C7070FC90810C20711AF1C2C95516E5E5B78CAD5E9A4B5C9
95ACBEC3D4E3BEC6D94D45666E3455951C31A3091BA20B1F9A172DA2364BA74C628D425B
7A334F77334E6E30479C7D86D3CED3D1D0D5D1D2D7CECFD4CBCDD2C9CDD4C8CBD2C8CBD2
C7CAD5C6CAD4C8CBD2C8CDD49294A05C6173687386425062808E9D93A2ABAAB3BBBBBFC6
B3B1B7B1A3A891746900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004CB82350BC2A7CA043AA8662AE8A6BB18F72B19075B3937AB6967C
BA987EC09F87C6A78FBB9A83CAA995CFAC9AD8AFA0DEADA0E5A69ABC655AB64F43D36C5D
D2745FBF654EED927CB85545DD7767C87663E2B29BD5B7A0D5BBA5DAC1ACDBC4AFDEC9B6
DFCAB9E2CDBCE4CCBBDFC7B5DDC8B4E0CCB7E5D1BCE7D2BFE1C9B7E4CBB7E2C8B4E6CBB6
E6CCB6E9D0BDE9CEBEE8CFBEE8D0BEE9D1C2E4D1C7D4D0D58685A17F5A82B35476C03143
CB212AD21F23D21B1DD21B1CD31B1ED21A1ED11A20CE1A22C71823C41E2DC0263ABD2F49
B42C46DB4B5FCB2732C80D13CB090FCC0910C80910B20D15DC7B88A6889C87879F8A93AD
2E3E62757CA16852757A39589C263BA70917B0040FAF030FAB0311A60615A308189D0A18
980C1890151B852E30D3AEAFD3CCD1CECECFCFCFCDD0CFCECBCCCEC9CCD0C8CBD0C7CCD2
C8CDD4C4CBD3C4C8D2C4C7D0B1B3BC9295A07A818D858F98879199879198979EA5A6AAAF
A4A3A9ABA6A9B1A19D43B42B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0047B6267F634992745BA88668AB886BAC896FAD8B72B08F77B09076B5967C
BC9C83C1A38CC6AA95D1AF9CD6AB9ADDA899CA8477AC5448DE7C6EC35B4CC65544D8634D
C95D45D26F56E28069BF5944E27968BA6451E6B09BD7B7A1D9BFA8DBC2ACDEC6B4DDC6B6
DAC3B3E2CBBBE0C9B9DFC8B8DBC4B3E2CAB8E7CEBDE7CEBDE2C9B5E3CAB4E2C9B3E4CBB5
E6CDB8E7CEBBEAD0BFEAD1BEE9D0BEE7D0C0DFD0CC8C90A85B4D7FA94C79C62438D41D20
D21D17D0221ACD251DC92623C32626C42A2CC4282CC22229C21F28C21A25C21823C01421
C01420C2121BC81217CB0B0ECC080EC8050BC7060CBF0910B728349740585C2B4D805579
6432597E375C9C324EA5192AAE0915B3030EB3020CB1020BAF020AAD020AAD030BA90509
A00D0E91241DC48C85DCCCCACFCDD0D1D0CAC3BEA5CBC2A6D0CDBFCDCFCDC7CCD1C6CCD4
C7CBD4C5C9D2C4C6D2C4C7D0C1C3CF6368792E384A64738346586467767E9CA4ABA4A8AC
97959A938D9193878546BC3600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
25DB11648D3C5C4D4A272429766C65A38974AA8971AB8A73AC8C76AD9079B0947EB69A84
BDA18BC3A792D1AF9CD39E8FB86A5EDA8272B45845C6604CC9624EEF8F7BD7735ED2614D
BE4C37E0705BC14F37BE5339F08F78AA5540E7AD97DCBAA5DABEAADBC1AEDBC2B1DBC4B4
DCC5B3E2CBB8E0C9B7E0CAB5DEC9B3DEC9B3E5CFBAE3CBB8E1CAB5E5CDB7E3CAB3E5CDB5
E7CEB8EAD0BCEAD0BDE9D0BCE8CEB9E7CDBCDCCCCC5A6183684E86AC3459CD2225D02E21
D04938E17364DB8074C97C76C98585BB787FB5717DB26979AF5F71AC4E61AC4252B03947
AE2A38B32430B41923C01218C60B10C9070EC9060EC4060EBB0A15B81C2CB02437A51C30
A4152AA80E21AD0715B2060EB3010BB5010AB4020CB00209B1050BAD0509A9080A9F0F0D
972A24C4897FDAC7C3CFCECECECED1D3D2C5B7AB7DB8A65DCEC392CFD0BDCACFCEC7CCD1
C9CDD6C7CAD2C6C8D4C8C8D2C7C8D6676A7C585C6F5B67783E505D80919A9DA9AFAFB8BA
C5C8CDB3B2B7B1A9AC85726800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0024DB13
816850403C400E19360A173569676EA08A7AA78973AC8F78AF937EAC927EB49B88B99E8E
BDA291C5A896D4AB99B16B5BBB5646B44835D87A61DF836ABE5942D26755C45743D56A53
B0432EB94C35CB6A4ED7896DEEA88FA45A42E5A891DDB8A2DABEA9DCC0AFDBC0B0DDC4B3
D9C3B0DDC5B2E0C6B7E0C9B6DDC7B1DDC6B0E6CEBAE3CDB8E0CAB3E2CDB4E0CAB2E6CEB6
E6CEB7E8CFBAE8CFBBE9CFBCE7CEBBE6CDBCE2D1D06D6F8F5D437CA3395BC63935EE8570
FDBFADFAD2C5E2C1B4E5CABEE7D0CADAC5C2D2BFC0E0CCD3DCC6D2C4A7B6A9829492697E
8458747C4B6A823F5FA83A4FB5121EC3070FC5040CC7050DC4060EBF0811BB0911BA0A10
B8070EB9070EB6040BB40309B40209B3030BB1050CAB0608A70B0AA0100C9B1F19A64E45
D5A39DDBC9C5CFCECEC9CED0CDCFD2CFD0C8C5BC98B8A255C0AB5CD2CB9DCED0C2C5CDCC
C6CDD3C7CDD5C4C8D3C6C9D3C7C7D59594A38887956C727D7C848A8C96988F979A999EA2
AAABAFAEADB3B6B2B8A496941AD10E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC12765F48
2D2E390D1E42011648031541595B6B9F8E82A88E7AB09681B29A87B69D8CB69B8DBEA294
BDA18FBD9F8ACAA28DAB6D59DD8673B14C39D6715BCE6851C65A45BA4834C0543FE48E74
D1896EDC9C7FDDA98CDAAE96DDAE99BC8770DDAD95D7B69FD9BEAADCC0B1DCC0B1DEC4B2
DBC1ACDDC2AFE2C8B6E2CAB9DCC5B4DDC7B4DFC9B4E4CDB6E4CCB3E4CBB3E5CBB4E5CAB5
E6CAB8E7CCBBE8CFBDE7D1BCE8D2BDE6CFBDE4CFC6A69CAF5547728E516CD27E78F3BBA6
E6C9B6E5D2C3D7C5B5D6C4B5DCCFC5E8DEDADCD1D1DED4D3E8E0E0D7CBCDCAB7B7CEBFC0
C9C1CE9D9AB646436D603C69A12B47BB0C19C70710CA0810C6030CC1040BBD0A0BB6110A
B2110DB0110FAB0D0DA90F0FA80E0FA5100FA01511971C159C332AAE5F53CE9A91DBC2BD
D4CBCACDCDCFCBCED1C9CED2CBD0D4CDD1D2D2D0C2C7BB8DB7A159BFAE69D0C9A3CACDC2
C7CBCEC6CDD3C2C9D1C4C8D2C4C8D4AAADBA52566A303A4D74818B5C6A71869197A6ACB0
A6A5AAA29FA6A09AA292848737A82400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0094725542393E
0A183F061D5601165604184E454E679C908CA79082A89181A89381B79E8FB99D8EB99E8B
B59A83B89C84C09F87C99B85C87E6CB34C3CCC5746AD3B26E57D66C15B46D8735FD4866E
DBA68AD4AA8FD0AC92D0AF97D2B09AD2AF99D6B69ED8BCA6DAC0ABDBC1B0DCC3B0DAC1AB
DAC1AADBC0ACDFC6B3E1C9B8DDC6B3DBC4AEDFC6AFE5CDB6E4CCB5E3CAB4E5CBB4E5C9B6
E7CCBBE7CEBBE8D0BAE4D0B7E4CFB7E2CCB7E4CDBDDBC9C7847784C3A7ADE7C0B3E4C6B1
DDC9B3D8C7B4DECEBED8C6B9DCCCC3EADED9DDD2CDCEC2BBD2C6C1DCCFCED5C7C5DBCFCC
E1DADEE0DDEC888BAD322A6195446DB01327C40912C7070DC8050DC00609BB1911D55846
B75344AE5044A447459F4A49AC5B54B1685DB97B6ECA9A90DAB8B1DAC7C3D3CBCCCECED0
CBCED1C8CCD0C8CDD1CACFD3CAD1D7CAD0D6CDD0D1CFCEC0CFC09BB8A666C1B071D4CDAF
CACCC7C6CBCFC3CAD0C2C9CFC5C9D2C0C4CE40425843455D595F6F525D688C98A1B0BAC0
B6BBC1C3C4CCC3C1CAB3ACB05A894500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0026DC10A6835D937B6D4B475B
06164902175901185E051B5A333D6290878AA69184AE9785AF9783B59A88B49685B3947F
B79A7FB99C80BD9E85C59C84C47E69A43E2AD25B4AC85744E68570CA6A56A4442CBA6D52
D4A285D0AC90CEAD93CCAC94CFB09ACFB4A0D5BBA9D6BDACD8BEACDAC0ACD9BEABD9BEAA
DABFAADCC2AEDFC8B3DDC7B2DDC6B0DCC4ABDDC4ACE5CDB7E4CEBAE2C8B5E5CBB6E1C7B2
E4CAB7E5CCB8E8D1BBE6D0B8E4CEB8E4CBB9E4CCBBE4CEC0DAC5BBDDC8B9E1CBB8DCC8B2
DAC6B0DAC7B6E8D7C9DBC8BBD7C2B5D9C5BBD8C8BFD6C4BCE0CDC8EDDCDBEDDADCD3BCBD
E2CACCE3CCD4C7B0C6553C678A426DB12239C20A16C6070DC30409BF080AAD0D0CDB6B66
8F4C4C916266AA838E5A3D4EC8AFB7E1C8C8E0CAC8DBC9CAD4C9CBD3CDD1D0CCD2CDCED2
CBCDD1C8CCD0CACED4C9CDD1C8CDD1C9D0D2CCCFCECDCFC6D4CDB6D3C58DBBA854CABB7B
D0CBB2C9CCC8C6CACEC6CBD1C4C7CFC8CBD371717F72707F6E717A868C938D949C9398A1
9C9FA8A2A5AFB4B6BFBCBAC18C7B7900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006E973BAF957E917F7B54546B
06174A01155C011764031B6124305B968C94AC9689B19886B19583B0907DB08F78B39178
BA997DB8997CC09F84CA9D87CA806DBE5A44CE5C46A93A24B3563DD68E72D29679D4A587
CCA68ACBA98DCBAB8FCBAC93CCB39DDAC8B8E7D7CCE1CDC2D9C0B2D9BEACD8BDAAD8BFAC
D9C2AFDAC4B0DBC5B0E2CCB6E0C8B1DBC2AADEC7AFE4CDB9E3CBBBE4C9B7E1C8B4E2C8B4
E6CBBAE2CCB9E5D0BCE6D0BCE6CDBCE7CFBCE6D0BBE4CDBBE2CBBADEC9B7D9C9B7D8C8B6
DAC0B0DFBCAFE2BCB1E1B9AEE7BAAFEABBB5FAD0CEFACBCDE6B1B3F1B8BDEEAEB4DB9096
D48288E48F98E6909FAF516BB43A57C62739C10812C4060DC2050BC2060CB6050DBE2932
A32C3B953243B55D707E2E47B36E85D296A4D59FACD9A9B5DAB3BEDBB9C3DDBFC9DDC6CE
DAC7D0D5C7CED2C8D0CEC9CECCCCD0CACCC9C2BDACCDC49ED0C387C2AF51C0A82DBFA938
D3C582D1CBAECCCCC4C8CCCBC4CACDC6C9CE8C8F9D464D60616E7D81919E73828C97A0AA
AFB2BDA6A6B09E9EA69A979F7F6E7000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF007CA44BAF98819484749D8F8B4D4D62
0D1F53021962011668031763192654968E96AA9387AE9383AD917FB3937FB49279B59277
BA987DB8997DBD9C80CD9B839A4832A8482DD57F60CF896CD59B7FD0A387C8A489CAA98F
CAA98FC9A98ECAAA91CAAD94CCB8A4E9DFD5E7E0DDEADED9D2BFB4D4BBA9DAC0AED9C1B0
DAC4B1D8C2ADD6C0ABDEC6B2E3CBB5DBC3ABDEC6B0E1CCB7E3CDBBE2CAB8E2CAB6E2C9B6
E4CBB8E2CAB7E4CEBCE4CFBEE5CFBFE6CFBDE5CFBBE3CCB8E2CAB9DCCABCB8B5AFB6B0AF
D5AFABE19590DE7F7CDD7272D45E62D05259D24E5ACB424FC4343EC32E38C22631C01D27
BF1921C31C24C21822BE141FC00F1BC20A13C4070DC3060AC1060BBF040BBD040CB6050D
B10813AA0914A70A17A40A1AA00B209C0D229C122898142B981D339924399D3046A34456
A95566B16877BF8290C599A5CFB4BBD4C8C1B7AB8AB39F57BDA43BBCA21BBEA40BC0A610
BBA528C4B45CCCC28EC8C7A7C8CBBCC7C8C5ACABB32B2E415E6577505C6C4B596895A3AE
AAB1BDB2B5BEAFB2B7B6B7BC998F9118D00F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0079A246A89480A99D919D9388AAA19C595D6F
172B61021A6702156501145D1524518C868DA28A80AA8E7FAD8E7CAD8E79B5957CB7947A
BA967DBA977FBD9A82C3987EC2886BC38666CD9A7CCBA289C8A58DC5A78FC2A690BEA58F
C5AC97C3A991C6A990C8AD93CEBBA8E7DED5E7E0DEE2D6D2D0BBAED4BCA8DBC2ADD9C0AF
DAC4B1DAC3ADDAC1ACE1C7B6E1C9B6DBC3ADDDC3AFE0C8B5E1CAB7DCC8B2E0CCB4DDC9B4
E2CDBAE1CBBAE3CCBCE3CCBDE3CDBDE0CBB6E2CCB6E2CCB5E4CEBADDCDC3787C8A4E5472
A46B82B12B37C92226CB1B1DCD181AD0191CD0181AD3171AD31518D31617D31516D21414
D11312D21513CD1310C9120EC81211C30D11C30C13C3070EC2050CC2050CC1030ABE030A
BC040AB7060AB6090DAF050AAE060DAC060EAD0611AA0611A90814A80714A90A19A00716
9C09179B0C1A950E208D1627842E3BDAB4B5D5C8B8C8BC92C3AE5FBCA228BCA209BBA202
BDA508B8A213B59F28B2A343C3BA77C9C297C2B99E6E665B7370737173797D8388888F96
8C8F97909197949298A1A0A6AB9FA435A82600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00769D40B4A28B9C9087A79D969489819D938E757485
09194D02166100115D0112540D1A457D7882A0877EA7887CAB8C79AE8F7AB5927CB8967E
B9977DB9967EBD9982BF9A80C39A7FC2997EC39F85C2A38EBDA28EB39D8D9C8B7D8D7F73
958A7DAEA18EBEA890C7AD93CEB6A1D8C4B8D9C6BDD5BFB3D1B8A6D8BEA8DABFAADBC2AD
D8C0ABD8C2ACD9C2AFDDC6B4E0CAB4DDC5ADDDC3AFE2CAB8E0CAB7DDC8B2DDCAB1E0CCB4
DFCAB5E2CBB7E3CAB7E0C9B5E2CCB5E1CBB4E1CBB4E3CDB5E3CEB6DEC9BCAEA9B6364066
996D90B22D3DCF1E1DD41912D51A11D31B11D21D12D11E13CF1E16CE2119CB2318C72318
C5231BBF2219C1281EBD291EB62722A11721A61325B80F1BC10710C2050CC1020BBF020B
BB070AB51711AB1B15A41B14A11B149D17139E14129E1212A01111A20F0FA50E12A40B0F
A50A0EA2080DA108119E0914870D19C18286DAC9C5CFCCC2D6CDAFBCA957BCA31ABDA304
BFA603BCA004B39904B19B0DB19D1CB2A02CB29E3A8A783A45423769727B8896A0818F95
A8B0B4AAABB09C99A08D898F8B7C8235A72600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0051BE2AAE9882B8ADA69A9491C1B9B699908DB8AEAE92909F
13204E0B206401155B0214560B18477A7681A38C83AB8D80AB8C7CA98A77B3937FB4947C
B29378B9967EB99781BA9B83C1A187BD9E82BFA188B99F8C9D8B7B82726686766B877A6F
766C65726B61A89C89C5AF98D0B6A0D2B8A5D2B9A8D1B7A3D5BAA5D9BEA8DAC0AAD9BFA8
D5BCA5DBC2ADD9C0AFD9C2AEE0C8B2DCC2ADDBC1ABDFC7B4E1CBB9DFC8B5E1CAB4E1C9B1
E0C7B1E2C9B3E1CAB4E1CAB4E3CCB5E3CCB5E4CCB7E3CDB9E4CEBAE1CBBBD5C7C667657D
81637FB5545CC03226C7331FCA3D27CC482FD2563DD8624DDA6D5DDE796BDF8474E28F7F
E6988BE49C90DF988CDA988AD49A957A4459742E53A82841BA0A17C1030DC2020CBC0208
AF0808D85F54D08075B1756DB27E7A9A69699D6A68AE716AAE6864A95B57A34949A03D3C
A034319928249720219116198B181D90494DDEC7C8CCCBCCCFCDC5C6BA89BAA130BFA50B
C0A402BFA404BAA00AB39D06B39C04B39D06B19B0DA39025332C084B5056505D6B62727C
A8B2BAB5BBC1B1B4BAAAA8AEABA1A440B63500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0026DC11AA8F70B3A49DABA4A3ABA7A79B9797ADA6A6988E8F938E9A
232C5303155502145B021459061448726F819E887FA68A79AA8E7AAB8D79B1917CB2937A
B4967CB6987FB79881B89A82B89D81B99E82B8A08A9E8D7B8274669D8D7EAB9886AC9989
94857B6E6861797368C3B19FCFB5A0D2B8A2D3BBA4D2B9A2D6BDA6DABFA9D8BDA7D7BDA6
D7BDA6D8BDA8D8BDA9D8BFAADEC5AFDEC4AED9BFABDEC4B2E1C9B8E1C8B7E2C9B4E2C9B3
E2C7B3E1C9B4E1CCB7E0CCB5E1CBB4E2C9B5E2CBB7E6D1BCE4CFBAE0CBB8DECBBDC3B2AD
C1A5A3DEAA9FE09C89EAA793E9AD99ECB5A0ECB8A2ECBBA6E7B9A9FDD3C7F1CAC1E1BBB3
F3CEC5EBCCC3CEB4ADBAAAA6D0C0C5B397AC622B51B3435FB60D1BC2050CC3040BBF0409
B2080BBB4140DC9EA255374968647C7A8397657080CDD0D7D0CCD2CFC1C7D7BEC3DCBBBB
D9B2B0D0A7A4C59795BA8482AA70718F6466D2C2C4CCCDD1CBCCCBCFC9ADB9A44BBCA511
BFA504C0A90E8F7B079E8F11AC9E10B7A40AB39B04B09B198B7C337B776474787A858E93
90959B8F949893959A908F94A69FA2806D6800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0078A045BCAB9EBBB3B39E9C9DC9CACC989799CDC9CB91898CBCB8C2
39406102124C01145A011459051348625F7298827AA68875A88975AA8B77AF917AB0917A
B2937CB3947CB7967FB99980BB9C80BB9F85B19D8A7D7164918577A99787AE9985AF9C89
9F9084766F6B69645FBAAA9DD0B6A3D3B9A3D4BAA4D3BAA4D7BFA8D4BCA4D5BBA4D8BFA7
D7BEA7D7BCA5D7BCA6DBC1ABDCC5AFDDC7B2D8C1AFDBC5B3E1CAB7E0C9B7E0C9B7E1CAB7
E4CCB8E1CAB5DEC8B3E0CAB5E1CBB7E1CBB9E0CCB9E4CFBBE4CFBAE3CEBBDEC9B8DCC6B5
DBC1B2DAC1B2D3BEB4C6B3B0B89D9EBF9998D9A7A1EDB1A7EDABA6F4B1B1EDA4A7DE8E90
D08080C48281E0B9BC6460757A7595A8708DAB3E56C32F3FBB0A14C4060DC3050CBD0409
B8070DAD131DB740527C2542572A4DA297B079859B899BB75C648271617D9A768ACCA4AD
D4AFB5D8BABDDCBEC3DEC3C6DCC6C7D3C6C7CCCBCDCAD0D3CBCFCFD1CFB9BAA858BBA414
BDA504BDA7127D6B183D38035B570C9E971BAD9F0CAF9E0EB09F31867F4397987D9AA295
A6ABAAAEB3B5ADB0B3A4A3A8928B9179646600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0029E015AC967EB4ACA9A8A6A9A3A5A8B9BDC0AAABAF9F9CA18E868C908893
40435E031146000F530211570312465B5A6E99847DA08472A38673A78A75AC8C77AD8C75
B2927AB4957DB6957DBB997EBB9C80B99E859A897A736961978B80AA9889A99887A9988A
96898278717068635FB3A496CFB6A0D2B8A2D3B8A4D6BCA7D6BDA7D2B8A1D6BAA3D7B9A3
DBBEA9D7BBA5D6BBA4D8BFA8DCC3ADDCC5AFD8C2ACDCC4B0E2C9B7E1CAB8E0C9B8DEC8B8
E0CBB7DEC8B3E1CCB7E1CAB5E2CAB7E0C9B5DFCAB5E2CDB8E8D3BCE6CFBDDEC8B8DCC6B6
D9C4B6C9BFBE8587977B6A80BA7C8EC86370C94A51C83A3DC93238C62A33C4232CC42026
BD1D23AB2227DC868E957E993E356590476EA9152ABD0A15C5060FC4030BC2050BBC0509
B7060BB3060FAB0614A10A1B931D32B67A879E94A920264C60436B86304D8E192E901826
91212F932E3D9A3E4DA15262A66976C5A7ADD1CCCFC8CFD2C9CECDD1CFB6B6A34DBAA211
BDA503BEA8117C691B100C001519013335028F8814A79A14A99916948614978931928B4B
81805AB2B3A3B4B7B3B7BABCAEACB1998C8F18D10F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A48862B5AEA3B1B1B2A0A2A5C7C9CEA6A9AEC5C6CB8E8A8EC1B8BD7E737D
7E7D950C184702104F01105206134955526A9B8582A28677A28671A78B76AA8E78AC8E76
B09175B3947AB6977CBA997DBD9D82BCA18B8C7C6F766E668F867E9E91879A8E848F8780
817C7A686868696660BEAD9DCCB29CD1B59FD3B8A2D6BDA5D5BDA5D1B9A0D4BAA2D7BBA4
D6BAA4D6BBA5D8BEA7DEC3ADDBC1ACDFC7B0D9C4ABDBC4ADE1C8B3E4CAB7DFC7B6DEC9B7
E0CBB8E1C8B6E4CAB6E4CAB5E2C9B6E2CBB6E0CAB3E1CCB6E4CFBBE1CBB9DDC6B5DBC4B7
D6C7C37E8699505479B57998B73242C81D26D2181ED6171AD71319D8131AD51014D51313
D01312C21815B93637D39BAA3F325E7E4C7BA31C35C10C16C6060CC6070CBF0709B8110F
A80E14A20716AD0717AF0310A60916A43B46966E851C123C7C4C70871127A10614A4030F
A405129E05119B06139A0B198E0E1C8B3943DDC1C7CCCDD1CBCECDCFCAABB39F3FBDA50F
BDA402BEA7127E6A1A1B140324280E33380A807C28575207898317A59B19AB9B14AA9A1A
A39228A092459791679392848D8B8794898831A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF004DB926A59384A6A7A8ABB1B4A8ADB1BFC2C7A7A8ADB7B6BB908A8FA2989D837780
7A7890091345010F5101115306154C504F689784809F8372A58770A78A71AA8C75AE8E76
AF8D70B59378B6967BB9987DBC9B82BB9C898A776C6D67637C7875847E7B827E7B797775
6D6F6E5F6260817C72C6B19FCCB29CD0B69FD3B9A2D2B8A1D4BCA4D5BCA5D0B59ED4B8A2
D5BAA4D6BCA6D7BDA7DBC2ACDAC1ADDCC6B1D9C4ACDAC3ACE1C8B3E0C9B4DFC7B3E0C8B5
E1C9B7E1C8B4E4C8B5E4C9B6E2C7B5E3C9B8E1CAB6E1CBB6E4CFBAE4CFBBDFC9B9DCC5BA
D3C7CA4755775D5F8EAE5E79C1232BD61719DA1312DC1412DC1112DD1315D5120ECF1A10
C61D11BD2012AE291DCB817F75617E4A37689C3A5BB9121FC6080EC5090BB70A07DA5951
B1565E690F2B8C0A28AB0517B104109D0B16AC53684221436A43618422329F0913AA040C
AB030CA60109A5010BA4020A9E070E861219CA959BD4CBCDCDD0CDC6BE9FB49F41BDA415
BDA405BEA60E8A72162D1C05343216141600847E3B302B001B1D00636414A2991CAB9A10
B09D11AD9A18AC9D3CBBB17B9F977F84776B31A41E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00729D45B0AAA6A3AAAEA5AEB0C3CACDA7A9AEB8B9BDA2A1A4B9B4B58B8383ADA4A7
66667B18255403135301105204124848476097857F9F836AA9895FAD8D5AAD8C5DB59265
B08E64B29171B5957BB8977EBC9982BA9A87967F7567605F6B6B6D7271736E6E6E696967
6667636E6A63AE9F90C9B09BCDB19BCFB59FD1B7A2D0B7A1D3BBA2D1B69FD6B7A2D5B9A3
D4B9A4D5BBA7D4BAA7D6BEAAD6C0ACDAC7AFD9C5ACD9C4ACE0C8B3E1C8B4DFC5B1E0C5B3
E2C9B6E2CAB7E3C9B8E3CAB7E2C9B5E2C9B8E1CAB9E1CCB8E1CEB7E0CFB9DCCAB7DCC8B9
D8CAC7656E8D444E7EB2809DB22D36CF1B1ADA1714DA1310DB1211DA1411D02216EA6753
E88169E1876FDC8C77D5A093B29FAB36335F824774A7172CC20A14C3070DB5090CD66160
C1848D5D3350630E38A00C24B50712AF080FA125309B65793C244081465C8E1622A0040E
A9020CA70008A8030AA3080A9A0E0D8A1718945154DBCBCCCED0CFCDCCBCBFB379B8A536
BCA513BDA70AB59B185F44063F2F052922008D823C3A3205181902292C0777722070660D
A69A18AA9B09AE9C14B6A73AB2A35CA798703FB42800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00967F689D9FA2949FA5AAB3B9B8BDC398999FB0AFB3A5A4A6B6B2B3888382A49B9E
6E6C7D16204B02114F021050020F45424058978377A58756BC993FC39D33BA922FC59D44
BC974FB79462B59374BC9982BC9985BC9B88AD9284726460646163636165656263736D68
84796EA08F7FC5AD98C7AB95CCB098D2B6A0CFB39ED1B6A0CEB49CD1B49DCEB19CD3B9A4
D4BCA9D2BBAACEB9A8C7B5A3CEBEABD5C4AFDEC9B3DDC4B0DEC5B2E2CAB7DEC6B5DFC4B3
E4CAB8E2CAB8E2CCBBE3CABBE2CAB9E0C9B7E4CDBBE3CCB8E2CFB7E1CEB8E2CDBADFC7B6
DEC8BCBBB3C1515D836B678EB67389B52E36CC1C1ED81514DB1412D71411C71F18FB8F83
F3AC9AE1B09BDBB39ED2B5A3C9BBBB5A5C7D5B42749C304EBB0F1DC5080EBC080CAF2225
D2888B8A6A7C42103B870D31B00518B2040D9E0C15B467727862773E2A437E3D4E8D131E
A0050EA60108A304079F1C17BB6058A36359895F5DC7BCBCCCD0D2CCD0D1CECCBDC7BE89
B8A941B9A415BEA50DBA9F179B82164936009A882F4F410E211E031D2200928F4359500E
6F650FA29919A79B0FB3A316AD9A20A08B3746B92000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
27DC13806E628F93999BA3ABBCC1CA9D9EA8B1B0B7A9A6AAA7A3A5B1ACADA8A1A2897F82
8F899711173C020C46020F4C041143434356978369B39440C3A11BC8A50EC7A017BD9528
BE9A46B79359B49170B6947DB7957FB8977FBA9984A1877878655E7A6B6593847A9F8D7E
AE9884C7AD97CAAE98CCB198CEB29BD0B49ECFB39DCDB19BCEB39CD1B69ECDB29CD3BAA5
CCB9A7B5A495AD9B8DAF9E8FA8998ACBBCABDAC5B3DAC1B0DFC5B4E3CBBADFC9B8DDC7B3
E1CBB7E1CBB9E0CAB8E1C9B8E4CABBE4CAB8E4CDB8E7D1BBE5D0BBE2D0BBE0CDB9DFC8B6
E0C9BAD9C7C1BAB4C0626687695F85B27993B3414CC42226D31618D71314D01416C82B2B
E0706AEC9E93E3AD9DD4B4A3DDCDC7A6A6B9332E5F914C73AA1526C00810C1070DAD0E11
D37274BE95A148244A6F0F3AA80820B50310A8050E9D2F35B1878D8579884B344B7F3B4F
89111D9D060DA2040A921310D58D88D7B7B2BEB2AFBCBCBDCBCFD4CACED7CBCDD2CECDC0
C8C08FBAA843BEA518BEA307BDA30CB49C12B59C1D6853102D24011B1B00807D36554E05
58520384801F756D09A59817B2A014A28C1848BB1200FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
50BF309A928D858E98A5AEB8B2B7C19B9CA3B1B0B6A8A5AAA9A3A7B1ABB0A9A2A58D8286
A19CA8192042020D45010E4B0311444343549A8554BE9E29C8A70CC7A704CAA613BA922A
B28F4EB08E64B08E71B39279B4937CB5947DBB9882BA9984B69886AF9484B39985BCA089
C6A991CEB099CDB09ACAAE98CBB099CCB29BCCB19BD0B69FD2B7A1CFB49ED1B7A1CFB8A4
B19F8EBEAB99D2BBA8D4BCABC4B2A2AC9C8DDBC9B9D9C3B3DBC4B3DFC8B7DDC8B6DBC8B4
DECCB9E0CBB9E1CCB8E2CBB8E0C8B5E2CAB6E2CBB5E6D0BAE2CEB9E2D0BCE1CFBCE3CDBC
E2CBBADEC9B8DBC9BECEC3C58F8CA05A547393738EBB6778B62E35C91B1ED31418D01318
C61B1FC12E2ED6645FE7A299DCBAB2D1C6CD44466B6444709C2740B90B15C1070DB90B11
B93740B86F7F7B4A6A680F3AA10A25B2030FAF040D971017C3868AD5CAD0938F9F48324C
7D3D5287142399051099081090222ACC939ADAC7CBCCCDD0C9CDD2C7CED4C9CDD5C8CDD0
D0CFC2C4BA87B6A235BDA30EBBA203B9A103B7A008A68F1465510A2E22008A7F2F706510
665E0F7A74205F5704675D0BAEA11DA997127AA71800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
729B457C7A7C697581A8B2BF8A8E99B1B0B7ACAAB09C9AA0B7B5BB9B989EACA3A89C8F95
867D8B33375803104801104E02114342434A9E8742C19F1BC9A707C7A602C8A50DBF9826
B5904EB08E6DAE9078AF927BB1927DB59681B99981BF9D86C09F89C0A18BBFA08BBFA08B
C9AA95C9AC97CEB09BCBAC97CCB09BC8AE97CDB19CD0B49FCDB19CCFB59FD0B6A0C5B09C
AF9A88D4BCA8D4B9A5D6BCA9D5C0B0A49284D7C4B4D9C3B1DCC4B3E0CAB7DEC9B7DDC8B7
DDCAB9E1CCBADFC9B5E1CCB8E2CFBBE1CBB7E0CAB5E2CDB9E2CFBBE1CFBBE5D2C0E6D0C0
E3CCBBE0C9B7DFC9B7DAC6B8D7C7C1BCB1BA736E89665A7CAB7C97B74E5DC02128CE1317
D01013CC1114C11719C13D3BE0908ACFADA890899F362E5A944467AF1122C00710C0070E
B40C15C13C49BB4B63981B37AA0B1EB2020CB2030BA007138F36449A8892CFD0D99C9DAD
49385174395187192A9807129A07148A1B2AC48A96D5C5CACBCCCFC5CBD0C7CED5C5CCD4
CBCFD0CFCDB8B0A559B9A523BDA50EB8A002B69F02B6A108AF98148D780F917D17807012
615508665E1D696210716C0E9D951E9C90119F8A1352C10F00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
B4997F9699A196A5B6A9B6C39098A1B7BCC2A8AAAF9C9CA3B6B7BC949298BAB5BAA69DA3
918A9555587803114501114B0710394C4633AF9533C3A40FC4A502C6A802C5A405CAA41D
BD9642AF8C68AB8E7AAB907BAF937CB3967EB89880BB9982C09D87C29F89C09F88BFA08B
C2A691C7AD9AC8AE9ACAAD9BC9AB98C8AD98CEB39CCFB19CD2B39FD0B49FD0B5A1C7B19F
AD9A8AD2BDADD3BDACD3BDADCCB8ABAE9C8FD9C5B4D6C0ADDCC6B4DEC9B8DDC7B5DDC5B4
DDC7B6E1CCBBDFC9B6E3CEBBE2CCBAE1CAB6E0CAB4E1CBB6E3CFBBE4D2BFE3D0C1E2CDBD
E3CBBAE1CAB7DFCAB7DAC5B3DBC7B5D9C6BCD1C4C9989AB3494F78886A8CD16D7CC11F22
D01211D10F0ECE0E10C41416B62E2BDD948CDCC5CE3C3A5F7547729F1D35BC0915C2070D
BD050DB60911AE0713AE0816B0050FB4030CB4020BAA040F931B26885A61CFCDD1C7D0D9
9FA6BB382D49783D528A13209D0512990614881B2AC6909BD3C6CCC9CCD0C6CCD3C4CBD4
C8CCD2CACBC4B2AD82C3B663C1AC38B8A110B8A104BAA403B49B03B19908AE950BA68E11
6550047465216D631D444000958F26867D0E28E20654C51000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
BCA99777808D697B8F6B7A8987919A9DA3A99D9FA6B0B1B695959AACABB0979298A49CA3
867D89393A5904114208143E1F20207B6822C1A31EC4A606C4A902C6A900CAA804C7A215
B48C35AD8A64A98A76A88C79A98F79B1937DB6967EB9987FBC9B84BD9D87C0A18BBFA08C
C5AD9DD2C1B3D6C5B8CFB8ABC5AA9BC8AD98CDB19BCEB29CCDB09AD4B5A0D2B6A2D4BBAB
A59084C6B4A7CDBBADC7B4A5AE9C8DCAB7A8DBC7B5D9C4B2DCC7B7DEC8B7DCC2B1DEC4B2
DFCAB8DFCCBCDCC9B9DECAB8E0CBB7E2CCB6E3CEB7E2CEB7E3D0BBE5D2C0E3D0C0E4D1BF
E1CCB9E1CCB9DEC9B5DFCAB6DCC9B8D5C6BECBC2C6AEACBE736B908F688DE38194C6282D
D01311D3100CD10D0CC80B0AB91511B95145DAAFAC776E8A42315F9C3F5EB10E1CC0070F
C0040ABC060BB40B12A80C14A30716AB0514B1010EAD020B980911A5565DC1B7C3ABBDD0
7783A2443956753E54A83D489B0510A0020B980813882430D2ABB1CECACDC7CDD4C6CDD7
C6CAD5C6CBCFCCCEC5CFCEAEC7BB75BFAB36B9A414BAA307B39C02B59C03B09802AF9707
A38C0C9B87148270184C40039E922E897D1054CC1400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
CBB9A788919D798A9D83909EB0B9C0A2A6ADA1A1A9BDBDC48A8A8FC5C3C98C8990C4BFC6
918A95454866132146282A26806E25B99C1EC2A00CC2A30BC4A707C7A802C9A903CAA614
C19A36AE8A58AB8A71A98C76AA8D77B1937BB6987FBA9B83BC9C85BE9E88BDA08CC4AD9D
DDCEC5E2D9D5DFD6D2E6DAD3D3C1B6C7AD9BCAAC96CEB29BCEB29CD2B6A1D4B9A4D6BEAB
CAB5A4AE998CAE9A8DB39D8ECCB7A4D7C1AFD9C4B2D8C3B0D7C3B0DEC8B6DBC5B2DDC7B6
DFC8B9E6CFC1DFCBBADECCB9E0CEBAE1CDBBE3CFBCE2D0BBE3D1BCE2D1BEE4D2C0E4D0BE
E2CCB9E1CBB7E1CAB9DEC9BAD5C5BEB2B1BB72758F907491C87B95C54C60C2242FCC1418
D2100FD00E0ACD1108C3160AB32412C06451D1A69BBAACB835315A854D75A4192EBC0815
C0050EB2080ACF524FC1666E6B122F880B2DA70519AD020CA5050F93253658385A232C59
4B3E6784435D902434990F18A1020AA60108A4050C900C13985255D9C8CBC9CCD2C5CDD7
C4CBD6C3CBD4C6CED1CDD2C8B9B286BEAE56C3B13BBAA51CB8A00CB49C03B59E04B29D03
B19B04B29A08AB94117B670B7C6A1292841781B52100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D5C3B0848A985B6B7E6D7D8C919CA591949DADADB59E9CA49E9BA29E9AA29C98A09A949B
847E8743465C131C21746A2CBB9C1EC3A10DAD910F7D6601B49A10C5A605C5A208BC9615
B79234AF8B4CAD8A61AC8C70AB8B76B3927DB99882B79982BA9B86BD9F8ABCA292DACAC0
E1D7D3C7BBB7C1B2ABD5C6BFE3D3CBBFA898CBAD97CFB09AD1B49ED2B7A2D3BAA6D3BCA9
D5BEACD7BDACD5BCACD7C0AFD9C3AFDAC4B1D8C4B1D7C3B0D5C0ACE0CAB7DDC6B5DEC7B7
E1CABAE3CCBCE0CBBADFCEBBE1D0BEDECDBDE2CFBEE4D1BEE4D1BDE3D2C0E5D3C3E5D1BF
E4CDBBE2CCB9E2CCBADDC8BBCFC5C8536180676892B56B87B62332CE1A21D51418D41112
D0100DC60E06C32011D1553CDA866BE7B8A1CAADA1D5C6C6646280543B69982E4FB30C1C
BE0811B00B0FCF6466EFC5D0493057590F429A0B29AB020FAC030E99101F80395B1B0D3B
6F4C6F7A14279D0915A5030BA70208A70208A5070B950F0F7F3130D6C0C0C7CAD0C4CCD6
C4CDD6C0CAD4C0CBD3C5D0D1C8C9BAB9B488BDB371C7B864B7A336B19B15B39F0BB19F04
B4A104B6A003B8A005BAA410A9950FA1911A998B1F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
D3C0AA7F838D48586980909D8B959EA4A9B0B6B8BE8A898EC3C1C5827D83C7C2C7807B7F
B9B4BA494B54272708A59127C2A10CBFA011826906604D088C740CC4A50ACAA614AF8B16
B99430BF9B3ABA964DA98860AC8B75B3917DB99883B89882BB9C87BC9F8AC1AB9BE5D8D1
D2C6C2BAA79FC0A99CC4B1A7E4D2C8C1A89BCEB19ECBAC97D2B4A1D4B9A8D4BAA9D4BBAB
D5BBACD5BAACDABFB1DBC1B1D8C0AEDAC4B1D8C4B1DAC6B3D8C3B0DBC6B3DDC8B5E1CCBA
E0CCBBE0CCBBE2CEBDE3D1C1E1D0C0E1D0C1E1CFBEE4D0BFE7D2C1E3D0C0E3D0C0E4D1BF
E3CFBCE2CDBAE2CDBBDFCABECBC4C83D4F74656897A85A75C2232ED41519D71013D30E0D
CE100BBC1005E55948F49D85DBAB94DFC5B1C8B2A5C1ADA6A198A53830598A456EA31126
B90611B70A0FAC2B31E0A9B545365C3A124A850D38A80315AE020DA00514A13B5237173D
553D5F792337970915A4030AA70108A404069E15119B4033A2766FCFC6C5C6CCD1C4CBD5
C2CBD4C1CAD3C1CAD3C6CFD8CAD0D5CACFC9CBCFBFCFCFB8C6BF95B8AA5EB0A233B3A61E
B1A313B3A30CB7A508BAA807C1AC1596821284751700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C7AF9693959B6877886C7D8C7C8995A4ADB5A0A5AA979A9FA8AAAE918F93A7A4A8837D80
A0999B4E4A41564C0EB89E1EC0A00AAC8F10594404604A07A5870DC7A407C8A40EBB9713
C49E1FC8A221BB9738AC8C5CAC8E76B08F7EB79683BC9B87BF9F8BBEA18EC0AC9EE7DBD5
CEBFBABEA99DBFA799CEB9ADDCCAC0C8B2A3D0B5A0CFB39CD1B49FD3B8A4D1B7A4D4BCA9
D6BFADD7BCADDBC0AFD8BFACD4BDA8D9C3AFDAC3B2DBC5B4D7C2B0D8C2AFDDCAB4DDCBB8
DBCAB8DFCDBCE0CDBEDDCCBDDECDBDE0CEBEE4D0C0E6D0BFE6D0C1E7D1C3E0CBBDD5C0B2
E5D0BFE0CABADEC8BADDC9BBD9CAC88589A3394674A684A7B14251C31C23D31417D30E11
CF0E0EC8120EC11F1AD35D51E59C8DD6AC9ACAAFA0C4AEA2BEACAE5049695D396794233D
B40A17BA070EA90E14C56C72C4A2B74D2C596E0B3DA3071FAF020EA9050E9718285F2748
261A426C415C821928990811A5030AA005089A2521D59F95CEBFBBC9CDCDC6CDD3C4CDD4
C1C8D2C0C8D3C0CAD4C6CFD9C5CDD7C7D0D6C7D0D4C8CFD2CBCDCBCCCCB9909168969955
959640ABA63CB2A625B5A611BDA811B39C19826D1482B21E4FBE0F00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
C4A786A8A5A857647555657586939FA8B2BB878F93B6BABE929398BAB8BD8E888CC0B6B8
8678729C8B6890781CBA9D13BEA111806409664E0C876D0DC3A112C4A008C29F17B39216
BF9F1DC3A01FBC973DAF8D61AB8B73B18E7DB18F7DB99A86BA9B87BC9F8EBCA698E2D5CE
DCD0CBBEAEA6C8B6ABDFCCC1CCB5AAC9AE9FCCB19CCFB59FD1B6A1D0B4A1D1B6A3D4B9A7
D3BAA7D4BAA8D7BDABD4BCA6D8C0AAD6BFABD8C3B1DCC6B7D9C5B5D7C5B2DBC9B5DBC9B5
DAC8B4DFCCB9E0CCBBDFCCBBDECCBAE3D0C0E4D1C1E6D3C2E4D1C0E6D3C2E3D0BEDFCCBB
E2CFBEDECBBCDECBBCDDCABAD9C7BCD0C5C881859F505277A47F9BB45262B7232AC71619
CE0E13D00F12CC1113BF1515BA302BD97B71EAB9ADDBC1B4BEAAA38C83933425508B3A5E
A91020BC0911B2090EBC444BFCC1D0915B7B720F399E061FB0030FAE040C9809148F4157
766786443A5A75425B841D2B980A149D050C8E0C11A95E5FD8BEC0CCCACDC5CBD5C2C9D3
C2CAD3C0CAD3C2CAD6C4CCD7BCC6D0C0CAD3C4CED6C2CCD5C4CCD6C6CDD2A9B3B59EABA3
B3BDA5B5BB92BAB772B5AC41B8A621C0AA1BA4900BC1AB2283AC1600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
94BD64C3BDBF6E7C8D677B8C9DADB99DA8B191969CACADB29A989EB0ACAF978E8AB7A798
8D784FB99E4CB39419B99A129A8008AA9230654E00B3971AC3A10BB99513A88728A68938
B4963CB89942AD8C54AC8A6EA98975AE8E7BB09280B39684B89B89BD9D8DBDA193C9B5AC
DDCFC8E1D3CBD9C8BECCB5A8C9AE9ECBAF9ACFB49DCBB09ACFB49FD1B6A1D2B7A3D3B8A5
D3BAA6D6BEABD2BDABD1BDA9D5C1AFD9C3B1D8C1AFDCC4B4D8C1B1D7C2B1DBC6B4DBC6B1
DCCAB4DDCBB9E1CEBFDFCCBCE0CFBEE5D3C4E8D6C8E8D4C6E5D3C4E6D5C5E4D3C3E3D2C2
E1D0C0E0CEBFDFCBBDDCC9BADCCABAD6C6B8CEC3BFA59FAE645F7D7E6883B77484AE373D
BC1A1DC81315CB0E10CC0E10C41011B51C1AC95E5AE1A79BC7A89AB9A9A94842616F3F69
9B1C34B80A16BB050EAD0F19BF3D4EA72B419E0F26AB0515B2030EAE020B9E060FAB4959
C2A6BCACAEC354496573455C832131930C189908118A0F189C505BD8BBC4CAC9D0C3CAD1
C0C9D1BEC8D1C2CAD6C7D0D9C5CFD8C1CBD3C5CED5C4CDD5C4CCD7C3CBD799A3B2344451
727E776C7362919780929261B3A84BBAA823BBA914C3AF18BB9E2200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
60CF40D5CBC95B66766173848695A379838DB1B5BC959499B0AEB0A7A098BDAB8DA9904E
BB9B35BB9817BD9B12A688125A44016A57128B7208AD8E09C3A10DB08C16B18C3FA78653
A2835AA58764A78A71A88978AA8B7BAD8F7EB08F7EB69685B99A88BE9E8DC09F8FBFA393
BFA698C3AC9DC5AF9EC6AD99CCB19CCFB69ECBB19ACDB29DCDB19CCDB29DD1B4A1D0B5A0
D3BBA6CDBBAABBAC9DB7AA9BCCBCADD7C1B2D8C0AFDEC6B3DAC2B0DAC3B1DCC6B2DBC9B2
D8C8B2DDCBB9E2CDBFE0CCBDDECBBCDFCCBEE2CFC1E5D2C4E5D2C5E5D2C4E6D3C5E5D3C5
E3D0C3E0CDBFDECBBDDCC9BADBC8B7D9C6B5D7C6B4D4C3B9C6BBBF8D84985F516A9C7185
AE565EA82B2DBA1C20C71214C90D0FC50F0FB91817BE4D44DEA193C8ACA583788C432B55
973856B0111EBC080DB6040BB30814AF0713B20710B1030BAF010AAE0309A9060F951424
844B61C5BFCEBCBCCE5F546E6F465F822C3C8E0F189708148B0E1E9A4E5BD3B9C2C6C7CD
BFC8D0BDCAD2C2CCD5C9D3DCC7CFDAC8CFD8C7CFD8C0CBD4C1CCD6C1CCD798A4B44C596A
586262828A7F8D9590949789AEAA76B1A73DB5A71FC0B027BDA43125DB0800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
59C632DED0C88189987E8EA081909D8D97A0AEB4BA98999DACAAA8ADA38ABCA75EB39820
BA9C0CBC9B08B29212705807533E02796007BA9A13C3A00AC29E0FB38B1AC29C46AC8A54
A082689F8273A28578A58879A88B7BAA8D80AB8D7FB49584B89986BC9E8ABD9D89BE9E8A
C2A491C7AB97C8AD98CBB09ACCB09BCBB19AC8AF96C7AE96CBB199CDB39CCFB4A0D0B4A1
D2B9A8B3A294AEA195AC9F92B5A596D4BEADD8BFAED9C4AFDAC6B2D8C5B2D8C6B2DBCAB6
DBCAB7DDCCBBDFCEBEDFCBBDE0CCBEE3CFC0E5CFC1E6D0C2E5D1C3E4CFC1E5D1C3E7D4C5
E6D2C6E4CFC4E2CDBFDDCABBDAC7B7D8C5B4D8C5B4D7C4B5D3C2B7D2C2BFB9ACB5796C80
6D576DA27587AE5D67AD262AC21416CB1011C71010AF1611D3776BD2AAA0B8A6AE4E3E5D
8245609E212CB31519AF100EAD1010AA0F0EAD1010A90C0DA90C10A7090FA80A119A0F1B
883B4CB9ACB8CDD1DBC2C5D4685F7967455D7F2E418B0E1C950616860C1BA15C6AD0BFC7
C1C6CEC0C9D2C4CDD6C7D0D9C8CEDAC5CCD9C5CED8BECAD6BDC9D5BBC8D2B2C1D09BADBF
9FB1BFA2B0B6A4B0B5B0B9BAB5B9A6AAA86FB4AE5BC6BF72A89B59628D2300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
2ADF14DCCABE8F96A64D5E725D708099A7B0899197ABACB0AFAA9DB2A36AB39B29B89B0A
BC9D05B6990D8F770D7C67187F6501BC9B16C39F07C4A009B69219A58031A7844FA28160
9F8172A08078A48378A9897CAA8B7FAD8E83AE8F81B09382B69987BC9D8BC09F8BC5A691
C9AD98C9AB96CAAD98C9AD98C5AA94C5AB93C6AC92C6AC92CBB199CCB29BD0B49FD1B6A3
D4BCABA39183C4B6A9BCAF9EB9A896D3BFAAD5BEAADAC5B3DBC7B5D7C5B1DAC9B4DAC9B4
DDCBB8DCCABADCCBBBDDCCBBDFCEBCE0CFBDE0CEBEE3D0C1E5D1C3E2CFC1E6D3C4E6D2C4
E6D0C3E3CEC1E1CDBFDECABADCC8B8D7C5B5D7C6B6D7C6B6D3C3B3D5C4B7D3C1B8CFBEBE
9D91A15650695D4F6CB17386AE252FC51115CB1010BA150FC35A4DD7A99EB4A3A4ADAAB6
C2ACB5B37273BE625BBC5F51B85E51B05847AA5246A84E46A54843A442429C383C8B333B
804C56B9B5C0C6D0D8C8CFD5C9CAD77772875C415B7D3045890B1C9307167D0F1EB88C95
CCC8CEC1CBD1C3CDD6C7D0D9C8CFDBC6CEDBC2CCD8BFCCD5BFCDD6BECBD5ABBACE49617C
3B547457708667798587939A88908E969A86A1A587AFB49F7B7B71604D3900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00DAC2B0ABADBA4B5A6D6E7E8C9DA8B38D939AAEAEACB3A886AF9A40B29810B99A06
B7980B9B81135644005441019A7F0AC2A00AC4A005BF9A13A7842C9D7C55997965997C6F
9C7C77A17F7BA4827AA6857BAA8A7FAC8C80AC8D7FAD907FB89A89BE9E8CBF9F8BC3A791
C3A890C8AA94C6A792C4A590C2A58FC3A891C4AC92C9B096CFB49DCCB09AD0B59FD1B7A1
D3BCA7B9A491A59484B3A491D3C2ADD4C0ABD3BEA9D8C3B1DCC7B6D6C1AED9C7B1DCCBB7
DAC9B8DAC9B8DDCCBADDCCBBDFCDBCE0CDBCE1D0BFE3D1C3E4D0C2E4D0C2E6D4C5E3D1C2
E3CFC2E3D1C4DFCFBFDCCAB8DDCAB9DCC9B8D6C4B3D7C6B7D4C3B4D6C5B6D4C1B2D3C0B2
CFBFBEBBB6C54B51735D4D6FBB5B6BB9191BC31710B52113C76D5DDFBCB1ABA4A85B6A7B
BCC5D1CDB7B9C99E96C39A8DC19F95B69B92D6C0BADDC8C7C4ADB0D9C0C7AE99A5564859
817F8F566877B9CDD6C6D3D8C9D0D5C8CDD862637D563A587C23378C071588081588414B
D1C3C9C3CAD0C5CFD8C5CFDBC6CFDCC6D0DAC3CBD7C1CDD6C0CDD6BDCAD5B6C1D42C405D
415776475C726E7E8A8F9BA1929B9C999D989EA2998C91926D6F7C4E404400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00D0B39ABCBCC64F5D70788697707886A7ABAFA4A08CAF9F58AF961CB69907B89908
A0840E5B45005B480E998320BA9A0DC3A005C19D0EAE8C2398794594776694776F967772
9E7B79A5817DA5827DA4827BA9887EAB8B7FAB8E80AE9284B5988BBB9B8CBC9C8BC3A390
C8A895C7A894C1A58FC4A891C5A993C6AD96C9B099CCB19BCAAE99CEB39CD2B8A1D2B8A2
D2BBA6D2BCA7CFBAA6D3BEA9D2BDA8D2BDA9D6C3AFD7C4B0DEC9B7D7C2B0D9C7B3DAC9B7
DAC9B8DBC9B7DDCCB8DECCBAE0CDBDE1CEBEE2D0C1E1D0C1E2D2C3E3D2C2E2D1C0E5D2C1
E1CDBFE3D0C2E0CEBFDDCCBBD9C8B6D8C7B6D9C7B8D7C4B6D5C4B3D6C6B4D7C6B5D5C3B5
CDBFBCB1AEBB4D5674766C88A86066AD352BBD442FCB6E56D49F8CD3B9AEC5BBBC6F7588
525A76907A8CA67378D09C9CEEC3C9BFA3ACAA96A3A999AA937F94877087725B764E3653
6E5D738D8B9CB8BCC6CCD0D5CBD1D5C9D2DB9BA5BD221F427E425A800C198A0C1475262A
D0BFC0C5CCD0C2CDD6C2CED8C5CFDBC5CFD9C6CED8C1CBD4C1CCD6C1CBD5BCC5D38392A7
96A8BEA3B5C49EAEB8A3B0B8A7B2B5AEB6BAB2B9BCB1BABF959AA8514C552FA01A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00C5A285D0CDD36371837A8999747C86B2B2A8A1955DAA9427B09709B59706B0920E
7860094D390377631690760ABF9E09C2A00BB1921C9A7C3C93776093766F9577749B7A7A
9F7B7B9F7C7AA07D7AA3817BA7857DAB8B80AA8C81AB8D83B49488BA998ABE9D8BC1A08D
C4A28FC1A08DC2A58FC8AE97C8AF98CCB39DCDB39FCCB39ECDB39ECDB19CD1B6A0D3B9A4
D3BEA9D2BDA8D2BDAAD1BCAACCB7A4D5BEABDAC3B3D7C2B1DCC7B6D8C3B1D8C2B0DAC7B6
DAC7B7DDC9B8E1CCBBDFCCBCE0CEBEE0CFBFDFCFBFDECFBEE2D3C1E0D0BFE3D0C1E5CEC1
E3CEC0E1CEBFE1CEC0DECDBBDAC9B8DAC8BAD9C5B7D8C4B6D5C4B4D5C4B4D7C5B7D2C0B5
BDB0AE77737C6E6E7EBCADB3CDA599D8A28EDCAA92D4AD97CCAE9EC8B2A6C1B0A7B4A9AB
6E667C7561798F55658E3241A33B4CA64053A34055A03D54A13A529E364C9D2F45962C3F
9331449E4F60AF7787D2AFBDD8CAD5CACAD658627B3B3D58825766751D217D1B1C7E4341
CBC0BEC5CDCFC3CCD6C4CDD7C7CFDAC8D0DBC4CCD7C4CED8C2CAD5C3CDD6C2CAD96E7C95
374F6E657E94687B8A7E8D9689939B8790978B949B969FA79098A748475533A72500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF006ADB50D7D2D3707E8F63748497A1A399956FA59232B0960DB29703B3980C846C03
6E59066B5400A28613B6980BC09F0AB795159A7C2E9074578D716A917572977977987878
9878779D7B799F7E79A98480AA847EA9877EAE8E82AC8C7FB49587B79987BB9D8BBE9F8D
C1A18FC4A694C4A894C9AE99C5AC95C8B19CC7B3A3CCBCAFD0BCAFCBB4A3CFB7A2D3BAA5
D1BAA5D0BAA7D1BBABD6C1B1D9C3B2DAC2B3D9C2B4D8C1B3DAC4B4D8C3B2D8C2B0DBC8B6
DAC8B8DCC9B8DFCAB9DDC9B9DFCDBEDFCEBFDDCBBCDECDBDE2D0BFE2D1C0E4D3C2E3CFC0
E5CFC1E1CDBEE0CEBCDFCEBBD8C8B8D5C5B5D8C6B7D8C6B7D7C7B7D5C4B6D5C3B7D1C0B3
D1C2B7C6BAB1CABEB9CDBDB1CDB9A8CBB6A3CCB6A3C6B29FC2AB9DC4AFA4C7B6ACDDCDC7
B7AAB1776C7C755D6EA066749A38439B2027A1161EA9141DAA0F18A80C14AA0D16A40B14
A10A179A0D1B9211248B2239A96579D9BAC7A9A1AE8E8995958386937370977771AB9D98
C7CBC9C3CCD0C5CED7C3CDD7C9D2DCC9D2DCC6CEDBC5CDDAC4CBD7C2CBD5C4CCDC6C7894
1E335653698257677A8B95A19CA3AD959CA49CA4AB9098A18288983D405066514800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0060CF41DBD1D0757E8E5D6C78949A8B958940AA9515AE9703B19804B399127F6700
A38B20A5890BB8990BBD9E07BA9C13A587298F72488E73668F7370907373957775967775
9A7B789D80799E7E77A3807AA8837DAA857EAD887FAE8C82B29386B59A8AB99E8CBEA18D
C1A291C5A795C7AA97CBAF9CC5AE9CC1B1A4D7CDC8E0DBDAE5DDDCD2C3BBCBB6A6D0B6A4
D2BAA7D2BAA8D0B8A8D1BAAAD9C2B4D7C1B3D9C2B4DAC1B3D9C2B2D5C2B1D5C3B2DAC7B6
DAC8B8DBCABADBC9B8DECABADFCDBDDFCDBDDDCBBBDDCCBBE3D1C1E3D1C1E1D1C1E2D0C1
E3D0C2E2CFBFE2D0BDE0CEBBDDCCBAD5C5B2D7C7B7D7C6B7D6C6B7D5C4B5D1C1B3D1C1B4
D2C2B6CFBFB2D0BEB2D2C0B3CEBCB0CBB9AAC7B6A6C4B3A3C6B0A3C9B5AAC3B1A7C9B8AF
BDAEA7BAACAAA0969D85768394707CA6676CA1484A9F2F2FA12220A41E1AA01C1A9D1E1A
9B1D1C981F22961D268D1A28811C2F894253D3B5BFCFCBD0C9C9CBC7C3C5C2C3C4C5CCCD
C5CFD1C3CCD3C5CDD6C5CFD9C6D2DEC4D0DCC4D0D9C4CDD7C3C9D7C0C8D3C0CBD7AAB9CB
8294AB99ACBDADBBC8A4AFB8A5AEB7A7B2BBB2BDC7B2BDC7ACB5C63F485C6C605D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0057C330DAC9C18488956B757A99976FAA9830B19809B29B06B19806B29710776003
7E6809AE930FB99B07B69B0F9B841B8F76408B715F8E736D8E726F927374947274947273
9B7978997A759D7F77A3837BA6837DA5837BAB8A7FAF8F82AF9183B39888B99E8CBFA491
C5A896C9AC9BCBAF9FC8B09EB9A898A79E96B4B2B3BDBFC4DEDEE0DAD1CBCBB8A9D0B8A6
D1B9A7D1BAA8D1BAA8D2B9A9D4BDADD8C1B3D6BEB1D8C0B2D7C1B0D8C6B3D4C2B1D8C5B5
DAC8B9D9C8B8D9C9B8DECDBCDFCDBEDFCEC0DDCDBCDDCEBDDECEBFE2D0C2E1CFC1E2CFC3
E3D1C2E3D2C1DFD0BDDFCFBEDFCEBFD8C8B8D5C5B6D5C5B6D5C6B7D3C6B6D0C3B2D0C1B1
CEBEAFD0BFB0CEBCAECFBDAFCBBBACCDBDAEC9B7A9C5B4A4C5B0A3C7B4A6C4B3A4BEB09F
C2B5A7BBB0A4CBC4C0DEDCDEB2A8AD9482849177798D6A6BB2827EC18F84C08E85BA8C84
C59B96C09699A0797F9369708E5C67824B5B795462C6C0C5CACFD2C5CDD2C5CBD4C4CDD3
C6CFD6C3CDD6C4CED7C3CED7C3D0D9C1D0DAC2CFD8C1CDD5C6CDD9C2CBD7C1CDD98DA2B4
5F7A935B768B70859376838E828C95848D96858D998C97A28B98A73A485B6E666A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D6C1AE9F9FA1737468908840AB9715B19804AE9608947B02AE92128F760E
715900B4980FB79B118E7D16534816847261886F6B8C726E907471927371977675987374
9A75759977739E7E79A2827CA6857DA9897EA9897DAD8E7FAF9283B6998BBA9F8EB89E8C
BEA290C0A491C2AA95BDA8959A8D7DC3BCB5DDDDDDB3B6B9D7D6D5CFC3BDCDB8A9CFB7A5
D1B7A7D3BBACD1BBACD3BDAFD5BEB0D8C0B2D7C0B1D8C1B1D8C3B0D9C7B4D5C2B2D8C5B7
D7C7B9D5C8B9D8CCBCD7CABCD8CCBDDACEBED9CEBCD8CEBCDDCFC1E0D1C1E0D0C0E1D0C1
E0CEC0DECFBEDFCFBEDDCDBEDFCEC1D8C6BAD5C3B6D4C4B5D3C6B7D2C5B6D2C3B3D3C3B1
CFBFAFCFBFB0CEBEB0CCBCADCBB9ADC9B9AACCBCADCABAAAC8B6A8C3B2A3C2B4A4BEB1A1
D9CEC1C4BAAFBAB2AAC1B9B5B2A7A4AFA59DC1B9B5C5C1BFBAB2B3D9D1D1DCD6D8AEB1B6
C6CBD2949DAD3E4D64AFBBC8B6B3BE857B89635A6D848791C7D0D7C5CFD6C7CED6C3CCD3
C4CDD6C3CDD7C2CCD6C2CED7C3D0DBC3D1DCC1CED8C2CCD6C4CED8C2CCD7C3CEDB6D8096
3852712B4660697F906C7C869AA4AD9DA4AD979BA6939AA389909E424E626B686F2C9E16
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D3B897BDB6A5827C4EAE9F37B4A00FB49B04B29912755B00A88E18B3960D
B39509B89A0C9B851A342F043A3A347E7072856E6F8E72729173749071709677759C7A78
9C79759C7B76A07F7AA5837DA28079A6857CAB8C81AF9183B49788B49888B89B89BDA08C
C1A58FBEA28CC0A790B7A39096897CB2AFA8B7B8B89C9C9CBEB7B2C4B3A7CDB6A5CBB49F
CDB5A2D1B7A7CFB9A8D3BEADD5BFB0D4BFAED5C0AED5C0ADD7C2AFD8C5B2D3C0B1D3C3B6
CBBFB5BFB7ADAAA39AACA49DC2BBB2D3CDBFD9D1BED8D0BEDBCFBFE0D2C2DFCFBFE1D1C2
DFCFC0DECDBFDECDBFDDCDC0DECDC0DAC8BDD9C8BCD6C8B8D5C5B6D6C6B7D3C3B4D2C3B3
CDC0B1CFC2B5CEC0B3CBBDB0CBB9AEC9B7AAC5B4A5C5B3A5C5B3A5C5B3A5C4B2A6C0B0A5
C0B1A7BEB1A6B9AFA6B7ADA4D0C8BFBBB7AFC7C6C2D8DBDCCBCED2B9BCC1BDC5CE495D6F
63768963748B132D4E7993A9C6D4DFCAD1DB949CAB516070BAC9D3C3CFD6C7CFD6C6D0D6
C4CED8C1CDD8C2CCD6C3CDD7C5CEDDC4D0DEC5CFDBC2CED9C2CCD6C4CED8C2CDD692A2B2
7C90A48DA1B2A2B4C2B0C1CAA8B5BEABB7C0ADB6C0B2BBC3A9B3BD5C697B6B6D782EA11D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00D0AC7DCBBA8D93842FAB9816B49F0AAC9504B0960F7C62059F8515B59807
B99905B498186257140D13133E3F517D6E75866D6F8E70729272779474799575789A797A
9B7977A07F7BA0827CA5877FA5847DA7867FAB8A81B09084B5988AB69B8BBC9E8FBE9F8F
BC9F8DBFA38FBFA48EBEA7938D7F728E867F918A87817974AA9D91C9B5A4D0B6A3CFB6A4
D3BCAACFB8A6D1BAA8D3BDACD1BEACD1BDABD8C1B1D7C1B1D8C4B2D9C6B5D5C5B6BDB2A8
978F899E968EA89F959F958F807B789C9991D1CCBDD7CEBCDDD1C0E1D0C2DFCEC1E1D1C4
E0D0C2DFCEC0DDCCBEDDCCBFDDCDBEDBCCBED8CCBCD1C6B5D5C7B7D2C5B4D0C3B4D1C5B7
CEC2B6CDC1B4CDC1B2C7BAABCEBFB2CBBBAEC2AFA3CCBAACC9B7ABC6B3A8C6B4AAC6B3AC
C2B1A9C3B5AAC5B9B1B8AEA6DDD7D1D2D0CCB0AEABBFC2C3A8ACB294969CAFB4B96B7988
6A7788BFCBD998AABD99B2C5C0D5E2C4D3DCC8D6DDA7B8C0B9C8D1C3D0D7C6D0D8C6CFD6
C5CFD8C3CFD7C4CDD8C3CCD7C3CCDBC2CEDAC3CDD9C4CED8C0CBD6BFCBD7BFCCD79EADBB
7A8EA36F879B74899A7A8D9A818F9987939C89929C8089927F8895536376646A7963493D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00C79A58C9AF61A9951CAE9B0BAB970D8B7701A38C11866D0C8F780DB59908
B5970999852128290E0711294A4B627F6E76866D6F907273917274927476947677987879
9A787A9D7E7D9E807DA1837EA48580A88883AB8983AE8B84B19389B89B8FBC9E91BD9E91
BA9A8CC2A392BFA28FBEA5919785779A8C80A59589AE9C92A29082CBB6A5D0B6A5D1B8A8
D2BCAACEB8A7D0B6A7CFB7A7D1BBAAD6BFAFD7C0B1D5BEB0D9C2B4DAC5BAC7B8B089817B
ACA49EC8BEB3C6BAACC4B8AEA19996767471A8A89ED5CFBFDACFBEDED0C1E0D0C4E1D0C6
DFCEC4DFCEC2DBCCBEDACCBEDACCBDDBCDBDD6C9B9D3C8B8D2C6B5D2C6B6D1C5B7CFC3B6
CFC1B8CCBEB4CFC3B7CBC3B4CBC0B5CDC0B3C9BBADC9BAABC4B2A4C4B2A6C2B1A7C7B5AB
C1AFA5C6B8AFCFC2BBB9AEA6BBB1ACB2ABA8ACA8A3ABABA6CECFD0C3C4C7C1C3C7D1D7E0
B1BDCA9CADBAA8BDCF3F607C99B8CFBFD2DEC2D2DAC2D1D7C6D3DBC5D1D9C7D0D9C6CFD8
C6CFD8C3CFD7C3CED7C2CED8C1CDD9C1CDD9BFCBD7BFCDD6C1CED7C2CCD7C0CBD8A6B4C6
3F5571435F79455E7081929F94A0AAAAB5BBA3ACB499A1A88B94A05666795C66756A554C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0065CE21C8A83AAF9910AA980C8172056B5B009B87147E6A0E79660BB2980D
B59B1F867A390F151B08133653536C7F6F77866E718D707391737691737596787A98797B
9B797CA28081A17E7DA2827EA2857DA98B85AB8C86AF8E87AE8F85B5988CB79B8DBA9E90
BEA290BFA18DBC9F8CC0A594978274B5A596B7A796A89686B3A090CBB6A3C9B4A3CAB5A4
D2BDABD4BDACCFB7A7CEB5A6D3B9AAD4BDADD3BCACD2BDAED8C3B6D7C4BD9C918F86807D
B7AFA9C7BEB4C7BEB3C7BBB4ABA0A07E7C7B888880D5CFBFDDD1C1DED2C2DECFC1E0D0C3
E1D3C6DDCEC1DECEC2DCCBC1DDCCC2DCCCC1D8CBBED2C8BBD2C8BAD2C5B8D2C5B8CFC3B6
D0C4B9CCBFB6CBBFB4CBC2B6C8C0B3C6BDB3C4BAAFC3B8AABBAB9DC3B2A4C2B2A7C0B2A7
C1B1A7BDB0A5B7ABA3B5ACA5AEA6A2CCC9C8D2CFD4AEACAFD8D4D8DBD5DAB2ABB1B4B3BD
6371872F44617F92AA203D5B6E91A8BFD5E1C0CED697A5AAC8D4DAC6D0D9C7D1DAC5D1D9
C5D0D9C0CDD6BFCBD6BFCCD8BDCBD6C1CED7C2CDD6BDCBD4C0CED6C1CED6BFCBD7A4B2C3
879BB271899F95ACBAA1B2BBB5C2CAA8B6BCACBAC0ACB8BEA7B2BD697A8C54627270625E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00C39F19B39B0C95840A5A4E005143009A86168C750B8D7609B09712
B49F3D877E610A112B09123A605F757E6E75856E708C6F7491717896767C97757B9B787E
9A76799E7A7B9E7C7AA1807BA68883A88B87A98B86AA8A84AD8D84B4978AB89D8FBCA193
BEA290BFA28FC0A391C2A595AC9284998676A09080A49081C4AE9EC4AFA0B4A196AC9C8F
C7B4A4D1B8A7D5B9ABD3B8ABD3BBABD2BCABD3BDAED6C2B4D8C3B8D7C3BD877B7B878383
AAA6A3B8B2ACBCB6B0B0A9A79894967A7B7B898981D3CCBCDBD0BEDED2C1DFD0C1E0D1C3
E0D3C6DDCFC1DECEC1DACABFDAC9BFD9CAC1D4C7BED5C8BFD1C5BAD3C6BCD0C2B9CFC5BA
CBC1B7CCC2B9CDC0B7CDC1B6CAC1B3C4BBAFC2BAAFC2BAAEC1B6A8C0B3A3BFB1A6BBB2A7
BBB0A7BAB1A7B3ADA8CDC9CB9E96A3978B9FA48DA4936F83B58995C2949CB88F93B8A0A3
9292A24C5A71A6B5C5A3B3C49AB2C3C2D4E0C8D4DBBCC7CDC7D2D8C7D2DBC6D0D9C6D0D9
C2CFD8BDCBD4BFCCD5BDCAD3BDC9D5C0CCD8BFCAD6BCC8D4BFCBD6C0CCD6C1CAD7ACBACB
7D92AB758FA46E85957D8E9A7E8C957F8B94838E97808A947D8692606F814D5E6F786F6C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0092B80DAF9B0F7B6F025D5201796705A7910DAC9509AD960EB19C27
92844368665F0B15380A163E6765797D6D7189727390727794737D96747D99767B987478
9B797C9C7B7A9C7B79A38481A48784A68886A98984AD8B83B18F84BB9A8EBC9D90B89B8C
B99B89C0A18DBFA28EC0A38FC6A796BB9F8FB9A190C3A999C6AD9CB9A597A4948CA7988F
B8A597D0B7A6D7BCABD1B9AAD0BCAACFBDAAD3C1B0D6C3B4D6C3B7D4C0BA897C7B827D80
8F8E919896999998999290937E7F837475749E9B91DAD0BFDDCFBEDFCEC0DECEC1E1D3C4
DFD2C3DDD0C2DCCFC0DACCBFD7CABDD4C8BDD5C8BFD3C6BDD2C5BCD4C6BED2C4BDCEC3BA
CDC4BBCDC3BACFC2BACDC0B6CDC1B6C8BCB3C4B8B0BFB5ABBFB4AABBB0A7BAB0AAB7B2AC
B6B1B1ACA7AE8D8595826E888253719A4C6A9E334EA4263CA21C2DA21F2D9F2C35AE5B63
E5BCC7D7CCD99096A3ACBBC87D94A7B9CFDDC9D6DFC8D2D9C8D1DAC4D1DAC4D1DAC4CED7
C3CED8C0CDD5BFCCD5BDCAD3BCC9D2BFCDD6BFCDD8BECBD4BBC7D3C0CAD6BFC7D8A1AFC3
213A594D6986536D8470839395A2ADA2ABB6AEB7C1A5AFBA868FA13E516A44576D7B7778
2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005FD00AAB9A13706200716101A08B0DAE9706AE9604AB9512C3B35E
8A81638A8C941922481019426F697D8572758D747590737792737A94757A95787B997B7E
9A7C7E9B7E7E9C7E7DA28582A48683A58684AA8984AA8981AD8E84B7978CB6968AB7998A
B89B8ABDA18CBEA28CC1A58FC3A793C3A694C5A996CAAD9AC8AE9BB9A4959E8E83A9998D
C3B09FCCB49ECFB5A0D3BDA9D0BDA9D1BFAAD5C4AFD4C3B2D2BFB1D5C2B6AB9B96776E6F
7C7A7F7F7D847E7D81797A7D727170847E76C5BAADDBCEBDDFCEBFE1D0C2DECFC2DED0C3
DACDC1DACFC1D9CFC0D9CDBFD5C8BCD4C7BECFC5BBCFC5BBD0C6BBD1C6BDD1C4BDCEC1BA
CDC2BCCDC2BCCDC3BACAC1B5C9BFB5C6BBB3C2B8AFBFB7ADBFB7B0B9B2AFB4AEB4A49DAB
81728B7C5C7B925576A54663A5243BA80F21B20A19B40814B60611B60711B00811A00C17
A2303FB26D80523D5372798E5D7288ACC1D1C9D6DFCAD4DBC6D0DAC5D2DCC6D2DBC5CFD8
C2CCD5BECBD4BECBD4BBC9D2BCC8D4BDC9D5BECAD6C1CBD5C1CBD7C3CDD7C1CAD7B7C4D5
374C68839BB48DA4B7A0B1BFB3C0CCB9C3CFACB8C4B0BCC89FADBF2D415E344663797A7E
32A72200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF005DCB0D9A8409776703907D0EAD9609B09803AE9504B09920AA9C5C
8B857A64677809143C182047787085856F798D74788B6F749173798F717594787B957A7C
997B7D9C7D7E9D7E7D9F7F7DA48482A58482A6847EA8887FAC8F85AF9388B29589BB9C8F
BE9F8FC2A691BEA48DBDA38DBEA38EC7AA95CAAB97C8AB97C8AE9AC6AE9ABEA896C0AD9B
CFBDA8D5C1ABD6BFABD4BEABD0BEABCFBEA9D2C2AFD1C1AFD2C1B1D4C2B3D1BEB39A8B85
7E757580797A8A848298908B9B9188C0B2A5DBC9BDDDCBBEDECDC0DECEC1D9CABDDBCDC1
DBCEC2D8CCC0D8CDC1D7CBC1D7CBC2D4CBC1D0C9BDD4CBBFD1C7BCD2C7BECDC2BBCEC3BD
CDC3BDCBC2BBCBC2BBCAC2B8C9C1B8C4BDB7BFB8B5BBB6B5B5B0B69E97A57D6B85815978
A05574AB3B58A71A32AF0E1EB70A15B9080EBA060EB6030BBA030DBB050DB70309B2040B
AB08169B16269B5062907E8DC2CAD6BFCED7CBD5DECAD4DDC7D1DBC6D0DAC7D1DBC5CFD9
C1CDD6BECBD3C0CAD3C0CAD2BFCBD4BDC9D4C3CDD9C2CCD6C0CDD6C0CDD6C0CBD6BAC8D6
74859A899EB37E94A47E909C8C97A387919B848E9A848E997A83962B3C582F3F5B74787F
4C7D3500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6F03806C02A18D0EB09905B09702AE9404AF9929978A58
B9B6B45D637A07133D22294F796F82836F788B737A8A6E738D6F749072749376799A7B7F
99787D9D7C7F9E7C7DA07E7DA28281A88886A6847EA88680AC8C84AF9186B09387B79A8A
BDA08DBCA18CC0A791C1A590C1A590C6AA95C6AB95C5AB93CBB09AC8AD98CAB19CCEBAA5
D0C0ABD1BFACD7C3B1D2BDACCCBAA7CFBEABD2C0B1CEBCADCEBCADD1C0B0D9C6B6D2BFB2
BBA89FB0A096C1B3A8C9BAADD3C3B3D8C7B8DCCABDDBCBBEDBCBBEDBCDC0DACCBFDACBC1
DACDC4D8CBC2D5C8C0D5C8C1D6CAC4D5CCC4CFC9BED1C9BED1C9BFD0C9BED0C7BECDC4BC
CBC2BCCCC5BECAC3BFC4C0BBC2BFBFBDBBC0B3ACB990859980668196637EA9526EAC324A
AE172AB70E1CBA0A15BA0B10BB0C0EB70D0EB30C10B10C13B30710B7070EB9050AB7040B
B5040EAE09149A1F2AC0868F9E959EC7D1D7CFDAE0CBD7E0C5D2DBC5D2DAC5D2DBC3D1DA
C1CED7BFCCD4C2CCD4C0CBD1BDC7D0BFCCD4C4CED8C4CED8BFCBD6C0CDD8BFCDD9A6B8C7
6D839B27445D6D8A9F7A909F98A5B29FABB4A9B2BCAAB2BE9CA3B7303F5E293A56697076
6B5B4F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF008B6C02A38E0BAC9706B09A02B09804AB930AAA97379F9573
8F8D925C617B08133D2C33567A73828370778870768B6E768E6F7592737994757B99787F
9D7C819F7D81A07E7FA28081A28281A38380A6837DA9847DAE8B83B6948BB4948AB6998B
BD9F8EBDA08EBDA28EBFA390C3A694C5AA96C7AB96C5AB95C8AE97CBB19CCDB4A2CDB8A6
D1BDACD3BFAED3C0ADCDBBA7CFBDA8D2BFADD2BDADD3BDAED1BFAED2C3B0D6C6B4D5C4B4
D3C1B3D9C6B7D9C8B8DBCABADAC9B9D8C6B7D9C6BBDAC9BCDACABCDACABCDACBBDD9CBC1
D5C7C0D3C8C2D6CBC5D6CBC5D8CFC8D3CDC8CCCBC8CBCAC6D1CAC4D3C8C0D4C6C1D1C2C0
CEC1BFCBBFBEC8BBC0BAADB7A392A294788E9B6C88A9607DAA4059A72134B11523BB121B
BC0F15BC1113B71311AF1812A91F17A72B23A73733A5393DA2252EA91019B4060DB6040A
B60208B40409A50A11A138417A5863BCC3CBCCD8E0CEDBE1CCD8DEC6D4DCC2CFD7C4D0D8
C5D0D9C2CCD6C0CAD3C0C9D2BEC7D2BCC8D1C4CED7C2CFD6C5CFD9C2CFD9BDCAD6A4B7C8
6C849D435F7887A1B49AAFBCA1B0BCB1BEC9B3BFCCAAB5C3A1ACC0384B692337535E6A6D
6D635600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00709702AD9508B09B05AC9905B39F19AB9927998B42C8BFAA
7B7A818A8FA708143A363E5B78727D816E758970758F7177906F7795737B97757C99787E
98787B9A78789F7D7DA07D7EA38182A28180A7837FAB857FAC8880B3928AB7998FB99C90
C1A192BFA18EBFA38EBFA38FBFA593C6AC98C7AC98C5AA94C8AF98CEB6A1CDB6A4CBB4A3
D4BEADD0BDACCEBBA8D0BBA8D2BDAAD3BDABD0BBAAD4BFAED1BFAED2C1B0D5C4B5D7C5B7
D4C2B4D7C5B7DBC9BCDECDBFDCCBBDDAC8BADBC9BBDBCABCD9CABDD8CBBCD7CBBDD3C7BC
D3C5BFD4C9C3D4C9C3D5CBC4D3CBC7C5C5C78E9CA9A4B6C5CAC8D2D1B9BCDFB8BBE2B3B8
CF9BA4C08896B4768AB66A81B85A72B64359B42C42B31B2BBB171FBC1315BC1716B51813
AE2019AE3328B54D3FBE6F5FCA8D7DC89788B68F8A6D505B794E639A3849A70C18B3040E
B60309B50309B0050E9A101899545FB5ADB5CDD6DDCFDAE0CDD8E1C7D5DEC6D3DCC3CED7
C6CED9C6CFD9C0CAD3C1C9D4C1C9D5BFC9D1C0CDD5C2CFD5C5CFD8C5CFD9C2CDD9AEBECE
7C8FA6748A9E8B9EAD7F909D808D9A7F8B97808A987E88957683932F405E24395457646B
6C665B16CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF005AC906AF9606AC9803AC980FAE9F34B6AA5EA2986AC1BCAF
7879808389A20711393D42607B727E846F768C727890727A92717A937179926F76947177
9874769A76769E7A7AA17D7FA58384A78584A5827FA9857FAD8982B3948BB79A91B89B91
C1A095C3A294C0A38FBCA18DBCA491C2A897C8AB9BC8AC98C7AD98CBB29DCAB29FCCB4A3
CFB8A7D4C1ADD4C2AED2BEAAD0B9A8D0BAA8D1BEAAD3C1ADD0BFABD0BEAED3C1B2D7C4B8
D1BFB2D5C5B8D8C7BDDACABDDBCBBDD7C7B9D8C8BBD7C9BDD9CCBDD9CDBDD5CABDD4C8BE
D9CBC3D9CCC5D6CAC4D5CAC4D4CBC7CBCCD065788F446287AFB7D4957182A95D6CB44F5E
B94656B83D4FB63347B42437B81F2FBD1D29C01A22BF1A1AC01D17B72015AB261AAE4032
BD6A5ACE9182C99B8CC1A293B59F91B29F91B1A19A8D86922D2745935A75941020AE040F
B4010BB6030CB1030CA50A119F4048BAA3AACED7DECCD9DFCED8E2C5D2DBC6D2DDBECCD4
C0CCD4C6CFD8C1C9D4C0CAD4C2CAD5C2CCD5C4CED7C4CED7C2CFD8C4D0DCC2CDD8B0BFCF
435A756E8BA36E88998599A59AA9B594A1AA96A2AE98A4B08D9AAA293B5B2A3F5B54616A
69645E2EA11900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE503AE9603AB990BA69625B1A761A8A37CADA99595938F
8E8E9859617B08163C484E697C737E826F768971778F737A92727A917078947278967378
9874769E79799E7A7BA07C7FA38183A58484AA8785A78481AE8C86AF9188B79A90B79A90
BF9E95C09F91C3A393C0A292BCA090C2A896C7AB9BC9AD9CC6AB97C9AF9BCBB39FCAB3A0
D0B9A6D5BEACD2BFABCFBCA8D0BAA9D0BAA8D0BCA9D2C0ACD1BFADD4C2B2D6C3B4D7C5B7
D3C2B4D7C6B9D8C7BDD8C9BED8C9BBD7C9BAD4C6B9DACBBFD8C9BCD9CDBED7CCC1D7CDC3
DBCEC6D9CCC6D6CAC5D7CBC7D6CCC9D1CDCDB5BECC5E73945E6C93A392B1A56C829E4253
A6303DAA2834B62834BB252DBB2329B72523B62A24B33228BB483BC76858D48677D69E8D
CBA595C2AA9CB4A397AFA497AAA195AAA294ACA29BAAA8B0393E5E6D54768B2436AA0A16
B5040EB5030CB2020CAE081098242D9C7481C1C9D5CBD9E1CFDAE4CAD7E0C5D1DCC0CED7
C3D0D9C6D0D9C5CDD8C1CAD4C3CCD6C2CED7C5D0DBC6D2DDC3D0DCC2CFDBC1CED9BBCAD9
3F56735C7D994F6E8295AFBD99AEBD9CAFBFA2B5C7ACBFD0A2B4CB2035582D435F5B6870
645F5C32A61F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF002FE603B19B09AA9A1FACA55EA9A990969693BDBEC086878C
ACAEBA515C7519294B5259707C737E806E75866F768B71768D707691727797757B9A767B
9A76799C7878A17C7E9F7A7EA38081A78684A78784A78783AC8B84B09086B6998EB99C91
BC9F94C2A297C09F93C1A094BFA090C3A592C5AA98C5A999C8AD9CC9AF9DCCB4A0CBB5A0
D2BCA8D7C1AED0BBA9D0BDABD1BEADD0BCACD3BFAFD4C1B2D4C2B3D4C1B2D6C2B4D6C4B5
D2C1B3D7C4B8D9C7BBDBCBC0DACBBFD9CABCD4C6B8D8C8BDD7C9BED6CBBFD8CEC4D6CBC4
D8CBC4D8CAC6D9CCC9D7CBC9D4CAC7D6CCCBD0CACBC5C5D29BA2BA717792857C94A98B9D
B3828FBA7B86BF767CC87777D2827CD68E81DC9C8EDBA597D7AC9ECDAE9FC9B3A7C1B3A6
BAAFA4B7AEA4B2AAA1ADA69BAAA398AEA59CADA6A0D2D0D27F859F3131588D4D65990F1B
B1050FB2010BB2010BAF040D970C179D5B6A9696A6CAD9E2CDD9E2CEDAE2C8D6DEC6D4DC
C2CDD7C4CFD9C3CED8C5CED9C4CDD9C1CDD8C1CDDAC3D1DDC2CFDDC2D0DBC0CFD9BCCCD8
8699B453718D7799B493B4D17796BA5E78A25C73A0586F9D4B6293102554364C695A686D
5A595236AE2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CE07AE970BA89C3AA7A5809EA3A09EA2A8A3A6AD94989E
818590535C740A18395D62777D727D816E75856C748A70758F727794727899747B99737B
9C777C9D787A9D787AA07A7CA4807FA68480A6847FA6847EAA8981AF8E84BB9C91BA9C91
BB9F93BB9F93BA9D91BC9E91BFA190C4A491C8A996CBAF9ECCB1A2CEB4A2C9B29ECBB5A2
CFB9A8D3BFAED2BFAFD3BFB0D2BDAFCEBAACD1BDB1D2BFB3D2BFB2D0BCADD4C1B3D4C4B4
D2C1B3D5C2B5D8C5BADAC9BDD8C6BBD7C5BAD6C6B9D7C9BCD6CABDD5CCC1D8CEC6D7CBC5
DACCC6D6C9C4D5CBC6D3C9C5D6CBC8D4CAC9D0C8C6D3CBCACCC6C9CAC8CFBEBEC7B2B2BD
B1ADB5B3AAB0B8AAADC4B2B2D2BFB8CEBDB2CCBCB1C6B9AEC4B7AEC2B8AEC1B6AFBCB3AB
B8AFA8B8B0A7B4ADA3B3AEA2B4AFA4B3ADA4A8A39DAEAAA79D9EAE2A345872577A861A2C
A70612B0010BB2010CB0030CA309149B3E48CEBBC3CFD9E0CDDAE3CFDBE3C9D8E1C6D4DC
C6D1DBC3CFDAC5D2DBC5D2DBC4CED9C1CCD7C3CEDCC1CEDAC3D0DDC1CFDABDCDDAAEC0D2
8297B558749A31507E132F68031C5E01165C01155E00125B02145C011452273E63576871
5F615A5F4E3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0061CD08B29916AEA24F999A82A6AEAFB2B8C094979FABAFB6
8286926B748D0C1A396468797B6F79806C74886E778E727A92727A9371779571779A757C
9C757D9A75799C797B9E797BA27F7EA78280A5827FA5817DAD8883AF8E86BC9D94BB9D93
B99C8FBDA191BA9D8EBB9F90BFA291C5A593C8A896CAAB9DCBB0A1CCB2A1C9B19ECEB8A5
CFB9A8D3BEADD5C2B2D3C0B0D2BEAECFBCADCEBBADD2BFB1D0BCAED4C1B2D4C2B5D3C1B4
D0C0B2D1BFB2D8C6B9D8C7B9D7C7BBD6C6BCD6C8BCD8CCBFD5CBBED4CCC0D5CBC3D5CAC4
D3C7C1D0C6C1D0C8C4D2C9C5D2C7C3D2C8C5D1CAC7D1CAC7D2C9C7CBC5C2CBC8C4CDCCC7
CBC9C4CBC8C4C9C3C0C8C2BECBC3BDCAC4BBC8C0B9C5BDB6BFB7B2C0B9B2BFB6B3B7B0AE
B7B1ACB9B0A9B7AFA6B4ACA4B2AAA2AFA8A0ACA69FA9A5A0B0B0B65864833839648F4A64
9A0E1CAE050FB3020DB2020CAA05108E171EDBB0B4D6D6DACED9E2CBD8E2C9D7E3C7D5DF
C6D3DDC3D1DBC7D4DDC5D1DBC7D1DCC3CEDAC7D2DDC3CFDBC4CFDBBDCDDCB9CCE48CA5CA
29447807216000175F00125E01125F01125D01115D01115C01115C011359031749394C61
5C62615F544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0030E504B0971DA39A4E9799819AA2A39FA5ADA0A3AB9F9FA8
7A7B89565E7814213D6B6C7B7B7076816D76876E798B6F7A8C6C769573799874799C747B
9A70789E767B9E7B7BA38182A17E7EA4807FA78382A98684AB8784AF8D87B4968DB4978C
B4978ABB9D8EBD9F90C3A597BEA090C3A491C6A896CCAFA0C9AD9FCCB2A2C9B1A0CDB6A5
D0B9A9D2BDACD1BDADD6C3B3D1BEAED2BDAFCFBDAED3C1B2D2BFB1D3C0B4D1BFB3D5C2B7
D4C0B4D2BFB3D7C5B9D7C8BBD7CABED4C7BCD7CABFD5C8BDD1C7BCD4CAC1D3C8C1D4CAC3
D3C8C1D2C8C4D1C8C5D5CBC8D3C8C3D1C7C4D0C8C6D3CBC9D2C9C7CBC4C2CCC8C4CCCAC5
CAC9C5C7C7C4C6C4C3C4C1C0C5BFBBC8BFBACABEB9C3B9B2C2B8B4C1B8B6B8B5B99FA7B2
ADAFB8BDB0B0C0AAA7C3A8A5BEA29FBCA4A1C4B5B0B5AFABBEBEC0B1BCCF25325D806285
8B1B2CAB0913B2020BB1010BAE040F970B17BF7880DFD5D8D2D9E1CDD8E3C8D4E2C5D3DE
C4D2DCC3D1DAC6D2DBC6D1DDC5D1DEC4D2DDC6D3DDC2CFDBBFCDE2ACC2E06984B2142F6F
01196401166601126300115E000F5C01115C00105901115901105B011258010F4A0E1D41
545E655F594E15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00B09938908D58A6AB9DB1B8BC959AA4B2B6C09E9FAA
9291A14D546E2029447371807D6F7583717786707A876C778F707997757C9570759B7279
A1777CA47B7D9F7A7AA17E7FA38081A48180A48180AA8684A98581AD8B85B4958DB79990
BD9C93B9978CA9877BBE9B8FC1A092C0A291C4A997C9AD9EC8AC9CCAB09FC9B2A3CDB6A8
CAB5A5CFBBABD6C3B4D3C0B2CFBBAED0BBAFCEBCAECFBEAFD1C0B1D2BEB2D2BFB3D2C0B3
D4C1B4D2C0B2D6C5B8D4C5B9D4C7BBD5C8BCD5C7BCD4C7BCD3C8BED3CAC0D2C9C1D1C9C1
D5CAC3D3C9C3D1CAC5D2CAC3D2C9C2D1C9C3D4CBC8D3CBC9D1CAC6CFC9C4CBC7C3C9C9C8
C0C7CEB7C3D0A6AEC0AB9FB0D3AFB9DCADB2DCABAED8ABACD1AEAFC8B0B2B1A9B7384768
8182A1A47787B56670BB6066B75861B86269D6A0A2BCA9A7B0ACABA9AEB75563843F3D69
8C3E57A10F1CB3050FB1010BB0040EA3081298363FE7CDD1D1D6DCCCD6E0C7D2DFC6D2DD
C4D2DBC4D0DBC5D0DCC3D0DCC3D2DEC5D3DEC1CDDBB9CBE096AFD3314D84031D64011868
011265001263001160011360000F5A011159011158011058000F58000F56010E4D020F3D
3E4C5B5D5C532BA01700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00CCB67A80816E8690939FA5B0989DA8A3A7B29698A4
8687974A4E68252B45756F7E7B6C738573788670788A6F77907078927077977278987378
9F777CA078799E7978A37F7EA58181A48180A88584A88382AB8684AD8A85B5948DB79790
BD9C94BA988EB69489BD9B8DC2A291BB9F8DC0A593C6AB9ACAAF9DC8AE9CCCB4A5C9B2A5
C9B5A7CFBCADD3C2B3CFBEB1CBB9ADCEBBAED0BEAFD0C0B0D3C3B3D2C1B2D2BFB2D2C0B3
D4C1B5D4C1B4D7C6B8D9CABCD2C7BAD5C9BDD3C5BBD3C7BDD2C8BFD1C8C0D2CAC2D3CBC3
D3C9C3D2C8C4D0C9C6D1CBC6CFCAC1D0CAC2D5CDC7D3CCC7D1CCC4CEC9C2CBC9C3BFC6CD
7C94B0485D82867CA0B46F8CB8495BB3343FB4343EB73E47BE535CC77279D59CAC7D6587
654B7194455EA61D2EB41521B91320B11721AA3E43CFA4A1B5ACA9ADAFB293A1B6202E5A
8961838E1428B00916B4040EB1010AAD061090121DCF9CA4D5D2DBCCD4DEC8D2DDC7D4DC
C4D2DAC1CED7C3CFDCC2D0DDC1D1DDC0D0DEBCCEE57F97BF17346F011A64011667011365
01126200116000115F01135D011156021554021553011154010F5502125502114E010E3F
1E2D435C605B32AA2300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D3BB979297958896A199A3AEB3B8C39DA0AA9597A1
9294A1474E6132364C766D7B7E6E748571778870778C6F76906F75957177977177997378
9D767A9C74769D7676A27B7C9F7C7BA3817EA88584A88383AC8685B18A88B4908BB7978F
BB9C92BD9D91BE9E90BE9F8FBEA08FC1A493C0A594C6AB9BCBB0A1CAB2A1CCB5A5CDB5A7
CBB5A7D2C0B1D3C2B4CFBEB2CCBAACCCBAABCCB9A9D0BFAFD1C0B1D1BFB0D0BEB1D4C2B6
D4C1B7D3C1B5D4C4B6D6C9BDD3C8BDD3C8BFD2C6BCD0C6BDD1C7BFD0C7BFD2CAC1D4CAC2
D3C9C2D2C8C5D1CAC7D1CAC7D0C8C2D1C9C2D2C9C3D2C9C6D2CCC8CFCAC5C8C7C59FB2C5
2A4C797681B1AD779BAC233BC61927CA161EC9141CC6141BC01921B31C26AA2A38B55167
AC5B74D16C7DAB1421C20E15CA0E16C40F15A41619DB9794C3B3B0AAACADC3CED94A5A7C
584E7689314AA60D1BB4060FB3020CB0040F9D0A179F505BDECFD7CCD2DBCAD4DEC8D3DC
C6D2DBC4CFD8C4D1DAC1D0DCBECFDEBACFE5738CB60C2768021967011462011161011160
00115F00135D03165A0217530D1F4E28385F3C4D7711235B06195025386319275104123D
0B19365A6468568E4700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D4BC9DA7ACB0768593949EACACB2BD9899A39697A0
9096A13E4A5B42485A766D7A7F6D76836E778970788C6E73906E74926E759772789C757A
9D757AA2787B9F7678A07A7BA48182A4807FA78282A88282AA8382B38B88B28E89B6948E
B5968CBA9D8FC0A395BC9E8FBE9E8FC3A495C2A698C9ADA0CBB0A2C9B1A1CCB4A5CDB6A7
CDB6A8D2BEAFD1BEB2CCBAADCEBCADCCB9A8CBB7A6CCB9A9CFBDAFD1BEB0D3C2B3D2C2B6
D5C3BAD4C3BAD0C0B6D5C8BED3C7BED2C8BECEC4BBD0C6BED2C9C1CFC7BFD1CBC2D5CDC4
D5CBC4D7CFC8D4CEC8D2C9C6D4CAC5D2C8C1D5CCC5D3CAC5D1C9C6CECAC6C9CACC7A94AF
28497BAEA9D7A1506CBF1C2ACD121ACF1015CE0F16C71414C22523B73337A82E3D9F2539
9D2035C53E4DBE1924C91017CC0D14C70D12B10F13C15D5FD1ADAEAEA7A8A8ACB17E8CA2
263158865875911224AC0511B0010BAD020CA60713861A25DBB7BFCDCFD7CAD3DDC6D0DB
C5CDD9C5D0DAC5D0DBC4D2DFBBCFE87590BB0B2669011A6801146501126000115E00125E
02155B051D572A416D4C60807E8DA48492A6627392061B48223A606A7C8F6B74882B3552
04112F4755606A625A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00D1B498BDC1C7808F9F9AA4B39CA0AC9DA0AAA5A8B2
6F7886233247484D62796F7C816E78836D77876E788A6E74907176906E74967278997279
9A7176A2797AA07879A27E7FA27E81A57F81A27B7BA98181AA8382B08A87AF8C86B6948E
B9978FB99B91BFA096BF9F94BF9F93C7A89BC3A79AC8AC9FCAAFA0C6AD9CCCB5A5CAB4A4
D0BAABD5BEB1D6BFB1D4BFAFD5C1B0CAB5A5CEB9A9CEBBACCEBDAFCEBEAFCEC0B0CFC1B4
D1C0B7CFBFB7CEC1B9C3B8B3C8BEBACDC4BED1C7BFD1C7BFD3C9C3D0C8C1D3CCC4D3CBC3
D3C9C2D5CDC5D3CCC4D4CCC5D5CCC5D3CAC3D6CDC8D5CBC8D3CAC7D1CCC9C9CACE859DBB
254579A4A0CDA85671BF1D2ACF1119D21115CF1015BC1713E87972D49494A26F7F965972
943C579D2037B51321C70F18CC0C15C50910BD0C13A51F25D09092B9A8A8A8A7AABFCAD7
3043666253787E2037A10916AC030EAB010AA8040E8F0C18BB7A85D6CED4C7D2DBC6D1DB
C6CFDAC4D1DAC4D0DCC2D1E87A93C00A276D011A6D01176A01146401165F01175C021C5B
0C255D6C8BB289A3BDA5B9C9ADBFD08CA0B7324871041C475A71897A8A92727B83606878
0B192F36465263625C13CD0900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C6A785BABCC18E9CAC9BA6B5999EAA9EA0ACAAAFBC
59667C091A3752556B796B77806D76826C75856D768970778F73789472789671789A727A
9A747B9A7477A17A7CA67F829F7A7DA67F81A57F80AB8385AA8283A07A79AF8D89B2928C
B99A94B89991BF9F97BE9F93C1A294C3A797C4A898C7AB9CCBB0A1CBB2A3CAB3A4CDB7A6
CAB5A5D4BDAFC2A896BCA38DDCC6B1CBB5A5CDB9A9CCBBABD2C3B4CDBEAFCEBCAFCFBFB3
D0C0B8C1B6AEA59A92ABA19CA99F9D9E9794C8C1BBD1C7C0D1C6C0D3C9C3D3C9C3D1C8C1
D3CAC4D2CBC4D3CDC5D3CBC4D4CCC5D4CCC8D6CECCD4CCCBD2CAC8D0C8C7CDCACDA7B7D1
26467A6974A7B37797B41F2FCE141BD11014CD1013B81A18EB948FCEB1AEC1B6BBA49BAB
6A547184506F9E324BB31524C50D18C60910C10A10AE1117C76B6DE6C9C8A6A5A5B6BFC6
647690272D547F4260920E1FA70411A9030DA7020B9B09148D2F3DDEC6CDCAD0D9C5D2DB
C6D1DCC5D2DCC1D0E294AAD0142F72031D7201186F011569011763021E5C2745737591B7
1E3B617D9DB95E798EA3BACD7B95AD4C698F021A4A1B3456697D897182866F7C7F6C787F
222E3E2D3B466B6C682FA51F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00C29C75C0BCBF7D89998A94A2A0A6B2A5A6B2828897
29385408163758586D7769747D6971806A72846B74886E758C6F77916D7799717B9C777E
9D7B819B787DA07A80A47B81A0777C9E7779AD86899F777AAE85889D7675AD8A84B3938C
B5958FBF9F98BE9D95BE9F90C0A290C2A593C4A896C1A593C6A99AC5A99DC6ADA0CBB4A5
CFB8A8D5BEAEC5AA97C9AF99D9C1AECCB6A5CBB6A5CDBCACCEBFB0CEBDAFCFBEB1D2C1B7
CCBEB7A39892C2B8AECFC4BACCC1BCB1ABA7B0ACA6D1C8C1D1C6C0D0C6C0D5CBC5D3CAC4
D3CEC8D0CCC7D2CEC8D1CCC6D1CAC4D4CCC9D5CCCBD3CCCAD3CBC9D4CDCCD0CBCEC5CCE0
3C5B8B2A447BAA8FB4A2263AC91720D01015D01117BE191BD46F6ED6B2ADC1B7B5BAB8BB
A9AABA575879704F77A63D59B81422C20A12C30A0FB80D12A82D31D09B9BA79D9D929798
8A95A424335771557A80172D9F0516A5020FA5010AA10512830C1BC4959ED0CFD8C5D2DB
C5D3DEC2D0E0ADC2DE27427C021E6F021A7000176A001A630B2862567399A3BCD48399B0
5E758B61788B728696778CA14964880520520A204D556B7F6B7C82717F826E797C6E797E
35424F28373F676C6839B22D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0065D344C4BCB97279889FA8B4A9AFBAA9ACB77D8192
1B24450C1739626276766A747C6973816B74856C75856A7290717B916D7997717A967279
9C7A80A17C84A27A83A57C839A7076A1797BA77F81A27A7DB28B8DA27C7AAA8681B4928C
B3928ABA9B92BD9D93BB9A8FBF9E91C2A291C5A796C4A797C7AC9CC8AD9FC7AB9ECAB2A2
CBB5A6CFB8A9D3BBABD2BBA9D1BCA9CBB6A5CEBAAACEBCACD0C0B0CDBEAECEBDAFD3C2B8
CDBDB8A69A95CBC1B8CCC2B7CDC3BBBCB6AFACA8A0CFC8C0D0C8C0D1C8C0D4CBC3D2C9C2
D2CBC6D1CDC9D0CDC8CFCBC7D1CAC7D5CCCAD3CCCAD4CCCAD4CDCBD1CAC9D1CACBCBCBD6
778DB21E3F73767BA9A64F67BE1A27CF1219D01118C7161BBA373BE6A9A7C7B3B0BEB7B4
B1AFB4939CB52C3768966793A01B33BC0C18C0070DBD090DAB1318BA6466BFA7A59B9B99
B9C1C75C6C873B38617E365394091DA20210A5020CA4030F9208159A4D59DBCCD4C9D1DB
C5D0DFBFD0E74F689703216B011B70001A6B0120651C3E707C9ABAACC3D5B5C6D66D8296
98ADBF7E93A3A6BACD6D85A4132C5F0621533D567496AAB3849095748082757E80707A7D
3C495525363F596360675C4D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF005CC735CFC2BA7E84928992A099A0AB989CA78F94A5
202849131B3D6B697C766A737B6B75816D77867078876D778E707B916F7A96717A97737A
96737A9F7981A07A81A47C81A17A7DA68083A78084A78083AB8587A07B79AA8483B28F8C
B4938BB8998FBF9D93C3A295BF9E91BE9E90C4A695C5AA99C8B09EC5AD9CC4A99AC7AC9D
CAB2A4CCB6A7CDB7A7CBB7A6CEBAAAD2BEADCCB8A7CBB9A9CFBEAFCDBEAFCDBEB0D1C2B7
CFC0BAA49894C8C0B9CDC7BDC9C3BCA6A198C1BBB1CFC9BECFC8BFD0C9C0D4CCC4D4CCC4
D3CBC4D5CDC8D3CDC6D2CBC7D2CAC8D2CBCAD1CDCBD2CECCD2CBCAD0C8C7D1C8C7C9C4C7
B3C0D63A5883374F86B383A5AE2334C9131CD01119CB1017BC1C23DB7D7ED1AFABC0B4AF
B6B0B0B0B3C14E5F8A5D568A953859B41222C10911BF0A0DB30D139E2D31E7BDBCB7B3B2
A0A7AA8D98AC1C254D7D5679820E25A10516A80310A5020E9C0613831C28D8B5BDCECFD8
C6D1E397ABCE0F2A6B021E70001A6D04256735598898B8D2B1C7D8B2C2CFB0BFCF435B73
6A859F6E8AA46280A51B3569031B56213963788C9C7B8B906974796C787971797C737D82
394854283A4256615C5C544400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056C12ADAC8BCA2A8B5A4AFBE9CA3AEA1A6B1B1B7CA
242D4D1A21426B6979766B7373646E826F7A826D76876F778C707990707A96717A946F76
98757B9C797F9F7C819E7B7EA58486A07F82A07E829E797DA983859E7878AE8786AE8787
B5918CBA968DBD9B8FBB9D8DBC9F90BDA191BCA18EC0A793C7AF9DC7AE9DC7AD9DC9AE9F
C9AFA1D0B8AACFB9AACCB9ABCBB9AACDBAABCAB5A7CDB8AACFBEAFD1C0B2CEBEB1CDBEB2
D0C0B7BEB1AAA29892AEA6A0A8A29CB8B0A8CEC7BCCEC6BCD0C9C1D0CAC2D1CCC3D6CFC8
D3CBC4D3CBC4D5CDC4D3CCC5D1CBC8CBC7C5CDC9C8CECACAD0CCCACEC8C6D1C8C6CBC7C5
C2C9D4889EBD27487D8F87B3A63F54C11924CC1019CD0F15C6141BBB393CE7A9A7C2AFAA
BEB7B2B4B3B6909DB92B386C93628CA1192EC11019C00A10B90A109D1319BE7778AC9A9A
98989B9498A540486A56486F7C264099081AA60311A5020DA10410890B18B37882D4CDD7
C2D0E744608F02216A011F6D0627685377A1A6C4DBB3CAD6B7C8D3B8C6D1B3C1D05B7088
2B466559779C0420530019521B335E63778F737E886F797D717A7D6A76766D777A6C7A81
293A492F444D5865605D564600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D7C4B3ABB1BE98A4B499A1AE9EA4B09A9EB2
292F4E2327446D69777569715E50597C6C75826D75846C738B6F758E6E76916C76957079
9B757D9B757C9D797E9D7B80A483879172779173789C7B80A68084A57D7EAC8484AD8585
B28C88B49188B9988DBC9D8FBB9F91BCA18FBEA391BAA18EC5AC9BC5AD9DC9B0A2D1B8AA
D1BAABCBB5A6CCB6A8CCBAABCCBAABCEBCADCAB8AACDB9ABCCB9ABCFBCAECCBAABCDBCAD
CFBFB1CCBEB3CCBEB6C5BBB4C9BFBACEC5BECDC5BDCEC7C0D0C9C2CEC8C1CFCAC3D4D0CA
D2CEC8D5CFC9D4CEC7D4CDC9D1CBC9CBC7C6CBC8C8D0CDCDCFCCCACEC9C6CEC6C4CEC7C4
C7C6CABEC9DC5B77A0485C8FB47A99B22131CE141FCD0E15CD1119B81A1FD87879CBA9A5
BAB3AEB4B3B1AFB6C6465A8564588B933151B40F21BE0914BA0810AC0F16AA4548C9A6A5
B3ADAEA4A6AD8991AA262C54814C6C8C0F22A10411A6020DA603119607148B3340DCC5D0
AEB9D5122F6902236C082B6D5D80AAB0CCE2B8CDD9BBCDD5BCCBD4BAC9D5B0C0CF96A9C1
50678D0F285800194E1F3D6671879EA6B6C0939DA4808A8D8690936B767769767A61737F
12243B4155615A67645D584C15CE0A00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00D3BBA6BBBEC99CA9BBA2ACBAB0B5C187899B
4449652A2D466C677473676F74656B7D6A737F6A71836B708B6F748D6F7596737D97707A
9A727A9F767BA27B7F9D787D9771798A696F896A6F896B6FA38183A68080AD8685AC8483
B28B86B38E86BC9A91C1A197BFA295BC9F8EBC9D8CBCA08FC6AB9BC8AE9FCDB4A5BBA392
C9B4A1CDB7A8CBB5A7C9B6A7CBB8A9CDBAACC9B7A9CBB8AACEBAACD0BDAFCDBBACCEBCAE
CCBFB0CCBFB3CFC1B9CBBFB8CFC4BFCFC5BFCEC6BFCDC4C0D0C8C4D0CAC4CBC7C1D5D4CE
D5D1CED4D0CBD3CECBD2CBCACFC7C8CCC8C7CCC9C8CCCAC6CECEC9CCCAC6CBC7C3CDC6C3
CDC6C8C6C7CFA1B2CA2545769F8FB89F3247C41622CF1218D01118C11118B63337D99D9B
BBACA8B4B2AEB2B5BA8A98B5303D738C5582A0142CBA0A17B90510B1081196161DC78B8D
D1C3C599999E939AAA2A355B6853787C1D349D0818A3020FA3010F99020E7C0C1ACEA1AF
9093B008215F0325684B709EABC8E1B8CCDABACCD6BACBD3BBCBD5BCCEDEA2BAD56983AE
163267021B51112C5866809A8294A196A5AB717D836F7C7F6C777A63727461737C3F536C
05193D48617557696B5C5E552CA21B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00CAAF92B9B9C2929EB09BA6B5A0A5B285899B
3E45602D324A6E687574696F776A6F7B69707E696F81696E856A708D6F7890717995717A
9A72799E7278A2767EA379838E646F9E757EA07D81866A6CA18586A48383AB8988B08A88
B69089B7928AB59389BFA195BDA093BEA091BFA091C1A192C1A595C2A796C8AD9BBEA490
C8B19EC6B1A1C9B5A6CAB7A8CCB6A8D1BAADCBB6AACDB6ABCEB8ACCDBAAECEBBB0CEBDB2
CABDB2CDC3B9CEC2BACCC0B9C9BFB9D0C7C0CFC6BFCDC5C0CDC7C1CEC9C1D2CEC7D3D0CB
D3D1CED1CDC9D4CFCBD2CCCAD0CCCACDCBC9CBC9C5CECDC7CDCDC7CBCCC7CCCAC6CDC8C6
CDC6C6CBC8CAC4C9D74D6892546395AE6E89B41D2BC91118CD0F14C80F15B8191ECF7070
CBA8A5B9B0ABB6B5B5B5BCCC4658864D3C6F89203EB3101DBC0912BA0B14A50D15A5474C
B395959B97989596A06069863535607D3E5D910C229E0212A1000F9B020E8A0714A15666
7F7192061C571B40779FC0DDB7CCDEBBCDD8BBCCD7B8CAD7B6C8DDA1BADA486698042562
031F581C365F6E839E657585738189707E816B747A6B767A6774795A6E763E51690A1D48
011345132A4E4E6473585F5C41752900FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0094BE69C5C3C87B889897A0AE9499A4ABB1C1
1E27423B41586C697571686D74676B7C6A70806B71816A71886B768A6975916E7999747D
9D757EA37980A0757D9E757E8B626C9E767BA28182A18C8BCABABBD0BCC0B2979CAC8A8B
B38F8CB28F88B49388B99D8DBEA292BB9D8EBE9F91BFA192B79D8DB49C8EB9A496BCA897
C1AD9CC3B09FC4B1A2C5B2A4C9B2A4CDB6A9CBB4A8CBB3A8CBB5AACBB7ADD1BFB5CEBDB5
CDBEB6CEC2B9CDC1B9C8BEB7C5BDB6D0C8C1CEC5BECDC5BECEC8C0D0CAC2CFCBC3D2CFC9
D2CFCCD3CFCCD1CDC9D3CFCBCFCCC8CFCDC8CAC8C5CBCAC6CBCBC6CCCEC8CCCCC7CCC8C4
CCC7C4CDC8C7C8C6CE96A6C429477CA391B5A02E42C31820CC1016CE1016C7161AB43234
DEA4A2C1AFACB9B4B4BBBEC58998B630396B93577CA3192CB90C16BE0B12B20B13941A20
C39091CDC5C7A2A2AC8D94A9232D5776567B7B10299703159F010F9D020D970511811323
784B6E0C1A504971A0B1CFE8B7CBDEB6CADAB2C8DDA5BFDE748FBB1E3C73011F5C02255A
46618672889D9DAEB985939BA6B5BA7E8C928B979F71818C6376882F4561061843010F46
000B46000F4224375656606655493D00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0061D245D2CCCE909AAAA4ADBA9CA1ACA0A7B7
1B26403D4A635E637565626E71656D7D6B717E6970836B748A6C79886674906C789D7682
9D74809F777FA37A8199717A8B666D957779B09B9BDACED0DBD3D9DDD3DAD6C4CBA5898E
AE8A8BB5918CB7958AB99A8ABB9E8EBA9A8CB99A8BB4998BA58F839481788C7B7391847A
B6A69ABEAC9CC5B1A2C7B1A3CBB5A7C9B2A4C9B3A6CDB6AACBB5A9CDB9AFCFBCB6D3C1BC
CEBEB7CBBEB5CBC1B9CBC3BCCBC5BDCDC6BDD0C7BFCEC7BECFC8C1CDC7C0CFCBC2D1CCC6
D2CECAD2CFCBD2CECBD1CDCAD1CDCAD0CDC8C9C7C3CDCAC7CCC9C7CACAC7CCCBC6CCC8C4
CBC7C3CBC7C5C9C7CBBFC6D544628E596997A76580B31F29C91219CB0D13C90E14B4171A
D17475CBA9A6BCB2B0B8B6B9B6BFD23D507B72608D952E49B30F20BD0A14B205109F0D17
B15F67C8B3BAA09FAB999CAA4551744B456D752643940B1D9F02119E020C9B010D880512
8237531D1B4D33598E9EC5EEA9C8EB95B3D76382AF20417903266401215C1A3C6C688CAD
89A6BCA7BCC891A2ADA4B5BF93A4AF8497A36F8295415773142850011145000C43010A42
010A43020E44091A444A5A685A564E00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0059C837D4CAC6848E9B98A1AFA8ACB8858A9C
2632501F2F56142148313654645E6D7A68717F69718368728A6B778D6D7991707A977380
9C73829F7580A37A829A727B836268857072D0C5C6CFC5CBA497A1A89AA4E2D2D9AB9196
AC8A8BB18C87B7958ABD9D8FBB9E90B29486B19585AA948784736A9B8A83A5948E746964
9B8F86B9A799C1AA9CC2AB9DC7B0A2C6B0A2C5AFA0C9B3A6CBB6AACAB8AECFBEB6D2C2BD
D1C3BDCBC0B6CFC6BDCBC3BBCAC3BACEC5BCCEC6BED1CAC3CEC7C1CEC8C0D1CDC4D0CCC5
D1CDC9D4CFCED4CFCECFCBCAD0CDCBCDCBC8C8C7C4CECBC8CDC9C7CDCAC8CDC8C4CDC7C3
CBC7C2C8C4C1CBC9C9C5C7CE8B9FBE254577A490B59D2B3CC1141ECB1015CB0D15C21117
B53439DDA0A1C1ACABB9AEB1C2C0CB818AA847426BAF6884AA172BBB0A16B5030DAB0912
98252CB78B8FAAA2A99B9EA5747E99222A54744668820C1F9B03119E020C9A000C91040F
7D1C30563E620D245C193D7C1D3F7D0B2C6802226103245F1A3A6A647FA55978988FAFC8
2F4C6191A6B55D6E7C7B8A95637381596E86223960031647000C46010A4701094200083F
000A40020E4402123F41546761646010CB0800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0051BF28DBCFC39199A5A3ACBAADB0BD858A9F
2B355B020E41020C440A123E605D757767727E6A718068718669748E6E79907079987480
996F7D9C717D9B717A9B727A9C797E988083DCCFD5AB9BA5A189939A8289DDC9CEAA9396
A88A88AA8881B19086B8988CB39488B09184AE90849884797D716A9B8D8A978A8A736C6B
847C76B4A599BCA798C0AA9BC5AFA0C1AA9BC4AE9DC7B3A5C7B4A8C9B8ADC9BBB1CEC0B9
CEC3BBC8BEB6CEC4BFCAC1BAC9C2B8CDC5BBCEC7BFD1CAC6D0CAC4CEC7BFD0CAC3CFCCC6
D0CDC9D3CFCED2CDCCD1CDCBCECBC8CECDCACECCC9CCC8C4CFC8C5CFC8C6CFC8C5CCC6C2
CCC7C3C7C3C0C9C5C5C7C6C9BCC5D73C5B876170A0A05E77AE1A28C60F18CE0F17CA1117
B4151CD86F75D899A0CE9CA4CD9CA9C99CAFA87793D37C93B01E2EBB0B16BA0611B30610
9C1118AF6C6DDED3D4C0C7CF8B95AA2A3A6056466C70152B9307149C020D9A010C94020D
760814B98B9D6F71932C3F701D33681D36683C57816E88A8A3B9CEB8C7DA4D6177647C8F
657D8E7C939F899CA58091988999A71F355901134A010D48010946020A4502094100093E
000B3D01103E02113B32455B63686827A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DAC9B9949AA89DA7B79DA0AF7C8198
0E173F020B40010843030A3D514F6D7365737A676F7B666F836974886974916F7A95707C
976F7B9B707D9A6E79986B759E767D9E8287DFCDD49F8892A6878F9F8389D6C0C5A48C8E
A88986A7857EAE8E84B29287AF8F84AF8E80B09184917D737065627C7376756F72686262
7B726CA39489BBA799C0AA9BC3AD9CC3AD9CC4AF9EC4AFA0C7B4A6CAB9ABC6B9ADC9BEB4
CEC3BBCBBFB8CBC1BACCC3BACAC3B7D0C9BECEC6C1CDC7C4CFCAC5CECAC4CDC8C3D1CDC8
D1CFCAD2D0CBD1CECAD0CCC8CFCCC8CDCAC7CECBC9CFC9C7CBC4C1D0C9C6CDC9C5CCC7C3
CCC7C3C7C3C1C7C4C5C7C6C6C5C7CF8C9EBC2B477B9C88AE9A3044BB1823C60F16CB1318
C31218BA2129B2303BA92F3AA72A38A82A3AA52635B12431B6141EBA0C15B50910AF0A10
9D1116974A4AC1B1B5979FA78C96A65768862D305A703550880A1C9A030E9B010B96020D
8307119A5862D5CBD6BBC6D7B1C1D5B1C3D8BACCDCBACCD8B9C6D1BAC5D0A1B0BF8AA0B1
AAC2D56D8CA29CBACF748F9C9DB2C122395F00124D010C49010B4500093F000A3C010E39
0E1E3F293B5511254122364B636C6F2AA52100FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00D4BCA99EA1AE9DA8B98C91A27F859D
02083001063902074102093E4545667467797765717E6A72886F798E6D7992707C916C78
97707C996F7B9669739E6F79A0767F98787FDBC6CBB29DA3A2888ECDB4B9B69DA2A7898B
A5817EAA857DAD8981AD8A81AF8C81AF8F7FAE907FA48A7F6E5B58695F5F655E5E7B736D
9C8F849F8E80BDA799BDA797C1AC9AC1AE9DC4B0A0C5B1A2C8B4A5CAB8AAC8BBAEC9BEB4
D0C2BCD0C2BCCDC4BACCC5B8CBC4B8CDC6BBCEC6C2CEC7C3CDC8C4CAC6C3C9C5C1D1CEC9
D3D0CCD6D4CFDAD8D3D5D3CED1CECAD1CECAD3CFCDCFCAC9CBC6C4CCC8C6CECBC9CEC9C7
CAC6C6CAC6C6C9C7C7C8C8C6C7C6C8C0C5D46B7EA44F5882A0718C9F303FB22025B71B1A
B81E1BB4201EAD2222A82122A71F23A92327A82627A92726A62323A52324A1242299231F
8B28269E6664A297999EA4A9A2AAB9788AA118284F6B4C6F7A0F269504129C010D98020C
9107127A202BD7BBC5C8CCD4C3CFD8C0CCD8C0CDD8BBCCD5B7C6D2B5C4D1B3C4D7486381
43618D0421571C3B6E385B78648090374E6D02134B000F4B000E45000F3D07183B26394D
475A634F60662F4352182C3F5D666D55483F00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CAAE94A2A2AB99A0B37E8599424966
01062E01043401063E02083F3F3F637267797B69737F6871886C768D6D788E6E78906C74
9770789B7179956A6F9C7177A0767DA07E83B2999DD9C6C9D1BCC2B69DA2997A7EAB8986
A5827AA9857DA9837BAD867FB08C81AE8D7DAE907DB194859F877B927E759180778D7B71
9A8579B59E90BDA596BDA896BFAA98C1AC9DC5B0A2C5B1A2C4B1A2C8B7A8C9BCAEC9BDB3
CDC2BAD0C6BECAC3B9CEC7BDC7C1B7CDC7BECDC7C1CDC9C2CBC5C0CDC7C4CFCBC6D3D1CB
D7D5D1D7D5D1D6D6D2D6D4D1DAD6D4D7D2D0D2CECCD0CCCBCCCAC9CAC8C7CDCACACCC9C9
CBC7C7C8C4C4C8C7C6C6C4C0C5C2C3C6C4CAB9BCCD9098B1827C91AA828DC57E7FC77872
C87770C77C71C58177C4837BC88781C88B83CB9189CD9690CD9691C8928EC48F8BBA8883
AF8985B5A5A2949698C0CAD1BBCBDA94A9BE31456748436872243E8E07179A020F9A000C
96030F7D0B18B8838DD2CCD2C5CED8C0CCD8BCC9D6B8C9D5B8CAD79AADBE72889E455E80
05225C02196201175D1835616B889A5C728C01154801134B05164220324D465864566668
5866645460603E4E5914253558676C625C5500FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0098C26CACA8AF84889B84899F141939
02062E01043401063D020A3F3C3D5E7868797F6672856975886A758B6C76916F788F6870
986F769A71769B71759A70769E767D9E797E9C797DA08287A5878CA281859D7678A57F79
A7847BA27F76A58075A9847AAC8A7EB19183AD9080B09685B89F91B8A191B49C8DB59D8F
B99F92BDA395BCA394BEA895C0AA97C2AB9CC4AEA0C7B2A3C8B6A5C8B7A8C8BBACC9BFB4
CAC0B7CDC3BBCEC5BFCDC5BFC6C0B9CAC6BFCCC7C1C9C6BFCBC7C0CFCBC6CFCBC5D2CECA
D9D6D1D7D5D0D5D4D2D3D1CFDAD6D5D5D0D0D3D0D0CDCDCDCBCACAC9C8C8CCCBCBC9C8C8
CBC8C7C8C6C3C6C5C2C5C2BFC6C1C1C5C2C3C4C0C4BFBEC3BDBDC3BFBBBCC4B7B3C6B7B1
C7B6B1C1B4ADB9AEA8B8AEA9B7ADA9B2A8A3B0A7A3B6AEAAB1A7A5AFA8A5B1A8A6ABA2A0
A6A1A1D2D4D5B5BCC2A1ACB76B7B8D7083976779951F2850784868840B229903149A010F
9A02108F09168D3D48DCC9CFC8CED9C2CFDBBFCDD9B7C8D3B7C9D696A9B8768C9DA9BFD5
1B326503186102155F041A4E59758D748CA0071C41172C4F3E516654666C5B68685B6663
576160535E603C4A5415253257686D79797410CB0800FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065D549BCB4B48A8EA1696D87070C2E
00042E020533010639030D3D3F3F5E766475816674866A77896A778E6C788E69748F6772
976F789B71799E737B9E737BA078809F767D9D7277A4797CA57B7DA1797AA27779A47978
A67E79A07971A37D71A68374AE8E80B39688B19585AF9585B39B8CBAA192B8A08DB9A28F
BAA292BCA395BEA697BEA694BEA793C3AC9BC2AC9DC5B0A1C9B5A6C8B6A8C7B9ABC7BDB2
CABFB6CCC2BACFC6C0D0C8C2CBC5BECAC6BFCAC6BFC7C4BEC9C6C1CECAC6D3CECAD4CECB
D8D3CFD9D6D2D5D4D1D3D3D1D9D6D5D5D1D2D0CED0CACACCCAC9CAC9C8C7C9C9C5CBCAC6
C8C7C2C8C7C2C6C5C1C5C4C1C3C2C1C2C1C0C2C0BFC3BFBEC0BFBEBCBCB9BBB9B6BBB8B6
B9B7B4B6B6B3B2B1AFB0B0ACAEACA9ADABAAAEACAAADACA9ABA9A6A6A4A3B6B7B6B9B8B9
9F9EA3A3A6AA989DA3949AA199A0ACB9C6D295A6BC23345D654E777715319405199B0210
9C010F9305107A1420CFA8B1C9CBD5C2CED8BFCDD7B6C7D1B8C9D5B8CAD8768DA1AFC6DB
42567F01135600125901164A4A6580657B884D60705A6D755D6F715A6B685B69645D6963
5B65655763672B3D481C303C55676A8B8F8C239C1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF005CCA39C6BBB7737B8C4A516B000528
03072E16163C22234A070D35494965746374816A778569778766768864728A66738E6A75
956F7A9D747F9C727B9C6F7A9E727BA0747CA4767DA6787CA6797BA4787AA17477A37678
A276759F7470A47C71AC8879B19082B59687B59889B69A8CB89D8EBA9F8FBA9F8EB9A28E
BBA292BFA697BDA496C1A797C0A794C4AD9BC3AD9DC7B1A3C7B2A5C7B5A9C7BAAEC7BEB3
CAC0B7CDC4BCCBC6BDD0CAC2C8C2BACAC3BFCEC7C3C8C4C0CCC9C5D2CFCCD5D2CFD4D1CF
D4D0CDD3D1CDD2D0CDD4D2D1DAD8D9D5D2D3D0CCCECCC9CBCCC9CACBC9C9CBCAC8CDCBC8
C9C7C3C8C7C2C7C6C2C4C5C3C0C1C0C2C2C0C3C1C3C4C1C2C0BFC0B9B7B7BEB9BBBBB7B7
BAB6B5B7B1B0B7B0B0B5AEADB6ADAFB2A8AAB1A5A7ACA4A2B0A5A5AEA1A1A69E9DB1A9AB
ABA2A79F999EC4C1C5BCBABFB1B0BABFC7D79AAAC64152793F37617B2F4B8F0A1D9A0311
98000D92020E810816A2646ED3CBD4BFCAD3BDCCD5BBCBD5BAC9D5A0B2C12D435B5C7289
6B7D990D2051041853051B4860778C6E81886F7E816878775F6F6D5E6C685B69645D6A64
5B6867526067112332253D474B60618C94922BA52300FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C02ACDBBB0868B9A343C5902072A
0A0D2C49415A4E455E0E0E2C57536C7A6B7C7E6A77806875866576866172835F6E886270
9169759B717C9B707B9E727CA0727C9C6E77A3727BA6767DA4757A9E7073A07375A07275
A27575A37876A88179AD8B7DB09081B29283B49586B39587B39587B59889B69C8ABAA08D
BBA191BCA294BEA496BEA393C2A997C1AC9AC2AC9EC7B0A4C7B2A6C7B6ABC7BCB0CAC2B7
C8BEB5CAC1B9CAC2BBCEC6C0CBC3BEC8C0BCCDC4C2CDC6C4CCCAC7D3D3CFD5D5D4CECECD
CFCECED3D1CFD6D3D2D4D1D2D2D1D2D4D3D4D2CED0CFCBCCCCC8C8CAC7C8CCCBCBC9C8C7
C8C8C5C3C3BEC4C4C2BDC3C3B8C2C4BEC1C5C4BCC2C7BABEC6B4B9C6B2B7CAB1B7CEB1B7
CFAAB3D2A8AFCCA1A8CA9DA2CA99A2C9939DC48D97C08993C18490C0828DB97D84B87D84
B97C87B27985D3A0ACDAABBAB07F949C728C724E70866888623C5A9F4C638B08199A0212
98010E91010C8804137B2633DBC1CBC5CBD5C1CCD8BFCBD6B7C2CF7E8E9B9AAAB9708390
B2C2D066778F2F43643348628697A46C7C826E7D7F6C7A78677172626B6A5E69675A6867
5363692C3D5002132C314B594961646F7D7C51474000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0052B920CFB8A68A8C9D1B234203092A
23243B5E5260564A5C15122A645C7279687777636F7B6370816271825C6E7E56678D6272
906571986D77966B789A6D7A9B6D799F6F7B9D6C77A27077A17177A071749A6C6EA07372
A07573A57A76A9827AAA8679A98879AF8F80B49686B19585B59888B69A87B89D8BBAA090
BBA091BCA193C1A698C0A797C0AA99BEAA9BC1AC9FC1ACA0C5B2A5C5B6A9C2B9ADC6BEB3
C9C0B5CCC0B9CCC1BCCFC5BFCAC2BCC3BCB5CAC4C0CCC7C5CCC9CAD2D1CFD1D2D0CECFCD
D0D0D0D2D1D2CFCED0CFCED0CECED0D2D4D4D1D0D1CCCACACACAC9C7C6C7C7C6C6C7C6C6
C7C6C5C1C1C0C3C7C99DABBA658096B4BACDBF9EABCA8894CA7884C56D79B75966B54E5E
B34154B13A4BAB3443A52D3BA326349F1F2EA01E2D9C1A2AA0192B9C17279C16239B1824
9A16259A17279B1A2F961A30971B3092172E901A33891A308A1D2F9317299706169C0210
9A010E93000C8F02127B081AB67086C4A0B8C5B0C7C9BDD0C9C4D2A4A7B2BFC9D196A7B2
9EB0BC8EA0AA70838D6D7E8569767C6A76796F7B7C6F7A79676F71626C6D5D6A6E50616B
293A51041234000C2F152A42435A645666675B554E00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B71AD4B6A08A8B9A101A39050C28
3D3C4B60555D5449571C172E6F657878657278626C7E63707E5E6D7A56668057688C616F
966A74966A75986C7A986D7B976C7B9C717E9D707A9C6C749D6E729D6E709B6C6D9D7370
A07772A67C76A88078A78276A78577AA897AAF907FB09384B39787B69B89B69C8CB89F92
BA9F92BDA294BFA697BEA797BEA99ABCA99CC0ADA0C3B0A3C3B1A2C1B4A5C1B7ACC3BBB0
C5BDB2C8BFB6CAC0B9CBC2BBCEC6BEBEB8B0CAC7C1CCC9C7CBC8C8CCCBC9D0D1CDD0D1CD
D2D2D1CFCFD0D0CFD2D0CFD0D1D1D2CFD0D0CCCCCCCBCBCBC9CAC9C7C8C7C8C7C7C5C4C3
C5C5C3C1C3C2C0C3C89DAEC42143728592BA92586FA42738B61E2CB91C26B91924BB1822
BD1623BD1421BD1422B7121DB61219B31015B4141BB01219AF1118AD1217AC1116A71012
A71013AA1116AB121AAA121CA50E18A40F199F09189B09179C0A169B09159F0A1799040F
9A020E96020D960212900416850C247A163279223E7B314A87495E8A65729E99A273808B
61727F7284886273776E7C7E6F787B727C7D75807F707B7A697274616C7054667420304F
010D37000735010733000B2F22364A54656A59565100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0054B414CCA88E827E8C060E2C080D26
5B566262545A514653201A2E72677876636F79616B7C5E6B7655647C5A69845C6B8F6473
966975986D78956F7E86687E7C637C8B6E8298717D9B6E769C6C719A696C9C6B6C9D706D
A27773A67C76A77F77A68174A68475A88776AF8F7DB29284B29588B09587B19B8DB49F91
B6A294B6A092BBA596BDA799BBA499C3AEA3C2AFA2C1AFA1C4B3A4BFB1A4C0B6ACC5BCB2
C8C0B5C9C1B7C9C1B8CCC4BCD0C8C0C4BEB8CBC8C4CBC9C6CBC7C6CBC9C5CBCCC7CECFCB
CDCECDCFD0D0D1D0D1CFCDCED0D1D1CCCDCCCDCECCCBCCCBC8C9C7C8C7C5C9C6C4C5C3C2
C6C5C4C4C4C4BEC1C2BAC3D24E6B973C5588AE82A0A22A38B81F26B71D1EB21D1BAF221E
AC2120AD2726AC2A2CA5292AA62F2CA6352FA43931A03B34A13D379F3E379E3F379B3E35
9B3E35A1443D9E3E3B9D3E3A973836933333923035902D328B242A851E24881C2386171C
8812198810178A0C168C0C188B0B1A890A1A880B1D850A1D7E0B206B18278C6F77A1A6AD
7E8C9395A5A78392948996977A83866E78797581816D797A6C76795A6973263854010D3A
01093B010836000734010A340616334559615257560CC80700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C79C7B7B717F060B2A0A0D27
6A616D64535B4B414D2C26376E667472636E775E697B5C68795664805B6A89616E8F6471
936775926C7E7B637D352F5916164A3831598E758A986C7698676B9766689C6C6BA17572
A47876A67876A27771A88277A58373AF8E7CB0907EB09183B09388AE9489AA988CAE9F93
B4A394B5A193BAA496BAA499BAA49BBDAA9FC0ACA1C1ADA1C0AEA2C1B2A7C0B5ACC6BCB2
C6BDB3C6BCB3C7BFB7CAC2BACEC5BFCBC5C0CBC7C3CFCDC9CBC8C4CECDC8CACAC7CDCDCA
CCCCCCCDCDCECCCBCCCCCBCBCDCECDCACCCAC9CBC9CBCECBC9CBC8C8C8C6C8C5C4C8C6C4
C5C3C4C5C3C4C0C1C1BCBFC794A4C12A44719A92AEAB7077BE6A69C77471CC817ACF8A83
D08F8ACF9791CB9894C99B95CBA09BC39F96C1A098C1A39ABFA29CBA9E98BCA09AC5ACA5
AB948CB49D96B8A09DB49D99AB9492B69F9EA98F91B0989AAA8F93AB8D90A78284A77C7E
A775799C656894575C8D4A4F8A41478133397C262E761A227415226416207D5C60BBBDC1
A7B4BB86959B8B979B6E7C7D707C7D6974746C77786875776572793F4F6504103C00083E
02083C010837010733000835000E302C41504D585A17921000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C092688F848B050C29171A33
5C515E64515B49414F36374B5A5B6E615A6C6F5D6B7357647A5A66815D6A885F6C8E6472
8D6476826480342C570A124C0610530D134B706180956D7A95656A9A6A6D9B6D6DA27574
A17271A57573A27570A87F77AC877AAF8C7CB49181B19082AE91869F8A7F8879707F746B
A99A90B5A195BAA498B9A397B9A499BAA79BC0ADA0C1ADA1BFACA1C0B0A7C2B7AEC0B6AD
C5BBB3C8BEB6C9C0B8C9C2BBCBC4BECFC9C4CCC8C2CECDC6CAC9C4CECDC9D0CECBCCCBC9
CDCCCCCCCBCDCBC9CBCECDCECECFCDCACBC9C7C9C6CACCCACACBCBC7C7C8C3C2C2C6C5C6
C1BFC3BEBDC0C1C0C3BEBFC2B7BBC88B98ACA6ABB9C4BABCCAB8B7C8B6B3C2B4AFC0B3AE
C3B4B3BDB3B2B6B0B0B5B0AFB4AEACAEACA9ADABA7ADAAA8AFA9A9AAA3A3AAA4A4ABA8A8
9A9C98989B99ACADAFACAFB1A6ACB1CFD7DEC4CED9ACBAC998ACBBC5D4DCC9CFD5C6C9D0
CDCCD4C7C4CAC3BBC2BFB6BBB8ACB1AA9C9FA48F929980867C5F6B755963756A6F8C9499
87959D6C7881717B816C777A6773746371716473736372745D6D7A142446020D43010840
01073C010837010833000A34010F351C2E444C5A5F28632000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B686539B8D90090F29323448
685C6862515B3A36472D36510E173A222543685D70715A66775A65815F6C886270896071
86627A59456C14124139396A20235B060D435A4D6F916C7A95666C98686B9B6C6E9F7071
A27372A97A78AA7E79A67E76A68075AE897AB08C7DB39184B4978C8C776DA6988F867B72
8F8279AD9E93B7A397B5A094B8A396B8A698BEAC9DC0AFA1C1B1A4BFB3A8BFB6ADC1B8B1
C6BCB6C5BBB5C5BDB7C4BFBAC8C4C0CCC7C2CCC7C2D0CCC7CCCAC7CDCBC8CDC8C5CEC9C6
CECCC9D0D0CECBCACACBCACBCACBCBC9CAC9C8C9C8CDCECCCACAC9C5C5C6C5C4C6C5C4C6
C2C1C4BFBFC0C3C2C3C1C1C1BFBEC0BCBFC0BABDBDBCBEBDBEBDBDBBBBB9BABBB6BAB9B6
BCB9BAB4B4B7B2B3B5B2B3B5AEAFB0AAACACA8A9AAABA9ADAAA7ABA4A2A3A5A3A59E9F9F
9EA3A2949B9AC7CFD1D0DADEA4AEB9B2C4D794ADCA7C97B357748BC0D6E5C6D4DFC5D2DC
C7D1DEC9D2DEC7D1DBC7D2DAC4D0D7C5CFD5C7CED5AEB7C4374458515D6D87929A839096
8E9AA38792997B858C838D9068747562737061746F5F707344556904123F040D48010840
00083C000C35020E300917360314331121384C5B6338333000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005EC631A28D8A1113292C2B3D
5D515A5E505A2B283F0E173D0109370C1239554F646E58647B5E6A836270876371876275
7A607C221842393259827191463D68090B3F5344678C64739463699A6A6B9E6D6FA06F6F
A1716FA67874A9807AA58077A58177AD8A7CB19181B49485B6998C8A756A85776D807066
8B7C6F8C8073AF9F95B5A196B7A498B6A497BAAA9ABDAE9EBCB0A3B9B0A5BCB3ABC1B9B1
C3BAB3C7BFB8C8C1BCC6BFBDCAC6C3CBC8C5CBC6C3CBC5C4CBC6C6CCC8C7CCC7C4CDC8C5
CCC9C6CCCCC8CCCBCBCDCCCECBCCCDC8CACAC8C8CACBC9CBC8C7C7C6C5C4C6C4C4C7C4C7
C7C4C6C1C0C0C0C0C0BDBFBCC1C0BEBEBFBDBDBFBFBABBBCBABBBABBBCBABABAB7B5B6B3
B5B5B7B0B4B6B0B1B5B1B1B4AFAFB1AAABADA9AAADA8A7ABA7A7AAA6A8A9A3A3A5A2A4A7
D1D5D7A6ABAEA7AEB4B4BDC698A2B07E8DA5304A6B768FAAA4B9CBC3D4E0C8D4DFC7D5E0
C5D1DFC8D4E2C3CFDDC4D2DDC2D0D9C2CFD8C6CFDA919CAB95A4B5708291AFBFC9B0BDC6
97A2ABA8B4BB738087768185677575657571637571607176253551000D42000944010B3F
02123A12263F344757475A6524354708182E4A5B663B3C3A00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0059BD25AB8E831F1B2B2C2835
6F65695F515B1E193401063102093C050B35554D66735D6A7A5F6B7F5F6E826070856679
58486917103971607D876F89352C570B0D415B486C8E637198656A9A67699D6B6C9B6A69
A47471A67A75A47B75A58179A7837AAC8A7CAF907FB29382B095839682748D7C70AA9688
B5A293918276A5968BB5A296B7A498B8A69AB6A799BCB0A1BAB0A5BAB0A7BDB4AAC0B7AF
C3BAB3C3BBB5C5BEB9C8C1BEC8C3C2CBC7C6CBC6C4CDC8C7CCC8C8CBC8C6CECCC8CCC9C6
CCC9CACDCBCCCBC9CACCCACCCACACCCBCBCDCBCBCDC9C8CBC7C6C7C6C5C4C6C3C3C5C2C3
C4C1C0C2C1C0BEC0BDBDBFBCC0C1C1BDBFBFBFC1C4BABCBDBBBCBDB8BAB9BABAB9B4B5B6
B3B4B6AEB2B3B1B3B6B4B4B7B0B0B2B1B2B4AAABAEABACAFA7A8ABB4B8BAA7AAAC9DA1A2
A6AAAE9AA0A392989D848E97ACB4BE949EABB0C3D7BCD5EBBAD1E2C4D7E0C2D2DAC4D3DE
C4D3DFC6D3E0C7D5E1C6D4E0C3D1DCC1CFD9C3D0DB9EAEBAB5C7D3A9BCC68A9BA7A4B2BE
7A879178858C707C816E787B68737467767262737160727A122246010C44010E4303163F
20364D4961664F62614F5F5F44525B06162A475A663339380DC80700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD10B28D76463E48443F4B
62585B584C55120D2801053103093E030735564C69745E6D785B6A7D5D6D8262727B647A
2E254A372F5489728A7A64811712440E0C436E57778D616D98646A9A656A9C696C9A6968
A27571A27772A27872A37B75A9837BAB887CAE8D7EAD907FAE96848C7968A89788B29E90
B5A0939C8A7FA29084BAA798B9A699BBAA9DBCAD9EB9AD9FB9B1A6B9B3A8BBB4A9C4BBB4
C4BAB7C5BCB8C5BFB9C6C2BDCAC5C2CCC8C4CDC8C4CCC8C5CBC8C6C9C6C6C8C6C3C9C7C5
C9C7C7CECCCDC9C9CACBCACCC8C6CACAC9CDC8C6C8C8C6C9C9C9CBC7C6C8C5C3C6C1C0C2
C0BFBFBFC1BFBDBFBDBABFBBC6C8C7C9CCCDBEC1C4B7BBBBBCBDBEB8B9BAB7B6BAB3B4B7
AFB0B3B0B3B5ADB0B1ADAFB1ADB0B2A9B0B0ABAEB1A7AAADA8A9ADA1A5A99FA3A69A9E9F
979C9DA6AFAE9DA7A9A8B3B8D0DCE3B6C5D096ABBD59799983A4C0BFD6E2C3D4DFC3D5DF
C2D1DCC3D4DFC5D3DFC4D2DFC3CFDCC0D0DBB7C8D88298AF6F889A6E85925C6F7E7B8994
717E8777868A7683866D787B6873736474705E716F5D6F7A09193D010C42011040223651
4D6368546763566660535F5E4A576008182B425A672635390BC80800FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B68A685E525666626E
685F654E46510A082402053102083D050A3B494161705A6B7C5E6C8261718264776C5A74
1510355F517290769056476D0B0C441B1649795D7790626E97636A9966699C6B6D9D6D6D
A07170A27672A77A76A37974A78077AC877BB18F82AE9283AD95868A786AA49388AE9C91
B29F95928074AA9788BAA597B8A699BAA99CBBAC9EB9ACA0B8AFA5BEB6ACC2BBB1C2B9B4
C3B8B6C0B6B4C4BDB8C6C0B9CAC5BFCCC8C2CECAC5CCC8C4CBC7C7C9C5C7CBC7C7CBC7C6
CAC6C6C8C6C8C8C8CAC9C9CBC7C6CACCC8CDCDC8CDC8C3C9C9C6CBC5C4C7C3C4C5BDC0BF
BBBEBEBFC1C2BABDBCBABEBDB8BCBDB8BCC0BDBFC3B9BDBEB9BABBB6B7BAB5B4B9B2B4B8
AFB2B5ADAFB3ACAFB1AFB5B6AEB6B7ACB6B6A9B0B2A6ABAEA0A4A8A3A7AAA1A5A89CA1A1
969C9CCBD5D4C8D1D6959FA99CABBE7E97AA8399AE2745656988A5C2D7E4C5D5E0C5D4DF
C3D0DDC4D2E1C2D0DFC3D1DDC6D2DDC5D3DE96A5B7394F6A415A709FB2BF8D9DA98A98A0
AEBDC375878A8A9A9B69777967737163736B5F72705F6F7B07153C010E410F2247506371
596C6B596A64566561556464465562091A313852660D20310C8D1200FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B92C6E5A5C5A5563
635D66453F4E030223020532030B3D070D3B3E3954644F5E7B5E6B81616F826679534664
1C173B7865838E76952B2456070C473B315D89667A91616A915E659968699B6A6D9E6C70
A37174A37272A47571A47973A98177A98477AD8C7FAF9183B09586A38C7F88766C98877E
938178A59285B6A292B9A495BBA89BB6A499BCAAA0BAADA1B6ADA1BAB1A8C4BCB4C3B9B5
C4B8B5C2B7B3C7BDB8C8C0BAC9C3C0CCC8C6CCC8C7CEC9C6CAC7C6CAC7C8CAC7C7C8C5C3
C7C5C4C8C7C9CBC9CDCBC9CEC6C4C8C7C5C9C5C2C6C2C0C5C6C5C9C4C3C5BFC0C0BDC2BE
BBC0BDB8BDBAB8BCBABABEBDB8BBBFBCBDC2BBBBBFB7B9BBB5B6B9B3B3B8B7B7BBB2B6B9
B0B4B7AFB3B6B4B7BAA4AAAD868C8E909798ABB2B3A1A8AAA0A6A9A0A6A8AEB4B7BBC1C4
959C9F9CA6AA9AA4AD9199A5717F93748DA0AFC0CE90A3B1B7CAD9C6D7E0C8D6DFC9D6E2
C1CDDCC3D1DFC0D0DDBFD0DAC7D5DFC7D4DE93A1AEABBECD9BAEBEA5B6C1BAC7D07D8B94
94A2AA77878A6F7E7F69777569787466776F62747063747E09173D02113D374D63586E71
596C6A596B6859676753646B2C3C510B193B0D2144031432088C1700FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0052B927826B676E6876
68606E3730450203250209310913400A11395F586F6C5A65795F698163707E667A382F4D
322D4E816F896E60830B0D46070B455A486D8D6574915F67915E619867679E6F709C6A6E
9B686BA06D6DA3726FA47871A77F75AC887BAB897CB19083B29485B39889A99283A18C80
A99488B8A294B6A090B8A393B7A495B9A79BBAA99FBAAAA1B7ACA1B9B0A7BEB7AEC0B8B0
C1B8B1C1B7B1C5BCB5C8C0BBC6BFBED1CBCEB8B1B4C0BBB9C9C8C4CACAC6C7C7C4C6C5C2
C5C3C2C3C3C4C5C3C8CBC8CDC8C4C9C7C5C8C5C5C6C4C4C6C5C7C7C2C3C4C1C1C3BCBEBC
BABEBCBCC0BCBABDBBBABCBBB8B9BABABABDB8B7BBB5B6B8B7B8BAB5B7BBB5B8BCACB2B7
AFB3B8B2B4B8B8B7BC9392968F91928E91919FA3A4A5ABAEA2AAACA1AAAC9BA4AC8A99A5
929EA98C949CB1B6BFC8C9D4ACAEBACED4E0D5D9E4A4ABB4CCD5DEC7D4DCC6D4DDC7D4E0
C4D3E0C3D3DDC2D2DEC2D1DCC3D3DDC3D2DF9DB1C197ADBCA8BBC877899884929E75818C
7A878F7D8A90737E7F6E7A7A68777565757063737167757E11204107173A4B626F576C6C
5B6E6D56686A54656D3B4D61061236010C39000D39020F3409122900FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0057BB24876C6166606C
67616F252138020526121B3B3841621317386960746D5B66725C6679616C79667C201C3D
4C46657B6B8834305B050D4718164A785E7D8C5E6C92606892606399696A9B6A6B9B686B
9A65689E6A6A9D6C68A1736DA87F78AD887EAF8C81B39185B49386B69788B69B8CB19A8A
B59D90B7A092B39D8DB7A292B9A496BAA899B7A59ABCABA3BAACA4BAAFA7BEB4ADC2B8B0
BFB6AEC0B7B0C4BCB5C7BFBBC6C0BECBC6C7C8C3C5C7C5C3C6C7C2C5C5C1C5C5C1C8C6C4
C6C2C2C1C0C1C8C7CBCBC8CCC8C3C7C6C5C7C2C2C3C2C3C5C3C3C5C0C0C4BEBDC2C1C1C4
BBBEBEBCBFBFB8BBBBBABCBBB8B9B7B8B9B8B8B8BAB5B7BAADB2B7A8B3BDA7B4C1A0A7B5
A8A1AFBBA8B4BFA0ADA3858FA58D93A09094ABA2A7ADA9AEA5A7AA9DA6A998A3B02B4361
5F72908D8296B792A6CA9CB0B7869AB7879BC094A8A37E90C9B5C4CED0DBC5D0DAC4D4E0
C2D3E0C0D2DCC6D4E0C2D0DBC2D4E0B0C7D84764815E7B927A8F9D637583899AA49EABB2
7A88909EACB1707E7F6C79796976766675726976766A767E22324C0A1C3B526B77566C6C
566B6F4C616E2F405908163C000836010938010A37010D330F162E00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002DDD119B7866524850
67626F16162B0308252E324B47486125233C6B5F7074606B735C6777616D6D5D75130E32
5A5275675D820C1145060F4A392F5C83607A8C5E6B905E66915F6497646A9C676D9C656A
9A63679D6668A2706DA3756FA77F78AF8982B28F86B19085B59487B49587B5998CB59E8F
B49D8FB7A191B7A191B59F90BAA496BBA799BAA89BB9A99FB6A9A0BAAEA6C1B5AEBEB1AD
C0B6B1C1B8B1C6BDB9C5BCB9C6C0BDC6C3C0C9C5C5C6C3C2CBC9C5C8C5C2C6C3C2C5C2C1
C3C0C0C3C2C3C6C6C7C9C9C9C7C5C6C2C0C2C4C3C4C2C1C3C1C0C4BFBFC4BFBFC3BDC1C3
BABDBFBCBFC0B8BABEBABDBEB9BAB9B6B8B9B2B4B9ABB6C393A8BF6A7D9B6A6A89967491
AA6781B0566BAF445995283C9D394AB05B69C07C89C595A0B4979EB4A8ADA8AABA384E75
273A6C765A7C771D3B8915318E132C8F14298D152E8718307E3349D9C3CFCACFDAC3D2DE
C3D4E2C3D3E0C2D2DFC4D1DDC4D3E09BB0C14D67835E7890ADBFCDBACBD48B9CA5B7C5CB
84929A818F94717F826C797B6976776777766775756B777C424F630618354660734B666F
42596D17284B020D3B000839010636010736010936020B321D243A148E1300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C6346584A4E
6E69770D0C24090A264D495D453F543A334972637175606B6E586277616F5B4D69110E35
656085302E5D040D4A0C114A655177805A70845C6A865C678D616897656C9B646A9D666A
9B64689C6769A16F6DA47772A77F78AD8781B39087AE8E81B29284B49688B29789B29A8B
B69E8FB6A090B8A293B7A193BBA597BBA799B5A498B6A99EBAAEA4BCB1A8BFB4ACBEB4AE
C0B8B2C0B9B5C7BEBBC5BDBAC5BFBBC4C0BBC8C4C1C5C0C0CBC6C7C7C4C4C5C3C3C4C2C0
C2C0BFC1C0C0C2C2C1C8C8C6C3C3C2C0BFBEC3C2C4C4C2C4C5C3C7BEBEC2BABDBEBABEBD
BCBDBDBFC1C1BCBCBEB7B7BCB6B6BAB1B6BBA9B6C47490B136527E7A7099914D709D2845
A61329AF0E22B70D1FB80D1DB40D1DB11123A41326A5273AAB4657C88290C39CAD807A9C
17225777638B7B1D3897071BA40414A60514A204139F0719860D21C18C98D4CFD9C5D1DC
C5D3E1C4D1E1C4D2DFC4D2DEC6D3E1A1AFBFBACBDCB6CADB8C9EABAFC0CB80929C819098
808C9379868A727E826F7A7E6B797B69797868777567767664717D101F3A253B5C213658
04123F000C4100083E01063A010536010734010B35010D3030394A1E9A1D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AC815C77696A
5A566609092219152E5E51623F3448453E5272626F745E695F4753776171463B5914163E
565B870B124A040E4D211F507C627D7856666749586247537A5A6492676E9A676B9D6569
9D67699C6869A47172A47574A97E7BAC867FAE8C82B29183B69687B49788B39888B59A8B
B79C8CB89F8FB59F90B7A193B5A294B9A799B5A699B5A89EB9ADA4BBAEA7BDB2ABBEB3AD
C3B9B5C1B8B5C2BAB7C4BCB9C7C1BCC7C3BECBC7C4CCC8C8C9C7C7C5C6C4C1C2C1C1C0C0
C3C2C1C2C2C1C2C3C4C2C2C3C5C5C4C2C2C1BFBFC1C0C0C3C3C2C4BDBDBFBEC1C2BCBEBC
BCBDBCBCBEBDBCBCBFB7B6BBB6B6BAAEB7BF839DBA2045797D7EAD974A6AA4172FB70D20
BE0917BC0712BD0610BC070FBB0510BB0511BA0915B40817AE0D1FA013289B2B42A75D7A
54325E553B638C4057930B1CA40210A8020FA5010DA3020E970817903D4AE1CBD6C8D0DC
C8D5E4C6D2E2C6D3E3C4D1E1C1CFE392A5BB869AAB8A9EAC778B9B8496A380929A788790
94A0A77C888D727B806E7A7D6A787968787667797565777565737B2F3E5A000E3D000B3F
01074000094200063D01083B0106350009320110331F33492E3C4429A92900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005AC83B837574
7272820809232B243A615260332A3C514C606C5E6E725D6A735A677860723F3456151E4D
26356A010D4B050D49473E657B5E73694A586A505B5F4A55553F4988666C97686D9B666B
9D69699C6869A37072A67778AA7E7EAD8681AE8C82B29284B59585B29685B09682B49A87
B49A8AB49C8CB49E8EB6A292B7A596B9A89AB8A79AB7A99FBBAEA7BCB0AABFB4AFC0B4B1
C2B7B5C3B9B6C3BBB6C4BCB9C4BDBAC4BFBCCAC6C4BDB9B9C7C6C6C4C4C3C1C2C1C1C0C1
C1C0C0C1C2C0BFC1C2BEC0C1C5C5C5C4C4C3BFC0C1C1C2C3C0C1C2BFBEC0BEBEC0C1C1C3
B8B9BAB7B8BABCBCC0BABABDB3B6BBA9B8C7375D8B34538AA2779E9C1933B80A1CC00914
C10711BF060EC00710BD060EBB060FBC070FB90913B50C16AE0D19A50A199F0B1D971025
922644863654B55B718F0D1DA10311A6010FA6010DA4010B9D051280101DD1A4AFCECED9
C8D3E1C5D2E1C3D1DFC6D4E49FB2CA24405F5E789199AEBD7F92A2899CA9C0D3DC86969F
95A1A978858A6F7C807180826A797A67767567787666777663737C1D2C4A010A3F010742
01064100073F01083E01093A000B3502123222384C4C636C28393B47463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064D1448A797A
4C4C610407233A344661566129263A4B4F6A403F5B64596E745F6F766075392E550F174E
091653020D4B16194E6F60806F54667559657659616F5660533F4B74595F8E666999686B
9C696B9D696AA06E6FA8797AA97E7EAB8580A9887EAE8D80B29283B09482B09682B29884
B79D8DB39B8EB7A091B7A294B8A697B8A698B7A598BAA9A0BEB0A9BCB0ABBEB3B0BEB3B1
C3B8B6C4BAB7C1B9B2C3BBB6C4BDBAC6C1BEC4C1BEBCBBBAC3C2C3C5C3C4C2C1C2C3C2C4
C1BFC0C1C0C0BFC1C1C0C3C4C3C4C4C1C1C1BFC0C0C1C2C3BFC0C1C0C0C2BDBEC0BEBEC0
BCBCBEBDBEC0BBBCC0BABEBFAEB5BB9DB2C81640776273A5964B6BAE1229BF0917BF060F
C20811C10612BF0511BC0510BC0610B70D13A7161BA42F379A37438E303E88202F8C1424
971125941227A92A3D9E12219F020FA4010DA5010BA3010BA0020F910A189F5563DBCDD7
CCD3DFC6D4E0C6D3E0C8D6E698ABC06D87A087A0B4A3B7C4C3D5E18598A391A3AE81929B
828E96768188707E83697C7D6A7A7A6D7B7B69777766767763737C293956010B3E000741
010743000A42010D40000F380618352D44524D646A52666A2A3B3D51514A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0061CB3BA28D8D
4D4D65060A254740505B505D1D1F3B17224E030B3C3433566A5C7069586F2E2650040843
010949030A453C37617E6982685061775C697758646D546050404B6751578B6467916064
9865699D6A6DA27072A7797AA77F7DA8827EAA867FAF8E84B19386AF9584B19683B09583
B49A89B39B8BB5A090B6A093B9A599B8A699B6A499BAA9A0BFAFA9BFB2B0BEB4B3BEB5B3
C4BAB8C2B9B6BFB7B3C0B8B5C2BCB9C6C0BEC6C2C0C5C4C2BFBFBEC0BFC0BEBDBFC1C0C1
C1BFBEC2C0C0BEBFBFBCBFBEC2C5C4C1C4C4BCBEC1BFC1C4BFC2C3C0C3C4BBBEC1BBBEC0
B7BABDB5B9BCB7BCBFB7BBBCB2B9C092A8C1133B77737CAF984461B21126C00716C00612
C00712BF0511BF0713BA020EB50510A6181BC47070A87E857963706A596B68506881556E
893D54851C308F0F219C0917A0020FA5020DA504109E010DA0020D990612811B2AD9B6C2
CDCEDAC5D3E0C4D2DFC6D4E392A5B6A4BBC9ACC1CF7B8F9C8597A283939C85959D87949B
7E8B917681866D7C7E6779796C7D7E6C7C7D6A797C6675786270783A4A62010A3B010941
000942010D4103143F192E463F55604C62644F636353676831424451554E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005BC22E886F6A
3A384F0F122B534958574B5B0C1032020B400209451B1E4B62597066566D25214C020944
0009471012456B5D7E776074624C5E7059686E57635F4E5A4A3C486850578A6164925E63
9D686CA26F70A17071A37676A37A77AB847EAA847DAF8D84AF9185B19788B29787B69A89
B49A87B6A08EB49F90B6A294B6A297B6A59ABAABA0B9A9A0BFAFA9C1B3B0BAB0AFBDB5B3
BCB5B3BDB8B5BEBAB6C1B9B7C4BDBBC3BDBCC7C2C1C5C1BFBEBDBCC0BFBEBFBFBEBEBFBE
BEBFBEC0C0C1BCBEBFBCC0C0BEC4C2BFC3C4BCC0C3BFC3C7BEC3C3BBC1C0BFC4C6B7BEC0
B2B9BCB4BCBFB8BDC0B8BCBFAFB6BD98ACC4163E7A616FA5954968B11327C10918BF0512
BD040FBC040DB9010CBB030FB20812AA3336C39594A59DA299A0A696A0AA7E879B515873
4B4665735572813C54831525970A169B030E9600099501099C010C9A020D880A1CB37685
D8CFDBC7D3DFC5D3E0BAC9DD647D97738FA3657F8D6D8592879AA493A3AA829097A7B2B8
808D93798589707E7F6372736B777B6B7A7D6575766574766573794B5B6F010C3C000B41
020E3E0C1D41394D64566B725163655165645267644E6563364C4D47504C1E981200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002FE115B09284
3F3B4F1B192F5C4E5D473C5103062D020942020947101343665D77675B731B1A48030A47
030D47312F5977637C7E66765848585B505E5A4F5A50475346374473535C8C5E64915D62
996568A06E6EA27372A57778A67B7AA7807CAC867FAF8D83B19387B19488B29688B39887
B49A88B69F8EB39F90B39F91B29F92B4A398B8A99DC0B1A7C0B1A9BBAEA9BCB1B0C1B6B5
BDB5B2BEB8B5BCB8B4BFBAB6C3BCBABFBABAC6C1C0C5C1C0C1BFBDBFBDBBC1C1BEC0C2BF
BCBFC0BEC1C4BEC0C4BABEC1B7BDBCBBC0C1BCBFC4BCC0C4BCC1C1BDC1C1BFC2C3B9BCBE
B9BFC1B3B8BCB4B8BCB6BBBFB1B8C0A4B7CB214880415A969D6588A7162BBD0816C10513
BF040FBE050DBB020DB9020DB20713A73338C3999AA6A1A19BA2A3BAC4C5AEB6BD959EAD
75859C3C4B694542637B547281273E8C091895020E98020B9C020B99010B930617822939
DEC4D0CED4DDC6D5E29DAFC918375B58799297B2BFA3BBC5899CA5B8C8D08F9BA5838D95
7B868C728083758183717E7F6C797A6877786778776678756776795A697905143904153B
2638514C616D5A6F725F7373596B69546765516868425C6038505835434525A21E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B89683
352E402C273C5E505F342C44010630020A43030A470B0F3D655E794D45630A0C3C020B45
0B11445E55767F65797E6473554B594B4857484453433B49543E4A774E578B565E965F65
9B656AA16E70A47274A57778A77A7CAA8080AA837FAE8B82B19085B19286B29686B19685
B49A8AB39B8CB49E8EB19D8EB7A397B4A398BEAFA4C2B4ABC1B3ABB9ADA8BBB0AEC1B6B4
C2B8B4BEB6B1BFB8B4BDB6B4BCB8B6C1BFBEC3C0BFC3C2C0C0BEBCC3C1BFBCBCBBBEBFBF
BABCBCB8B9BDBBBDC1B9BEC0BBC1C1BCC1C3BDC1C5BCC0C3BEC3C3BDC0C2BFC1C2BABBBE
BDBFC2B9BDC0B2B4B8B4B8BCB2BABFAEBCCC4669971C41829A82AD941D35B60A19C10614
C20410C0050EBF0510B9030FB50815A3272EC69495A7A09DA0A5A4A9B3B2A3ACAE939BA1
8D9AA596A7B9798BAB25315C785C827B1D34980818A004109E030D9C010A990312800C1C
C28F9ED3CFD8CCD5E49CACC17B95AF95AFC38EA2AEAEBFC983919C7D8893838C977C858C
7B868B737E82747F816F7E7E6C7B7B697979677A78677876677777617277273B4A3E5261
566972586C6D5C6F6E6174725C6E6E52686C425B69152C4223394E27394244413800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C49F84
382F3D3D374A5D515F231E38030732020A400109420D123D63607E282547010639020A41
25254E76647D816172826170634F5C4A3D4E4F42515A455276515C8350598F565E996167
9F696FA16E72A27074A5787AA4797AA87F80A98380AE8A80B49486AF9182B09583AE9585
B3998AB4998AB49C8DB39E90B8A59AC2B0A7C5B5ADBEAFA7C2B4ADBAAEA9BDB2AFC1B7B5
BFB5B3BEB6B0BEB5B0BFB8B6BCB8B7C1BFBEC4C1C0BFBFBDBEBEBCC0BFBDBCBBBABAB9B9
BDBEBEBABBBDB7BBBCB9BEBDB8BDBDBCC1C3BEC2C6BABEC2B9BEBFBBBFC0BDC1C3B5B8BB
B8BABFB9BBBFB6B6BAB5B9BCB3BABDAFBAC2809ABC16407F7078AC93425CAE1121BF0815
C20612BF040DBD030FB90311B204119D121CC27E82AB9F9D9DA3A2939D9E9DA8AAA3AAB1
8D97A0B8C6D1C8D8EE415985283064804D6D880B219703119601099D030C9E0211900819
914152DFCAD6CDD1DF8C9AAB97A9B98B9EAD788A99808C9787919C7A848E9FA8B2838D93
7782877983876F7B7C717F7F7281826A7A7B6679776879786978776175715C716E546768
596B6E5C6F705D70705C7174586F7A364E63091D40000F38192C492037424D4E4800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BF9570
3F31374840515B4F5E15122C020831010A3E010941151B4955577A0C0D3802073C060B3D
574F6F7D6274845F6E8C64728862716B49596B4957774F5B875661864E5890575F996167
9C666CA06C72A37175A27576A57C7DA67E7EAA8480B08C80B08F7FB19381AF9282B19688
B19789B3988AB49B8DB9A499BCA9A1C2B0A9B9AAA1C0B1AAC1B3ADBBB0ACBDB5B0BDB4B0
B8AFABBEB5B0C1B9B3BEBAB5BBB9B6C0BFBCBAB8B5BFBEBDBDBCBCBCBCBDBABAB9BBBABA
BCBCBDB3B6B7B5B9B9BABDBDB8BCBEBBC1C3B9BDC0BABDC1BABFC0BBC0C0B7BBBEB1B6BA
B4B7BCB6B9BBBABABDB4B8BAB5B9BBB3B9BEA7B8CC32558A2E4B86A57E9E99182BB90A17
C10610BD030CBC010DB6010DB3020DA70A16B05057B49999A2A5A48F989AB7C0C6D3DAE2
A3A9B4A6B1C0B8CADD6A81A611255B715E877818318D05148D000696020A9F0211980516
7D1223D4AAB7C6C9D9687C947B90A3677B8B7B8D9C8C99A3B9C3CD84909A919DA588969B
758085768183707D7D7684846E7D7F6A7C7E6779796679776878775F736C60746F5C6F6C
5B6C6C5E7274576F764C647721385A041644000C3F010C3C0C193C2035444E504E10CA08
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0069D547
5B48484F4354594D5E0C0A2702083005103D010A3B202855383F6901063A02073E1A1B45
6D5E767E5F6E8059678B5E6E885A6B8554667543537C4655844D5A8A525C9159609A6368
9D676D9F6B6F9F6C6EA27372A57979A67E7CA8847DAD8A7FAF8D80AF8E80B29387B3968B
B09589B0968AB29A8EB7A298B9A69DBFADA5C0B0A8C0B1ABBEB2ADBAB1ACBBB3ADBDB4B0
BFB4B1BDB4B0BBB5B2BAB6B4B9B9B5BABAB5BBB9B6BAB8B8BBBABCB8B8BBB5B5B9B5B5B7
BBBBBDBABBBCB4B7B7B9BABCB5BABBB9BEC1BABCC0BBBEC2BCC0C4BBBEC2B7BCBEB1B8B9
B5BABBB6BBBCB3B6B8B2B6B8B2B6B7B0B5B8AFBAC57791B51136727F7EAE913750B2131F
BD0811BD040BBD030FBA030FB6010EB107129D2029C28E90D2CCCC9EA5A9A1A9B1B3BBC3
9CA2AE8592A4617A92ADC7E0324A783C41727C3E5E870B1C92020C94010A99020C96010D
890A19A7616FB9B0C23F58757D98B0A6BBCBB3C3CF7F8D9597A4AD808F977482897A898C
778488707E7F6E7D7D6C7C7C7382846C7A7C6A797A6576756977766374726274715E7070
586D70576D7A354C68091D4900124A010C4A010B46000A3C04103622364C424A4E209914
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064CC3A
735A5557495850465906042204082D3137591A234825325D161F5002084002073B322E52
74607280606E845E6C845A69875A6B8351617843537D4654824B588A535E935B63996268
9A65699C6869A47171A57574A47676A47C7AA6827CA9887EAE8D81AD8D80B09285AE9185
AD9185AE9589B19A8CB39E92B8A69BBCA9A1C1AFA8C2B2ADBEB0AEB7ADAAB8AEABBCB1AF
BDB1B0BAB1AFBAB4B2B9B4B5B7B4B4B9B5B3BDB8B7BCBABABAB9BCB8B8BAB8B8BAB8B7B8
B9B8B9B8B8B8B8B9BABBBFC0B8BDBEB8BDBFB8BBBFB9BCC1BABCC2BCBDC2B8BCBFB2B7B9
B6BBBBB6BBBBB1B4B8AFB4B7B6BCBFB2B9BBAFB8BBA1B4C72A4D83324B88A475989C1829
B70A13BD060CBE0510BB020FB7010EB40310A10D15B46568B4A2A1A1A6A996A1A88D99A1
BBC5CC96A4B25C758BBDD7EA7B95B911265A745B8376112695061594000A97020C97030D
950713831A28AA8191929EB199AFC180939F8B99A17F8D927E8B937B8990758389718082
7A86896F7E7E7181816C7B7D727D7F737F7F6C78786975736C78786676766073745D7379
465D721C3156021144000C48010B4B00094D010A49010A3F010C37263C56313E4625A21F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0064C933
8264575C4C5742394C02021F0C0D2C58566D262948222E5B020B40020741010336373152
725D6D7A5A6884606F835D6B815865875A677A4955804C58834F5B8E5965915A64925C61
9965689B6968A1706FA67575A57577A67A7AA47E78A7857CAD8C81AF8F81AF9082AC9081
AF9486B19A8BB39D8EB8A596B9A89ABDACA3BCABA4BBAAA5B9ACAAB7ACA9B8ADABBEB3B1
BAB0ADBCB3AFBBB5B1BCB6B5B6B1B0B9B2B1BAB4B3BBB8B8B7B6B7BCBCBDB8B9B9B9B9B9
B5B6B6B3B6B5B8BBBBB7BBBBB7BBBCB8BCBEB9BDBFBDC0C2BFC1C4BBBCC1BCBEC3B7BABE
B9BBBEBBBDBFB4B7BCB4B9BDB1B8BBB0B9BAB3BABCAEBAC36681A7133677837DAE8A2D45
AE0E1BB9050DBA020EB9010CB9020EB7020EAD0810A13136BE9698AEACAFA2ACB18E9BA3
D1DDE4C9D7E08DA1B1A0BCD287A7C91B396D454678752F4C8C071B93010D95000A97010B
98030E8706108D434D9388927F8F9D7E929E8B9CA59FAFB67D8A93A2B0B788969D738284
7A8788718080717F806E7B7C6E7B7B74827F6976756A777766777763797D5A6F7D344B67
0A1D4C000E49000A4B00084A01094A020B4E020D4C010D4107183C374D61233139453E34
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0065CA30
9B786562505637304103041D242036625769252441111B4B010A43010842010638393454
745E707C5C6C805E6D886170845B698256617F505A7E4B55824C588A535F8C575F905D61
9664679B696C9F6D6FA47173A57376A47777A67E79A7837AAC8A7FAF8F81AF8F82AF9184
B29888B09988B29C8DB4A192BDAC9DB8A69BBEADA5BDAFA9B7ADA8B7AFABB5ADA9B7AFAC
B3ABA7BBB2AEBBB2AFB8B2AFB7B3B1B8B4B2BAB5B4BAB7B7B7B6B7BAB9B9B9BABABCBDBD
B3B5B6B7BBBAB6BABAB6B8B9BDBFC1B8BBBCBFC2C1BCBEBEC4C5C9BEBFC4BBBFC3B9BBBF
B7B8BDB6B8BCB6B9BEB5BABDB3B8BAB4BBBBB1B6B8AEB6BB9BACC521447C3D528D9A6786
9C1426B60815B9040FBB0410B9020DB7020CB406109D121BB87479D5C8CCCED3D997A0A9
A8B6C0A6B5C08496A927486D5882AD5C7FAD12245C78567B790C249505139B030D970109
97000A92030C8018209B777F5E6C7996B0BC899EA8BACBD386959D7A888F7C8A92738185
717F807382826F7C7D6C79796B7A7B6778776B7C7D64797B59727A4C677C1F345B021247
010C4C010B4E01094E010A4D010C4D000D4C0110490D1F473C51645367701C29304A443D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B28C706856592B26350505193933446053621B1836040C3F010A420D184B1018442F2B4D
715F737B5E6D7E5C6B865C6C8759698657647F4E587F4C5587535D8C55618F5B63966467
96656899686B9D6B6FA26F72A47275A37677A77F7AA58077AC897FAF8D81AF8E83B09185
B29889AF9789B29B8EB6A092C1AD9FB9A69DB9A9A2B5A9A2B4ABA6B6ADAAB6ACAAB8AEAC
B6ADAABBB2AEBBB3AFB8B2AFB6B2B0B8B4B4B8B4B5B6B4B6B9B9BAB5B5B6B9B9BAB6B6B9
B6B6B8B7BABABBBDBFBABCBEB8B9BCB6B8BABDBFBFBDC0C1C1C2C6BABCBFBABEC1BABCC0
B7B9BCB8BABDBABCC1B4B9BCB3B8BAB3BABAB5BBBDB1B9BCAEBBC85C7BA21335738C80AB
8C263DAE0C1CB60410B6030EB7020DB7030CB4030CA709129F3C42BF9FA4A9A7AE9AA0AC
7585989AAFC1BACCDF3F5C7E557CA1A2C1E3173063524B7B71233E90081A9D02109C020B
99010B97030D870711925059A3A0AAB1C4CD8091998393997D8B917E8A907D898F7A888B
707F81738382707E7E6B79796C7C7C67797A6B7E845B74813954710D235400104E010B4E
020B5000094C01094D000C4E01104E03184A21375C50657658687056686C222F35474543
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
B18565735D602A223308051B4E45535C505D13113202093D020A412C325F1E2048211F40
7164777F6372825F6E83596886596785586283555D804F578957618C58638C5860946266
96656599696B9C6A709D696FA37174A47777A87D7BA9837CAD8A81AC8B81AC8C81B19485
B29788B0988BB1998DB39C8FBBA498B8A59BBEAFA5B3A9A2BAB2AEB7AEACB3A9A7B5A9A8
B8AEACB8AFACB7B1AEBAB5B2B3AFADB8B4B4BAB6B8B8B6B8B7B7B9B7B7B9B9B9BBB8B8BB
BABABDBABBBDB9BABDB9BBBEBBBDC1B8BBBDBCBDBFBCBEC0BDBFC1C0C0C4BFC1C4BFC1C5
BCBEC0BEC1C2BCBFC2B2B9BBAFB5B8B5BCBDB2B6B9B0B8BAAEB9C095ABC5173B774B5A94
9C5E7C9D1122B30512B7040FB8030DB7030DB3020BAF051097131DBA7E85B7ADB4C9CED6
7F8EA1849BB0CDE0EE97AFC188A5BBC1DAF15268931F2A6274486E7D0A209803129E020E
9A000D97010D92051282242F9B7E868E969C909EA67D8C92A9B6B9838E938793988E9DA1
7181846F8080728283697A7B697B7D63777E566E81263E6303164F011054010C54000A50
00094D010A49020B4A000F49091E4C3B536F5D73815F7277617274596C6F2D3E453E4042
1D961000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D6B436F555422192B120E22594E5A564A5909072B02093C070E3F55547B2B284D151739
6E647979606E7D5C6B855E6C8A606D855A658557607C4B538351598C5861905C62956166
9765679D6C6F9E6C729D6970A06E72A57778A37A77A57F7BAA8781AA897FAB8D7EAD9282
AF9585B19889B29A8BB59E90BAA59AB4A398C0B0A6B1A49DB9ADABB3A8A6AFA5A4B6ADAB
B2ACA8B7B2AEB5AEADB7B3B1B6B4B1BAB7B4B6B2B2B6B4B4B8B7B9B9B9BAB9BABBB8B9BA
B8B8B9BDBDC0B8B9BDBCBEC1BBBFC1B8BCBDB9BBBDBDC0C2C0C1C4C0C0C4BEC0C4BEC1C5
BBBFC2B9BDBFB9BEC1ADB6B8B0B7BAB6BBBFB3B7BBAEB4B7ADB7BDABB9C84C69991A3879
9983AC8A1E33B10B1AB6030FB7020AB6020CB4020DB10410A10914A0464EC3AAB3D8D8E0
B3BCC98EA2B591ACC087A4B64B687CB8D0E39CAFCF1529605143746916308F06179A0212
99020F96010D970410800D19956168A3A2A7B0BEC585969DA2AFB48994977B878C768387
7281846D7F826E81846C7F84647A8548617A122957021454000C55010953020B53010A50
01094D020C4A020F470A2049476177677D86657A7C5F73755C7171566B6D3C4F562F3639
229D1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB21F7E625A2119261F192A60525E4A3F5006062A0107371F224B6A6582312E510E1135
6C647C78606F7A5B69835E6C885F6E85596785546085525C88555C8D59618F5A62925D65
98646A9A686C9D696F9E696FA37074A57579A57B7AA47D7AAC8680AE8B80AC8E7FAB9181
AC9385B19787B09786B49D8FB6A097B6A29AB9A89FB8A9A3BBACAAB3A6A4B3A9A7B4ADAA
B0ACA7B3AFADB1AEADB3B4B2B0B1AEB6B7B3B6B6B3BEBEBDC7C8C9C4C6C8BDBFC2BABCBE
B5B6B7B7B8BBB6B8BCB7BBBEBABFC1BBC1C2BCC3C4BCC2C4BDC2C5BFC1C5BFC1C5B8BCC0
BBBFC1BABFC1B7BCBFB6BABEB4B8BDB2B6BAB7BABFB1B5B8AFB5BAB0BAC389A0C0143978
5B669D8C48669F0C1FB20210B7020DB7030DB4020EB1020FAA0612941B25B7848CAAA4AE
9DA7B3687F982A51778BB3D08EABBEC5D8E6C8D7EC3F537F262E63744262800A20910213
93000C94010C96010C8A071286353D9F8F91ADB6BC8593997E8B907E898B7C8688758083
7281846D7D806A7D846379883C5675081F53001258010C5701095401095000094F01094C
01094C010B48031242415B72647C846B8081687C7B6076755E7374596D6F4E60651F292C
27A32000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4FB61D7458471E17202E283363555F39304604072D040A34413F5F6E647B3A355506072F
665E7A7760717C5D6B815C6A88606E8559668451608856628857618C5863915C66945F69
925E669561669A646AA16D72A16F73A57578A67A7CA57D7CAE8680AF8A80AE8E80AE9282
AC9282AF9584B19988B39B8EB59E96B6A29AB6A59CB9ABA7B1A4A3B7AAA8B2A6A3AEA5A2
AEA9A5ADA9A7A8A7A7979998939695ADB0AED1D4D4DBDEE0DBDFE3DBE0E3D6DBDFC0C4C9
B7BABDB3B7B9B2B7B9B7BDBEBABEC0B7BBBEB7BEBFBBC2C2BABFC1B8BDC0BCBFC3BDC1C3
C1C5C6BBBFC0BBBCC0B8B9BDB2B5BAB5B8BDB6B9BDB2B6B9AEB2B6B2B8BEA5B4C936558B
203D7F957AA28B172CAD0716B7020EB6020DB2000CB3020EB1030F9D0A18A553628D808E
CDD9E593A9BF1D446B6E99B6C6DEEDCBDBE4CAD9E7889BBB0F215667567F6E142D8B0517
92010D95020A96010B9304107D121CA1777986878A8793967A888A8D9B9B8A97996B797B
7182826A8081607A87355173061D5700135A010F5C010C57000C51020E4D010E4903124C
010B48000D431F335559727D657A7D6A7E7E677B7B5F74775D73775B6F73596C70152227
463E3700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
58BD217C5D4620151C3A2F3A675763261F3904082E0A0E325B556F726478433D5D060834
50496B755F727B5C6A7C5B66825C698257648758658656628C5B668C58638F5B64905C65
9563699766699662679F6B70A06E72A47578A57A7DA88081AA8280B18B84B29085AF9181
AF9381AE9381B09886B0998BB5A197B6A49BB6A69FB6AAA5AA9E9BB0A5A1B0A5A1B0A5A2
ACA5A2A29D9B949392A7A7A6AAABA9C6CACACFD3D7BEC0C7BEC2C8CFD4DADAE0E7D2D6DD
B6BAC0B7BBBEB6BBBCBABEC0B8BBBDBBBEC0B5B8BABEC3C4BEC4C4BABFC1BDC1C5BEC2C6
BCC2C4BABEC0C0C0C5BCBDC2B9BCC2B7BBBFB6BABDB1B6B9AEB3B7AEB3B8AAB4C1788EB4
103373696FA18A3C56A50D1EB70612B6020EB4010DB5020EB5030FA90613922234876473
C4CCD8C8DBE97D9AB4769CB4C0DAE7C9DBE3CAD7E5BFD0E72C417033396C70355782091F
8F010E94010A94000894030C860813934951908184BEC6C98F9DA08796968A989D607376
6A7F81637F89304D70041D5900125C01115E010F5D010E5601124C061B492E456A1F3563
020E47010F40425D725D767A65797B6A7E7F657A7E59727C4B6777445E6C5069721F3138
3C3C3A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0087604425141941333F66596717143203072F1E1F406C62767464774D4467070B3C
3C39607461767D5F6D825F6C8057668358668A5D69895A648C5A64905E688D5B65905D65
93616797676B97666A9C696E9F6D72A27377A6787EA67D7FAB8482B18C85B29185AF9183
AE9081B09281B29888B39F90B5A296B6A59CB1A29AB3A69FB3A6A2BAB0ADACA39EADA5A1
ABA6A2908C8AADABA8B0B0ABAFB2AED3D7D89FA2A8B3B4BCB7B9BFB6BEC2D8DFE3DADEE4
B9BDC4B9BDC1BCC1C4BABEC2B6BABEB5B8BCBABDC1C3C7CABDC1C4C0C5C8BEC4C7B9C0C4
B9BFC3BCC1C5BDBFC3BCBDC1BABDC1B4B8BCB7BBBFB3B8BBAEB3B7ADB1B6ADB3BDA2B2C8
2D4E822A447E997394931528B10616B5020EB6020DB6030EB6010DAF0310960B1AA86472
9C96A89BB0C37E9AB130566FB9D5E4C9DAE3CBD7E3C9D7E96F82A90F1E576D517C6F0E27
8B031393010D94000993000A900411841C279F777E98989C8993997B898C7482865B6D72
657C8938547403195702156200105F01135F02145B021651172E5746607A506983081D49
02134A051743526D7E60787B6A7E7F677C7F627886334B6A08204B041D4338546B2C4550
2D31330EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AA7F5E2C171A4D404A5850600A0B2B04082E3D3953695B6C6E5E7253496F06093E
2726536E5D757C5E6D805C6C8159668458658759648957628B58628E59658A5562915D65
9462699A676E9B676D9E696E9C666BA47275A97A7EA3797AA9847EAD8C83B19085AE8E81
B19285B19286B2978BB49F91B6A497B5A29AB5A59DB4A79EB4A9A4AFA6A2AAA29EABA4A0
AEA7A58D8987B0AFACADAEABB5B8B6CED2D39B9DA3B2B3B8B2B6BAB3BCBED5DFE1D6DBE0
B0B3BAB8BCC2B5BABEB7BBC0B8BBC0B9BEC1B9BEC1B9BFC2BAC0C3BAC0C3B8BEC1BABFC3
BEC3C6BCC1C4BEC1C5B9BBBFB7BBBEB2B6BAB6BABEB4B9BCB3B7BCB0B4B9AEB3B9A4B1BD
6882A710346F77749F872D44A80B1DB60411B8040EB6040CB4010CB1020DA50715932D3E
745E7A647E9DA3C2DB638398C8DEEBC9D9E1CBD8E2C9D7E3B4C5E01D3162413E70682341
85061994020E96000C94010C9402108408169B58628F8387838B8E808B8F76858A62767F
475F7D061D5801136001136400115E011559061E53314C6D556F82577182294061001344
1A35660A1D46557081627A7D667D82617A8833496D05174F01115001124A13294F3B5467
1C262A1E981300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00AE815A2C18154E424A453F5106092A0C0D2F584D62695B694D43595B5779080C3E
101344695D7A7D61727F5C697D5964875E6A895A678956628B57628C58628D58638E5960
9461679A676D9C686F9B686C9E6B6EA57476A6787BA97F7EA9857EAD8C82B19084B08E81
B19184B09388B1988CB39E90B39F93B09D95B1A299B0A49BB0A7A0ACA3A0ACA4A0B1AAA5
B2AAA78A86859A999BB1B1B3ACADB0C2C6C9B9BCC0ACAEB3ACB2B6C6D0D3D9E1E5C7CCD2
B8BAC1BABBC2B8BBC1B9BBC0BCBDC1BABEC2B5B9BCB7BEC1B7BFC1BEC5C8BBBFC2BEC1C6
BEC2C6BDC1C5BABDC1BEC0C4B8BBBFB2B7BAB3B9BCB2B9BBB4B8BDAFB3B7B0B4B9A7B1B6
9AABC2224479334780956384961126B00413B6030FB6030EB4020CB1020BA903118F0C1F
8C56713F4C6BAFCBE1C3D9E4C9DCE6CAD8E2C9D7E2C6D7E3C6D6E85C7095152255704A6E
760A1E90021193000C93000B93010E8B04128329349B8082999D9F939FA26D7D875D748B
0E285B03176302136603166401145719305F4C67805F788361778149637A061D490C2251
3A55800316404B66805D7786557085254169021753010F54000C50000F4A0214423A536C
121E272A631D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00BA8E5C311C11574B51352F430407281C1A356456655C526222223B5D61810A0F3C
050A3C544D6F7A61737C5966825D68855A698A5A6A8756638C5B6585555E8C59618D585E
9360659B68709D6A719F6C71A06F729F6E72A5777AA87D7FA88380AC8B83AF8F84B19084
B19186B3968BB0968AB29B8EB39E93AE9B93AB9C93ADA199ACA39DA9A19DA9A09DB6AFAB
ACA4A2A49E9E8A878A8E8D918D8E91B1B4B6D4D7DBD1D4D9D2D7DCD3DAE1BFC6CDB4B7BF
B7B6BDBBBBC1B9BAC1BCBDC3BCBDC1B9BBC0BBBEC3BFC4C8BCC2C5BEC2C6BCBFC3BABDC2
BBBFC4BCC0C5BFC1C6BCBDC2B7B9BDB4BCBEB2BBBCAFB7B8B1B8BBADB4B7AFB3B8A9AFB3
A8B5C05B769B12316F8376A386233CA90A1AB20211B5030FB4020DB0010CAC0210A00919
98394C99879D92A6BBC9DFE9C9DBE4CCDAE4C7D7E3C4D6E1C6D5E3A4B5D1132656534973
6D1D3685041390010C91000A93000C91020F7C0C17A06E72898484818E916D7F90263F69
021A60011466021463041B5B29416A587085657A8164797D5C74831C33590116482F476C
455D7F001244183061374F7C162D6201175A02155F010F58000C51020D49001042283E5E
192735312B2600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0058C22C402615564A5028223B0408282F2C426356624841560A0F2F5A6084161A4A
01073D3A385E725D727958667E59667F56658557668B5A698856638857618B5A618D5B60
9360669663699C696E9C686DA06E72A16F73A77579A77B7DA98381AB8983AD8D83B09084
AF9285B09488B59A8EB59C90B5A096AA978EA3948AA99D95A99F9AA19796AEA4A3ABA2A0
B1A9A7B1ABA8ABA7A5ABA8A7B2B1B0ABABADABABB0B0B3B7B3B7BDACB0B8A6ABB2A6AAB0
B2B3B8B8B9BEBCBEC3BCBEC4BDBFC3BDBEC2BBBDC2B7BBBFBCC2C3B8BCBFBABDC2BABEC3
BCC2C6BAC0C4BCC1C6BDC0C4B9BCBFB2B9BBB6BDBFB1BABAAEB7B8ACB5B7AEB6B9AAB1B4
A8B1B993A7C018377145548D9055749B1125B00314B50210B3020DB0010EAD0110A70411
92142595687C5F6E83C7DDE9CADAE4CBDAE3C9D9E2C7D7E0C8D6E1C4D5E742587E2A3262
6F3E607A0B1E8F021093010C95010B94010B8706108B3F439581817D868D576D89051C5A
011767001563051C5A365073627989697C81687B7C627880324B69021949112853576D83
52677F03154800135600115A00115D00106101105F021059010D52000E49000F4217294C
2736482F2D2E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF005EC42B5433205547511C1834070A2C4A43596557672D28450409324E537A212452
030940161845685A737B5D6C7E5D69805966825663875564824D5D8854628B5A658B5A62
91606596666A98696D99696E9E6C719D6C70A67778A67B7CA67F7DA9857EB08F85AF9184
AE9284AF9488B1978CB49C93B39E96AB978FA6958CAB9E96ACA29DA09795ABA1A0A69C9A
ACA3A1B5AEABB4B0ADB6B3AFB5B2B0A8A6A5A6A5A7A0A0A1A3A2A6AEADB2A5A6ABA5A9AD
AAADB1ADAFB3B1B4B9B7B9BEBDC0C4BDBFC4B6BABEB9BEC1B9C0C1BAC0C3BBC0C6B7BDC3
BDC5C9BBC2C7B9C0C4BCC1C4B8BCC0B3B9BCB2BABCADB4B7AFB5B8AFB7B8ACB5B8A7B0B2
A6AFB5A2B1C244608F1735748D79A1891D35AB0718B60412B50210B1010EB0000DAB020F
980818944B5CB1ADBDCEDDE7CDDBE4CBDAE4CAD7E2C9D7E0CBD7E0C8D6E296A7C2142451
634B7370142E8A041593020E95010B9200098D030D7A151D9E767C7F8595223A68021A65
02196905215E3D597B637A876A7E816C807F6B7D85496078081F4C051D4B455D786B7D86
657685132750021358010D5D020D61000C5F011060011058000F4C071A4B0719410E1D3C
3748572C2F310EC90700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0067CA306D48354F414D13102E0F0F305B516660546915123903093840446B32355E
040A3E05093B4E48677661727A5A697C56647F53618553618A55658C5767905F6A8A5B64
8F606794656C996A719D6D759F6F749F6F72A37676A67E7CA98481A9847EB18E85B09085
B09489AF958BAF968DB39E93B09D93AD9992A8958EAB9C97A89E9BA79E9CA89F9CB0A6A3
B1A9A5B4ACABB9B5B4B6B5B3B4B3B1B4B2B0B0AFAEA9A6A7A09EA1B4B3B7A7A7AB9DA0A3
A3A6A9A5A7ABABAEB2B2B6BAB7BBBFB2B9BCB7BDC0B8BFC2B6BEC0BDC4C7B8BEC3B9C1C5
BCC3C8BAC1C7B7BEC1BCC2C4B9BEC1B4B9BDB4BABDB1B6BAB4B8BCB0B6B9AFB7BBA9B3B5
A6B1B4A7B4BE8298B9133573525C918E49679E0E20B30513B60210B4020EB1010EAF0210
A40516922A3AEEC6D5DCD3E1D8D1E2D7D2E4D5CFE1D2CCDED4CCDFD3CADFCDC5E0494168
583A5D84334A8404168E010E93000C92010B8F020C7D06108E505D77758E0A1F5B011867
0721643D5C80627B88667A7D6C81826D8389596D8510265200154826405F657B876E8183
6D7E883F5471031551011059010D5B010E5C01115B0217530F2651445A7534475E07172D
42555E2A31321C941100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF007F593E5448530B0A281C1A3665596B50465E070833030A3936395C474668
02053401063B262850695F75765C6B7A55627F546181505D8854638A55648C58658E5D66
93626B9A6871A06E779E6C75A07074A47478A5787AA57C7BA98380A98580AF8E85B09188
B0938BAF958CB0998FB29D92B09C93A9968EA99791AC9B96AC9E9BB1A6A4ACA39FAFA7A2
B5ACA8B3AFABB4B3B2B5B7B6ACADACB4B3B2B0ADAEACA7AAACABAFAEB2B4ABAEB0A3A6A8
A9AAADACAEB1A6ABADB3B9BCB3BABDAEB6B9B5BBBFB3B9BCB7BFC1BCC2C6BBC1C5B3BBBE
B6BEC1B3BBBEBABFC3BEC3C6B9BDC0BABFC1B4B9BBB2BABCB0B8BBAFB7BBADB5B9A8B1B4
ACB3B7A8B3B89FADC23453861935739578A089162CAE0A18B90613B3020FB1000EB20211
AF04179C0C21B44C66AA57749E5170974C6A9548679145669043668E41648D3F637C2C4F
862E4A8B1E328903138F010D92010D91010B8F010D8806147A2435624E7008195C031E64
37537F678091697E83677C7E678188567289142D5800164B142D535871816B7E836D8080
6D7D82697C8B21365C01144E0012550112560218511C395E4E687C5369714D5F6B041626
485C632B3536219C1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00946D4B4539430607242F2842695A6C332D48050C35050C374B4A68595370
05063102063C080D3E4F4B6B6F5C6C7A5A647C535D804F5C804B59854E5D8A55618F5C65
92616996656D9B6B739C6E759E72779F7578A6787CA97E80AA8281AA8682AE8D87AD8E88
AE928AAB9289B19A8FB39E94AD9991A7948EA8968FAE9F98ADA19CA79C9AB2A9A5AFA7A3
B1ABA7ACA9A79D9E9F9B9CA0AAABAEADADAEB7B5B6ABA7A9AAA9ACB1B4B6B1B4B4AEAFB0
B0B1B3A6ABAEA3A9ACACB2B5B2B9BCB3BABDB7BBC0BABDC1B8BCC0BBC1C5B9BFC3B8C0C3
B5BDBFB6BEC0B8BFC1BAC2C4B9BEC1BBC0C2B4B8BCB3BCBEAFB9BBB2BDBFADB6B9A9B1B4
AEB3B8AAB1B6A6B1BC798FB112326F6267998A415D9F1021B40715B2020FB2020FB0030F
B20212AD0417A70720A00B26990823980B249507229407229005229007238D04208D051C
8E05198F021390010D92010B92010B90000A8F000C8B0310780E20643F630B1758112D65
65809A6F848D6D8286677F88527089123160011D540C28534D677B667A806D7E7E70817E
6B7B7B6F7E83607382263E5B0C234D1029512E4A66607D895F787C536B6D495E67071B28
485F6533424126A31E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0072943B3A2D35070823423B51675A6E1A1936020B3414183C5F5771685D76
0B093101053B01073E191C485D536E795D6B7E556181505C84505C8954618C5865905F68
906268986A719A6E75956D758E6A71967378A47C81A47B7DA88080A78280AD8B87AC8D87
AF938CAB9489AC978AAD9A8EAB9A91A8978FAA9A92AC9F99A69C99ABA19EADA5A0B2ABA6
ADA8A68C8C8A92949695989C828489AEB0B3B2B2B4A1A0A2B2B4B5AAACAEBCBDBFAEAFAF
B5B6B7AEB2B4A2A7AAA9AEB1B6BABEB8BCC0B3B7BCBABEC3BBBFC3BABEC3BBBFC3B7BCC0
BAC0C3B9BFC2B6BEC1B8C2C3B6C0C2B6BEC1B3BABDB2BBBEAFB8BBAFBABCACB5B8B0B9BB
ACB5B8B2BBC09DA6AFBCCADD425F8F203B778C779F86273CA51020AE0714AF0410AC0410
B00511AE0511AC0512A60411A306119E07129B05119604109806139404129203108E020F
90021190031090020C90020B8F030D8D020C8F020E8B030E7A0A196F42600E17521B386B
67869E69828E667D903F597B0C285B001F5A0D2C5B4B687E60797E677A7B6D7E7C70827C
6C7D7B6F7F7F6A7B7D5F767B5B747F5D747D60767B6279795B7172536A6C425864071C2C
485F663C4B4B41393000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0052BF2F281C200A0C24514C5F5C5468080C2C030B322D2D4C66596C6A596D
1C163A02053901064102073D27264F6C576E78536182566183535E83505B8A576190616A
93646B96696F996F7687636A896B747C616A95777D9F7C7EA47E7FA68281A98785A88984
AB9086A99185AD988BAB9A8EAA9A91A99C94A79B94A69C96A09693A59B97ACA5A0AAA5A0
9B99979A9E9DCDD3D2CACFD191959BA3A6ABABACB09397999EA2A4A6A9ABABADB1A3A6AB
AFB2B6A6A9ADA2A6AAA2A6ABB3B6BBB4B7BCB2B6BBB3BABDBBC0C4BBC0C4BEC3C7BCBFC4
BEC1C7BABEC4B8BDC2BAC2C6B9C1C4B7C0C2B5BDC0B4BCBEB0B9BBAFBABBB1BABEB0BABC
BBC6C9D1DDE2A3ADB7A9B5C08AA0BA2E4D7E32477C8A70968A374F921A2A98111F9C121C
9D12189C1618961618961B1C911A1D88161A8B191E86191D851A1F7F171D7B131879141B
79121C760F187B12197C10147D0F157C0C12810D157A0C126914198566761924550A2661
3B5C8C416088213D6D031D5A021C59163260536E85687F86687E7F667A796D807E6E807D
6A7D7C6D7E7F6D7D7D697A7A6B7C7B6978766977776678775A6E6E53696E2E45550E2337
4D626B49595C43413B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0058C3303321201310255D566747435902072B060C315049616F5B69715C6C
3126460304370105410105410708385343617452637C525F7F525C82525A8A5B6291636B
94656E966A7190676F936E7795767F755E677D686E9E7D81A78184A88284AB8787AA8A86
AC8F88AA9186A99489A9978CAF9E95A2948BA0968D9B948B9F9791A0969297908B9E9A94
A8A8A4AFB4B5D9DFE2D7DDE2A1A5ACA9AAAFAEAFB39DA2A5A3A6A896999BA4A6AA9FA2A8
A0A4AB9B9DA39DA1A79FA4AAB3B7BDB3B7BBB1B7BBBAC1C5B6BBBFBDC2C6BCC3C5BFC4C7
BDC1C6B9BDC2B9BCC2BDC2C7BBBFC4B9BFC2B4BBBEB4BBBDB2BBBEB6C1C2CED7D9B3BDC0
ABB5BBAEB9BFAAB3BBA7B5BCA9BAC5B9D0E8415F8D2E42726B658589677D87576D986373
A56E71A56E6DAB7774AB7A77AA7D7CA67A7BA67A7DA37A7DA57E809D7A7C97787E94747B
8364707B626D8C6A6E895F5E8B5F5E8D5B5B8E57598453538565638480844B5A760B2259
021F5E01205B021F58082357334C7260788B6E82887080836D7F816D7E7E6E7E7E728282
6E8081697B7D6D7C7E6D7C7C6C7A796C7A776674746373735D7072566A75152C421F384C
4F676E4E616040463F0FCB0700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF005BC32C52392F1B1223665D6D36324D050A331B1C3E615668715C67735C68
4D3C5A0602330307400206400A0A395E4D69775364794E5B7C4D5881535B8C5E679C6E78
9C6E78976B758E646E936C77896A7677616B7A64699D7C7EA78082A98285AA8687AA8987
AD8F8AA88E86AA968CAC9B92AB9A91A6998F9B92889E968C9A938AA19993968E8A9D9A95
BDBDBAB7BBBDB6BCC1B7BDC4B6B8C0ACAAB0AEAEAF9EA2A39A9C9F9192949C9B9F98999E
989AA094989F90969B989EA3B8BEC2B3B9BDB2B8BDBCC1C8B7BBC0BBBFC3BEC3C6B7BEC1
B5BDC0B5BCC1BBC1C6BAC1C4BEC5C8BCC2C5B9BEC2B7BEC1B5BCC0B2BBBFB7C0C3B3BABE
AEB5BBB3BCC2CED9DEA7B7BF9CACB7C9DBE6A9BED47F98B87D97B2A3B6CB617595425A79
C0CED8CDD2D4D1D3D4D2D4D6D3D3D6D2D4D7CFD2D8D0D3D9CFD3DAC7D0DE7389A1ADC0D6
5362754155658B959D7E8182868A88A0A19F8785878B8D8D9CA2A07985867A8892576A84
334A6F2C466B405A785D75896E838D6E82857081847181846F7F7F6E7E7E6F7D7E6E7F7E
6E80816D8082697A8064757A6576766273706476746274745C6F7745596E03163A27415E
48656F506665424B43209B1300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002EE01361412D271C246860701E1E3C040B3131314B6B5D68705B62755E69
5F4B620D063103063D01043A12103C6A567076506180536183545F885965936571986A76
996A779A6B77956B7687626D836570775E658B6D70A07A7BA67F7FA88282A78484A68785
A88C88A38B84A8938BAB99929E8E869D9187A2978EA1978E9F978D9D958C98908A93908B
ADAEADD6DADCD1D6DAD5D9DFBCBDC4A9A9AEACADAFA3A8A8A0A4A5A2A3A3ABABADA0A1A5
989B9F93979D888F93969D9FB2BABCB0B7BBBABFC7BBBDC6BCBFC5BEC1C7BCC0C5BEC4C7
BDC2C6B9BDC2BABFC6BBC2C7BCC4C7B6C0C1BBC0C4B5BCBFB5BDC0B2BABEB4BBBFC2C8CC
BDC2C8B0B8BFD2DCE2AFBCC798A6B3A0AEB9ADBFCB97B2CA5F84A7B7D9F46384A45B809F
C7E2EECEDFE5D0DDE4D1DCE3D3DBE3D0DAE2CCD8E1CAD7E2C9D6E2B4C5DC223E655F7D9A
74899A6B7E8BADBDC5A3B0B688959BC5D3D994A1A77B898C808F917787897B888D76848B
73838E6F828C7084897183867484877083837385867284856F7F7F6C7D7B6D7E7C6F8280
6E82816B8182566B76364F5B5B72775E72705E72715870754E657A12244A000D4001123E
233C554E686F4755522F6A1E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006F4929342225695F700F0F2F080C304D485C6F5C61715C5E755E65
6C586A1B133702043503063A19174169546D7753627F545F8355618659658E606C92636F
9969759A6B76986E78946D77906D759A787D9D787BA57D7FA67E7EA67F7DA4817FA48683
A18681A18A83A8948BA39189A6978EA4988EA1948CA2968E978D85958C839A918997918B
989594B5B5B7C0C2C6B1B3B7A0A1A4A0A0A4A6A8AAAAAFAFA6ABABACB0B0AEAFB3A5A6AA
9B9EA2999DA2888F929DA5A7B0B7B9B2B7BBBABFC4BEC2C7BDC0C5BBC0C6BAC0C5BBC1C4
BDC1C6BDBFC5BFC1C7BCC2C7B9C1C5B9C1C4B8BFC3B7BFC1B6BCC0B4BCBFB4BBC1D2DBDF
CAD0D6AFB6BDAEB7BDB1BBC4AEBBC995A9BCC8DDF0728FB50D39735982ADA3C2DAB2CDDF
CDE1EAD0DFE7CFDCE4D0DEE5CFDDE4D0DCE5CDD9E5CDDAE6C9D7E4B1C0D3596D8AA1BBD1
B8CBD9899AA8A8BBCABFD0DE7E8E9B83949D808F9678888A798A8D79888C7A878D768286
7785887585887284857385857386866F84836D81817688887282816F827E697B796F8281
6E81806A7E7F3F56650E273E57747D566E71556D763B546A11254E020F45000945000B41
03143C3B576848595B3C372B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00875A31422A2763576B09082B131435655969715C5E6F5A5A715C60
6F5C6934294703033103053A1B17416C566F7854638157638458648D626D91656F93646F
9969749B6D77996F789970789D747B9F777BA37B7FA67E80A67D7EA57E7DA3817EA58582
9D807CA3898299837BA6948BA3948B9E9389978C839A8E869A8E869D928A9F958E9C948D
948F8B9995939998989A9A999A9A97949493A3A6A7A4A9AAACB1B2A5A9ACAAADB1ABADB1
979A9F95989C8E92969BA3A5B3B9BBB3B8BBB6BEC1BAC2C5B5BDC0BDC5C8BCC4C8BCC4C7
BAC0C5BAC0C6BAC0C6B8C0C4B7BFC3B8BEC4B8BEC3B5BBBFD1D5DAC2C8CEB2BBC1B5BEC4
B2BAC0ACB7BBA6B2B6CBD7DEAABDD5415F81A6C0DB9CB5D343648E6489ABA5C1D2CCE2E9
D0DFE8D1DEE6D0DCE5CEDEE5CEDDE4CBDBE3CCD9E5CCD9E4C9D8E2C3D4E399ADC55D7D9B
98B7D19AAFC45B6E828393A47B889476848D88969A8191927B8A8D99A8AB768588798789
7583857382847584847383847283836F81826F82847283857181816D807F6C7D7E6E8182
6D7E81697E7E4F6573051B354E6C7E4D6A7B2B4262051643010B44010A45000944000B40
000D3C243C564B60633F3E3400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF006986254D332954495A0606282626426B5E68725F60705D5F6D5B62
715C6A5647620604300104371C1A416C59707955647F54618459658C626C906670946973
956973986C769B717A9E757D9D747C9E747AA2787CA07678A47B7CA37B7DA47D7DA58181
9D7B799B7E799B857CA08E83A6968DA4978E988E85948A819C9389A39A90A0978F9D968E
95918A9B9891989691A09F9A93938E91928E989B98A3A9A8A9AEB0A7ABAFA5A8ACABAEB3
95999C8D8F938E9195959C9FB4BABDB8BEC1B0B9BBBAC3C5B6BFC1BCC4C8B9BFC3BCC2C6
BBC2C8B1B8BFADB5BD9FA9AFB4BCC2BDC3C7C2C8CCB7BDC1BEC5C8B8C0C4B8C1C5AFB9BC
BCC8CCCADAE0A4B7C1C1D3DDB8CCE2607A9A92A9C29FB4C4B6D0E56388A4A6C4D6CAE0E7
CEDFE7D2DFE7CFDBE4CEDDE5CDDDE5CADBE3CCDAE4CDDBE5C9D8E7B2C6DAA5BCD61F3E63
40617F8298A9798895909EA9B4C2CA808E969BA9AF9FACB17C898F78868B768589758384
7683857684867681837583847583846D7D7D6F80837080857281856F81836B7C7F6B7D7F
6A7C7E667A7B5E7280081D3C314B6F102851011145000945010846000842010B42000C41
010E3C10223E496062484B3F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0047AF195B3D2D453B4C070829403C536E5E676F5E63594F5A544B5D
6C5C6E64546C110E3604083919183F6E5B737C5967835B678C656E8B636C8C646C936A73
966C769D737B9B72799F767F9D737C9A6E779F757A986F71A0777AA57D81A47F829E7A7B
987876A38984A08D84A4948AA18F879C8C85988D849A91879F988DA1988EA39B93A29A96
95908B9E9B949D9B95A09F9A9B9B96999B96999C97A3A9A6AFB6B6AAB3B59EA5A7B4B6BA
A0A1A694959A8C8F938D9497B2B8BBB5BCBEAAB2B4B9C1C4B9C1C3BCC4C8B9C0C4BFC5C9
B1B6BDADB4BBB8C0C6B3BCC2BEC7CCBDC5C8BDC6C8B7BFC4B6BEC3B8C2C4BFC9CDADBBBF
BECDD3CBDDE6899DAAA5B7C2AEBEC9B6C8DB8EA9C793B3D0AACCE42A5474B3D1E7CDE0EA
D0DFE7D2DFE7D0DDE6CEDCE5CCDBE6CBDCE6CDDBE6CBD9E3CBD9EA677C948498AE768DA0
7E96A6BFD4DEA6B5BE909EA8BFCED98D9EA67B8A907D8A8F7A878D7A888C7A898D798889
7686867283827182817283837482837383826F81836E81847382866E7F816E7E816C7E7E
6A7E7F61767D556C830D204B011148000B48000846000846000845010943010D41010F3D
020F3C041533465E634C564A10CC0800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004FB41A6B4936372D3E080728524A606855605F5364171837101534
5A546A675A6D2E284904083614133E6D5B747D5C6C825D6A8E67728B646C936A73976D76
9970799C747C9B717A9C737C9D727C9E737C9F767BA0787B9D7579A0787DA17C7F9A797A
A08381A58F8A9F8F889D8D859C8A839C8C859A8E859A91879D968C9F989199928D9D9792
96908B99948EA2A099A09F9B9A9B979A9B99979997ACAEADA2A9AA9BA5A799A2A4B3B4B8
A7A5AB94959A8E95988D9699A7AFB1B4BBBDAEB6B9BCC4C7BDC4C8BDC3C8BCC3C7B9C1C5
BAC3C6A8B2B5B1B8BEB2BBC0B6C0C3B6C0C2B1BABEBDC5CAB5BDC2C6D0D5D2DEE6ABBAC2
AEBBC4B0BFC6B2C3CCAABDC9B0C5D2C1D8EE2C52831C4A808BB0D381A1BACBE0EFCFDDE6
CFDCE5D0DDE6CFDDE6CEDDE5CEDBE5CEDCE7CBD9E6CCDAE5C7D7E77A91AABCD4EABFD4E3
879CAFAAC2D3B3C5D27986957583917B8B947A898E86959794A1A77281859CAAAF8F9FA1
7486867286846F827F70817F7583847180826C7E8172868778878A7484866F7D826C7F82
687E87536C811B315B010F46000949010847010847010846000843010D4102153D142D4A
1025440113303D565F505D55219D1400FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0057BB1D7B563D2E202E0D0C275E54646A5B6639344E040B35030D36
464761675C6D4F455E0608320C0E396C5E7B7C5D6E86616F9269788D6571926872946A73
997078966D76966C75996E789B7079A4787FA3797F996F72A07779A2797BA27D7E987978
9F83819E88839D8D869D8F86A2948C9E8F889D8E889C90889A918CA9A29E9B979298958E
98948D9A968EA4A39AA4A39F9A9A99999998989898AAA9AA9A9B9D8E94968A9092ACAEAF
B1B0B49FA2A68B9396929B9FA6ADB0BCC2C5B6BCBFBAC0C3B6BDC1BABFC5BBC1C7B7BFC5
B5BFC4AAB5B9B0B7BDB9C1C6BEC7CAB6BEC2BCC5C9D5DDE1BDC5CDB6C1C9BECBD4ABB9C1
B1BDC3B2C1C6CCE0ED87A8C47598B7B2CEEA42648E2E588587A4C1CDE0EDD3E0E7D4E0E7
CFDCE5D0DEE6D0DEE7D1DFE6D2DCE5CFDDE7CBD9E8CBDBEBC6D7F15B749B5B729EA5B1D5
707696464B66969AAB9398A47D85917C8A9277858D8D9FA3BCCBD27E8C947B88917B898E
78888A7386847484817382817381836F7F807184847083847587897486886E7E86657B89
3F57780F2556011350000C4A01094A010848000845000940010C3D0B1D40324B604C6773
4A617105172E38515E4F5F5A336F2300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF007C53342519211B182C675D69655968181736020A37030B38
34345465586A68596C1E183C070A345E55757A5F72866373916A7A8F6675916873946874
916770916870956B73996F789D707AA0737BA1757B996E71A07578A4787AA17A799B7A77
997C79A087839E8A849D8C84A5958EA3948D9E9089A09390988E89A59C97A39D97918E85
98958B9490889A98939999979A9A9A919190969595A8A7A79A999A9E9EA2929495ACAEAE
B5B7B6A2A4A4999FA299A1A59DA3A8BCC1C5BEC3C6BCC2C5BDC3C7BBC1C5B2B9BEB5BEC2
B2BCC0A6B1B4B3BCC1BBC3C9C1CACFB9C2C8BDC6CBCBD4D8B6C0C7B2BBC2B8C2C9CDDAE1
C5D6E0ACC0CBC5DBEC4165854A6F9298B1C9A6BED791B3D086A4BAD1E3EDD3E0E6D1DEE4
D2DFE7D2DFE7D1DFE8D1DEE7CFDDE8CBDEEEC3D6EFACC0E17880AE3C356C4F2F68683462
733256753754A16C84C8A4B69A889783858D8188917C8991818E9A74838B717F87758388
79878B7584847585847182816D7D7D708181708282718383748688728589637886253E63
03195601145A000F57010B4E010748000845010C4102143C1C304B475D6953686E586C6F
5D6F78142738364E5B50605F4A453700FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00845B3524181F2822356C5F6B51475808092C030B3A020A38
312E4F6E5C6C6D56644E405B08072F45406379647889697795707F956C7A926673946773
916672916870986E769C727B9D727B9D737BA1787D9C74779F7578A4787A9D75759D7A77
9C7E7BA08682A28A86A28D879F8C869B8C859B8F889C928B9A90899F9590A49B95968F88
948E86928D8893908E9999989293928F908E9B9C99A4A6A49E9FA2A2A2A79B9B9FAFB1B1
B4B5B4B0B2B3A5ABAE98A0A39FA5AABABEC2B6BCBFB9C1C4B6BFC2B8C0C3B5BEC1B7BFC3
B9C1C4AFB9BAC0C9CEC1CCD1C9D5DCB1BEC6B4BDC3B6C0C2C2CCD2C0CAD0BFCAD0D2E1E9
8DA1B398AEBFAEC2CFA6C1D1A7C6DE92B1CABDDBF5486E8F7C9FB7CDE1EBD2E0E7D2E0E6
D2DFE7D1DEE8CFDEECCADDEEC6D9F4A2B6DB656C9B5B497C6A376B75214E7D0E35870726
8C06228807218209267D15317B2E448F677493898E81878E79848E91A0A67B898F788389
7C878B7A88897A8A89798A8A778688738484697A7A6B7E7D707F8272848A54687E02194E
00115D00105F020F5B000A52010849000C41081A3D2D46584F6A6E576D6C576869596A6A
5E6C74182938364F59526264514E4600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF008D61362112143831416E606A3C324604072D030A3B030A39
312B4D6D58696E525E70596D20173A27244875657A816372906C7B9268759265718F636E
916672906670966B759C727B9E767EA17A819E767D9870759B7275A178799871729A7776
A0807FA186839E8581A18B859E8A839A89839B8E89998F899C928CA29894A49B979C948F
9C94909A94909997949B9B9A969796929492979997A2A4A59C9EA19B9DA1A9AAADAFB0B2
BFC0C2B0B6B8A6ADB0959DA1A9B1B3B3B9BCB9C0C2BAC3C5B6BEC0B9C0C3B6BFC3B8C1C5
BAC3C6C4CFD0C5D1D4B4C1C7B2BEC6B2BEC3B7C0C7BDC6CAD8E3E9D1DEE6B7C4CDBBC9D3
A9B9C7AFC3D0A4BCC6C2DDE9779DC12B5A8D769EC96E91AEBBD5E6CFDFE8D1DEE7D1DFE9
CDDCEACBDCF0C4D7F599AAD363639763497F783B6E801E478A0B2D94061E970115970211
95010F9301119201148D021786071B731526B88E97C7C2C7869198A8B6BC8C99A078848B
7B878D7C8A8B7B898A76868678878A77868A76858873858674858771848962758B04184F
01105D00105E010F5D010F55000D48152A50465F6C566E6F58706C5A6F6A576B69576C68
586A711525353A525C5366685555510FCA0700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006988271F0D0A413B466C626C262037050933010A3C030938
3931516F56687254606F536052425B1811326A5B737D606F8F6B7A916776916470936671
9265719468739569739B71799B737A9E777E9D757C956B729C73769F767A9770749A7778
987B799C817E9A827D9A847D98857E9B8A849C8E889A8E88988E889D9591A29B969C9691
97918D958F8C9E9B999999989A9B999294929C9D9D9C9D9FA1A3A5999D9FA8ABADAEB1B2
BCC1C3AAB2B3A4ABAE939A9EA4ACAFAAB1B4BBC1C4B3BABDB9BEC1BEC5C7B9C1C5B8C0C4
B4BEC0BBC6C7BDC9CAA9B5BCB6C1C8CFD9DCCBD4DAB6C1C6C2D0D7B2C2C9B3C0CAADBBC3
C7D7DFBCD5E787AAC4ACCEE93E66930D3B78416B97B9D5E7CCDFE9CDDEE8CEDEEBCCDEF1
BDCFF08C9AC6625E9367447D7F356A881B47940D2C9C061C9F02159F02119D020F97010C
94000C92000B91010C91000D90010F880619832D3DD0ADBA95949D7E8A907D8B907C8A90
7A888E7B898B7A888A78878B78888A76868978878B76868977858B75868C7083960B2052
01125A01125B0115560C215807164837506A577074576F6A5A70675B706A5A6E69576C68
50646D05172B425966566C6E5359561F981200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0043AC19250F06493E48685E6A13102C040935030C3C040A35
3C324F6E546272535B74555E6F57673628424F3E5880627386616F8F65738B606D956874
996B779C6F7B996C779C707A9B717AA078809E757B9B72749C7376976D7392696E977374
987A789C807C937B749E88819A88819E8D869D8E87978B849B928C9F9794A09A969C9792
958E8B8E88879D9A9990908F9395929394939A9B9C989B9CA0A6A69FA4A6A3A7A9A9AEB0
B5BCBDA9AFB1A0A4A7A5A9ADA3A8ADADB2B6BCC3C6B2B9BCB9C0C3BCC3C7BBC2C6BCC4C7
B5BEC0BEC8CAC6D0D2B1BCC1B6C0C6CED8DDC9D4D9B3BFC5B4C1C7C0D0D6C8D9E3B6CAD5
C4D7E4819DB81A426A84A6C28FADC886A9CE89B3D4BEDDF0C5DBEEC2D7F0B0C1E2898EB9
67568B6940787A2E6286173F960B2C9C061E9F05169E0512990511960813940B15890813
8805138C030E8F010A91010B93010D92021185081A7F303F9B808A808489808D91808F92
7C8D90798A8C79878D79888D78868A78868A7A868B768487738187738388738696152C55
021853051D532942695A728D1C2F502C445E5971765A716D5C716A5A6F695D706C586C6C
31465603162F4A626F586C6E53605B24A01A00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF004BB21C2A110451444B5D52600907260309302F345A0C0D2F
473B5272576376555D73545B775B66715B6C4E364A7E607085606E8C6370926773976977
966977976A77966A74986C769B707BA0777F9C7277986F71986F71966B6E966C6F95706F
967874947B749B837C9D87809A87809F8E87998A849A8E889B938F9E97959C97949F9996
968D8B968D8B9995918B8B879293908C8D8B979A9B959A9A9AA0A19CA0A39DA1A4A6AAAD
B2B6BAB5B7BBA7A9AEAEB1B6A3AAADA4ACAFBAC3C6BDC4C7BBC1C5BEC5C9BDC3C7C1C8CC
BBC1C6B9C0C4D0D7DCD1DAE1B6BFC5B6C1C6B5C0C5C0CCD2B5C1C7C8DAE4ACC8E07EA2BE
A9C0D39FB0C48CA0BAA2B7C8ABBED0A2BDDA4A6C95A0B8DD8F93BC7E719E7953867E3D71
802353841138910D2B980D209409168D08108D101784121880202685363B8848527B4153
7D374E7713258A041291020D95010D93000B9002107F0B1B965A648C8487858E91879598
7E8C917C8B907C8A9178868C7584887684897883897784896E7E8372848872848E29425A
1F385A4E6680657D8A687E882D42591D364E59727B5D72725E716F5A6F6A5D706D596D70
12263712273B4F696F576D6C58666135732700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0054B92031140355484F5A52640506260E11315C5A74171229
4F455470596275565D75545C755761785C677B5D6A7E5C6A845E6C9066748F64728F626E
976975986975986A749A6E78996E78A0747E9A6F769A727699717493686C93676996706E
93736F967C769D857F9B857F9A867FA290899B8A859A8E8A958D879994909D9894999390
938A8898908C96918C8A87828989848C8C88979997929797959A9C989B9FACAFB2A7ABAD
AFB3B7B8BABFA6A9ADA7AEB1A3AEAFA5AFB1AEB8BABAC3C6BDC4C8BFC4C9BCC2C6CED3D7
C0C4CAC1C8CCC0C7CCBCC3CAB9C1C7B5BEC4CBD7DDD4E3EAC5D3DCB2C6D7638AB14073A4
9DB9DBB2B2C7DAC8DBBFA7BD997D9B85678D7B59878653817F38668429548B1A40921234
99122B930C1E94111F8D18207F1D207A2C2B7E3F3E8053539075797B727E595E774A5476
2C2851693B5D780C2390041594011194010C94010E8D05168026349B8083818687808B8E
7F8A8F7E8C917D8B8F7D898C7C888B79898B77858A7381856F8083728586738588687D85
687D876B7F866B7F836A7E85455B6E0E263F57727C5D72736174735E736E5C716C5A7070
182D37385059546C6D5A716D56686146463800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002CDE103A1806594A52453F5504052522203A685F721B1325
5E525E6C555B72555B76575F7456617A5B677C5C687E5C6A896473936B7A8D6471926672
936571976874976A74996C77996D779B6E77966B73966E73956D7390666A92676997706F
95716E9576719E847E9F888299827D9C88839D8A86998B87988E8899928D9E9995999490
8F8885A29B988B86838B8884908C8893908C9898948F949291989999A0A2A9AEB1AEB2B5
A9ADB1B2B8BBA3A9ACACB5B7A1ABADACB6B8A7B0B2BFC7CBBEC4CABBC2C6BFC5C9C6CBCF
BEC2C6BEC5C8BBC1C6C4CACFD3D7DDC1C8CFC3CED4BDCCD4ADBDC6B1C5D27D9EC01B4C84
567AB38081A9774E6D823A5A872C4C8B24438D193694173395142D9213288F13238A151F
881C2380232884393D8954538A6967978683ADA5A5BEBFC5B0BCCA5E728A092247627EA0
2E436E3B3463681D3F85051A91011192010D93000C9003107C0C1A9D6A6E8B8787848E8F
818D8F7F8D8F7B8A8B7E8B8C7C898B7889897585867385856D7E7F6F8281718383718484
7184876F82856E7F826A7C815A6F7D0720375570795D72745E71715E726F5D726E576E6A
4258594F6766536967596F6B5A6D654D524700FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004C220B57434B39334B040727363349685B6A1F1322
6B5A656F565C75575F72545D6E515B7657637959627C5A66825F6C8A6271916775926774
90636F946773946974986D779C71799C7079996E76966D74956C718F6367956A6C946E6D
9A75729B7875987B77977F7A9A837E9986819E8E88A2938E978D88968D899F9895938E8A
9F9B97A7A39F908C89938E8B918D89989694999B998E9392969B9C9A9EA1A1A6AAA0A4AA
9EA3AAB2BBBEA2ABADBCC3C6A8AEB2ACB4B7ABAFB3B0B6BBC8CED3BFC4C9C1C5C8C3C7CB
BDC3C6BDC3C7B8BEC6C9CFD6DCE0E7CAD1D8BAC3C9B8C4C9C8D7DDC3D5DDB4CADD779CC8
0E397E3B56937F79A7926C908D4D6A89364C892A398827338628338330377D383B7F4745
8E62609A7D7C9B8D8DB1B1AEC1C9C7CAD7D7CBD8DCC1CFDD49627594ADC0768CA49CB4C8
7C94B6131D516137617508218C021492010F92000B90010B850511863A40968283858A8B
808B8C7C8A8B7B8A8B7C8A8C7C898C7B8A8C79898A7284847485866F80806F8080708082
6F80817081827281836C7E816577821F38465772785C73755D72725F72715C706D5A6E6A
5B6E6D516866455C5B596D6B5C6E69575E541E960F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF006032155842472C2640070A294E475A64545F291A26
6B586170575B7053586F51596B4D5670505A75545E7756607B586386606C8C636F8C606D
8E616D9669759268729970789970779B7077946971966D74956C7293686B9D73759B7676
9B78779977769B7D7A9A807B98827C96847F9E9089998F87978D88958B8899918E999590
9E9C97A4A19D99959299959191918C989D989CA2A18B909195999C959A9EA1A7AD999FA7
828992848C9299A3A6BEC7CAB5BCBFB5BABEB6BABFB4B9BEBFC5C9C5C9CEBFC2C8C5C9CE
D5DCE3D7E1E6C3CDD3B8C1C8BEC6CDBEC8CEBDC7CDBCC9CFCEDFEAB1CBDCADC5D996AFCA
4667946183B552719E596E95535C7E7E778B8A76818A6F799C838A9885899E9496ABA9A8
C3C5C4CAD1D2CDD8DACAD9DAC9D8DDC6D8DEC9D7E0BBCCDE658296BDDAE8C0D5E27994A6
8AA7C7152A5C4233646B173686031990010F92000C92010B8D040F77141C9D757988878A
7F8A8B7B87897D8B8E7B898B7D888E7B898C7382846C8081748589738184738284738084
7482837180807281836E7C817180876B7D8365797C5F77765D73725F73715E726E5D716C
5D6F6E586C6C33494B5268685B6D6B5A635B229D1700FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0076461C533D40201C370E0F2D6156675A4A56332637
5A4E5F5C4A556950556A4C536D4C56724E5974525D75545E7D57628259658A5F6A926570
946572956672966A74966D76966E769A7177976D73976D75976D75966D72986F729C7577
9A7879997B799E827F9D858098827D927F7A9E918A978D86948B848F86808F888197938E
A2A09BA4A19D9E9A9897969391938E989C979BA09F8E92968E95988F979B9DA5A97C848B
949DA39DA7AA889395B2BABDB7BEC1B7BCC1B9BFC4B6BDC1B2BABDC4CACFC4C8CFC0C5CE
C7D1D9C8D3D9BEC8CEB8C2C6BAC5C8D4E2E6D4E3EBBAC9D1AEC0CF516C8397AFC2B0C2CF
BED5E8A9CBEE739DCC8CB5DC7094AEC1D7E5CAD6DCCFD5DBD0D6DBD1DADFD0D9DFCEDADD
CDDADFCBDAE0C9D9DFC8DAE1C7D9E1C7D8E0C8D6E3C2D4E94968897092B294B0C5486178
37526F536A911C1F516C375A7A071E8F021292000C92010B8F020B7D070E9252588F8687
828C8E7F8A8B7E8A8B7C8A8B7B898E7A898C778688748588748388758386748386737F84
778286748284728084728084717E83707E836B7E80657B7B5F74755E72715E73705C706D
5C6F6D5D70702A41463E585E54696B59655F356F2600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF002E970649343316162F1E1D38685C6A4A3E4C302C45
1818371C17315A4B5A674D566F4E586F4A56744F5B78525E7C5460835765895B678B5F69
8D616B91626D946772926772956D769B737A936A6F9B7176986D7592666C9B71739A7274
9B777A9F807F9D827E9D86829B858098847D9A8B83978B849188808A827B8B867D96928A
9C979398928EA49F9C9897959395919A9C9AA2A6A88A8F937B80837C83858F989A798286
8F989D8C969B949DA0B7BBBFC0C3C7B8BDC1B2BABDB4BDC1ADB6BAC6CFD2CAD1D6BEC5CD
B7C1C7B9C4C9CDD6DCCAD3D8BEC8CCC8D7DEAABCCAB5C6CFB7C6D0B7CBD8C5DDEDB4CEE0
B7D1EC3862950B408443729CC1DEEFCCDEE6CFDCE3CFDAE2CFDCE3CEDDE3CEDAE3CCD9E0
CCDBE2CADBE3C6D9E5C2DAE7C4DAE7C6D8E2CAD7E6AEBDD6142C59062250859FB7AEC3CF
90A2B3AABED7152451513C656C112D8A051692000E90000A90010A87050E7C242A9C8183
8287897F8A8C7E8B8C7C8C8D78888B78878B79868A77858878858A738387728185727F85
738085728084717F84728183707E827181866C7F85687D806276796074745F73725C716F
5B706F5A6F70324A5219343F465D645A69674E483C00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF003BA40F3B26220E0F292D2C43695F6A3931420F1131
04083005062B494157634C56694A526E4955724C5A76515D7A535F7F54618558638B5E68
8B606A8F626D9467739469749970799A727A997176976E7390646B94676C9A6E719C7376
9C777B9C7B7C9B817D98837E9A86809B8B829889819B8D869689859187838C847F958E8A
928A87928B88A2A09C92928F9599959BA09E909798838A8C828788888B8C7B7F8294989D
7E8488878F94A5ABB0B5B7BCC4C4C8BABEC2B9BFC4C1C9CDB6BCC0BFC5C9BDC5C7BCC3C9
B4BCC3C0CBD1D6E1E8D8E1EABBC4CDB9C5CFABBBC7C3D2DBBCCBD3C5DAE985A6CC5481B1
8DB3DB48709C285488779EBDC9E0EFC9DDECC9DDEECADBECCFDAEAD1DAE6D1D9E4CED8E1
CCDAE2CAD9E8A8BDD67D9EC1ACC6E5BEC6DFC4BFD7BAAFCB584D74373356AEB6C8C5D5DD
A5B7C48299B13349732322536C325580091D91020E92010A93010C8E030C7D0C159E6A6D
8883867F8C8C7A8A8A798B8D7A898C7C8A8D7C898C7B878B79878A708085738287728183
7281836F7D80738185728081707F806E80836C8082677D7D687B7E6276775C72725A7172
596E70556B6D415A603A5760415A615B6B6A56524900FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF004BB119341C14090722403D537065722D253A030528
01042D0204293D344C644D5867494F6C4A53714D5774515A754E587D525E835561895A66
8A5C688C616D936874926772956B76946E76956F77966C7593656E95686E986F72997274
9C787B9B7B7C9E83819E8A849C8A839E90879A8B85978885998B899388868B828099918D
8E88848C898494938D8F908B90938F9FA5A37C858592999B7F8484919496777A7E95999D
959B9E98A1A2ACB4B8B9BDC0BFC2C5BDC0C5BBC1C7BCC4C8BAC1C4B9C1C4CAD4D5D6DFE2
C5CED5C0C9D2BDC7D0B4C1C9BDC7CFBAC4CCCDDCE6C6DDEFBFD7EBB0C7E0325789174A83
78A1C6A6C5DDB4D3ECC1DDF1C3DCF49CB9DC7186AE908DB1AD93B2AA86A3BC9BB7C9B3C9
D2C9DDD4D5E999A6C6122E623E4C7F563A64692A4F7126446B1D3B611E37826273A8AAB4
8494A23E5469647A9C0F1A4B6245706E0E268E051392010B94010C94010C8D09158A3B40
978586808C897B8B8B798A8B7A898B7B898C7B8B8B7A8A8B77878A75868A748285728383
7483846E7D7F6F7E816F80807082826C7F7E6A7F80697F7D687D7E6378775D7673587271
5A6F71566C6B4E64691A353F415B6358686963615C20960F00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0056BB1E4428190E0920585067706273221934020229
01032E0304293A3047644B556B4D506C4D5170505572515777535C7F56617F525F855461
8E5F6C8C5F6B90666F8F6470936874946A75946B75976A759666719568719C73779A7577
A07E809E7F7F9C817F9D87849D8B869D8D88978884988B87948B85918B8788827D918C85
8F8A858884808C8A859693908D8B899B9C9B8186878E9497818589818588818588929699
949B9DA3ADADA9B2B4BAC1C3B9C0C2BABEC3BBC0C6BBC3C6C0C9CBB8C1C5C5CED1D1DADE
C2CBD2C0C8D1B9C3CBCAD6DCD7E2E9C9D3DBC0CFE15F82A4587EA3A6BED890AACA8EB6DE
9FC9F08CB2CF8EAEC4BBD8F26484B230497F614D817C37618623488B1F41841B3F7E2449
874062A26E8CB897B94032634331636B2E55780B2C81041B8204187A081B6B1F2F95828B
BEC9D099ABB8A6B9D02E436B38346268264385071994030F93000B97010C9405127D141D
A0787A8689867F8C8C7B8B8B78878A7B8A8D768889778A8B76888B77878A768587778484
7482837182826F81836D81816E82826C80806D81826D82816B8081657B796077745B7470
586E6D596E6C586C6D243F441F3B43546969626963229C1600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00583620160B1B6F63766E5E6F140C28020329
00012D0201273B2E45664D546A4D4F6C4D5170505672515977545F7E57627D525D825560
865A64895D678D626B8E636C956A74946872966A74956771966570986B749F747A9E767B
9E7A7D9D7D7E9C807E9A8382978382978683968985958D88C4C0BBCAC8C69D9B99888480
908A8687827F8D88859792908B86869796949799998081847C7B817C7C7F90919395989A
9A9FA29EA7A9A9B3B4BBC5C6BBC4C5BEC4C7B6BABDC4CBCDD9E0E3C0C6CEC3CAD1C5CDD3
CAD3D9CAD2D9BBC5CBCFDCE2C2D3E0C2D3E1B5C4D5809CB797B7D5C0D7F0AABFD97295C4
17498A245488A9CDEA99BBDD0F316D60629573284D90112C98081F99081D990C248F0B25
840E2B811B3B7117396E23477D3A5E9745607E0C228B061689010F83020F700816946771
CED0D6C1D1D97B8DA04960820F1A4A664263750A208F021194010C96010C950210820612
9552599286887F888B7A898B7B8A8D7C8B8F748688778B8B758788778789728081778585
7382837183847183867084856C80816E83847084857084837082826A7E7D667C7A5E7672
5C716F5B6F6C596C6B49656529484D4D6A6B5E6C6942382900FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00734A272412176F606E6A5B6C0B0521010327
00032A020225392E43654D54674B4E694C506C4E5570515974545D7A565E7C535C7F545E
875C688A606A895F688F636D9569739468729367719A6C7590616A9669719C7178A1797E
9E787D9F7D809D83819A848095807E9D8B87978B87B3B0ADD5D6D6D4D6D8BEBDC1817D7E
867F7E837D7B8A8582938F8C8A87859291909C9D9A8F8E8E8F8A8D8783868E8F91909397
91969B97A0A2A7B1B2B5BEC0B7BEC0CCD1D5B9BEC1C3C9CCC9D0D3BFC6CCBDC3CAC7CFD3
D9E2E7D9E3E9D0D9E1BFCAD3899BAAABBECBBECCD8B7CCDAAFCFEE89B0D88CB0D73A6193
0E3C80225082BAD9F47597BA0F316B7D729D7919369B0C1F9F0817A10C1B9B0B1C900F1B
84212C7223356C1E386E173378143290243E890D238E07168E03108A010C880C1A7A2C3A
A9959FA1A8B06F7D8A5667821928544538606A193488051792010C93000B93010D8F0513
80222E9E7E8483878A7D8B8F7A8B8D7A898D78888C798A8A778989778889728183738284
7281847081826F80836D81827083836E81836F82827083816E81806E82806B807E667B79
6376765D6F6F57696B476166193640415E625B6C6A47453600FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF008D5D303F2520705E685A4D6105021E030426
0206280202203F3345654D52694D506A4E526C4F5671555B74565C77555C79535B7E545E
825664875A67895D678B5F698D626C92677097697497697294666E91646A996D739C7478
A17B7E9F7E7EA186839A84809F8A86998782948884B7B4B4D3D5DAD4D5DEAFADB4817C7C
887F7D867D7B847F7B908C898787848989889998989392919492938786888A8C90898D92
8C93978F989BA6AFB1BABFC3B8BDC0C8CDD2BAC0C5C3CACDC4CCCFD3DADED8DDE2C6CED2
CBD6DCBAC9D2C5D0D9BDC6CEBFCBD5D0E3F0CDE3F5B0CBE0466E9B0E4380406F9C7FA1C0
7B9BBDA5C4DECAE1F37D99BB0D2C666C62907B1E3B9A0E219F0A1AA51222970B1B82191F
B98387A189926750664C2A476122456D11307E061E8F09198E02119103109005137A0E1D
8F5E6ABFBCC2BFCAD27D8B9C3F4E73191B486C3A5C7B071D91030F94020D92000B910210
7B0A189A666E8A86897D898D7A8A8E7B8A8C7A888A788789798A8C748589748487768588
7583867483847381847282827584857181826F81817185836D81816E82826E81816B7F7E
66787A5E7273586D6F3D545B0B2531415E625B706D4E524510CB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0046AF1C78594C735D6543374A03011D080722
2D2B4405021A473A496950566B4D506A4C526C4D556F515772525977545D7A535D7D535E
825463885966895A668C606A8D636C936970986B74956771936670946870966B729E777B
9F797BA17E7DA186829E89849F8D889B89849587849B9293BDB9BFB2ADB48A8285837A78
89807B877E7A807B788D8C888B8C888989869795959393948B8D8F86878B878B908A9094
88919497A1A3B9C1C3B8BEC1B8BDC2BABFC5B9C0C4C3CBCEC9D2D4D7E0E3D7E1E4C3CCD1
B8C4CAAAB9C0CDDAE1D4DDE5BBC8D698B3D15A83AD90B4D46E90B4416C9893BCDDA7C7DB
B4CBDCC0D2DFCFDEECA1B8D50F2C6756568B752948931023A30D1FA10C1F9107187A1C25
DCBEC2D5D7DCCCD2E18C92AB3D355A502D556213337A061A8701108E0110920312870917
7C333EC9BABFCAD4DA97A6B2657390101B4757406870142C8F051496020C95010C90010E
850515873C469282847F888A7A888D7C8B8E7A898B7685887384887284886F8283728484
76858676828475808475838579898B7485857183837185846D81826D81836E81816E8382
677C7D5D7274586D6E5267692A4248365052596D6950574A0FCB0600FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0049B11B84614E71585C2F2233030219221D2E
584D5A1006174F3F4D644C50694D4E6C4E536E4F576C4D5570505876515C7A535D7E535F
8354618959648B5C678B5F6990656E91666E93676E93666F9268719369729870789D767B
9C75779D7A7A9E837F9C88829D8A879D8A8A9786869183838B7E80887B7B887B78877B75
877D77867D78827C7885807D878581908F8B9797948B8E8D8C8F917F818683888D838B8F
8A91959CA0A6A1A7AAB6BCBFBFC4C9BAC0C5CFD9DAD2DCDEC0CACDCAD3D7CBD4D6C9D2D4
C1CBCDC5D1D6D2E2ECD4E5F3BDCCDF607E9E3260899CC1DCA9C3D9AFD0EF7DA8D55C8AB6
8EB3CBCADFEBD0DDE9C5D9EF2D4B803846817E4D728C162DA10E1EA60F2098091B7E1727
C3A0AAD4D8DFCBD9E0CAD8E4A7B4CE262E59422B576D1F3A860B1E9004129302118F0513
7913209C777E93999E83939B69798C323F652824506E314D80061690010B94000C91010C
8C031079171E9A76798083857B8A8D78888C7586887385877383867385896E8183728585
7786867584857282847184856F81857284857082837386866F81847083856F83846E8583
677B7F6175795B6D6E576B6A536968485E5D5C6D695B625720991100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0053B81E835D446C55552016270402163F3741
57484D1408135947526B4F556C4F536E51556C5157694C536E4E57714C5779525D7E545F
84576382545E8658638659658D616B92656F94676D94686D946870976D759971789D7479
9F77799C7A799D807D9D85829C8787A08B8D9A898990817F8C7E7B8E7F7B8B7D77867A72
877D76887E79847B77877E7D8B86848B8A87959593898B8B898A8E88888D82848B8A8F94
8D9197979BA09DA4A7B1B9BBBFC3C8B6BABFCAD3D5C5CFD3BBC5CAC0C8CED3DBDFD7E1E4
CFDCDFBDCDD4A5BBCB748DA4B5C6D7AAC0CEB3D4EAB5DBF7ABCFF07BA0CB114083083E7F
79A3C3CCE1ECD1DEE6D1E1F06682AC152D6C735F8C76173296091CA20D1C98081B830E22
945A6ADBD5DECDDBE1CBD9E1CCDBEA6B7E9F1E295C6E456C780E268F0615940111960414
83071785454D9E989CC3D0D3A3B3BF5E6D8A0D144268486D6E0D218A031091000B92000B
91020D7F07109252588E83867D888B76878977888B74868974858875888C73868A738588
7485866F80846C7F816C81826E82837083856C7F81708385748487738585708585708885
6C7F8364777B5F7172596D6C586D6B576B695F706D5E6661356B2100FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002DDE108C6444604B49130C1B08051652454B
5342441B0D15634B566D4E556A4C516C4F536D4E556B4B53714F58734F5977525D7D5560
7C515D845664875867895A688D5F6A90646D90646C93666C94686E986C72976D72997072
9D75769F797A9E7D7B9D837F9C88869E8B899989858D7E798E80798F817C8D8078857A71
877D768A807C857B7A837A7A8781828E8B8B8F8F8E88898C84858A888990878990899093
8C94979BA3A59BA4A6C3CDCFD4DCE0BBC0C6C2C8CCC2C9CDCDD6DBC3CBD1CDD7DFD0DFE6
C5D5DBB6C6CEA5B8C6A1B9CCD0E2F1C3D6E19FBBD6356498285B97739CCC395E92385F8C
B0CDE3D1E0EBD1DEE6D0DFE9B0C3E219346D575D907333528F12259E0B1D9704188E0B1E
792032C9AEBAD0D8DFCDDAE2CAD9E1B6C7DC25386744396C6E1D3F88061C960215970415
8A0314731926A68C93C9D0D4BCC9D46F7D951B295240386368244080071790010D93000B
92010B8A050F7F252D9A7F837D82857B888C78858B77868D74878B7084877285896F8185
6E80846E81877084886D81826E82826D80836C80826D81837282867184866F84846E8685
7083856B7D806476785E72725C7070586D6B5D706E606B69433A2C00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF008E65405D46430C051219121F5A4B4E
50404124131B664B566B4B516B4C526D4E556C4A536E4B54734E57734F5877525C7B555F
8057628257648457658457628B60688E646C90666F92676E91676C946B6F956C70996F72
9F77799D787A947472967C7899837F9B888499878396868091827C8F837D8A8078857B75
887D788B817D8A807E847B7A85807E8D8A898C8C8C88898B838589878B908A8F93858D90
90999BA7B1B29CA6A9A6B0B6B0BAC0B3BBC2BCC2C6CFD5DAD7DFE4CDD7DDC2CED79CAEB7
C2D3DAC6D6DCBDCAD4C0D4E7AFCDEAABCBE883A0C418447B24548F98C0E48EABC2BFD7E8
CEDFE8D3E0E8D2DFE7D1DEE8CFE0F44C69951F37717F648B841E3595071A9D071A9B0B1D
7F0A1D905764D9D4DCCFD9E1CCD8E0CEDBEA66779E19205B62315E7D0925930418950113
9002127B08178D5562949198919EA67C8A9B3C4D6F131A466B4464710A1D8C030E910009
93000A8F030C790C1598696D8885867F8A8D7E898E78868C74858975888775888C738689
7385896F82876E82866F83847183856D81836C7F837082867181877284896D83836E8685
72868670828466787C6376775F72725B706D687B7B6170704A463A00FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF009A6F46533E390A030F2A202A604D4E
453436322027664A4F6E4E516B4C516C4D546D4B526F4C53734F5777555D74525A78555E
7D58617F58627E5660835A63885E668D636B90666F9268718E656C90676D976F72997174
A1797C9C787A937272997D7B9E88859A86849E8B899583809587819086808B827C8A807B
897F7A867E7887807B87807D837F7C8A8787918F918A8B8C898B8D878B8F8F94998F9398
9AA2A5A5B0B298A4A5A5AFB3B6C1C6D3DDE0C4CDD0C5CBD1C0C8D0BEC6CEC4CED5BAC9D0
CEE2E8CFE3EACBDBE69BB2CC28518347739FA8C5E283A5C79AC6EE9CC8EF89ADC7C6DDE7
D0DDE5D4E1E8D3DFE8D3DFE8D0DFEC9AB3D213336D5E61917B334F9612269C06189C0918
8D0717701625C9ADB7D3D7DECCD6E0CBD8E5B0BEDA1F31674F3F7570193A8D071D950112
9501118C06167A23318C777EBFC9CFC0D0D96E809912214C55456C68172E88041393010B
94010B92020B860611883E4295848381898A7D888D79868B7A898C788A8C74868A718586
7386897184886F82866F82857382857486856D80826F82866C7E857386896E83836E8382
708484708283677B7B6477766679775F74726B807E6A7C7D4F514A0FCA0700FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00719032412D2807010C3D3035644D4B
3B2729422B2F6B4C4D6E4C4D6B4B4F6C4C516E4E546F4D5474535B74555C74555C78575E
7A535B805A627A556076515B845A658A5F688E636D9066708E646C8C6269926A6C987173
9772749C787B916F729C7F8098807F9D88869B88869483809A8C86958B839189828C827D
8B827C837D7687837D868481817E7F8683838C89898A898A878A8D858C90A5ABB0909399
8F979B8A96999EACACA7B3B3B5BFC3D3DEE3BCC5CAC3C8D0BABFC9D1D9DFD4DCE1BECBD4
AFC7D89CB8CEB5CBDEA6BAD05271978EB3D9C5E5FD89A9C93F6FA30F44883D6D9AC7E2F2
D0DFE9D2E0E8D2DEE7D3E0E8D1DEE7CADDF03A5B892B41788F698B85162C9C0D209C0A19
990B19850E1E9D5E6CDDD3DCCED5DECAD7E1CAD9ED5B709A232963703C65800A23940214
9A03119404137B0A1A90606AB4B4BDC2D1DB899AAE35496E2225536D39567F081B92010F
97010C97010D8F040F7A161C9D797C8485877E888C78868976858875888A7386886B7E7F
6F82847184877082866E81856D80837284846F82827082866F82887085886E83846E8282
7386866E8381687F7C607674657A786279776A827F687D7D575E581D960E00FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF004FBA2937251C08030A493B3E604B48
301C1E533C406848486C4A4A6B4B4E6E4E536A494F6E4D5471525972525B73515C78545C
7A525A7C555F6D4A566C4A567B5561875D688C616B8F646E8E626A8E626891676B926A6D
946F719C797B9373759C7F809B83829F8A889784839A8B889A8D89948B85948C878D8380
918784857F7A87827F87848285828282807D8888868B8D917F87916975808B959B92989B
929A9D98A4A6D3E0E1C0CBCFA5AEB6A3ACB3B3BDC2BBC4C9B3BBC1D5DFE4D5E0E5C6D5DE
738A9F4E6C85AEC5D8CADBE7B1C7DD84A7D35D89BE719BC92C588F0B3D7C4C79A2C9E3F3
D0DFE9D4E0E8D2DEE6D4DFE8D2DDE6D1E0EB85A0BF133066746C95792942910E209A0C1B
9B0A1B960E20832237D3B3C0D3D5DFC9D7E0C9D8E79FB4D016295F5846777115348F0519
97011095010F8705138536428F7D87848E998294A15C708C0F1E4D6751766E11288E0515
96020E96010D94030F7E091193585D8B84867E898C79898B75868776898B7588896C7E7F
7382857282847385886F83856B7F816C80806D807F6F82836E81846F84876F8486708584
7085836C8280667E7B647A77607674607977728C89778C8B5F6A641F9B1400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0056C12E3520150E070C5142415E4A45
2716175B4648664B496749486A4B4E69494E6B4C516D4E53704F5875505C785260764F5B
7A535C77515C6F4F5B72525F7A5460855B658A5D6792636C9161698F5F66906368946A6C
9A72739B7878907271947B7A9C888695828094827F978884998D8898918A98918B918583
9186838A84808C87858C8786878281868381828384878F98516072687887828E94A4ADAF
9BA3A78C969BB0BBC29EA9B1A3ADB3A8B2B5D2DCDED6DEE2C0C8CFAAB8BFB6C6CBC5D5DA
B5C6D0B6CBDBC9E1F2C8E0F59EB8D61C457D0A3C84628FBF94B6D87D9FBCB6D5E5CFE4EB
D4E0E8D4DFE7D4DFE8D3DFE7D3DEE5D1DEE7C5D6EB2D4A784655877A4F6F8111278F0515
990819960818830B1F9C606FDBD4DCCCD6DFC7D7E3C4D5E84D648E252A61703A5F810921
90011093010B8D030F77101C936B75A1A6AEBFD1D99BAEC12A3E653A38636C2B4884081D
92011193010F93010D87060F7F2D349B83887F858A78898A778A8975898A738686738585
75858876878778878A7083867084866F83827183846E82826C7F836F83867285876D8381
6E84826E8382677F7C647B785F77736078756F88857A908E63716C346E2400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0061C83340271A190D0F5946435F4944
2616165D4D4D644D4F62484C67484F6A4B516C4D526D4D55714E57754E5A78505F784F5D
7A515D7D55626F4A566F4B568058618659638D5E6791636B8F5F698B5B648F646A956C6E
9A74759E7B7B937574997F7F97817E93807B93837C94858090857F99958C9A958D938785
8A807D8B8480918B8A958D8F8D8587807D7E7F81886B7A8C394F647B8A988D969DC8D0D3
B1B8BD8E969C8A939BAFBAC0C1CBCEABB5B7C7D2D6CAD5DBB6C1C8AAB9C1C2D4DBD0E0E6
C5D4DEA9C0D46E91B54673A38BB1D65E81AA4B72A59FC9EEB8D7F19EB7C4CFE2E8D2E1E6
D5E1E8D2DFE7D2DFE7D1E0E7D1DFE5CFDDE5D0DEEC748DAF132F67625886711A38890618
960515980717910B1A761B2BD2B5BFD1D5DDC7D5E0C7D7E59DB1D11225595945736C122E
8B051692010E90010F7E051383434E948D94BAC9D1A6B7C45A6C8C131C486B476A760D24
8F031492011091010D89040D720D179F727883848979878976898A778B8D75898B728688
75888A7286857384876E80837285867084837084857186876E81856F81847082846D8180
7084846F84846A7F80667D7D6076756279776E85847A8E9067767447413500FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0031E3174D2E1A251512604A43604640
3925234C3A3D5B464F3B242F5E444C694A516B4C536C4D5370505874515B744F5B744C59
784F5B8258638156617E545E7F545C8659618C5E6792636E91626D8C60698F666C977174
9A75779F7C7E9B7C7D987D7D947A798F7A768E7C769A8B849B92899B988F99938F948B89
89807D8B84818985828A8484878283828084788390324761667A8F89959E929A9E9AA2A5
989EA391979C8E979BD0DBDFD6DFE4ABB5BBA5B3B8B1C0C4C8D6DAC0CFD6BBCED9C8DDEB
BDD1E1A5BDD54266911F508597C1E2B5D3EC81A3CC4875AF3A659A95B5CFCDE0EAD2E0E7
D2DFE7D2E0E7D2DFE7D1DFE6D2E0E7D1DDE5D3DFEABDD2E82340732F3B71713D5D841025
920415940311960714871020A56A77D9D2DACAD6DFC6D6E38DA0B9364B762C2D5D6C3150
80091B90021091010D880410731A2497778080868D8D9BA58090A61A2B53504770681B33
88061790000E91010D8C020D79051188464E8B83857D8A8A78888C788B90788B8F738789
75898A7587877385877386887082857184866C7F826D80826F83847083857384866E7F7F
6D7F81697D7F687C7E6A7D7E66797A6176756C80837B8D926D7A7C53504600FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00563316331D18624A3F63483D
5C423D462F332B18233D283260484D674B4E6D4F536E4F556C4E536E4F5671505974535A
7E5F66A2848A83606B825864805360845964895F688F656E9267718B616A8E656D936E75
9672779D797E9D7B7E9576779073728F7773907D769588809D938A99928B9C9693918A88
88807E8F8A868884808C88848884857E838A51637D1E385698AABA959EA4929A9F919B9E
B3BABDCED2D699A0A6A8B2B9B9C3CAA6AFB6A6B1B8BFCDD1D2E0E4C6D6DF92A9BB4B6B83
A5C2D3BFD7E49DB7CD90B6D8ABD5F99FC6EA476DA10938870737807A9FC1CDE2EDD2E0E7
D2DFE7CFDEE5D3DFE8D2DDE6D2DDE6D1DDE4CFDCE3CCDFEC6881A510295E725F876C132C
880619920311990714930A1A7E2032D8B8C4D2D3DDD0D7E7717891979CBF312B557F4E6C
7B0E238F021193010D8D020D7707138E5961858185C6D2D6BDCDDC455A7D2229586D3B5A
7E0B208E010F91010B8E010B82030F721B2393787C7F868778898B788B8E788A8D76898B
75878A78878978898D74878974868A728286718386728486718483708385748386708181
6E8081687F7D687D7C6B7D7E6B7C7C65787A6A7E817B8E92738184585A530FCA0700FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00643B1841251A664B3D684C3D
6A4D444E373638252A5D494E5E464A694D526C4D526E50556D4F546D4C526F4E566B5258
A99A9ECBBFC4A089947B5365835566875B69845B668C636B9168708E656E8D656D97717A
98747B9D787F9572768C6B6C8D6E6E8C726E927F799887829E918B958B869B9390938B8B
8D86838883808C86838F8885868284767D8E182F51435A7782909B8991958F969B99A2A7
B8C2C5D1DAE09DA6AE87919AB6C1C7D3DCE2C5CED7A2AEB9B8C7D2A3B3BD9AAFBE7794A8
BFDDEAC9E2EDBFD7E75F83A921508E1C4D88769DCA294F854970A0B4D1E8D0E1EAD0E0E7
D1DFE6D0DFE6D2DEE6D2DCE5D1DDE4D0DDE4CEDDE3CCDDE6B3C7DE193362373D6F62304F
76081C8E0414960412940312850A1EA35266B37F97A475938655788D547889486B963F59
880D2191021194020D91020E810715925058ADA1A8A3AFB7AEBFCC6A8099172753685378
6C0F2889041390010C90010A8B020D74070F8F595E8883847D8A8C798B8D798B8D798B8D
76868B73838975848B76878C7584887281837283857587887284866F83856F82846E8282
6C807F69817E6C807F697C7B687B7C677B7C6D8285788C8D78898C5B635F219B1400FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0075461C4B2A1E6C50416C4F3E
6B4D425C413F45333A362832463339664C517051566B4B506D4D53704E55714F58675059
B4ACB2C6C1C8A18E9C81596D865569875768865B688F64718D626E8A616B8C676E936E75
9872799C747B8F696F8B696B8F706F8F75738F7C799988879A8C8A938783968C898E8583
89837F86817C8D89858F8B8888898F505D7A132B516C7F96869096A3ABAED0D8DD9FA8AF
9DA5ACA2ABB2ADB7BF9DA7B0AFBCC4D3DFE7B8C3CF8897A47C8D99C8D8E0CBDAE2A1B6C6
A4C4E197BCDD92B5D64C709C0A377A21528BB4D8F788A9C87195B2C9E1EFD2DFE8D3E1E7
D1DFE7D0DEE4D4DFE7D4DFE8D2DDE4D1DEE5CEDDE4CDDCE4CCDDEC677F9F1228595D527A
631933820A1D9309189204148E0617870C2280112D80123282113384113089122D880B1E
8C07178D08128F09138908117E0D19753540998D967B858F818F9B8D9EAF33476B3B3C65
6B2A4781061990011092010D8E010C8305107E2E36978384808A8B778A8C77898B7D8F90
7A8D8F76898E79888F7A888E788689758486748387708284697C7D6E82836D82826D8283
6E82826F82816A7B7B687D7B6A7F8064787B697E81778B8C74878A5F6B69209D1800FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00299101522E1F6E51456C4D3F
6D4C41684A491F101827212E4F424B634C4F6B4D506B4B506A49506E4C546F4E56684F58
A2939EC3B4C285697C82566A855565885867895B6B8B60718B606E8B626B8A646B926E73
956E749A7178946C728F6C6D927573917977917E7F928283968A89998F8C968C88908681
8C857E88857D8988839090907A8396172E56324B6F8594A38A929899A1A8B1BAC39BA3AD
99A0A8B6C0C5D4DFE5C8D5E082909C9AA9B399A7B09CAAB38E9FA9CDE0E9CEDFEA8EA4BF
274E800E3F795A87B4B1D1F05B7FA889B4E393BBE75E88B64F7897CBE3F0D3E0E9D3E0E6
D4E0E8D4DFE5D3DFE8D0DFE6D2DEE5D0DDE4D0DEE5D0DEE5CDDBE5C4D5E5556B8C2C3B61
5A44626520337718247E161F8018207B1720801F2C7C1F2D7C2130802A3981303B873539
83323883383C81383B7D383A783D44856A71A7A8AE87919A9FACB5C5D3E07E90AD16234E
704A6E770B228D021491000D8F010B89030E740F17956D7183868878898C78888B7E8F8F
70828478898E78899077888D78898B77888B74858A7285876D81816E82826E83836C8183
6D7F83728184707F7F6D807F6B7F7F697D7D6B80816E84856F83845F6D6C453C3100FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00369D08532E1C6E5142684B3A
6C4B3F6B4C482E1B21180F1B261B24654E526B4C4E69494C67464C6A49526E4B546E4A57
7353617C5C6E7D5769805665865863885866895D6D865F7085626E855F67845E66946F76
9A7578956D718D6568906D6D917371977D7D9C87899585869B8D8C9C918F9A908B938984
9189828C87828D8B89959AA34A5D7F092957627C98C3CFD69BA1A58C939A8D959DB6BFC6
ACB5BDA0AAB3C4CFD9A4B0BC77879292A1AACFDDE4D2E0E6A3B4C0869FB38CA7BB94ADC3
47688D3F659198BCE1C6E4FE9BBBDC2C5892083C881D55919EC6E4CBE1ECD2E2E9D1DFE6
D5E2EAD3DFE6D1E0E7D1E0E7D2DEE6D1DEE6D1DEE6D1DEE5D0DBE4CFDBE4C7D6E597ABBF
6C798C776E7A927579906C6E90696C9874759C7D7EA1888AA9939B6D6273827B8A9E969A
9B9094928C918C898EACA7A99B9A9F929EA7C4D5DEB9C9D48A99A5B0C0CD899BB421345C
4E40686A193588051990010D90000A8C020C7C051086474C8C85847A89897B8A8F7B8B8E
7A8B8D7D8D917B8D92788A8F7A8B8F76888B72858974888A7185877488897286876D8284
7284866F80837081836A7E7E6D82816B807E667C7A6D82827386876470704B453D00FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A8105129146D513D6B4F3B
6C4A3E6B494260464643323B3A2C35654F53684A4B66464A66464C68454E6C46536D4551
71495579505E7C505E7E535E8256628459677D59686E536264505C6F58627F6067946F74
9A72769A7276936B6D957071917070957A79937F7F8473749788869A8D8A978C88978D8A
9289878F8887918F92858FA4102D5D193B6A7990A49CA6AB8C9295898E939DA5ABD4DDE5
C7D2DC87939F8C98A3ACB8C1BBC8CF9DAEB6C2D3DCC0CFDA9AABBC46647C7290A8CCE3F2
B3C8DD87A1C1799BCA537BB2709ACA204D8A073986376CA2BEE0F6CEE1EAD1DFE8D1E0E7
D1DFE7D2E0E8D1E0E7D0DFE6D2DEE7D2DFE7D0DDE5D0DDE3D4DDE5CFDBE2CCDBE3C6DBE0
C6DCE1C7D7DBCBD4D6CBD0D1CCD0D1CBD2D4CDD5D7CCD8D9BFCBD66B8299617E997992A6
9FB1BD6F8397617990C0D4DFBACDD78194A3A5BACAA3B7C57B8A977787938EA0AF586C8A
2227536933558008208F021092010D90010B890510772025967C7D80898A7E8E91798B8F
7B8E907B8E8F778A8B798B8D778A8E76898C74868A71848872858976898A728587738688
7486867185846F83836A81806D83826F85856D828270848576878B69757654504900FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053B51951280B6B4E3A6C4D3C
6C493C6C48416347472C1B252E1F2C5F484D6A4C4D67474B67454C67444D6B45526C424F
7349547C4F5C80525E825662815763765160614453634E5C5B4C5A50434F6C57608A6A72
977078926770946A6F926B6F917274947A799985838C7C7A988A87988E8999918C958E8A
97918E9893938F919D4C5D840A2B673E5C8795A4B399A1A5B4BDBDBEC5C98C949DA2AEB7
8E9BA48A969F8B98A0CEDCE3D1DFE5A0B0BA8294A29FAEBAC2CFDC98ACC09DB9D2BEDAF4
A2BCDA7595BC15407E083D886495C892B8E0537DB279A8D2C2E1F3CDE0E9D2E1E9D1E0E7
CFE1E6D1E0E6D2DFE7CFDDE3D1DEE6D1DFE7CFDDE5D0DEE4D1DDE6CCDAE3CBDBE3C8DAE0
C7DAE0CBDBDFCFDAE0CED9DDCBD8DCC7D7DCC7DADFC7D8DEBFD0DC728AA523447234557F
B8D3EA6A839C344C6BA0B7C8B3C6D48395A47082929DAFBAA5B2BB818F98C2D2DCA9BBD1
19275361436B770F2A91051795010E92010A8D020E770A1296646A8787898090917D8F91
7B8E907A8D8D7A8B8B738685788C8C7B8E916F818477898C73858875868876888B76888A
7183857085856C81816A807E6E828371868973888A718586788A8E6C797B5B5B561F950F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005B2F056848346C4D3D
704D3F6B473E55383919050F39262F61464C6B4A4C6C484C6A464D6A434C683F4C704652
754C57784D5A7F525F7F55617C58656043516C5260785F6B75616C594E59544653826874
916B768F646E936A73906D758A6F758C767A968483988986938883938B85948D88958F8C
98938F9B999A858FA6142C640629666B86A69AA5B09FA6A9C8D0D3C3CCD2919AA4808B95
BCC8CECED9DF98A3ACA6B5BFABB9C3909EA9758690C0D0D9D3DFEABDCBE06A87AF2A5588
618DB69FC7E94972A02D5D9497C6EEA1CAEE5D87B4306089C1DFF1CDDFE7D1E0E7D1E0E7
D2E1E7D2E1E7D3E0E8D1DCE5D5DEE8D1DFE6CFDEE5CDDDE5CCDDE7CBDCE6CDDCE5CBD9E0
CEDAE3CED9E1CDD7DFCDD7DFCCD7E0CAD7E0CBD9E3CCD6E2C9D1E2939FBE182B6113275C
97A6C5B8C2D79699B2898CA09DA2B3B7BBCB8E91A3CACADAD3D1E1A1A0B1A9A6B8ADABC3
4C4B7150375C791F3A8E051997010F95010D91010D860612883A459785898890937E8D8F
7F8D938190928392937C908E7A8D8D7F91936D8083798C8E728485768A8A758989768989
7285866F84866C82836B82826B818273878A6D808473868876888B6D7D7F5A615C219B15
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B3B0C67472E6E503D
6F4F3E6C483D5A3A354327286245456847476B49496A47496A454B6D444D6C424D69414C
754D58794F5B7C525F79505C70515C5A44507359667E626E7B66716155614D4351796471
8B69738E677086616C7B5D67775F69806B748E7C7E988887968A879A908B988F8A928B86
95918C9A9DA257698B062665193B6F90A7BABFCACEA2A7ABA9AFB4959FA5A1ABB287939B
C8D5DCD3DFE79DABB68495A1A5B5BED1DDE4BDC9D38E9FAEA8BBD09AAEC65977A10D3A74
5E8CB6C2E8FFB1D1EB6D95C24274B1356CA86091C05D88A8CAE3EFD0E0E6D3E1E8D4E0E8
D4E0E8D2DFE7D3E0E8D2DEE6D2DDE7CFDEE4D1DFE5CCDEE9C3DAEEC3DBEFCDDAE9D2D8E5
D4D3E2D8D2E3D4C8DDD2C3DAC8B5D0C6AFCBC2A7C4BE9DB9BD95B6AE83A96F447170436E
8957798953708E506F8A4A68915370955976874869904E6E9A57788C4869874262884563
8543628C415F92223C91021698021194010C93010E8F04107F121FA76E75977F8790858D
8D868F87888D828A8C7C8C8B7D8E907D8F9274878B778C8D798D8D798E8D788D8E738988
73888972898B6D8685677F7F6B8282748A8C5C6E727284877B8D907082845C6865336C23
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00834D166844266C4D38
6C4D3B6C4C3D6B483C67443C6946416C4A446B4B4767474768454969434B6B444E6C454F
764E597B515D7C525E79545E614651604C58755D6A7A616E72626C5E576147414D75626E
8B6A748A656E7E5C659070798C72797D676E927D80968383958685998E8B9C928E8E8782
8F8B898C93A2223A6C0326693958839CADB9B3BCBEA9AFB3A1A7ABB7C0C4D4DDE2ABB8BF
8A98A2A0ADB4AAB9C196A5B0AFBDC8D1DDE7BDCBD87990A843617EB5CFE7B9D2EC6C8EB4
9AC4EB9EC7EA96BCE0406B9F073E920C489495C3E9BCDAEBCFE0E8D3E1E8D5E1E9D6E0E9
D6DFE8D4DFE7D3DEE5D1DEE5D2E0E6D1DFE4D2DFE7BED3E24667905D7DAC979BBE8E6D8D
955B7D934E6F883B5E8631547A22447E21447E1C41811A3E84173D7E0E347F0B2E810B29
8109258509268808268807248808258807278C0A2A8C09288D08298D09278B0724890721
8B08218B071D93041998021496011092010B93010E91020C8D0614841523822637853548
843E51854D5B87666F8A888A7E8C8E798C8E76898D768B8C798B8D7A8E91788C8F758A8C
74898B73888A6E84846F83836F838375898A65787A697D7F7D9193708486637071474035
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DA1086A4221704F3B
714F406C4B3C6C493B6A463B67433B6846406748446748486846496A454B6A464E6B4851
734D5779505B7B515B7A565F58414C584A556A5A656B5C66665F6854535C47424C79666F
88656D89626A83626891737890767A7E686C957E83937E82958585968C899B938E948D88
979799667391032162163A7D6883A7A2ADB7A3A9ACB7BBBFA2A8AEB7C0C7CCD6DCA4AFB7
8D98A1B1BCC2D5E1E7C5D2DC94A2AF93A4B099ABB58EA6B754748AC2DBEECCE0F295B4D7
2857940E45894275AF83AEDB2251923A70B1A1CEF3C9E2F3D1E1E9D2E1E8D2E0E8D4E0E9
D3DFE7D5E1E7D4DFE5D2DFE5D1DFE5D1DDE3D1DFE7CADEEF4869951035747170A367244B
871538971836930E2B971029950F258F0C208F0A208C0A1F8C0B1F8E0D218D0B1F8B091A
8F0C1D900D1C8C08198D0B1B8A081A89091B8809198709188A08188C0B188A09178A0916
8C09168E0B178F08178F08168D06148B06118C05118C05108A030F8A04128C05178A061A
86071A7F0B1E6B142296777B858C8E7B8E927B8E92788C8D788B8C72868875898C73878B
768A8E768A8B7084857084837385857589897286876C8183758D8E798F906C7C7D4C4A41
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0047A90C72441F724D3A
7551446E4C3D6A49396C483B69443B67453F69484666474667474A6A474D69474D6C4A51
714D5676505A79505A78546057414D4D44505A54605C57625858624A4B56524853836771
8C656D8861698261688C7074816A6D867076947B83957F859786889A8D8B9A918C97918D
8B8F98293D6A03236D1232708DA0BCA8ADB4B2B5B8D6DBE0BEC5CE9AA3AE909BA4B8C3CA
B6C0C8A5B2BBC7D4DEB2C0CB8A9BA97C8F9BCADDE4CFE2EA9DB3C394AEC698B3CD85A5CB
184687073E8B376CAABDE3FF97BAE64C7CB92A5B93B1D3EDCFE2ECD4E2EAD2E1E8D2E1E8
D3E2E8D2E1E6D2E0E6D2E0E6D1DEE4D1DEE6D0DFE8CEDEEB9BB4D4153A7455649A6C3E5C
7E1A2E8C19268C18238E1E26861D2781202880232F7A232D81303881333B883C438C4348
8A434889464F8B485386434A89474E84464D86494F85464C84454987484B834247844147
864145864043873E42843B4181363C7C30367C2932792429741B1E75171B7710167B0F15
820E17800C176E0C1883565B8B8C8F788A8C7D90937B8E8F748789758A8B73878A778A8E
75888C73868970848672868770848474888872878973898C71888C768E91758989585C55
0ECA0700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0050B211724219724C39
744F42714F406A49396E4A3E69463B63423A67474566484863464863464967484B6B4A51
6E4A53714D54764F5A734F5E634958463C4B4A48564F4D5B51505C4C48546B5865896572
8B616B8C636B7F5B62795B608266698D7578937D81947F83978587968888988E8D999596
767F960B225E02206C2B4477A5B0C4B3B5BAABADB2BEC2CAA4ABB59DA5AF9FABB4D2DDE5
D1DDE58D9DA890A0AAB4C1C9B3C1CB8D9DAABDD0DCC5D7E47E94AB35587F4C749BC3E2FE
86A6CF4972A8699AD277A5D78DB7E71545841A4C8EB3D4F3CEE1ECD3E0E9D4E1E9D3E1E8
D2DEE4D4E0E8D2E0E7D1E0E7D2DFE5D0E0E6CEDFE7CEDFE7C9DCF143658E28497879768E
7C545F936064986869986E709874779F8286A68F92A79496B8A6AAA89A9EADA4ABA6A5AB
B2B2BB7E849A6E7791ADB2BCAAAAAE83858985878C888689888789828183ACACAEA6A4A6
8D888AB3AEAEA89FA1928A8C8E85878F8587998B8D928180957E7E9277748D6B698E6462
8C5A5B814B4E6F3E42745D5C848B8A798C8C7A8D8F7B8F90788B8F768C8D6A7F8174888A
788B9074888B6C8086697D816E818372878772878974898B73878C73898E788E915D6562
1F981400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00774618704B36
724F426E4C3F6C4A3D6C483B6F4C3F68473D6545426648476246476146486446496A4950
704D55754E57764D5A77505E7353614E3C4A48404D4B44515C535F675A65856D788E6976
8F68738F676F8E696D8E6B6D947575937777957E7F958183908080958A889A94928F8F9A
46537A051E67031F6B50648FC1CBD8C7CBD0A6AAAF9FA3A9C4CAD0C5CED494A0A9B0BDC8
9FABB692A0AB92A1AAD0DDE3D5E1EAA3B4C27D94A493AABBAFC5DA46678B4F779CC1E2FA
A9C6DF7FA2CC1C4C900B4494598FCB517DAC426792C4DEF2CFE1EAD3E1E8D4E1E8D4E1E7
D3DEE3D4DFE7D5E0E9D2DFE7D3E0E6CFDFE2D0E0E6CFE0E7CBDCE9A9C4D87E9DB69CADBA
B0B6BCBEC0C1BEC2C3C4CACCC6CFD2C7D3D6C9D6D8CAD7D9CDD8DECDD8E18598B0527396
B1D0EF3455821236688BA9C2B4C7D28D9FA781949A9FB0B3B5C5C88D9FA5BFD0D9BFD1D7
8999A2A2B2B89FADB3919DA297A4A78E9B9D909EA28896978E969A8C97978891908D9392
909294888B8C8285877D84827C8B8B788C8D7A8D90798D8F7A8E92758D8E73878C74888C
768B8F72878A6E8286677B7E697D7F6E828274898A768B8D73878C728A8D758A8D5F696A
31682100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007C4A16745035
7151406F50406B493E6C493E6D4B4068463E64433E64454262444464474A66454B6A4750
6C4750714854764B597C53607E586571535E5C45506A576179646E8870798F707893707B
8F6A758E69718E6A6D9674749876799173748F7776998683988A86978F8A9A97978E93A7
1629600220720B2E726B83A1919CA3A6AEB1AAB1B4A9AEB3D3DBDFD1DAE09BA5AF8A95A0
B1BDC5CCDAE1A7B5C0B0C0CBB4C4D19FB3C15772859DB8C8CCE0EEBED5EB6D8FB4608AB4
8BB6DD76A2CD114288064095528BC6AED5EEB2CCDFD0E3EDD3E2E9D3E0E6D4E2E8D4E1E7
D4E0E5D3DFE5D3DFE8D3E0E8D2E1E7D2E1E5D3DFE5D3E1E6CCDAE3CADEE5CCDFE7CADDE1
CDDCE0CDDCE0CCDADFCDDCE2CBDBE1CCDCE1CBDBE1CCDDE2CDDCE4CDDDEA89A2C50E3874
7198C97697BF4C6D95819FB9A0B7C6B6CCD68DA6B0B3C8D0C5D7E09EB1BD9AACB9ADBEC9
97A6B199AAB4A6B5BDA6B5BB9FADB4B6C6CC92A2A991A0A78B99A18C9EA28A9B9F8FA0A3
87969C80909885959C8090927C8D9074898C788D90798D9175888C778C8F74878D758A8D
71898B728989718689667B7C6A7E806C808173878B768A8D71858B72888D7A8D93677375
443D3400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00825117745030
72533E7051406D4C406D4B416B4A416B4A4166453E67464266474667484C65444C6B4853
69444F724755794D5D7F536480556480596682616A886A718F707790707894707B98727F
936D79936E768F6B7198767A98767C97787C987F7F978582998D889B928E9C979C727B99
061D6104267A1F44818399B1929B9FB8BFC1D2D9DDABAEB6A7ABB5A1AAB3AAB3BC8E98A0
C8D6DBD3E0E9AEBCCA94A6B4AFBFCACCDDE6A8BCCC87A0B3ADC6D796AFC5426693083B7E
4579AFB4E2FF83ACD84C7BBB4578B77FAFD9BAD9EED1E3ECD4E1E9D3E0E7D3E2E8D6E3E9
D2DFE5D4E1E7D3E0E8D4E2E9D2E0E7D2E1E8D4E1E7D3E0E5D2E0E7CFDEE5D0DFE6CCDDE3
CDDDE4CCDEE2CFDEE6CCDDE4CFDDE6CDDDE3D1E0E7D0DFE6CEDDE5CCDDEAAEC6E2315687
779EC99BBAD2B4D1E881A6C3A7C8DFC1DEEC748FA294AABABACAD89AA8B698A5B1ABB6C0
B5C2CBAEBBC6C4D2DCC2D1DA9BACB5A5B8BF92A5AC93A4AB97A7AF95A6AD8E9FA78C9DA4
85959E80919984959C899B9E84979B7B8F93758A8E778C8F77898F778A8E70828972858A
71878A718788708487697D7F697C8162757A6C80856C808472868A71858A788B906F7E80
48463F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008C5A1A74502C
71533C7053426E4E3F6E4C416E4D436E4F466A4A456848466A4A4C68494E694950694952
6A4651734A58794E5F7B4F627E51648459678A636B8F6C728F6D74926F78926F7B967380
99768198747C96737A9B797F9A787E9B7C819981839D8C8BA093919B91919996A0394671
031C6C01207727447B9AA7BB9EA1A7B5BBC0D0D7DDA7A9B19FA1AABBC2C9D3DCE3B2BDC4
9DADB49DADB6A6B4BF8F9FACAEBEC9D3E1EBB8C8D9728BA6597A9AACCCE67593B91A447C
5E8BBBB7DDFAADCCED648BC30131841E5BA49DC9EBCBE2F0D3E2EBD4E1E9D5E3EAD5E2EA
D4E1E8D3E1E8D7E4EAD5E2E8D5E3E9D4E1E9D5E3EBD2E1E8D1E1E8CFDFE6CFDFE7CEDFE7
CFE0E8D0E0E9D1DFE8CEDFE8D0DEE7D1E0E7D3E2E9D1E0E7CDDEE6CDDDE8C2D8EC9BC1E9
70A0D1A1CCEE9EC5E42255866090B8B0D1E798B2C69FB2C1B1BECBC0CAD4AFB9C3BDC9D1
C7D5DDB3BECBB8C4D1B3C1CF99A9B6A1B3BDA3B5BD9EAFB696A8B293A4AD91A2AB93A2AB
8B9CA48C9EA48C9EA3889B9F7183896F8388788C92819498899AA17D909474878E6F8388
6A8083687E806A7D826A7D8166797E5063695B7177617A7E667E8170848971858A708183
51544C0FCA0700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0040A60A744E27
6D51386F55406E513E7050416F50457053496E514B6F524F6D50516A4C50694B506F4F56
6947506D4753744D5A79505F7E5364855B688D646F906B75926E78906B7794707C977580
98767E9B767F9C787F9E7F83A081859E8184A0888B9E8D8E9C8F909D94988C90A5162863
011C7502207348608ECBD4E1AFB2B79DA1A6A7ADB2B6BAC0A3A8AFBAC3CBD1DDE6A8B5BE
9AA9B1A6B8BFD1E1E8C8D8E37D909E92A4B296A6B86882A1183E659ABBD8C9E1F897B5DA
6E99CB6090C493C1EF5B89BE0A3E8E1856A197C5E9CCE4F2D2E1EAD5E3EBD5E2EAD7E4EC
D7E3EBD6E4EAD7E4EAD6E5EAD6E5ECD5E2E9D6E3ECD6E4EBD4E2EAD2E0E8D5E2EBD1E1E9
D1DFE9D2DFE9D2E0E9D2DFE8D5E1EAD3E0E8D2E0E8D2E0E8D0DDE9CFDDE9C7DEF35D8AC0
0E4C9E437EBC9DCAED4877A375A1C5A1C2D6B4CBD9A9BBC8B7C8D1CBDAE0BFCCD5B7C7D0
CAD8E4BEC9D6B8C3D0ADB9C6A1AFBB96A8B2BACBD4A3B4BD9CACB897A7B195A4AF94A2AB
93A3AB8E9EA48E9EA286989E879AA17B8E9476898F788C91788C91768D906A8085637A7E
6A8084687E80697D836B7F826A7D8153686E556B735D7679657C7F6A7F836E86896C8082
5E605D1F961100FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0043A90B744C24
6E4F366E533D6D523E6C503F7053447255496D514A7155536F5454694F516B4F536E4E54
69464E714C5578515B7A515D805664865C6A8C63708D6876906C7A8F6A77936E7A97727D
97737C9C777F9E7A819F80839C7D809F8184A28A8EA28F919D90939C959E656E91061D69
011E7D01206D6D84A9B6C1CBA9AEB39FA6A9B1B6BAD6DCE2C9D1DA95A0AA8E9BA4B5C3CB
A9B9BF93A6AEC1D3DDB6C8D48296A690A5B5C9DBE9BFD2E76A85A4A2BEDEB1CAE399B8E0
164C930B50A32E71B4A8D5F76F9AC67FB5E4B3DFFCD0E6F3D8E6EED9E5EBD9E5EBDDE7EC
DCE6EBDEE8EDDDE7EFDCE9EEDAE7EEDBE8EED8E5EDD8E5EDD8E3EAD8E2EAD6E2EAD5E3EC
D5E1EAD6E3EBD5E2EAD3E1E8D6E2EAD7E2EBD6E2EBD2DEE7D0D9E8D1DDEACADEF5658EC5
134FA44683C2B5DEFABCDEF7BFE0FABADBEEC6DEECB4CBDAB7CCDBC1D4E0BCCCDAB2C3D0
B5C4D0C5D1DCC5D0DDCCD8E4BCCAD690A1ACA8BAC5A1B2BDA7B5C2A4B2BE9FAEB99AAAB2
99A7B1919FA797A4AD8B9AA380909971848A70828971858A7084896D8488687E83657A7E
6B7F82697E80667C80667E81687D804E666B4159605A727664797C677F806A8384697E7F
616867229D1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004DB01077491F
704E377054416E54416B513E7155457153476E514B7153546D5153694F506A50526D4E54
6C49516D495279525C7B535E825966865D6A8C65728D6874916C79906B79946F7A97737C
99777F9A7980A08085A18084A18185A4868CA0888DA190929E91969894A63A487B051D76
06268824468D798EAD97A0A6ABB3B4B3BABDAAB0B5C7CFD8ABB4C08B99A399A9B0D1E0E4
CDDDE376879390A1ABACBEC6AABCC7798E9BC7DAE7C6D5E899B0CF7899C789ACDAA7CAF4
3465A43773B95E98CCCEF1FFDBFCFF7CB4D786BBDCD0E7F6DEE8F0E0E8EDE4EAEEE7EEF0
EAEEF1E9F0F4E6EDF4E1EAF1DFEAF0DFEBF1DAE6EDDBE7EEDCE6EDDAE4ECD7E3EBD5E2EB
D7E3EBD6E3E9D5E2EAD2E1E9D5E2EBD4E2EAD4E0E8D1DFE7D1DEE8D1DEE8CDDEEDA9C9E8
79A9DD8FC4F4ABD4F1B9DAF45E86AF83ADCEB9D8EB9DB6C89EB4C8A6B9C9B1C1D0A2B2C0
C4D3E0C8D7E4ACBBCABCCBDCBCCFDEBBD0DDB5C8D3ADBEC7ABB7C3A0AEBB9DAEB8A4B5BF
A1AFBC9AA9B394A3AD90A0A98A9AA3798C92768A8F7284887083887084886D82866A7D81
6A7E7F6E8384697E82677F8362777B526B6E5B747A566F735F777A647D7C6279776B8082
64706E433B3000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A4917
704E336E513F6E53426C513E70524273524770524B6E504F6E50536E53546A50526C5156
6B4C566E4E5874515C77515D7E5561845B688B616F906974936D79956F7C936E7997757D
98787F9E8086A18388A5858BA4848AA5898EA0878FA08E939E929B9191AD182A6C031F80
0223841233758B9DB799A1A5CDD5D6D2D8DDA6ABB3969EA7B8C0CAC7D2DAA3B2BAB4C4CD
AEBFC883939D95A3ACCBD9E0D3E2E9B8C8D3A5B7C67F92A78EA6C7183E762D558CBBD7F8
C6E0F6C9EAFCBEEBFEA4DFF3AAE5F97FBEE197C9E8DAF0FBEAF0F8F7FAFCFBFCFFFCFEFF
FAFDFFECF2F7E8EFF6E2EBF4E0EAF2E0EAF1DEE8F0DAE6EDD8E4EBDAE4ECD7E3EBD6E4EC
D8E5EDD9E5EBD7E2ECD3E0EAD4E1EAD2E1E8D3E1E8D0DFE7D0DFE9CFDFE8CEDFEBC4DEF1
94C0EB326EB06BA3D6B0D9F647719A7DA5C7ADC9DCB2C7D6AFC1D1B7C9D7C9D9E8B5C7D5
B9CCDBBBCDDDA6B7C8A2B3C6A1B6C49DB6C2AEC5CEC0D1DAABBAC4B0BEC9A8B7C0A6B6BF
A4B3BE94A6B090A1AD8EA0A98C9EA47D9195798F936D82856F83866E8385708587708487
7387877286866C7E82697D8164797D566E706881825A7376637A7B617877667A7B657A7C
66757447473B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00814F18
704B2E6E523E6F54426F514273504476534872534A6D4F4D6E51537153556D52546B5154
694E566B4F5973545D73515A7C55618257678C61718C6471926D79926E7A96737E977580
9C7C86A1838AA2848BA08188A08088A3858D9D858B9E8B909D939E757CA108206D032288
0122812A4882A9BACD9EA5AAB7BCC1B4BAC0A2A8AEA0A8AECDD6DCD4DFE8A5B3BE8C9CA6
AEBEC5C7D4DCB0BCC3C5D2DACCD8E1C0CEDAB4CBE3A5C1DBC8DFF6849BBA93AAC8D5E7F3
EFFEFFE2FDFF88C1E34CA8D86BB9E1C2F0FFD4EFFDE7F5FCEEF4FBF5F9FCF7F9FCF3F6FA
EAEFF5E4EDF4E0EAF2DFE8F1DCE5EEDEE7EFDAE5EDD6E5ECD2E1E9D7E3EBD6E2EAD5E4EB
D5E2EAD5E2E9D6E2EBD4E0EAD1DFE8D2E2E9D1E1E9D1E1E9CCDBE6CFE0EBCEDFEBC7DDF3
6F9ACE1051A53777BBABD6F4AFD1E9AAC9DFB6CFE2C6DBEBBBCFE0A9BFCFC2D3E4A7B9CA
99AABEA1B3C4A0B3C29CAEBBBED1DDA8BCC69EB3BEB4C8D298AAB6A6B6C0A2B1B8A8B6BE
A2B0B998A9B37D8E998699A08EA0A67A8F95798E93768B8F708789708788748B8C768C8F
768B8C788A8B808F946F80866A7E82597072657D7D546C6C62777A61777763777963777A
6375744D52480ECA06
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00865317
6E482A6E503C70524173524774514874514973524C6D4F4D6D4E516D4D516C4E526C4E54
6B4D566A4D586E525D71515B7C55638458698D61708D6471946F7B93727C95767F987B83
997D859D81889F828AA2828BA08088A4858CA3888C9E898F9D95A64F5A89041F75001F87
0425834B689EC9D9EBA7AEB4A2A8ACBFC6C8D1D8DAB3BABFB2BBC3AEB8C2929DA896A2AB
CBD7DCDAE1E5CED5DCCCD6DDD0DDE5D3E2EEA6BED59BB6CBDCEBF5EDF6FBF0FFFFD0F2FF
AEDCF4B8EAFF92CDED7FC7E7ACDFF3EAFFFFE8F3F8E1ECF2E6EFF6E7EEF3E8EDF3E4E9EE
E6ECF1E1EAF0E2EAF2DFE8F0DFE8F1E1EAF1DBE7EED5E5ECD4E5EDD5E4EBD6E3EBD5E4EA
D7E4ECD6E4EBD7E2EBD5E2EBD2E0E9D2E2EAD0DFE8D0DFE8CFDDE8D2E1EBD3E2ECCDDEF0
9EBDE25887BF7EB0E4A2CCE9BFE0F88FB5D692B6D9BED8F09DB2C895ADBFA7BAC9AFBFCF
9DADBDC4D5E2C3D5E19DB1BDC6D7E4B3C4CF95A7B494A5B095A5B095A5AD94A3AB99A6AE
9BA6B094A2AC8696A07A8D94788A937D9199788B92768A9070858B71888C738B8D768F90
788C90788A8D7B8E9273868B6F83885A70745C7275506667677B7D667A7C64777B637678
607272565C551C950D
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00657E0F
724B276E4C3873514075504475524875524B70514D6A4D4D684C4E6C4F506C4E526B4D51
694A52674954664B586D505C795764855D6A895F6B8F6670916C7594737B987A82967A84
987B859A7F889E838D9A7E86A2848AA28389A68A8E9F8C939B97AD28387205217F05258D
072A83516DA09DACBC9CA3A8A1A8ABC6CCCFD5DCE0C0C4CBAFB3BDB0B6BED1DAE0CED4DB
CBCFD5DADEE5D4DAE4D9E3E9E4EFF5D9E4EDD8E4F0EFFCFFF7FFFFF2FCFFC4E5F9559DD0
4495C994D1F1CFF4FFDDFBFFDBFAFFCAEBF8D1EAF9DAEBF2E1EBF1E8EEF4ECF1F4F4F6F9
F6F9FBF3F9FBEEF3FAE7EFF7E4EDF6E2EDF3DDE8F1D6E5EDD4E3EBD7E5EDD4E2EAD1E1E9
D4E2EBD4E2E9D4E1EAD5E2EBD3E1EAD1DFE8D1DFE8D0E0E8D1DFE9D2E0EAD4E1EACFDEEA
B4C9DDBCDAFB729DD16696C8B1D9FE35608B5178A3A2BCD6A6BACC9DB1C0B8CAD5CBDCE6
B9CAD6C2D3E0C3D4E39CAEBD9CAEBC9DACB995A6B19CADB69BA9B1909FA593A1A79CA9B1
99A4AD8E9CA4899AA2889BA1798D93667A8172868D788D93677E836E868A748B8C788E91
798E92768C9072888B748B8C72878963787D4D65695D7275667A7B647778647577637676
5D706E5D655E1C9610
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0042A809
734A226F4B32734F3C74504275534673524874544F6C4F4E684D4C6C50506A4D50684C51
684C536245506147546549577B5967845F6B86606A8C676F916D7492717993737F9A7C88
9E808C977C87856E79836B76967B84A4868DA4888FA290989090A9112566021D80082A92
0B31885E79A7A2AEBAD0D5D8CACBCFB8B8BFB9BAC2B8BAC1BEC0C6CFD0D5E2E3E8E2E3E9
D4D6DDE1E5EED7DFE8DCE5EDEEF6FCE6ECF3ECF1F9F2FDFFCDE5F6BAD8F3B1DAF96FADD9
8CC6E7D1F7FFEAFFFFE3FCFF96CAE26FB7DAA6D9F2DAF0FBE8F3FAF4FAFEF8FCFFF9FCFF
F5F8FDE9F0F6E3EBF2E0E9F1DBE5EEDCE9F0DAE8EFD5E4EBD3E1EAD7E5ECD2E0E9CFE1EB
D0E1E9D1E1E8D2E0E9D2E0E9D3E0EAD1DEE7D1DFE8CEDDE6D0E0E8D2E1E9D3E1E9D1E0EB
B0C3D69FBCE316478E134B947CA6D28BACCC94AFCCA6BED2CCDEECC3D5E2B6C8D6C9DCE8
B2C4D299ABB99DAEBD96A7B496A7B3BACED5A2B5BEADC0C9BDCCD59FAEB493A0A68D9B9F
909FA48E9EA583979E83979D879AA06F838864797D6B83865F787A738C8E7B9093798E91
738A8D6F898C6D86876E8786708787708689677F816A8081677B7B637675627272647775
596E6B606D64336C20
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0046AA0B
754B1E6C4B2F6F4E3973524078574876564B7454516D4E4E694A4B68494B65484B65484E
684C545D434D644A566C4E5C7D5A6987617187626F8C67728C6A7291727993737E9A7A86
977A868B727E836D798E7985836B769D818CA286919F8D9A797B9E051C67011E8401228D
042A80748CB7AEB2BDD9D6D9D4D0D5BEB8C0C9C3CBDCDAE0DADBE0D5D5DAD9D9E0D8D9E1
E0E3ECE5EAF4D8E1EBDAE2ECE7EDF6EDF2FAEBF3FAD3E5F7749ABD8BB2D3D6EFFFE7FEFF
E3FFFFCFF5FFA8DAF4B7E8FE95D4ED80CDEBA7DBF2D6EDFADFECF4E0EAF2DFE6F0DDE6F1
DBE3EED9E5EDD7E4ECD9E5ECD5E2E9D7E6EDD6E5ECD4E3EAD3E2EAD4E2EAD1E0E8D0E2EA
D0E1E9CFE1E7CEE0E7CDDEE8CCDCE8CCDCE5D0DEE9CFDDE6CCDDE6CFDEE7D2E0E9D3E2EC
B2C4D78BA6C7486FA4406CA48EB0D5BFD8ECBFD9F08EAECBC0DAF0B7CBDD94A7BA95A8B7
9EAEBB99A8B5B8C9D4BFCED998A9B3C2D4DDB1C4D08C9FAB95A7B292A2AA99A8AE9AAAB0
8F9FA682939B85999F7F939A879AA175888F687D81647C7E5973746B8387798E917A8D91
768B8F718A8D6F878969818270888A738B8E6E8487677B7C68797A657676617474667B79
5D72705B6B6346402F
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004EB111
764B1C6E4C316D4D3971503F70534372564A72544E6D504F6A4D4F694B4D684B4E65484E
674A52654A5360444E7254607F5E6B83606E84606F8A65738C6A7491717A94737D957580
9577828E75817F6A767C6A7478646E937D87A58E989E8EA15B629006227801248F022793
0C35889FB7DDBDB9C3CDC0C6CBC0C6CEC8CDD6CFD5E5E0E7DDE0E4D7DCE1D2D4DCD7D9E4
DBDFEAD9DFE9D7DEE6E0E7EFE6ECF5ECF4FCE1EBF4D1E0EFCBE0F4E6FBFFF1FFFFE5F9FF
A8D7F54F9BD2368ECE93D2EFCBF6FDC4F0FCBDE4F9CEE4F4D8E5EED7E4EDD8E4EED5E2EC
D6E3EDD6E3EBD4E2EAD5E3E9D3E4E8D3E4E8D6E5ECD5E3EBD3E1E8D3E1E8D1DFE7D1E2E9
CFE0E8CEE0E7CEE0E8CDDFE7CDDFE8CBDDE7D0DEE7CFDDE6CCDDE7CDDEE8D0DFE8D3E0EA
CDDDEAACC1D4B8D4F0AED4FA86AEDBB2D5F689AACD2E59839EBEDC97AEC39EAFC29EB0BE
CCDBE6B9C9D3BBCDD8CADBE8A5B5C2A7B8C2A6B7C491A2AF8F9FAB92A3AB8799A099ABB2
86959E7C8C947A8B92768A907A8D9671858C677D83647D805D767963797E72858B778B8F
778B90738A8E6D83886C848771878B768A916D80866C7F836A7D7F667978637876637C79
5D73715A6A634C493A
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0054B714
774A196D4A306D4C3971524073584874594D70544A6B504B664C4C64494A66494C684B50
664B526B505871535B77596180616983616B835F6D8864728E6B778F6E78906F7896757F
9776819478846F58656D586486707A826B75A48F98A498AB4C578B072885012796012997
0E3A8DA3BDE2C1BDC7D2C3C8D6CDD0DFDDE0DEDCE1DDDCE1D1D4D9CCD3D7D8DCE3DFE0E9
DDE1EADEE2EAE7EBF0ECF1F7DEE5EECCD6DFD7E0E9DBE3EDE9F2FAEDFDFFD2EDFFBEE1FD
6FAADC2A7EC42781C6A1DCF6D4F6FFB6D9EB82ACCDCCE5F6D6E3EDD4E1E9D5E2EBD4E1E9
D3E1EAD5E2E9D3E0E8D1E0E5D0E1E8D0E2E7D3E2E9D5E2EBD3E1E9D3E2E9D1E0E7CFE0E7
CFE0E8D0E1E8CEDFE7CFE0E7CDDEE6CEE1E8D0DFE8CFDFE7CFE0EACFE0EACDDEE8D2E0EB
D2E2EEB7CCDCB6D3EE5E8CC31C529C7AABDE8CB2D848729B9BBDD9BED7E8BCCFDFA8BECC
CADCEAC5D7E7A9BECFB7CCDCA4B6C39DAFBAABBBC89CADBAA3B4BFB9CCD38B9EA59CAEB5
8E9EA686949D7C8B9383969C7B8E956D8188667E83657E8261797D617679687D806D8287
758A8F6D85896A82866F878B71868B788B9172858B6E8184788C8D667C7A647A78657E7B
5F73745868624C4A3B
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
7A4A16704B306E4C3872533E74584876584C75574C6E524B654B48654B4B674D4E664D50
715B5E8B7579755A617D5D6583636C85636D86606E8864708F6F7991717993727C957680
9879839476817E636D8E6F79A2808A8F727CA08A92ADA3B545548C072B8F022B9F012D9D
0530878DA6CFBCBEC9CDC6CCD8D2D8DEDEE2DADCE1D4D6DBD6D8DCDDE0E4DFE3E7E0E3E7
E3E6EDE4E8EDEBF0F5E9F0F8D8E0E9D7E0E9EAF2FAEEF5FDE4F0FAB2D0EE4B7EB97AB0E1
A3D8F974B0E177B4E7AADBFDBBE4FF76A8D25B93BEC7E5F8D4E3EED8E3EAD5E2EAD4E3EA
D5E2EBD3E2E9D3E2E9D2E1E8D2E1E9D1E2E9D4E3EAD4E1E9D2E1EAD2E2EACFE1E9CEE0E9
CEE1E9CEE2E8CEE1E9CCE1E8CCE1EACCE1EACDDFECCCE0ECCBE0ECCAE1ECC9DFEFC9E1F0
C9E1F3ADCEE793C0E92965B3094CAF5793D7AAD4F7A9D1EFA5CAE5BFE0F8C5E2F9A0BFD9
B3D0EDA7C3E28FADCB9DBBD4A8C3D797B0C3B9CFE2AFC5D69EB4C5AFC8D5899FAB8A9FAA
8FA1AD8EA0A9899BA3889DA17D949871888C667E826B83866B80826981815D7776657E7F
738B8F6F87896F848A71868B72878D758A8D778C91758B8E7287896D817F647A77687E7C
5D71725C6B674C4B3C
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
824E15754F2F724F3A72533F75574974564A75564A6F52486B514C684F4E684F525D4A4B
978C8CC0B6BA76636B7C5C68805F6A85646F8A66728C68748F6B75926E7892727B977783
97778393737E8F6E77AA8089B38791B18D97A9919AB3ABBE3A4986062A910431A90434AB
0432927E9CCDC9D1E0D5D4DCCFCCD6D4D4DCCED0D9D1D5DDDCDFE5E1E5E9E0E4E9E7EAF1
E1E8F0DBE5EDD5E0EAD2DDE9D4DFEBD9E3EDD8E2EFD0DEEFD1E2F89EBEE53368A56FA6D9
A9D5F4AED9FA90C0ED2565AF3C7FC87AB4E56C9AC0CBE4F5D4E2ECD3E0E8D3E1E9D3E1EA
D3E0E9D5E2EAD5E2EBD5E2EAD4E2EAD3E1E9D3E1E9D0E0EACADDEACBE0ECCBE2F1C8E4F1
C4E2F3C2E3F4C0E2F3BFE3F7BFE3F9BEE3FABBDFFBB3DDFBAEDAFCA7D6FCA5D4FF9CD0FB
96CDFA79B5EE4E94DC2C7BDD0754C64C96E675B3EC71ACE8649FE268A3E369A3E4457EC4
5187CC5588CB598BCC78A9E38AB7ED6691C68EB5E78CB2DF7096C2769CC181A4C57F9DBC
85A1BD7F9CB3819DAF829EAB809BA7718C95647C84687E836E85886F8A8A6F88896F8789
728A8C758A8D6F83896E868A71858C6C7F85768B90778C8F778A8C728686677E7D677D7D
596D6D5A6965545345
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
8B5418754F2B73533C74554473544873544A7354487153486F514B694E4E6850525D4B4E
A0989DBCB7BF7967737B5C697E5E6982626C8664718C68748F6A7493717B94747F987985
987A859E7F8893707AB88B97C695A2B18D98A7929CAEA6BE314281032890012EA60334B0
03359C6789C1C6D1E4DEDDE6CFCCD5D1D1D7D6DADFDBE1E7DCE0E7E0E4ECDADFE7D2D9E2
CCD7E1D4E2EBD5E2EED0DCE8C9D6E0CFDCE5CCDEEF7791AE9FBAD8BDD8F39CBCE284ACD9
90BDE6ADDDFF6296CC0D51A7175CB09DD0F8C1DEF5D1E3ECD6E2EBD6E2EAD8E3EBD9E3EC
D9E2EBD7E2E9D6E4ECD3E4EBD2E5EFCDE5F2C9E6F6C1E5F8BCE5F9B4E5FBA9DEFE9CD8FE
8DD0FB7BC3F473BEF45FAEF056A9F04697E8408EE93586E42D7CDE2572D61D69D11865CF
1561CF115ACD0F54CF0E4FCF0B4ACC0C4AC5124ABE1249BB1044B91348BC1145B91041B5
0E3CB0113EAF0E3CAC0E3CAB0E3AA70B369E0E3A9F103B9C0C3795113E951643951D4695
29539F325DA13D67A34E74A85B81AC567C9F5C7C9864819668869461808A6B89906D888D
738B91758B9071858C728A8E71868B63787D73898D6D8589778C90768C906F84886A7F81
667B7B5F6E6B525047
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
40A60B754D2976533F74534373554972534875544A72514971514D6D514F654D4C5C4A4B
83787FAA9DA8735B6A7D5D697F5E6A8562718965738B677493707B95727E9473809C7C89
A3838FA8869197727FB9909EB7919E957A86AD9EA8AEAFC6283F80062E96012CA40332AD
083CA1799ED4BEC9DDD0CED8D0CFD5D0D2D7D0D4DBD9DDE5D1D5E0C6C9D7D2D7E2DBE1EB
D5DCE7BECAD5C4D1DFC5D1DDBFCBD4CCD9E4CFDEEF93ABC58AA5C0A2BAD1B2CCEC305A96
114B94437DBA94C7F34D84B865A2DCA7DFFFC1E5FDCDE4F0D1E5EED4E6EDD8E7EEDCE8EE
E0EAF1E3EFF5DEF0F6D2F2F9BEECFDA4E2FF86D4FA66C4F552BBF73DB1F42DA7F12098EE
148BEA127FE71B7EEA176DE11A69E21A60DE1E58D92457D4254EC92546C02B46C22D43BF
3446C03944BB3D3CB44037AE4436AC4635A4462F9C4F38A4462E9C49309C4F339F4A2E97
4327934128913D28913927903827943627913328912C278D26268C22268D1F29901A2990
14278E11288D1029900B278908268207287A0D2C76193A7B274C81395E89567A9C6486A0
7291A3728E9B718A93718B90748A8E697F836D85886C86876D8388788D90788D90718A8C
7286896C7A7B545049
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
45A90D764C2673543C74574472554775564A75544874544971514C6F534F664E4A634E4D
6750557258637658657D5D68805F6A8663708964728A677493727D9A78859C7B88A2828E
A98894B08B97AF8A95A4828D9D838CAB99A1BCB1BABABED5314B8A052D96022EA90234B1
0A40AC527ABBB8C5DEBFBFCAD6D7DFD4D8DFC2C5CFC7CAD5C7CCD7C3C9D5CED4DFDDE3EF
CDD4E0AFBAC6AFBDC8D0DDE6C6D0DBAEBAC8BACADAA0B2C79BB4CC9FBDD2C4E0FC436BA0
245A9B477BB0AAD3F3BEE7FE72BCE63598D471C5EFB0E9FEB8E8FBC0ECFCD2F2FDE1FDFF
E3FFFFD5FAFFB4ECFE7ECEF458C0F52EABEF1BA3F00F9CF20C98F80691F50790F90383F4
107FF4286EE55164DA6559CC6F54C4774BB78544AB923D9F9833919C2C86A02A82A02379
A11E72A41E6CA71D67A81A5EAA1A5BAA1856AA1551AB1652A81652A61951A51452A1124B
9F104998114995104A900D49900D4A8F0E498C0F4D8511508212587F175F7816666F1A69
651D6C561E71481F793A1C7D30207F231C791817731217730E1A73091D720723710F2F75
244983416792597A9A67889D6D8A976C868E698288697F84677C80687E81688082718A8E
84989E7D898D524947
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
49AD0C764A1D73543872574173574475564676554770534771534C6E5250634C4B624B4C
684D5275575F7556627D5C6985616D8A616F8D6472946F7D9B78859F7A86A3808CA3838E
A88A92AE8F9AB0909AB99FA7BEACB2CBBDC5C0B6C1B8BAD2425997072E95032FA9012FAD
0333A52D569EACBFDAB9BDC9D5D6E0CFD2DCB5B9C3B2B9C1D5DCE5D8DFE9BFC6D1B5BDC9
B6BEC9BAC5CDAFBDC4D1DFE7CAD7E0A1B1BC9DAEBAC2D5E596B4D0507697C2DDF6BBD3EC
BCDAEBD2F4FFC5EDFDA9E6FF4EB5ED2DB4F335B9F841BAF552BFF669CDF785DCFD78CDF2
59BBF134A4E51F9AE61297E90C96EE0496F00292F2008AF1018BF60089F50086F7067FF5
2A6CE68350BFBD368CD33074D92C68DC2B5EDD2652DC2047E02045DE1B3DDB173AD81539
D20D33D20F2FD00E2BCC132AC61A31BD1B30BB152EBB0F28B81A31BE3148AD1733B10F28
AD1329A9192EA50E28AA0520AF031EAE051CA8071DA2102899132F961333971235931135
9211368C0F37880C3D860C437E0D4675114A6810505A11574A115F3817651F126616166B
0D1A6D081E6E0926701A3D7A345786547392607B8F5F788162797D64797A64797D667E83
8A9CA381888C3E7432
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
28D90878491876523774544076564577554777564B74544B71544E6E5350674E4D674D4F
6B4F536F515773535D805D6A855F6D8B6270966C7A9A75829E7B889F7C89A58391A68792
A68A95AC909EAB919FB8A3AEC8B6C0CDBBC5C2B3BFB4AEC64C5D9906278D02279F0126A2
062FA12A529CC4DAF6C4C7D3B7B5C2B0B0BCC3C7CDB3B8BDCED3D9D5D9E3B4B8C4A3AAB3
D0D9DED6DEE4ADB5C0ACB7C3ABBAC6A6BAC6AFC7D3C7E1F2B5D7F09CC5DAD6F9FFCBF0FE
A1DBF37BC6F052ACEE32A3EF28ABF91CA8F60F9CF60D99F30A96E919A7EB2BAFEE24A1E6
1593DE1A96E21B93E21E99E61C9FEC19AAF418AEFA12A9F80DA4F80BA1FB0C9FFE1995FD
5978EABE449DEE2A5AF5233FF41D37F21A2FF01B2CE21320E51523E11220DC0E20D30A1D
CE071DCC071ACA0819BB121EE4737AEE9FA3CD6C789A1C2FCC6473FFC1CAB65D71911D33
E18995EFABB4AB4357A00921AD0416AC05119B0C16DD7F86CF8F99C0838FB97986B06977
A758689D435594273E930D2899042095031D9304218C0727880C327B0C3768093E5F114D
4811553216611F1565101667091A680B246723427641637F5573815F7B7E61797A5E7579
7D8D92787A7B2BA320
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007B4B197451347958447655427755437B5A4C7757507255516F545069504D684F51
6C52567053597958607F5B67885F6D8E6671956F7A9D7B86997B859F818DA28593A48994
A88E99AA929FAF99A6B69FACC2A7B5C3A5B3C3A4B2B8A2BC505491072282032293011F93
0324921C3F8AAAC0DFACB2BEAFAFB7BABBC2D8DCE1C2C9CDAFB3BBB2B8C1C4C9D4B1B5BE
D1D8DED5DCE4B9C4D1B4C6D6C0DBF0B8DFFB86BAE3A0D9FE83C1F274BAEE5EACED3895E9
198BE61C98F90B83EE0576E90277E80885EE087FE70A87E60CA1F313A9EF1CA1E551BEE9
81D9EFAAEDFEB3F1FFAAF4FF87E9FF62DAFE3BC2FA20ADF7109CFA078DFA0782F71175EF
4956CDB42E82E31B3FE61424E20E20DF0D1CD70B19D00915D10918CE0818CB0516C60618
C10114C00314C00516A90B1CE28C98F2CDD3ECC6D085394FAA6176F6D2DDAF798F833750
EFC5D2E8CCD8AD5F79960A26A70215A503108C0D1CE3A8B2DCC8D3DAC9D9E0CADAE0C8D6
E0C7D7DFC5D0E0B4C09033489509209802139304119219238C1F2D7E0E217C0A217E0A26
7B0C2F710B37660D434E0F4D32125916105A0A135C061F5B21436B4D6F845A7680577076
6F81836D6F6D239A15
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF007D4E1875533578584376554375564378594A7C5C557658567255536C51516E5456
74585C795C617B5C637F5E688A6573906B7794707B997982997D889A828DA18895A38A98
A68E9BAA92A0AD93A1B394A3BB95A6CAA0AFCCA0AEC39EB94D47820B1F7C021B84021B87
011D8513307894A7C4A7AEB7BBBFC3B6B7BED2D5DCB4B8C0B2B8BFC3CBD3D2DCE5CFD9E6
BECCDEB5CDE5A9CEF19BCCF978B5F2418DE01974DA1375E40F6DE30C5EDB0963E00473EE
017AF30183F90283F90287F7038DF7099EFA20B6FE37C9FB3BCCFC4FD5FF70DFFF91E8FD
9FE5FD96DCF76DBDED48A6EE218EE81382E81077E9106EE61468E5175FDF1E58D92C4FCB
5F41B1A71B68D51136D90C1FD40917D10918C50211C20312C50516C50516C40415C40616
C30415BE0212BD0314B6071BBE4055E3A9B6EDD4DFA7778C935771F2D2E2BA91A582445F
EBCCDBD7B8CB9035589E0928A80115A30211860919D298A6D1BCCE826181935F859B678A
A6799AAD93AAD9C5D495576C860A259003157E0611CE878BD1A6AB7E4F56A86D778B4651
8731447E152C8507258308277309305B0E3F37104C1311520418580D2B5C395977516E7A
5F75785C5F5912CC09
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0082521775523174553F7555427859487C5E51795C53795A56785956755755745758
7A5B607E5F667C5D6582626C8565718C6B7891737D927A8299848C9B88919C87939F8796
A68B99A68C9AAB8D9CB390A0B991A2C79AAACB9BACBE97B3473D7708157001127901177E
041E810F2870828FAEBEC2C9DCDEE2B6B5BDB6B8C1C0C9D3C2D1DFB6CCE1BDDAF9A1C5F0
7FAEE8518DDA2B74D31568D40B63D80461E10262E90267EF0060EB0865EE0470F00684FC
058EFF038FFC0699FF0AA3FF0BA7FF17B3FD22B6FA2BB6F81FAAFA1398F1168BEC1A7FE3
217AE12372DE2165D8235FD62D60DA395CD74951CD5849C16A44B7793FAD82349E933192
AB297EBF1450D20F30D60D1FD70B19D10B16CC0814C70512C80717C60413CA0815C70510
C70512C80614CB0815CB0C1CBE152BC3596CF6CFD9D5B3C386546AF0D1DFC7A4B6864B64
EECEDED1ADC18C2145A50724AD0216A402128A0618C68492D8C2CE876A7F84516C7F465F
743956704860D5BFD199677D830E2C8F03177D0514B98089C3B8BC827F83B6B1B6BDB4B8
CAB2BBA36A7A7A0D228904178A031782041C700A2E3D0D430D105402175B051E5333516D
566D775C605900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF006783157B583172553B70543D785B487A5D4F7C5E547A5C547C5D59795B5A795C5E
7C60657E626782666B81656E8468748B707C90798494808996868D9989939886929D8794
A18996A78E9BAB929FAD8F9CB593A0B6919FBB95A4AE8EA73F376E08156E00117501167D
031A7D11276E8A93B3A5A6B1BEC0CBB3BACCB1C0D9B7D4F895C1F15A91D73070C81359C1
0A54C80453D00356DB0257E0015BE70060ED0165F1036CF70574FA0A82FD0B8EFF0990FF
078EFF0289FC068BFB0286FA068BFB0886F60C77EB0862DA1262DC226CE42A5AD7435BD5
5451CA6246BC7946B5893EA79133999F3092A72986AD287DAC2474A8216FA624729F226F
9E206CAE1D60CC1542D91026E0101DDB0F18D80D17D40915D50A17D30914D40812D50913
D40814D50915D30713D40B18CD0F22B5283AF8BAC6EFD1DC936C7CE9CCD9D4B2C48B536E
EDCEDED0A5BA931F42AE0822B20213AB020F960516C37280E0C6D0D4C7D2D3C5D1D1C0CC
CCBAC7C0B7C1CFC8D5A5768D88133197041B8B0919A2606AC1B8BDAAB5B9AAB5BCAFB8C0
8D8A95AC8B9A6F13298404148C020F8B020F7F0419550C33160D4C04145A011555061D4A
3B5468535B5600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0044AB0D815C3373563A745841795B477D5D4E7F5E527E5E557C5D597D5F5D806164
816367816769826A6D81676D866B748E7581917A8795818D947F8B9A869298838F9F8996
A48D9BA48C9AA58A99A48997A58795AB8C98B493A0B295AD352F6705136D01157B011882
011C831939888DA5D199A8C492ABCE88AEE44E7FCA2763C00F53BF074FC70450CF014ED2
0250D70154DD0155E20158E60562F1066BFA056EFC0673FC0976FC0671F80571F6046CF1
0769F00B69EE1068EB1360E41E5EDE295AD4243BB32A269B4225977437A3923299A62F8C
AE2A82B62C7FAD2876AA2976A9307E9E307E903286873A8E773E966444A15852B34755B8
4155BC634EB1AB2D77E01C3EF11C27EE1A1FEB181DE8141CE6111CE4111AE5111BEA1722
E00F1ADE0F1BDB0C18DA0F1BD50F1FBF1B31E38F9FF2D7E1B097A4E5CBD9DAB7CA95617A
F0CFE1CA94AD9B1C3FB40820B80414B70613AA0A1AAA4052B78294AD8DA0A891A5B09CAF
B5A8BAC7C7D2CEC6D4AD738E890D2D990319930819984C57CBBDC5B6BEC4ADB6C1A9B1BC
AFAEBCB193A3731A3184041788000B88020B8004135D0C301C0F4B04105601115401164B
11274647525200FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0048AE10865F367E5D447E5D487F5E4A81614F83635385635883625A836260866667
8568697E6465846D6F887075896F778B747F8F7985967E8D93798A987E8F9A80919C8192
A48A999D82929D8091A18392A88A97B493A0B6909FB495AF35306B061A77041F8A02208F
022493042E904671C23A68B71C57B51456C70445C00344C40145C9014AD30050D90253DC
0659E4055CE9055EEC065FEE065FEF055DEF0259EA055DEA0A59E60D50DB144ED51C46CA
2D42C43C42BD5145BB603BA97D38A0852D8B7313697516667D1A6A9226729C28769C317D
9739868F44918152A06556A45562B24067BF2F6ECD2676D91F7CE01A81E71685ED1588F0
1585F43876E9944CADE12C5CF5202FF11C20EE191EE9161CE7131DE4101CDF0C1ADC0E1A
DA0D19D60915D60917D30B16CF0A1ABE0F24C75E72F5D6E1C5B8C3E0D0DBD4B2C5A4758B
F5D0E5BB77969F1638B00319B50111B50410A70A19CB6A76E2B6C2CAB1BFBDA7B7B39FB0
A294A4C7C2CCCFBACB883C5B960C2B9D01179507189D4D5AD4C2CAC3C5CEADAEBB91909D
AEA5B3946D8078183389051B89010F85010B77010F5A0929230F4807135501125801134E
04163D3C444D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0050B315875B32835E47815E4A815F4B84645286665587655A87655D886965866967
856B6A836C6C86707387707889727D8A73808F77859379899376889C7E8F987989957485
9B79899D7D8C9D7D8CA1818EA98894BB97A3BA90A0BC9BB8403E7C061F8003269501289B
052FA50130A50434A90235B1033EC10141C90145CE0248D0034ED90657E4065CE70659E5
0655E10251DE014FDC064EDD094BD90D45D11340C82240C33337B3472DA065319A74288A
8925808D1F7295237095216B9A25709B317B7A2A784F21763C2D874C53AD455DB5456CBE
5481C97CA2D69AC2DE97CDE48AD8F068D0FB3FBDFF1FACFE0F9FFD0C9BFE098EFB0884FA
0476F81866E96A4ABAC42662E0122CE5121FDD0E19D50914D80B17D50916CD0111CD0613
CA0610CE0812CE0513CE0714CA0617BF0A1EB4384EF5CAD5CFC8D3DBD3DFC4A7BCBA90A7
F3CDE2A55274A51134B10317B30110AF020E9E0A18CE7684DEB7C6D1BECBD2C4D3D3CAD5
D3CAD5D2C8D5E6C5D89B42609E0B29A30216950817994752DBC5CBC2C0C9B5B3C0B9B7C2
C5BFC8AE8D9E7A1C3889051D8A010F83000875020C5E031A380B38120D4909165702124B
021239252D3600FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF002BDB0C895B2D836046825F4C83604E8865548C6B5B8A695E8A6A628B6E69866C69
826969826A6C846A73816674856B788E73818A6F7F90738590718391718291707F93707E
9B79879B7E8AA08490A48694AF8E9DB694A5AB8DA5AA9DC23C4A9007298E032CA0022DA7
022DA8002FAD0030B20034B9023BC30646D0054BD60650DA0551DA0450DA044DD80547D3
0842CD0C3EC71237BD1E33B53130AD4A2EA2612A94782583881C72951E68901B5F8E2064
82216579266D682B77583A8E4B4CAA3956B62D68CE1A70D6167EE12598EA47B9F078D9FF
A5F0FFB8F0FFADE6FE7DCBF040A5EE1D95F50886F30281F6027CF60279F6006EF10067F1
015FED0B55DF3834ABA22067D40F31D90B1DD50718CE0411CF0511D20714CE0412CE0915
CC0510CB0410CB0411CC0715C80A17C11523A52939EDBCC8DDD4DFDACDDDBB93ACCA98B0
EDBAD1983959A50F2EB20517B30210AB0410A01D28C275829C7284BDA3B4BAA7B6B6A5B5
B39DB0A6859CBF829E9D2D4EA60A26A704168F0B17C6848BD2C2C9A9A5AFBEBAC8B0AEB9
C8C7D2CAAFC28026458C06208E020F8802087A01066C020E5606223D103B1D1449050F44
05153B1F242E00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008A5B28825F4284644E8665528A6956906F5E8F70638F726891766F8C746F
846C6B80656A765B657A606D886E7B876F7C8469788A6C7B8465758867788B65778D6879
9776859C808DA38A97A68F9FA390A69D94B17A7CAE40559D0E3293022C9F012DA8032FAF
0232B40234B70237BC0742C70540C7033DC60340C90442CA0741C8093BC21137BB1B31B1
2A27A344269A5F248D731D7B85196D8A17618A195C871E5F7C2167702E78512D7F34338C
2846A42355B52067CB1872DB1684EA1591F21198FC13A2FF0E99FA1598F61999F6168EF0
1B89EB187DE41478E50E73E8046AEA016AF00168F20169F30060EB0063ED005FEA005EE8
015BE70553DC2E46C08D257BD0133CDA0B1DD90915D90B16D90916DC0C18D90915D60914
D50712D30612D50A17CF0C18C7222AD2565EB76872DDC0C6DFD8E0B8A5B5AC8196B48298
C08BA1C0708AAD2D48B0081CB40210AB0513B84350F6C6CFD8C9D3CEC8D4D1CBD8D4CEDB
D7CEDBC4B4C4D6A6BC9D3350A30822A40513911621D2A0A6D3CAD2C6C5D1C2C1CFC0C4D0
CCCEDAD0B3C987264995062395000E8F010885020772020D550318410728340F36151039
0B163627262D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF008D5C2585604086634C8D69558F6C5795725E987A6891776A988177927D78
87727180696B7C626A7C626D7E646F7B616C7F64708062708363728766758F6B788E6B79
9174839A83959588A08D8BAE616DA228428C103592052D9B0430A90130AF0231B20237BB
053CC20234BC0232B70136BA073BBF0737BA0F3ABA1836B4222AA4382295531E87711E7A
84186A8C135E8C12578616587C1B60651D684C287934358D2644A8194EBB125BCD1773E6
0E7BED138CF81495FF078AF71399FD0787F90381FB017BF80275F6016BEE0068EE026DF5
0166EF0166F10164EE0169F10166F10062EC0061ED0064EF0067EE016CF1016FF3006FF1
0476F8036BED235FDB80399DD62155E91627E9131AEB161CE91219EC151AEB151AE40F16
E51019E40F1AE4111DD81620DC525AFDC6CCEDD1D8E0D5DFDCD6E3DFD5E5E3D2E3E2D2E1
E1CFDEF3CCDFBA5772B2102ABC0517B60719BA3249EAA8B9E1CEDBBDB8C7B6ADBEB5ABBB
BDB9C7D1CDDBE4C0D69A3452A60C26A4081892262FD2AAAECAC2CBA29EACBAB4C4BEBFCB
D1CBDCBD8AA8951E44A408239F010F9701088B01097004133C04231C03262A0B2D281633
19192C1F5A1C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00966326875E3E87614E906854916952947059987B6798817296807496807B
877270806A6E7D666E7961697258627359647A5F6B7F626F8564728968768E6E7C8E7383
8A79907A779B4D58901C3685092D8F042D9C032CA1002BA50436B50438BA0438BC063BC2
0438BE022CB00428A70B2BA414289E1F1F90381D85632583801F728E165E941255901351
8015546C1B615221713827812231941740AA1350C00D5DD11070E90C73F20B78F90A79FB
0370F50472F40577F70575F7016CF10069F20168F40063EF0469F5005FEB0061EE0066F2
0067F1026BF2026DF00577F40376F20677F1077EF30883F30788F2068CF4058EF6038EF6
038DF8058DF81C83EF785EC4D7346EF72739FA2328FC2324FB2125F91F22F41A1FF11820
EB121CEE1621EB1521DF1822DB4453FEAEC2F1B2CAE6ABC8E1A7C7E3A8C6E3A8C8DEA7C5
E1A8C7ECA4C5BF4568B70D2BBE0417BD0519B30B26B23B57F1BACFE0C9DDDCCCDFD9CDDF
D7CCDFD8C0D7A961839B1A3CA6071F9C0817AC565EDAC5CBC9CBD2C0C3CDA8A7B5C6C5D2
D7C1D79E4D729F1136A9071DA704119F020A91020D71071D2F08310C0A3D0C09331C122F
271B2700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0043AA0E855B368B684F906E56936F558E6C559F8573A994869D8A80917C77
89727182696B775E636E575D765D657258627B606A82666F846772866C7C85728B726A8D
495083152973072584062B980129A00129A3032BA6012AA8022DAD0331B30534B60632B2
0C2EA80D1D921C168335167756166E751564830E51901350911754851E606C2571462376
2E2C861B34991340AE0A47BD0F5ED6106AE60863E70765EA0565E9096CF30162EC005CEA
015DEC005BE60060E90060EA015FEC005EEE0061EF0169F20069F1026FF60374F6057CF4
0981F00F86EC198DEB2294EA2D9DEC38A9F23DB2F443C1F33CC3F533C5F62AC2F928C4FE
1FBDFF12B0FF1B9FFD6682E5C04089F12A46FA222CF91E24F0181EEE151DEA121DE7111E
E20E1DE3101DE20F1FD80C1DD2152FCC254AC82956C22556BE2054BC1F51B81E4FB62050
B41E4EB51A49B61036B80620B90417B80316B5041CAE102EB1375DB04F7AB4628CBD759B
CA85ABB86088981840A60827A60215970614C66F7CDDBDCAC4BAC9CFC9D6C4C0CFC4BECC
B690AA952E53A50C29AD0817AC0610A3030C9203106E0B28270A3F07104E0310460C1136
2C1E2B00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF004CB112895D308C6B4B9273579E7F659C816BAB9787AD9B92A8989090807C
8975747E6566755B5E795E657457637458647D646E7E67727C6D7C6F6987464A7B142166
031B7003228601259402299F0128A10328A20125A00227A20427A50927A611269E181786
2F11744E1266690D567C0C4A830E467E0E4871135257155F43267E2C339A2043B60F41B8
0A45C1074ACA0851D40553D80455D90559DF0151DE0152DD0256DF0051DA0155DF0054E3
0054E30059E6005FEA0167EE0069F1006DF50174F70384FB0488F8088DF41295F129A4EE
54BDF180D6F1A2E6FAC0F5FFC8FCFFC2FFFFA7F7FF7FE7FC62DDFA32C0F61BB4FA0EA7FB
059CFC0393FB0682F6326FE58A41A1D1275CE51B35E41628E11427DE1328D40E26D2112D
CD102BC8112BC51030C00F31B90E35BB153FB61243B11245AD0F45AB1045A70E44A61043
A30F41A10E3F9F0C379D0B309C082B9F0729A1092B990729950831950B39970E3F971041
9A14429D0E37A4072BA6021CA401159C0317981B36C46F8AAE6D8DB582A1CFAEC7DEC6DA
DFADC7932645A80D26AD0613AD050EA2040C8D0313640F361D0E4F06155D021456061243
251D2E00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADB0A895B288E6A47937558A489709E8773A39083A1928AABA09B9C8F8D
8C78787B6263785D5F7D61667B6069785E697765747069804D5278172562031566021A77
021F8402238E01249703269D01259D0121980521990D2297151A8B2D19824D1571711663
7D0B47850C407E0D41680C46511558361C6B2224801128921237AE0639B90D53DA0651DB
0247D30247D2024AD40149D30048D3024BD70048D5004BD9004ED90256E20057E30059E5
005FEA016AF20271F4037EFA0284FB008BFA0397FC0BA7FD1DB6FB3DC9F96BE3FE98F7FF
B4FAFFB7F5FFABEBFD9EE3F883D5F459BEF22DA2ED1497EB0F97F20690F5048FFB0289FC
017FFA0179F90272F81067ED434FC885328DAC2365B11D54AB1F53A522589E225E922062
8E256C81266F822D7D772C7E6A267A6C2D83642B84612B895927875325834F25814B247D
4B227C4A20784F21774A1C6C4D196B4E16644F146053155A5610535F0F516910516F0F4D
770E497F0D428409398C0A328D07288F0625910828900E319011388F163D9B3459C26A8F
B14C70A01737AB0A20AD0612AA040CA0040E87051B520E3C15135B04146403176304154D
1D1F3300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF008A5C228F6B45907355A28A72A692809E8E83A99F99BCB4B2A19494
8771727F65657C63637F686B7D6A72726275585475222A5F06145E02156B021978011B82
02208C011E8F011D91031E94061E930B188A19147E3713715E1164841359900D4689093B
74093B590D4938125D201C75101F870E2E9D0832A70837B30332B50031B80B52DA0552DD
0145D20244D10145D00146D10046D20149D7014CDA0154E3015CE90164F0026DF60272F8
027BFB0484FD058BFC0698FC09A6FF09AAFF0DAEFF12B3FD1DB6FA20B4F62AB5F82DB0F6
2AA2EE2399EA1A92EC168FEC118CF00987F20587F90384FB0180FB017AF9027BFC0174F9
016FF8026AF60366F30360EE115AE42C53CE4249B94848B13E42AA3843AD2C3DAB253DAF
233DB21F3DB41D3EB81A3FB9173DB8163CB8153CBA123ABA133ABD123AB91036B51039B4
1135B10F31AC0E2DA50F2BA10F289C11289812269410218C132088131C81171B811C1D82
221D7E291D782D197233166640155D4C10515A0E47670C4172093A7D0934880D368F1136
9C0F31A50A22AA0619AD0612A8030E98020F800A244714480F156102176A051D6E021757
171D3700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF009565258F6A419174569A846B9C897C9D8F89BAB4B3BEB8BA948687
846E6E856E6C836F6E7A6C746E697D3C3F690A155402105F01136E021778031B7F001981
001A85031C890518870D16821E12763C0F67620E57820E4A8D0B3F8A0E426F094448094D
250C5D1214730D1F8A062899042FA70732B00126A50029AA0A41C5033CC5074BD6044BD8
003DC9003EC80044CF014BD50254E0015AE8015FEC026AF20575FA0278FB0482FD0688FF
0890FF0794FF0796FE089DFF059BFD0294FC008FFA0494FC0592FA028BF70389F80489F9
0586F90383F9047EFB0279FA0176FA0178FB0277FC0072F90271FB026DF8016BF60169F6
0166F40161EF015AE80159E60258E30756DC0A51D40A4FD0084ACC084ACE0647CA0547CA
0443C80240C40342C60648CB0343C60341C30645C90441C70340C50340C2023DC0023CBD
0137B90235B50131B0022EAA022DA5032DA3022BA001279A04279A01249604269905269A
05249506249508249309218C0C1F85101B7F141A781A177126166832105B470E505F0E46
770D388D0F2E9C0B23A208199F0312920413740B2936134B081562021C70042173021B5F
141F3D00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AB0128E6437927052957A668773689B8B88B3AAAAAAA1A08F7F7C
8B77718A79768A8189636580202B5E03145801156501146C03167701157A01167B02157A
041475080F6B170A623A0C5B660E537F0C43830B3C760B426013543A105F1D0E6910187C
08208C04239604269D0228A1022AA7032EB00732B40131B5033EC50042CE054ED9034CD8
0044CF014AD40154DF0462EC0469F3026DF80371FA077DFE0683FF0685FF0584FD0380FC
017CFB017AFA027FFC0182FC0280FC007BFA017DFC017CFB017CFC017BFB0176FA0176FA
0276FB0173FB016DF90168F80269F9016AF7046CF90066F30163F00163EE0062ED0163ED
0260EA015AE30157DF0056DC0259DC0255D70354D40252D0034ECE054DCD064BC80447C3
0647C00747BD0645BA0745B80743B30741B00A42B0083FAA0B46B00B46AD0B45AC0B44A9
083EA3093D9F083A9B07369409359207328F07308F072E8D062E8D072D8C052D8E042B8E
032A8F032A9304299202258D01218B02218B021F8B041F890620870A1D800F1C78171A70
2818673C16575C10477A113A890C2A810720650B31280F4D061564021E72032477031F63
181F3F00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0C956533916C4C9276608A7467A4938E9B8F8EBBB2B0928682
8F827E8D888E5F6686152763041B6C02187301167301147203167501147404147208106A
160D5C2703424C063A6D0B38750936690B3F470C5127116617197D0A1A85061F8F052296
05249A02209A011E9901209A00209D0127A60231B30039C00347D00251DA075FE90159E4
0259E4045FEA0369F40574FC0678FE0677FE0473FD0275FD0276FB0478FD0174FB0272FB
0270FC016FFB026FFB016CF7016EFA0272FA0375FC0374FC016EF80070F90170FA006EF7
026CF80166F70161F30261F2015FF0005CEA015EEB0261EB0362EA0262E70462E60360E3
055CDC065BD7085BD4085CCE0C5AC80C56C01058BC1357B71454B31A52AD1F54A82358A5
2858A22E5BA1315FA136639E4169A04368994C6A98516F9B4F719C4F709B4D6E9B4D6F98
496B934B6B9248688D46668A47658C43648845638A3F5D843957803656802F5380264B7D
254A801C427D193C7D13337A0C2C7907297906267D03257F042381021F7F021E83042085
0720850D2081161A752A196745165556124449124816105303176802227803287B06276C
1E234100FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00758E249069438B6E558F7666917C748E807CC5BCB99F9997
9998A05A64830B205D052074031F7E021B8001177C021476010E6C070F651209562D0A4C
47083B58082B5C09294F07323506431F1061121C7F08239106269C03249B012198011E94
001B93001A94001C9600219B0126A3012DAB0339BC0243C9034ED70258E20766F10769F5
0464F00567F3036BF70471FC026EFB0168F70267F80166F70269F90269F80167F70165F6
0062F40162F40161F20060F10062F10267F20165F20369F40265F20063F00165F20265EF
0062EF0265F10462ED015DE50560E6055EE20860E00962DD0A61D60C60CD105FC71762C2
1E60BB2764B53269B23E6EAC4C73AA587DAA5C7DA45F7FA36582A26D85A26D849E70899D
73899C75899C748B9C748C99778C977C8D97808D967E8D977C8C967D8E987C8D977B8E97
788B957588906B7E87667A826578826A80886C7F886A7C8664768060757D60778159747E
5B75805F79855A7281556B804C637E435D7C3952782C487327437527437E113075062776
04257C02237E0323810826840E237F162176141E70071E7403227D032883042D81092A6B
24264000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF002ADC0D94693987694A8E72618A706692817AABA4A1BDBDC9
535F841022600F1C6A0D1A75051B7C041D8302187D0816730E0D5B1F05464107395D0B2F
5A0826430424250231160B500B136C051983032295032AA30128A30126A001259F01249D
02249E0228A5032BAC012DAD0130AF0136B60343C6034CD30758E20459E6045DEB035CEB
015AE8015FED0465F50162F4005EF1015DEF035DED015BEC015BEE025FF00263F40261EF
015EED015CEB015CEA015CEA025EEB015CE6015DE7015EE70260E80160E80464E70766E3
0864DF0963DA0E62D4105ECA1860C42265BF2867B93871B84B79B8547FB06186AE6A8BAC
728FAC7892A77E96A48599A384959F87979F8C99A18B9BA18D9CA28A989D849295899A9B
91A1A390A0A38FA0A58A9B9F8B9B9E86959595A0A2929FA192A0A38E9C9F88979B93A2A5
929FA38E9D9D879496829193808F93899A9B8D9B9D8895988390927B8A8C7C8E90778B8B
768B897E94917F93928294977D909576899072858D6579825C6F7C5A6F8050667E3F5979
2D4A741D3D70113475082F7D082F89072F8F062E91032B8F022A8F012889042C820D2A67
2E263900FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00AC814986654289695489706194847AA7A5AD6A779E
142464281B644A1B624316641A106D0A177B0B12731D0B5C39063E52072D5A08274A0528
28012C0E023C080C5A031672021E8503239502279E0127A30128A4032BA7032BAA022BAB
022DAE0230B40135BC0741C70541C4013FC20546CB0248CE0146D0034CD8014CDB024FDD
004FDC0155E20157E70157E80156E7035AE7035CE70157E4035CE9035CE9025BE80159E4
0158E30156E10158E30158E2025BE20560E10661DE055DD50D63D41165D11764C5236ABD
3170BA4379BA5A84BC698BB77590B47B93AE8197AD869BAC8999A88A9BA58D9FA48E9FA3
8F9FA49AA9AB99A7A897A5A49DACAC96A3A49EAAAB97A1A39BA6A99BA7A798A2A2929E9D
9CA8AA9AA7A9A0ADB099A6A898A4A69CA7A8A1AAAC9CA6A8A0A9ABA1AAACA1AAACA4ADAE
A1A9AAA9B2AEA8AEAEA6ADB0A3ACAEA6B0B0A5AFB19DA4A89CA3A59BA4A695A1A297A2A3
8894958D9C9B8A999A93A3A391A1A193A2A394A3A5879798879697879697819294778B90
687D86576F7A4B6376415D7D2343750C3579073489043291022D93022C8C052D7C172A5B
16901A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF009DB84C966F4984614B8F7466998C8C6B7390202F6B
2E1C616A17508F0E39870F3E500F54270E61330A56590D44650A2F520628320330190742
06064D020B5E031775021F8600239001299A012AA10129A30128A4012AA9012CAF0233B6
063CC0033BC10139C3013EC60647CA013EC1013ABE013CC0013EC30141C90245CD0246D0
024CD60151DB0354E00455E40256E40153E10154DF0155DD0155DE0154DD0156DD0257DA
0458D80455D30759D40C5DD20F5DCA155FBF2367BA336FB54D7EB6618AB67697B8829CB4
8FA4B696A8B894A4B297A5AEA0ACAEA2AEAFA2ABADA2ABAEA5ACAFA3ADACACB8B5B2C0BB
B4BEC0B2BCBDABB5B6A7B2B0A3ADABA5ADACA8AEADACB2B3B4B8B6BDC2BCBCBFBBC5C9C5
C4CAC9CDD0D1CCCFD2CFD4D7D1D3D6D3D2D4D3D1D4D1D0D2D0CED1D1CFD1D2CDD0CBC8C9
CBC8C8C6C5C3C6C3C4C7C5C8C0BEC1BFC0C2C0BFC3BEBCC0C2BFC2C3C0C3BABBBCBBBABC
B9B9BBB0B5B5ABB1B3B0B7B6AAB1B0A8B0AEA3AAAA9CA4A4959F9F95A0A0949FA08D9D9C
7E9091788D8C718385687C815A727E415D75284A74123C7A073182053285082B6F202748
0CC70A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0035E617B38251856044927A6E80798722295A2E1E5D
6F1E519A0E2DA90617A5091E840731690A41690A3B66093048072F23063D0D0A53071166
02136E021676021D8301228E01279802299F0028A1012DA40130AA0333B30336B90339BB
0138BC043BC1023AC1013AC00240C20341C20338BB0236B80137B7013ABC013CBF003EC3
0248CE0555DA0254DB0150D90151DA0252D90355D90255D50355D20656CF0B58CB0E57C0
1B5FBC2664B9356CBA4B78B55F83B27491B27D96AE8AA0B096A7B3A2B2B6A7B4B6A6B3B2
AFB9B8AEB7B7A9B2B5ACB6B7B4BCB8BCC4BEC0C5C3BFC4C4BDC3C2C2C9C7C9D0CED0D4D4
D8DBDDD2D6D7DBDFDFE1E3E3E8E8E9E9E6E8E3E1E2DFDEDEDBD5D7D2CFCFC4C0C0BFBBBC
B4B0B2ABA4AAA199A298909C9489958F828C887A8384777D82757B82737A837178847276
817374786C6C7A6C70786B70776A6C736969776E70766D6C7E74757E7777837B7B867B7C
867C7D8783828D8988938F8D9996969896959F9D9AA4A49FA5A8A4AEB2B09DA4A397A19F
8D999781908C7E8D8B7788876C80806076785B7178435E702545681136640F2A56292636
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0060C52787603B8F79733C3A562B1D54631A4D
980F2FAC0816B40812AC050F9D021687062662072E3706381406420A105B04156C021775
01157501177B011E880224930025990028A0012CA5083AB10336B00232B40135B90136B9
0133B60134BB0238BE0239BE0138BC023ABB0032B30131B10234B30036B5013BBB013FC1
0248CA0048CC014DD10454D50353D00551C90A54C20F56BA1F60B92E68B44978B3668BB5
7792B3859CB790A2BA95A4B39BA7B1A9B3B99DA6ABA3ACAEACB2B4B5BDBDBCC4C1C0C7C4
C6CBC9CBD0CEC4C7CAC5C8CAD6D8D6DEE1DEE7E9E8ECECEEECEFF1EDEEF0EBECF0E3E2E9
D6D4DCC3C2C9B5B2BEA49FAC9891A08E85918376827F727B7C6E75766A7072666B716566
7164646E64636F6362706564726464716261756563766A62776A6073665C75655D77665E
75675F74675B75675D74675D796B6274675C71685C6F66596D64586D6358695F55665D56
645D53635D51625B50635B52645B56645D596B625E756F6A7A7572817D7A817E7B878582
868883868A828489837A837D71807B687975627370596D6C4C636639535B20333C139313
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0034E515976C427765662A2049541E50921837
AA0917B50A13B1040DB1060FA704137B0423360537120F51020C56021366011A73021C79
01187800177C01208B032999022BA1032CA6022FAB0330AD002CAB012EAF0131B20130B3
022FB50134B90338BC0136BA0135B7043BBA0239B70237B60239B7013CB9013DBC0242C1
0447C5084DC4084FBE0B54BA195DB72F69B2517FB67192B98BA4C09FB3C6A7B6C2AAB6BC
B1BBC0ACB5BAABB4B9ABB1B7ADB4B6B5BDBCB3B9B9BDC5C3C8CDCDD2D4D6DADDDDDFE2E3
ECECF0F2F1F3F3F0F5F2EEF6E9E4ECD9D4DFCCC3D2B3ACBC9F97A8908A99827B8B746F7D
6E6A756E6A716C667065616A67666C6D6B6A706B69776D69796D67776E65787066797167
786F64786F62797063786F63766C61756B5F7A6F647A71627A74627A7260766C5A7B6F5F
7A6D61766D5B776F5D796F5E766D5D756C5B776F5D766E5C786F5E746D5C746E5C6F6A5A
6A67576969576B69586D69586B6555696356645E53615A4F6058505D544D60574E625A50
6763596E6B5F75726676756973756D6F766C676F665D696251625B485F573D504427691D
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00809F425947503D1E4879193EAB1222
B70F15AE0D12A8080EB61017AC08177C06252F0A410C1A66031C7103207B022382012282
012084011E87012391032B9E032CA5032AA70228A60127A50127A6012AAA002FAF0231B4
012FB60335BB0235BB0336BB0035B60136B5023AB70239B6033DB6023FB50743B70A46B2
0D45A52657A54774AD6E93BB8EA9C5A1B5C4AEBCC3BDC5C8BCC1C4BEC3C5C4C7C7C4C9C9
C3C8C7C4C9C8C8CDCFCCD1D0CED2D1D4D9D7E0E4E3EDF0F0F2F2F5F1EFF5E7E5EDD3D0DC
C4BDCCACA3B39B8FA38B8195857B8D857A8B867B8A756F7C74707B74727C6D6E75717476
6F73726F7370696F6E626A6B636A6860685F6B6E63737164797265777160757361777563
76705F797260797260797160796E60776E5F7A6E617971607C7562766E5C7A71607C7361
7A705E78705C756D59736D57756D5B74705776705C726C5A756D5D766F5D76705D716D59
6E6A596E6C5C6C6A5C6C69596D6A596C695A6C66576D6859666154665E506A5E4E655D4C
625C4D5E58495E59495F5E4E6462566A6B5E6B6B5E676A5E5963584E6052465747434A38
12CF0A00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00CA9A6F6243515A1F4990142EB8151C
AA1214CD5B5CBF4C50A8141CB10A179709235B14471C1B6906238202258B02278F022791
02299303289501269503299C0127A001239E00219D0227A30129A5032CA9032DAD012DB1
012FB50132B40031B20131B10133B30133B10236AF063BAC0A3FA513479F315EA55E81B5
8AA3C3AFC0D2BCC9D0C5CFCFC7CDCACCD0CCCED2CCD4D7D3D5D9D7CFD4D1D7DCD9DDE1DE
E1E2E3E4E4E8EDEDF1EDEDF1EBEAEEDCDAE1C5C4CFAEACBA9794A2867D8F766D7E6D6876
746F7C827D8797949DA4A5ABA5A8ADA2A6ACA0A4A9888E91737C7E697677687677667473
667473667473636F71646E6F636C6B5E686060675A65695A6F6F62777767767563787461
76705C78725D776F5F766D5E776D5C756E5B766F5B78715D79725F7A6F607C7062776E5E
797060776F5D766F5D756E5B726B566F6B53736E58736E5A756E5E736D5B746D5C77705F
766E61726B5F70695B6F69596C65556D66566F6A5A6D6B5869675768625169604F6B6450
68645165624E58594755594A494A3F4F504659584D6163546166565861514E57494B5040
37712300FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0065C836743F42721D399B1120B1191A
A12828F5ACB2DA8B99991928AC0B17A907188B113848185E13217E04278F012693002895
022A9801299801279902279E02269F0225A00226A00127A20127A2012AA5032CAA012CAD
0330B00130AE0031AC0234AB0537A708379F16429A30569A627FAF8CA1C1AFBDD2B9C3CD
C3CACDCCD1CFD1D3CED2D5D0DBDDD9DDDEDBD9DAD5E1E2E0E2E4E4EAEBEDEDECF1E2E0E8
D2CFDBC0BAC9AAA5B5928D9E7D7987706B7867636E66646C6C6C71797A7D8E8F92929699
909498878F907C8687717B7B6B7575687171697271626B6A5B6868596967586867586968
56686956696C56696D586A6C5D6B6C5D68645C665E5D655963665C696C61747264787160
77705C76715B756F5C766F5D726B59756F58756E57746E56746E59776E5D776C5C756D5B
7A725F756E5B746D5B756F5C726B586E6852736D57736E597B7565767061767062746E60
726C5E736D5E716B5C706A596F69566E67556E69566E6C596D68576C6553655F4868654D
676653666857565A4C50554A343A323239323F433A4F5242575A476163515F5E50535645
4D493312CE0800FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF006BC82A8E472E8720279E171C9B1E1C
BB6767D097A0BC7B88B5505DA4131FAE0612A4081E7E13463619690D2488032896012597
02279801289A01289A02269C0226A002259F0127A10129A20129A20128A00129A3022DA8
032DA6052FA108329A143D952C5195546EA08798B89DA9BBADB5BEBCBFC6C1C4C6CACACC
CDCDCDD1D1D1D5D6D5D8DBD9DDDDE0E1DFE3D9D5DBD0CAD2BBB4C0A79FAD8F86967A7382
6C6573675F6D66606A63616866686C6E74728087857F8885798380737E796C757267706D
65696765696463675F64695E65675E66675D66655C67665A63645A5D62565A5E53575C55
5058554553544053544457594B5D605160605663605C685E60675B64675A6A685C756E5F
746D5B74705B746F5C777060797060776E5B746D57756F59776F5A78705C77705D79735F
756F5C746D5A726A55756D58746B58726954766D59756F5C767061736E607370616E6B5C
726D60756D5D716A596D68586D69586D68556E67546E68546E67576C67546A664F69654D
6362506B6C5F595A533A403B29342F28342D2D392E3C4535494E3D5254415E5D4B5C5E49
56533C29A31500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C0713A8D210C9D1E17B24E4D
D89EA2D9B5BDE5C0CBE3A2B0951C2CB10D19AD04119C09276E1752281B7509238F012596
01249801249902269A01259A02269D0127A00229A30128A000269A032899022799072D99
10329326408F4B5C97717BA1868BA19B9CA8A5A5ACA7A8ABB0B0B3BDBCBFC7C4C6C9C4C7
D0CBCFCDCACDCAC9CFC1BFC8B0ADB997919D8B808B80707A77666D7063676E6365716968
6D6C696B6E6C6E7474697474677272636F6B626C6B6169675B645F61665E67695F6A6A5F
6C6A5D6F6C5C6E6B5B6B6B596E6B5C736F5F77715F7A72607871617A75657D7464786E5F
746B5F5E5B54464A4439423D444D4A4854534D5C5857655D60695D6B6F62757168706B5F
706B5D6F6C5A746E5D746E5E766D5D756E5B736E58736F59756E57736C54756E5A756D5B
776D5C756F59736D56746C55786D5A7B705E776F5C706957726B5A746D5E7D7768898576
7D75697165567164546E65566E69596F6958716A577069576C65566E68586A645268634F
6B695A6465594D4D48373C37303C342F3E33314034424F414B53445355445354405A5B45
5D59412EA91B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007769079E2D18B8615E
A77278DAB9C2BE9EAAE1B1C0A34051AB101FB20410AC0619940E35511560161B82022192
02249901249B01259B01269B01269B02259D02249C01239803269208298B163286314386
585F8D7672918A8095928895968E94A0999CA09C9FA5A4A7ACABADBBB7BAB9B3B7B3ADB2
A9A1A8978F98837C88706773675D64655A5B75676183736983766A7D766B75736972756E
66706C6472715B6B6C54636457605E58605A5C615960635969695E6F6C5F736D5F726F5E
7877658B8B7AA8A59AC2C1BAD1CFC9D3D1C8D5CFC7CCC1B7BCAEA4B6A79AB2A193AC9888
A18E7F9181767E7466645F515A594E484C424651484E5E5458635A64675F7170687D7B70
767568686655736C5E766F60756C5B736C5A716C56706C56746B56766B57756958756858
756856756A56756D57756F56766E59716956776F5C746C58706956726B58756D5E746D61
7A7064796D5E786B5B776C5C777060726C5C716A5A70695970685B6F695A696454666554
64665B52554D41423B3B3F363842363A4737404E404855494D574D5961545F6251555540
5A573E2FAA1B00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002CD506A04924CF8C85
E9BFC4EACCD5E1BECBF9C6D6AF475CAC1022B40512B30512A5071F78134A2B167108218E
02259702279903289C02269A0124970125940324910925861C33803E4B825D5D82746C84
8173828B7984917F8792818892848995898D9790939B959C9B959C958D93867F82767171
675E5C615451675A566E615A74675B7C6E607F71628076677F7A6B727067686C67586361
5162624C5F60495B5D4E59575F60576966586D6A5A6E6C5B7876678782779E9C8FB8BAAD
CBCEC3DCDBD8DDDADFCFCAD5BDB6C2A79FA8998F938D807F84726F7E6C647E685D7B6457
7865557A69587E6F5C80735F7C73616E6D5A4F5446414D434D59545B625B63665D6B6B5F
7C7C72817F74777367756E60786F5D766C58736E56726D55716952726B53756A58776A57
776854756955756A54746952776A57756B57786F5A756E59736B58706956726958746B5D
766B5F776B5D7C6F607A6D5D776F5E766F5F726D5F726E607772666F695D666154636255
5A5C53494C4342463943483B464C3F4853434D594C4E5A514C57525D6860696D635B5C4A
58543C2DAA1A00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0051AD19D19287
D9ADB4CBA4B1C88DA1B44E68AC1931B60C1AB7050FB7060FB108168C10393C15650A2089
02269501249401259602239203238C0726821B307D40477C635E7C6F62757D6C7A7F7078
84727889757B8E7A809181879085898D83868780857B72776C636364595662574D696050
7368547C6E597B6C597D6E5981725A84735C7F705D786F606D6B5F62655F555E5D485958
3A4F4D394C4849554E5D61556C695A7B78688D8A7BA7A497B3B2AAB4B3ADA7A5A29A9896
908B8F8781889187908A8187897F838881808A8180887F79847C737B7467695F516B5F4E
6C5E4D6C5C46746044755E417562487A725A6B6C5B4851453847404B59545B625B63675A
6E6F627D7E71858578807C6E76705D746E57747058736E55766B55776C53766D57756C55
766A54756953716753766E59776F5C78715E746C59756D5A756C5A746D5A756E5C746C5B
776B5E776D5E786E607E73657971607570607774667474676E6E63656156665D545C5A4E
4E4E424B4B3D4E4F40515445525848525C4B545F50525C52505C545D68616A7168676858
59553C2EAA1900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C48370
B5838AECC1CFE19EB0A42132B60D17BB090FBA060ABF0F13AE0B1987123D3B1869091F88
02249201228E04268D072582182E79333F72525271685E6E74636C7D69707F6D727E6E70
807172857578847579817679756D6E6A6462605A5560564D695C4D796954806F5785765B
83765B7F73597E70577E6F5582735683735881715A776C5A686558595D56495350344441
33433C4553475B6354727466888579949187928D838A847C857C797F7976867E7B877F7C
87807C7F7C777F7D777F7E777F807A7A7D7478777271716B686C665C655D525A5350554C
515249514D3C6F6044856B4B7C5F3E7560426C624D686B5B464D443A464049554E556053
6367596A6C5E7070628481728784737C786477715E79705A756951796C547A6E59736B56
756A57736854746C57756E5A78715F776F5B706A54766F59766C5A76705B746E586D6652
756958766E5D756D5F7773617773637471647471667172686B6C6465655D5E5B51555045
5750445653435C5A48595B4B5E61525962535862575561575D675E6168616A6D656B6859
5E563C2CA71300FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A96C4D
DBA8A9E0A6B6B54C61B71B27C71314C60E0EBE0A0CB40D1795102E5E19571E1C7907248E
02248B062581122B742E3A6E4746665F56676A5D666D5F62736565786969796E6D7A706D
796F6B756B686D6460675D5763594E695E4D72664F7E6F5686755A88765988755788755A
84745A8072597F70577F6F558474568272537E6E52776A536B63515555483D433940493E
5B64576A6F617274667E7B6F7A736A7A73697B756A7B776B7C776C828175808176797C73
777A72727A707079716B786F65716A646F67676D67656B64616A6359645C565D56545850
4D4F464B4A3C6D624B8671537E5F3F785B3974624477745C6265573F484037433F47544D
5961536367556B6B5D6F6C5D807E70878575817C6A7E7460786C54776B53776C57746D5A
766E5A766B57776D55746B54746C58746C59726A55756E57786D5A746A57716954746C57
796E5C78705E767160797766787468767468726F656D6F666869645A5A535352475B5649
60594A645D4D63604F67675964685D5C655A58635A5C665E5F655F5F645E696B636E6958
63573830A60F00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0090A346
D39A97E092A1A62634C1181BCE1613CE1415BC121B95153261225D2423790A2989082A87
0D297724356B424765524C5B5E555A655A5D695C5F6D5E5F716362706661756C6570685F
665E535F5647675B4772634C7D6C518371558472548573558A785A8E7C5E8A76588B7556
87745881725A7F70597E6E558071528273517E6E4F776B4E71694F5D58435855446E6B5C
7774667571627672617972627774667473666E73677A82768C938A838E87717F7B677875
5F716D5C6C685C6B6557645C5A655B5A62556264586765566665546765536A66556B6558
6F685D726B5D84775F806B4D7D5E3B795A3679624174684B75726064675D4047423A453F
4C554B565E4E66685A6F6E5F7374647777667C7A677873607A725D7B715C776C58746C59
746955796C57796B53746A52746C58746D5A736B55776E56786C567C715D7F7463776E5C
7B6F617A72647975677777697674697372676E6D67656862565A5655564E5B584D655F50
6D6656716A5D6F6A5E6D6C6063675F5B635A5F69615F6A625F66605E645D65665C69614D
614E2840B11400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053AF19
C4796B95343EA61D24C41A17D11815C6171E9F1A3865296721257C0B2B8908297B1D326D
3B42634B4956554E516057576057555F5855645C596C625E6E645D6B6456665D4A665B43
6B5D417769497F6F4C847150867051856F508672548773558874568A775686734F88714E
86725383725A7E715B7C6E557D705387795A8374567C6D5074684B695F43766D537E755F
776E5A716853746E5C6A6A5D565E574F605B576D6B667D7B788B8D657B7E526A6F496062
485C5A505C575B5E566163536666536968526B6752706D557E7B648C877397918490897E
7E776C7C73617E6F577A6547796140836B48826B4A7B684873664E7673626A6C63454E46
444C44757B6F74766A6E6D60726F60726F5C706C586E6C57706B57746D5A7B735E807863
7B6F5C75665076634A76684D726951716953706650766B56786D5B82766880776B7A7366
7B73697771667370666B6C6167685F6868625F5F5C545753565B535F62556A675A716D5F
747162797669747367686C60636A63616C64636D67646F65636B6162655B655F516D5C41
76592627DD0D00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
9D5226D6867CBE5051BD2221C31618AF203675336C292E800C2D84122F76293762454554
544C4D5A524D5C554E605852645C55666057686259625C4F645B476A5D4172613F7D6945
826D4B84704F8673528976568873548A73548972538872538B755687735384714E86734F
8673528573578072597F72587C6F547F70548371558270537361437E6D4F8473567B6A4F
796A50726751535041313832293B392E4946355254365359364E562E474D2D4346384945
4C554B5B5E4E656452706F5B7B7B68969684ADAFA0BCC1B5BFC0B8AEAAA59A908D837872
7B6D617B6A557F6B51877558806C4F7D67467A623D785D36745E3A7164497A7A686A7164
4E544B5D5E52706B5E756F5E756C59786D56766C55726A536E63506C614E706551756D58
8277657D6F5B77624874624473664B746952766C587B72617F74677B70647971647B7569
76746974756B72736A64675D575B53555853585B575F625B62655A686B5D6F6F63767669
7A7A6D7476686E71636A71636B74696C756D696F69686F63686B606561526E60486E5429
70932200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
23D003A6593DD47471AF2123B724328D386838348514368A1B336E3D415C50474B544A41
5F554A625A50635B50645D506E65576B634F695E486B5A4275603F79633B806840826A43
886F4D856E4F8573568A795F8373578473558573548B77588B7454887152846F4F887452
84714D83704E837051806F52807052816F50806B4D826D4F7C67498872537E69477C6846
807155655C454443333C413736413931443C2F443C2C403B2A3C392D3E3947534B656C5E
8284769E9F94B5B6ADBFC1B8BABCB7A6ABA58C918C7A7E7B716E6F74706E78716D7E756B
8275668878668B79658E7C63816B50745F3F785F3B795F34775D31705D36756A4E6C6C5A
7070675E5A4E706657756C55766A4F74654776644977664C77664F6B5C46756A53756E56
776E5B7E746082705977664A796C537971597C74607B7362746C5C716B596F67596F685C
6261555D6357575D53535A535159535A6259646B60686F616F766674776A7E7E737E7E73
76776C71746671746973776B72766D6C736A6B6E656A6B5F6C6B5B6A62496F5830678C1F
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00807F1CA3321EA31A1BA134565A3C851E378D2036713F404F5B4D435D4D3A5A4D39
605843675E4C6D63536D62516B5F486D5E4075614078603E7A613B7B623A806845866D4C
886F4F87705289755888785B847558847657847655857252867154887356937E61897254
836B4B866E4D866E4C86704E806D4B7D6A4A7E6C4D816F53826D50856D4C7D663E7D6A44
827457787059716C5776705D7E7A69909382A5AA9CB4BAAFCBD2CCD7DCDACED1D0C9CAC7
B7B6B4A6A3A38A85897670706C68686D6E68787A71909389A8A7A29F9E9A84857F727268
716C5E8278678274649485729F907CB5AA9690826D7D6948796137735D30705E366F6446
6C68556A665471665075654775634077633E725D3C6F5A3F77654C76664C6C5F46787158
78725D79725F86776584745E7F705B776B567468536D614D675E49655F48605A485C594C
53574B4C594D525D5656625B5C686366716770776C727A6B797F717B7E757A7D74797B71
757770777A71787A7173766B6E71676F71676D6B616E685A756952735F37658C2000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF009F390A91211E8545753B3D8A293A793F3C51594A3966513365503368563C
6F614772654C6E6049706046756345746340786542806B4A806C4A826E4C877352847251
8572538875568C7A5C8A795B87785A8B7C608473558370508670518D76568B7453866D4C
866E4A876F48867046836E44836F47816E4B7F6D4E7F6F5488775B8672508069417F6841
7C694B7B6C527B6D557F715980715B8C7F6D9A8E84ACA3A2BDB6BEB0A8B68F8894777277
7068686D645E786F647B7164756E6167685B929288BABCB2CBC9C4B5B0AC9B968F8F877D
7D73647D715E877A67877D6A8D8677BEBCB69D97958A7E718772547D66417761386F5B37
6C62457B745B70624677613D7B633A78603779603C745E3F6D5B3E76674873654B786E59
8076667D72628172607C6B5375644C71634B6C5F45655B41635E455F5E4A5B5E4F555C52
525F57586962596B656070696B7871737E76787F76787E73797F75797F76797E77767B74
797E78787D76777A707174676F6F63716F626E685974664F7B623A6A922400FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ED608883825714C723F3F743B37505341366A53346D5631715A39776344
7766467164446D624277694A7B6A4B7C6C4B7C6C4B7F6F5083735684735784735786775C
89795F88755B8D795C88745593806088755886735486705188705088714C877049886F4A
836945846C43826B42826B41856D437F67417D68467D6D4C8070528A795A877150836B46
8068447D67457A6442755F3C77603F7D67497E6752816B607F6A667B6967766967706C67
82807B7C7B6F827C6B867A667C6E59837A648A816E8E8476968A7F968A7D9488778F8370
887A67827560877864857967857D6F847E77877F7A877C728E7F6A8E7B5E826D4B735B38
726142776A4F7564457C66437C633E79623A8068447A66466C5D3F77694C7667517A6D5C
8173667F71617F6D5977664C7162486A62466961476360486060515D64585F696057665D
59686261716E6A78776B7A7774807C78837B77817A7981797A81797B81797D807B7C7E77
777B7273776D74756B7371656F695C71685478684C7E633672962900FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0076892C6E4F524635424F3930644B2E7259327961397D65407B6643
786746685E3F6E674B766A4F7B6B4D7E6D4C7F6C4A7F6E4E81705484735A86755D82745D
82745B8A795E8B795C8D7A5C8D7A5D85745886745790795A876F4C846D44866E45866B45
846843876B44846B4285684084673E85693E7F663B7661367766408170509380628B7354
8B704F836845826741856A41856941856D44846C448269487E674C7A6A564B493E4B5552
838F8D868C88979589958B778C7C668A7B6491806992826B93836D94866E93846D8C7C65
8B7965897A638778628A7D6B877D6D867E728C82778E81728A7A68837358776343735E37
73613C7464457B6A4E8170537F6E4F806F508473567E7058796D557B6F587D705C7E7564
7E73637E715F7A6B577167516B66516A69566A6A5B666C5F6A716C6A75706B76736F7D79
6C79756D7B7772818072807F74817F79847F7A838178817C7F857F81867F80827B7C7C77
7D7C737B7A6E787569786F617B6B577E664789673650BB1B00FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF002ADC0F653C1B50341E5D412371552F7F633B8269407F67407E6A49
6F6247655E496A665075694F7C69497C67427F68428068447D6744836D4E837057817358
8274598475598B7C628C7C6084735585735585704F866F4C836A4482693F846B41846B45
876D48866E46826A3F836A3D83683B856A3C84693A7D6435775F3278633A846F4D90785C
8E7457917556896C4982663E856942846B41826A3D7F693C7E6943776A4D65685822322B
475654969B9BA8A29F978C80887A6A83725E86735B88775E8C7B648B7C65907E69907E69
8F7D698E816C897E6C857C6C857D708881748B82758B7F6F8B7A677E694E745E3B7C6A43
8776517C69487E6E537F735B817861897F69877E6A817A67827A67857C67857D697E7865
827C6B827D6D817C6E7A7A6C7C7D73757A72747D78707D78747F7A7F8A877F8989818C8D
7F8A897D88857785837383827A8888808C8B80888983888784868380827D7C7D787C7D77
807E787B756A7E72617E6C5084643C6E8F272ADE0F00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00653D085B3B13674B227E6337856A407D663F6F5C3C63573D
6F6A585B5C4D6768556C634A7562427A633B7D633A7E623A7E633B7F66427A6748817156
8375597D705484765B87785E8775588771538169487F6841806A40836C42816A41846D47
846D4A826A44836C42856D41826A3C866E40836B3C876A3C8366377D63367D653F7F6A4D
8C775E8772558B7252876F497E643C7C61357C61327B63337B653B73674571715B828A7D
9EA49EEBE9E8AFA6A7877A7094826E9B83699C83649A846494816897826AA08770A28C73
95846F89806E8D86798E8B7F7F7B6F888478847D6F7E72617767517D6C508E7C5D948564
918363807152867860877E6B8A82708C85738B8676878371857B68887D678B826E8C8676
918E8190908492928B8A8B868B8F8D8A8E8F848C8E859191859190899495889294899294
83898B89939284908E7F8E8B808D8A828E8C83898C8285848385827A7C797979747A7871
7A756A7B6F5E7E65488A683650B91B00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF006B470F67481A7D5F3185693B80683D6959354C422B444030
5052445E64556269586F705C6F674D736344735F3C7A63417C66437D6A497A694B7C6E53
82745B80735986775C857458847154846F50816B467F6A407E6B407F6C44836F48836E4A
86714F856F4A867047886F45866C3E856C3C856B3A866A3A8569398367397C60387A6341
7A6648826F538D7A5B8C77548C724D8164397A5C2C795E2C795F3176643D72684B827D6E
8A878093908C8C827F8B7A68AF9375BC9B7AB99674BA9C7DAE967BAF977EBA9F84B89D84
9B8675877C6F888075857F737C7467756C5C74685482735A9282678F806386765B85775C
887C618E8769978F79938C7C90897A8B8475837E6E898370968E7AA79D8AB1A89AA9A397
A7A49BADACA5ADADA9A0A2A1969A9D9CA0A39A9EA1979EA1939A9D8C9596949E9F919C9D
92989A929B9A8E9797848F8D838E8D7D86867D85827D827D7C7E797777727A766C7E7461
7C6B4C846A3B72942700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0020D404704B157D5C2C89683884683B70613A59553A494839424438
3E4539445042576355656F626F7263706C5B746A55776B53786C517B6F557B6F567B6E56
7E705980735B82755A837157826D50816E4D806C46816B43867049866F4D846F4D857250
85735086714E89734E876D44866B3E84693B886D3F85693B896C3F85673A84683C7E663D
7B67407F6D4881714F8272518C77578F775181673C7E62347B613278633772613E766A52
80796A7F7C70847C6D9B8970C8A88AC8A485C7A489C2A68DB6A08AB09985B09682A98F7A
8D78677F70618174647C705B80715A83745B887D61887F648379628279618B806A958C76
99947C9390788C8777847D718B877A999789B0B0A2BEBFB1BDBDB0BBB8ADC2BCB5BFB9B5
B5B4B0BABAB8B5B5B5AEB2B2ADB1B4A4A8ABA7A8ADA1A5A8A4A8AB9CA4A7969FA399A4A6
97A0A28E989886908F838C8A7F87867D8383797E7A7B7D777C7A737C75667E6D5382683B
6F95272ADF0E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA5067C531C89673388693B7A643E6A6248595C4B50574C4A5248
444E443F4B3E455245525D54676F6774776E7672687974647A776278745E76705B776E59
7B735D7A6F5A7E715B7F7057827055826F517D6A487F6B47856E4D856E4F8A76568C7859
88755387755387735287714C876F46866F44836C41876F44866D43876E45836B43836C44
836D4784714F8474538070518675589686679786648B78538470487C693E75623971613D
74654B776D567066507A6950987F669C816999816C94806D8574647F705E86736185735F
8373608779648578637F755E827861857C678C847096927E9C99859D9A8495907F8D8D7B
979985A0A591ACB1A4C0C3BBC5C7C3C8C9C5C8CCC7C2C6C1C5C7C4C3C3C1C4C3C2C7C5C4
C2C2C2BDBFC0B4B9BBAFB6B6ACB6B5ADB4B4B2B7BAA7ACB0ABAFB4A3ACAE979FA4919A9D
8B9396848D8E8088867C868078807E787C7978766F7E76677D6C558266426F942D28DE0E
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF003FA504875C218E6B3783683D72664868685660685C5C675D536056
535F554E5A4E49554948534A4D585260696380877F898F847B8173737668757466726E5E
75725F7B75627D745F796F5A776D567C6F567F715583725686735789775A8A785C87765A
87765A8574598574588675578674538876548877548979568979578979588B7C5D8C7F5F
8E7E618E7E628C7C6089795D85755B86775D8F80689589709B8F739A8F6F9488648E7F5B
9080608275567F7558807659887A608E7E6693836F95897598907DA59E88B6AC97BBB19C
B7AC98B2A994B1A997AEA898A8A394A19E919D9B8EA1A393ACAE9EBBBFAFC9CBC0D7DDD1
E0E7DCE0E7DDD7DDDACCD1D0CDD2D5C6CDCEC3CCCCBFC7C6C5CACCC3C6C8C7C9CCC3C5C8
C3C6C8BDC1C2BEC3C3BDC4C4BBC4C4B8BFC2ADB4B8A7AEB4A1A6AC969CA28E94998C9095
868A8E8183867878787579747979727972657A674E85673F7596302BDF1200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0043A80593692A8E6D3A78633D79745E6B6F63687167657366606E63
616E645C695D55635655615855605956615C5A656263706C87948D8A938D7A7F78777B6F
797B6D8080707B79697A78667E7C69807B67867E68867D688A80698D836B8A80688E836A
8D846D8B836C8A836A8B83698E866B8E866C91896F90886D8C84698F876D938B71918B71
958E75988E769A8C7695887091846D8A7D67867863847961837860867E648A83698E876C
938A6F958E7299947B9C97809D9780A09783A49C8BA4A08CA2A18FA9A696B2ADA1BAB4AB
BFB7AFB8B1A8C1BEB6CFCFC8DDDDD7E9EAE3F2F3EDF9FBF6FCFDF9F6F8F4ECEFECE8EDEC
DFE6E6D9DFE0D3D7DBD2D4D9CCD0D4C6CFD1C5CED0C5CDCFC3CBCEC7D0D1D1D8DACED2D6
CBCED3C6CACEC6CECEB9C3C4B2BCBEABB6B9A4ADB19AA3A8979EA195999D8B8E92898A8E
8180837D78797F746E7B6D5C78634688693E4AB71D00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF004AAF09956A2982613279674A82817170756E6A746C69766C6B796F
6D797069766D68746C68746F6A767163716C61706D60716E6471706A7674707C77858E88
8C948C8D938B888B82858A7E8B8F838C8D808889798786758785738987748A89778E8B7A
9591809493809595819A9A849D9B849B9884979681928F7A8D8A7289856D918C75939079
9B98819A978296907D9A947F9E98849F9B86A19D889F9B849E9B84A29F8498957B98967C
99937D98947E9A96819E9D89A3A38FB1B09FC3C1B4CDD0BFDEE0D3EBEBE2F5F5F0FAFAF8
FFFCFCFFFDFDFFFDFDFEFEFDFEFEFDFEFEFCFEFEFDFEFEFEFEFEFEF7F8FAEAEDEEE9ECEE
E0E4E6E3E8E8E0E2E5E2E3E6E2E4E6E1E7E8E1E7E7E3E8E8DEE3E6D5DCDFD7DEE1D1D8DE
CACED6BDC3C9BCC3C7B3BBBDACB3B8A3AEB1A0A8AA99A2A4969C9F8F9293858382807975
7C6F667968528265426D922E54BE2100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0029DA079C6C298564347F71537B7E6F7A857C6F7D766A79706A7972
717E7775807C767F7D7882817986847686847181807C8B8A7C87877C87837B8784778582
7C89867E8B8986928E97A29C9DA6A09EA49CA3A89FA6A99EAAAC9F9B9F929AA0939A9D92
9EA0959DA0929FA594B4B9A7C2C4B6BEC0B3BBBFB2BCBFB1B7B9A8B3B6A5ADAF9FB5B8A8
B9BDAEC2C5B6BCBEAFC1C3B4B9BAAAB7B7A7BEBFB0B9BCABBFC4B1C6CBB6C8CAB8CDCFBD
D5D4C8DFE0D3E9E8DEEEF0E5F4F5EDFDFEF8FEFEFAFDFFFBFEFFFBFEFEFCFEFEFDFEFEFC
FEFEFEFEFEFEFFFFFFFEFEFEFEFDFDFEFEFCFDFFFEFCFEFDFEFEFEFDFDFDFAFAFAFBFCFC
FCFDFDFDFEFEFEFEFEFEFEFEFDFEFDF8F9FBEEF0F3EBECF0E2E5EBDADDE2D3D6DDC8CFD5
C2C9D0BBC2C7B4B9BDACB1B7A9ADB2A2A8AB9FA3A69598998F8C8C857D767969587B6143
916D3F4EBA202BDF1000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF009E671F845F2C7D7151777B6A758076717E7874817D727F7D
7681807882827A8385818B8C838E8F8996968593938894958995968E9B99919D9B8B9996
92A1A091A1A28F9E9F9AA8A8A7B3B3AEB9B8B9C3C1C5CEC9CED4CEDCE3DBDAE0D8E1E6E0
E0E4DDD7DCD3D2DACFC9D2C7C6CEC5C4C9C4C3CCC5C7D0C9C6CEC5C5CCC3C7CEC5CAD1CA
CBD1C9D1D8CFD3D9D1D9DED6E0E3DAE2E6DDE7ECE5ECF1E9F2F5F0F6F9F1FBFCF5FDFEF9
FDFEFAFDFEFAFEFEFDFDFEFAFDFDFCFEFEFEFDFDFDFDFEFEFEFDFDFEFEFEFEFDFEFDFDFD
FEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFEFEFEFEFEFEFFFEFE
FEFEFFFEFEFEFDFEFEFEFEFCFBFBFBF5F5F8EBECF0E3E7EADEE1E7D7DADFD2D3D8C8CDD0
C1C6CABABEC1B6B8BCABADB1A5A7A9A3A3A296928C83796B79644C8B6D444BB8202CE011
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0029DB098F64287A63407F7D6B78817772807775857E778782
7B8987838F8F828D8C8A94938D98988E9B9C8D9C9C909E9E92A0A097A5A499A7A49FABAB
A0AEAF9BAAAE96A5A8A5B2B4B6C1C3B9C4C5C2CCCBCBD4D4CFD8D7DBE3E0DDE3E1E3E9E9
E5EBEAE8EFEBE7EEEBE3ECE9E6EDECE4ECE9E3ECE9E7F1EEE8F3EFE7F1ECE5ECE9EBF1F0
ECF1F1F4F9F6F0F4F4F2F6F4F5FAF9F3F5F3FAFCFCFBFDFBFEFEFEFEFEFDFFFDFDFEFEFD
FFFFFDFFFFFFFEFEFEFEFEFEFDFEFDFEFEFEFEFEFEFEFEFEFDFEFEFEFEFDFFFFFFFEFEFD
FEFEFEFDFDFDFFFDFEFDFDFDFBFBFBF8F8F8F9F9F9FAFAFAFBFBFBFCFCFCFEFEFEFFFFFF
FEFEFEFEFEFEFDFEFEF9FBFBF1F2F4EDF0F1E8ECEDE3E7E9E2E5E8DCDFE1D4D5D8CBD1D3
C2C6C9C3C4C5B9B4B49D9692877A6D846F578E6F49779A3558C12500FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00748F1B8361307C6C527677686F7A6F79887E788881
7F8F8984939085929294A0A095A0A198A5A595A4A49AAAA99BAAA9A2AFADA6B1B0A9B3B4
ABB6B89DA9AB99A5A8A1ADAFB0BCBCBFCACAC6D1D1D1DCDDDCE6E6E0E8E9E2E8E9DFE8E7
E3ECEBE9F0F0E6EDEEEBF1F3E9EFF0E8EDEFECF1F3EDF3F4EBF4F3E9F1F3E9EFF1EDF3F4
F1F5F7F2F6F7F3F5F7F4F8F8F6F9FAF5F8F7F8F9FBF7FAFAF9F9FBFAFBFCFBFCFDFCFFFF
FBFBFCFAFCFCFBFCFDF9F9FAF9F9FBF9F9FAFAFAFCF7F8FAF8F8FAF9FAFCF6F7F9F5F6F8
F4F4F6F1F3F2F4F4F4F4F4F6F3F4F6F7F9F8F8F8F8FBFBF9FCFCFCFDFDFDFDFDFDFAFAFA
F9F9F9F7F8F8F5F6F8F2F3F5ECEDEFEDF0F1E9ECEDE7ECEDE1E6E8DFE0E1D7D2D6C6C0C2
ACA2A195847993775E9A764C4DBB242BE01200FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00718D1E816135786C537A7D6D7D857C7A847F
828E8884938F8696948F9E9E98A6A69EACAC98A7A6A5B3B4AFBABCAEB9BBAFBABBBBC6C6
BFC9CABFC9CABAC5C2C0C9C9C6CFD0CDD7D8D6E0E2E2EBEDE5EDEFECF1F5E7ECF0E7EEF0
E4EEEFE7F1F3E6EEF2E5ECF1E7EFF2E8EFF3E9EEF3E5ECEEE8F1F3E5EEF1E5EDF0E5EEF0
E6EEF1E1E9EBE6EDF0E2EBEDE5ECEFE6ECEEE6E8ECE8ECEFEAEEF2E7ECEFECF0F4E4E8EC
DFE4E7E1E6E9E2E6EAE6E8EDE0E0E4E6E8ECE6E9ECE8ECEFEAEEF1EEF3F3F0F3F5F2F3F5
F9F9FBF7F7F7FAFAFAF5F5F5F9F9F9FCFCFEF5F5F5F8F8F8F6F6F6F7F7F7F6F6F8F7F7F9
F7F6F8F3F4F4F2F5F4F5F6F6F2F1F3F0EDF0F1EEF0E0DADDCDC7C5B5A8A1A1887E9A7A65
A47C5955C02B2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00708D1C8161337F71557D7C6B7F837A
8790898996928998968B999993A1A297A6A79AA8A9A5B0B3ABB5B9B4C0C3B6C4C6C6D0D3
C7CFD2C7CFD2C6CFD0C3CDCEC3CDCFC2CDCFC6D0D2C9D3D6CAD4D9CBD4DAC9D0D8CAD3DA
C8D5D9CAD7DDCCD7DDCED8DED0D9DECED7DCD1D9DCD1DCDED2DDE1D1DBE0D5DEE3D3DDE2
D0DCDDCFDADCD1DBDDD3DDDFD3DDDFD8DFE2D9DDE0DEE1E6D9DEE2D7DDE1E0E2E7E0E2E7
DAE0E3DDE5E7DCE1E4E2E7EAE3E7E9E4EAEAE6EBEEEBF0F3EAEFF2EFF5F5F2F6F7F3F4F6
F5F5F7F5F6F8F3F4F6F0F1F3F2F3F5F4F5F7F2F2F4F4F5F7F5F6F8F5F5F5F5F5F7F8F7FA
F8F7FAF8F5F6F7F2F3EFE6E8DCCED2C3B1B1B19A94A58778A9856684A5465BC32D30E215
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0025D90B88612B81674481755F
87847A8D938E7D8683848F8D8D9A9998A5A39EA9A8A2ACAD97A2A4B1BFC1B1BCC2B7C1C8
BEC8CBC0C9CDC4CCD1C1CBCEC1CCCFBFCACDC4D2D3C5D3D5BDCBCEC5D0D4C5CDD2C8CFD4
C6CFD4C5CFD5C6CFD4C5CFD2C6D0D1C1CBCCC7D2D3C9D5D5C9D6D7D0DADCD2DADDCDD7D8
D2DCDDD0DADBD5DDE0D7DFE1DBE3E5DEE4E7DCE1E4E0E5E9E1E6EAD9E0E2DFE3E6DEE3E6
DCE3E6DDE7E8E2E9E8E2E7E8E2E6E9E3E7E8E6EBECE8EEEEE8ECEFEAECF0ECEDF1EDEEF0
F0F1F3EEF1F0EDEEF0EBEDEFF2F3F5F4F4F6F3F3F5F8F9F8F6F5F6FCF7F9F8F1F3EBE1E4
D6CAC9C5B1ABB69A8FAC8879B3866EB889615DC53230E31700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0048B112876431
806C4C89806C8584767E8279858C8698A19C9FA8A5A2ABABA6B0B2ADB8BAADB8BBAFBABD
B3BEC0B6BFC2BBC5C9B5BFC3B7C1C4BDC7C9C3CED0C4CFD2C2CDD1C3CED2C5D0D2C9D2D4
C7D0D2CAD3D7C4D0D2C5D1D2CBD5D7C3CDCEC5CFD0CAD7D7CAD8D9CDD9DAD0D9DBCDD5D8
CCD5D8CCD5D8D0D6DAD2D7DAD2DADCD7DCE0D8DDE0D7DCDFD7DCDFD6DEDDDADEE1DBE1E3
D9E2E3D7E0DFDBE1E1DBE1E1DBE0E3E1E5E8E0E3E6E4E7E9E5E8EBE9EAEEE9EAECEDEEF0
EEEEF0EDEFF0F6F5F8F8F5F6FAF6F8F6F0F0EBE2E3DCCFCDCCBAB7BCA39AB69385B38A74
BA8D688FAB4A5FC52E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
4AB517906B35866C4487785A897F6B918C7D9A9A90A4A49FA9ABA9A9AFB0B0B9B8ACB6B5
B2BCBCB1BCBBB6C1C2B7C5C6B3BFC0B9C4C5B9C4C6BCC6CABFC8CDC0CACDC4CDD0C1C9CE
C2CCCEC0CCCFBFCDD0BFCBCDC4CED0C0C9CBBDC6C9BEC8CABFCBCCC0CDCEC5CFD0C5CED0
C8D0D2C7CFD1C9D1D3C7CFD1CCD4D6CCD4D6D0D6D8D1D8DBD4D8DBD7D9DCDADBDCD7DAD9
D4D9D9D4DAD7D8DDDCD7DEDDD6D8DBD8D7DBDAD8DCDFDDDFE7E4E8EEEBEDF0EDEDF3EEED
EBE2E0DFD4D0D3C1BDC8B0A8C0A397B29380B59075B78D688BA9485EC63031E31700FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF002ADF0E48B518906C358C6E448A7152907C66998A7BA79F93B0AEA4ACADA7
B0B3AEB4B9B5BCC1BFBAC1C0B3BCBBB3BBBBB6BCBDBFC5C7BEC6C8C3CBCDC1C7C9C0C4C6
C5CDCDBEC9CABBC8C8BDC8C8BEC8C8C0C8CABDC3C7BCC3C6BDC6C8C2CBCBC6CFCEC7CECE
C7CDD0C7CED1C9CDCFC9D1D0CDD2D4D1D6D5D1D4D3D4D8D7D6D8D8D7D8D9DADAD9DEDEDB
DFDEDCDCDBD7DFDCD8DEDAD7DFD6D4DACFCAD0C1BCC6B5B0C5B1AABCA498B29888B39582
B28D72B68C668BA9495EC73162C93031E31600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF002BDF0F4DB61C47B31E95724390754F8C755A
907E689787759F9082AA9E94B3AAA1BCB4AEBBB4AFC4BEB9C0BDB9C9C6C6C8C4C4CBC8C6
CCCAC8C4C6C3C6C9C5C8CCC8CCCECBC6C9C7C4C5C6C6C4C5C9C7C6C9C7C5CCC9C7D1CFCD
D1CFCED8D4D4D7D2D1D5D1CDD2CFCBD5D2CCD7CECAD7CDC7CABFB7C4B9AFBFB1A9BAA89F
B8A195AE9584AA8E78A98C70AC8A6BB18B67B5885E88A7465DC6325FC82F61C82C31E416
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
56BF234FBA204AB61F47B4219D754A98754F95745293765695785F987B669C816D9F8470
A28977A08978A48E7BA48E7AA4907DA69280A5917FA8917FAA927EA78E7AA68D7AA38876
A38774A48771A98971A7866BA48568A0805FA3815FAB8660AE875981A33F55C02C59C32D
5EC62E2FE21500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0106283 0.97619 0.435759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00588235 -0.00588235 0.00588235 [
[ 0 0 0 0 ]
[ 1 1.64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.64706 L
0 1.64706 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00588 translate
1.00588 1.65294 scale
513 string
171 281 8 [171 0 0 281 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F000FF00A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 178.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000/R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooolR
003o000F01O`2@0]h140;^0A04C@6P1L`2<0M;<_08bS=P2bSdD0^hQ:0;f7C02mQdd0_HI<0;V5B`2F
W3/0Rj@f08ZT=P2;YCP0RjHh05g49`0^hA80;n8C02oR52000?l02OoooolR003o000802S8?01@T7P0
D91h06RX?020`000Z8Pl0=1@N03XJ3`50?n000D0d51h00@0P<00052@N01@T7P0D91h8000o`3=oooo
o`002_oooolN003o000E01K_2@1H_b80PYda0:en@@2/OD80[ge20;>0A@2bPDL0/X180;B1C@2dOdT0
^8170;J2B`2eP4`0]h5;0;R4CP2dPD`0]8580;F1A`2_O400/X150080[ge400L0ZgTn0:el?@2^O3h0
/H120;63A@1^/Bd0;>0B01`00?l02OoooolN003o0003052@N02P8?00X23`01T0oh000P2P8?0L003o
0<gooooo000:oooooaP00?l002T08^P>05Nm801F_B40PIdd07nM=@2=UC/0/Wm:0;F2CP2hQ5@0_8EF
0<:5F@3;Qe`0chMO0<n5G03CPU/0e7mL0=MkFP3HMUD0eWED0=EbD`3FM5D0eGEG0=EhFP3DO5`0cWeJ
0<MoF@2iP5/0]XIO0;B7F`2_PU80[7m>0:ioC02XNTH0YGPn0:Mf>`2YMcX0Qhl^07jJ:`2DRS<0MJ<W
02_N3P0G003o00Wooooo6000o`000`1@T7P0P<00083000030=1@N080oh00203@D7P00`2P8?00^3Rd
0:0Pl0040:0Pl0030;Ph]03@D7P0d51h00@0d51h00<0j6Pl0?n0003oP0000`3oP0040=1@N003052@
N000o`000?l001D00?l0cOooool000[ooooo5@00o`004`0ZgA40E;/R08R@=@2]NDD0/g];0;UmD`36
OET0bGED0<eZC@3BGTL0ee0n0=U7>@3H?Bh0fC8U0=`]8P3N:Qh0gbHI0>4T5@3O8A@00P3R7QH06@3S
7aL0i1hD0>8L4P3V8AH0hAdD0=dL503G7A@0`1TB098=2`2:5Q80RQ`E08hX802?=BX0Td8d09I@?@2M
HdT0ZGIE0:anEP2WNdl0YWU40:5e>@2RLS@0YG<c06nN7`1@^1D05@00o`09oooooaD00?l000@0D91h
0830003@D7P0oh000`3@D7P00`2P8?00^3Rd0=1@N0030=1@N0030>QX?03oP000oh000100oh0000D0
j6Pl0=1@N03@D7P0d51h0;Ph]0030=1@N0@0oh0000<0d51h08300000o`005000o`3=ooooo`002_oo
oolB003o000b02WM3`1C^b00SHLk0:UhBP2aMdl0`7MF0<Y[C`3<FD<0`c`]0<PU6P3>7Q@0eATB0=dH
4`3T6140iQL>0>TJ4`3Z6Q80jaX@0?4N4P3_7Q80m24F0?<P503d7a@0mR0F0?8N503d7a@0m20C0?@O
4`3c7Q<0lQdB0>`L4@3<3PT0Z@850:D31`2P0@H0W0@809@31`2?10X0R0D907T72@1_3@d0LQXF088h
;P2QJU40ZWaI0:QiD02SLSh0VVT^09IU901gTQ`D003o00Wooooo4P00o`020:0Pl0030=1@N03oP000
X23`00<0X23`8`3oP0030:0Pl0<0oh0000<0d51h003o0000o`004P00o`3=ooooo`002_ooool@003o
000g00_g1@1C_2<0UH]10;9jD`2iJD/0_D`h0<4i;035:1l0baTB0=4B3P3G4Pl0h1<>0><D403U5Q40
iADA0>PH4@3Z5a00kQ/D0?4N503b7Q<0m20D0?@Q5@3d8AH0mR<F0?XU6@3k9QX0nRDG0?`W5`3g8Q<0
nR@D0?LR503e8180l1hC0<T91`2g1PL0]@L90:`11P2[10T0Y0880:822@2M0@H0UP<908X22P210PP0
O0D907@82`1c4A40OBDN08@o;@2?EcL0VfLo09aZ<`25NQl0BK0:02g;0`0A003o00Wooooo4000o`00
0`0Xb3`0T71h0=1@N0040=1@N2P0oh0000@0j6Pl0=1@N03@D7P0d51h0P3XJ3`00`20`000D91h003o
000@003o0<gooooo000:ooooo``00?l003h02_L3052i6P1mVC80VhU00;IaB`2gDSX0/SLX0:TK5031
4a00d0h<0=D=3`3J3Q00gPh=0>8A3`3S4`l0g0h=0=L:2`3G2PX0e`T;0=/<2`3T4`h0lAdD0?XR603j
91L0nbDG0?XV6@3m:Q/0oB/K0?h/7@3n;Q/0oR`K0?`X5`3l9AD0nb<D0?XS503i8Q<0kQdC0<<60P30
2PT0`PX;0;P5202a10T0[`@90:`31`2X0PL0Y08609L11`2?0@T0R`8708T11`280PL0Q@8808032@1i
1PT0K`T907HM5024AB/0UF4g09AQ:`1[H@/0?ZD401?[0`h00?l02Oooool<003o000402S8?02@L7P0
d51h0:0Pl0<0d51h<03oP0020>QX?0050=1@N03XJ3`0j6Pl0830000Xb3`03P00o`3=ooooo`002_oo
ool;003o001001G_2026Tc40/8E00;M]=02`;aX0^AP?0<H>2`392PX0c`/<0=@=2`3H40`0f@l=0>0@
4@3X5A40jaL?0>DC2`3D1`H0d`L80=D92P3J2`/0g@h:0=h>2@3Z5Pl0nbPL0?Ha803c=R<0lSh]0?55
<`3bBcP0mS/[0?ha7`3o<1`0oRdK0?hY6@3m9aP0o2@F0?LU503P7a80^@D50;l=302n2`d0/`P<0:T4
202[1@T0ZP@80:L22@2W0`P0X@<809/2202D0PH0RP4508`21`280PL0Q08608P420240`P0OP<907X5
2`1a1`L0MAdC08M;:02;FBP0M5D@03V`0`d00?l02Oooool;003o0005052@N03XJ3`0oh000>QX?03@
D7P05@3oP0000`3XJ3`0d51h0=1@N00N0?n000050>QX?03@D7P0d51h0>QX?02@L7P03@00o`3=oooo
o`002_ooool9003o001302GG0P2;PB80ZWU20;N7>038Vad0aVHB0;L@0@3120L0a`T80<`92@3E30`0
g14>0=<@303[;b`0fA4>0>TF403]6@l0l1`A0=l?203J2`P0f@/80=X=2@3M3`P0h1080?8O4`3L8QP0
jW]/0?faY03oa[`0om?90?oHc@3`NFd0o3@P0?d_603n;1T0oRTK0?hW6@3j:1P0gSh/0==HBP2/5a40
^Q<@0;@;3@2V1PX0V`@809`5202T1@L0Y@860:@21`2J0@D0T`0409H31P250@D0Q00508<11@1g0080
NP0207L00`1f0@D0N`4507d11P1n10/0K0T506`Q3`2BG3L0ND<@04>U0`0<003o00Wooooo2@00o`00
1P1@T7P0d51h0?n0003@D7P0X23`0=1@N1@0oh001@2P8?000`3@D7P0oh000?n000040?n00080d51h
603oP0000`2P8?00oh000:0Pl00<003o0<gooooo000:ooooo`P00?l004H0>LL=08Yn;P2UESH0V3@D
0<=l5P3AX`H0b6T<0;XC0`3120L0b@/80=4<2@3G3@`0f`l>0<X=303G9bD0ea<>0>`J3`3^6`d0lAd@
0>dL403^81D0iadB0=TG3@3U7a<0lBDG0?XZ703E9Ad0WEYE0?_/j@3hl>l0n??a0?Wbk`3b[ZT0mSLU
0?d_6@3o;AP0oRXH0?dY603T:a/0_gAX0?cOe`3TYid0cFUP0:/]:02E5a40RAD?084K4`2S=B`0Zb<P
0:452P2L0PT0TP8808`11@280PD0Q`4408T21P220P@0O`4407X1101e0@<0N@4507l21`210`P0O@<8
07851`1Q3`P0NC`Q07i5501<Q`807>032P00o`09ooooo`P00?l000<0D91h0=1@N03@D7P00P3@D7P0
0`2P8?00d51h0?n0000C0?n000030:0Pl03oP000oh000080oh0000<0d51h0?n0003oP000103oP004
0=1@N0060>QX?03oP000oh000?n0003@D7P0j6Pl4@3oP000103@D7P0j6Pl0=1@N00Xb3`:003o0<go
oooo000:ooooo`H00?l004T04n`407V6:@1nCRh0L2<E09/=2@2/4@<0bgHB0=6U1034K@`0]a@20<<:
1`3>2`T0e0`90=/?3@3N4@d0gaHA0>@O6@3Y6A00jaT>0>PL403H8QD0fU530>MiK`3^TXH0mJZN0?J[
W`3dX9@0lX]o0>AYGP20>380hM7=0?Odl`3dlo40m?;a0?_Jf@3/@SL0oC4N0?`_703c<Al0ec<S0<MX
F@3fi]l0m??b0?GclP3hl>h0k]G>0>70]03L_:h0f[RZ0<>9OP2@8B00U`<:09H12@2@0@P0S`4808/1
1P280@D0R`4708T11`230@H0OP4507l21`210PL0PP4708D22@250PX0MP4406@10@1K0`40H1X<07Pl
6@1eC@T07=l200T00?l02Oooool6003o000402S8?03@D7P0oh000>QX?080oh0000<0d51h0:0Pl03@
D7P0303oP0020=1@N0050;Ph]03@D7P0^3Rd0:0Pl02h>;@00P3@D7P00`3XJ3`0oh000?n000020?n0
00030>QX?03oP000oh000080oh0000<0d51h0>QX?03oP0000P3oP0000`3XJ3`0d51h0:0Pl0020:0P
l0030>QX?03oP000oh000100oh0000@0j6Pl0=1@N03XJ3`0:<Pl2@00o`3=ooooo`002_ooool6003o
001908Am9`1J<AT0@0L205P2102J1`T0/A040<Y_4P3EZ@@0cWH>0;dG0`3<3@T0d0/90=H<2P3K3`/0
g0h>0=lC3@3O4PT0iQL=0>8I3`3281D0aVAJ0?kMe`3jkNP0n?3[0?Kak`3fl_00nO7`0?W]j`3nj^D0
n>3H0>oVh03dl_00lno^0?;`kP3ijnP0gf5G0>Lo<03J@S@0d69E0>^_YP3njn@0mO?a0?;cl`3al_40
kno`0>GPgP3Vf]T0imG?0:ioMP1_4Q00S@H;09d32P2K0`P0U@4809H22@2<0PP0SP<:08d1202<0@P0
Q`4708011P1k0@D0M`4307/110200@P0P@<807/21@1X0000H04105P20P1@1P00MCLF04f40@09003o
00Wooooo1P00o`020=1@N0@0oh0000<0d51h0:0Pl03@D7P02`3oP0000`3@D7P0oh000?n0000<0?n0
00030=1@N03oP000oh000080X23`203oP0000`2P8?00oh000?n0000E0?n000030=1@N000o`000?l0
00L00?l0cOooool000[ooooo1000o`00C@0Ni0P0R88`05`b5P0i1`@0?P@705D31`2?1@L0[0d20<UW
403GZ0@0eH4?0;lH0P3>30X0d@/:0=H<3@3H30`0f`l>0=dA3@3P50d0haD>0;XD402WETh0mMOA0?G/
jP3ain@0l]oM0>O<b`3SaLD0ilc;0>cGeP3dinH0m^k]0?GakP3bl_00l_3^0?;`k`3flO00m/k70?G5
^`3jem00nn[U0?W`k`3fl_<0m??c0??cl`3_knd0inCQ0>CEd@3H^[@0]Gaf07`I5P2210L0T@8809d2
202J0@L0UP0709D2202?0@P0SP8908T11`290PP0P`8607X1101b0080L`4207H10`1j0@L0O08407h3
1P1i0`H0K@8306810P1H0@40F0/407Db301AR@<02_D100L00?l02Oooool4003o000302S8?03@D7P0
j6Pl00D0oh0000<0d51h0:0Pl03@D7P02P3oP0000`3@D7P0j6Pl0?n000020?n000030>QX?03@D7P0
d51h00P0oh0000<0j6Pl0=1@N03XJ3`0203oP0020=1@N1T0oh0000<0d51h02S8?000o`001P00o`08
ooooob400?l001403?P602oR5`1Y_SD0J[hh08fZC02;[E40[IQU0:>RI`2PQF/0YXe^0:J:K@2;^6H0
]iYm0:B[LP2@^6L0=Nh[03;/:@0W003o00Sooooo8@00o`00100Xb3`0D91h0:R8?01hF;@20:0Pl004
0=1@N02h>;@0^3Rd0=1@N0D0X23`0P1@T7PW003o00_ooooo000:ooooo`<00?l004h05>d60:fOJP33
[j@0<a4?03D41`0n10P0F`@809@5202a3@P0b5H=0=JV103GRQ00^1P10<T;203:20P0d@X;0=D<2P3H
3@/0g0h=0>0@303P4`h0R`d<0<nb[`3fg]T0dXF10<YGE@32=3@0_ahM0<0K702m7Al0^bHU0;`m>`3:
IFH0ZGYj0>kWiP3bl?40l>o^0?7_k`3dl_40mO?`0?Kcl`3fl_<0mO;c0?Kbl`3flO00nNk_0>3:b036
V8l0XE1808TN6P2:1`T0T@8808l1202A0PH0W`8;09l2302I0@L0U@8708h11`2=0@H0R@8608L11P1i
0@<0K`4106h10@1e0P<0N@8407d21@1k0P<0MP4207P31P1j10P0K`8306P20`1L0P40F`d306hX1P1:
TP<7003o00Wooooo0`00o`000`0Xb3`0^3Rd0=1@N0060?n000030=1@N02P8?00X23`00X0oh0000<0
d51h0?n0003@D7P00P3@D7P40?n000030=1@N02P8?00d51h00d0oh0000<0^3Rd0=1@N03oP0006`3o
P0000`2@L7P00?l0003o0005003o00Sooooo7000o`00800Gl0`0>]/N07Fk@`2=/5P0]j9c0<2MO@3C
]id0dkRU0=>gY03A^:H0d<6d0=77``2UX:H0OH2A0:^ea026UJX0JX6O07Z@YP30bLl0emGB0=KCd@3C
d<d0d/g80=39`@2XdYh0VmB?09O=Q`2=_gH0G==;05W=A@0hgb/05?0>7@00o`08oooooa`00?l000@0
:<Pl06RX?01hF;@0X23`0P2h>;@40:0Pl080d51h00<0^3Rd0:0Pl02h>;@00`2P8?001`3XJ3`0oh00
0?n0003oP000j6Pl0=1@N03XJ3`00P3@D7P01@2P8?00D91h052@N01XZ3`0:<Pl01d00?l02oooool0
00[ooooo0`00o`00C`1^]ST0eLRm0<Ro`@0d6Q`0<0<703L21P1=0@<0S@@80:T92034B``0f:H60=R?
3`2a6P40a@/80<D71`3:20L0dP/90=H;303N3a40h10>0=lB3P2I3@h0Y6iX0=N9OP2o61@0cPd:0=D<
303F3PX0f10<0=/A3@3N50l0lB<J0?8[8P2J7a`0f<W70??^kP3^jn/0lNo_0?C^k03mhn00omkS0?oO
h`3oh><0omSL0>bk_P3=QXd0SC4f08XC502E1PP0U`<609D2102C0@@0T`8809812@2K0@X0WP4<09L1
1`2C0@L0T08709411`2?0@L0P`4507800@1/0000K@4106l10@1d0@40N`4207/1101f00D0M@4607L9
3@1]10L0I`4206020P1J0`40F`h107P`0`0DjP801P00o`09ooooo`<00?l00P3@D7P70?n000030=1@
N02P8?00X23`00X0oh000P2P8?0:0?n000030=1@N03oP000oh0000P0oh000P2P8?0O0?n00003052@
N000o`000?l000@00?l02?oooolH003o000W00ch1P0kfah0Q;A60:bVIP3=Z8/0dkNS0=k:^P3Ga;L0
flVm0=g>a@3Kc/D0e/W10>7Fd@3Gc<P0dl_80=G>b`3=c=40`/;?05QWR@2M[<@0KXFU096Za024Vk80
c]SN0=GGf@3@e=H0dM?F0<k@d`3;cm00blg>0<[:c@36a/H0aL?20<O4``3?blP0c<>m0:VjTP1LcTX0
2oP801X00?l02?oooolH003o000402S8?01XZ3`0^3Rd0;Ph]0D0X23`0P2h>;@00`3@D7P0j6Pl0?n0
00020?n000030>QX?02h>;@0X23`00@0X23`00<0j6Pl0?n0003oP0002@3oP0020=1@N003091`N00X
b3`00?l001T00?l02oooool000[ooooo0P00o`00D00YgA00ak2L0=3>c`3DdM@0?2X/03462P0l0`P0
C@<707X31`2K1`L0_DD<0=RV1`3FT@h0/1d10<8:1`3110H0b`L90=092P3B2``0e@`=0=492@3C2PT0
_PX:0;H[9@3>=2X0c``90=8<203C3@T0eA080=HC2P3G5@X0fQX<0>d]7@3^<b40`cDZ0;^OV03bk^/0
l>o/0?7`k`3il>h0gZNT0=mnO03TOG/0hg]f0=I/JP2fDDl0/d0m09lW7`2N7100W18709L<102C2080
T0D309441P2B0PH0W08:09T22@2G0PL0U@8609D2202B0@D0S`8507l2101a0@40K@4106l10@1^0@40
K`8107H20P1i0P@0N@4707811@29:Bd0W45706X;3P1L0P80F0820583001Y6@808Ld11P00o`09oooo
o`800?l000D0D91h0=1@N03oP000oh000=1@N0050?n000030=1@N02P8?00X23`00/0oh0000<0j6Pl
0?n0003oP000203oP0000`3@D7P0oh000?n000020?n000030=1@N02P8?00X23`00<0X23`00<0^3Rd
0?n0003oP0005`3oP0000`3@D7P0^3Rd0?n000040?n00003052@N000o`000?l000@00?l02?oooolE
003o000]01O`2`16e2@0M[e30;^TM@3?Z8`0e[BJ0=joZ`3H_Zd0gLZk0=_:_P3Wf]00g<g50>7DcP3P
eLl0i=cH0=_Ad03Tf]/0gMGC0=;>b`3>bLX0b/K;0;FkbP1_QJ40MXZR04QSQ02R]l`0[/;A0=?Ig03C
e]P0d]KI0=7Ef03?dMD0c<oC0<[>dP39bLh0`lG80<W<c`3@dmD0c=3C0<_>d03;bL`0`kVi06ZbHP0d
^R<01o@301L00?l02?oooolE003o000402S8?01XZ3`0T71h0;Ph]0H0X23`00@0d51h0;Ph]03oP000
j6Pl1@3oP0020>QX?0030=1@N02P8?00X23`0080X23`00<0^3Rd0?n0003oP000303oP000103XJ3`0
X23`06RX?00Xb3`G003o00_ooooo000:ooooo`800?l00500MWh^0=?:b@3>cm80e=CG05Q;CP0`1@T0
?P8604/11`1g10X0U@D80;4f303HXPX0eY<=0;0R0@342`L0aPH;0<L72`3;20`0bPP80<H410330P40
a@<30=0;2`3:2@P0a0h60<DK2P37:180bcTR0=5B=`3IK540hH1V0>VDO@3j_:l0n/Rm0?WBbP3ai=d0
l>gZ0?3^k03_kN`0lo3_0?K^jP3ikNP0nN[V0?S[i@3jjnH0n^[U0?WVg`3`dlL0i/2]0>6eW@3JYi00
dYV30<N1K031JeT0TaTF09L32@2G0PL0U@8809D1202F0@L0U08808d1201g0@80L@4106X1001^0@00
K`4106h10@1`0@40M04207D10`1a0@@0K0H909i6CP2TDUX0OB/]05H2101>0@40H`d303>N00H00?l0
2Oooool2003o00050:0Pl03oP000oh000?n0003@D7P01P3oP0020:0Pl0d0oh000`3@D7P0102h>;@0
X23`0:0Pl02h>;@20=1@N0030>QX?03oP000oh0000D0oh0000<0d51h0?n0003XJ3`00P3@D7P50:0P
l0030=1@N03oP000oh000140oh000P2P8?001@3@D7P0oh000?n0003oP000J:Pl00H00?l02?oooolB
003o000a02;Y4@15dbD0M;Xo0<:GL03:YX@0d:nE0=6eW`3D^J@0fkbW0=VoZ@3Ob[H0hM310>7A``3R
e<P0j^3I0>GJeP3Wgmh0iMkK0>KNg03Sf=L0hMSE0>ORg`3Gdm00^K[00<?4bP2IZ;X0VJfo09b_a01E
M9X0IhBO0<kJi03Dem`0d]KI0=?Ef03@dmL0cm?F0<kAd`3<c]40bLkA0<[Ae03@e=L0cm?H0<[>d`36
bll0b/cB07=gRP1TK7T0MhmU01[U4P0F003o00Sooooo4P00o`001010h000P<000:R8?02h>;@:0:0P
l0030>QX?03oP000oh0000H0oh0000<0j6Pl0=1@N02P8?00102P8?000`3XJ3`0oh000?n0000;0?n0
00050>QX?02P8?00X23`0:0Pl010h0005P00o`0;ooooo`002_ooool0DP00o`00:]P=078c7`39`;l0
cloD0=?Df01mMGP0;PH903X220180PL0K`@808P2102^;PT0f9l<0=JC3@2/8`00_PP30;d52@2[0@<0
^0850<431@310P<0``830<P51P3@2`h0_@X<08dT6`3V[I<0k<Bb0>_>`03Ze/P0j]_B0>cRg03bjnL0
lnk[0?7[jP3`jNL0l^_[0>k/k03`kNd0l^k^0?;`lP3al?40mNoa0?O]l03ek>d0m^c^0?C/k03`inP0
k>7R0>GGe@3Te]00h]K?0>7Fc`3Rell0k=G>09i?BP2=1`X0S``@08T42`2@0PT0UP8809L2202=0PP0
M`4207<20@1^0040K`8106h10@1a0@40LP4107820P1`0@80K@4207DC4`2UDEL0Z5iW09=9C@1`8BH0
B@4405L7101IA`46003o00Wooooo00@00?l0052@N03oP000j6Pl0P3oP0000`3XJ3`0oh000?n00004
0?n00080X23`2`3oP0001@3XJ3`0X23`0:0Pl03@D7P0^3Rd0080d51h5@3oP0030=1@N140oh0000D0
j6Pl0:0Pl02P8?00X23`0=1@N0020?n000030=1@N000o`000?l000@00?l02?ooool@003o000d03SJ
7@1c^Cl0/Y]Z0<:KN`36Y8D0cZjD0<jaVP3>/i/0e[fU0=VoZ`3Qb;H0h<Zi0>CB_P3WelP0kMkE0>_M
dP3/hMX0j^;L0>SPfP3Qf=<0i^3L0=oKf03Qg=P0fmOB0>3Lg03MeMD0/;2e09VP/@1RMI80[[[<07^D
/@2?Z/@0P9bd0=7Fg@3Ae]T0d=CG0=3Ce`3?dmP0bm3D0<c@e03;cm80c=3D0<cAeP3?e=P0cM?H0<[?
d`39c]80]kg6069cR01/O8d0S9J503?78AD00?l02?ooool@003o000306RX?02@L7P0^3Rd00/0X23`
00<0d51h0:0Pl03oP0002@3oP0000`3@D7P0^3Rd0:0Pl0040:0Pl0h0oh0000D0d51h0:0Pl02P8?00
^3Rd07QH]00E003o00_ooooo000:ooooo`1301O`2@2bNU@0HQhC0:29QP3@d=<0d]7G09>?T00Y1`/0
=@8804L3201S0PH0QPL80:4S1`3IWPd0eY<<0:XQ002o2@H0a0L=0;/42@2j0@D0`@<70<02103210D0
bPT80=4;3@312`h0L1HD0=k6^P3Tf=80iMSB0>_Hc`3afM<0mmgN0?gNh03nfm/0o<_<0?k6b02ePH@0
_:n_0?3/jP3ak^l0lNo`0?;_kP3abLd0jYVO0=>2RP3?Q8d0eHbC0=2@U`3>UIX0ciNI0<FBR03:W940
dZbU0=k3`@3UbLT0]W1^0:Dg=03FL6l0bf9U08T;4@2A0PP0T`4608T1101i0@80M@4107000@0206h1
0@0=07020@1c0P80M04207010@1]0080K@h@0;=]L@1T8b/0/g5i08Y0BP1C3a@0D0@306dI0`06003o
00Wooooo00@0D91h0:0Pl03oP000X23`0P3oP0000`3@D7P0oh000?n000040?n00080X23`303oP000
102P8?00oh000?n0002P8?060?n000030:0Pl03oP000oh0000<0oh0000<0d51h0:0Pl02P8?00202P
8?030?n000030=1@N02P8?00X23`00l0oh00102P8?030?n000H00?l02?ooool>003o000g02cP5P2C
XE40^YAb0<2NO`35YH/0b:N?0<faV03@]Z00d[VT0=FoZP3Lak80glZg0>7<^@3RcKX0jMG30>WIa`3Z
el/0k]gB0>WIc@3WfLh0im_C0>SNf`3Mdld0h]gG0>7Ke`3Qe]D0g]CB0=O>b`3JeMH0b<K90:jd`@1T
MHd0Q9B_08jS_P2;X[L0^loH0=;Ff`3AeMP0cm?E0<gCe@3<dMD0c=7C0<_?d@3>d=@0c<oB0<gAeP3<
d=D0bloF0<[<e@34a/h0Q92Q07b>X02EWjP0]:ZX02kE8P0D003o00Sooooo3P00o`000`1@T7P0X23`
0:0Pl00A0:0Pl0030;Ph]03oP000oh0000H0oh0000<0j6Pl0:0Pl02P8?000`2P8?000`3XJ3`0oh00
0?n0000:0?n00080j6Pl0`2P8?000`3@D7P0D91h003o000C003o00_ooooo000:ooooo`1404;A7`2V
OVL0GaXB09MeLP3AdM@0dM;F0:JTY`0W20h0<`<803l21`1G0`L0LP4209/P1P3JWPh0fIL>0:XU002o
2PL0a@H;0<842P2k0@H0_`860<@320371@T0c`X<0=T>3`3E4@l0ZA@B0>nSW`3[ZZ@0e8Qn0<icI`3D
KVL0h7Ac0>1^K03QKV/0geYI0=Y;B036FeD0Z8J10?;Zj03ako00lO3a0?3_k@3^`l80eVQV0;`d<`2c
7B00/AhR09X_<@2WEeD0]FAQ0:]GC02OBCd0UD4f09]9AP2GA4<0Tbd]0;5:BP2nIVP0/U]P0:@h@02=
0`X0SP8808P21P1j0@80MP4107<20@1`0P8206l10@0=07820P1c0@80L04106l10P1W0`D0JaTO08Dn
AP2FD5X0Z69[064K8P1B10@0K1D501o;0005003o00Wooooo00@0J:Pl0:0Pl03oP000X23`0P3oP000
0`3@D7P0oh000?n000040?n00080X23`303oP0000`2h>;@0d51h0;Ph]0020=1@N0@0X23`00<0d51h
0;Ph]02P8?00103oP0000`3XJ3`0X23`0=1@N0020=1@N0030;Ph]02P8?00^3Rd0080d51h00D0j6Pl
0=1@N03@D7P0j6Pl0=1@N0020:0Pl0030=1@N03oP000oh0000`0oh0000D0j6Pl0:0Pl02P8?00X23`
0=1@N0020?n00003052@N000o`000?l000<00?l02?ooool<003o000]03OJ7P2YTel0^YA^0;bIN@2m
WX<0`JF>0<^]U`3@/id0dkVW0=O0/03I`k80flRf0=[8]@3Qb[L0h/^i0>?=^@3Wdl80i]?00>_Ha`3X
e<H0jmW:0>SGb@3Wf<`0i][B0>;Gd@3Qf=40f]7<0>WPg@3Ndll0e/g;0;>a^P2STJH0fJFa0=>GYP39
QY<0HT]W086D[P2F[/40cmOK0<kDf03:cmL0d=;F0<cAe03;cm80b]3C0080c<oC00/0c<oD0<_=d`37
c=40b/cC0<W:d@1hNX`0CEmh07V:V@2SZ:l0WYn=02;I5P0C003o00Sooooo3000o`000`1XZ3`0^3Rd
0:0Pl00D0:0Pl0030>QX?03oP000j6Pl00@0oh0000<0j6Pl0:0Pl03@D7P0102P8?00102h>;@0oh00
0?n0003@D7P:0?n000070>QX?02P8?00X23`0:0Pl02h>;@0d51h052@N00C003o00_ooooo000:oooo
o`1C06R`=@2QQGD0J2LQ0:n:SP3@dMH0d=;F0<;3aP0N2Ph0:04403T3201D0`P0N0D709XN1P3MXA40
g9d@0:TX0@2o2PL0a`L;0<D62`300`P0b@L<0</82`3:20P0e0`<0=`A3P3O71<0hRdP0<lV802d;2D0
aVAH0>6JS03e_KH0nlo70?cJdP3lhM`0ml6n08dn>03egm@0mnkY0??ak@3bko40knk^0>o_k`3`k>X0
nN[U0?[Dc@34Ge`0NalL0>34_03aiMl0l^OS0??Tg`3dh]d0l][F0>g>b03Z]k40W3<c0:8X;@3;L7H0
dWR10:XkA02>0PX0T04908T11P1k0@<0M04107<10@1`0@40JP4106P1001]0@40L`4407@10`1^0@80
I`4306821@1O0`/0KQDO07XW<P1c92d0HPP;06hA1@0mTP001@00o`09ooooo`04091`N02P8?00oh00
0=1@N080oh0000<0j6Pl0?n0003oP000103oP0020:0Pl0h0oh0000@0d51h0:0Pl03@D7P0d51h0P3X
J3`00`3@D7P0j6Pl0:0Pl0070?n00080d51h00@0oh000=1@N03oP000oh000P3@D7P00`3XJ3`0d51h
0=1@N0020>QX?080X23`00<0^3Rd0?n0003oP0003P3oP0000`3@D7P0^3Rd0:0Pl0020?n000030:0P
l000o`000?l000<00?l02?ooool;003o000k06Zc=`2eT6T0^IAb0<6QP@33XXL0`jJ?0<V]V03B]:80
e[NV0=nj[@3M]ZP0f;n/0=[5/P3Ka[80hLjl0>7=_P3Vdkl0jMK60>O@_@3Yd/00j=?00>[Gb03Ze/L0
k]g@0>;BaP3Ld<P0g]CA0>GKfP3Nc//0g<c90>CIf@2`Zk`0JcaY0:<P?02i52@0_A0L0<AMK@2X[L40
FWND0<GDgP32bMH0Heem0=FhaP3Bc]80b/oC0<K>e`38cmX0bm7E0<[?d`3;c]D0b/kC0<S<d`39b]40
/Jnl08:=XP2=WJX0Y[:h0:j//@2VSH@04`00o`08ooooo`/00?l000<0d51h0:0Pl02P8?005P2P8?00
0`3@D7P0oh000?n000030?n000050=1@N02P8?00X23`0:0Pl03oP0000`2P8?020=1@N080X23`0P3o
P0000`3@D7P0X23`0?n000040?n000030=1@N02P8?00X23`00@0X23`4`00o`0;ooooo`002_ooool0
D`22Z4`0WH^106di=P2ON7l0c<gB0<kBe`31aLL060h?01L0000^0PH0CP4506d1102D7@D0gZ0B0=VM
3@2[;000_@T50<@72P361`d0aPD:0<d93P3=2@X0d``<0=P>303L4`l0galE0>8e:02M7QD0ciB90?GO
f@3ajnL0kng[0>k/j`3^kN/0mNo^0?SPg021BD00dkn`0?7[iP3blO40mO7b0?WWjP3[gMl0k^_Z0?3]
j`3`jnP0iKNd06@]:`3Yh]d0jNWX0>[ZjP3/k>`0j^[[0>KVi`3ZjNP0l^GT0;9WJ@2F20h0U1@P09dT
;`2=2A00TP8809@2202<0PP0O04207L10@1e0@40L00206/10P1[0P40J`4206d10@1`0@40KP8306D1
1@1Q0@L0I@4906X32`1e51/0PbXa06H72P1Z3PH0>Xl000D00?l02Oooool20:0Pl080d51h2@3oP002
0:0Pl0d0oh0000<0X23`0?n0003oP0001@3oP0000`3@D7P0X23`0?n000070?n000030=1@N03oP000
oh0000L0oh0000@0d51h0?n0003@D7P0X23`4P3oP0001@3@D7P0X23`0?n0003oP000X23`00D00?l0
2?ooool9003o000n00_h1P1//cd0/8e[0;NDM@2mVWl0_j260<BVTP3?/Id0f[:P0=ZWUP35QgT0eXYo
0=65MP3J^J<0el2[0=_5/@3Td<00h<bk0>7>^@3Xe<<0i/jm0>SA_P3Xd;d0j];20>SA`@3Wd/<0gm37
0<Noa@34UZH0eh>=0=iiP03TR980hI:H0=ZU/`1jA6`0/3mN0;hB7`392Q80^R0^06M@L@23U[40/<;C
09ZN]@1`:dd0X2<i0;e/O@2dQ9H0RfN006e=I@2i/[T0d=;G0<c>e038c=<0al[C0<S;d`2Y[;H0CEQ^
05MWN@2KZ;40ZJR_0:BCU00ebB@B003o00Sooooo2@00o`000`0Xb3`0N5Rd0:0Pl00G0:0Pl0040;Ph
]03@D7P0^3Rd0;Ph]0<0d51h00H0^3Rd0:0Pl02P8?00d51h0?n0003@D7P:0:0Pl0070=1@N03oP000
oh000?n0003@D7P0j6Pl0=1@N0030:0Pl0030;Ph]02P8?00D91h01800?l02oooool000[ooooo04H0
U:aS09Z=RP1eBDT0SEmU0<W8c@3:cm<0_L3002DM7P0?0000:08604L2201P0`L0OQL30=^O4`3JWPl0
Zb`00;l;1P3520X0a`L;0</92`3?2`d0d0T;0=@;303H3Ph0fQ4>0=`D3@3>5a@0QT8m0?7Qf@3_jnT0
k^g]0>c/k03]k>d0l>_[0?GXiP3lhM/0ZfaN0:^=O@3Xg=@0in?R0?3XiP3HT9@0U3i00=2j^P3/jn/0
jnWZ0??Kf`1b<c<0`K6_0>SXiP3[jn/0jnc/0>[YjP3YinL0in;Q0>oSh`3;Ti00V@/<09l42`2H0PX0
UP8909@22@2@0@T0R`4607l10`1k0@80NP8307810P1_0@40KP420P1/0@802`1_0@80LP8406H11@1M
0@D0I04706/32@1]1`d0K`/A06P82`1T2P@0MRL100D00?l02Oooool20:0Pl080d51h0`3oP0000`3X
J3`0oh000?n000030?n00080X23`303oP0020=1@N0L0oh0000<0d51h0;Ph]03@D7P00P3oP0020=1@
N0060>QX?03oP000oh000?n0003@D7P0j6Pl1`3oP0000`3@D7P0oh000?n0000H0?n000D00?l02?oo
ool7003o001001;]2P1/Tcd0WheO0:j<L02bTGL0^IQo0<BUSP3;Z9@0e::C0=B9O02oFD`0dVUD0<UZ
DP3BL5`0dG=Q0=fdWP3I`:X0g/Nd0>3:^@3Qb[T0glVf0>O@_P3Sb[H0i<Ze0>K=]`3Yckh0jM2n0>GA
aP2ASJP0ZDQ[0<dS:P3A8Ah0cB4Q0</R9P377BH0`Qh/0;dQ=03?;cd0bQDK0</83`312Q40]E]/07aW
Q@1RBFl0RCIB0:T?7P2a0`h0[0@?0:H74P2G5AP0YEeK0=G5a`3=bl<0c/_10<[=d038c=@0aLWC0;o1
b`1XKWd0KW^708VCVP2RXjP0WiZM07BVHA800?l02?ooool7003o000302S8?02P8?00^3Rd01P0X23`
0P2h>;@01P2P8?00d51h0?n0003oP000j6Pl0;Ph]080X23`00@0d51h0>QX?03oP000oh00102P8?00
1P3XJ3`0oh000?n0003XJ3`0oh000:0Pl080j6Pl00@0d51h0?n0003oP000^3Rd1`2P8?0B003o00_o
oooo000:ooooo`150;VJO02GSXd0OUaJ07@o@@39`lT0a/W=0;:e]@0n=cT0504202d32@130PT0G0<8
07lF103HWQ<0fid@0:TY002n2PD0aPT90<L9203920T0cPX:0=0;2P3D3P/0f0h=0=X?3P3L4@h0e1DC
07XR8P3B_kd0k>WX0>o_kP3^kNd0kng]0>K;bP3JOW`0gEmM0<Y1>P24Cd@0iMS90>o/j03cl>d0i:FS
0;Df<`2VMg<0l>[X0>_ZjP3ainL0/VEU084]<@2lX:<0j^OW0>[Zj@3Zj^X0i^3N0<6BT`2aI6L0aVQY
0:8?4@2Y10X0X@4709T21P2k82@0YA8H08d11@260P@0OP4107`10P1i0P80M@820080L@4100`0L@81
07410P1a0@@0JP4505l11@1Q0@D0H`8606H4201V0PP0J@H<06LB2`1i<@h5003o00Wooooo00@0d51h
0:0Pl03@D7P0d51h0`3oP0000`3@D7P0oh000?n000030?n00080X23`303oP0000`3XJ3`0d51h0?n0
00040?n000050;Ph]03@D7P0j6Pl0=1@N02P8?000P3oP0000`3@D7P0oh000?n000030?n00080j6Pl
00<0d51h0?n0003oP0000P3oP0000`2h>;@0X23`0:0Pl0040?n000030>QX?03oP000oh0001<0oh00
1@00o`08ooooo`D00?l004<02OH505>R<@14C3l0ADA=0:J:M@2]SgP0/9F00;^OS03<ZiP0_W=T0<MW
E03<J580f71M0<IG@P3=GTP0bFI;0<]jH`3R/Y`0fl2]0=c3/`3Na[@0h<Vg0=k8/P3Uc[T0hlbe0>C<
]@3Wc[P0jM2l0>W?^`3Sc/D0I5V50;TcA03SKeh0ij:E0=RWX@38W:00b9NT0;9_P02MBEd0V3Q=0:PY
>`322a<0a`H>0;h=6@2c5B80/0dJ0;<63P2d0P/0/@@;0:X:2`2S8Qh0`hR20=G;b@3=cm40b<>Y0<2^
J03?ck/0algB0<K:e037bMD0MgV9065/N02>VYl0[[>f0;6`]@2UVIP01o@401400?l02?ooool5003o
000402S8?02P8?00^3Rd0;Ph]0H0X23`00<0^3Rd0:0Pl02P8?00402P8?00203@D7P0X23`0=1@N03@
D7P0X23`0;Ph]03@D7P0^3Rd0`2P8?00102h>;@0j6Pl0?n0003XJ3`20=1@N0@0oh0000T0j6Pl0=1@
N03oP000oh000=1@N03oP000d51h0?n0003@D7P0102P8?00103@D7P0X23`0:0Pl00Xb3`A003o00_o
oooo000:ooooo`0N0;ZKP@2VWYh0P6ES05lT:P3;_lL0_l?70:f^/01@BT/05`8402/32`0l0@P0E@89
07`E1P3GWA<0f9/>0:PV002n2@@0aPT80<P8203:20T0cPT;0=4;2P3B30T0ePh=0=T?3@3K4@d0gQ@?
0;`H601Y5Q/0b;>g0P3]k^h0<`3]jn`0mnOT0>RFS`35<BD0e2DK07d]9`3Lc;h0k>WT0>k/k03X`L00
Xc8`09=BCP3cjNH0kN[Z0>kYj@3@SX`0[A/N07hF7P2bU9L0j>KU0>_[jP3Zj>H0i[bh09Xe<@2T4aH0
Z`H;0:X3202V0PX0W@<70:dJ802I2Q40S`8908l21@1o0@40NP4207L00@1g0@80L`000781001a0@40
L@4207<11@1/0PD0G04305/10`1Q0PP0H`<706D11`1W10/0IQDA0<^YW005003o00Wooooo00<0d51h
0:0Pl02P8?000P3@D7P00`3oP000d51h0=1@N0050?n00080X23`3P3oP0000`3@D7P0oh000?n00002
0?n0000:0=1@N03oP000oh000?n0002P8?00d51h0?n0003@D7P0oh000=1@N0<0oh0000@0d51h0?n0
003oP000d51h0`3oP0000`3@D7P0oh000?n0000I0?n000030:0Pl000o`000?l000<00?l02?ooool5
003o001305ej?00L8c`01QY>02XfF@2SSh<0[IJ30;RMSP2kWhd0`:290<N3L032F4H0bUm90<EKAP3I
TGL0f:>70=J]T`3@YI00fKJO0=_0[P3L`k00g<6]0>;9]`3Ma[<0h/^d0>C<]03UbkD0il^j0>S?_03V
dKX0i<jn09N9V`33SY80ilFa0=g<^`3Jb[h0hmSE0=[?c03Ea/H0eL_>0;nld@1HCGT0ZB@m0<P84034
1@`0`B@K0;8b:P2V;2/0ZcTd0:mBBP30QGd0dkjk0<k=c`3:c]40bm3E0<kAc`37^i40`kAi0<c=`P35
bm40a<WB07n3T`1AF6T0L7f50:fb]`2c/[T0Zj>Y02G<6`0A003o00Sooooo1@00o`0:0:0Pl080^3Rd
4P2P8?000`2h>;@0X23`0:0Pl0020:0Pl0<0oh0000@0j6Pl0:0Pl02P8?00^3Rd0P3oP0000`3XJ3`0
d51h0=1@N0030=1@N0040>QX?03oP000oh000?n00080j6Pl00@0oh000=1@N03oP000^3Rd0`2P8?00
102h>;@0d51h0:0Pl01XZ3`A003o00_ooooo000:ooooo`1C0;^RR02CTi<0T7in04dD6@30/KP0^;^o
0:jb/@1UHf006`L902X42`0o0`d0B04906L?0`3CW1<0f9/?0:LU002n2@D0a`P80<X82`3<2@X0c@P:
0=4:2`3C30/0e`d=0=`A3P3N4Pd0hA<>0>4G503;71d0Vbhd0<2TZP3Zj^T0k>c]0>c[jP3ehmd0jJZL
0=1?@@2771H0_J>I0>kWhP3_k>d0l^3P0=FHU03<WYT0lNOU0>k[k03/jNX0iKJd0;@K6P2i5AP0SR@Z
0;bXZ03Xi^<0j^WY0>gUhP3X`[d0/DY60:X92`2]10P0Z0480:H83P3:Be00T18D08h21`2C0@H0QP43
07X00@1i0@80N08107<00@1c0@80L@4107810P1b0@<0JP8305`10P1H0@<0F04505d21`1P0@D0I0D8
064@3036Y9L01@00o`09ooooo`060=1@N02P8?00X23`0>QX?02h>;@0oh000P3XJ3`50?n00080X23`
3P3oP0000`3XJ3`0d51h0?n000020?n000050>QX?02P8?00j6Pl0?n0002P8?000`3oP0020=1@N0<0
oh0000<0d51h0?n0003oP0000P3XJ3`30?n000030=1@N03XJ3`0oh0000<0oh0000<0X23`0?n0003o
P0004P3oP0000`2P8?000?l0003o0003003o00Sooooo1000o`00A01kXdX0LFI/00HGBP025eh062UO
09j?R`2`UhD0/iB10;JGO@2lWH80b8ii0<5D@033G4H0aWEL0<bGN`3>Zhl0cJbC0=:hY03MakT0f[n^
0=VoZ`3K`Zh0glVc0=k5[P3Rb[<0i<^i0>?9]03UbkT0i/nk0>K?^P3Vc[/0hL^m0=k:^03Ja[80hLJh
0=o0]03Va/00i/C20>o7bP3IYZX0i:jf0:edSP2^<Th0a0PA0<862`30:Rd0UT==08iCI@3<WjX0fkNm
0=O1b03Fb<l0dL[@0<k;dP3;c=40bL[60=39Z@35/EP0c;ej0<_<`P36blh0XjF`069XMP22SIL0WZ>]
0:BV/02ZZ[80@kXk4@00o`08ooooo`@00?l000<0^3Rd0:0Pl02P8?00202P8?020;Ph]1L0X23`00<0
d51h0>QX?03XJ3`00P3@D7P20:0Pl080oh0000@0d51h0:0Pl02P8?00^3Rd0P3@D7P20>QX?080oh00
00L0j6Pl0=1@N03XJ3`0d51h0>QX?03oP000d51h00D0X23`00<0D91h003o0000o`003`00o`0;oooo
o`002_ooool0D`2kXXH0VIRI09J;R`144Q<0ZYNI0;Vk_`33b<X0Rhf?01d;400Z1@`0?`D:04L11P1U
3`D0cYDB0=JE402X8000_PX60<P9203:2@T0c`X:0<`82@3A2``0dP/<0=P=3P3K3`h0fa4<0=hC3`3S
5A40jATB0>4L5`2S9B<0Yhf:0>SSh@3[jNT0jnWX0>gTh03a_[@0YBhW06`l>@3[h]l0jn_[0>c[j`3a
j^P0lNWX0>gZjP3/j^/0k>_[0?;If@2_=C<0ZQLA09d`:@2ONG80hMOB0>[ViP3Wi^L0jnGV0>S5``2Q
9R<0Z@D90:T42@2V0PT0W`<:09h42P2F0@H0UP8809@21`270@@0O`4207P10@1e0@40M`8207<10@1e
0@80M@8406/2101N0@@0E`4305D10`1K0PH0H04606@4201U3``0c:RL00D00?l02Oooool01@3@D7P0
X23`0:0Pl03oP000d51h0080oh0000<0d51h0?n0003oP0000`3oP0020:0Pl100oh0000<0d51h0?n0
003oP0000P3oP0000`2h>;@0j6Pl0=1@N0090?n000040=1@N03oP000j6Pl0=1@N0@0oh000P3XJ3`H
0?n000030:0Pl000o`000?l000<00?l02?ooool3003o001506RgA@2SU8@0O7Mo018UFP0266H03AiJ
09b=R`2]TH00/i=l0;REN`2kVX00^h5X0<AjG03>Vh40b:F<0<JYT@36ZI00bJbC0=_=_P3WgMX0dkf]
0=[1[`3Ja:l0g<B`0=o7/@3Pb;<0hL^g0>7:]@3Sc;T0hlbk0>C>_P3Tc[X0hlbi0;^c[`2PR9@0ceUK
0==1@`3A=C/0cRT`0</P9P3961`0baTL0<HE60343a@0a0T>0<86302m10`0]0L?0:d94P2V2QP0X`dN
0:4E9P2S8S<0YCE40:Y8F02ZIG40ckb^0;n/H@2mXaH0_JDA0<2^BP32_8P0`;b/05]KHP1SJgH0UIfV
0:6SZ`2WYjd0IJYK01400?l02?ooool3003o00030:R8?02P8?00X23`0100X23`00<0oh000:0Pl02P
8?00302P8?020;Ph]0@0d51h00<0j6Pl0?n0003XJ3`01@3oP0000`3XJ3`0d51h0=1@N0030=1@N080
X23`00@0d51h0>QX?02P8?00X23`0`3@D7P40:0Pl0030;Ph]02P8?000?l001000?l02oooool000[o
oooo05<0_ZB609bJUP2FSXd0DQlN09YmP033`lP0cM7E0:R[[`0K4180:PT<03/42P1A1@/0GP`30=6H
5@3FTPl0[1l20<4920392@`0b@T90<l<303A2``0d@X<0=@<3P3F30`0f@h?0=L@4@3B3`l0ea0;0=`J
5@2k9Qh0eHb10>[Ie03[i^@0jnWY0>cXiP3`hMl0m/2n0<Pf<P1[3Pd0ak:^0>cZj03/jNP0kM?C0:aX
K@2ELg<0knWV0>cZjP3]i>40[6IS04/;1`3K`kX0jn?P0>WVi@3UiND0hn7R0>COh03UdM40XTA009L3
1`2K0@H0WP4809`11`2J0@L0U04609411@2D0@H0T04608P20`1l0@<0N@4307P10P1d0@80M@4407@1
1@1]0@<0H`4305T1101D0@D0D@4505L11@1O0`H0H0T509UE>P05003o00Wooooo00D0d51h0:0Pl02P
8?00j6Pl0=1@N0020?n000030=1@N03oP000oh0000<0oh000P2P8?0?0?n000030=1@N03XJ3`0oh00
00<0oh000P3XJ3`00`3oP000d51h0?n000020?n000030:0Pl03@D7P0oh000080oh0000<0j6Pl0?n0
003@D7P01P3oP0000`3@D7P0oh000?n0000F0?n000030:0Pl000o`000?l000<00?l02?ooool2003o
001605jm>`2YWI<0YYbG09RBV00>7Dh011MP00LFCP2?PH80ZXam0;2@O02fUG`0^YN00<2MP`31WX@0
]Yb909J5M`28O740T8Ih0;fXTP3B^ZP0eKj_0=JlY`3J`J/0fL2[0=[3/03Oak00glJb0>3:]P3Pbk<0
h<Vc0>;:]P3RbkD0hlbf0>C>^03A`Kd0KUim0;he>03?:A/0dCHT0=E3=@3FDD@0eUa@0=9OE@3>HED0
ZTQ=09lO=@301a40`08;0;hR7P2eBd<0XdM30:91?P2W>CL0XbPZ0:4L7@2L51T0TA8I0<>GV@3AcL40
_ZY;0;nU1P2kX0H0/Yd=0;>N7`1ZGRP0Hfih08fIX02`/kT0XZ2V06^OHA400?l02?ooool2003o0004
091`N02P8?00^3Rd0;Ph]1h0X23`00@0^3Rd0:0Pl03@D7P0oh001`3@D7P0102h>;@0oh000?n0003X
J3`50=1@N0<0oh000`3@D7P40:0Pl0040>QX?02P8?00X23`0=1@N080X23`4@00o`0;ooooo`002_oo
ool0D`2nXH<0WY^H09VCU01J:R/0TW9f0<W:d03@e]/0^K_001hD5@0/2Ph0>P@;05P:4P1L3@@0dY/E
0=:;3@2^7000`PT60<P82`391PX0cPX;0=0:2`3@2@X0d`/<0=H<3@3H3@h0f@l@0=TA3P3J5A40/a@C
09iNFP3bi>00jnWY0>[Xj03Wi^D0j=3?0?:][@3IEEL0gRDR09dI5`2QP7`0k^_Y0?7]k03mh=l0]Da=
07`d<`3^hMh0j^KV0>kYj037Ti<0B`l<0<Rl]`3XinL0inKX0>CRh`3NeM<0c[J`0<>>Q`2B7AX0U@84
09<00P2E0@D0U04609<01`2C0@L0T04409@21@2@0@@0R04507d10`1h0@80MP4207@00@1f0@<0MP85
06l10P1Q0@80FP4305D1101=0@@0D04605H1101N1`80QS4A00D00?l02Oooool0103@D7P0X23`0:0P
l03@D7P30?n000030=1@N03oP000oh0000<0oh000P2P8?0>0?n000030=1@N03oP000oh0000<0oh00
0P2P8?060?n000030:0Pl03@D7P0oh000080oh0000<0d51h0?n0003@D7P0103oP0020:0Pl1X0oh00
1@00o`08ooooo`18003o000XgaH0]JFH0;2][@2/Z:T0WiRN02hfFP0355H011AA08=fO02XRgP0[Xmj
0;:DN`2fUgl0^Yb10;ROQ`2<OW00Z9J50:BCQ@1bK6H0V8f10=:hX`3D^j@0ekjW0=RmY`3H_ZL0fKnZ
0=k6/03K`k00hLZh0>;:]P3Sb[H0hLZe0>7;]P3RbkP0iM2k0>3<^`3?^:h0fk:T0=FYW`3M[9l0k;BX
0?Bm^03QYZ<0f:NR0;>NXP2ZT:D0XCMB0;h94`311@/0]ATN09Y?H01gJXD0SIV[09^EYP37YJh0e[6b
0=6[[038X:00`:j`0<_?d035^H<0_JD<0:>>401iL0`0[Yh>0:NF8`24PVP0UYbL09nTY`2MWZ<0SGn1
4@00o`08ooooo`03003o001XZ3`0^3Rd0080^3Rd8P2P8?00102h>;@0X23`0:0Pl02h>;@20:0Pl080
^3Rd00@0X23`0>QX?03oP000j6Pl0P2P8?000`2h>;@0d51h0=1@N0030=1@N0030>QX?03oP000d51h
0080X23`00H0d51h0:0Pl02h>;@0^3Rd0:0Pl03@D7P20:0Pl1400?l02oooool000[ooooo0400_j>3
09jNW02FTID0Hcdm089MHP3;b]40cmOL0<S;d00P6ad0:@T=03@32P130@P0G@h50=FN5@3AQa00[AP1
0<<:1`371PT0bPH90<h:2P3?20/0dP/<0=4:2@3E2``0f@h?0=X>3P3N40l0gaDB0:`C4@27G5X0k>OW
0>_Xj@3Zj>L0jNOT0>K7aP3>KFX0f3@/0>PS6`3:9R@0ReEA0>cXi@3^jnT0n>KT0<1VI022:B@0dKbg
0>cYi`3[jNX0iKZj08d/:P27D540hM[J0>GQh`3Pfmh0g<k;0;fAQ@2C;b@0U0D409T20`2F0P<0T`44
09811`2B0@T0T0490P2@0@D04@2;0@@0QP0309H;3P2[;2h0R1DE07<10`1b0@40O@D80741101S0@80
G00305L1101<0@<0C@0405P21`1L1@80SCLK00D00?l02Oooool00`3@D7P0X23`0:0Pl0020=1@N080
oh0000<0j6Pl0?n0003oP0000`3oP0020:0Pl0h0oh0000<0j6Pl0?n0003oP0000P3oP0000`3XJ3`0
X23`0?n000020?n000070>QX?03oP000oh000?n0003XJ3`0oh000=1@N0020?n000030=1@N03oP000
j6Pl00@0oh0000<0X23`0?n0003oP0002`3oP0000`3@D7P0j6Pl0?n0000:0?n000030:0Pl000o`00
0?l000<00?l02?ooool0B@00o`00S:]W0:bZZ`2c]KT0Z:J[09R?U`1OH7X01A=<00@BC`1iKWH0XXId
0:V<M`2_T7L0]IIm0;bKP02WTWl0Q7]b0:>DQ`2DRX80L6e/0967O@3@]Z00eK^U0=BkY03F^Z@0f;bV
0=VoZ@3Ma:l0flB^0>?:]`3ObKP0h<^h0>;:]P3Sb[H0hLZe0>C?^P3Qb[T0f/Jj08R9VP2YIGX0bcU2
0=0V:`3>7B@0bQTL0;LM7P30MX<0Hcm/0;<B8`361Pd0_PT;0:h94P2Z1aH0YCM605a?KP1k=E@0V@lN
09XG902K8S00W3I40<2LXP3:c]00`kMl0;fU2P2NRAL06QT505iM4P2<PQ<0Wi8M09R>>P2YXg@0YZFG
09^DU00Cg@`04000o`08ooooo`04003o002P8?00^3Rd0=1@N080^3Rd7`2P8?020;Ph]0040:0Pl02h
>;@0d51h0=1@N080oh000P2P8?001P3@D7P0oh000?n0003oP000j6Pl0;Ph]080X23`0`3@D7P03`2h
>;@0d51h0?n0002h>;@0X23`0=1@N03oP000j6Pl0;Ph]02P8?00^3Rd0=1@N03XJ3`0X23`052@N00@
003o00_ooooo000:ooooo`1C0;fSPP2RYZD0TYBF06Y?C`1R>ch0dloE0<oEf`3?e]T0:BP[02D83`0f
10d0>`4805`A1@3FXAL0cX4A0:lE0@322@T0aPH90<P61`3;20X0c`T;0=8<2`3A30P0e`h;0=X?3@3M
40`0gQ0<0>4C403H5A@0VQHI0;6:T@3WhN@0jNOX0>WWi`3/j>H0m^CO0>n_Y@3J?cD0dB4N07/U903X
g]/0kN_Y0?3Yi`3VaKh0ejVP0=K4^`3/inD0jn[[0??Lg02bDDd0YAXK08a5B`36/kD0g=GE0=cGe`3R
dll0d9fB09HN5`2D0P<0T@4308l10`2@0@D0T@4809822@2B0PH0S08508@21P2?0PH0/@D:0:X51`2X
4aL0M`4207@210263@l0LP4406X2101S0P<0FP8504d10`1:00<0D`4605l50P2=<QT01@00o`09oooo
o`030=1@N02P8?00X23`0080d51h203oP0000`2P8?00d51h0?n0000>0?n000030=1@N03oP000oh00
00<0oh0000@0^3Rd0>QX?03oP000j6Pl0`3oP0000`3XJ3`0d51h0=1@N0030?n000040=1@N03oP000
d51h0=1@N0<0oh0000<0^3Rd0>QX?03oP0002`3oP0000`3XJ3`0oh000?n000090?n000030=1@N000
o`000?l000<00?l02?ooool0B@0`eA/0Z:BP0:nf^@2b];P0ZJJY09R>TP1`KhH02QM@00<CC`1bJ780
XhI[0:^<J02aSf`0]IAh0;^IP02VRgd0Kf]Y07YgMP1^KV`0IfIR0;2PS`3?]9h0d[RR0=BkX`3D^:80
e[^V0=RnZ@3Ja:l0f/F/0>79]03Pak<0h/Vg0>?9]`3SbKH0h/Zh0>;>^03PcKT0fLS205AMQ02eC5h0
eaLG0=`C4P3H5a<0fTPh0<mD@@3;MVX0JU]m0:0[A`342@l0ac@b08i7FP2?2bL0[@PB08]0E@1[=4`0
WPXD0:T22`2W0P/0X0P<09a4B@3Cc/h0`[N60;bU6@2_Ua80@34:05A>7P0X9@80JVLF09f>4P2/Va40
/jE20:2CKP0LeQ804000o`08ooooo`0506RX?02P8?00^3Rd0=1@N02h>;@01@2P8?000`2h>;@0d51h
0=1@N00H0:0Pl0030=1@N02P8?00X23`00<0oh000P3@D7P01@2h>;@0X23`0:0Pl03oP000d51h0080
X23`00@0oh000:0Pl02P8?00j6Pl0`3oP0000`3@D7P0oh000=1@N0020:0Pl0040>QX?03oP000oh00
0>QX?080X23`0P2h>;@00`1@T7P00?l0003o000>003o00_ooooo000:ooooo`1C0<2TP`2f^[X0TYNH
06eIF@1C:b/0f=7E0<oDf@3Efml0>C/o02<73`0e0P/0?@4505/A0`3@WQP0bGT?0;0C00301`P0a0D9
0<D72P3;20X0d0/;0=0<2`3?2PP0d`/<0=T>3@3M40/0g14;0=h@3P3Q4A40g1HG09/G7@2[PH`0hM_M
0>WWj03ZjNT0k>c[0?7Yi`3UU8h0_b4N08LF5@3C`kl0k>_X0>k/jP3Yi^@0jnKU0>gXiP3^k>/0j>KX
0>oRh@3LTi00]ATI0:8@5`1M4QL0]:6N0=[Ge03Je]H0hM??0;ilLP2?20P0TP850901102=0@@0S`46
09411`2A0PL0Q`8407D10P270PD0/0870:h00P2Z0P@0R08307H1102=6A/0L04406X10`1O0@40F042
04l21@170@80C@4405d40P26;1401@00o`09ooooo`030=1@N03oP000X23`0080d51h0`3oP0000`2P
8?00oh000?n000020?n000030:0Pl03@D7P0oh0000l0oh0000<0X23`0?n0003oP0000`3oP000103@
D7P0oh000?n0003@D7P80?n000050:0Pl03oP000oh000?n0003@D7P00`3oP0000`2P8?00oh000?n0
000G0?n000D00?l02?ooool0B@1@/cP0UifS0:nd_02YZ:d0[JZ[09R@T@1oNhX02aI800<@B@1]Hf@0
]YHl0<BM8P2oVD40]Y=X0;ZGP@2gV8@0O6eW07I]JP2APgH0]9j;0<V^V03?/id0ckBN0=2eW@3A]Z40
b[JT0;fZVP36]Z@0g<Fb0>78]P3OakD0hl^h0>;;^P3Sb[X0hlbi0>G@^P3Rc[X0glVi0:RS/P1lJ8T0
^T9=0=<I6@3B5aD0iWI]0>NWU`3I/j40ZZ>^06lkIP2k3AT0]a0D0;aoR01P53d0/0HF0:HZ<`1lI7@0
MS1209`84@2S10T0/DQ20;6;QP37a/P0c<k>0<JnQ`2lYR00]9X@09An6012=PT0De<O05iF2P2CSA`0
WI4B0:VE8@0Tg@d04000o`08ooooo`0507QH]02P8?00^3Rd0:0Pl02h>;@01@2P8?00103XJ3`0X23`
0>QX?03@D7PH0:0Pl0030;Ph]02P8?00^3Rd0080oh0000L0^3Rd0:0Pl02P8?00d51h0:0Pl03@D7P0
oh000080X23`0P3@D7P0102P8?00^3Rd0?n0003oP0020=1@N0030?n0003XJ3`0d51h0080X23`00@0
^3Rd0?n0003oP000j6Pl0P2P8?000`2h>;@0D91h003o000?003o00_ooooo000:ooooo`1C0;^_P`2[
[Zh0VIfP07ASH`1=7b80g=3E0=KLi03Cf>00AdU>02H84@0m1@h0C`L=064C103CX1L0aW8?0;8B0`2o
1`P0a0L90<@52P3920X0c@X;0<h;2`3@2``0e0`=0=L=3@3I3@`0gA0>0>4B403R4Pl0iA@B0=dJ6@2X
7280Sd]=0<Zg]@3/j^D0jncW0>g[jP3ecL/0]C0]0;DO703;SX/0mN3O0?;Ph@3dh>00mMoO0?KPhP3e
g^40l]kP0??MgP3ka/H0]RLX0;h>4P2P3A80L24R0;^]Z`3KeM@0gMKG0=g3`@2C:RL0T@8508l2102<
0@<0R`4208h2102<0@L0Q@850742101b0@@0Y@D90:T10P2Y0P<0SP8407H11@1i0PH0LP4406X10`1Q
0@80F04304h11@170@80B00206840`239@`01@00o`09ooooo`80d51h00<0X23`0;Ph]03XJ3`00`3o
P0000`2P8?00oh000?n000020?n000030:0Pl03@D7P0oh0000l0oh0000<0j6Pl0=1@N03XJ3`00`3o
P000103XJ3`0oh000?n0003XJ3`90?n000030>QX?03oP000oh000080j6Pl0P3oP0020>QX?1P0oh00
1@00o`08ooooo`1907JJH02?VJD0XZF]0:VW[02[Yj`0X9JK09B=VP0E7TX00Q19071UC@35XaH0b:L:
0;VC>`2`Sfl0/Y=l0;RGP@2lW8L0^Ib80<>US`3<[YP0cJnJ0<^`VP3?/ih0d;FO0<jfX@2mZIH0e;^Y
0;^XV@3IaKD0g/Ne0=g9]`3NbkT0hLbi0>;<^03RbkH0hlnj0>?A_@3Tc[d0g/Vj0<Bh^027NY80XE]`
0<DX;`3=5AT0ab0Q0=1GD`3G/:d0G55e0:HR>02o2100^Sa808h`D02/1aP0Y`PA0;64S02BS9d0LC56
090?7@2G3aP0_H2:0<k;c`37c]@0blk>0;ndM02lY140^:4409b73`1fIQH0KV<?071Y7`1XH@`0YIPH
05^m3`0@003o00Sooooo00<0^3Rd0:0Pl02P8?001P2P8?001@3@D7P0X23`0:0Pl03@D7P0^3Rd01T0
X23`00@0d51h0:0Pl02P8?00d51h0P3oP0020;Ph]0070:0Pl02h>;@0oh000;Ph]02P8?00d51h0?n0
00020;Ph]0040:0Pl03@D7P0j6Pl0;Ph]080oh0000D0j6Pl0=1@N02P8?00X23`0;Ph]0030=1@N080
X23`00<0N5Rd003o0000o`003P00o`0;ooooo`002_ooool0E02Ib7L0`<?609jUZ01kL700@Q8F0=C2
a`3CfMl0d]_Q05]OIP0R2Q80=P<;04@2301O5`D0ej8F0<=Z302b3P80_PL70<462@2n10T0a0D90</8
2P3;1`X0cPT;0=4:2P3F3@d0fPh<0=/>3@3R4100iQ@@0>LF3`3Y6180iQTD0=LQ7P208B80el_70>[Y
i`3^jNX0kko20;P^<02`7AX0f8=m0<MXJ@36DUD0`dY<0;Y1@`2oB4P0_4Q;0;19C02bDU@0a5=@0;`U
802h30`0[`D809P:3P1H9R@0b;Zf0=kFf03Oe=80We9<08h31P2@0P@0S@8208/10P2:0@40Q`4208@1
0P1j0P@0G@4107410P250P@0S@<50781101X0@<0N`8707X11P1]0@80I@4305X10P1?0@@0B@4304X1
0@1]0`@0Pah802?<0P@00?l02Oooool0102P8?00oh000:0Pl02P8?040?n000030:0Pl03oP000oh00
0080oh0000<0X23`0=1@N03oP0004@3oP0020>QX?080oh0000<0j6Pl0=1@N03oP0000`2P8?001`2h
>;@0d51h0=1@N03@D7P0^3Rd0:0Pl03@D7P0103oP0001@3XJ3`0d51h0?n0003oP000d51h01P0oh00
00<0D91h003o0000o`000P00o`08ooooo`190:2GT@25U:D0Vj>Z0:FV[02SXjP0Yj6V08b4S`0V;EL0
31Hi08ij:P34YPL0ajP30<6J:`2/S6l0Zi1k0;FFO`2lVh@0`9n90<:UTP3=]jL0c[NV0<R/V@3?/Y`0
dKBO0=2fY02kYiT0ck^[0;fZW03Ia;<0gLRg0=k5/`3NbKL0gl^j0>7<^P3Rc;H0hlni0>CA`@3Sc[`0
h<^g0=g8]P3CaL<0PH2O0;=`R`3:71d0dQ0=0</?3`32Bd@0VhNI07deFP2l2Q@0_0L=0:h:502]1A80
/0<=09Le?P31aM00IFB007LnD`2K5b<0U`/H0;f:T`3:c=80a/cE0<C5]`37^g00^jDH0;NP102aV@L0
V84:08Qf6`1PE@l0THLM03CM2`0@003o00Sooooo0P2P8?000`2h>;@0X23`0;Ph]0030:0Pl0050;Ph
]03@D7P0X23`0:0Pl03@D7P06`2P8?00103@D7P0X23`0:0Pl03XJ3`20?n000040=1@N02h>;@0X23`
0>QX?0@0oh0000/0^3Rd0=1@N02P8?00X23`0=1@N03XJ3`0^3Rd0?n0003@D7P0j6Pl0=1@N0030:0P
l0050;Ph]03@D7P0j6Pl0:0Pl01hF;@04000o`0;ooooo`002_ooool0E02Lbg/0]KVk09^TY`2=QXH0
@Q0C0;bX[03@em/0d][P071dN@0P2Q40=@<;03l11`1S6`L0fj@F0<AR3@2e3@80_`L80<872P331@/0
a@D:0<X72`3;1`/0cPX<0=8;303G3@`0fa0<0=dA3@3S4@h0iQ@@0>HE3`3Y5a40iAH>0=PJ5P2@9R40
im?>0>kQhP3df=X0fWMl0<@L7`2]61T0`I:?0?kLe@3i_KH0hi^C0=26O03AS8<0hZ>K0>^g/03c`;T0
m[R/0=^5N02]<2L0YA8>08d51P1e>Rh0dKV]0>?EdP3Ob/H0USdg09820`2C0@<0S@4208h10@2;0@40
Q`4008H10@240P<0L@X806@F5@1N2`/0G@4405D00P1S0@<0O`8608821P1d0@80J`4306420`1A0P<0
A`4204T10@1_0`<0O1H202?;0P@00?l02Oooool01P2P8?00oh000=1@N02P8?00oh000:0Pl080oh00
00<0X23`0?n0003oP0000P3oP0000`2P8?00d51h0?n0000E0?n000040:0Pl03oP000oh000=1@N080
oh001@2P8?000`3@D7P0X23`0:0Pl0030?n000050=1@N02P8?00oh000?n0003@D7P0603oP0000`1@
T7P00?l0003o0002003o00Sooooo04T0ZjJT0761TP2NY:`0ZjZb0:>QZ02RWZD0RhB>02`cB`1fJ2H0
^i`B0:jC2@37Y`D0`9XU0:j;GP2[S7D0]IIo0;ZKQ@2nX8`0elRn0=G:aP3Gb/@0ck^^0<f_V@3A]J00
eKbX0<ZcXP34[Ih0e/2]0=W4/@3Ka[<0gLNf0>39^P3ScKd0h<jk0>;>_@3TdKd0i=?10>C?_@3Rc;T0
f<No07QlV02aH7P0bbPc0=4B4P3;3PP0bBPH0<ibG03;/Zl0GDM^0:/G;02h2@l0e7Um06HG?P2W1AP0
X10M04H[D`1^>EL0UaLU0:863P2V10X0T2PZ0=38c035cML0`lcC0<G8]`2n/V<0_JTa0;BN2P2cWP@0
]9d60:N@3@2GQQD0Am0@01000?l02?ooool40:0Pl080^3Rd00<0X23`0;Ph]03XJ3`0102P8?000`3@
D7P0X23`0:0Pl0020:0Pl0040;Ph]03oP000j6Pl0;Ph]140X23`00@0d51h0:0Pl02P8?00d51h0P3o
P0001P3XJ3`0^3Rd0;Ph]02P8?00^3Rd0?n00080X23`0P3@D7P20:0Pl00:0=1@N03oP000oh000>QX
?03oP000^3Rd0>QX?03@D7P0j6Pl0;Ph]0D0X23`00<0D91h003o0000o`003P00o`0;ooooo`002_oo
ool0?@2McWh0`lS90:2ZZ`23Ogh0BQXM0:R;TP3Een00dmWR08:5R`0P2A00<P<803l31`1[8`X0fZ<D
0<1F302j3PD0`PP:0<H730381P/0b0H80<T72P391`/0c@T;0=8:2`3G3@`0f@h:0=`@2P3P4P`0i1D?
0>LF403Y5Q00jQTD0=<G503FGel0kIJH0=n0R03AEE`0c2<T0=@F5P3>61L0Xc<i0>70`P3ej>L0l^SU
0?7Xh`3bjNH0lNWW0>kXi`3^jNL0kNSS0?3Qg03V_KL0bGae09T/9`2]CD@0^FaV0;UbL@2/EeD0TA4?
09D10P2C0@800P2@0P405@2=0@80R04008L10@260@40RAHC09eDD02cMgH0GQ4B06<1101g0PD0Q0<7
08X32@1l0P@0KP4206@10P1D0P<0A`4204X10P1b0`@0OQD402?:0P04003o00Wooooo00T0X23`0?n0
002h>;@0X23`0?n0002P8?00j6Pl0?n0002P8?00103oP0000`2P8?00d51h0?n0000A0?n000050;Ph
]03@D7P0d51h0;Ph]03XJ3`00P3oP0000`3@D7P0j6Pl0?n000080?n00080d51h00D0j6Pl0=1@N02P
8?00X23`0=1@N00:0?n000030;Ph]02P8?00oh0000`0oh0000<0D91h003o0000o`000P00o`08oooo
o`1:0:^RVP1WN8L0U9fW09jQYP2PWZ<0WIRL0:fWZ`16@b/0^9dG099h2`1mI@/0b:D=0;ZE7`30VcT0
[8aZ0;FDP@2lW8L0_jJE0=_?b@2lZ9h0aJnS0=>n/P3>/Yd0dkNS0=BkZ@3F_:d0fl2`0=S2[P3JaK<0
fLBa0=k;]`3NbkX0hLjm0>3?_`3Rd<00i]700>C@`@3QcK`0hLbk0=S9``1HHXT0/E5W0=4F6P3A3`h0
`Q4:0=aMCP3N[i`0a[2T07Y`QP28;Dl0^0TB0;mDG01UAVh0T0T[0:X4401d9D00FBm>08dA7`2S10`0
Wa4@0;R6O@39c<h0`l_D0<7:e037cmP0bM3=0<_;^`2aZfd0Y9lb0:nU902gYa80/YdE06:U4`0Dk`@?
003o00Sooooo102P8?020;Ph]0050:0Pl03XJ3`0X23`0;Ph]03@D7P00P2P8?020;Ph]0<0X23`00<0
oh000:0Pl02P8?004P2P8?000`3@D7P0X23`0:0Pl0030?n000030;Ph]02P8?00X23`0080X23`00D0
oh000;Ph]02P8?00X23`0?n000020:0Pl0050=1@N03oP000oh000=1@N03oP0000`3@D7P20>QX?003
0;Ph]03@D7P0X23`0080X23`00<0N5Rd02S8?000o`003P00o`0;ooooo`002_ooool0502k/HH0`LO:
09nZ[P2<Shh0CR@T08MQJ@3GeMl0dMWR092AVP0T2Q@0<`8:03d21P1^:``0fj@E0;]62`2j30P0`0H:
0<H630381@/0bPL90P3;2@X0?P3>2@X0d`/=0=L<3@3N3`h0h14=0>DD3`3U5A00i1<?0>LF403Z6180
j1PD0><L6P3N6ad0d10D0=DD5`3E4Q80eQ@D0=DC503F6Q`0_2P^0<5GG`3FRY<0iZje0?2na03Y]K`0
kKFo0>R]]@3QY:X0fj>Y0<ZUZ03H_;`0gjn[09XP7P2R1@/0X@@:09h31P2J0@<0U`4209H10P2D0@<0
T@4308`10P2:0P80Q`4308L110260PH0R1DG094W9`2B7Al0QP<808T21`2@10/0T@@:08D11P1g0@@0
JP4205P10P1<0@80E`4107T310204`H09ld61000o`09ooooo`090=1@N03oP000^3Rd0:0Pl03XJ3`0
X23`0>QX?03oP000X23`00@0oh0000<0X23`0=1@N03oP0006@3oP0000`3@D7P0X23`0;Ph]0090=1@
N080j6Pl3P3oP0000`3@D7P0j6Pl0?n0000;0?n00003052@N000o`000?l000800?l02?ooool0BP2f
YYL0EVEe09NS[@2OYJT0YZJ[0:NOXP26N780UX920;bO4P1cF@/0YHL@0<>P402iVAX0`9`^0:f<JP2a
Sgd0^Y^70;bST`3Odld0_ZjV0=C1]P3;/ZD0c[>N0=6eX@3C^:D0e;ZX0=JmZ@3G`:/0f/Fd0=S5]03K
bKD0f/Rd0>3<^P3Oc;/0i=710>GB`@3Ud/00hLjm0=k;_03KbK/0ZJFd07YYR@2f>dH0ba8F0=0?4P36
4a@0bUI>0>>m/@2UUi/0H31G0;<=6@2g9bd0ahjV08P;;02_10h0U2Df05eAL01e@U/0SQ@P09H93`31
SY00bL_A0<;:d`31b]D0`<WD0<;<e@33c=H0^<340:VdY02e^i80^;9J0;bX7P2cWQL0@]H;3`00o`08
ooooo`<0X23`0`3@D7P30:0Pl0040=1@N02P8?00X23`0:0Pl080d51h0`2P8?000`3oP000X23`0:0P
l00C0:0Pl0030=1@N02P8?00X23`00<0oh0000@0d51h0:0Pl02P8?00X23`0P3@D7P20:0Pl0060?n0
003@D7P0X23`0:0Pl03@D7P0oh00103@D7P01`2P8?00oh000=1@N03oP000X23`0?n0003@D7P00P2P
8?000`1@T7P00?l0003o000=003o00_ooooo000:ooooo`1D09_8NP3:c=40Y[6d08F9R`1O=c/0Jci6
0=GAfP3<e=`0SiFK020:4`0f0`d0@0@907@h3`3KY1@0]CL90;/81`2o1PT0``H:0<D52P3920X0cPX:
0=0:2P3C30/0ePd<0=/>403O3a00h14>0>8B403P4Ph0iA<A0>LF4@3V5A00jQPB0>LH5@3E3`h0d0h=
0=DB4@3C4Q80eA<A0=TE4`3M5aD0gaXH0=`K6`3G7Ad0e1hQ0<lN90396B40cATS0</H7`3:5a/0`A@H
0:@>5P2?4Q/0U3m30;=<A`2Q10L0Y04409l1102N0@D0V`4709P11@2H0@L0U00309410`2>0@D0R042
08H10P270@D0QP4608P0102>0PP0T0<:08l22@2D0``0U@@<08L11`1k0@@0K@4205/20@1E0@40J@<3
07h20`1j30809/d51000o`09ooooo`060:0Pl03oP000d51h0:0Pl03@D7P0X23`0P3oP0000`2P8?00
oh000?n000020?n000030:0Pl03oP000oh0001`0oh001@3@D7P30?n000<0d51h703oP0000`1@T7P0
0?l0003o0002003o00Sooooo04X0XlF;06EdQ@2?W:L0XJBY0:VUYP2]WH00Y8Y20;VJ902ENP`0PF/C
0;ZJ3`2aSRD0ZH]90:f>F`2ZRWH0[i1n0;NIQ`2oWhl0bKBX0=;0]03<]jP0c;:M0<fbW03?]9l0d[NS
0=>lZ@36]J<0eL6`0=_3/P3I`k40g<Nc0=[9/`3PcK`0h<fm0>CB``3VdlD0i]C50>?B``3PcKh0g<Vj
0=K6^@2YWjT0RFf30:e6D02h7b40aa<E0<8C4`39FeD0bZRO0619J`2W7300]`T@0;8N;P2[21H0/0<;
0:8K9`2^V:`0R8>J0751E`2@5200TahZ0<BS[@33bM00`<[D0<OAfP36c]L0`lcF0:jha@1CH6H0Mgma
096FO`2dZDT0_J`M06S75`l00?l02?ooool00`3XJ3`0X23`0:0Pl0020:0Pl0090;Ph]02P8?00^3Rd
0;Ph]03@D7P0X23`0;Ph]03XJ3`0d51h00@0X23`00<0^3Rd0=1@N02P8?004`2P8?020;Ph]0030:0P
l02h>;@0oh000080oh0000T0^3Rd0:0Pl02P8?00^3Rd0?n0003@D7P0j6Pl0?n0003@D7P00`2P8?00
203XJ3`0d51h0;Ph]03oP000d51h0>QX?03oP000d51h0`2P8?00102h>;@0d51h0:0Pl01hF;@?003o
00_ooooo000:ooooo`1309[6M`37b/l0WjV]08^AU01P?D00F2P^0=3=dP36d]P0VZ6V024<4`0e0`/0
>@8507Hm3@3MXaD0/BT40;h:1`2m10P0a0H<0<D530361@X0c0P90=4:2`3C30X0e`l90=P>2@3J3@/0
gQ0>0=h?3`3T5180i1@@0>LF4P3W5a<0jAPC0>0C4@3C30h0e0l?0=<?3`3A3`l0eQ@D0=`H5@3M5aD0
gALG0=lK6P3O6QH0gQPF0=@B4@3E4a<0ea@D0=8@4@3A3Pl0bP`@0;@6302/0PP0W`H:09d=402S0PL0
X`4509l1102P0@L0W@4909/2202J0@H0UP040981102@0@D0R`4308P10P0208H10P0?08L10`2>0@L0
T08:08/1202B10`0U@@<08P11`1n0@<0L`8305h10@1M0040L`4207l21@1j2@00=[0500@00?l02Ooo
ool01P2P8?00oh000=1@N02P8?00d51h0:0Pl080oh0000H0X23`0?n0003oP000oh000=1@N02P8?15
0?n00003052@N000o`000?l000800?l02?ooool08`2@d7<0Mh>D086@W02OXjP0[jN?0;NN;@2kW@T0
[I0>071I2@2]SPh0`9`?0;6;>@2TQ6@0XX=g0:R:O02]SX40]IN50;jNR`34YY80b:^G0<Z^V@39[YP0
ajjD0<bbV`3A]J40_j^K0;NZW036/j40fL:_0=[6/`3JbK@0g<^h0=k<_03OcKd0hlo00080iM7302D0
im;50>?>`@3MbKX0f<Je0=G4]P3=_KT0UHFC07aSN02KDV40`1LK0;lC403@RWh0VXfJ0:IRKP2h>SD0
/3H^0:/_:`2W:2X0Vb4Y09mkQ`3:dMX0[k2o06m:H02:52D0SR0_0<Jg_P33c=@0b=3J0<G=f@2obmH0
]/CB0725W01mT9h0TIjT0:2SR`2c/Wd0NWa:00l00?l02?ooool0102h>;@0X23`0:0Pl02P8?020;Ph
]080X23`00D0d51h0:0Pl02P8?00j6Pl0;Ph]00M0:0Pl080^3Rd00@0X23`0;Ph]03XJ3`0oh000`2P
8?050=1@N0040:0Pl03oP000^3Rd0:0Pl080^3Rd00D0d51h0>QX?03@D7P0X23`0=1@N0030:0Pl080
^3Rd00<0d51h0;Ph]000o`003P00o`0;ooooo`002_ooool0702IaW<0a/S=0:^c^@24RH/0I4Q:04LH
7031_L00`Lc?09jTZ00Q3Q<0=0@:03d52@23BQ00gJ0G0:lP0`2n20T0`PL;0<D72@381PT0c0T;0=0;
303D2`h0ePd=0=L=2`3I3@d0e`/=0=X=3`3O3a420>@B4P0f0>DD4@3X5A80iA@D0=T?3P3F3Q00f14B
0=HA4P3?4100dQ4B0=HD503J5AD0g1PF0=dG5P3L5aD0gAPF0=LC4P3H5AD0eQ8C0=4>403A3A40aPT@
0;422@2/0@L0ZP880:H22P2U0@T0X`480:82202N0PH0V`4509/21`2I0@H0U`4509811@2A0PH0T084
08T10@250@80Q04208H00`2>0@P0TP8;09<43P2E1@`0U0@;08T2201o0@H0MP4506P10`1_0P<0M`42
07d20`1f1`00B9P91000o`09ooooo`090:0Pl03oP000^3Rd0:0Pl03@D7P0oh000>QX?03oP000X23`
00<0oh0000<0d51h0:0Pl03oP000A03oP0000`1XZ3`00?l0003o0002003o00Sooooo04/0JmeC0869
V01mRIP0XZ>Q0;2NC`2gVPX0[8h=06YE2@2AN0l0`j090:b9:P2HNF@0Vg]e0:B1O02XQgd0[8f00;>E
QP2nWX`0aJNB0<RYU034Yi40aJVC0<V`V03=/Y/0d[RQ0<ffXP2o[9T0dl2[0=O3[`3JaK<0f/Ve0=[9
^03LbkT0glfl0>;?_`3SdL<0i=;30>?@`P3Rd<40g<Zi0=W7]`3FaKH0e/Fe0=71^@2f//00FeUh0;=3
AP30>b/0e:6C08n@VP2KUJ@0`I:>0<ZXY`32[[@0[YNU075MLP1eM8H0^LG>0<[BeP2TZ[`0GC1;08P:
5P2XNh00a<gD0<G?f`36cmT0`LgF0;c7e@1RMHh0MHVK092NY`2QZJT0Y:ZZ06UVL00<j0L03P00o`08
ooooo`05052@N02P8?00X23`0;Ph]03@D7P00P2P8?00103XJ3`0^3Rd0:0Pl02h>;@P0:0Pl0030=1@
N02P8?00X23`0080d51h00L0X23`0;Ph]02h>;@0X23`0;Ph]03@D7P0^3Rd0080X23`00L0d51h0?n0
002h>;@0X23`0?n0003XJ3`0oh000080X23`00<0j6Pl0:0Pl02P8?000P2P8?020=1@N0030:0Pl00X
b3`00?l000d00?l02oooool000[ooooo03L0Ul9a0<S;dP2R[;00O8:406UBE00l3Q80[jJZ0<;;cP2Q
ZJd08@`F03@32`0h0PD0S5PC0=JE4`2`5`L0_`L;0<<730341PH0bPP:0</82P3@30`0d`X=0=@;3P3D
2`d0f0`?0=/>3`3J3Ph0gA0@0>8A3`3S4Q00j1HB0>TI4`3L40l0ePl?0=LB4P3C3Q00c`hA0<lA4@3B
51D0cQ8A0=0E5P3<71P0aB@N0<4d;@3DCdP0fU9<0=Q7@`3>9280eQDE0=DA4`3;3140]0<:0:`2202Y
0PP0Y`880080X`4601/0X0860:021@2M0@@0W04509P1102E0PD0T@8609011P2@0@@0R`4108L10P27
0@<0R04508`1202B0P/0T`8;09@4302B10/0R0480841201k0@L0O04508`21`210@<0N08206l60019
V`d01000o`09ooooo`090:0Pl03oP000X23`0:0Pl03@D7P0oh000;Ph]03oP000X23`00<0oh0000<0
d51h0:0Pl03oP000703oP0001@3XJ3`0d51h0=1@N03@D7P0j6Pl02<0oh0000<0D91h003o0000o`00
0P00o`08ooooo`1;04cO=P2OY:h0NhNB0:FLJP2_UQ00Yh`907=M201eGP`0/Y<;0;:A6`2CMUP0U7Md
09]jN@2OOGX0Z8An0:^;P@2`THD0^i^:0<:QSP33Xi40aZ^E0<V`VP3;]Z@0c[JT0=:iX`3B_:P0dkj]
0=Jo[@3I`k<0f/Fd0=[5/`3Jb;P0glZi0=o=_@3Oc[l0h=2o0>?B`@3Tcl40hLjo0=c<^P3IakP0elJg
0=K4]P3=_K@0WiNG0;6VY`3@[Yd0dK2K0<N_XP37]k80QGR908eCH`2P=D<0Y2Xj0:DS<`2Q7B`0VbHf
0:54EP2hPI40ZZ:b07UXM`27BDP0[i^I0<C=e036cmT0aloK0<C=f033c=T0C5il05adR`1cPHl0TIVQ
09BLY01VJWX09khL00h00?l02?ooool0101@T7P0d51h0:0Pl02h>;@30:0Pl0040=1@N02P8?00^3Rd
0;Ph]200X23`00<0^3Rd0:0Pl02h>;@00`2P8?00102h>;@0X23`0:0Pl02P8?030=1@N0030;Ph]02P
8?00X23`0080X23`0P3@D7P01@3XJ3`0^3Rd0;Ph]02P8?00^3Rd00H0X23`00<0D91h003o0000o`00
3000o`0;ooooo`002_ooool0E02B_fd0a<O>0:Ze^024S8`0GDY<03462`2/Y:P0bM;D0:2Z[00J3140
;@<903L71P2@HAD0ch/G0:d@1@3020T0``L90<P92P371PT0c@X<0=0;303A2P`0d@X;0=H=303H3@l0
f0/;0=/?3@3L3``0gQ8<0>@E403Z6180gA8=0=8<2P3A3P`0dQ0@0<`<3`3:3Q40b@h@0<hD50335A@0
]28N0:I8@03JWYD0n=;=0?[Qg@3lhMd0o]cI0?:YY033<2/0d1DD0<h?4P2k1`d0[0<:0:P22@2V0@D0
XP440:41102O0@@0WP4409`11@2K0@@0U`4308L0101m0@<0S@<608h10`2;0@40Q`4208P10`2:0@D0
S@8809<32`2B0`/0U0H=09443@250@H0OP0607X10`2>0PL0W04808h10P1i0@80K`@004RI30@00?l0
2Oooool02@2P8?00oh000=1@N02P8?00d51h0?n0003@D7P0oh000:0Pl0030?n000030=1@N02P8?00
oh0001X0oh0000<0d51h0:0Pl03oP0000`3oP0000`3@D7P0oh000?n0000Q0?n00003052@N000o`00
0?l000800?l02?ooool0B`0^i1d0[:R^07j5N`2WU2@0/IT509Mn2P2ANQD0/Y@;0;>G4@2DNDD0Sg=]
09=dM@2HN7H0WGig0:F3O02ZQgh0/9240;NLR`31Y980ajZH0<Z_W02jZY`0blO70=cDd@3>]jL0d[ZX
0=:jZ@3H`K80fL6c0=S3/P3GaK@0f/Ri0=[9^@3OcKd0g/fn0=o?_P3RdL80hm720>;A_`3Oc[d0elNf
0=K6]`3Ca;D0dL6c0=2o/@3@_[40cKb]0<NfYP37/jH0a;>W0;j`Y`2dZk00X86709QGF02_EDl0[UE@
0:iLG02KBe<0S3m<09IVM03;bLd0aLS<0<K>dP34c]H0aM3J0<?@fP34c=L0`L_G08NK/01jTJ@0SYfY
09FOZ02NZ;<0KGR:03Na<P0>003o00Sooooo00@0D91h0=1@N02P8?00^3Rd1@2P8?000`2h>;@0X23`
0:0Pl00:0:0Pl0030?n0003XJ3`0X23`01X0X23`00<0d51h0:0Pl02h>;@00`3@D7P30:0Pl0@0oh00
0P3@D7P00`2h>;@0X23`0:0Pl0050:0Pl003052@N000o`000?l000`00?l02oooool000[ooooo05@0
U<5/0<O<d@2T/KH0Phf<06ACE00k3A00^:ba0<gFfP2PZZ`05``A02/42@0/0`80UfLG0<Un5P2c40P0
_`P90<<72P3720/0bPP;0<h92P3?20X0dP/<0=@=3@3G30`0g0h?0=h?303Q4`h0h18>0>8D3`3V6180
iQHA0=P?3P3D3`h0ea<A0=<A4P3=3a00cA8C0<HF5@2j71T0ZBdW0;MaJ@3/d<X0l>KR0>oYj03[j^T0
k>_Z0>cXj03eiN<0hiJA0;hW8`3<4QD0_`P?0:d32@2W0@P0Y0460:01102N0@@0W04509d21@2J00@0
V@0209T1102>0PD0O04308P21`2?0@@0S@8208T10`2:0@@0RP0408h11`2C0`X0T@<90945302@1@d0
Q@4707l11P1n0@<0VP<80:<3202G0`H0NP8306X30015UPX4003o00Wooooo00T0X23`0?n0002h>;@0
X23`0=1@N03oP000d51h0?n0002P8?000`3oP0020=1@N1T0oh0000<0j6Pl0=1@N03XJ3`01P3oP000
0`3@D7P0oh000?n0000P0?n0000308300000o`000?l000800?l02?ooool0B`00o`00`[BS08f6C02b
V`/0Vh870:J;4P2BM`D0/9DB05A<6@24L6`0Sg=b09AeL`2KMgH0WGah0:B3O02YRGh0/9>40;NKR`2n
XXh0_j>?0;jXT`2ZXIH0^KZk0<_1^`3=]jD0dKRX0=:l[03F`;00el6`0=W5/P3E`kD0dL>g0<Jl[`38
_[<0f<nn0=[?_`3PdL40hM310=o>_`3Nc/00f<Nk0=G6]`3DaKH0dL:a0<o1/`3=_[40b[V/0<VhZ@36
]:H0`K:T0<Nk/02k/Z/0^k>/0<[7a@36a<H0YJ^c08VEY@0Y?ET0ZKK409:AW`2FXJ/0a/oF0<G>eP32
cML0a<oJ0<C@g033cMP0`lkI06f1V01LM8T0RYfY0:>^]`2SZ[<0M7n?04b6A`0>003o00Sooooo00<0
0?l00:0Pl03@D7P01@2P8?000`3XJ3`0X23`0:0Pl00;0:0Pl080j6Pl6`2P8?00102h>;@0X23`0?n0
003oP0020;Ph]080X23`0P2h>;@0103oP000j6Pl0:0Pl02h>;@20:0Pl0030;Ph]02P8?00X23`00D0
X23`3P00o`0;ooooo`002_ooool0?`2@_6L0b<c@0:Rd^P1jQhP0HUIG03l>4@2jZ[00c=?K09ZPYP0M
3180<0@<03030P2/Na`0`VX?0;H=2@2o20/0`PL:0;l51`351`X0cPX;0=8;3@3F30h0f0h=0=X>3P3L
3`h0h10>0>@C403U4a00iA@@0>DE4@3O5100d`h?0=DA4P3E4Q80cQHB0<<L602e:B<0]V1H0<VIT@3X
dL`0k>KU0>_[k03Xj>X0jN[/0>OXjP3Yj^`0k>c_0>g]kP3`iN<0l;Ne0;h];`343A40/PH;0:P32P2V
0`T0X04509`10`2H0@D0V@4509P1102I0PD0VP4409T21P0209021@0C08l10`2:0@40R`4408T11028
0@@0S@4709822@2F10/0U0D:094530260@P0O`4608h22@2R0`/0X08909<2101j0@<0I040042B2004
003o00Wooooo00T0X23`0?n0002h>;@0X23`0;Ph]03oP000d51h0?n0002P8?000`3oP0020=1@N1L0
oh000P3@D7P00`3XJ3`0oh000?n000070?n000030=1@N03XJ3`0oh0001l0oh0000<0P<00003o0000
o`000P00o`08ooooo`1;003o003;[740YY@L0:JA202FO@d0YX`=0;NH1`1fJ1L09b`l089^L`2ALWD0
U7Eh09YiNP2OP7d0Y8Eo0:Z9PP2aTXL0^Yf?0;fNS`31Xi40_jFA09>6N`2JSXH0^:NH0=2gY@3A^ZT0
dKVY0=>n[03G`K40f/Ff0;V]X`2RVY@0]JbQ0::IT`2SXIP0fM2o0>3@``3Qd<@0g/g00=c=_`3Ic;d0
dlNg0=;5]P3@`kL0cL2d0<c1/`3=_k<0bKRZ0<JdZ036]:/0a;BZ0<:f[P37`Kd0/[6^0;Bf^P2[/[X0
WZ^j0:2daP2=Z;d0a=CM0;_:d@36dMT0a/oH0<C?f033cMT0`/gI0<;>e`31c=P0P9:V05UcRP1^PY40
TYjW09:JX`1]NXX0I5aN00h00?l02?ooool00`00o`00oh000;Ph]0040:0Pl0030=1@N02h>;@0X23`
02T0X23`00<0^3Rd0=1@N02h>;@00P3@D7P30:0Pl0050>QX?03@D7P0oh000?n0003XJ3`00P2P8?00
0`3@D7P0X23`0:0Pl0050:0Pl0030;Ph]000o`000?l000`00?l02oooool000[ooooo0480T;YT0<75
b@2/^;h0MH>3075XJ00n3a@0/9nV0<cCfP2JWJ807``C02X3200c1`@0]hPL0;EG3P2d20P0_@H:0<07
20311PP0a0H80<`92P3C30h0ePd?0=@=2`3J40d0f`l=0=lB3`3S4Ph0i1D@0><D3`3R5Q40dPh;0<l@
403<4a40b1dG0:`a9`2bI5/0hkV`0>kQg03Zi^D0i^GV0>OWi`3Yj>P0j^WY0>SXjP3Xj>T0k>c]0>WY
j`3[k>h0k>g^0?GTi@3?Kfh0`a4A0;D62@2/1@X0YP@90:411P2L0@@0VP4409P11P2G00@0U04409L1
1P2F0@H0U04409@21@2@0PL208`1100@08P10`270@80R04408l2202D0PX0UP@;09<42`280@P0R046
09X2202E0`X0R`4508h21@1k0P80I`40051e1P@00?l02Oooool00`2P8?00oh000=1@N0020:0Pl004
0?n0003@D7P0oh000:0Pl0<0oh000P3@D7PE0?n00080X23`;P3oP0000`3@D7P00?l0003o0002003o
00Sooooo04/00?l007g67P2YU0d0IUP2091l4@2JP`d0]Id^04Y8>00b=UD0Pfmd08maMP2FMWX0VgUl
0:1mO@2SQ7l0ZXb60:j=QP2gVXd0_J6A0;nRSP30Xi80YI210:VHR032[Id0_JZL0=2jZ@3B^:T0dkb/
0=Bo[`3Ha;X0SHB30;6[YP31^K40[jJU08>3OP3Hd;l0gm720>7Ba@3Ncl80g<_10=W:`03Cb;`0d/Fj
0<o4^03<`KP0c<6f0<No/P33^Zh0`;:T0<2bY`2m/JL0^kB_0:bT[02^WZ/0bk:i0;JTZ@1MJGl0TjBh
07>=X`33dmd0^LG;0<OAfP35dMT0_lcF0;k;eP31cML0_lcE0<7<e`2EYk/0LhbR08VMZP2GY:`0Uj>[
07b9V01SIF/03P00o`08ooooo`04003o001hF;@0X23`0=1@N0<0X23`00<0d51h0:0Pl02P8?004`2P
8?000`3@D7P0X23`0:0Pl00C0:0Pl0<0^3Rd00<0d51h0:0Pl02P8?000P2P8?001P3@D7P0j6Pl0?n0
003oP000j6Pl0;Ph]080d51h00<0^3Rd0:0Pl02P8?001@2P8?0>003o00_ooooo000:ooooo`1D08nh
H@35b/h0/;c408J@TP1ZHfD0>0dE0:ZJX03?em`0SIBG01/;4@0[0`X0?``20<JC7P2]@`/0^0T;0<07
30331``0a@H:0<T82`3<2@/0d@X<0=8=3P3>40l0fATI0=/@403O4Pl0g1<?0=Ha:@3F>c80dC8Y0<Ta
:@3;BD40cVAK0=N;P`3]c<L0l^OS0>cXiP3Yj>P0j^GW0>cPi@3Zd=H0ik>m0=J@V`2LI700^k6f0>c/
kP3/k>l0kNg`0>c]k`3/j>H0h:BT0;/F5`2k20`0/@H;0:H32P2R0@P0X08809/10`2I0@D0T`450981
1@2B0@@0TP0609811P2@0@H0S04508/11`2;0@D0R04308@00@280PD0S`8909<32`2F1@`0U0D<08h1
2@2K0@/0X@<;08011@2:5QX0P`@807T10P1Y0@00GeT61000o`09ooooo`030:0Pl03oP000^3Rd0080
X23`00@0oh000=1@N03oP000X23`0`3oP0000`2P8?00j6Pl0?n0000<0?n000040>QX?03@D7P0oh00
0>QX?0<0d51h00<0j6Pl0?n0003oP0000`3oP0001@3XJ3`0d51h0=1@N02P8?00j6Pl00D0oh0000<0
d51h0?n0003oP0007P3oP0000`3@D7P00?l0003o0002003o00Sooooo04`00?l003gR1P2BPPT0NVX5
0:bE2@2cWbX0SX=C04I;G@0l@5h0QW9d099cNP2FMW`0VWYl09amO02TQX<0Z8R50:j=P`2iVXd0^I^;
0;nQS@30Xhh0`ZFD0<>XU`30ZYT0YIF;0<JaW`3C^ZP0d;jZ0=G3/P3E`KH0S86108J4R02<Rhh0Ogn1
09NCRP3Mckl0glo20=oA``3Ld<40f<^n0=?8_P3Aa[`0dlFn0<k3^`3=`k/0cL:h0<Vn]@31]jh0_KB/
0;>/[P2HRYX0TVAn09/eCP2Z6bh0[18O0:PW<035RYP0LFYk07j?XP2ncm/0b=;J0<GBf`34c]P0_lcE
0;c:d`2oc=L0_l[E0<7;f01/OiL0J8:M07bBY02Y]<00[;O206EdRP1KI7806=8?3@00o`08ooooo`07
003o001@T7P0X23`0;Ph]02P8?00^3Rd0=1@N00F0:0Pl0030;Ph]02P8?00X23`00X0X23`0`3@D7P3
0:0Pl0030;Ph]02P8?00^3Rd0080X23`0`3@D7P30:0Pl0050=1@N03XJ3`0oh000>QX?03oP0000`2h
>;@80:0Pl003052@N000o`000?l000/00?l02oooool000[ooooo05@0SKEN0<G9c@2a_<80Phf@07Qd
N00f3aL0[IbU0=;Jh@1oQXd07@/C02h31`176040didR0:L[1P2k20`0``T=0<<72P3020`0/`D:0;<6
2@392`d0bPd>0;hL70397Qh0g@l@0>0A3@3H4Q00Vb<S0<B=S@3cd]00nN7N0?OWi@3dj>L0ln_Z0>oY
jP3^hn80kM;E0>:X[P3ANH40d5aW0<@^>@367BD0cA/O0;@N8@1Z?440jNW[0>_[k@3/k^l0j^_]0>c]
kP3eemX0_2/^0<X>4`2l20`0Z`<:0:<01`2P0PH0VP4309T1102C0PD0T08809<11`2C0@D0T@4508l1
1P2:0@<0RP4408X21@280@H0PP4208<10`2<0PL0T@<809L53P2G1@d0XP@=0:X32`2P0PT0N@4507/3
201g0PL0MPP;06L10@1KEPL4003o00Wooooo00<0X23`0?n0003@D7P00P2P8?00103oP000d51h0?n0
002P8?030?n000030:0Pl03oP000oh0000P0oh0000P0j6Pl0?n0003oP000oh000>QX?03@D7P0oh00
0>QX?0D0oh0000D0j6Pl0=1@N02P8?00X23`0;Ph]0020=1@N0030?n0003@D7P0oh0000@0oh0000<0
j6Pl0=1@N03oP0007P3oP0000`3@D7P00?l0003o0002003o00Sooooo04`00?l001Sb1028LPD0Y8l;
0:nG102YUT00XYjG03DmF`1;BfP0R79i08e`MP2BMGP0VG]n09imOP2RPH00YhF10:Z;P`2`ThP0_9j>
0;nTS`2oYHl0a:NB0<R[UP39[iX0a[6M0=;0Z`3E`:d0ckfZ0=70[`3B`;40a[BY09f?RP2OUHl0]:RM
0=C4]P3Mc;l0g<g00=_=`P3Hc<40el_20=?;`@3BbKl0d<Nn0<g4_@3<a;d0bL:l0<Bn_02`Z:l0VhBG
09ECKP2/;TD0/a0N0;T;402f2@l0^0H?0;L42`2[2aP0VcQ60:bIY038e=/0bMCM0<KBf`33cmT0`<cD
0;o:dP31cML0`/gG0<3=f02AX[D0F76807V@X02CWZX0Uj2/05eYP@1>FFX0;[HQ3@00o`08ooooo`03
003o000Xb3`0X23`0080X23`0P3@D7PO0:0Pl0070;Ph]03@D7P0^3Rd0:0Pl02h>;@0j6Pl0?n00002
0>QX?0050=1@N02P8?00X23`0:0Pl03@D7P0103oP0000`3XJ3`0X23`0:0Pl0020?n00080j6Pl00<0
oh000>QX?02h>;@00P2h>;@70:0Pl00306RX?000o`000?l000/00?l02oooool000[ooooo02P0R[AK
0;Vm_P2d`<L0SifR07AaMP0f4AP0ZIVQ0=KLiP1`MWl070/C03052@1T=A00dYXW0:0G1@2h1``0_@L?
0;T7302T0`L0`Rde0<4e>P2W1`T0c@h?0=TS9P3H7Al0ga4@0>8B403R4`l0dQ<E0:lA602]=400a6Ib
0<YfP@3NS9H0gH>?0=EWL`3>CeP0bC8j0=0O9P3A6Ad0dADG0P3F5QT05@3D5QH0bQTK07DF6@2^YjP0
j>[[0>_/kP3/kNl0kNg`0?;WjP37FE`0b18E0<<;3@2d1P/0Z0480:<1202K0@@0UP4209H1102E0@L0
S`880902200209411`0C08l21@2=0@80S@4408/11P2700D0Q04408`2202>0@T0T`@<0:053P2]1@`0
Z08909d32P1]0@@0L@H<07P32@1d2`h0K08405Q?0`04003o00Wooooo00<0X23`0?n0003@D7P00P2P
8?00103oP000d51h0?n0002P8?030?n000030:0Pl03oP000oh0000<0oh0000H0X23`0=1@N03oP000
oh000=1@N03XJ3`50?n000050;Ph]02P8?00X23`0=1@N02h>;@00P2P8?020=1@N0L0oh0000<0d51h
0?n0003oP0000`3oP0000`3@D7P0oh000?n0000M0?n000030=1@N000o`000?l000800?l02?ooool2
003o001:09>:1P2^VPD0[iTD0:^NIP25Q8X0?TIW05EFK@26L7H0SW1g09EdN`2JNGl0Wgen0::1P@2U
Pgl0[8R00;JES02lWXl0_Z6>0;nSS`34ZIH0aZbF0<^bW03=]Z@0dkj]0=2mZP3B_Z/0dkf]0=;1[`3F
aKH0e<:d0=W8^@3Lbk`0f/Rj0=_:_@3Ibkd0eLS00=G:a03Fc<L0_Ko10<?5b@3F`;h0eKFg0<JTZP2k
Tj40ZVYo0:]5G@2c8c40^1HJ0;DM6`2g>S40^Ea@09aDEP2H;cd0/PL@0;H42@2[2100U3e70<?8d03>
f^40a]?L0<G?f@32c=H0`LWD0<3<e034cmP0`/kI08nS]`1LMH/0Rj2_09FR[P2GXZl0H6n7041@H00l
YRl=003o00Sooooo0P00o`030:0Pl0030;Ph]02P8?00X23`01d0X23`00H0d51h0?n0003oP000j6Pl
0=1@N03oP0020=1@N0080;Ph]02P8?00X23`0=1@N03XJ3`0oh000>QX?03@D7P20;Ph]0<0oh0000L0
^3Rd0=1@N03oP000oh000>QX?03@D7P0X23`0080j6Pl202P8?000`1hF;@00?l0003o000;003o00_o
oooo000:ooooo`0I08V`E`3>dM<0^LC=08>BUP25Q8T0=18H0:VIX@3DgNH0GF9[024;4P0a1PT0RELJ
0<^=802L3`H0]`L=0;P84@2X1@`0Z@@:0<0:4`2g2Q40W0<50<d=3P3C3Pl0fPlC0=l@40020>0C3`0i
0=8>3@3;2`X0cA0B0=4E603B61d0caLO0=4I803D6Ad0dALH0=@F5P3G6AP0f1dJ0=<K5`3C6aT0ea`L
0=@E603?5AT0WAPL0655A`3Si^H0j>_/0>_/kP3Zjnd0k^[[0<moP`315aT0a0`=0;X8302`1@`0YP49
09/0102H0P@0U00209<110220@80P`4309021`2>0@D0S04408X00@2=0P@0RP4508P010270@<0R`86
09012P2P2100Y`@;0:`4302S0@P0W08906`72`1<00@0L0<:07P73@1`0P<0Fe0400@00?l02Oooool0
0`2P8?00oh000:0Pl0020:0Pl0040?n0003@D7P0oh000:0Pl0<0oh0000<0X23`0?n0003oP0007P3o
P0000`2P8?00oh000?n000030?n000030=1@N03oP000oh0001d0oh0000<0d51h003o0000o`000P00
o`08ooooo`800?l004X0N[L50:^H4@2`YE`0ZZF@08>4S00kAFD0H5ib08MaM`2ALgX0Tg5h09McM`2M
NGX0Xh220:N5P`2[R880]9N>0;bMT`32XI<0`:>A0;nUU039[9/0bJnJ0<^dX@3C_JX0d[n[0=2jZ@3B
_j`0d/2^0=K4]P3B`K<0elNk0=[:_@3Gb;X0fL^n0=S<_`3Hc<<0f<_60=K<a`2^];l0K7nQ0:9dR@2]
@U80/C=20;LZ>02j8BT0^R@R0;ll<031HeD0aY>40;bQU02_XI<0YYfN05Y5I02N4Al0]P<=0;83302S
7RH0^Zjh0<kIhP37e=h0`LkG0<G>f032bmD0a<kH0<C@fP33cm/0O8nT06F4WP1fT:00VJZg09n__P1O
L8/0@U=U04b3?@d00?l02?ooool2003o0080X23`00<0d51h0;Ph]02P8?007P2P8?00103@D7P0oh00
0?n0003@D7P50:0Pl0040;Ph]03oP000j6Pl0=1@N0D0X23`00`0d51h0?n0003oP000d51h0;Ph]03o
P000d51h0?n0003@D7P0X23`0>QX?03@D7P90:0Pl0d00?l02oooool000[ooooo05@0Hl520<W:b`2f
`LT0UJ>W07AeN`0d51/0[IfV0=OOi`1=DUX08PXA03471@2/O200_gXJ09d;1@2b1@`0[@P>09021P2f
20l0a0H=0;H72`2L1@H0cPd>0<l92P3H3Q00f`h?0=d@3`3L4a40c0`=0<P<303>3a40dQ@B0<lO703?
;RP0dSTb0=4_:P3<8A`0bA`J0;Xi=03OMVd0g7Y_0>68OP3XQh80`2l_0=4H702m71l0CPd?0=3<c03X
j^T0j^_]0>_/k03Zj^/0gJZ/0;DQ90343A00^0D;0;@53`2/0`/0WP4709L11@2C0@<0U00308h21029
0@<0SP8308d10P2@0@L0S`4608h11@2<0@L0S04508/1102<0PH0V@D<0:h94P2b2100Z`D;0:D12@2O
0PT0TB8Y07Ti?P1^10X0P`<907H10`1KC0@4003o00Wooooo00T0N5Rd0?n0003XJ3`0^3Rd0:0Pl03o
P000d51h0?n0002P8?000P3oP0000`2P8?00d51h0?n0000C0?n000050=1@N03oP000oh000?n0003X
J3`01@3@D7P30?n000030>QX?03oP000oh000080oh0000<0d51h0?n0003oP000603oP0020=1@N0<0
oh0000<0d51h003o0000o`000P00o`08ooooo`800?l004X0O;X80:ZPCP2OXI/0Wj6V09NJY@0b?e`0
JfUi08A^M@2=LGL0UWAj09]fN`2NNG/0XWeo0:N6PP2YR880]IF;0;^NT`2oXID0_YnC0<:ST@38ZiX0
bk6P0<^dX03C_Z/0d[j]0=6m[@3C_k80dl2b0=G3]@3B`K<0f<Fi0=[:_P3GakX0f<Zn0=O=``3Hc<D0
el_70=G;b03Cb/X0`;k80:2O/02`W:P0]i>K0<6CU@3BY9X0djjR0<^cY`32]:X0^JnV0;:[X@2`ZIl0
][6^05iSP028=4X0[`@>0;81302W2180Yg^70<gJhP3<fN80aM;K0<C@fP35cmX0`/kJ0<?@g@31cm/0
WJo505IcU01DM9/0=e2602i3OP0H;6H0A5M[05A^@`d00?l02?ooool2003o00040:0Pl02h>;@0X23`
0;Ph]1h0X23`00<0^3Rd0?n0003oP0000P3oP000103@D7P0^3Rd0:0Pl02P8?020;Ph]0H0X23`00<0
^3Rd0:0Pl02h>;@00`3oP000102P8?00oh000?n0003XJ3`20;Ph]0/0X23`3@00o`0;ooooo`002_oo
ool0E016]B@0c/_70;g9c`2@X:H0NGf2034F6`2[WJL0e]kW03Dh@00T2A40?@l30<RH;02YG1@0XPT8
0;053`2I1`h0O`840;X83P3620h0[0H90:P72P3C3@l0eP`>0=L?3P3J40h0f10@0=4<3`3:2Pd0c@h?
0<DA4`2R;2L0g:FL0?SJe03hhM`0n=WD0?;3_@3EUXl0NUeJ0>CKf@3Zi>@0k>OW0?GUiP3<Oh80b24T
0=0K70295QP0Wh^=0>c/k@3/kNl0inSY0>SYj@3Zd]<0YCTl0;P@502f1Pd0/`H=0:h42`2W0PP0WP86
09P00`2F0@<0S`8208T00@290@40S04108h10`2A0@D0TP4708h21P290@@0RP4209H1102X10X0]0P?
0;<63P2^10/0Z@890:02202E20l0RaTP08H63P260@H0N04207@S10@00?l02Oooool02@1@T7P0oh00
0>QX?02h>;@0X23`0?n0002P8?00oh000:0Pl0020?n000030:0Pl03@D7P0oh000100oh000P3XJ3`0
0`3@D7P0j6Pl0?n000020=1@N0030;Ph]03oP000oh000080oh0000D0X23`0=1@N03oP000oh000>QX
?0040?n000030>QX?02P8?00oh0001T0oh0000D0d51h0?n0003oP000oh000>QX?004003o00Sooooo
0P00o`00B`1m^A00XIaY0:F//02PXZX0OX6>03U4G`1bKGT0QFig08i`N@2FLgP0VgAl09ehN`2ROWl0
YX:10:Z6P`2dU8`0^9Z?0;bOT02nX980`Z>B0<V[V`3;/J40c;BR0=:lZ`3D`K40d[j^0=6n/03C`;80
e<:e0=;0/`3E`kH0f<Vl0=K8_@3Eb[h0e<_20=C9``3Ab<@0e<W50=;9aP3Bb/P0c<O30<c:aP39b<@0
al?10<W2_037_KL0`KVd0;Ba/`2g/;00_:bV0;NVX@2d[:L0WZBb05a6J`2P3Q/0/`8<0:l43P2`De/0
e]SN0<_Gh`36e=h0aM;L0<KAg@36d]d0`loM0:>he@0cCHH011aS004DH0014Uh00A5K004BF`0C94h0
G5aF00Kc0`0<003o00Sooooo0P00o`000`2P8?00d51h0:0Pl00O0:0Pl0030=1@N03oP000oh0000L0
oh00103XJ3`00`2h>;@0X23`0:0Pl0020;Ph]0090:0Pl03@D7P0oh000?n0003@D7P0oh000;Ph]03X
J3`0oh000080^3Rd2P2P8?000`0Xb3`00?l0003o000:003o00_ooooo000:ooooo`0P04Rf8`36`/00
/l3709>SZP1iOH40<aDJ0:jPZ03Cf^@0:b`e02H94@1@80X0cYd]08`o402N20/0[0L?08T42@1g0@D0
/@P=0;`;402K0`L0/PT;0=8=3P3B30/0dPX;0=P@3@3?2`/0b`T<0<d=3@3:30/0YQ0A0:=mN03ak>X2
0>c/k@0b0>_[kP3[j^`0k>SW0=oKe`3Ccll0inKY0>SYj@3^j>P0m/S:0;l/<03B5Q/0]R0W07iEF03/
k^l0jng]0>GUj03YjN/0k^7S0:aRIP2/5AP0]@P?0;863`2/0`/0Z`<90:<11@2I00<0U@8508h10@2;
0P80R@4208/10@2?0@<0T@4609812@2<00@0S04409<10`2U0PP0[0890;D5402d1@h0[P<:0:T3202U
0PP0W@8909832`2<0@X0Q08507<0001n50D4003o00Wooooo00<0D91h0?n0003@D7P00P2P8?00103o
P000d51h0?n0002P8?020?n000030:0Pl03@D7P0oh0001d0oh0000@0d51h0?n0002P8?00d51h1@3o
P0000`2P8?00oh000?n0000M0?n000@00?l02?ooool2003o001;05oD;@2?Tgh0X:J^0:>V/02<S9`0
>3iH07Q_NP25LGT0SFmh09IbN@2MMG/0XGYj0:>0P02UPX40ZXJ30;6@R@2jVY80^YR=0;NER030XI40
aJZI0<V_WP3;]:H0cKVY0=?1/`3>^jl0d;j`0=;1/P3B`;<0e<6e0=G4]P3Eb;/0eLRm0=C8_P3Bb/40
dl[30=;:a@3Bbl@0dl_60=;<a`3=bL<0/K_5082@Z@2SSZL0agN20<QcN038RHh0SgfE08QSOP2c?dX0
]cY30<>;S02_[[00DUb0098aB02b1a<0/P<=09hF803GaL`0b]CO0<KCg034d=/0`m7N0<7@g`1jT[T0
3RM]004DIP004V800A9P008BF0024UH00A1G008@AP16CU<06=8?00`00?l02?ooool2003o000306RX
?02h>;@0^3Rd01l0X23`00@0j6Pl0?n0003oP000j6Pl0`3oP0000`3XJ3`0X23`0:0Pl0020:0Pl005
0;Ph]02P8?00X23`0:0Pl02h>;@00`2P8?000`2h>;@0oh000?n000020>QX?0030=1@N03XJ3`0^3Rd
00`0X23`00<0D91h003o0000o`002P00o`0;ooooo`002_ooool0E018]bD0aL;00;W6c@2@WJ<0O864
03<F6`2bY:`0b<oH01hJ900W1Ph0HS<B0=FR<@28;@d0X`H;0:`63`2510T0J`4408l32@2D0`T0Q@44
0;@:3@3C30h0dP`;0=@=3P3@2`d0a@@90<T83P3>30d0cPl@08l>402jZJH0k^k^0>g]l03/jnh0jMcP
0;jCW@2oUj<0i=cO0>KUi`3ViNP0inWY0>SWj03hhN<0aU1D0=@K7P397B00Lbdb0>W[k03Wj>T0j>W[
0>OVj@3XhN@0f:R[0:LO8`2b1`h0/0D>0:d43P2^0`/0Z`<:09h11`2G0@D0T`4209020@2<0P<0RP81
08d20`2?0@D0TP4809811@2H0@D0XP860:T2202W0PP0/PD>0;H8402a1@d0ZP<:0:<11`2H0PP0T0<:
08/21`240PH0L`4107XA10@00?l02Oooool02@1@T7P0oh000?n0002h>;@0X23`0?n0002h>;@0j6Pl
0=1@N0020?n000030:0Pl03oP000oh000100oh0000<0d51h0?n0003oP0000P3oP0020=1@N0030>QX
?03oP000oh0000<0oh0000@0^3Rd0?n0003oP000d51h1@3oP0000`3@D7P0j6Pl0?n0000M0?n000@0
0?l02?ooool2003o001;06[MC02=Ui/0YZji09VLYP2BU:40?D9G07Y^N027LGL0SVmf09IaM`2KMGT0
WGEf0:5lO02VPh40ZXF40;>=RP2iVY40_IfA0;jOT030XY40`jRH0<^aX@3=]JH0ck^/0=70/`3<^Z`0
c[b/0=70/@3B`;@0e<6g0=C3]P3EbKd0dlNn0=77_P3AbL00e<[20=;9aP3AbLD0d/W30=;;a`3<bLD0
IGnO07J1/@2]CF/0b1PS0<PD702j6b@0/3i@0;mTN@2g4A/0a`lF0<1GE`2g/:l0QiB[0750H02V3A/0
]0@>0:L74`2oT9T0bm?M0<OCg034d=T0`=3M09N^cP0786P00A=R004AH0004ed00aMG01//E`0W>6T0
5RUJ00lMA`0c?dl0:lLT00`00?l02?ooool2003o0003052@N02P8?00X23`01h0X23`0P3@D7P60?n0
00<0X23`00<0d51h0?n0003@D7P00P2P8?00103@D7P0oh000=1@N03@D7P30:0Pl080oh0000@0d51h
0?n0003oP000oh00302P8?000`20`0000?l0003o000:003o00_ooooo000:ooooo`1D04Bc8`2f/k80
_LS@096PY020PXL0<aLL0;FX/@2d^lH06A4L02X63`1oCQT0bi@]08DB1P2/1P/0/@D=09L63`1T0@D0
N10G080H7`230`T0_PT=0=4<303B2``0e@h@0<L82`341Pd0b@T?0<h:3`3?3Pl0UQ0C0;:SY03/k>d0
jNW/0>WXjP3E[;00[RP_0;`N9P2@<cl0Z9NP0>?Ri@3Ui^L0i^SY0>gUi@3GQh`0d20T0=4H6`264aT0
`;bn0>CWj03Zj^`0jN_]0>OVj03Wd]<0Xce00;094@2`0`d0/0D>0:h32`2^0P/0Y`8909l21`2D0@@0
T04108h10P2;0@40RP8208l10`2G0@H0XP890:D21`2U0@H0TP4408T2102W1Pd0]PP?0;452P2[0`P0
X`4709<220210@@0Q`8708D11P1h0@80M@`31000o`09ooooo`08052@N03oP000d51h0;Ph]02P8?00
oh000:0Pl03@D7P20?n000030=1@N02P8?00oh0000@0oh0000<0j6Pl0=1@N03oP0002P3oP000103@
D7P0oh000?n0003oP0030=1@N0030:0Pl03@D7P0oh0000<0oh000P3@D7P20?n000030>QX?03oP000
oh0000<0oh0000<0d51h0?n0003oP000703oP004003o00Sooooo0P00o`00B`1Zg4h0Uj6[09jU/`2M
WjP0P8ND03]5F01lKWT0QVmh08i_M@2DL7L0W7Ai0:5hNP2ROX00YH200:Z3PP2bS8P0]iJ>0;ZLT02o
XI@0`Z>E0<JZW@3:/:00c;FV0=:k[@3B_[00ck^[0<fiZP3@_[00dL:d0=?2^@3A`KT0cL:k0=36_P3B
b<40dL[20=C;a03Ec/L0e<_60=G;a@3CblL0cL_;05A`V02YYM80/SQ=0=0B60394aD0cUYI0:17FP2U
;d@0`A<N0<T<4`2e9R/0`jBT0:B[]P1@B6/0R1T^0:/54@2Z10h0ZeIQ0<kAf@36d=/0aM7K0:o2g00S
?X000AMW004DG`046Ud0>EB506Z0W@2?X;D0:3eU05Q]P`1KI7H0939403VT<00<003o00Sooooo0P00
o`000`1@T7P0^3Rd0:0Pl00L0:0Pl080d51h0`3XJ3`50?n000030:0Pl03oP000X23`0080oh0000H0
^3Rd0:0Pl02P8?00d51h0?n0003XJ3`40:0Pl080oh0000@0^3Rd0?n0002h>;@0^3Rd302P8?000`1h
F;@00?l0003o000:003o00_ooooo000:ooooo`1D04Fb902k^KX0_LWB08nNY@1eN7l0;a<H0;JX/P2W
[[L04@`E02@52P2@H200ZfXO08T;1P2`1``0]0D;0:h:4P1c0`H0i:6X0>>QZ02B4A@0aPX<0=4=3`3B
3@l0c0P>0<052@321@/0b`/@0=0:3`3C41<0ZA8F09Z4R03Yin/0iNGW0>KTi`3N_[h0YRX/0<@D602`
6200?@P?0<W5a@3Vi^L0inSX0>k[j`3P/;40^b@W0<hG6`2R5Q/0Th>60>;Vi`3UjNX0i^[[0>CViP3V
g=d0[V=V0:/;4`2[0`/0[08<0:d4302Y0P/0Y@490:421`2F0@T0TP440941102A0P@0S@4109800@2Q
0@H0Y`490:H01`2S0@D0V`@908@1102I1P/0]`TC0;84302^10X0Y@4809P1202700D0Q`4608H21@1k
0@<0M@X21000o`09ooooo`03052@N03oP000d51h0080X23`00<0oh000:0Pl03@D7P00P3oP0000`3@
D7P0oh000?n000040?n000030=1@N02P8?00oh0000X0oh0000D0d51h0?n0003oP000oh000=1@N002
0?n000030=1@N03oP000d51h00<0oh0000D0d51h0?n0003oP000oh000=1@N0050?n000030=1@N03o
P000oh0001`0oh001000o`08ooooo`800?l004/0H]4o0::X/P2HX:d0W:2]045?J00_>580O6]e08=/
M@2<L7L0UW5i09agO@2NN7`0Xg^00:IoP@2YPH<0Yh9o0;FFS`2lW9D0_inD0<:TU034Z9P0bJjO0<Zc
Y03A^j/0a:VE0=BmZ`3=^ZX0cl2a0=2o/`3>_kP0/jRP0;bb[02b[:P0dLO10=?9``3CblD0d/g70=?<
a@3EcL/0e<c:0=7;c01dRZh0BUbA0:eCKP3?4aX0aAHH0=VJU`2h/KH0O6Z509XeD0323QL0^`dC0<Yo
P@2VYZP0Ce]h07Q<K@2F31d0Y`<=09<C803?_lP0a];L0;k=g`0eCh`00QY_00@LI@19II00GGNE06n;
XP1kTZD0AV6601lgG01^OhD0KWYo02`iA@1?S4L03000o`08ooooo`800?l000<0D91h0=1@N02P8?00
6P2P8?00103@D7P0X23`0;Ph]02h>;@80?n000<0X23`0P3oP0001P2h>;@0d51h0:0Pl02P8?00j6Pl
0?n00080^3Rd0P2P8?001P3@D7P0oh000=1@N03XJ3`0d51h0;Ph]0d0X23`3000o`0;ooooo`002_oo
ool0E01;^2P0]K6`0<;<e@2GYZ`0Oh:7038C6@2o/[T0V:2Z014<500Q1@P0Y7@/08Xm3@2B2@L0[@@9
0;D62`2f1`h0W0P=0:I7C@2VBD/0^BHV0<T<3@3310P0b`d@0<D6303320`0a@P>0<P92`3?30d0cP`>
0;TC5`1jEEL0i^;U0>KTi`3Ti>L0i]KD0:QCC`2j6A`0`APL06/<4P2FRHX0i^KV0>OVj03Wi^L0kmGG
0:dh?0324aP0]1LM07E?D`3Si>D0iNGW0>[Zk03UiNL0hmgO0;n9S02U3aD0[0L>0:d43@2/0`/0Z@8:
0:D2202Q0`P0V`4809`11`2F0@@0T@4309H10P2Q0PH0Z@480:P1202U0@L0X`450:421P2I0`P0V`<9
0;D93`2d1@h0/0@<0:@12P2K0@P0TP4608T10`240P@0O@8407L:0P@00?l02Oooool00`1@T7P0d51h
0=1@N0020:0Pl0030?n0003@D7P0d51h0080oh0000<0^3Rd0?n0003oP000103oP0020:0Pl0030>QX
?03oP000oh0000P0oh0000<0j6Pl0?n0003oP0000P3oP0001@2P8?00oh000?n0003oP000j6Pl00<0
oh0000D0j6Pl0=1@N03oP000oh000>QX?0050?n000030=1@N03oP000oh0001`0oh001000o`08oooo
o`800?l002H0<NHO0:6OY02KXjl0U9RV01hVA`0l@5X0NFYd08A]M`2;KgP0U71j09QeO02QNh<0XWUn
0:IoP@2ZPhD0YX5n0;BBS02iVY40_ijC0<2OT@35Z9L0b:jN0<R]WP3=]ZL0d;VY0=2kZP3=^ZX0ckn`
0=30]03>_kT0^:fW0<c4^`2d[jL0d<W00=?;`P3Cbl@0dlg80=;;b080dlg;02<0dLW90;2hbP0/C7/0
PVN?0<4I9@3=4QT0cUmQ0<Jd/02[[;L0G5F40:XM<P302@h0[Rda0;j][02AVjX0;2mG08DYA02U1140
WPDB0;EkQ@39dMh0KHB^008NK`0?;g00NIJe0;73d`1]Q9X0MXnT06AmX00@:E/0LXJE07AoP`1cO7l0
<D5;05eME00<003o00Sooooo0P00o`000`1@T7P0^3Rd0:0Pl00J0:0Pl0060?n0002h>;@0^3Rd0:0P
l03@D7P0j6Pl1P3oP0002`2h>;@0X23`0:0Pl03@D7P0oh000;Ph]03XJ3`0^3Rd0:0Pl02h>;@0oh00
0080d51h00<0^3Rd0:0Pl02P8?000P3oP0000`2h>;@0d51h0:0Pl00=0:0Pl0`00?l02oooool000[o
oooo05D0A:lL0;bd/P33c=D0VJN/07AjO@0_61/0b<3708N@V00D2a<08`L60;9o;01`5@40V@H70;45
3@2h1@h0^0@=0;842P2i51T0]@lC0<893@3:2@`0`PD:0<06302n1@T0``L;0<H62P3:2`d0c@h<0<h>
3`344AH0HalS0=gGf@3Vi>H0iNGV0>SShP3EZjL0Z2HU0<LF6@2W6Ah0ID120>7Qh03Wi^H0inGV0>kT
i03;Oh40_1dO0;`C6@1S6b00dm3B0>?Qi03UiNL0hN7T0>3Mh03I_Kh0W1XO0:d73`2_10d0[P<<0:T3
2P2W0PX0Z0@<0:L32`2T00/0XP480:011@2U0@D0Z0470:/22@2X0@L0Y@470:811@2R0@H0Y`890:P2
2@2a1Pd0]@L?0:d1302R0PX0V04808l11P260@@0P04507h21@1h1`808LL100<00?l02Oooool01P1@
T7P0d51h0;Ph]02h>;@0X23`0?n00080d51h0P3oP0000`3XJ3`0oh000?n0000A0?n000030>QX?03o
P000oh000080oh0000D0d51h0>QX?03oP000oh000=1@N0040?n000040;Ph]03oP000oh000>QX?0D0
oh000P3XJ3`M0?n00004052@N000o`000?l0003o00Sooooo0P00o`00C00Fl0/0`;Zi09fV]02SZ;P0
9bi>04I7GP1`HV/0PFig08U_MP2BKgP0V7=j09eiO`2RP8<0VGUm0:=nPP2XPH00/H^80;NDR`2lW8h0
_J2A0;fST@36[Yd0bk6S0<jfY`3=^JX0cK^/0<bhZP3?_Jl0cKf_0=30]02n/ZX0^[6[0<W1^03?b<00
d<[30=C?b03Ec/L0dlc80<c8a`3@c</0clS60<W8bP2S]<d0EfVH0;@mD@3=4AT0`QlT0=BOW02h];80
KGZM08]1IP2m3AP0/0dD0;QoP02QXJL0IFf:05ljG02L21P0Y@<?09P`?038amT05cEd01`mN`2I]/h0
^L_E0;K5dP1LLXl0=51j00TTE`1VNY<0OXR>07AnP01YMgd0:ci=05]OEP06l`<;003o00Sooooo0P00
o`000`0Xb3`0X23`0:0Pl00L0:0Pl080^3Rd0P3XJ3`00`3oP000j6Pl0?n000030?n000080>QX?02P
8?00X23`0:0Pl03oP000j6Pl0:0Pl03oP0020:0Pl0030>QX?03oP000X23`00<0X23`00<0d51h0?n0
003@D7P0102P8?000`3@D7P0X23`0:0Pl0080:0Pl00302S8?000o`000?l000T00?l02oooool000[o
oooo05D0@jdI0;R`[`3;e=d0TInV08>8S@0b6R<0al?<079kQ@0A2Q00:`h40:ig;@1[2040W0L;0;<7
3@2h1@X0^@D90;T320362@d0a@P90<H82@3:2@`0`@H:0;P21P2l1@X0`@P<0<042@361`/0bPd=0<T<
3@312@h0K``A0<S1`P3UiND0iNGV0>KUiP3Udm40[4E50<HE6P2n61h0G1LM0=7@c`3Sh^00inOW0>_V
j03MZjh0ZR8T0<0D5P1e3a<0]:j_0>;RhP3Rh^<0h=oQ0=kNh03Ncm00Wc0g0:h94`2a1Ph0[08:0:T2
2P2W0`/0YP8:0:L1302Y00/0/@8;0:l3202Y0@H0Z@480:X11`2X0@L0Y@450:41102R0@L0Y@490:H1
1@2a1Pd0/P@>0:`23@2Q0@X0U@4708d11P250@H0O00407X11@1d1@808LL200<00?l02Oooool00`1@
T7P0oh000?n000030:0Pl080d51h5`3oP0000`3@D7P0oh000?n000020?n000030=1@N03oP000oh00
00D0oh0000D0d51h0?n0003oP000oh000=1@N0050?n000030=1@N03oP000oh0001/0oh0000@0D91h
003o0000o`000?l02?ooool3003o001;0<Fi/@2KYkL0Ui^[0457H`1=C5l0MFQ^07iZL@25K740T75i
09QbNP2QMgd0VW9j09EbN02EMgX0ZHF50;6;Q`2eT8P0_IbB0;jQTP2oX900aJZJ0<B[V@3:]:<0b[JX
0<jiZ`3;]j/0ck^^0<jl[`3;_[40c/:h0<c1^`3@a/00c/O20<o;a03Dd/h0e<o;0=7;bP3=b/P0c/g8
0<c:aP3=alH0bLS=07J;Z`2AIHP0a1HP0<X@5`36EeT0_JjZ0:Z`_@1DBW/0YQ@X0;T94P2Z?T<0[Z:T
09BHY@1:BVl0RQ`c0:82402?1Q<0X7nF00/YIP2C/Ll0^lgH0;W;e`2BZ/X08Smd00lYF01CJXH0OhnF
06iiOP1ULgP0>deW01T^DP1GHf@07<HA00/00?l02?ooool3003o01h0X23`303oP0020:0Pl0030=1@
N03oP000^3Rd0080^3Rd00D0X23`0;Ph]03oP000d51h0;Ph]0030:0Pl080oh00102P8?000`2h>;@0
X23`0:0Pl0080:0Pl00306RX?000o`000?l000T00?l02oooool000[ooooo05D0A:dJ0;N/Z036cmL0
UZF[06mbM@0b6b<0blSB061YL@0G2Pl0@Al=0:AW9`1h2@@0T`<80:L42P2j20d0_`T<0;l52P392`d0
aPX<0<H82`331P/0]P<:0;<42P2d10/0^`D<0;/42`2o1P`0``T<0<892`332Pl0T0lE09N;R`3Thn@0
i>?U0>GSiP3[hN80_gEd0<DK70365QX0N10G0:RQY03Qgml0h^?R0>?Ui@3Xcll0XcPl0;dF6@2D4aP0
RGan0>3Rh@3OhN80h>3Q0=kNgP3QfM/0XTiC0:X<4`2b1`l0[@@=0:`5302U0P/0Y`<>0:d33@2f0`h0
^P@<0;P4302^0@X0Z`890:/2202X0@P0Y@880:811`2P0PH0X`480:@1202^10`0/PH?0:P22P2O0@L0
UP4608d11P240@P0O04607X2101e1@808LL200<00?l02Oooool00`1@T7P0d51h0>QX?0020:0Pl003
0?n0003@D7P0j6Pl01L0oh0000<0j6Pl0?n0003oP0000P3oP0001@3@D7P0oh000?n0003oP000d51h
00<0oh0000D0j6Pl0:0Pl03oP000oh000>QX?0050?n000030=1@N03oP000oh0001/0oh0000@0D91h
003o0000o`000?l02?ooool3003o001;0:C8T@2BW:/0WjFb01dW@@1AEVX0KfI]07i[L@26K7H0SF]g
09aeP02RN800U6ae0::3Q@39^[`0c[_10:f<S@2dT8X0^9R;0;bNS`2kWHl0ZI>60:FCQ`2o[9d0a[:S
0<^dY`3;]JP0c;N/0=6o^03>_[L0cL6h0<W1^P3?akl0clO00<o:`P3BclX0dlo;0=7>bP3=blH0c<[7
0<c<b03<b<@0c<S60;Zoc@1KJIH0/3=30<`@5`2n71l0cibK0;^g^@1/NI`0T41P0;X=5`2V3QL0`iZO
0:6Q[01TK8P0KCEE09/55@2L0`h0PBLn02Y0L`2/b^P0VK;@051^WP0?;fH0CfnC08fR/`2FY[00Sj2X
06]mS@0Z?F000Q14004=A00d@eX0;:PS00/00?l02?ooool3003o00030>QX?02P8?00X23`00X0X23`
0P3XJ3`<0:0Pl080d51h00<0X23`0>QX?03XJ3`00P3XJ3`80?n000070=1@N02P8?00^3Rd0?n0003X
J3`0^3Rd0>QX?0020:0Pl0030>QX?03oP000^3Rd00<0X23`00<0d51h0?n0002h>;@03P2P8?000`1X
Z3`00?l0003o0009003o00_ooooo000:ooooo`1E04Na702hZjD0b]CK092QZ01cM7T0>B<Z0=;Af@1;
CEX06@L<05`k6@1l?AT0O`P;09T32`2[10/0^0D=0;h73@2o1PX0b@X<0<X9303720/0^`H:0;032`2R
0@L0U`850:`53@2g10d0^`D=0;d7302n20d0`@/@0:h@5`1XB4P0fM[J0>;RhP3Sh^<0i>?Q0=Vd]02f
8bD0aA@G0:8G6`1bFUl0h=kQ0>3PhP3PhN80jMkO0;eoPP2[6B00/AHM06U1A@3Jf]`0h=oQ0=kNg`3P
gn00h=gM0;V1P`2R51T0/PT?0;053@2]10d0W@870:042@2g1`l0^P@<0;X32`2i10X0]0@;0:X01@2U
0@D0YP880:@11`2R0@L0X04609P21P2A0@H0[@L>0:/32P2V0@L0W@4709D21P2:0@D0OP4507H2101d
0@40M@H202770P03003o00Wooooo00P0J:Pl0:0Pl03oP000^3Rd0:0Pl03@D7P0oh000=1@N1L0oh00
00<0d51h0?n0003oP0000P3oP0001@3@D7P0j6Pl0?n0003oP000j6Pl00@0oh0000@0X23`0?n0003o
P000d51h1@3oP0000`3@D7P0oh000?n0000K0?n00004052@N000o`000?l0003o00Sooooo0`00o`00
B`2GbG/0UIj[09RL[@0Y=5H03Q]90411G@1lJG80QFUd091_NP2JLh00WgEo09I`M`2cXJD0/:2Y0<6^
]P2[SY00[XZ40;RGR`2dUXT0ZI2308ioN@29OGX0Y9J<0<2ZV`35[j00ak6S0<Zg[03>_kP0d<>l0<g2
^P3;`kX0c/Jn0=3:a03@b/80dLg80=C?cP3@c</0cL_80<k:aP3>bLH0cLO30<S4`@38alX0Jh6U095S
P`3151d0bQ0G0<QGF`39Y:T0]j6c09eXQP2d4b80]0L@0:M<D034^kl0Uin^04HlHP282a`0W08=08L;
601SF7`083ae01XgK@1<J900LHRT069nTP27WJX0NHZD05U/PP0:74l00P]60049@@013D007S1?03n>
>`0;003o00Sooooo0`00o`000`2h>;@0X23`0:0Pl0090:0Pl0030=1@N02h>;@0d51h00`0X23`0P3@
D7P30;Ph]0030?n0003XJ3`0oh0000P0oh000P2P8?000`3XJ3`0oh000;Ph]0030:0Pl0090=1@N03o
P000^3Rd0=1@N02h>;@0X23`0=1@N03oP000j6Pl00l0X23`2`00o`0;ooooo`002_ooool0=011Y`l0
ZiV@0<[Bf`2LZkD0L71f04dg@03Fen00=C8m02882P1iDR@0Ia/<08`63P2W1@d0]0D=0;P62`2j1PX0
_@H:0<X:3P3;2@d0`0H:0:`1202/0P/0Z@<:0:T52`2_1PT0]PD90;D5302h1`h0^@L=0;d94@2g3AH0
G1LJ0;nm_`3Ph^<0h^?R0>?ShP3PeMD0]faW0<QSF@2nJF00W81l0=cFe@3Sh^40hN7R0>GQi03M_Kh0
XRT`0;TA6@1L5AT0_Kfo0=oNh03Pgn420=kNg`0O0=Bf^02B8BL0/``D0;H83@2h1P/0_@T?0;L6302l
1P`0_@D=0;`42P2h10T0/@@80:L21P2O0@@0X@470:811`2T0PP0X@4609l11P2L0`X0ZPH>0:h53P2V
0P/0V`4609421P270@D0N`440782101]0@<0LP`802?;1`03003o00Wooooo00<0P<000:0Pl03XJ3`0
0`2P8?001@3XJ3`0d51h0?n0003oP000j6Pl01@0oh0000<0j6Pl0=1@N03oP0000`3oP000102h>;@0
d51h0=1@N03@D7P50?n000030=1@N03oP000oh0000D0oh000P3@D7PL0?n00004052@N000o`000?l0
003o00Sooooo0`00o`00B`1/hET0Vj>b08Z>XP0843P00PU002LZE01gIW<0PVYd08m^N@2EKg/0VFii
09ebN`2lY:X0YhjE0;jVZ`2WR8P0ZHEn0:n=Q02_Sh80YH]n075UI01`JFP0UhUo0;jXV@32[Y`0aK2P
0<VgZ@38_;40cl>l0<g2^P3<a;T0clO00<k8a@3<b<<0d/o:0=GCcP3BclX0d<g:0<g8aP3>b/L0c<S5
0<W5a038alH0][g:065ZU02U>dd0_aPL0;/M7`2]:Bl0Z2H`0:XV;@2_6Ql0Z1LI09Pk>`2bY:L0VJ6/
04ICM@1h9d40VP<>0945402`P8/0_/WG0;_;f@2jbMD0/L3>072:Y@0iEgd0FGRE05M_R0014D/00@e2
00`K@00dAEP07c=8051`C`0;003o00Sooooo0`00o`000`1@T7P0X23`0:0Pl0090:0Pl0030=1@N02P
8?00^3Rd00d0X23`00@0d51h0>QX?02P8?00d51h2`3oP0001@3@D7P0X23`0:0Pl03oP000j6Pl00<0
d51h0P3oP0000`3@D7P0X23`0:0Pl0020:0Pl080oh0000@0X23`0=1@N02P8?00^3Rd2P2P8?000`2h
>;@00?l0003o0009003o00_ooooo000:ooooo`1E04:W3`3;^:d0b=7I08bKX`1_KgD0GDYC0=?Gg`0S
8RX08@L509=X<`1R2`@0T08:0:`53@2f1P/0_0L:0;d82@301`/0b@P@0<P93P2j1@X0[@8:0:/12@2_
10/0/0@90;@62@2f1PT0/`@<0;<3302h1`d0^@T?0;L94P1h3A<0N6=Z0=WGf@3QhN80gn7P0>;Ph03X
g]T0k]kI0>[Of@3Wgmd0hn3N0>3PgP3Nh=l0h=kP0>G7b`2W<3L0_@lE06X:3P28PX@0fm[L0>7Oi03P
gn@0g]gQ0=c:cP2NA4`0/@hF0<8;3`332@l0`0T>0;X53@2h1@d0^@<=0;`43@2f0`/0/P@<0:/12@2Q
0@D0X`470:D11`2X0@L0YP470:@01`2U0@X0[0@;0:h4302V0@`0W04808d1201o0PH0N0440701101X
00<0J0T702NY1P03003o00Wooooo00<0P<000:0Pl03oP0000`2P8?00103oP000d51h0?n0003@D7PF
0?n000030:0Pl03oP000oh0000/0oh0000@0d51h0?n0003oP000X23`1@3oP0000`2P8?00oh000?n0
000J0?n0000408300000o`000?l0003o00Sooooo0`00o`00C01Ig400VifZ05ILMP021Rh00@Di020T
D01iJ7H0QFYe08i^N02DKGD0VW1e09edNP2SPhL0_:>X0:B4R02WQ7h0YX9j0:V4N`2_SH00/9>20:VB
Q@2RSH40/YZ=0;jVUP31Zi/0a[6R0<NfYP39_K40c<6i0<k5_@3;a;/0cLO00<_7`@3?b/H0e]?>0=OE
dP3HeM<0eM3?0<k<b`3<b/X0blW80<S5a037aL80a/?50;Be`P2[WZP0aYZF0<JHT02oVI40_iZD0<2O
VP2nWY/0]iVF0;RYZ02UZJd0XZnl06MkU@1E=UP0TPHH09T23`2E=D40clgE0<3=f@2hb]H0QY^]04AM
QP036F8021mK06EoU@087DT0;T1I05ESIP1FHV40:CU606=ZJ@04lP8:003o00Sooooo0`00o`000`1X
Z3`0X23`0:0Pl00:0:0Pl0030=1@N02P8?00X23`00d0X23`00<0^3Rd0=1@N03XJ3`0303oP0030=1@
N0030;Ph]02P8?00X23`00<0X23`00<0^3Rd0=1@N02h>;@00P2P8?00103XJ3`0oh000=1@N03@D7P=
0:0Pl00302S8?000o`000?l000P00?l02oooool000[ooooo05D0AjTB0;>MU@36dMP0WJfe05eLHP1b
HFX0b/kH01LD7@0P1`@0Tf@_07D:1`2I1@h0[0D=0;P6302o20`0`0T;0<4930311P`0`@T@0;<32@2^
0`/0[P8:0:`21`2^0`P0/P@:0;852`2b10d0]@D>0;L6302g1`l0]`TA0:D@5`1U4Q`0ZhN@0>3Cf03P
eMP0h=;H0=g<d@3Ga<T0e[o60=Zl``3D/k/0cZfc0<nZ/P3<W:L0_fYe0:/G802m2a40R@`B04Xf>03G
f=X0h^;V0=oOh`3Ogn40h]SK0<>5RP2_5Q/0b@hA0<D93`2o2@l0Z0<90:X32`2a0``0/P8<0;422`2]
0P/0Z0480:<21P2U0PL0YP470:X2202b1@/0Y`460:L21`2/10/0ZP<;0:H12@2M0@L0RP8707H11P1f
0@P0KP4506H10P1T1PH0;hP700<00?l02Oooool01020`000X23`0?n0002h>;@20:0Pl0040;Ph]03@
D7P0oh000>QX?1L0oh0000<0^3Rd0?n0003oP0002@3@D7P01@2P8?00j6Pl0?n0003oP000d51h00D0
oh0000<0X23`0?n0003oP0006P3oP0001020`0000?l0003o0000o`08ooooo`<00?l004`0<NPQ0:2O
Y`0_=5800PH^00lB?@0U:Dh0NfIf08MYM`2<J7D0Tfag09ecO02NLgd0XGEl0:IjO02SN7T0Y7Uh0:1g
L@2WPW@0/Y>50;>HR02hWXl0^J6?0;fTU02oYYL0`ZZH0<F_X038]JP0akb`0<[0]`3=aKd0cLNo0<_6
`03:a/40d/o;0=GAcP3Edm00emGD0=?@d@3;b//0b/[80<_9a@38al80a/K20<;2`@34`L40_[fl0;bi
^02i][@0];2_0;6/Z`2_ZJP0[:FT0;:^[P2SX:D0[Znd0:NY/P2Z^</0@T=/08HE;@2K0Q00R@TE0<BY
/`30cMH0^LWD07nCYP1_Pil01aYD00<GD01PMXL0H75h05e^K01LJV@0F6EW020d@01^Ng/05=0?2P00
o`08ooooo`<00?l000<0D91h0=1@N02P8?006P2P8?000`2h>;@0j6Pl0?n0000@0?n000080>QX?02P
8?00X23`0:0Pl03@D7P0X23`0=1@N02h>;@30:0Pl0040?n0003XJ3`0^3Rd0=1@N0`0X23`00<0D91h
003o0000o`002000o`0;ooooo`002_ooool0@P14Y@d0X89h0<_Af02>X:@0F5]M08f1R@2d^<<04PXA
03/M2P26DbT0L`D709h43P2/1@/0]P@<0;d73@3120d0`0L:0;X62P2c1@X0ZP480:X22@2Z0`T0Z@<8
0:/42P2_0`X0/`D=0;@43@2d1@h0]PL?0;H73P2g2Pl0^PhD0;H?5`2Z5b40]3]70;0kB02_=440[B/h
0:PQ;P2^8c40[AhZ0;8K:02b62@0/1PR0;8E8@2g4QP0_Q4D0<HA5@2`5AP0>@@70;no``3RhnH0h^?W
0>7Ri@3Pgml0gKjo0:lb=0313A00`0T=0;T42`2`0P/0Z@880:P11P2Y0@P0Y`470:D11`80X`470140
Y`890:H1202Y0PT0]0H=0:h2202^10X0[@@;0:P32@2W0PP0WP4608h120230@L0O@8606l1101X0@<0
H@@303671P03003o00Wooooo00L0P<000:0Pl03oP000X23`0;Ph]02P8?00d51h01X0oh0000T0d51h
0;Ph]02P8?00X23`0;Ph]03@D7P0X23`0=1@N02h>;@00`3@D7P50?n000030=1@N03oP000oh000080
oh000P3@D7PK0?n0000408300000o`000?l0003o00Sooooo0`00o`00C00ZgQ<0Zj>T01HL?00G6C@0
DdUM03PdC@1kJGL0PFEd08=MKP2>IG80VVmj09e`N`2OKgT0Y7=j09iaL`2QM7@0Y7Uf0:^6N`2_Sh00
/iJ60;FHR02iWhd0_::C0<2UUP31ZiX0`jfQ0<JdZ037_[80bKne0<_2^`3=aKl0bL6m0<g9a`3Cdm40
clo>0=?Ad@3Ad=40dm;C0<g:bP3:b<T0b<O60<;2_`2i_l<0Y;2k0<JW/037Ti`0`X>=0<9dP@2jJ7<0
]UeY0;1DH@2`CU`0Zd]D0:Q9EP2gGFh0[UQ/08`mF01o=e40UAd_09X2402?0Q00XUQX0<Bjc032a=80
Wj^f09JW]01jS9d0D6=g07:0Q`1_Ng`0IFi_05YXJP0[?5004RHn05EXJ`0[Yb@:003o00Sooooo0`00
o`000`1@T7P0X23`0:0Pl00J0:0Pl0030>QX?03oP000j6Pl00X0oh0000<0j6Pl0=1@N03@D7P03@2P
8?000`2h>;@0oh000?n000030:0Pl0030;Ph]02P8?00X23`00P0X23`00<0D91h003o0000o`002000
o`0;ooooo`002_ooool08`16Y0/0R69F0<_=e02O/;D0DDiA0:NJX@2NXjd05`P<06Q59@1d>1`0PP@=
0:023@2]10/0]@D=0;h73P302@`0_PH80;X82P2^0@L0Z`890:H11@2W0PP0X0460:<11P2`0`/0]@@=
0;<43@2b0`d0]0@>0;P74@2e20l0]PXA0;d=5P2k3Q@0]@hE0080]a8G0300^a@G0;/B602l4aT0^Q8H
0;dD602l5AL0^ALJ0;LF602h5AD0^aDE0<HG6@2l6QX0GP`>09N?TP3Ri>H0iNSZ0>CTi`3Qgn80imWK
0;ACEP2n3a00_0T=0;@42`2_0P/0Z`890:H10`2X0@H0YP060:@21P2P00H0XP460:L2202T00L0Z089
0;453@2`10/0[`<;0:h32`2X0@P0Y`8909h1202A0@H0Q`4607/10`1^0P80IP4206420@0^PP43003o
00Wooooo00<0P<000:0Pl03oP0000P3@D7P0102P8?00d51h0?n0002P8?0Y0?n000030=1@N03oP000
oh0000<0oh0000<0d51h0?n0003oP0006@3oP0001020`0000?l0003o0000o`08ooooo`<00?l004`0
:]/<0:^JU@094Bd0C4UG05Y?F@18@5<0N6=_07aNK01oFFT0TVMc09M]NP2=JWd0V75n09e]M02LK6h0
WgEa0:IlMP2XPGL0Z8Mg0;2BP@2cUhP0]Ij@0;VQT`2nYiP0_jZM0<:_XP32/j@0`kZ_0<No]03:`KP0
c/Fn0<K2_03<bLL0cLg90=3@cP3@d=40dM3A0<k>c@3:blX0bLS60<K5a033a<<0][k804eVT`2RBf00
^1hV0;HL802e7B<0/QlV0:hR8`2Z9bL0YbPX0:<X9P2T:BL0YBP[0:4V:@2K7bL0UATS098D7@2A31D0
T0PC08/:6`2252X0PR@j08QRK@1mRI<0Q9FH07R6R@1cO7h0LWim06E`M@0W=eD00@Xh0049<`0a@e<0
;Yh/2P00o`08ooooo`<00?l000<0D91h0:0Pl02P8?006P2P8?000`2h>;@0d51h0>QX?00:0?n00003
0=1@N02P8?00X23`00<0d51h00<0j6Pl0?n0003oP0000`3oP000103@D7P0oh000>QX?03@D7P30?n0
00030;Ph]02P8?00X23`00/0X23`00<0N5Rd003o0000o`002000o`0;ooooo`002_ooool0E@19YP`0
V71V0<_>eP2<Vj80F55I0;jc_027RiH07`X<09ee@@1V7`h0T@H>0:L43@2/10/0]`L?0;`63P2o1``0
^PD;0:l22@2V0@H0ZP890:T2202Z0`T0Z@480:X22@2`10/0/@@90;<5302d1@h0]@D?0;L8402a30l0
[18@0:hH4`2]6aH0[b@N0:`[8@2[<BT0]D<l0;M:@`2lDd`0_EeE0<5VG@34KVD0_FeT0<1`J@35MG00
bWUc0<igLP3AO7L0YgE`0:fTX03PhN00hnCT0>3Qh`3Qh>@0hmgP0;EiN@2Z7AT0[18A0:P:3@2W1@/0
Y`880:H11P2X0@P0YP470:@1202T0@T0Y@480:D11`2U0@X0Z0890;862`2c10/0/@<;0:/22P2[0P/0
Z@8=0:412`2=0@L0OP8407d11@1a0@<0HP0105h20P0kT@l00`00o`09ooooo`030830002P8?00oh00
00<0X23`00@0d51h0?n0003oP000j6Pl6P3oP0000`3XJ3`0d51h0=1@N0060=1@N0030?n0003@D7P0
j6Pl00P0oh0000<0d51h0?n0003oP0006@3oP0001020`0000?l0003o0000o`08ooooo`@00?l004/0
YHUl00`@;01SFFH0EdYE04]8F@1_Gf`0NEUV08ENK02@IG@0LEQe01LJD@1AAf`0UfYb09][K02SMG@0
YWMe0:ElM02/RGX0/Y620:^AQP2HRWl0/Z2C0;ZTV02kYi`0`JfQ0<6_Y@32^:l0a[bc0<Ro]`3<a;d0
cLS30<g;aP3>cLT0cLc;0<g;c@3>c/d0bL_90<_<b`37a/D0aLC50<;0`P2o`<@0PHnZ0:bJY`36Ti40
b9fG0<RTX@30YJ80_JNR0;NWX@2eY:40]ZJS0:FJU@2bYjH0[J>T0;fe^P2XY:d0^:fb0;VRY`2_Si@0
Y7b109=RIP20A4h0LdiE09jW[@1iQhh0MX:506UfMP1WMGH0AUEX008<@00223X00@Td01<T?`0gJS/0
2P00o`08ooooo`@00?l000<0^3Rd0:0Pl02P8?006P2P8?000`3XJ3`0oh000?n000090?n000030>QX
?02P8?00^3Rd00@0d51h00<0^3Rd0:0Pl02P8?00102P8?001@2h>;@0X23`0=1@N03@D7P0^3Rd0080
X23`0`2h>;@90:0Pl0030;Ph]000o`000?l000P00?l02oooool000[ooooo0440BjH<08IHC@37bM40
SifT04i7C`3Ab]<0Ifif02lG3@2UMdH0E@P208`42`2N1@d0U`8809h3202f1`d0^`P@0:`22P2Z0`/0
YP470:/22@2Y0PT0[@880:l21`2_0``0XP8809l11P2`1Ph0]@H>0;<53P2W2a00R3Lb0<fHR`3H[J<0
g;^^0>C7_`3Wd<T0i]K?0>SLe`3Xg=X0im_J0>WPg@3UhMd0h^7N0>?Ph03ShN00h^7Q0>CQh`3ShN80
i>;R0>7Sh@3WinL0hn?U0>?Ti03QhN<0h>3T0>7Qi03Ldm80f;^h0<fUX@30T8X0Ze]I09X52P2V0@P0
Z0480:H11`020:D12@0B0:H12P2V0PP0Y08:0:@22P2^10/0]0D=0;442`2_10`0[@@=0:P2302R0PX0
S08807H10P1j0PD0L`4406H10P1M0P40?YHD0`00o`09ooooo`070830002P8?00d51h0;Ph]02P8?00
d51h0;Ph]00G0?n000040>QX?02P8?00d51h0:0Pl0<0d51h503oP0030=1@N0030>QX?03oP000oh00
01D0oh0000@0P<00003o0000o`000?l02?ooool4003o000O09FJJ00N8CH0HeMQ04Y0C`0C7400>cUD
07EKI`25HW00Q65g03<YDP19@g00<2]F099WL@2KJfd0XG5a0:QiMP2XOgT0ZXIi0;>APP2PQg`0SGme
09F7O02dXIH0^:FH0;j]WP2n/ZH0`;N_0<Fk]@37_[T0al:o0<c8a0020<g9a`0Z0<k:a`3=cL/0c<c=
0<W:bP3;blX0a/G50<K4aP30`<00`L710;no_`2l_[h0_;bk0;Vj]P2f][P0/[:e0:f^[`2ZZJ`0YjJY
0::SY02[/;40]ko30;2ja01mTjd0O9F]0<GEh@36dml0am;N0<GAfP36cmP0PhnP07j=V@2GXj/0V:>Z
07Z5R`1VMG<0HG=c01`[C`022d<01A<k028bB@0A8CP0@dY=2P00o`08ooooo`@00?l000<0^3Rd0:0P
l02P8?00602P8?000`3@D7P0oh000?n0000A0?n000030=1@N02h>;@0X23`0080X23`00<0^3Rd0=1@
N02h>;@00`2P8?020;Ph]080j6Pl302P8?000`2h>;@00?l0003o0008003o00_ooooo000:ooooo`0h
04fX3P1hAcd0`Ko809NV[01FE5T0em?L04iDG017:a/0MdHW05H60`2?1@h0V08;09012@2E0@L0/@D<
0;D63@2T00P0YP480:X2202/0PT0Z0480:h32@2`0@/0[`<:0:d42`2[0PX0]0D?0;@63@2e1Pd0Z`dD
05hd=@3LeMD0h]oP0>3Og@3PgMh0h=kP0>7Oh@3Rgn<0i=gS0>7Jh03Rf^00fmOL0=WDfP3MeM`0g]SL
0=cFfP3KdmT0g=GK0=gGg03MfMh0g]WO0>3Lh03Rg^80iMoV0>?Pi03Qh>D20=kNhP0K0=_IgP3Ie=P0
a:FW08d:402V0@T0Y`890:D11P2T0@P0XP4:0:@12P2T00T0W`4;09/12P2Y0P/0/0D>0:d22P2a1@l0
[@D>0:L22@2P0@L0S04708811P1l0@D0L@4306<10@1K0@80Ce<=00<00?l02Oooool00`20`000oh00
0=1@N0020:0Pl0040?n0003@D7P0d51h0:0Pl1D0oh0000<0d51h0?n0003oP0006`3oP0000`3@D7P0
oh000?n0000E0?n000040=1@N000o`000?l0003o00Sooooo1000o`00<@1i[T`0=S4m06UOHP0j<D<0
0PPg02d[C`1gGV`0P61`069>JP1BAFH0E4EZ03T_FP2CI6d0W6Q[09m`K@2TNG@0Y7af0:Z6O02`TH00
X8Yi0:FBQ02VU8L0[Yb@0;VWV`2j[Ih0^[:W0;ng[P34^[D0aKjh0<S3`03<b<D0cLS70<_8aP3;b<P0
c<_<0<_9c03;b/`0bLS:0<O5aP33`L80`L700;g0_@33a/D0_;o00;Zl_02g]kT0/;>e0;2b]02^/K80
0P2Z[:l06@2PY:D0X:JX09RPX`2Z]Kd0Y;G409FabP33eMl0a=?O0<KDh034d]h0_lkJ096V]P20Tj00
Pi6K07R6R`1aO800IgAc061bM@085D<02Q]504=IH01BHV009cI503U9D006i0@02@00o`08ooooo`@0
0?l06`2P8?000`3@D7P0oh000?n0000@0?n00080j6Pl00L0oh000:0Pl02h>;@0X23`0;Ph]02P8?00
^3Rd0080X23`00<0d51h0;Ph]02P8?003`2P8?000`1@T7P00?l0003o0007003o00_ooooo000:oooo
o`0D04ZU301L:R40/:fd09JSZP1BCU@0emOP02hb?01J?2H0B1L705H30`2>0``0VP4909T12@2Y1@h0
]0PA0;062`2Y0`T0Z`8:0:/1202^0PX20:/22@0o0:`21`2^10X0/@@;0;@5302c1@`0]0H?0;D63@2f
2a@0IaDJ0=c5bP3Sc]@0e;S00<bU[@31UIh0^HN@0;=fP@2bKWP0/6Qd0;9QL@2_FFT0/EMW0;aKJP36
GVd0`UIT0<QKJ@38Ff/0a5Y[0<AOK`31HG00`FYg0<QhQ@38OH/0c8RF0<jEXP3:W:T0c:Ze0<Za^`3;
][l0`JBZ090H7P2V0PX0Z08;0:H1202U0@P0Y08:0:<12`2S0@d0X`8<09`22P2S0@T0Z`@;0;453P2b
1`d0Z`@;0:L32P2O0PT0S@4708811P1k0@H0L@4406@10P1J0@40Ce@<00<00?l02Oooool00`20`000
oh000:0Pl0020:0Pl0030?n0003@D7P0d51h01H0oh000P3XJ3`40=1@N0030;Ph]02P8?00X23`0180
X23`0`3@D7P00`2h>;@0j6Pl0?n0000E0?n000040=1@N000o`000?l0003o00Sooooo1000o`00C01K
aC@0HUYR06QOI@0/9c/00PLg02LVCP1fG6`0PV=d044eE@1hI840<BYI04XjH02DHf`0VfU[09m_K`2R
MW80YGYe0:Z4N@2`TH<0W8Mh0:VHS@2RT8D0/Yj@0;VXV`2j[9l0^k>Y0<:j/`33^;H0`[Zf0<S3_03=
bL@0c<S60<[6a`3;alH0b<O90<S8b`3=b<d0bLG:0<C4aP2l_kl0_l720;Zn_@2h_;l0^kk10;Ri^`2d
];T0[[6d0:jb]02]][L0Z:j`0::VZ@2OXjD0/KVh0<SAeP2IYK@0PIR/04QWQ@34e^80a=;N0<?Ah035
d]d0[[c;03eEK@2FZ;@0W:^b07F7RP1jRHX0IG=^05maMP044Sl0<4=L05U[J01FIF<0:3Q:02<iC006
aPT9003o00Sooooo1000o`000`1@T7P0X23`0:0Pl00G0:0Pl0030=1@N03oP000oh000100oh000`3@
D7P01P3oP000d51h0:0Pl02P8?00d51h0?n000X0X23`00<0d51h0:0Pl02P8?00202P8?000`1@T7P0
0?l0003o0007003o00_ooooo000:ooooo`1004^V3P1=6A40WIRM07j8S01PG680b<_B01<B5`1N?RP0
?0@107442P2I0``0X`8=0:X33@2U10h0SP8709d52`2W0PT0[@8:0;822P2c0`T0/P890;@32P2b0PP0
/0880;852P2b10`0/`8=0;@53`2e1Pd0]PLA0:d<5@2h;SP0]2Hc0;8J:02c5240/@lL0;0>6@2b3QH0
/`hH0;@B6P2e4AP0^@lI0;h>5`3;4QX0da8J0=LC5`3H4aP0e14I0=@A603B41P0ca0H0<P=5P3431L0
aPhK0<TA6`303a/0^PhL0;DC8P2W5RD0XQl]0:<Y=P2Q41/0Y`8:0:H12080Y04701<0XP470:<22P2S
0@X0Y0490:@12P2Q0@L0Y0460:d3302c1Pl0ZP<;0:@22P2K0@P0SP460801101i0@<0L08306810@1I
0@00D5@<00<00?l02Oooool00`20`000oh000:0Pl0020:0Pl0030?n0003XJ3`0d51h01L0oh001@3@
D7P00`3XJ3`0oh000?n000020?n000030>QX?03oP000oh0000T0oh00203@D7P00`3XJ3`0oh000?n0
000D0?n000040=1@N000o`000?l0003o00Sooooo1000o`00C00Yg1D0KV5X06IOJP0Q7SL010/i02`/
CP1aFVH0PFAe03L_C`1nJhT04A=:06]BKP2AGfH0Vf]/09i/L02RL700Y7Ma0:Z3N02^SX40[YB509^7
O02WThL0^:>C0;VVV@2kZj40^JnU0<:j/P33^;<0a;Ze0<S1_@39a<@0bLG30<[8a`37aL<0alK90<W7
c036aLP0aLC70<;2a02l`;d0^[nk0;Zm_02j^kl0^;Vl0;Ff^P2c][X0/KBh0:V[[`2=TY<0Y:^/0:6X
Z`2T[K@0U9fT0:J]]P2NY;80/[o=0:jlb037e]h0a]?P0<;BgP33dmd0[kk<0::fa02GYk80P8jG07Z9
S@1_O7`0J7Mc06AeN00963h0CF=/05U/J`1?H6P041do00DE>@05Ya09003o00Sooooo1000o`000`1@
T7P0X23`0:0Pl00G0:0Pl0050;Ph]03@D7P0j6Pl0?n0003XJ3`03@3oP0030>QX?0050=1@N02P8?00
^3Rd0:0Pl03@D7P0102P8?001P2h>;@0oh000:0Pl02h>;@0d51h0;Ph]0d0X23`00<0D91h003o0000
o`001`00o`0;ooooo`002_ooool05@1<Y`d0C1@<09>9SP1OJFX0G5UO0:6RZ`0C1`T0ICXV04l51`1l
0`X0V`8<0:@1302Y0`h0U0<908001P2@0`/0WP4:0:T21`2b0PT0]@8:0;L32P020;L32@0X0;@32@2b
10`0/`<:0;D4302i1@l0^PH?0;/7402k20l0^PPA0;X64@2l2A80_@/B0;`;502o2a@0_`dF0<0=5P2k
31@0^@`A0<PA503>4A<0e18H0=H@503M5QL0gADG0=L?5@3F3Q80dP`A0<`94@3<2Q@0b@PB0</84@38
1Pl0b0PA0<@8403120h0]`D=0;04302Y0PX0Z08:0:P12@80Y@4801@0Y0480:41202R0PT0X0490:<1
2`2S0@T0X0470:801`2X0PX0/PL?0:T22`2R0@T0VP4608`11`200@H0MP4207020`1U0P<0G08105=D
3P<00?l02Oooool02020`000oh000:0Pl02P8?00d51h0:0Pl03oP000d51hC03oP000103@D7P00?l0
003o0000o`08ooooo`@00?l004`08NH>07MSH@1WHVl04A8/030fD`13?eH0LUeX07IRL`0g<E<0BD=[
01PICP25Gg@0TV1V09YXJ`2KIVX0WVQY0:5aK@2[Q7`0/Y250;FER02eVhd0]YnA0;JPT02kYYP0^ZVN
0;V]Y@30]Jl0`;J`0<>k]036_k`0bLG50<S6a037aL80a/?20<G4aP39alT0a<?50<;2a@30_l@0_L32
0;bo`02i_;d0^;Zi0;>g_@2EXk@0TXnT0;22U02ZIGD0YFeg0;RGX02[XjP0JGR@06=RQ02GF740Ye=Z
0:EBI`2MH7@0c/gH0<CDh033dml0`m?N07RAZ01iTJ<0SIjY09FSZP2@WZ<0Kgan06QfMP1ZMgX07Bi8
04mXLP0oE6H03a]30048=`022cD0478O2@00o`08ooooo`@00?l000<0D91h0:0Pl02P8?005`2P8?00
0`2h>;@0d51h0;Ph]00>0?n000030=1@N02P8?00X23`00d0X23`00@0^3Rd0:0Pl02P8?00X23`0P2h
>;@:0:0Pl00307QH]000o`000?l000L00?l02oooool000[ooooo05D0=;T704H@1@26Ngh0IVi`05]F
G01SHfT05`T805//7`1=00@0NP8909T32`2U0`h0Y`8=08T11P210@T0RP490:PC702S0@T0[P4:0;<3
302f0PT0]P@90:h32P2Q0PL0/`@;0;H32@2d0PX0_0H>0;d53@322@l0a0X@0;h63P312Q80_P`B0;T;
4P2b10d0_0/E0;h;4`2o2aH0_PXE0<<=4P3;41@0dQ0G0=<@5P3I4QD0fA8D0=PA503H41H0f14D0=@=
3`3C3A80c@TB0<`94P3B31<0b@P?0<463P2l1@d0_0H=0;<3302/0`/0Z@8:0:P12@2W0@P0Y@070:D1
1`2S0@T0X04909l22@2P0PP0Y@4:0:@1202Q0@P0X0090:<12P2^1100Z08;0:00202I00P0R`480801
201c0@<0K`8306L10P1M0@40CD`700<00?l02Oooool0201@T7P0oh000:0Pl02P8?00d51h0:0Pl03o
P000d51hC03oP000103@D7P00?l0003o0000o`08ooooo`D00?l004/0PVIG06APK`0>3RL0C4AG05U>
G`1^F6<0I5=Y03ThH00A5e00A3UT07UFIP1lF680V6I/09eVJP2LJ6T0Y7=b0:^3O@2aSh@0]9J70;BI
RP2gWhl0]j6C0;VVV02fYi`0^jnV0;jd[@32^K@0`k^g0<Jo^`38a<00b/K60<G4``33`L00`/;20<G5
a031`L80`l;50;fo`@2l_[d0_/2o0;Zj_P2c]k`0L8^Z079SS02S9d80]0dM0;X:5`2g2QT0[Q<T0;4k
C02RJ880CSeY08@_B02M1QL0YP@A09P86032VJD0am?P0<GChP34d^40WJo1096U]02=WjT0Q96I07^7
S01aO800JWUi06MhMP13DF<04R==008<@@011cd00@Le00TG>@0ZKcD02@00o`08ooooo`D00?l06P2P
8?0>0?n000030>QX?03@D7P0X23`0080X23`103@D7P40:0Pl0030=1@N03oP000d51h01<0X23`2@00
o`0;ooooo`002_ooool0<00X`@@0CQ@<089cM01GFe/0H5aN03De>@0T5a80AQPA05@22@1n10d0S`89
0:033@2V10d0R@4607l22@1g0@D0SPL?09T2202[0`/0[@8:0:h22P2d10X0[`@;0:021P2e1@/0^@@9
0;T52`2h10/0``/@0</<4P3=3A@0aPX@0<@=4P2n2Q00^PT@0;X:4@2l2A@0`0XC0<<;5P363QL0bQ0D
0<`@503<3Q@0dQ0G0=LC5@3J51D0fA@F0=PA5080fA0C02<0ePhB0<l:4P3=2Q80c0TB0<P8402l10`0
^P<<0;P32`2a0``0ZP890:P22`2W0@P0Y`460:H11`2T0@P0X@470:811`2Q0@T0V`870:02202Q0@P0
W@4909`1202N0@T0Z@<<0:T33@2R0P/0V04:08/12@210@H0L08306`10P1[0@80H@8104U70`03003o
00Wooooo00@0D91h0?n0002P8?00X23`0P3@D7Q>0?n000040=1@N000o`000?l0003o00Sooooo1@00
o`00B`1cXU`0Gemb01dJ<P18?Th0DTmU071LK01JBFD05B5G00P@C01XE700L5AO05i8D`29I6T0W6Q[
09eYJP2UM7D0Zh:00:j=P@2cUH@0/YR40;FLS@2gXI80^JNH0;VXW@2m/:X0_kBa0<>h]P33^[H0a;fi
0<K2_`31_l00a<?30<;1`P30`L40`/C40<72`P31`/<0_ko10;fn_`2j^kd0^kbo0:Zf`P0iFHd0XCaJ
0;h95P311a40_`H@0;/84@2_5al0Wb0]09<D9P2A83X0[d=G09`:602V0@d0XP<>0:55DP3@dM`0a]?Q
0;;2e@1NN980X;C209R[]P28UYl0Mh>906mnP@1ZNWT0IgQg04=CIP012D400@Q2004<?00>7c`0A5YS
03]3@@09003o00Sooooo1@00o`0I0:0Pl080oh0000<0j6Pl0?n0003oP0002`3oP0030:0Pl0060>QX
?03oP000oh000?n0003XJ3`0d51h0`2P8?00103@D7P0oh000?n0002h>;@50:0Pl0030;Ph]02P8?00
X23`00T0X23`00<0^3Rd003o0000o`001`00o`0;ooooo`002_ooool0E@0Mb`40A@X307AQHP1KFe`0
K6UZ00d=3`0a8QT0;P<405l22P270Ph0U08;09d22P2L0PX0SP4808L2201a10T0P1TM09L42P2/0P/0
Z0<60:L21P2a1@X0]@<90;L42`2m1@`0`0L=0;l73P3120h0c@dB0=<@4`3E41D0bPdC0;l940303Q<0
_PhA0;X@4@2i4A80a18E0<LA5@384AD0bQ8E0<0C602j81d0_BLU0;lY:034;BT0bc4]0<LZ9`3?9RH0
eADJ0=L>4`3D2a<0cPTB0<X74@371a40_@<<0;d4302f0P`0/0<<0:d32`2X0@T0YP890:@1202U0@P0
XP480:411`2Q0@T0W`4:09D21P2G0@D0WP8809l12@2M0@L0W@480:422`2V10h0V`8908L11`260PT0
O`8607L10`1`0@<0KP4206H20P1P2@800`00o`09ooooo`05052@N03oP000X23`0:0Pl02h>;@02`3o
P0000`3@D7P0oh000?n0000K0?n000<0j6Pl903oP003003o00Sooooo1@00o`00C01jXeT0A4=J02`Z
?P0g<dX0215404M2H@19?Uh00PU602l/F`1`FVh0M5YW05Y8E01jFUl0Uf=X0:1]K`2TM7D0Z81l0:f:
P@2`U8H0/iR60;FLR`2fXI80^:FI0;VYW`30/Jd0_KBb0<2h]P30^KH0`[^h0<K1_`32`Kl0`;no0<30
_`2o`<00_/?10;k2``2o`lD0_/;30;Nl_`2e^kh0^;fo0:>a`@10FY80YBe60<475@2o1Q00_0@@0:hG
7@2fRH/0QH2;06iRNP1c?UL0R2Hk09H;6@2O0`h0W08<090<6P3=/l00a]?P09j`a02;Xk80OI:M08RG
W`2;V9h0N8>806YjN`1/Ngd0IgIh05ASL@012cl0115102/oE`1<H6@0DFIU041=B`08iPD8003o00So
oooo1@00o`0H0:0Pl0030=1@N03oP000oh0000h0oh000`2P8?030?n000030>QX?02P8?00X23`00<0
X23`00@0j6Pl0?n0003oP000d51h4P2P8?000`0Xb3`00?l0003o0006003o00_ooooo000:ooooo`1E
01g:001:2`@0O6MX04]9A`1UH6<00P42030Q6P0W0@80G@8808L33P2F0P/0W04<09D12`2B0@/0T`8<
09D?6P2];3H0X`<:0:`22P2b10T0/@<80;832@2g10T0^P<;0;d6302n1@d0`@H=0<`:4@3B3Q<0cP`@
0<l=4@394A<0^10E0;8N702[=2d0ZT4h0:m5?@2_=2l0/B<P0<0M6`385AL0P0L:0:agM03S^K@0kLG1
0>o7`P3cbL@0llK20?J_/02i:Rd0bPdB0=H=503@2A00d0/@0<d;4@2o10/0_0D;0;<2302]0`X0Z08;
0:L12`2U0@X0Y0090:D0202R0@H0XP890:402`2N0@/0W04909P01`2K0@T0WP4:09d12P2L0@`0V@4:
09L33@2E0`h0O`8707P11P1_00<0M@850701101_0@D0I@8305h80P03003o00Wooooo00D0D91h0?n0
002P8?00d51h0:0Pl00;0?n000030:0Pl03oP000oh0001L0oh0000<0X23`0?n0003oP0000`3oP000
0`3@D7P0oh000?n0000R0?n000<00?l02?ooool5003o001<06K2B00j=DP0@CQ:020M?@032TD0>SQL
03LbE`053DH0HU=b06]HI`1BBeT0C3i;085FGP2GHVL0XFi_0:AeMP2XOWd0[HV10;6CQ`2bUhL0]Ib;
0;>OT02eXYL0_[2U0;j`ZP2o];80`;Nc0;jh]02o^KL0`knn0<?1_`30_kd0_L2o0;bn`P2j_l00_L74
0;g1``2n`/<0^kk00;Jk_P2d^;`0[[[6039DS02MAfH0_PPF0<053`2k10l0[A/T0;JLW02X/;00WjN_
07F5V@1OIhL0Id=T08h<7@2M0`d0V@<@0:USL@3=e=l0M8ZU08FO/@2HZ[@0TYjX07j8S`1cOh<0Lgn1
06]iNP1WNGL0Hg=h01`^B018G6P0GW9b05M[J`0kDed0;T9<01^i5PP00?l02?ooool5003o000307QH
]02P8?00X23`01H0X23`403oP0000`2h>;@0X23`0:0Pl0030?n000030=1@N02P8?00d51h00@0X23`
00D0d51h0?n0003XJ3`0X23`0=1@N0030:0Pl0030;Ph]02P8?00X23`00X0X23`00<0J:Pl003o0000
o`001P00o`0;ooooo`002_ooool03P0Nb`00B`X1075KG01?CD/0FeQJ00@10P0]6aL0;P4205h11@20
0@T0U08;09L23@2@0@X0T08;0P2A0@/0>02L10d0Y@870:X2202^10X0[0870;D42`2d0PP0^0<;0;d4
2`311Pd0`PL=0<T93`3A3Pl0e0h@0</D5P2L7A/0XEAA0<NITP3WcLT0j]SB0>OBcP3Ub/L0gKB`0<n?
R@31Cd/0N1XK04Y0A@3Ce=D0jNKV0>KTi@3Uhn@0inCU0>oKg@2nGf<0b1DK0=D=4@3@2Q00cP/A0<D6
3@2l10X0^@D<0;83302[0`X0Z@8;0:P22@2W0PT0XP490:41202P0@P0X@8809l12`2Q0@`0W04809T1
1`2J00L0W0470P2M0@P02`2M0PX0UP<>08D22@1l0PD0PP<:07@21P1b0@D0K`4406`1101V0P<0I@d6
00<00?l02Oooool01@1@T7P0oh000:0Pl02h>;@0X23`01/0oh0000@0d51h0>QX?03@D7P0d51h0P3X
J3`01@3@D7P0j6Pl0=1@N03oP000X23`00H0oh0000<0X23`0>QX?03oP0008@3oP003003o00Sooooo
1@00o`00C01QcCd0?30j0516E`0@43800PY103LjH00>43h08B=?07mRM@1oGV`0G4ED07A?F`2;De`0
W6E[0:5]LP2TM7L0YWen0:f8P02aTX<0/9F50;>IRP2eWi40_ZbS0;n`Z02o/Z`0_[Fb0;bb[`2o]k40
_[Vg0<2n_02o_[d0_Kfl0;bl_02g^[/0^Kjn0;c1``2j_l40^ko10;Fh_@2h^[d0]kVl0;>j_P1LNZD0
MV6;0;0?7P301@l0^`8?0:/9502ePX@0VJ2P0;>k`@2T[[X0`=7V03Y<N`1m=580TP<>09d33P2>6BX0
d/CB08:DY`1jSI`0TinY08bGX01nRXl0N8:5079oP01]OGl0IgUh06EfL`1KKfd0G6m`05M^M@0]@el0
0a8m01X]@`0[VRP8003o00Sooooo1@00o`000`1@T7P0X23`0:0Pl00F0:0Pl0030?n0003@D7P0j6Pl
00d0oh0000@0j6Pl0:0Pl02P8?00d51h0`3oP0020:0Pl0030=1@N02P8?00X23`0080X23`0P3oP000
0`2h>;@0X23`0:0Pl00?0:0Pl00307QH]000o`000?l000H00?l02oooool000[ooooo05D07l`004`:
0@1eGUl0?CXj05MDE@0;10<0:AHB03`2101T0PH0M`4408h22@2?0PX0S04808l12`2B0@d0U@8<09T2
2`2P0@L0Z@<:0:P22@2W0PP0]@D;0;H32`2h0``0_`D=0<@73P311`d0a@/=0<`<3P3;41<0Oa4C0<:Z
Z03[j>D0iNKT0>CTi@3Vi>L0iNCU0>CSi03QhN40i>;Q0>WNg02nZZP0@D940;c0``3VinT0i>?U0>_Z
k03YjN/0k>OY0=f//032:2l0fa4G0=4;4@381@h0_P@;0;/3302k1@h0]0<;0:l22`2/0P/0Z08:0:L1
2@2S0@P0XP480:412@2P0@X0XP8:0:412`2I0@L0V04609T11P2L0@P0W04909`1202H0@L0T`8<0881
1P280`T0P@460803201b0@D0J04506X21@1S0@<0I0h800<00?l02Oooool00`1@T7P0oh000:0Pl002
0=1@N1X0oh0000<0j6Pl0?n0003oP0001`3oP0030=1@N0D0oh000P3@D7PR0?n000<00?l02?ooool5
003o001<03CX8@1WDDl0E4QI00H8:P0E7TL09BiK0087?@1<@V00PEi/08QKK01nBe`0P4UG08iGH02K
IFX0WVY/0:=bLP2UNgX0ZHIn0:n>P@2aU8L0[iF90;BMT@2lZJ00`K6Z0;b`[@2l/Zh0_[>a0;bd/@2i
][D0^kVf0;^j^`2h^;/0^KRj0;Ri^P2i_Kh0^Kg00;^n``2j_L40];Zj0;Jk_02b]KP0/kRk09j^_`0l
E8/0XCI<0;`73`2m1100]@<@0:e9CP2b[k00WZR`09fX]01ON8l0QZ2o0511K02:2AT0UP8;09<64P2T
K7/0NY2V09V[]`25TiX0NXR?07R5R01`OWl0KWin079oP01YN7L0J7Mf061cM015FVd04B9@004=C001
2d<052A402ma<PP00?l02?ooool5003o0003052@N02P8?00X23`01D0X23`00<0^3Rd0=1@N03oP000
3`3oP0000`2h>;@0X23`0:0Pl0030?n00080^3Rd00<0X23`0;Ph]02P8?000P2P8?000`3@D7P0oh00
0?n0000B0:0Pl0P00?l02oooool000[ooooo00X07l`004d:001]EUD0@Sdo04]8B`0I40l07`X90441
101Y0PH0N0450P2400L0B@270@X0RP0809012P2B00X0U@4909h2202W0`X0Y@870:H21P2b0`X0/`<;
0;P32`3020/0a@P>0<@83P332@h0aPP?0;/C6@1^?Sh0i^;Q0>SXjP3Sh^D0hn;T0>3Qh03Rhn@0hn;U
0>CRi03ThnH0iNO[0>KXj@3Vj>L0f=_K0>OXj@3Ti>D0jN_[0>KXj03Wj>X0l=SM0;]2B`3H4AX0e`hD
0<X83@321Pd0_`H?0;/43@2g0`/0/`8;0:d22P2W0@P0Y`4;0:D12@2T0@P0X`490:402P2R0@X0XP4<
09L22@2D0@H0V@470:012P2M00P0W04909T22@2L10d0T`@;08/1202:0PP0QP4607/21P1U0@<0I042
06020`1J20800`00o`09ooooo`03052@N03oP000X23`0080d51h6@3oP0000`3@D7P0oh000?n0000A
0?n000030:0Pl03oP000oh000200oh000`00o`08ooooo`D00?l004`0<nDI08m^GP1>@Tl03PdX048o
F00>64/00PLm05I9H@1oGF`0QEe[085CGP21CET0SUQR09EQI@2KJFX0Xg5b0:EgN02VPGX0[Xf10:nA
P`2aV8T0]J2A0;^ZWP2m[JH0^:jZ0;V_[@2g[ZX0_;B`0;Vc/P2j];<0^KNh0;Zk^`2h^KT0][Zj0;Vl
_@2j_[l0`<740;fo``2h^kl0^K^n0;Fi_@2b^K/0/;Rm04iZV01iFH80[``I0;X33`2h0Ph0Z1DM0;nP
Y02V[kH0^lSA08VL[@1ZS:h0=4Ul07dW@P2F0`h0V08;08XJ8`23OhX0RYnZ09RW[`28UYh0MH>507:1
P@1_O7d0KWak06UiN@1LLg/0;45R00@AC0012Td00@a=00DCB00dB5d0=3Lg2000o`08ooooo`D00?l0
00<0D91h0:0Pl02P8?005P2P8?020=1@N0l0oh0000@0d51h0:0Pl02P8?00j6Pl0P3oP000103XJ3`0
^3Rd0;Ph]03@D7P40:0Pl080oh0000@0j6Pl0:0Pl02P8?00^3Rd3@2P8?000`3@D7P00?l0003o0006
003o00_ooooo000:ooooo`0^023<0@1;2P00KeQE04U3A00o>C`0:aXJ01`30`190P@0K08607@21@1j
0PP0NP0908412`280P/0R04908`12@2I0P/0W@480:H32@2T0PP0X0050;44302a0@/0]`D<0;l63@34
2@l0`0L=0<@83P352Q40VP`A085`K`3Vi^H0j>W[0>SXj@3Vi^L0hN;Q0>?Si@3NbM00^h2?0;5^P@2f
TJ<0cl_E0>7Uj03TinP0iNKV0>?Ui@80iNSY02H0i^OY0>cQi@33JW<0d1@L0=H?5`3=2a80`PH?0;l5
3P2l0``0^@<<0;H3302a0P/0ZP4:0:D12@2U0Pd0YP4;0:D12`2S0@/0XP8;0:022P2B0PP0T`<909T1
2@2O0@X0X04;0:01302L0P/0T@<70:@73P2Q1@h0S0<908h32P1k0PH0H`8305P00@1I0P<0E`/500Ka
0@800?l02Oooool00`1@T7P0oh000;Ph]0020=1@N200oh0000D0j6Pl0:0Pl02P8?00^3Rd0=1@N008
0?n000030:0Pl03oP000oh000200oh0000<0:<Pl003o0000o`002?ooool6003o000X0;:9J`1=?dT0
9R4c03/dBP032d006R5>04e4GP1oH6l0QUYY08AEG`24DU/0SEUR09ITI`2IJF/0Wfaa0:AeMP2XP7/0
[X^10;2@Q02aV8X0]9b@0;bXW02hZj<0]jn[0;J/ZP2g[Z/0^[:^0;Nc/02i]KH0^;Ni0;Rh^P2h^;/0
^[bm0;Zl_`2j_;h0_/330;fo``2l_/40^kk00;Nl_`80/kVk0280U:Nl045CR`2M:Ch0]PD@0;P33@2`
1@l0[5aS0;6a^@25V:/0a=KW06f<Y`1dSK<0ESUS09465`2L0Pd0TP@@09EUKP2DXj/0RYVN08:=T`1k
RXd0LH:106imOP1XNWd0DFQk01<XFP013E000@Y=004<C00B9eD0C65c05]/L00f?D002>D41`00o`08
ooooo`H00?l05`2P8?000`3@D7P0^3Rd0=1@N00@0?n000<0X23`0`3oP0020;Ph]0D0X23`00<0d51h
0?n0003oP0000P2P8?000`2h>;@0X23`0:0Pl00<0:0Pl00302S8?000o`000?l000D00?l02oooool0
00[ooooo04T07ld104P:001_FUP0FeIF02HP8@0]6a/06@010543101Z0@80K`8307<11`1f0@T0N089
08822`220@L0RP8809`3302P0PX0Y`8:0:`32P2X0PP0[P<:0;432P2`10X0]`D;0;/42@2j1@/0`PPA
0<T;5`2=2Q00SH>50>SWjP3XjN`0j>WZ0>OVj@3Wi^L0jNCW0;=VL0346bH0caDN0<TN9`2=7bd0PeAU
0:nX]03Jg^40h^CU0>CUi`3Vj>X0iNOX0>GTiP3BXJL0_1DM0<X<4`372@l0a@H=0<H7302l0`T0^0<;
0;D22`2a0PX0/0<<0:P22P2V0PX0YP0:0:@12@2T0@X0XP4;09h12P1n0PD0K`4308l32P2L0@L0WP4;
0080Y08=00/0V0<90:@63`2O1@d0N@4408H32@1m0`L0I`8405l00P1I0P80F@T401W50@02003o00Wo
oooo00D0D91h0?n0002P8?00X23`0>QX?00I0?n000030>QX?03oP000oh0000@0oh0000L0X23`0=1@
N03@D7P0d51h0;Ph]02P8?00^3Rd00H0oh000P3@D7PQ0?n00003052@N000o`000?l000Sooooo1P00
o`00C01dSc40CC]003/b@@0/9T002a1004M4I`10?5T0Nei]08MOK@25F6<0Q55J08mJHP2FHVP0W6Y^
09iZL@2TLgH0YGej0:b9P@2/T840/9J70;>LS@2gXiT0^JZR0;NZZ02cZZT0/JbX0;B`[P2d];40]kJd
0;fm_@2m_l00^;Vj0;Vj_P2k_/40^ko10;k2a030`LD0^ko30;Zn`02e^kh0/kVm0;>g^`2^^<40@EnC
08=DN@2^21L0]`<=0;<33`2P7BL0_j^d09:R/`1NOi`0Ni^`0;W<hP0c?6h0O1Xc09H24@2F0Ph0RR/e
0:RZ[`2;VIl0P8^>07B2Q@1]OX40JWj503aDLP065eL00@YD004:D0022d/05BQB061gP@1TN7T0Ffma
03I4B@0Cd0h7003o00Sooooo1P00o`0J0:0Pl100oh000`2P8?001@3@D7P0oh000?n0003@D7P0^3Rd
00H0X23`0P3oP0000`3@D7P0X23`0:0Pl00=0:0Pl0030;Ph]01@T7P00?l000H00?l02oooool000[o
oooo05H08<d104D;001hHV80FEEH01`B4P0F10D0:P8205T30`1[0P<0K@4507821`1d0PP0L@450801
2@250@L0RP4809T2302N0@P0X`470:H11P2V0@P0ZP490;422`2d10/0/`D:0:`2202g1`h0^`H=0<05
3`2P3Q@0MF=W0>CTj03Xj>X0inOY0>SXjP3XjN/0jnOY0<1[L`395A`0fA@H0=`E5`3B4aH0_aDN06`B
7`1jMGd0g>3Q0>?UiP3UiNL0iNKY0>?SiP3Obll0/BXa0<P?503:3180`@D>0<053P2o1Pd0^`D:0;H3
2P2c0@X0/@8<0:h12`2Y0@T0Z0890:H2202P0@T0X@4<09h12P2A0PH0PP4409421`2L0@L0W`4:0:<2
2`2Q0PX0U@8:09h53@2N1P`0T0@;08/220200`P0L`8606h31@1L0P80E0L201S40@800?l02Oooool0
101@T7P0oh000:0Pl02P8?0J0?n000030>QX?03oP000oh0000@0oh0000<0X23`0?n0003oP0000P3o
P0000`3@D7P0^3Rd0=1@N0050?n000030>QX?03@D7P0oh000200oh0000<0D91h003o0000o`002?oo
ool6003o001<05Bj7`1<>C<0CD5<01XH=`0[:dd0F4mZ034^D`1iGfl0PUeZ08EGI029F6<0SUYT09=P
J02FI6P0W6Q]0:=bMP2WOGh0[XR10;2AP`2_U8<0/YZ:0;JRV@2gZJ80/JFR0;2VXP2]Yj@0Xj2O09nQ
W`35bLT0cM3E0=OLh@30a<T0]KVl0;Vn_`2h_;h0_L?30;^o``2o`lD0^ko00;bm`P2f^[h0];Rk0:ne
^@20Tk<0C5N>09XJ;P2g0`l0]08>0:/64`2CEfH0_<_J04e_T02K_=00b][U065dVP1N=e`0S0@E09D2
2P2;2A<0Tg9f09BPX`2:VIX0JWan06N0Q@0cCW400QEK004>FP034Td05BMI008>A@16GW00J7an065g
O01BJW@0>4]A026N7@L00?l02?ooool6003o00030:0Pl03@D7P0X23`01T0X23`0`3oP0000`3XJ3`0
oh000?n000060?n000030>QX?03oP000X23`0080X23`00@0^3Rd0?n0003oP000oh00102P8?00103@
D7P0X23`0:0Pl03@D7P20?n000030:0Pl02h>;@0X23`00`0X23`00<0^3Rd06RX?000o`001P00o`0;
ooooo`002_ooool0A`0Pc@40B0/006iEEP1SFel040H601410@0]0@40H08306/10`1[0@D0MP8807@0
201e0@L0O`4908P22`2;0@P0U04;0:022P2V0PP0Y@470:81202X0@T0/@8;0;D33@2/0`X0ZP@:0;<4
2`2j0`/0`@D<0;D?5P1O?T80hN7T0>SXjP3VinT0j>[]0>KXjP3Vhn<0cHJ<0<LI8P3F4aT0da0E0=@@
5P3@41L0XA8I04/a=`3@dmH0i^KX0>KVi`3ShnL0i>?W0>?Jg@2_ADd0``lD0<H93`2m10d0_0<=0;`4
3@2o1Ph0_0D=0;L1302e0Pd0/08<0:P12P2V0PX0X`480:81202P0@L0WP4:09L11P2@00<0U`470080
W04900d0X04:0:022`2C0PT0V0<<09D42`2@10`0R08906`1101[0@<0K04306@20P1J1`<06LD20080
0?l02Oooool0101@T7P0oh000:0Pl02P8?0J0?n000030=1@N03oP000oh0000@0oh0000<0d51h0?n0
003oP000103oP0000`3@D7P0oh000?n000040?n000030=1@N03oP000oh0001l0oh0000<0D91h003o
0000o`002?ooool7003o000W0653=P1CB5D02``_04e6GP1QE7007Ae<07MOLP21FfT0QeYW08]IH`2>
FVH0Tf1W09UWK@2KJ6d0XFmc0:MjOP2]R880/I640;6BQ02cW8h0]ZBI0;BVWP2eZZH0[:BP0:fWY02O
W9X0/K:_0;Nk_P2d][`0a/kA0<O;d@2i_/80^;c00;Vm`02m`/D0_<;50;_1a@2l`LD0_Kk20080][Zn
0280/;Bi0:Vc_`0dDXH0Rd]X0;865@2g10h0/`8>09hY>024RJ40TJk608JT]P3:fN<0[[kF03LhJP1j
3bD0U@4=09<23P2A?DP0SHnC07Z7R`1KL7h07cUV008EH0014eh03bEK04=LMP0Q=ed02am?05]dOP1V
OH<0=4U/00@IB`0]AUd07VlN1`00o`08ooooo`L00?l000<0d51h0:0Pl02P8?004`2P8?00102h>;@0
X23`0:0Pl02h>;@20=1@N0030;Ph]03oP000d51h00X0oh0000D0^3Rd0:0Pl02P8?00X23`0>QX?002
0?n000050;Ph]02P8?00X23`0:0Pl03XJ3`00P2P8?00102h>;@0oh000?n0002h>;@?0:0Pl0030;Ph
]000o`000?l000D00?l02oooool000[ooooo05H08Lh204T90020IfH0CD=600d51@0D0@40?P<306D2
101V0P<0I`4407<21P1e0@P0M`4907P11`280PX0T08;09<02P2M0@X0W`480:41202S0PT0Z0490:d2
2P2`0P/0[P<<0:h32@2j1@`0c@`A0=L?4`3D5a`0E1HJ0=CCf03TiNL0j>WY0>OXj`3Yj^`0jNSY0=2N
X@2m8RT0d1<I0=0@603C3a@0da4D0;`D6`163180^;Vn0>?SiP3Wj>T0iNGY0>?Ti`3ThN@0_79g0;hG
70362Q00``L?0;l73P2i0`d0^0@=0;D32`2d0``0Y@<;09P;4P2c:380W@dF0:<33@2T0PL0X@8909h1
2P2I0@L0T`0509H2202L0PT0W04709h1202O0PX0V`8<08d11`2@1P/0U`D<0903301d0PL0K@8506d1
101Q0@40G@P401[60`800?l02Oooool0101@T7P0oh000:0Pl02P8?0J0?n00080j6Pl1@3oP0020=1@
N0H0oh0000<0d51h0?n0003oP0000`3oP0000`2h>;@0oh000?n000070?n000030>QX?03@D7P0j6Pl
01D0oh0000<0D91h003o0000o`002?ooool7003o001;079A=`18?d`03@h^065EI@1:B6@02Plo06iK
M01oFfL0R5]Z08YHI02;F640TEeS09]XK`2MJW00XFmb0:QkO@2[R840/I240;:CR02bVXd0/IjD0:nQ
V02]Y9l0/:RT0:nWY@2ETI<0WinR0<74a`2o`lP0cMGJ0;^ma02j^l80_;g20;Vm`@2k`L@0_L;50;g0
a@2m`LD0_Ko40;Jj_@2b^K/0/KJj0:bb]`1`QjH0F5F609hA902e0a00/`8=0:875`1oFG80XKW>0<SL
iP3:f><0a]OT04YLQ@1Z;dh0S`8?09<130273a`0V8B607b;T`0U?V`00QIU00<GH`0W?VX0GWF104UQ
MP0A:5@08CMQ03iGN@0U?V/00Q=H004=CP0I;U@08SDX00L00?l02?ooool7003o00030>QX?02P8?00
X23`01L0X23`00H0^3Rd0?n0003@D7P0oh000;Ph]03@D7P90?n000050>QX?02P8?00X23`0:0Pl02h
>;@00P3oP0001@3@D7P0X23`0:0Pl03XJ3`0d51h00<0X23`0P3oP0000`3XJ3`0X23`0:0Pl00=0:0P
l0030=1@N000o`000?l000D00?l02oooool000[ooooo05H08/h204X8001kGV00?cHi00`20P0J0000
AP8206430`1L0040H@4306h21`1b0@P0L`4707X11`270@T0R`4809812@2I0@L0VP4609/11`2O0@T0
Z04;0:h3302[0PX0Y`470;853P2l1Pd0e0lC0=hC5P3H4QL0L@/>0:JVZP3Zjnd0jn_/0>SYjP3XjNT0
i^GW0>C:c02X>3l0aADK0<d@5P3B3aH0dPlC0<dC601k31@0EdY?0=KKgP3TiNP0h^;U0=oPh@3Rh^D0
dZ^`0:@L90312a<0`0H@0;d53P2k1@d0]`<<0;@33P2Z0`d0O@<608`63`2N2AH0T`hH09432P2S0PX0
X08<09h2302G0@L0S`4608`11@2L0@T0W@4809d12P2M0@T0WP8;09X2302I1@d0V`H=09<32`1o0PL0
L@8507021@1S0P80G0@101[40P800?l02Oooool0101@T7P0oh000:0Pl02h>;@K0?n000030=1@N03o
P000oh0000<0oh0000<0j6Pl0:0Pl03oP0001@3oP0000`2P8?00oh000?n000030?n00080d51h2@3o
P0000`3@D7P0j6Pl0?n0000D0?n00003052@N000o`000?l000Sooooo1`00o`00901CN2@0?3=5028Q
?01@AUX0;S=H00lDA`1;@V<0O5]Y089HIP27EF@0RUQS08mNI02FIFX0VfU^09m^LP2WNG/0ZHB00;2@
Q02`ThL0]9^@0;2KT`2XVY40YYbI0:^QX02_YZ@0/ZfZ0;>`[P2ZZJ/0ZZb_0:Z//P2Z[K80]KNl0;bn
``2k_/80^[o10;Zo``80^l7602H0_<750;Jk_P2b^[`0[kJh0:^d]P2Q[[`0;TV1094oG02b11@0/`8?
0:`2402E=4H0R8jP0<cLiP3;fN<0bMOQ09V[``14>680P@XM09@2302?0`d0Se=H05i]Q@036V@00a]Q
03M@M01YOH<0H7Ao014XD`16G7H0=4MW004AFP013f000Q1M00<AC@0<74<0;cM000OT10H00?l02?oo
ool7003o00030=1@N02P8?00X23`01H0X23`00<0^3Rd0>QX?02P8?000`2P8?000`3@D7P0oh000?n0
00080?n000050>QX?02P8?00X23`0:0Pl03XJ3`00P3oP0020:0Pl0<0j6Pl0P2P8?00103@D7P0oh00
0?n0002h>;@>0:0Pl0030;Ph]01@T7P00?l000D00?l02oooool000[ooooo04P08/h2054;001lGV40
<b//01010@0X0P80CP8205d10P1I0@00G04206/11`1]0@D0L@4507h11`260@P0R00808l12P2C0@H0
UP4709T0202O0PX0Y@4;0:/22P2/0``0Z04<0:l22`2i0`X0d@lC0=LA4P3D3a<0U10C07=^L03VjNd0
inOZ0>;Ri03Ph^40h^?T0>GKf`2hKG<0_1PP0<h>5P3A3aL0d@lF0<d?5P2P4QL0:0H:0<?6c03TiNT0
hnCV0=oPh`3QhnD0gL[=09Ha>@2h31D0_PL@0;`63@2i1P/0]0<;0;L43P2Z1a00I`4409@73P2U0Ph0
VPD?07d21P2P0`d0X@4;09d12@2J0@P0UP4609L2202L0@L209`1200<09`12P2G0PX0TP4909P33027
0PP0R0<<07@10`1R0@80I0<506820`1O1@<0<hX40P00o`09ooooo`04052@N03oP000X23`0=1@N280
oh0000<0X23`0?n0003oP0001@3oP0000`3@D7P0oh000?n000020?n000030=1@N02P8?00oh0001l0
oh0000<0P<00003o0000o`002?ooool7003o001<06Z9<`0a:Ch0=C1;03/cD@0R9e806b1>02XYD@1h
GVh0OUES08QDH`2>FfT0SEiV09AUK02KK7<0Wfmc0:EjN@2YQ800/Hn50;2ERP2aVY00[i^C0:ZIT`2X
WY`0[:>P0;6YY@2g/K00]KBb0;:a[`2UXZ@0[Zfa0:2SYP2XZjl0]KVm0;Fk_P2g_l40^l750;_2a`2j
`LL0^/330;Nl_`2c^;`0/[Nk0:be^02W/kT0BfNF071CO02Y2QX0]@8?0;023`2K62P0k/KE0=[BhP3F
dN<0dlcO0=38h01A?V<0Q1``09413@2A0P`0QR/g045:M@047FH0?Eb006AkP`1]PXH0=DY/01<[E01Z
OXD0EVUm008CE@013U`00QAG02Y0H`0N;dH0=T=801bD4@H00?l02?ooool7003o00030=1@N02P8?00
X23`01H0X23`00<0d51h0?n0003oP000102P8?0;0?n000<0X23`00@0d51h0?n0003oP000d51h1`2P
8?020?n000030=1@N02P8?00X23`00h0X23`1P00o`0;ooooo`002_ooool0EP0Sc`80D@`0075FEP0Z
92D0304103420`1C0`<0F@8105D1001I0@80J@4606d11P1a0@H0OP4908L22P280@P0S@4:09802@2D
0@P0V04809h22`2R0@P0YP870:P22@2Y0P/0/`<<0<072`3@3A40cP`?0<d<4`2U3Q@0CSXm0<W>dP3Q
hn@0h^;R0>3Ph03Qh^80iN?R0=JZ[@2h9R`0d10H0=8@5`3?3AH0c`hG0;/C6`1;0PP0ShbB0>CWj@3S
i>H0hN;T0=oRhP3Of]X0XF=W0:TA6@2j1Q40^PH>0;L42`2e1@h0/`<=0:T94@1J0@<0JP@:08/53024
1@/0I08409/43`2P0P`0WP8909/21`2E0@L0U@4809/1202M0@L0WP4909d12`2H0@`0U04909X33@29
0PT0Q@8:07h22@1^0PL0G`4306010P1Q1@@0=8`60P00o`09ooooo`04052@N03oP000X23`0=1@N1/0
oh0000<0d51h0?n0003oP000103oP0020=1@N0H0oh0000<0d51h0?n0003oP0000`3oP0000`2P8?00
oh000?n0000N0?n0000308300000o`000?l000Sooooo1`00o`00C015/B<0:bDi04LnE00T8T@08bM=
02XZD00=4D80J5U^07aFH@23D5h0RUER095PJ02HIfl0WVee0:5cM`2WNgd0ZXF10:n?Q`2^U8/0/YbA
0:bHT02[VY@0[J6N0:nWX`2c[:P0[J^Y0:Z[[02c/K40[:V/0:nb]02[[Jh0Yjb_0;:h^`2d^[h0^;g0
0;_1a@2f_/40]Kfo0;_1a02j_l80];Zm0;6j_02[];L0Zk>h07f@[P19DXL0VAda0;D54P2b0Q00Z`HI
0:hZ@`2Q;d`0UbY6098UA02>8d<0R1Xd08d96P2B0@`0T04<088?7`0g<680;4Qi06^2S`1YOh@0BFIo
00TRD`18H7@0KX2006amP`0[?f8021eC02]6J01EKGH0:Ca803a=D00TX1/6003o00Sooooo1`00o`00
0`1@T7P0X23`0:0Pl00F0:0Pl080^3Rd00D0d51h0:0Pl03XJ3`0d51h0:0Pl00:0?n000050=1@N02P
8?00X23`0:0Pl02h>;@00P3oP0000`2h>;@0X23`0:0Pl0040:0Pl0040>QX?03oP000oh000=1@N100
X23`1P00o`0;ooooo`002_ooool0EP0Sc`<0C0T007AHF00P6A/05P8103l30P1C0P80DP4105410@1F
0@40I`4506/11@1`0@D0O@4:08D12`2600T0S04:09402P2B0@T0V04909h22P2T0@X0ZP8;0:X12@2f
0``0a@P?0<l<4@3;2Q00`PL>0<<94P2h3A@0AA0D0:V[[`3Mg^00hn?U0>7Sh`3Si><0i>?U0>cHfP2h
BE40cA8I0=4>5@3@3a@0d@lG0<dA6P2?3aP0GDM=0=oSi@3Ri>H0h>?T0=oSi03NhN00aJb^09XT;@2d
1a00]@D>0;D43@2d0Pl0/@<?0:d53P1k10T0B0T<05PD5P0o0P@0E04709X4402M0@/0W08909T12@2A
0@H0T@0509/1202M0@P0WP4909d22`2K0P`0T`8:08l22P2>0PX0O08807821`1a0P@0L08506@10P1P
0`80<HP40P00o`09ooooo`04052@N03oP000X23`0>QX?1`0oh0000<0d51h0?n0003oP000103oP000
0`2h>;@0oh000?n000040?n000030=1@N03oP000oh0000<0oh000P3@D7PO0?n0000308300000o`00
0?l000Sooooo1`00o`00C00aeA/07APX05I>HP0:3c80@SiJ03lfE0021Sd0:2QA07MGI`23Deh0REEQ
095RJP2GJW00U6ac08][LP2PNgl0Yh610:^:QP2/ThP0[IV=0:ZJTP2YWIH0YYbI0:jWXP2TXIl0XZFT
09fQY@2/[K40XJBV0:j`/`2^/;80YZ^^0:ja]P2e^Kd0^Kk20;c0a@2k`<@0^[o30;S0a02h`<<0];bo
0;2j_02`^K`0^lG90:Ze`@17HY00M5Il09`K;02T2aL0YPdE0:4>5@2L41L0T`lG08l@60293AH0Q@/F
08D:50262A40Q`PA07/<5@17>F00<U1n05EaR`0cC7D02BIL04EQN@1VNgd0KX1m06enOP1XNW`0HgMl
06EhN@1GKFl08SQ804MJG`12?CH6003o00Sooooo1`00o`000`1XZ3`0^3Rd0:0Pl00F0:0Pl0D0^3Rd
00@0d51h0;Ph]02h>;@0j6Pl2P3oP0030:0Pl0030;Ph]03XJ3`0oh0000X0oh003`2P8?000`3oP000
0?l0003o0004003o00_ooooo000:ooooo`1F02C@0`1@2@00I4=101D=3P0G0@80@P8205410@1B0@40
D@4005X10P1V0@D0J`0407410P1l0PP0P`8<08@12P2900/0T04909D22@2J0PP0WP490:@12P2Y0@/0
[@8;0;L43@352Q00b@X@0<<73@301``0_`L=0;`;4@1J1`/0JfY^0=3CeP3QhN<0h^CS0>7RhP3Rh^<0
jn7T0<5bM`3951P0d@lF0=4@5@3B3aH0dQ0F0;LH7P1;7280d]KJ0>3Si@3OhnH0h>?W0=gQhP3Oe=D0
VT1:0:l94`2a0P`0]0@=0;03402Z0@`0[0<;0:083@27=CL0cI2C05lN801_0`T0WP8<09/01`2J00T0
V@4:09<11`2E0@L0V@4809/1202M0@X0W04809<22`1n00D0QP8:08T32P1X0080E`0307421@1c0`D0
H08205d30@0cRPD2003o00Wooooo00<0D91h0?n0002P8?007@3oP0000`2P8?00oh000?n000040?n0
00030:0Pl03oP000oh0000@0oh0000<0d51h0?n0003oP000103oP0000`2P8?00oh000?n000050?n0
00030=1@N02P8?00d51h01D0oh0000<0P<00003o0000o`002?ooool7003o001=02gQ5`0]7bH0DD]O
00/?=01UEVL0FDMM00@5>`0623d0J4iU07e@G027F600V6Yc09M[L`2AJW<0PfQb08ebMP2XPX@0ZhV7
0:^@R02[Uhd0ZIZ@09jES02OUi40ViF@0;>c[`2n`lH0^[k50:f]/@2OXZ@0VYbO09bOY@2HW:40ZJjd
0;>h_02i_/@0_L;60;[0a02g_L80^l750;c2a@2g_L00];g00;_4a`2_^;h0/[k60;;5d`1VOZ<0QHNP
075SO02fWj<0_ZFT0;nXZ02lYjX0^ZR/09bCW`26Ohh0MFih08McLP2AMWL0SGYi075jQ@0V?V/05c=S
02Y5K01LLh@0L8:506ioO`1`P7l0KGn106YjO@1XN7H0I7Ed05IYM00H;dX0CVEY0459@@0<f@L01@00
o`08ooooo`L00?l000<0D91h0=1@N02P8?005@2P8?000`3@D7P0oh000;Ph]0050:0Pl0030;Ph]03o
P000oh0000P0oh000`2h>;@30:0Pl0030;Ph]03@D7P0d51h0080d51h5@2P8?000`3@D7P0D91h003o
0004003o00_ooooo000:ooooo`1F02CA101@3000IdE200X51@0D0@40@@8305D30`1C0P80D`8005/1
101X0@H0K@4606l11@1e1@/0Q1PO070220240P/0S@8:09@12@2I0@L0W@480:<12@2V00P0[08:0;<3
2P2o1``0a0X?0<07302o1Pd0_`P>0;d<4@1k3180;R<V0;Vl`03RhN<0hN7Q0>?Ri03Ui>D0iN7R0<bJ
W0306Ah0ca0E0=8?5`3B3QD0d0hD0<DC6P1L2a40/kFk0>;TiP3RhnH0h>;T0=oPhP3Sg=h0YfM^0:X<
5P2c1Q00/0<=0:d33P2Y0P`0Y`4:0:H43@2V:380V3Q308lR;02J1@l0X`8;09`1202K0@X0U`890980
1P2H0@P0VP4909d22@2N0PT0V`4808h2201l00D0Q0<=07h22@1i10X0H@8506l31`1/0P@0G04105/3
0@0eS@P2003o00Wooooo00<0D91h0?n0003@D7P02`3oP0000`3@D7P0oh000?n0000?0?n00080d51h
1@3oP0000`3@D7P0oh000?n000050?n000030=1@N03oP000oh0000<0oh0000<0^3Rd0?n0003oP000
1@3oP0000`2h>;@0X23`0=1@N00E0?n0000308300000o`000?l000Sooooo1`00o`00C@0<n0D0Bc8X
040lD`0S9D<0KeeS06iHI`0<2CL030dm075DJ@22EF00S5iZ09MYM@2JJgL0Tf]e08YZLP2LN7X0Yh20
0:J5P`2TRXD0Z9F=0::DR`2RUhh0VY:909NAR`2SXZ40b<[=0;Vk`02WZ:/0YJZZ0:Z/[@2OXJD0SiFJ
0:J][`2f^l40_L360;c1aP2m`lH0^kk40;g1a`2j`/D0^;o20;Fl`02oal/0^/370;S3b`2O[kd0X;S?
05n7[`25YKl0cN7Y0=3Mi03AgN@0cm[T0<_Hi01iSJP0Rj>h09>T/@2JZK<0UjJ]07b;S@1jR8`0MXB:
07:4RP1bQ8L0LXF507:5QP1`PGl0KH1n06f1P@0gCUh0FW9f059YLP0M<5H00@e202a4F`18EeL06jPC
00D00?l02?ooool7003o000302S8?03XJ3`0X23`01D0X23`00@0d51h0?n0002h>;@0X23`0P2h>;@2
0:0Pl0030=1@N03XJ3`0j6Pl00P0oh0000<0d51h0;Ph]02P8?000`2P8?00103XJ3`0oh000?n0003X
J3`50:0Pl0030;Ph]02P8?00X23`00l0X23`00<0P<00003o0000o`000`00o`0;ooooo`002_ooool0
EP0Td@@0C`d105<a;@080@40808104@20P1>0@80D04205@10@1H0@80I04606T11P1R0@<0MPL=08@;
5@1Q0@D0M`<:08h12P2D0@T0U`4909`12@2R0@T0Y0490:`22P2m1`d0a@X@0<07302l1`h0^`LA0;d8
4@312a00XA0F02X1102<S900h^7P0>?Ph@3ShN@0iNCV0>CRi03Pb//0]2T/0=0B5`3A3aD0dPhE0=8@
503=41H0S0hE07MbN03RhnH0hN;U0>;Ri@3Pgn80h=gQ0<:SZ02P5Ad0]0TB0;463P2/10`0Z0<<0:@1
2@2U0@`0Y@8@0:83402T0Pl0Z08=0:D2302P0P/0W@4809L22@2E0@P0V08909/1202M0@X0X08:0:41
2`2L0P/0U@8;09D33`280`/0NP4706l21P1R0P@0GP4206820`1M0P40>7X50P00o`09ooooo`03052@
N03oP000j6Pl01h0oh0000<0d51h0?n0003oP0000`3oP0020>QX?0H0oh0000<0d51h0?n0003oP000
0`3oP0000`3@D7P0oh000?n0000M0?n000030:R8?000o`000?l000Sooooo2000o`00C01PD2X0<Ra7
04<mD`1aGEh0L5aV02DN@`0?3cd0LeMZ089HI02?I6l0UVQc09Y]M`2KLWX0WWEl0:=jO@2UOGd0YH60
09j1O@2ORh80XiF<09R=Q02NU8/0WiJ?09F@R`2JUi@0VYZG09VJV@2X[Jd0Yj^_0:6TZ02@TiL0YZf_
0;Fl_P2h`L<0_<C70;c2a`2f_<<0/;Rn0;W0a@2j`<@0`lW=0;Bm`P2iaLX0]/G=086I]@2M]Lh0LI:a
0;WBgP3AgnP0d=cU0<kNi@3<fn@0bmWU0:g1e`1EMI@0O92R096OZ`27UI`0QYFH082>TP1gQ8H0MH>5
07F3Q01aPH80L8:50721PP1]OX00JWeo02m4FP0hDfl03Ae<004:A@012d803Qm304YPH`0RXQd5003o
00Sooooo2000o`000`3@D7P0X23`0:0Pl00H0:0Pl0050;Ph]02P8?00X23`0:0Pl03@D7P0103oP002
0=1@N0@0oh0000<0j6Pl0=1@N02P8?000P2P8?001P3@D7P0oh000?n0003oP000j6Pl0=1@N1H0X23`
00<0P<00003o0000o`000`00o`0;ooooo`002_ooool0EP0Vd`H0D0h204db;0070@40:P4204`3101<
0@80D@4105P10@1H0@00G`4306D21`1A0@<0MP<;08L32`1W0PH0J`8708h22@2C0@T0U`4909T12@2N
0PX0X`890:l42P2m1P`0_PH<0;`63@2m1`l0`0P@0<0940312a00]0dG05d6301NEE/0g]kP0>7QhP3Q
i>@0i>GW0>GTiP3Vg^00^UAK0<`D6`3B41T0d`lH0=0>5P3?41H0]A<K04l_=P3CeMT0h^?V0>3Ph`3P
gn@0g]kQ0=[?d@2H;SL0[PXD0;07402Z10h0Z08=0:@12`2R0P/0X08=0:012`2R0@`0YP8;0:<13@2Q
0@`0WP8909`12@2I0@T0V@4:09X12@2L0@P0X@4;0:H23@2V1Q00U0<;08T22@2>0PX0QP4808422@1h
0PL0L08506820P1L0P80D5@=0P00o`09ooooo`03052@N03oP000d51h01h0oh0000<0d51h0?n0003o
P000103oP0000`2P8?00oh000?n000040?n000030=1@N03oP000oh0000<0oh0000<0j6Pl0;Ph]03o
P0007@3oP0000`3@D7P00?l0003o0008ooooo`P00?l000/0Eg/V02<N=`1JCel0D4MG04]4F`13>EL0
3Pll07IKK`28HFd0SVI^09M]M`0209edO00o09ebN`2NMGT0XGUm0:1lOP2PQH80XI2709j=Q@2JT8H0
WiR?09nHTP2FT8/0WY^D09jMV@2IViP0ZJj]0:2XZP2/[;40TIBH09fUY`2a^;/0^l?60;c3a`2i`<D0
Zk>h0;Bl`P2ja<L0^L750;_4b02kb<h0^/WA0:>e`@2fbMX0FgnW07VM^P37g>X0dMkW0=3MiP3>g>H0
cM_W0<_Ii`29WkH0SjFg0;74d@2@WZX0P92F08FBU`21T9@0OHf>07:5P`1aPX40M8>306n2Q01dQ8H0
KWn1069hP@0P=5`00@a90048A`012T<01aQ200HG>@12FV40=8P_00D00?l02?ooool8003o00030;Ph
]02P8?00X23`01P0X23`00D0d51h0;Ph]03@D7P0X23`0;Ph]0030?n000030>QX?03@D7P0j6Pl00<0
oh000P3XJ3`40:0Pl0060=1@N03oP000oh000?n0003XJ3`0d51h0P2P8?000`2h>;@0X23`0:0Pl00B
0:0Pl0D00?l02oooool000[ooooo0380:=@705HC0`0m8Ah01P0003010@1:0P40BP4205<20P1I0P40
G08106@11@1R0PP0@P4206D42@1[0`T0D@4606P2202?0@T0T@0909L12P2L0PX0X0490:D2202e1@d0
^@H<0;P43@2m2100_0H>0;h73`2o1a00`@XB0;X=5`273AL0BS8j0=CDf03Si>@0hN;T0>CTi@3UhnH0
i^?V0<AmPP385a`0da<I0=<@5`3A3aL0d0hG0<HD7@1:3A@0`/K;0>7Si080h>3R0280gMgN0>3Kg`2J
CE@0ZP`F0:d63P2Z10d0Y@8=0:812`2O0@T0W@4:09`02P2O0@/0Y08;0:412`2Q0@`0W`4:09d1302J
00T0VP4809X11`2K0@L0X04:0:P33P2Z1A00XP@@09<22P2=0PX0QP070801201f0@H0L`4406L2101N
0@40Ce@=0P00o`09ooooo`03052@N03oP000oh0001h0oh0000<0d51h0?n0003oP000103oP0000`3@
D7P0oh000?n000050?n000030=1@N03oP000oh0000<0oh0000<0d51h0?n0003oP000703oP0000`3@
D7P00?l0003o0008ooooo`P00?l00200E9TT01lH:@1VFVL05QTl020UB@1QEFT03Phg071LM02<IWD0
T6Mc09E[M02DJg<0V6if09mcO02NLgP0XWQj09ikNP2NQ800WXf50:>DS02NTH/0X9RC09ZFT02HUH`0
ViVA09fLV`2FUYH0XZ6S09:FV02`/K80VYjQ09bSY`80^l7402X0^Ko40;Fo``2X/kL0][k40;c5b@37
d=@0]l780;c9d02ea/h0Uk?908>R`01ZS:l0Zl?F0=?Pi`3AgnL0dMoX0=7Ni`3:fn`0[[gK055CQ01m
I8T0OF9k09fCX@1nR900TZ6X07R6SP1iQh/0M8F407B4PP1`P840LH>407B7R@1GK7h05B]P004?D001
24P00@e101`^C@1;HV`0<DAD03M@G@18GDD5003o00Sooooo2000o`000`1hF;@0^3Rd0:0Pl00J0:0P
l0030=1@N02P8?00X23`00@0oh0000D0d51h0>QX?03oP000oh000=1@N0020>QX?0<0X23`00<0^3Rd
0?n0003oP0000P3oP0000`2h>;@0X23`0:0Pl0040:0Pl0030;Ph]02P8?00X23`00h0X23`00<0d51h
003o0000o`000`00o`0;ooooo`002_ooool0A@0We0L0DQ<4040Y:00;0@40@@<404l20P1<0@80DP42
05P10@1L0@80IP8506@32@0i0P<0>08304811@140080L08808d1202B00X0UP4:09X12P2R0P/0ZPH=
0:/6302g2100]`<>0;`7402m20l0_@T?0;d9402m2A80_0XE0:HB7@124a`0alS=0>7Ri03ShnL0iNCV
0>GSi@3Ui>H0cjFY0;hL8`3?51T0d1<H0=4D603?4QL0bQDJ06/>5@2NW:40h>7T0>3PhP3Ogn00gMgM
0=oNgP2YM7/0X18M0:d7402Y0`d0YP<=0:<13@2P0P/0W`8<09d1302N0@`0X@8<09l23@2L0@/0WP8:
09`12P0209T1200?09/1202L0@P0XP890:P43@2U1A00YPLB09l43P220PL0Q@<908422@1e0PH0J@83
05`20P1P0P80C4h700800?l02Oooool00`1@T7P0oh000=1@N00N0?n000030>QX?03@D7P0oh0000@0
oh0000<0d51h0>QX?03oP0001@3oP0000`3@D7P0oh000?n000030?n000030;Ph]03@D7P0oh0001`0
oh0000<0d51h003o0000o`002?ooool8003o001=04F_6`0Z82/0FTmM00D:=00J74@0KUMV03X^C@1G
C6P0S6Yi09=XM@2BIW80TFM`09Y`N@2OMWh0WGEj0:1fN@2LMWH0X8>00:6:Q@2MRhD0Vi2:09jDS`2O
Ui40V96;09JCS`2GV9L0UIND0:2RY02QXZD0]KJg0:^`/`2NYJT0^;g00;S1``2h`<<0^L750;[4a@2o
b/l0^<C;0;S1aP3;e]d0`LkG0:2c``2_am@0Mibn07^O_`2ecMd0d^3X0<oNj`3:fo40Y;7D07UZV@1d
:eL0R0h^09056`2<1A/0Pa@Z09AUL02BV9l0TIjU07Z6R`1kRHX0NXV907N6R01`PH80LX>802m4JP01
4Eh00PiH00HCB@0eC5d0Efi/05Q[J@0iBED0>55K05=KF@04lP801000o`08ooooo`P00?l000<0D91h
0=1@N02P8?006P2P8?000`3oP000d51h0;Ph]0060?n000040=1@N03oP000oh000=1@N0<0X23`00H0
^3Rd0=1@N03oP000d51h0:0Pl02h>;@30:0Pl0050=1@N02h>;@0X23`0:0Pl02h>;@04@2P8?000`0X
b3`00?l0003o0002003o00_ooooo000:ooooo`1F02SE201E5`P0<a/H01810@150P<0CP4104l10P1G
0@80FP4205l10P1T0@<0H`4304l3101F:2d0KCLl06X73@250`X0S`4:09812@2B0@L0U`490:<32`2Y
1@`0W@@70;46402h10l0^`LB0;/54@2k1a40^`P@0;/94P2m2Q@0]`lH05h:3`2GUid0h^?W0>3Si`3S
hnL0h^7V0>;SiP3NdmD0]VMV0<QSH038If80aVIR0<IXI036JfH0XfUW09jJW03MgN40gn3S0=cPh@3O
gn80gmkQ0<R]/P2:72L0[0TD0:d43@2[1Pl0Y`<>0:<23P2P0P`0WP<;09d1302M0@/0W@4<09T02@2J
0@X0V@4909T22@2H0@P0W04;0:42302S0P/0Y`@?0:86402E0``0VPD>08D2201l0`P0M`4607821P1Z
0P@0H@<306<20`1;B`L2003o00Wooooo00<0D91h0?n0003oP0002P3oP0020=1@N1<0oh0000<0d51h
0?n0003oP000103oP0000`2h>;@0d51h0=1@N0040=1@N0030>QX?03oP000oh0000<0oh0000<0d51h
0:0Pl03oP000703oP0000`3@D7P00?l0003o0008ooooo`P00?l004d0:ld@03@V:014?4l010Xh020N
A01aEF80JU5P048eD025I7<0SfAb09EXM02HK7L0VVih09eeO@2KLWP0W7=g09MaM02JOW/0VX=l09^:
P`2KSXL0W9>?09nIU02FT8`0V9BB09JGU@2GV9P0WZ6R0:6UY`2c^;T0YZf_0:2VZP2d^[d0][g00;c3
a`2h`<<0_LO90;S3a`33cM80`<[@0;[9d02hb=80/lSI07FH]`1IOZT0TKCA0<WLk02e`mh0Qh2_06i6
N`219eD0UPdZ09d55@2J1Q80S`@@0902302B0@d0RA0Q0:1mR@1oRXl0OHb@07Z:S01jR8`0N8N:07R6
RP1eQ8X0@EIe00<GE`0T>fX08SMH05UaL@1KLFX0FVi[02<fB016GV/0EFET017>2`04003o00Sooooo
2000o`000`1@T7P0d51h0:0Pl00J0:0Pl0040>QX?02h>;@0X23`0=1@N0@0oh0000@0j6Pl0?n0003o
P000oh000P2h>;@30:0Pl0030=1@N02P8?00X23`0080X23`00<0^3Rd0=1@N03oP0000`3oP0000`2h
>;@0X23`0:0Pl00@0:0Pl003052@N000o`000?l000800?l02oooool000[ooooo0400:=H805TM3@0d
7Q`07@4104d30`1;0000C`4205P10`1H0@80GP4305l10P1R0@80I0D807Tg@`25=T@0OP<>08/1302?
0@X0T@0808h11P2G0P/0Y08;0:h3302a1@h0]`H?0;P23P2l1Q80^`LB0;T64@2h2140^PPB0;h;5P2j
2aD0P@dC06iWKP3Oh^H0h^CX0>3SiP3Sh^L0i>?V0>CSi@3Ugmh0imoM0>WPgP3YhN40i=kM0>OQh03U
h^40hn;S0>;Qh`3PhN@0gMoQ0=cNh03MgMl0elW<08hi@02Y2QL0[@@<0:X53P2X0Ph0Y08>0:894`2K
0P`0WP8=0P2L0@`0502M0Pd0V`4;09/12P2I0@X0VP4909d22P2O0P/0XP4:0:H3302X2100TP@;08X5
30290PP0NP0507d22P1X0@@0G`0106@10`1V0P80DDl;0P00o`09ooooo`03052@N03oP000oh0000X0
oh000P2P8?0C0?n000030=1@N03oP000oh000180oh0000<0X23`0?n0003oP0006`3oP0000`3@D7P0
0?l0003o0008ooooo`P00?l004d0:=/?044]:@0b;D@0:2Y<02lX@01dEf00MEMP06eCHP22Gfd0T6Ic
09EXM@2HJWH0V6af09ecO@2JLGH0Ufe`09I]KP2ENG@0W8Eo09j;Q02JS8L0VY>?09fGU02ES8X0V96>
08f<R02BU980UY^L0:2SYP2//;<0[k6f0:N^/@2]][P0_<C70;k4b033bLd0_LC80<S?e@2g`<H0aM;H
0;g=f01dV[d0Y[O?0;:ba`2KV;D0NgFO08AJQ@25<5/0SADe09<?9@2?4ah0QB4U08Do@`1iE640G3iK
07TH;P2C0Q00T`8>08TT<`2<QXT0PXjB07f<T@1lRXh0NHN:07N4R@1aPXD0GW=n055WNP1YOXL0:3mF
05]bN01NLVl0G71_01dc@@1BJfh0F6]W01n^6004003o00Sooooo2000o`000`1@T7P0d51h0:0Pl00J
0:0Pl0040;Ph]03@D7P0X23`0=1@N0L0oh0000<0j6Pl0:0Pl02P8?001`2P8?020>QX?0040=1@N02P
8?00X23`0;Ph]080oh0000<0^3Rd0:0Pl02P8?003`2P8?000`20`0000?l0003o0002003o00_ooooo
000:ooooo`0a02SF201M8Q@0:aLE01d10@1;0`80C04204d10P1E1@L0DP8205X20`1P0`H0H`4506@1
101]2Q@0N@HC08P23`2=0P`0T@8:09812P2?0@D0U`490:P3302a1@`0/0D=0;<73`2k2100_0LB0;T7
4@2e1Pl0]@LA0;H8402g1a80_0/B0:<?6@1A=Ch0aLS?0>7TiP3Phn@0hN;U0>CSi@3Ti>D0hn?U0>CS
i03Sh^@0h^;T0>7Qh`3Rh^@0i>?U0>7Ri@020=kPi00S0=_Nh03Lg^00g]kP0=g=dP2B@4P0Z0`F0:d3
3@2Z0Pd0Z0<>0:@23@2O10l0WP<?09d1302N0P/0W04<09/1302J0@/0V`8;09`12P2K0@X0W@8:09l2
302S0Pd0Z@@=0:T63P2Q1a00S@@;09432`280PT0MP8705l21`1P0PD0J08406T30P1D?PT00P00o`09
ooooo`03052@N03oP000oh0000X0oh000P3XJ3`C0?n00080d51h4P3oP0000`3XJ3`0X23`0?n0000L
0?n000030>QX?000o`000?l000Sooooo2000o`00C@0;m`@0CS8/028P>`1:A5P0@CE3075FG@1cEEh0
NUYU089OK02?IgD0TVIb09IXM02HK7H0W6mh09M^M@2CJFh0UFa]09QeLP2KPWd0VhF009j>R@2HShX0
ViFA09NBSP2JU940T8b909RGU02BUiL0X:FX0:JZ[`2[/[D0[KFh0:^c]P2na<T0_lC90<;6bP2na<P0
`LO=0<oEf`2mbLl0^lcE076D^`18Hi`0Peb008XeDP2=8CH0SB0`08HZ<@2<B4X0T6=U0::>S02g]kL0
Wj^i05edSP1ZPj<0ARYE08H56@2C0@d0R@HB099/KP23S8h0OXb=07b;S01kRX`0MHJ70722PP1aPX<0
L8:406ioPP0jD600FW9g05mbL@1KL6`0D6IU04aSH@1JKVT0<I8[00@00?l02?ooool8003o000302S8
?03@D7P0X23`01X0X23`00<0^3Rd0=1@N03@D7P00P3XJ3`30?n000040>QX?03oP000oh000=1@N0H0
X23`00<0^3Rd0=1@N02P8?000P3@D7P01@2h>;@0X23`0:0Pl02P8?00d51h0080oh004@2P8?000`1h
F;@00?l0003o0002003o00_ooooo000:ooooo`0J02[G2P1Q8aD09a8A02<10P190P80C08204l20P1L
3a<0CP4404P2101H4QH0DPD:05d21@1b0@H0Q`8>08h13@2?0Ph0T04908h22@2A0@P0VP880:d4302c
0`d0[`<<0:l53@2f1a020;L64@0j0;433@2c1Pl0/0D=0;L;4P2l31<0^`hF07h=6@1/>T/0]IZZ0=O;
e@3JdMT0gM;J0>3?f`3ObmD0g<C=0=o5dP3K`<l0g/;?0=^obP3N`Ld0d[[80<jha03:]/80d[o:0=C0
b`3G_<P0_7Z909/G902`2140[`@?0:`22`2W0PX0X`<=0:02302M0@`0WP8=09h22P2L0@/0W08;09/1
2P2J0@/0VP4709X1202O0`/0XP4;0:@23@2V0`d0Y0@=0:D53`2P1@d0QP8708011P1f0PH0H04505d1
0`1O0P@0IP<306DA2@800?l02Oooool00`1@T7P0oh000?n0000O0?n000030>QX?02P8?00^3Rd0140
d51h00<0X23`0=1@N03oP0007@3oP002003o00Sooooo2@00o`00C01Q?Rl06ALd05a?GP19>TP0JU9H
06e>EP1cDE`0NEMQ08QOJ`2@Hg00UVQd09I/M@2JL7L0Ufad09I/LP2LM7H0VWUh09f2OP2FPWd0Vi29
09B;Q@2FTH`0X9jI0:2MV@2EU900VYnL092DU`2IX:@0Ri>J096KWP2g_l80]kc10;Nn`P34b<h0bLoF
0=3Jh02mal`0`lkC0<;?eP2P]/L0Xk[>08BSb01[SKL0PI2W0:bT[@2f[k@0^[fo0<[CeP3;fMd0bM[O
0<SHh@2;XkX0XKgA065lU@0b>VT0MQHb09413`2@0P`0RCTo08N9R`1mRHX0OH^<07b9S@1cQ8H0M8>7
07B2Q@1ePX@0LH24071oQ01UNg`0GgAc05ibKP1LKfh0;dE9051VI`13MCh4003o00Sooooo2@00o`00
0`2h>;@0X23`0:0Pl00K0:0Pl0@0oh0000<0j6Pl0?n0003oP0000P3oP0000`2h>;@0X23`0:0Pl002
0:0Pl0<0d51h0`3oP0000`3XJ3`0X23`0:0Pl0030:0Pl080oh0000<0d51h0:0Pl02P8?003P2P8?00
0`2h>;@00?l0003o0002003o00_ooooo000:ooooo`0H02[H2@1W;AT07P/802T10@1=0P<0B`020502
0`1A0`D0BP4206DI7P2PC5T0W4QE05<10`1i0PX0RP8>08h23@2;0@`0RP4808`02@2?0PT0V`870;<5
3`2e1A00]@DA0P2g1Q00?02h1a40/`@=0:d22@2b1Pd0/0@=0;L94@2h2A00_@/A0;h@6P2^52<0V1L_
0:Q5GP2jH7H0_EY`0;i>I02g@ED0]SQ>0;DdC02a;TL0/Bi40;0/?`2^:Sd0Z2Ln0:HW?`2X;480Yc15
0:PbB02X:d80Za4R0;H84@2f1@l0[`<<0:d32`2V0@T0YP8<0:<13@2N0Pd0W04=09/12`2L0@/0W@8;
09/12P2I0@T0VP4709`12@2N0`/0X@8=0:<23@2S0@d0Z0H@0:P43`2T0``0SP8908T32P1h0@@0M0<8
06l11P1S0PD0H08306XG40800?l02Oooool00`1@T7P0oh000?n000060?n000030=1@N02P8?00X23`
01L0oh00502P8?0O0?n000800?l02?ooool9003o001<03aV6`0L73D0ET]I01LH>00b:d@0JDeF075<
F@1iDel0Q5QT08aPJP2@HVd0U6Qc09UaN@2HKg@0U6Q^09]bM02MNgd0W8Ao09^7P02IRh@0THN1096;
Q02GTHd0W9RD09FFT`2JWih0PhV;08B:S027SY<0U9bP0;bo``2h_/80]kk20<C;c`2j`/P0_LS=0=;K
hP2ob]80]<C?0;c>fP2E]M<0LIJo03aYVP38gn`0cMcX0=3LiP3?f^<0bm_T0;O;gP2/a]d0aLgP07Ej
W01MJhX0Zkg905ebT`1C:Dl0S0@D09812`243QL0TGj007n;S01lS8`0NXV<07Z7R`1fQ8P0Lh6507:0
P`1bPH@0L82306YoPP1SMgT0GG9b05U^L00jDUT0=e5J05MLEP@00?l02?ooool9003o00030=1@N02P
8?00X23`01/0X23`103oP000103XJ3`0oh000?n0003@D7P20;Ph]0<0X23`00<0^3Rd0=1@N03@D7P0
0P3XJ3`20:0Pl0040;Ph]02P8?00X23`0;Ph]080X23`00<0j6Pl0?n0003XJ3`0402P8?000`2h>;@0
0?l0003o0002003o00_ooooo000:ooooo`1F02_I2P1W;QH06`L503D30`1=0@40C04304`10P180@80
E04306h3201l10l0OP<@06h32@1g0P/0R@8=08/23@2;0P/0S04:08/12@2?0@L0X0880;<6302d10l0
]`D?0;T5402i1@l0]PL>0;<6302`1``0/0H>0;453`2h2A40_PlG0<4<4`333AH0`@hF0<4@6@304Ql0
a1LS0<TF8@3>5B40cADO0<hE7`3A5Ql0d1@O0<hC7@3=4Q/0bQ8J0<D@6@3331T0a0dJ0<4<602n2aH0
_PXG0;h7502k1100]P@>0:d33@2X0Pd0YP<=0:@2302S0@`0W`4<09d23P2K0Ph0VP8<09`12@2K0@P0
V08809`32P2K0@T0W@8;0:42302R0P`0X`8<0:T63`2W10l0X`<=09T22P2A0PP0P`8707D11@1b0PD0
JP8506<20`1Z4P`2003o00Wooooo00<0D91h0=1@N03oP0008@3oP0000`3XJ3`0d51h0=1@N0080=1@
N0030?n0003XJ3`0d51h00@0d51h803oP002003o00Sooooo2@00o`00C@17K1X0;2Po04a2E@0212`0
81/j06M<E01_CU@0ME5J081DH02:FfL0S61/099WLP2DJgH0UVaf09EWL02JLgH0WWan09j6PP2NSHL0
VHZ609F;Q`2@RH@0ShV508f;QP2ATHd0SYBC08R>T023QhT0UIZM0:F][`2k`<<0_<360;g5b031bL`0
c=GJ0<39dP2mbM40a]7H0:g3e`2L]m80FX6^09>if@2`c^D0OIW107QVT@2KEgP0XVB20;BD[P2YWl00
=CQZ06TXCP1h4bd0LbXm0:2S[@1iSJ@0=SIR07/@9P2D0Pd0U0@@091DF023RhP0O8b<07Z9S01iRX/0
MhR;07F4Q@1bPX<0Kh6206j1P@1/PH00Igel05eeL`1IKVh0DfQ[02Q3B`1MIfD04L`:00<00?l02?oo
ool9003o00030=1@N02P8?00X23`01X0X23`00<0d51h0?n0003oP0000`3oP000102P8?00^3Rd0?n0
002h>;@>0:0Pl0040;Ph]02P8?00X23`0;Ph]080oh0000<0^3Rd0:0Pl02P8?003P2P8?00101@T7P0
0?l0003o0000o`0;ooooo`002_ooool0EP0Zf@X0MD0S01D40`0l0`<0C`8204X10P1<0P80AP4306D3
101g0PD0P04808D12`1f0`T0K@8908D23P280@`0RP8:08h12P2?0@P0U0480:H42`2b0``0]@D>0;H5
3`2h1A00]P@@0;D43`2e1A00[`<=0:h23P2a10`0^0PC0;h>60333QL0``hD0<0>4`2n3QH0``lH0<XA
60383aD0cA<I0=0C5`3?4A@0e1<H0=DB603B3aH0dQ0F0=0>5P3?3QH0bPXB0<P94P342A00`PT@0<48
4@2k1@l0^@D@0;@43P2]0`h0Y`8?0:813`2T0a00YP8=0:413@2K0@`0VP8=09X2302K0PX0V@4909H2
2P2D0PT0U@4:09/2302N0PX0XP8=0:<2302S2@l0Y1hM0:0M802G1@d0U`4808d1201l0PL0K04406H1
101Y0P@0I`T40P00o`09ooooo`03052@N02P8?00oh0005<0oh000P00o`08ooooo`T00?l004d0<j0B
04HiAP0n<dX00@<Z01hH=@1XCE80KDiD07ACG01mEEl0Q5QS08YOJ@2=HV`0UFUc09MZL`2EIg00WgIk
09ikOP2LPh40V8J309jET@3>cL`0VYNF08^5PP29Q840T8b:09RHUP27QXP0RHR;09FIW02RZjd0^L;3
0;o4a`3;dM@0`<O>0<cEfP3Bfn40am7I0:o0cP2[_]00Y<CS07VJ`P0KBhD0WKkN03m>P`2663@0W@TL
09D=801o7380Ka/i07DR@`2<8CT0S@DC08864`2ROhT0Tj6]0393J@1S:4H0T0<@09D23P2:82`0V8:6
07n9S01kRhh0MhV;07N8R@1dPh@0LX:40723Q@1^PX<0L8B306j1P01VO7T0GW9a05Q[J`0eDEL0DVQY
02>O6003003o00Sooooo2@00o`000`1XZ3`0^3Rd0:0Pl00@0:0Pl0030;Ph]03oP000^3Rd00L0X23`
00<0d51h0?n0003oP0001@3oP0080:0Pl080^3Rd102P8?020?n00080^3Rd0P2P8?000`3XJ3`0oh00
0=1@N00@0:0Pl00408300000o`000?l0003o00_ooooo000:ooooo`1F02_J2P1[>1T070<104/4101B
0P80B`4204@20P0k0@80I@@507P11P200PP0N`8:06021P1W0PT0Q08?08L13`2=0Ph0T04909<12@2D
0@L0Y0890;<53P2e1@d0]0D=0;L63`2e10l0]@<?0;843P2]0P`0[P8=0;843`2f1a40^@TC0;l>5@33
3AH0`@hG0;`<5P3241L0a@hD0<T@5@3?4QL0dQ4G0=0@503B41D0da4F0=@@5@3C41H0dPlG0<l=5@3<
3180b0XA0<L;4P342@l0`@P@0;`63`2j10l0^@H>0;042`2U0`d0X@8=0:02302Q0P`0WP4:09`12P2K
0@/0W04<09/13@2G0@X0T`490981202E0@X0V`8;09/12P2L0PX0XPH>0:Hi>P3S];<0_7f609hh@02=
4aP0Q@T?0801201h0@H0KP4406D10P1`50l2003o00Wooooo00<0D91h0:0Pl03oP000B03oP0020=1@
N080^3Rd1`3oP002003o00Sooooo2@00o`00C@17[QP0F494030X@0031BL08A/c06M=D@1[Ce@0LeIL
07QDG020EF40QeYW08YNJ02@IFh0UfUc09=UK02KLGH0X7en09j5PP2LRH@0YYjL0=CEg02HUIP0R7mm
08EnN`2<RXL0TI6@09BBTP29RH`0Ri2E09^TYP2i_/80`LO<0<C;cP3Fg>00bM;G0;[9dP31bm@0b=OS
0;oGj`0ZFHh0H8R^092`cP2T_ML0?DMk08/F;P2R3Qh0SA8M0:f6S@1WD6H0EbI607H<9`2?1QD0T@@B
08DfA02o`lX0GVf804<[DP261AH0T`4<08H6502JIVh0Q8R;07^:S@1iR8X0MhR;07F5R01ePhD0Lh:3
07>3Q01`Ph80KX:206f0P01RMGL0F6e_02@mAP1>IfP0;hlV00<00?l02?ooool9003o00030830003@
D7P0X23`0100X23`00<0d51h0?n0002P8?00202P8?050?n000030:0Pl03oP000X23`00P0X23`00<0
d51h0:0Pl02P8?000P2P8?00103@D7P0oh000:0Pl03oP0020:0Pl0030=1@N03oP000oh000140X23`
0`00o`0;ooooo`002_ooool0F00[fPX0JSDD01h200190P<0D04204P10P0m0P80:04105030`1[0`H0
KP@:05/11`120080J0<:084130270@h0S@4?08h12P2B00L0U`070:L32`2c10h0/P8<0;<53@2d1@l0
]0@>0;@63@2_0`d0[@<<0:h23P2b10l0]0H@0;@63`2l31<0`PhG0;h>602m3aT0_`hC0<H>4`3<4QD0
d18E0=@A5`3D4AD0eA8H0=8A5`3C51P0cQ4H0</D6@3=51P0ba0E0<H;4`352Q80``P>0<<94@2m1Pd0
^`@?0;X53`2`10`0Y`8>0:013@2L00P0V`0:09/0202L0PX0V`4909d23@2J0@X0U0470981202C0@P0
U`4:09`22`2K0PP0V`4:09l63P2_Ff40gK_608DV>02UAU00e9VJ0:YQI@1h1P/0NP4507L1101/0P<0
KPl;02b60000o`09ooooo`03052@N02P8?00oh0004P0oh0000<0d51h0:0Pl02P8?000`2P8?050?n0
00030:0Pl000o`3ooooo00Oooooo2@00o`00C@0Tf0h0N5aG01hH;@0/9c`0:b4b06U>D@1/CUD0L51H
07UCG@21E640REUU08]NJ@2AIVh0UFQa09AXL@2KLgP0WgYk09n7PP2MRhP0UXV80:6HW027OG/0R7mi
08AmN@29R8@0TY6?08j@T@24Qh`0R92D0:B[[P2j_l<0_lO:0<SAe03Afmd0`/c@0;S5b`3Bh>X0W;;:
06jG^P22Y<H0QJkA0;?<g@32e>L0<dEm08DW@`2S3R00RA4P0=?4bP3<e^40SiF^04LWCP1n3B40T@<B
08<E8P2aZ:h0NXZK034`F@1l5BT0U08<08d34020:S80Rh6407^:S@1gQhT0LhF80764Q01gQHH0M8>5
07B5Q`1bQH@0Kh:406n3P`1SN7/0FVe^04YPH@1=HV40=hP_00<00?l02?ooool9003o0003052@N02P
8?00X23`01X0X23`00<0^3Rd0?n0003oP0000`3oP0000`3@D7P0j6Pl0:0Pl0020:0Pl0030;Ph]02P
8?00X23`00@0X23`00H0j6Pl0=1@N02P8?00X23`0;Ph]03oP0020=1@N080X23`00@0d51h0?n0003o
P000d51h402P8?03003o00_ooooo000:ooooo`1702cJ2P1K8`<08@4104X20`1<0@80@`4103d20`0N
0@40;P41048310140PT0=`450441101e0`d0PP4=08L13P2<0Ph0SP4;09<12@2K0@T0Z`<<0;422`2e
1@h0/P@>0;032`2c10`0]0D<0;443P2_0Pd0[@8=0;043P2a10h0/PH@0;P=5@2j2a@0^0/D0;P=5@2m
3A@0a0hE0<T@5@3A4AL0da<H0<hD5`355Q/0/AXN0:DX:P2`BTX0cG=_0<UWH@31BDP0]R4T0<<>5034
2A00`@L?0;h53P2k10l0]`<>0;443@2V0P`0XP4<0:012P2J0@X0V`4:09`22@2K0PT0W08:09T12@2E
0@T0U@4809L1202H0PT00P2I0@T03`2N0@X0X0D=0;1JH03L];d0R1XW09T_=`3M/KT0QDmG09MBE01]
4A@0M@@707410`1Z2@D0;hL1003o0009ooooo`03052@N03oP000oh0002X0oh000P3@D7P0103XJ3`0
d51h0=1@N03XJ3`H0?n000040=1@N02P8?00^3Rd0=1@N080X23`00<0d51h0?n0003oP0000P3oP000
0`2P8?000?l0ooooo`07ooooo`T00?l004d08>D<07MIBP0@2a`0Cd9803/Z=01/Ce@0KE1E06e>EP1e
D5/0OeEP08=EH@28FFH0Sf=]09=WK@2FJg80VW5f09ihN@2NPWl0WXZ909F5PP2>P7/0RGee08MmMP27
OGX0Qh20092?S@28RH`0QhR?08bBUP2KXZD0`/[=0<36bP34cM80bM;H0<oMh@2jb]40V:o10;g@gP2?
]=@0LI[802=?R@2bcN00dMoZ055ZVP1]@VP0VPdO094:7@2]P8d0cm[P0<cJi01JJY00IR]@09445P2?
1AH0Sf5Y0;_7c`0nBVd0H2e=08/3402C0@`0Q@H@08mOI01kQhX0MhN;07B6RP1bQHT0L8:606j2Q01_
PX@0KX6307>4Q`1`QXD0Jgj1069dM@1KL6l0Ffi/04iNAP03003o00Sooooo2@00o`001@1@T7P0X23`
0;Ph]02P8?00d51h01T0X23`1P3oP0030:0Pl0040;Ph]02P8?00d51h0>QX?0@0X23`00<0^3Rd0?n0
003XJ3`00P2P8?00103@D7P0oh000:0Pl03@D7P20:0Pl0<0oh003`2P8?00103@D7P00?l0003o0000
o`0;ooooo`002_ooool0A`0]g0/0FRL702D10@1?0`80CP4204P10P180P<0:P8204Xb=02iYZT0<10G
03T11P1S0`/0O08<0801302400/0R`8;08`12@2B0@X0V@090:h3302d0`/0]PH@0;H74@2b10d0]@D>
0;H53P2c0`h0/@8=0:l33P2]0`h0/PLA0;D:4P2f2a@0]`XC0;T<502l31H0`PlJ0<TA70394aT0`AHL
0:@M802F>3T0[WEf0=2f]P3SfMP0hn3R0>CSi03Uh^40i=_J0=Zi^02cAdX0]a4I0;l94P2n1a00_0DA
0;L23P2a0Pd0Z08=0:812`2N0@X0V04:09P12`2J0@/0VP4:09h2302M0@X0V`4:09P1202E0@L0U@48
0080UP4800l0V@8;0:033`2S=d80j[S108dR;P2@5R00hZN`07HoB@2jWJ40OEeO0:1ZK@1^41@0KPd:
02j70@00o`002Oooool00`1@T7P0oh000?n000050?n000030=1@N02P8?00j6Pl01/0oh0000@0d51h
0?n0003oP000oh000`3@D7P50?n000030>QX?02h>;@0oh0001H0oh0000@0d51h0:0Pl03@D7P0j6Pl
102P8?001@2h>;@0j6Pl0?n0002P8?000?l000Sooooo2P00o`00C@1fET405`lK05A3A@19<cX0K4eB
06e=E01aCUH0MU9K07eGH@21F6<0PeQS08aRJP2AIg00TFQ]09Q_LP2ON7/0UWQf09b7P`2IQh<0TXEo
08Z0N@29OWT0RH1l08EoO@2>S8`0R8V<08Z?T`2@UiX0X:^]0:fg_032b/h0bm;H0<G?eP2jc=<0bmgS
0;W;g01cUkh0LYBj07fYe@2X`mL0d^3X0=?Oj02R]m80A4ao08/K<@2M2AX0Pb0`0=71bP3?f>00[;_B
03/aIP2432H0U08C08@R<@2LW:<0NXZO03XbF@1l2a`0T`4;09433028;cH0R8R907b8S@1gR8/0M8N:
07:5R@1_PhH0LXB506n1Q@1aPhP0KXB40764Q@1WNW`0I7Mf06AhM`1JHEd01?8200800?l02?ooool:
003o00040;Ph]03@D7P0X23`0;Ph]1P0X23`00<0d51h0;Ph]03XJ3`00P3oP0000`3XJ3`0oh000;Ph
]0030:0Pl0030;Ph]03oP000oh0000<0X23`0P2h>;@00`3@D7P0oh000:0Pl0020:0Pl0060?n0003@
D7P0^3Rd0;Ph]02P8?00d51h0P3oP0000`3@D7P0X23`0:0Pl00<0:0Pl0040;Ph]00Xb3`00?l0003o
00_ooooo000:ooooo`1H02cL301A80<0:04105420P1:0@40B00104`10P1=3100:@PA03lU=`1<5R40
H`D<07D22P1n0@/0O`4:08@02`2:0@`0S@4:09812`2I00X0/0@?0;<33P2f2140/PD=0;843@2e1Pd0
/P@<0;833@2^0P/0[@<;0:/22P2`1Pl0]PXB0;P<4`2h31D0_Q0J0<<@6@3441X0`10I0;8J7P23:BP0
_inK0>7Ie@3Thn80i>CU0>;SiP3Ri>H0hN?V0>?SiP3PhN<0gmkO0=>d/`2H:bl0^0dE0;l64@2j0P`0
]P8=0;823`2Y0Pd0X`8:09d22`2G0@/0U00909X0302L0@`0V`4:09P1202I0@X0UP4709@1202F0@X0
U04909D12@2G0@`0X@<>09LA703TWjP0Vca808l:5P2fHfl0RU=L0;NPYP2iYZ`0XXR?09AFG@1[3PX0
;XH0003o00Wooooo00<0D91h0?n0003oP0001P3oP0000`2P8?00d51h0?n0000M0?n000030=1@N03o
P000oh0000L0oh0000<0d51h0:0Pl03oP0005@3oP000103@D7P0X23`0:0Pl03oP0060:0Pl0030?n0
002P8?000?l000Sooooo2P00o`00C@1>IbP09Q`S04`g=`1K?d80K4]>06e=DP1aD5L0M5AL07UEG01n
F640LdmJ08EKIP2?I6h0SV=Z09A/KP2IMGL0UgQj09b6Q02HQhD0V8b60927PP2>QH00QX5k08F2PP27
QX@0QhZ?08RAU`2AV9/0YK:d0;6k_`2j`lT0^l;90=CMh`2Z_L/0MI:Z0;G:g026YLP0QjgD029CSP27
ZlT0d^3Y0=?Oj03@gn/0@5b:0856I02I3Ad0U0dM0910DP3Ec=L0b]SV04eNR`1_:Dd0UP<D08/6502G
LW`0UJBa0350I`1a:D@0U0<@09L13@272Q<0T7Mj07b9R`1fR8X0L8>407:3QP1aPhH0KX6206n2P`1`
Q8L0KhB40725P`1WOg`0HgQf06R0OP1VMG403l`900800?l02?ooool:003o00<0d51h6@2P8?001P2h
>;@0j6Pl0>QX?03XJ3`0oh000=1@N080X23`00@0^3Rd0:0Pl02P8?00X23`0P3oP0000`3XJ3`0X23`
0:0Pl0020;Ph]0030:0Pl03XJ3`0d51h0080X23`0P3XJ3`0102P8?00^3Rd0:0Pl02P8?030?n000l0
X23`00<0D91h003o0000o`002oooool000[ooooo05P0;Md=05/[300_0@80E@8304/10@190@80CP42
05h9401_:3D0L2/l07@B801c0@X0M`4807d12`1o0@T0QP4<08`23P2@0@X0T`4;09/12`2a1@l0]0@>
0;@63`2d1a00/`@>0;@63`2f2100/PH=0:`22P2/0`/0Z`<;0;874@2d2A80]0XA0;X>5@2j4aT0]1PJ
09lT9@2LAD40[7ef0=K7`P3Thn80hn?S0>?TiP3ThnP0iNGY0>;SiP3Ri>H0hnCV0>3Qi03Ph>80hMcL
0<6BU02W72D0_PLA0;`43@2h0`h0/@8<0:X3302V0P`0X08=09`12`2K0@d0W04=09d13@2I0@X0U`47
09/22@2F0PL0T@4609@22@2C0@X0T`4909D12P2P0Pd0WPLB09XY=@2iHF/0Z4M=07HG8P2QDV00XWR4
0:R9T`2GLGT0KbTb06H6100aQ`800?l02Oooool00`1@T7P0oh000?n000040?n000040>QX?02P8?00
X23`0>QX?1/0oh000P3@D7P00`3XJ3`0oh000?n000090?n000030:0Pl03XJ3`0oh0001D0oh0000<0
d51h0:0Pl02h>;@01@2P8?00102h>;@0oh000:0Pl000o`08ooooo`X00?l004d0C7DU03DW:013<2h0
HD]<06M:C@1[C540KdmF07M@GP1iDEd0NU=O071>FP22F6<0Sf5Z08mOI`2CJ6/0W7Mg09EiN02GPh00
UHF009N>R02FSHP0SX>008f7Q02>QhP0PX6305m_O`1mRYD0[[Nj09FOYP2]]kd0_<K80<K@eP2c`lX0
a=CL0;36f02B/]00JHbe05J2]P2J^M<0b^3X0=CPj03Ch>P0dMoV08jS`01>BgT0P`hT09P8602:2ad0
/8:>0<_Fh02N/L`0@CAS08<97P2A0Ph0Pc4m0:bd^`1bQ9h0BS9H08L76P2C0A00S@<>08]<D`1mQhX0
MhZ;07B7R01eQhP0LhB70765Q@1aQ8D0KX6506n3Q01_Q8<0JGmn06=jN01XP7h0L8:001n/5`02003o
00Sooooo2P00o`030=1@N1P0X23`00<0d51h0:0Pl02h>;@00P3oP0000`3@D7P0j6Pl0:0Pl0040:0P
l0040>QX?03oP000oh000?n00080X23`00D0^3Rd0=1@N02P8?00^3Rd0=1@N0020:0Pl0040=1@N03o
P000d51h0=1@N080X23`00@0d51h0?n0003oP000^3Rd3P2P8?000`20`0000?l0003o000;ooooo`00
2_ooool0F00^gPl0DQl703T20@1D0P<0B@4104/10P1A0@80GP8306811@1Z0@P0N@8907H01`1f0@T0
NP8807d12@260@d0SP8<09@12`2J0@`0WP490;053P2d10h0/@<<0;03302a0``0]@D@0;D7402^10/0
X@<;09HB5@2L8R40XQ/L0:4K6`2N8b80XCdi0:]PF02kU8X0f/o:0>;RgP3Ri><0h^CV0>7Qi@3Qfn40
hMCL0>33d03=YK<0SgZ90=3FfP3Pi>H0h>?V0>3Qi@3Oh><0gm?F0:Q>E@2j2A<0_0D>0;T33P2_0P`0
Y`4<0:H13`2Q0@`0W@8909`12`2L0@T0WP8;09d12`2L0@X0V`8:09T22P2F0@L0U@4909<12@2B0PP0
U04909d1302R0`d0X@PB09T@7P2U=DD0Q`/H08P44P2A>dH0TVM`09a]M`1i>Cl0J``:03mZ1000o`09
ooooo`03052@N03oP000oh0001/0oh0000@0j6Pl0?n0003oP000oh000`3@D7P00`3XJ3`0oh000?n0
00030?n000<0d51h00<0X23`0>QX?03oP000103oP0000`2P8?00oh000?n0000E0?n000050>QX?02P
8?00d51h0>QX?02h>;@00P2P8?00102h>;@0oh000=1@N000o`08ooooo`X00?l004d0=Y4B04Lb:`1G
?SP0AS8i04hf?`1ZCE80KTmE079@FP1hE5h0TVig085II023Ef40SV9[08mSK@2BJg40VgQk09YkO02A
N7H0U8Al09^DS02GT8d0RH1n08^6P`2:QH@0Lg^705AYP@2AVZ00WZJY0::Y[@32c=80Z;:i0<?Ae@2e
b=<0W[O90;;:g@1TRJl0Y/c]04M`Z@1EO:/0d>7Z0=;Oi`3CgnL0d]kV0<_Lj@0cBWX0MC1>0904502H
1a@0T2Ti0=C=e`2U//D0Be1j07XV?`2A0Pl0P0XF08]fO@2U/l00=CiV07LJ<P2?0@l0S`8<07hK9@27
PhD0N8Z>07N:S01fR8T0MHN:07:4Q`1`PX@0L8B507:2P`1/Oh00J7em06YlO@1WNgd0MXJ902nM:@02
003o00Sooooo2P00o`000`2@L7P0j6Pl0=1@N00H0:0Pl080^3Rd00@0j6Pl0:0Pl03oP000d51h102P
8?000`2h>;@0X23`0?n000030?n000070=1@N02P8?00X23`0>QX?03oP000X23`0>QX?0030:0Pl004
0?n0003XJ3`0X23`0;Ph]080X23`0P3oP0000`3XJ3`0X23`0:0Pl00<0:0Pl00307QH]000o`000?l0
00_ooooo000:ooooo`0402oP401=70L0=P4105<10@80CP410140D00105X10@1O0040JP4607P12P1d
00L0N@4:07X1201j00T0Q@4<08l1302I0@/0W@4909h22P2Z0PX0/P@<0:l12P020;433@0Z0;82302c
10h0ZP8:09P52P1E30d0/9JF0=Nd[@3G/ZX0hLFm0>SLeP3Uh=h0i>?Q0>3Ti@3Qi>P0h>3V0=S?f03P
_/d0ei:U0<=LL@2f;T@0]Ah_07<B7`2MW:40hNGV0>3Pi03Ogn80g^7R0=oQh02eOX<0/@dG0;P3302g
10h0/08>0:/24@2V0@d0XP4;09`1202K0@P0VP4809`12@2N0P`0V`0:0P2H0@T04`2G0@P0UP4:09@1
202G0PL0VP0809h1302Q1100W0@=09L43P2@0`l0TP4<09012P2H=Sl0Z6]h07P_?P2CFF00IPd;064B
1`00o`002Oooool00`1@T7P0oh000?n0000K0?n00080d51h00<0X23`0=1@N03oP0001@3oP0000`3@
D7P0X23`0:0Pl0030:0Pl080d51h1@3oP0000`3@D7P0oh000?n0000I0?n000040=1@N02P8?00X23`
0:0Pl080oh0000<00?l0ooooooooool01_ooool:003o001=03NP3@1H>bh0Jdi104Xd=`1>>d40JdiC
06e>E01`CUH0S7Z10<W0aP2@LH40QUMY08YPJ`2>I6h0TF]c09]eO02?K700SW9`09F3O`2HS8P0UHb:
08^5P@2:QH40RhR903e=J`1^Oi00Xj^_0:B]/P2`^L00Xjjf0<WDg02HYk<0]LK@09nkc`2`cnD0P:31
01]:Q`1gW<@0SZk;0=;Qj03AgnH0dmoW0=;Ni@3>gND0P9Jc04<jI@1k3240U@LE08l65`2H?5<0RcaM
08T`D02=62`0T@HA08L8502DKGH0U:6/055SPP1O<e@0Q@DF09413@2510l0S6AW07b;S@1jS8h0MhR=
07R7S@1fQ8L0LhB606n2P`1^PX<0KH:106]nO@1YOGd0JGf007N:S00oPSd00P00o`08ooooo`X00?l0
00@0J:Pl0>QX?02h>;@0^3Rd1@2P8?000`3oP000X23`0:0Pl00>0:0Pl0@0^3Rd00D0j6Pl0:0Pl03@
D7P0X23`0=1@N0040:0Pl0D0oh000P2P8?000`2h>;@0oh000=1@N0030:0Pl0030;Ph]03oP000oh00
00@0X23`00<0d51h0?n0003oP0003`2P8?02003o00_ooooo000:ooooo`1602CX301?6`H0?08105L2
0P1A0@40C04305410P1M0P40IP8406h21P1f0@L0M@4807L02P1m0P/0O`4808X22`2E0`d0V`4;0:01
2`2N0@X0Y`<:0:l3302_0@/0/08=0;032`2/0PH0[`<:0:d32`2V0`/0P0D<068/>P2UTZ40bKo90=?<
d`3HeMT0gMKM0=W?e`3Ka=00eZbl0<f:WP37Fg00`Bi30<HJ;@3=4b<0c@dH0<l?5@2T4AL0L5iR0>3S
iP3PhND0h>7T0=gQhP3LhN40aJJZ0:LB7@2h1Ph0]@@<0;423@2[0P`0Y@4:0:<23P2M0@/0V`4809`1
2@2M0@`0WP8:09`12P2J0PX0V08909P12P80U@490100U`4809T1202M0@`0WP8=09D22`2;0`/0OP49
08H22P280PT0P0`F09HW=P1k1A80QR`e06H81`1S4PL00?l02Oooool00`1@T7P0oh000?n0000K0?n0
0080^3Rd0P3@D7P0103XJ3`0d51h0=1@N03@D7P50:0Pl0050;Ph]03XJ3`0oh000?n0003XJ3`01@3o
P0020=1@N1X0oh0000@0j6Pl0=1@N03oP000d51h0P3oP0000`00o`3oooooooooo`06ooooo`X00?l0
04d06</30650<@1/C3l0BC4c02hT;`1XCE00JTU>06i<E01kH6`0X8RH085KKP27F6H0REi_08QQK02=
J6l0V75f095[K@2CN7H0UXB509Z>S@2ERhL0ShN008^8P`1kPi<0;DQ^09bV[P2IXJT0YZjg0;c6cP2J
Z;<0YKBm0:Rh`@2/`]40I8:T02MBQ@2K_n40Ji:o04If[P2Q`MH0dn7X0=GPj03Bh>P0d]kV0=7NiP3=
f^D0N8ZU06UCI`25Adl0R45708a:D02AEf40ODiM095TJ029HVH0T6ib0:6RZ@2KZ;80X;3403hiH01a
4R`0SP<B08h23023<SX0PHR907b;SP1hRHd0NHZ@07R9S01cQXX0L8B506n4Q@1aPXD0L82106b0P01Z
Ogh0L8B505EHD`02003o00Sooooo2P00o`001@1@T7P0d51h0?n0003@D7P0^3Rd01@0X23`00D0^3Rd
0:0Pl02h>;@0d51h0:0Pl0020;Ph]0040=1@N02P8?00X23`0:0Pl0<0^3Rd1@3oP0001P3XJ3`0X23`
0:0Pl02P8?00d51h0;Ph]0D0X23`00<0^3Rd0:0Pl02P8?000P2P8?000`3XJ3`0oh000=1@N00=0:0P
l0030=1@N000o`000?l000_ooooo000:ooooo`1H00ch101>6@D0A@8205d20`1F0@40C`4205@20P1Q
0P<0I@4306/1101i0@H0N@4707/22@1o0P/0Q@4:08d2302E0@/0W@8;09h22P2I0@T0XP8:0:l2302_
10`0[`<;0:`22`2[0PT0[0<70:`22P2Z0PT0[@<<0:D84P2D2a`0UQ/^09`W?@2iAU`0`DIL0<8nD`2m
8S@0`QHV0</C8P3A4a`0da4I0=<A5`3B3QH0c``A0=4>40344QL0FB0V0=CGf`3PhnH0h>7U0=kPh`3L
g^40f<g@09dY<`2c1100]P<>0;42302Z0@T0Y@490:02302M0@/0V`8909`12P2M0@/0W`8<09h23@2H
0PT0UP4909P22`2C0@T0T`8909D1202G0@P0V@4809l13@2J0Pd0R`<:07d220200`/0L@8606<21@1m
0PT0Q0<:07D2101Y0P40H@/3003o00Wooooo00<0:<Pl0?n0003oP000703oP0000`3@D7P0X23`0:0P
l0030:0Pl0040;Ph]03@D7P0d51h0>QX?0H0oh0000<0j6Pl0?n0003oP0000`3oP0000`3XJ3`0^3Rd
0?n0000O0?n00003003o0?oooooooooo00Kooooo2P00o`00A@0Ve`/0GcdV06a<?@1WB4D0=RLa06I<
CP1WAd`0JTIA0717D`1kD5d0Oe=O081FI01/D5l0H4iJ08=UK02HKgD0U6e_09=fMP2?OG`0VHb909N?
RP2ESH/0TXnC03]AN`1JLi<0WZJY09fTZ@2c_lL0RiNQ0<;?eP2Q/[`0[kk;07bG[P2hdNP0OY^o03]U
X@1RS[l0@g>[0<OQl03Bh>P0dN3W0=7OiP3BgnL0d=kU0=7Li@3:fn80b=[O0<gGf`3=eML0b]OJ0<GC
f`1IM9<0PY^d05acS02db=D0QiZY09RY]@2BXZh0D5j106DkH02621d0T`4=084=5P2=O7l0OHjA07^>
S`1hRXX0NHb>07>6R@0207F7R@0807:5QP1^PX80K8:10726Q`1dQhX0HVMU00SU1000o`08ooooo`X0
0?l000<0D91h0=1@N03@D7P05P2P8?020;Ph]0040=1@N02P8?00j6Pl0;Ph]0H0X23`00<0^3Rd0=1@
N03oP0002P3oP0000`3@D7P0X23`0:0Pl0040:0Pl0040;Ph]02P8?00X23`0;Ph]080oh003P2P8?00
0`0Xb3`00?l0ooooo`0:ooooo`002_ooool07000o`00CaT40544101S0P80F04105D10P1A0@40G`44
06D10`1Y0@@0N@8807P11`1k0@T0Q04<08L1302@0Q00UP4>09X22P2J0@X0T`0909/22`2Z0PX0[`D;
0:l5302[0`T0Y`470:P1202Y0@T20:P22@0j0:`42`2f2a80^@lF0;`B6@315Qd0`APL0<8G6P3;5AT0
c18I0;lC5P2o:BP0`Rla0<@c=@37=cH0c34a0<XD6@3<3A@0L0/?0:ZY[@3QhND0h=oT0=oNh`3LgN80
gM_N0:1DG02/2aH0]0@>0;423@2[0@`0Y`8;0:413@2M0P/0W08909/1202J0@X0T`<<08422@2<61h0
Q0D;09822P2D0@L0T`490981202D0@L0V@4809d2302M0P/0V`<<08l430260`T0P08706`21@1X0PH0
JP8406/10P1V0P40H`d5003o00Wooooo00<00?l00?n0003oP0009P3oP0040=1@N0<0oh0000<0d51h
0?n0003oP0000`3oP0000`2P8?00oh000?n0000:0?n000030=1@N03oP000oh000140oh0000<00?l0
ooooooooool01_ooool;003o000V06Ho7@1_Cch0HT4k03hV:`1XBD/0JdM<06]3C@1aBE@0NDiK07eC
G`1ZCET0MUaX06]KIP1XEV<0SfQb08YVK`24K7<0UHF409J<Q`2ESXT0Ui:>08F<W00?;VP0UZRh0:fd
]`2S[K@0Xjng0;K2bP2O[[T0YK>m0;?3d@27W[h0?V^J0;7Hm01US[T0K9c>05>0ZP3;hN`20=?Qj00V
0=?Oi`3BgnL0cmoV0<SLj`3>f^D0d]OS0=7@gP3=b]/0b<;E0<Bgc@1cIHl0JEZ209Z0V`2ALh/0VGbD
0;:@Z@2HM8d0PV1o06hlGP2;4bX0U`8?08l3402BD5T0S8V>08F;T@20SXl0OHnA07F8R`1gRh/0MXZ;
07:7R@1]Q8@0JX:206f0P`1fR8/0IG=b01G23P00o`08ooooo`/00?l000@0d51h0;Ph]03XJ3`0d51h
4`2P8?030;Ph]080d51h00<0X23`0;Ph]03@D7P01P2P8?000`3@D7P0oh000?n000030?n000H0d51h
2`2P8?020?n000h0X23`00<0J:Pl003o0?ooool02_ooool000[ooooo05P00?l0058F101O10@0HP41
05X1001H0@00EP0206421@1V0P@0J`0407l12@260@X0Q04:08D22P280@T0T04=09T23P2K0P/0U049
09412@2E0@/0YP8:0:h72P2_10/0ZP490:H01P2V0@D0YP470:L12@2Z0`X0[@@<0;H=5@2_5AX0Va`L
0;=ED02nKfP0]f1L0:db<P2a7R40M0`<0=J`ZP3P`K`0hl?10>K7`P3X[J`0[R0Y0<`?6@2E3aD0OW=h
0=kNh`3Ogn<0g]oS0=cPh`3Kg^00[7f30:0B6`2b0`h0/P4=0:h12`2Y0@X0XP4=09d12P2M0@T0V`49
09H22P1m0PH0MP4809HM:02>6b40SP<;09D2202D0@P0T@0609<1202G0@T0W@8<09`12P2J1@d0U`D>
09P32`210PH0NP<707811@1U0@<0G04206D20P1U40L00?l02Oooool00`00o`00oh000?n0000O0?n0
00<0X23`00<0d51h0?n0003oP0000P3@D7P20?n000030=1@N02P8?00oh0000L0oh0000<0d51h0?n0
003oP0002P3oP0020=1@N180oh0000<00?l0ooooooooool01_ooool;003o001>06EM6P1_CS`0K4/m
06U5?@1ZBD@0J4M906]5C@1aBe@0NU5L07]DGP1MB5<0LUiY06=KI@1ODeh0RVI_08UYL026KW@0UH23
09N:R02GShX0Ti6A04IIP@0_Ch@0YK2g0:V_/`34cM<0VZJ_0;G1b02X]/40[kk:06R3VP30end0LIS3
05J6^P1WTl<075:K0:oDk`3BhNT0eN7Y0=GPj03CgnD0d]oU0<_Lj00oHI80P6R?098fE`2>9DD0S1dj
08LE<P284Rl0QPdY08L;8P2;2R40RPTP08X98P2;2B40S0TO08/9702=2AX0T`HG0944402@10l0RPTG
08PJ;024:3X0QEmV07j=S`1hS8l0N8^=07J:S@1eRX`0KhB50764Q01aQ8H0LXN906n0P@0UXQh00?l0
2?ooool;003o00040;Ph]02P8?00oh000>QX?1<0X23`0P2h>;@00`3oP000X23`0=1@N0020;Ph]0@0
X23`00<0^3Rd0:0Pl02P8?001@3oP0000`3@D7P0X23`0:0Pl00:0:0Pl0050;Ph]03@D7P0d51h0=1@
N03XJ3`00P3oP0000`3XJ3`0X23`0:0Pl00;0:0Pl00308300000o`3ooooo00[ooooo000:ooooo`1H
003o001D50<0HP@206<20P1K0P80D`4005T10P1R0P@0IP4307011@220PT0R@4=08D130210@T0R`8=
08l12P2I0``0VP4:09@1202A0@L0TP480:D3202Z1@H0[@H;0:`32P2Y0@P0Y`480:X22@2/0@X0[0@<
0;87402E31D0FaPI0:V9Q03LdL`0gm[E0=oEdP3MaL40cZJO07iSH02UZ:T0h>;Q0>7Rh@3Sh^40imCF
0;1>E`3551d0/Q8J0654B@3Gfml0gn3S0=kOhP3Nh>@0fmkP0;jSZ@2>62@0/@LB0;423@2/0PX0Y`49
0:813@2M0@/0V`0809/12@2?0`/0L`<708h3302D0Pd0QP@:08H3202C0PT0U@8809D1202F0@X0UP48
09`12P2L0@T0S`8808@2202F1@h0K`8407831@220`L0L@8505L1001Q0`40H`l600_Q00Wooooo00<0
0?l00?n0003oP0007P3oP0001@3@D7P0j6Pl0?n0003oP000j6Pl00<0d51h103oP000102P8?00oh00
0?n0003@D7P50?n000030=1@N02P8?00oh0001h0oh0000<0:<Plooooooooool01_ooool;003o001>
05mi5P1dCcl0KD`l06]7?01WAT80ITQ806Q8C01^Be<0M4mG07MAG@1D@e40E51M051?FP1cFfL0Rf=[
089RJ026KW40UGj309R9R@2ITY00PHNG00lYJ@1LLYX0[k6f0;k4c02JY:h0aM3H0:>a^`2Y^<80YKO2
0:c1c`1/S:`0NYg802QHVP1eY=D0HXg306ZD`@3Bh^/0dn7Y0=?Qi`3Bh>L0d]oV0<oOj@1_S;80FEUo
08LjAP2B@4H0TDQ=099EG02GI6X0V6ab09ahOP21Hg@0VWZ108EWK@27IVX0Sfia091/L02MMgT0TVU]
08MMH@29Ee/0QDY;08@l?P24<3H0MT15086<S@1lSi40MXZ<07>6R@1fRH`0KX:606n3Q01cR8T0LhV<
07J<S`0iRCD00?l02?ooool;003o00050;Ph]02P8?00j6Pl0?n0002h>;@04P2P8?020;Ph]0040:0P
l03XJ3`0^3Rd0:0Pl080^3Rd00H0X23`0;Ph]02P8?00^3Rd0=1@N02P8?050?n000030>QX?02P8?00
X23`00d0X23`00@0d51h0:0Pl02P8?00^3Rd0`3@D7P00`2h>;@0X23`0:0Pl0090:0Pl003003o0?oo
oooooooo00Wooooo000:ooooo`0L003o001D4`40I@@306810@1G0@40E04205T10P1O0@40J`8307@1
10220PL0R@4:08H22`250@/0S`4=09D23@2K0`d0V08809@01P2?0@P0SP4609d31`2S0@H0Z0890:/2
2@2/0@X0Z`890:`22P80[0<:03X0/0/C0587302?RXd0gMkM0>3Qh`3Qh^@0hN7S0=WGg@3Kemh0h>;T
0=;Ge`3Nhn<0g^CS0=oSi03Rgn00dj6W0;4O9P324QL0D18I0;6e_03Kgn<0g]oR0=gNhP3KgN00d<G7
08doB02T2aP0/0<@0:X12P2W0PT0Y04<0:413@2N0@/0V`4:08T4301O0`D0R0@=09<22`220PL0M044
0902202E0@P0T08808D21`2?0`P0V`4;09d1302L0P`0R`<908X32@1m10X0I`4408L5301k0`D0JP<3
05l10@1W5Pl05L812Oooool00`00o`00oh000?n0000M0?n000030:0Pl03oP000oh000080oh0000<0
j6Pl0=1@N03oP0001@3oP0001@2P8?00d51h0?n0003XJ3`0d51h00@0oh0000<0j6Pl0:0Pl03@D7P0
7P3oP0000`1@T7Soooooooooo`06ooooo`/00?l004h0?J@<079??01^C3l0KD/o06M6?`1TATH0I4M:
06a9DP1cBeH0N4mM06e?G01GBE@0LV5[08i^N@2?JG80T6e_09AfM`2EP7l0UHV609FDV`0^?Vd01R=^
08BDZ`2`][X0^;k30;:l``2S[kT0Y[Bn0<?Af`26W:`0Zl;C072A/P2F^]/0Nj;=0115T@1[Vl/0X[kE
0=;Rj@3Dh^P0e=oU0=CPj@3BhNH0d^7W0<?Fh`2/`/l0`lc@0<G>d@39e=T0b]WM0<cJh02Z_=40HHFa
049TT02H//D0UJZb0;?5b`2R/kd0XkBm09j^]P2P[K@0Wjfb08nNX`2=VYh0S9RJ08RAU@22S8h0NHb>
07V=T01gS8l0MHR=07>9S01`Q8P0JGeo0765Q`1dRHd0MH^?04mQCP00o`08ooooo`/00?l000D0P<00
0:0Pl03XJ3`0oh000=1@N00B0:0Pl0060;Ph]03@D7P0d51h0:0Pl02h>;@0d51h102P8?00103oP000
X23`0:0Pl02h>;@60?n00080d51h00<0j6Pl0?n0003oP0000P3oP0000`2h>;@0X23`0:0Pl0020:0P
l0030>QX?02h>;@0^3Rd0080X23`00<0^3Rd0:0Pl02P8?003@2P8?000`3@D7P00?l0ooooo`0:oooo
o`002_ooool0F000o`00FQL106P30P1S0P40E`8205410@1D0@40I`8306d1101d0@D0PP4808P12020
0P`0O`8<08l1302E0@d0V04;09T12@2D0PL0S04608X10`2H0@L0X@060:L22@2Z0PT0[P<;0:l2302a
10`0[@880:h32`2]21<0APX>0:NVZP3Nh>40gN7S0=_OhP3LfN00ZWB907P_C@2WS:40fmkU0=oSiP3M
hN@0h>CV0>7Ti@3Pb/h0[3Hm0<<@501W2a40Kfed0=OLg`3Kg>00g]oT0=cMh03HeML0Y79j09P@7P2[
0a00Z08;0:H12`2S0Ph0WP4=09`1302I00/0RP<;04L00P1R0`X0OP@;06`5201S0@@0R`<:09D22@2A
0PT0M`8507/21@2I0P/0V`4=09X23P270PT0OP4608L32P1g0`L0O@@806/00@1T0@40H`8106LF3`0F
``49ooooo`03003o003oP000oh0001d0oh0000<0X23`0?n0003oP0000P3oP0030:0Pl0H0oh0000@0
d51h0?n0003oP000X23`1@3oP0000`2P8?00d51h0?n0000M0?n00003052@N?oooooooooo00Kooooo
2`00o`00CP14Z`d0Le8f06m@@@1^C480Jd]306Q8A`1XB4h0JTMB07=9E`1kD640PEIV08UWK`2@L7L0
UG9n09IbN`2GM7X0VGUn09Z5Q02LTHl0NGbB00DMI`0C=7`0U9n]0<C;c`2VZK80]ko70:Zg_@2a`</0
XK6m0<3AgP20Vk<0Oijn039QV@2fh?d0N:3A03U][`2mf^h0e>;Y0=GSjP3DhNP0eN;Y0=CRj@3Dh^P0
dN3W0<oOiP3>gnH0d=oW0<oNi`3Ah>L0d=oW0<?Fj01]U/<0Y<OS06^E^@2P_Ll0Z;W80:Vd`02ia/l0
/Kg90;g:eP2O/KX0VZbc09JW[`2@XJT0QiVP08VKX01hRi00NXjB07f@U@1bQH/0KXB606f1Q@1YO800
Gg=h06Z0Q01cQh`0GfMT00Cb0PSooooo2`00o`001@20`000X23`0;Ph]03XJ3`0d51h0180X23`00<0
oh000:0Pl03@D7P00P2h>;@00`2P8?00d51h0:0Pl0030:0Pl0<0^3Rd3@3oP0020;Ph]0D0X23`00<0
d51h0:0Pl03@D7P0402P8?000`2h>;@0:<Plooooo`0:ooooo`002_ooool0>P00o`00Ia`407450`1S
0@40F04105410@1E0@80J@8606`21@1a0@D0P`8;08P3301[0PH0I@8709023@2G0P`0W08;09T12P2?
0@L0R@4708X21@2E0@D0Y@<:0:X22P2/0`/0[P8:0;@33P2g1Q00/`@;0;<73`2[1a80B`P>08n@U@3L
gn40g>3R0=kRh`3Pe]/0Z3M60;/G:P2C6Rh0RG630=[Pi03NhnD0h>CV0>3SiP3SgN00/e]R0<DA5`2=
3Q<0>RP/0<K>dP3Jg]l0f]gO0=cMh03Mg=h0^j6X090M:P2W10h20:L1300L0:<2302M0P`0V`4;09`2
302F10h0BP8404493@150`P0>`4305h11P2=0P`0TP4709H2202@0`T0Q`8709P22P2L0`d0VP8=08D2
20220`P0RP<708031@2:20d0M08306D10@1V0P80HP/601O30@Wooooo00<00?l00?n0003oP0007@3o
P0001@2P8?00oh000?n0003oP000j6Pl00@0X23`1@3oP0001@2P8?00oh000?n0003@D7P0j6Pl00@0
oh0000<0X23`0=1@N03oP0007@3oP0000`1@T7Soooooooooo`06ooooo`/00?l002d08M@6075?;`1_
Dcl0Ke53071CBP1_De80JTiB06a;DP1_BU@0N51M08=II`2>Ig<0TFah09IbO@2JMWh0WWf209n0Q02Q
S8l0WI>G04AAP@017GT0;dV60;NnaP2UZjl0_/C;0:bg`02Y]kl0/lG=0:2b_`2Q/l<0JhJU0:k:i@1]
ULH0=W2d07:Te`15NKL0^]cc0=KTk03IiN`0f^K/0=[Wk@3Hi^d0enG]0=KRjP3Eh^/00P3DhNX07`3E
hNT0eN7Z0=7Mj@3=g^l0>Ffb07N[fP2>]]L0]];S0;?7e032d]`0^l[E0<;=f@2nb]H0XK6l0:Zka@2P
[k/0VJRb09>RZP2>WJD0OHnF07B8S@1cRHd0Igf106YoPP1XOH80JGj204iUK01QN7/0Jh:506IbLP0A
c@/02?ooool;003o0003052@N02P8?00X23`01@0X23`00D0^3Rd0=1@N02h>;@0X23`0=1@N0060:0P
l080^3Rd00<0X23`0?n0003oP0002P3oP0000`3@D7P0X23`0:0Pl0040:0Pl0030=1@N02P8?00X23`
0080X23`00<0^3Rd0:0Pl02P8?003@2P8?000`1@T7Soooooooooo`09ooooo`002_ooool0F000o`00
J1h407D60P1V0@40F04105@1001G0@40I04306P10P1d0@<0Q04908`23@240``0O08:09@23P2K0Pd0
W08<09P22P2<0@P0R@4608d11@2C0@L0W0470:T32`2`10`0]0@>0;L43`2f10l0/`<>0;85402`2A40
I`T@059<E03@eMP0gN7R0=gQh`3Ng=l0/eAN0<DB70374ad0J@dK0;6a^P3Pi>H0gn?U0>;Ti`3ThnD0
bIBI0;hE702b41L0@04609^LW`3IgN00em_N0=WMg`3Hfmd0e]3C09=4CP2T1A80Y@8;0:@22@2Q0@`0
W@4;09/12@2H0@P0V@8;084H7P2GHFL0I3]104L2101l0`X0T@4909411P2E0@H0U@4509L11P2I0@T0
V`4=09/23@2=0PT0O`8408421@1k0@D0MP4407D3101]0P80I`8106H>2@0F`P09ooooo`03003o003o
P000oh0001d0oh0000<0X23`0?n0003oP0000P3oP0000`2P8?00oh000?n000020=1@N0@0oh0000D0
d51h0>QX?03oP000oh000=1@N0050?n000030:0Pl03oP000oh0000H0oh0000<0j6Pl0:0Pl03@D7P0
4`3oP0000`1@T7Soooooooooo`06ooooo`/00?l004h09mP807A<:`1_E440KU=2071BB@1_DU@0JU1A
06e<D`1]BE80NU=M08AKJ02=Ig<0TFai09IaN`2JN800XH250:>4R@2QS900Vi>N020cN@069XP0CfZM
0:6Z[@2_]KT0^L;<09:QZP3?gn@0PiBO0:^ma`2P]<40/<?L086Sd@1^V<`0=g>i09K5iP2/f>/0Zm7Y
0=oXk`3Vk>l0j^oc0>C/l`3Ojo40fnO^0=_Uk@3Fhn/0en?Z0=GRjP3Dh^X0e>7Y0=7Oj03?g^/0TKWS
09g<l`2</=80W/?M09jeb02/_Ld0/l?@0<SGi02d`m<0_=3N0;73c@2V/kl0XK:l09j/^02BXZ/0PY>K
07B7S01`Q8P0K82406b1PP1YOX80IG]o05M`M01KLgL0Hg]j06QhN00RWAP8ooooo`/00?l000<0D91h
0=1@N02P8?004`2P8?030=1@N0030:0Pl03oP000X23`00<0X23`00H0d51h0:0Pl02P8?00X23`0=1@
N02P8?0=0?n000<0d51h602P8?000`20`03oooooooooo`09ooooo`002_ooool0F000o`00J1`307H5
0P1W0040FP4105@1001F0@00H`4206T10P1c0P@0PP4708`2302:0@T0R04;09<13@2L0Ph0W`4>09P2
2P2>0@T0R`4508/11`2C0@T0V0070:X43P2`0`h0]0@>0;T52`2d0PX0/@4;0;843P2a1Pl0P0XC02@D
6`2oa<P0gN7S0=[Ph03NhN@0`X:80;hK903>4Q`0U10I085iPP3OiNL0hNCX0>7SiP3Phn<0eKVk0;<M
903141T0K`TB079XKP3Jgn80f=_O0=SLg`3Ef]`0fMWK0:1YLP2O1a@0Y08;0:812P2N0PX0W`8<09`0
2@2J0@T0VP4<09<;5P2S@4`0USQ508@53P2A0@T0TP4709801`2C00H0UP4809T12@2H0@/0V`4<09X1
30290@H0L`0207L10`210PP0OP4806/10`1U0@40I04006H>2@0G`P49ooooo`03003o003oP000oh00
01h0oh0000H0d51h0?n0003oP000oh000=1@N02P8?020?n000030=1@N03oP000oh000080oh000P3@
D7P20?n000030=1@N03oP000oh0000<0oh0000<0X23`0?n0003oP0001P3oP0000`3@D7P0X23`0:0P
l00C0?n00003052@N?oooooooooo00Kooooo3000o`00C@1gCBD0Ke=1071A@P1cDdX0KU5A06iBE01[
CeH0KDmI07EBG@20EfD0SFAb09A^NP2FLgh0WGj60:>4RP2SQH`0WhZ@096=XP0:8gT00R>305aeW`2_
][X0];[00:ng_`2ia/l0YkS10:Bb^`3<f^40]LKF09ngd01GMj40d^Oi0=KdoP2>cN`0U]?_0<cXn03a
m_/0nO_n0>gcn03Sk?@0gnW`0=[WkP3Gi>/0enC/0=OTj`3Gh^`0e>3Z0=;Rj@3@gnP0cn3[0:C6j00i
MkX0UKgL0:?2f@2icMd0^lgM0:bnc`2^`=40XK?30:Zob`2`aLh0YkK10:Je_P2M[KL0RI^T08FHW@1f
Rhl0L8F807>8R`1eRHX0MXN;06YnPP1PMgT0GGEf06=iN@1UMgP0:ITS00Sooooo3000o`000`3@D7P0
X23`0:0Pl00B0:0Pl0070=1@N02h>;@0^3Rd0=1@N02P8?00^3Rd0?n000030:0Pl080d51h00<0^3Rd
0:0Pl03@D7P03@3oP0000`3@D7P0^3Rd0:0Pl0080:0Pl0030;Ph]02P8?00X23`00d0X23`00<0T71h
ooooooooool02Oooool000[ooooo00`00?l0074Q1@1m1`40JP4105`10@1J0@80GP4106P20P1X0@<0
K`450841202<0P`208/12`0D09D13@2O0a00X08@09T22`2@0@P0S@4708h1202C0PX0U@490:<4302b
1@h0]P@?0;P4302d10`0/P<<0;<53`2a10l0T`TD02X22@2IWJ@20=gQhP0d0=gQh`3G];L0[2L_0<dE
702c5A/0HdI>0=SMh03Lh^<0hN?W0=kPh`3QdmH0[c4k0<LB602F4Q/0E3U00=OMh03JgN00f=_N0=OK
gP3Hfml0[i2G09P=6@2U1@l0X@@=09l2302N0P/0W@4:09/12`2H0@/0V08=09433`2A1A40U08;09<1
2P2D0@T0U08909<11`2@0PL0V04909X22@2H0@X0V@4;09022P1n0@@0OP<607X21P1l0`P0J`840642
0P1W0P80HPT4026T0@Wooooo00<00?l00?n0003oP0007P3oP0001P3@D7P0oh000?n0003oP000d51h
0:0Pl080oh0000<0d51h0?n0003oP0000P3oP0001@3XJ3`0^3Rd0?n0003oP000d51h00D0oh0000<0
d51h0>QX?03oP000703oP0000`1XZ3coooooooooo`06ooooo``00?l004d0LeXN071@?P1eDTL0M59<
06a>C`1]CU80JdeD06U;EP1]D5`0P5UW08eSL02DLGX0UgZ309]nQ`2OPX/0XX>:0:::S`1/L9@01262
00HXP`21UkX0XZV]0<_Be@2f^l<0/K[20;o7cP3Fg><0en;X0<_Jj@3Hio00iOKm08K1i02Vg_P0/>7e
0<oan`3Nk_H0i^kd0>_`m03/loH0i^ke0>;/l`3Iinl0eNG/0=CSj`3Fhn/0e^;[0=CRj`3Bh>T0d=oY
0=?Rj`2ldNL0PJcL09k7jP1ZTKP0ZL3G0:Fib02daM<0`mCQ0;33d02]_/X0UjRc09JU[@2HYJd0UZ:/
08FFWP1fRI00MX^A06j5R@1fSHl0N8b@07N;S`1cQh/0FW1d05mdM@1UN7X0HGAd03]l=@08ooooo``0
0?l000<0^3Rd0:0Pl02P8?004`2P8?00103oP000d51h0;Ph]03XJ3`20?n000030;Ph]03XJ3`0j6Pl
0080X23`0P3@D7P00`3XJ3`0oh000?n0000<0?n000030:0Pl02h>;@0X23`00<0X23`00<0^3Rd0:0P
l02P8?004P2P8?0;ooooo`002_ooool0F000o`00M1h308060P1[0@40G`4105`10@1N0P80J08306@1
0@1^0@@0P@8808P12P2=0@`0T@8=09L12`2O0P/0W08<09<12P2?0@X0SP8:08l1202C0@T0UP8;09T2
2`2]10d0]@@>0;D3302d10d0/P@=0;46302]0`d0XPLB05L63@1OFf80fn3S0=_Oh@3Nh^D0hmWL0;QY
K`356b80baHL05hE7P2l`<L0gNCU0=oSi03Phn@0i>;U0;YWK`3751/0]a4J058D6`37c=40fmoQ0=[M
h03Hfml0fMgO0<Jj_`2>72T0X`DA0:<43`2R0@l0W`4;09`12@2I0PX0VP4:09T22P2D00L0U@4:09@1
2`2D0@P0U@4709<11P2A0PL0Q@4509<22@2G0@L0U`4809P12`2C0PP0PP4507P11P1U0`H0F04106P4
1@1S0P<0J04206D:1@0^QP89ooooo`03003o003oP000oh0001h0oh0000<0^3Rd0?n0003oP0000P3o
P0001@2P8?00oh000?n0003XJ3`0d51h00@0oh0000<0X23`0>QX?03oP0000P3XJ3`40?n000030=1@
N02h>;@0oh0001`0oh0000<0P<00ooooooooool01_ooool<003o001=05aj5@1`CCH0MU=407EDC@1[
CTd0JDa>06Q;DP1PA4l0IT]H085MJ`2:I6l0TFmf09MgP`2FNXH0Qg1l09MlQ@2RRiD0B5B600@RR@08
;X@0RIZf0=;BeP2n_<@0blcB0=SIgP3Lg^D0g^C^0>?[l`3[lOT0`]W[0;CEl02bgO00d?Ko0<_`o@27
bNH0`>Gg0>Oan03/lOP0iNgd0=gXk`3Ii^h0enK]0=GSj`3AhNX0d>7Y0=3Pj03@gnT0d=kX0<oNi`3B
hNT0`]?R06:6]`1HQ;P0Z<?M0;39g`2aa=@0[;k<09VZ]`2[_<P0Zkg60:Bg`@2Q/KX0UJBY08bLX`23
Uih0OI2G06MnP@1VOh40NXnB07>;SP1^QhP0KXJ706n6R01YO7d0HgEe061eL`1>HDH02?ooool<003o
00030;Ph]02P8?00X23`0180X23`00<0oh000:0Pl03XJ3`01@3oP0001`2h>;@0X23`0>QX?03oP000
d51h0:0Pl02h>;@02P3oP0001`3XJ3`0oh000?n0003oP000d51h0:0Pl02h>;@01P2P8?000`3@D7P0
X23`0;Ph]00>0:0Pl0030=1@N?oooooooooo00Wooooo000:ooooo`1H003o001i80<0Q0L206l10@1U
0P<0G04205h10P1Y0P@0I`4106`00P220@T0RP0<08l23@2@0P/0UP4;0:043@2J0P`0T@4909412P2@
00T0T@4709L12@2L0`d0V@8=0:422@2b1@h0/P<:0;422`2_10`0[@@;0:/32`2T10`0Pa0H04Da>P3>
dmT0fn7Q0=oRi03Ogml0gK:f0;/V;P3C5Q/0PQ0G079WL@3Oi>D0h>CV0>7UiP3Qi>D0biFL0<HK9P38
4Q`0JPXB0:V_]03Kh><0fMgP0=OKgP3Ig^00d/kB094d@02U1A80Y@<?0:<33P2M0@X0V`0:09T12P2E
0@X0U@0809D01`2D0@X0T`0709@01P2A00H0T@4509411P2@0@L0TP4809<01`2C0@H0U`4809D11`2<
0PH0M@4307@31`1O0040H04206/10`1[0P80I`d803291@Wooooo00<00?l00?n0003oP0007P3oP000
0`3@D7P0oh000?n000020?n000050:0Pl03@D7P0oh000?n0002P8?00103oP0020=1@N080oh0000<0
d51h0?n0003oP0000`3oP0000`2P8?00oh000?n0000K0?n0000308300?oooooooooo00Kooooo3000
o`00;`1TP1L0KT`e079D@`1bET`0JTm>06M:C@1WBe40J4eF06mBF`22HF`0Qf=a08m^N02DLgh0U7N3
07IQK@25KgT0Xi6O02i1Q`029i@03CR;0;2kd`3AaLT0fMGI0=cLhP3Df=h0g=oY0=kSj`3Tjo<0g>K_
0=SVl`3VnOl0[mOd03f=b`1U/=l0anki0;OGk03Gi>d0e^?/0=KSj`3Dh^P0d^?X0=GTj`3Ch^T0dN7X
0<oQj03>h>P0c^3W0080cmoX01`0cmoY0=;Pk02ec^@0K9S>096gg`1/T[D0[<7D0;O:e`2od=d0^/gK
0:Be`@2P/Kh0X;6j09:U[026UIh0O8jE07F9T01VOX80HGQl0724R@1cRXh0K8>70727RP1dQhd0Kh>5
06EjN01QN7L0DeY?2?ooool<003o00030=1@N02P8?00X23`0180X23`103oP0001`3XJ3`0oh000?n0
003oP000d51h0>QX?03@D7P00P2P8?000`3XJ3`0X23`0?n0000=0?n000040=1@N02P8?00^3Rd0;Ph
]080X23`00<0^3Rd0:0Pl02P8?000P2P8?000`2h>;@0X23`0:0Pl00<0:0Pl0030=1@N?oooooooooo
00Wooooo000:ooooo`0B003o001i8`@0QPT207D10@1V0@40G`4106@10`1/0@D0K@8407811P240P/0
RP4=08`23@2>0@`0U08<09X33@2E0@/0TP0:0P2C0@/0A02D0P/0V08<09d23@2M0`h0X08;0:`43P2b
10d0/0<<0:h63P2W0`X0YP880:P42`2G31@0>a8J0;_2bP3Nh^@0gn;S0=oRhP3XeMP0a4eF0=dK7@2c
6R40AAlX0=OHf`3RiNH0i>GW0>;Ui`3M_l@0_b@^0=@D6P2D4AT0SXR?0=cSi@3LhN<0fMkP0=SMh03J
f]h0WEQR0:P95P2X0`l0Y@<>09l12P2L0@/0V`4909L12P2J0@`0V04:09D02`2B0@T0TP4709811P2B
0@L0T0450941202=0`P0S`8909H22P2F0@T0T`8808P2101l0PD0P@<707D10P1Y0P<0J`8406d20P1U
1P@0<XP52Oooool00`00o`00oh000?n0000N0?n000030>QX?03@D7P0oh0000<0oh0000@0X23`0?n0
003XJ3`0d51h103oP0020=1@N080oh0000<0d51h0?n0003oP0000`3oP0000`2P8?00oh000?n0000K
0?n0000308300?oooooooooo00Kooooo3000o`009@0oYP/0LThe07AFA01eEd/0K51:06Q>C`1cH680
YYJJ07YNI`24Hfd0RFEa095_N02EMGl0UWN2099aNP2VPX`0Zi^X02@mS@03<:@01C6=0:FedP3Cc]H0
emSN0=KIg`3Pi>P0hnO^0>3Xk`3Ji>h0gNK`0=gZn01dWLd0S/7Z0975kP1f[N00N[3P09Nnf`3Ehn/0
0`3Dh^X20=?RjP0S0<oPj`3<h^d0bN?^0<ORkP36h_40aN7c0;oNm02hfoH0/]Sg08:fi`0JH<80LJgY
08Vjj02F`nl0NjKF07jVe`20Ym@0S:oD0:6oh02=[<P0QJ2f08VP/P25WJP0N96I06QoQ01]QHH0J8:2
07>:S@1_Q8X0LHJ<07B9S@1fRhd0Jh1o069gM`1FGE@02?ooool<003o00030830002P8?00X23`00@0
X23`00<0d51h0:0Pl02P8?002P2P8?000`2h>;@0j6Pl0?n000040?n000040=1@N03XJ3`0d51h0:0P
l0@0d51h00<0X23`0?n0003oP000103oP0050=1@N0030;Ph]02P8?00^3Rd0080^3Rd00<0X23`0;Ph
]02P8?00102P8?000`2h>;@0d51h0:0Pl00>0:0Pl0030;Ph]?oooooooooo00Wooooo000:ooooo`1H
003o001o9PL0RPP407`20`1[0@80I04306410P1X0P@0KP8507011@1k0@P0P@4<08<12@2<0@`0T`8<
0981302?0P/0T@4909802P2B0PT0T@8909H2302J0P`0V`8<0:423@2V0@`0[`<=0;043@2/1@d0Z089
0:P1202`10h0[PTE06074P2BU9l0gnCW0>3Ui@3Ri^H0j>CT0>:RY@3P?Cl0gdM=08Pg@@3;`/H0i^WY
0>KYj`3WjN/0k^CW0=YPI`3^9b/0c20S085NI@3OiNP0g^CW0=cPh`3Kgn80f]kQ0;bCVP2[41`0]PDA
0;044@2Y0Ph0X`4=09l12`2L0@X0V`0:09X12P2I0P/0UP8:09D02@2C0@P0TP4709411`2A0@P0RP87
08`12@2K0P`0V@4:09011P240PH0MP4408821P1d0@<0JP<406X10P1]0@40IP@203>81@Wooooo00<0
0?l00?n0003oP0007`3oP0000`2h>;@0oh000?n000020?n000030=1@N02h>;@0X23`0080d51h103o
P000102P8?00d51h0?n0003XJ3`50?n00080d51h703oP0000`20`03oooooooooo`06ooooo``00?l0
04d0<kh907EA=01dEDL0M5A9075BB`1YD4l0N6Y^0;>Z]01iGf`0PV1]08YWL`2CL7/0UgR40:61S02W
P8`0/HbH0:bR/P0I=XX00S2Z00HiW`2I/MH0e=;J0=;EfP3IgND0eMWT0=CLiP3;f>@0b=CO0<kMjP2=
Yl<0[<OU05J4^`1h[Md0E8g8072/h@38ho@0eNC]0=[Vk@3Mj>l0en_b0<7Wn02NfOP0P<kh06Fnm`1<
Z?40Aik_03Z<j@0`N>80:f[H02EJb`0TE<P09Tc302Q2_P0[?k40;Sf^02ll[00[=J@0:C>P02DbW`0R
<9/0836G01XaT@0L=i<08D2G02Y;VP0aDi80>UV804]/R`1UQIL0M8jH0768T01cRXh0Jh:60727RP1f
Rhh0KH>505eRGP08ooooo``00?l000<0J:Pl0:0Pl02P8?004P2P8?00203XJ3`0oh000>QX?03@D7P0
oh000;Ph]03@D7P0^3Rd0P2P8?001@2h>;@0X23`0;Ph]02P8?00^3Rd00@0oh000`2h>;@00`2P8?00
^3Rd0=1@N00O0:0Pl0_ooooo000:ooooo`0C003o0024:0H0S@P207d20P1/0@80H`8205h10@1U0P@0
J04206`11@1j0PX0O@4;07d020270@X0S`8<08h13@2<0@/0S@8;09012P0209022P1309@12P2I0P/0
W@8<0:@23P2R00/0Y`@<0;873P2h20h0_0T?0<<:4P383AD0ba<I0;8M9P2=KWT0jng`0>KZk03Xj^`0
kNg_0?C^kP3li^H0oo7b0?ofm`3oo?d0moSi0?Gfm`3cm?H0lo;d0?J/[`3jCTT0mD8k08i1B`3]k_<0
hnOX0>;Ui`3PhnH0gn;V0=o6c@2g82h0b`/H0<D7502l1Q00/`<=0:/23@2T0@/0WP4:09/1202M0P`0
V`4;09X12P2I0@P0UP4;09812@2A0@L0U04909X2302M0Pl0V`4;09H11`2@0PT0Q04608021@1`0@<0
I`8307420P1/0@40H0<103]o2P09ooooo`03003o003oP000oh0001h0oh0000<0d51h0;Ph]03oP000
303oP000103@D7P0X23`0=1@N02h>;@50?n000030=1@N02P8?00oh0001/0oh0000<0Z8Ploooooooo
ool01_ooool<003o001=02CE1`1eD2h0LeM507IFB01bDdX0JU1>06I>D@1dF640NUYW08IQKP2=J7H0
VWN40::1S02/RiH0/8nI0;FRZ@2l^<T0842D00<a[007>ZT0NIG50<W;e@37b]@0a/_E0<_Ag036cMT0
/[o80<gIh`2Z^LH0YKcB09jme`1hWLD0SKSH0;KTo019/>L0I/Wg08gInP2]i_/0T]Ke05Vkl@0VY_40
39Ob00F@mP05Q_L0>V_P08M=/`2P@i/0[SR50;X]K`2n8f00^aUF0;`GC02i6DD0]1Q20;8F@02^7TP0
Z18j0:4E?02M33L0X0Td09L>>@2=54L0QAE?07LGD`1T5Eh0DQMS03/DI00W66/04am^01lkO00aD8D0
BFZ>06=nSP1UO840IWeo07Z?U@1TM6D02?ooool<003o0003052@N02h>;@0X23`0180X23`0P3@D7P2
0;Ph]0030:0Pl02h>;@0j6Pl00@0X23`00T0d51h0:0Pl03@D7P0d51h0;Ph]03@D7P0j6Pl0:0Pl02h
>;@08`2P8?000`2h>;Coooooooooo`09ooooo`002_ooool0F000o`00Q2H708d80`1i0@80JP4106@1
0@1Q0@80H04106@10@1_0@80N04807T02@1m0@X0Q@4:08`1302=0Ph0R@4:08T12@2900P0SP8:08l1
2@2J0@/0W`4<0:D23@2[0P`0[@<=0:`22`2l2100cQ0F0=hG6P3U6Qh0jb4T0?<Z;P3`=S`0]eQ[0?kg
oP3_ko80ko3c0?7bmP3cm?H0mOOg0?_lo03koO`0o?gm0?[jn`3fmoL0m?Cf0?Gdm@3fYJ/0nU5;0?Q1
>@2Q>dD0m?3f0>?Wj03Ti^T0h^CW0>7Ti`3/fn<0`3E20=4?6P3A31T0b@LC0<D74P2j10h0/08<0:H1
2P2O00L0XP4:0:833@2P0Pd0W@4;09T12P2C00P0T@4809L12P2K0@/0W04=09X12`2H0@P0T`480882
1P1b0PD0K`8206L10`1/0@80K04105l20@1<D@`9ooooo`03003o003oP000oh0001d0oh000`2P8?0=
0?n000040=1@N02P8?00oh000:0Pl0H0oh0000<0X23`0?n0003oP0006P3oP0000`3@D7Sooooooooo
o`06ooooo``00?l004d02_H207Q>:01gET<0N5M907AFC`1/DTl0JU1C071BF01kFF@0RV9_09UcO`2N
OHT0YHJC0:V?V`2bVjP0ak2l0;fZ_@0[?hl00RBJ00DZVP1]Rkl0][S30<;4b`2m`/P0`<G?0;k5c035
cML0/lGD0:G7gP2XeOD0TL[]072kl@1<[oD09Y?]01BDlP0<Snh04J;^032/j@1G_>`0I/Gb04S3n00R
/_T039cj012;n@25D;H0jB==0>dI;`3W52D0fPlM0=H<703;1QX0aPHH0<]8D`3WZ;00YTMJ0=NKZP2i
JG/0k;c60:@^AP2Z11@0^U5K0=:Y]@3;WZ`0`HZJ0:I7G02G1A`0T@XO08@B;P1a33D0FQ1704<AE00W
5Eh052=U031>LP1JMgl0JGf204f:B008ooooo``00?l000<0:<Pl0=1@N02P8?004`2P8?000`3@D7P0
j6Pl0;Ph]0020=1@N080X23`00<0^3Rd0=1@N02P8?001@2P8?001@2h>;@0X23`0;Ph]02P8?00^3Rd
00D0X23`00L0^3Rd0=1@N02h>;@0X23`0=1@N02P8?00^3Rd00D0X23`00<0d51h0;Ph]02P8?000`2P
8?020;Ph]0X0X23`2oooool000[ooooo05P00?l008`Y2`2<2080M08106L10@1S0@40I@4306H10`1[
0@<0L`4507/22P1h0@T0N04:08L13@2<0Ph0R04:08/22@2=0@T0T04;09D22`2I0PT0YP880:l42@2j
1`d0a0T?0<P;4@382Q80d0hG0=/B6P3/7R<0mR<U0?dZ;@3m;380oCHl0>DjC03LKh/0mm;P0?Sbn03i
l_T0mo7f0?_bm`3lm_T0noWj0?cko@3lmoT0o??c0?g^k`3jd=@0lfe_0?Y9?`3k@3L0XBXb0<g7d03Q
inX0h>?W0=oRi03Nh^@0h]SO0;XoCP3>4Ah0c@hG0<X=5@352Q80_`PB0;T74P2`0`l0ZP8=0:L13@2X
0Pd0Z@<>0:H23P2O0P`0VP4;09H12P2G0@/0WP8=0:023@2O0Pd0W08;09H120240PL0I04306h41@1X
0P<0L04206`10P1K0@00ATX42Oooool00`00o`00oh000?n0000J0?n000030>QX?03oP000d51h00@0
X23`00<0^3Rd0?n0003oP000203oP000103XJ3`0X23`0?n0003oP0020:0Pl0D0oh0000<0X23`0=1@
N03oP0006P3oP0000`3@D7Soooooooooo`06ooooo`d00?l004`0Ne8V07IF@P1iFTX0NU]E07=FE01d
F5/0O5iT07mOI`2;J7D0UGIo09Z3S@2PRIH0YhjL0;2AX@32V:T0aifb02X^NP0268400aj304iTU`30
a<X0_Ko70;[3c@33e>D0[<KW07NWh@1=TnH06G7R00Y[j@09I^L0183g00:9n`05T_`03:;l02Vkn`0_
^OX0CKGc05n/k@0oR^<09g?Q035Pf014DlX0F4>f09`WNP3D43<0e``L0<d85@361AD0a`HE0<H65034
1A@0`1/^0>>Z]`2VMX/0fKO80;V;X03D/lH0V1Xk0:P2502ZBe/0[I>W08eHM`2>I7l0]i6T08/8802Q
ADl0YH^A0:Z6SP2MFFX0P0XT08<68P1R2cH06A9A01@_H@1?JGH0<j<_2?ooool=003o00030=1@N02P
8?00X23`0140X23`00L0j6Pl0;Ph]02P8?00d51h0;Ph]02P8?00d51h00L0X23`00D0d51h0;Ph]02P
8?00X23`0;Ph]0060:0Pl0030=1@N03oP000oh0000<0oh001`2P8?000`3@D7P0X23`0:0Pl0040:0P
l0030=1@N02h>;@0^3Rd00L0X23`00<0N5Rdooooooooool02Oooool000[ooooo05P00?l0080T1P27
1`40LP4106P10@1Y0@80IP4206D10P1/0P@0M04707h12`1f0@D0M`4708X1302>0@`0R`0809812@2L
0Ph0X04>0:T33@2b10d0_@H>0<H93@3@3A00fA8@0=D=3`3;1Ph0b`LA0<l:4`3G3AH0l1/P0?/V:03m
;2d0oS8_0?df>03j>T00le9Q0?AcQ`3fMhX0m7N50?J1RP3iV:D0nKK80?o3f03iZ[P0mhV@0?YnOP3l
JVH0oUA<0?m7@@3n?S/0^2Tc0:jFXP3UjNh0gnCW0=kRi@3Jgn80hMkS0;MDH`364b40b0lI0<H>5`30
21D0^PDC0;H44@2b10h0Z`4:0:T1302/0@l0[P<>0:X13@2T0@X0X04<0901202E0PP0X@4=0:H23`2Y
1A40YPL@09X22P2:0@H0M`8506d2101_0PD0N08306h10P1R0@00BTX42Oooool00`00o`00oh000?n0
000O0?n000X0X23`00<0^3Rd0:0Pl02P8?000`2P8?000`3@D7P0X23`0:0Pl0050?n00080X23`6`3o
P0000`3@D7Soooooooooo`06ooooo`d00?l004`0JWTR07=F?@1kG4`0OEiD07aMF`1nHF@0P6EX089W
K@29KgX0Tgj909R6T02KQi<0YHbJ0:V=V`2_SY`0]9>V024TK@015G`00Q^0055VW`2T[l@0Sj[E066C
fP0VJ<h025?=00=Ef`03G>P00fSf00Icn`08OO/01ggh00Mim@0;Mo405W?Y01U?a@0kBkl0JTJe08Ll
XP2G=Y<0WS6:09/`QP2<<XL0NCbD07diS`2l8Ed0haHZ0>@D6`3N3aX0g@dG0=d>6@3I2aL0e0hN0=AT
M@3:ZkP0gl7@0<2EZP3=WK@0Y1<a0;<44`2/<D40ajNf0<2]_@33^<H0_9jb094:9@2F<3d0^k_00:bf
_`2WUZ@0LAL]08L34P250a80>@do00<CE`0E;5409j/Z2?ooool=003o01<0X23`00@0^3Rd0:0Pl02h
>;@0^3Rd5`2P8?030?n000050>QX?03oP000d51h0:0Pl02h>;@0102P8?000`3oP000^3Rd0:0Pl005
0:0Pl0040>QX?02P8?00X23`0:0Pl080j6Pl0`2P8?000`1@T7Soooooooooo`09ooooo`002_ooool0
F000o`00Ob8408L80P1d0@80J@4106L10P1S0@80I@4206h11@1h0@H0Q08908<120250@T0S`8;09L5
3`2D0@T0W@<<0:@2302Z0`h0/P@>0;@3302k0`X0`0@:0<P52@3D3Pd0e0d>0</73P391Pl0cPTC0=8=
5P3]6RD0o2P/0?/Z:`3n<2d0oS4`0?da;`3n=c/0nca50?e1BP3i?TD0n4A90?A6D`3^Bf40kTeX0?58
FP3d@DT0n4930?Ll>`3g<c@0m2X/0?<Y;@2_7RX0GT5C0=GIhP3Mh^@0g>7T0=[Nh@3Mg>40Y59Q0;LA
802m31P0`PhK0;T65@2d11@0/P@?0;433P2]0Pd0ZP8=0:X13P2/0@`0ZP4<0:D02P2Q0P`0QP4408l1
2@2O0@/0Y@4?0:d85P2b51d0X0H=090220200PL0I`0106X10P1g0@80K@4206810@19BP@9ooooo`03
003o003oP000oh0001/0oh0000<0X23`0=1@N03oP0000`3oP00=0:0Pl0050?n0003@D7P0X23`0:0P
l03@D7P0103oP0020:0Pl0030?n0003@D7P0oh0000l0oh0000<0d51h0?n0003oP0001P3oP0000`3@
D7Soooooooooo`06ooooo`d00?l000`0JXLT085NB022HDh0QVEG08IUH026JFT0PFQY08M`M02:Lgd0
TWZ809MkS02IO8d209n1T00n0;6?W02hU:X08BYh00<TT`04:Y`0546Y01M=^007BLP00dS>00ADgP05
En8015OT00MFi@0:Cmd06TcB03A0^`1B=ZH0IC6H07LaT02>;hH0KAi`06HaQ@1aBIX0OVR^08J>`P1R
WML0;ICY01F>l@0@R?D06gK`07m;]03O8DL0jAHN0>0@6@3J2QP0e0XF0=885@3?2AL0_ba10>38d`3E
`<l0dZVo0;1UQ@2Z32L0/`8@0;PmB`3G^<D0a[K40<Bja`2gP9P0W@LQ09PY=`3>a<`0Zj^g0:jHY`1i
6SH0RP<F07d230152S402A9D00<DA00IW248ooooo`d00?l0:02P8?000`2h>;@0X23`0:0Pl0030:0P
l0030>QX?03oP000oh000080oh0000<0d51h0:0Pl02P8?00102P8?000`3oP000d51h0:0Pl0040:0P
l080^3Rd0`2P8?000`3@D7P0oh000:0Pl0020:0Pl003052@N?oooooooooo00Wooooo000:ooooo`1H
003o00259`D0Q0L107D10@1U0@40H04106<10@1Z0@<0M@8508011`280@T0R04:08d22P2Q3QP0/ATT
0:D74P2Y1@h0ZP<;0:X22P2`0PX0/@890;P42@2n10X0aPP=0<<:2`2j1PP0^@D;0;P53@2g10h0_0LB
0<D85@3O5b80iA/Q0>/Q9P3^9bT0kRTY0>/];@3V<380iSDf0>Hi>03U?ch0iTI40>=<B@3TDU80i55B
0>MGE`3SEU@0eDY70=e@C`3FBd`0ad5409/i@01=>4@0^l;70=_NhP3Ig^40f=_O0=WKh02AFVD0WAHS
0:@=5`2X2QD0Z0HC0:D24@2S0@h0X`8=0:<23P2S0@`0Z08<0:X13@2W0Ph0X@4;0:02302D0PT0UP4:
0:822P2T0@/0Y`8A0:X95`2Q2140S`@<07`31`1j10L0LP4307T20`1/0@80G`4004a=1`Wooooo00<0
0?l00?n0003oP0002P3oP0000`3XJ3`0^3Rd0?n0000>0?n00080j6Pl1@3oP0030:0Pl0030;Ph]02P
8?00X23`00<0X23`00D0^3Rd0=1@N03@D7P0d51h0;Ph]0020:0Pl0030=1@N03oP000oh000080oh00
0P2P8?0B0?n000030>QX?03oP000oh0000H0oh0000<0d51hooooooooool01_ooool=003o001<052T
6@23HDT0QfEC08i]G`2>L6T0QVi[085XJ`1nHfl0RFmm08Y^OP2<K7d0Sfal09]lR@2TRIL0ZY:W08Ao
[@0E=ID00bjX008`[P01<kD013g300E4cP06BM802DC<01Di_@0a<:/0DRNC070SO@218Fl0NRE`05/_
O`1>?Y40?U2[02a^c`0KQNP069;_03b_mP1T^_@0E:O_01V4l004M_@00Fkb001UkP05FN@0<cff0;DJ
E03I2QX0e0PD0=H95@3B21<0d0HC0</@702l@4`0h/[D0;nR]@3;V:l0[5Eb0:dC:`2`1140a6Mc0<2Z
^036^/P0_JZk0;AROP2V1ad0[U9K0<Jna`2l_<T0c;k>08@VA`2B11T0QP8806<45P0d3cT02a<l01:B
5`Sooooo3@00o`000`2XR3`0X23`0:0Pl00Q0:0Pl0030;Ph]02P8?00X23`00L0X23`00<0^3Rd0?n0
003oP0000P3oP0000`3XJ3`0X23`0=1@N0040:0Pl0030?n0002P8?00X23`00<0X23`0P2h>;@01`3@
D7P0X23`0:0Pl02P8?00d51h0?n0003@D7P00P2P8?000`1@T7Soooooooooo`09ooooo`002_ooool0
F000o`00Pb@508060P1c0P40I@4205d10@1R0P40L04407`110250@P0R04708T01`2C0`d0Z`/H0:P7
4`2V0`h0Z@<>0;84402b0`h0]0<=0;P53P2a0`X0/`D>0:d32P2P0PL0V@0409P11P2F0@H0U04709P1
2`2N0Pd0X`DB08T94`2`EUT0g96>0>ZVXP3_][@0lL[90??@c`3fem@0m=_I0??MfP3ahM`0lN;O0?;T
h`3biND0lN?S0>cPg03/h=l0jmoP0>KKf`3Me]D0eMOG0=KLgP3Kgn<0f]kQ0=SLh03JgN00^[6a0:n?
S`2/Ogh0YfY]0:ACF@2A4Q`0V`8<09P12P2E0@X0U`4<09d2302P0Ph0WP4=09/12`2J0@X0V`4:09h1
2P2U0@/0YP4>0:L24@2L0@h0RP8907P21`1c10P0MP@807831@1n0`D0LP8206800@1<=`89ooooo`03
003o003oP000oh0001h0oh0000D0X23`0=1@N03@D7P0d51h0>QX?00D0?n000060>QX?03@D7P0d51h
0:0Pl03@D7P0j6Pl5`3oP0000`3XJ3coooooooooo`06ooooo`d00?l004`0BK0C08MQAP2@JUD0UgIR
09IoLP2>NGH0P6Y]07aSK01hGVT0Of9_08IVM02?KW`0S7ZA06=YV@0V@iL01bnM00@d/P04=k/01C[0
00<_/`0:<Zl072bS04PZU01/6W@0PQQS07HIHP1G8g@0=cJC01iB_00AI]d03GKa00aomP0:PoT01gkg
009bmP02J_800FSa009Xl@03KO400fka00Abl@04N_800goe00AomP0PLND0ZSb:0?4M:@3c7200lQTN
0>XC6`3Y4al0g34l0?Nnc03Q`=D0h[kF0>6md`3`^=80^Bm<0;`66033BF00g<?D0<RmcP3@aMH0/Eaj
0:<97P2kNh80_[c60;ZhaP31VK@0VQPm0:D6602E0PX0E0HQ01P9<@0Q5bh02=H72?ooool=003o0003
0830002P8?00X23`02/0X23`00P0d51h0?n0003oP000oh000=1@N02h>;@0d51h0;Ph]0X0X23`0`2h
>;@30:0Pl0030=1@N03oP000^3Rd0080X23`00<0@>00ooooooooool02Oooool000[ooooo05P00?l0
084V1P1k1@40L`4206810P1C0000G@4207<1101o00@0Q`4708X11@2=00P0V@<>0:P5402T0`h0XP8>
0:/44@2_1100/0<=0;453P2[1@`0WP890:44302K0@P0TP480980202>0@D0R@4308T01P2B0@`0V`8>
09d85P1O1A@0RGj90>SZjP3Yj^X0jng^0>WZk03Zjnd0k^oa0?CdmP3`l?80kNo_0>k^l03`k_40l_7b
0?7bl`3/k>d0j^[]0>_[k`3WjN`0i>SY0>7UiP3Oi>L0fn7T0=_OhP3LhN@0gMoR0=[MgP3HgMd0e]_K
0=CGe`3?a/P0Rc8m09l23@2I0@/0T`4709D02@2I0P/0VP0909L02P2I0@X0UP0909H12@2L0@X0Y`8>
0:l55@2]1aD0V`4:08d1201f0@@0N@<606d3201@0000M`8607D10P1U0@00GPX32Oooool00`00o`00
oh000?n0000N0?n000030=1@N03oP000oh0001/0oh0000<0X23`0?n0003oP0005P3oP008ooooo`d0
0?l004`09=L808YS@02EM5X0WH=_0:NERP2=NGL0P6MY07ELH@1dFF@0OVE_07i[O@1EDWl06Bil00@X
U002:J800RVT00D[Z`0=:J<07R2>03TEM@1S4Uh0NQ9D06lJH@1@;hT093JN0114^P09E=8025kS00AM
i003G^L00EWX001JiP01H^/00FGa009am@04O?D04H_c03bWl01X`?@0O=7h06[En@11b_L07kWl00nX
oP0ATOX0NEfm0>TT@@3/62D0ha8S0=/@9@3E4BH0bA0]0<8NB@2h6Th0/QM;0:dHB@2[54@0Z```0:`6
8@2X2RP0XbMA0:PnJP2_@V`0XP//0:045P30KX80_Yfd0<jmc`2`IH<0Y`dX0:d74P2J10l0APdk00DC
DP0I63D00?l02?ooool=003o0003052@N02h>;@0X23`0280X23`0P2h>;@20=1@N0030>QX?03@D7P0
^3Rd00<0X23`0P3@D7P?0:0Pl0030;Ph]02P8?00X23`00<0X23`0P3oP0030:0Pl003003o0?oooooo
oooo00Wooooo000:ooooo`0[003o001m9@H0N@@107<10@1W0P<0E`0106<10P1i0@@0PP4608T11`2>
0@L0U@8809T32`2V2140[a8H0;0I802W2aH0Y0<@0:833@2L0PX0UP8:08/01`2D0@L0U@4609L12@2F
00T0UP4909H11P2I0@T0Y0@>0:h54@2g31L0WAHU08QUM@3^ko<0kNob0?Gen03hn?X0nOSj0?[in`3n
oOl0oogo0?klo`020?kko`80oOWm02T0noGk0?[dn`3il_X0nO?k0?G^m`3cj_<0knGa0>GNj`3Sgnd0
fm[V0=OJi03Gfn80em[R0=OLh@3Df]l0e=;H09]:F@2Z1180Y08=09`02P2N0@`0W`8=09d1302K0@d0
V04;09D0202F0@X0V`4<0:L64`2h5R80^APR0:053`2@0`/0N04507D31`1]0`D0I@<507`31`1j0@80
J@41068;0`09ooooo`03003o003oP000oh0001d0oh000P2P8?0>0?n000030>QX?03@D7P0d51h00P0
d51h103oP0000`2P8?00oh000?n0000:0?n000030:0Pl03@D7P0oh0000T0oh002?ooool=003o001<
00_f0`2=I3H0VgmT0::>O`2]XYd0UHB307eTI01lHfD0NF=_05UDL`0L:6T00aUf008QS0028YL01B2E
01TKR01:5W<0MQ5F07T:@@1U3dX0>aMW01`XS00<<j/024C:00A<f002Am800DSC009:f001Dn000V3[
005Zl@03MoP01HGj00JHo@0<Z?h09[_j05O@n`1^boH0Gkcd03jZlP0CT_<01XWg00>2o002MOT00fcf
01YMhP1X?Il0NC:106XbQ01K<8`0D3BG04DdV`0o=Il0>3:R038_W@0^;YP0;BVB02hVR`0_8840<Qag
03LGK0135VT0DAIQ05dAD@1[3Cl0N@`i08@?>@2N<5H0YB0o0:/87@2[1A00T0HH030CD00466P03aY4
003o00Sooooo3@00o`001@0Xb3`0d51h0:0Pl02P8?00^3Rd01h0X23`0P2h>;@00`3@D7P0X23`0;Ph
]00N0:0Pl0030?n0003@D7P0X23`0080X23`00<00?l0ooooooooool02Oooool000[ooooo00T00?l0
07/Q1@1h0`40N@8207T20`1`0@40M@4408011@250@D00P2<0PP0202?0@T0S`8909T44@2O2QL0Y1@Q
09X85P2E0P`0U08;0P2>0@T0=02E0@P0X0880:X32@2g2@d0`0l@0;`83@2k1Q00_0D?0;l84P332QD0
b@hJ0<HE8@2U;DL0gIVk0=nJ_@3ZWl40l:G20?6U_`3bY[/0lJVe0>j^^@3/]<80j[320>RQ/03[TYl0
k8B@0>ihQ`3^KH80kfUo0>eVNP3/Fg@0kUeg0>QEL@3ODg<0e51e0<eGN@39HX40aF^:0;e]RP2mMi80
_hJS0<JB[P2cAe`0]0DB0:l33@2Y0@X0Z@8;0:L23@2T0Pd0X@8=09d12`2K0@X209X12`0=0:844@2[
2aT0Z`lK09P33P1n00L0M`@:07T2201g0PD0M@8408L21@200@80L@4106L90P09ooooo`03003o003o
P000oh0000/0oh0000<0j6Pl0=1@N03@D7P03P3oP0000`3XJ3`0d51h0:0Pl00N0:0Pl0d0oh0000<0
j6Pl0?n0003oP000203oP008ooooo`h00?l004/0TVPc09IlH@2MS8<0_;Jg08ajN`25KV`0Ofia05ED
L`064eX00QEc008JP0026hL02AN502dAK`1b3U40S0e105`9B@0U35d041Yo00D/X004;:/01CFh00E4
cP02A=40047<009@f`01GNX0173f00=mo007S?l01iCo00RJo`04V?d00Y;k00B?n@04ROT018Gi00=l
n`01Mo/00GGk009_nP01J_H00FCb005Jj002FND02ECH00U=cP07BL`01DG900=1a@05A/T01D?600A1
aP03?l400SZk008e]@02<:d00bfT008YW@039YP01BJJ00HTU@098i003Qf201LIM@0/4f80D`i;088>
<`2L2b<0X@HF08<87P0O55L00amb00/MCP00o`002?ooool>003o00040=1@N02P8?00X23`0?n00440
X23`0P3@D7P30:0Pl003003o0?oooooooooo00Wooooo000:ooooo`1H003o001g8@<0M`@108410@2<
0@<0Q`4108010P240PH0Q`4508P21`270@L0P`8807d11P1n0@/0P`<@0:0B7`2R3Q/0V@@@09L12P2J
0@T0Z0<=0;433P2h1Pl0^`H>0;`72@3740h0_PD90;L22@2g0Pd0]P8<0;d440362aH0b@/F0=@E903L
7c<0hB@i0>T_AP3gB5X0neEM0?]QH@3mN6l0nXb90?NMY`3fXK<0miFQ0?MjN@3kIEh0o51:0?a4@`3l
@3d0nS/i0?L`<@3g;2d0lb<W0>`N9@3U6240gaHR0=LF9P3@4R@0bPlQ0<8>7P2i3B<0/``T0;@76P2g
1100[P4<0:/12`2Z0@X0ZP4;0:P22`2X0Pd0YP4:0:812P2N0@X0W@4<0:02402W21D0Z`lM09`54@22
0@T0H@8406@21@1^0PH0NP8508T210230@80M`4106d;0`Wooooo00<00?l00?n0003oP000303oP000
0`3@D7P0j6Pl0?n0000=0?n000030>QX?03oP000^3Rd00L0X23`00@0^3Rd0=1@N02P8?00^3Rd0P2P
8?020;Ph]0P0d51h0P2h>;@20=1@N0030;Ph]02P8?00d51h00d0oh0000<0^3Rd0?n0003oP000203o
P008ooooo`h00?l001l0IYHR09=cF@2EPWX0[JBR08n0O02<PH80FEem00/MIP015Fh00QIg00@DM@0C
3F00@`Y<074<@`1J3Dh0;aI^00lJP`078Y<00b:J008UX004;k000Sc300AAf`02DM`00e[U00E^m`04
L_`01G_n00Ano@03N?`00GGk00800WOk02X00WWl005fnP01LoX00Voj009VmP02I?<00VGa009Sk002
H^T015gP00EIfP06F]@02EK:00aC``0BD;/05U2c01aB[`0REJ/0:5JU02eJY@0]Fj@0:eRN02YDV@0X
D9809db>02E8R`0P@hL063j7018hR00=<8H01RJ200@SQ006888031em01lLL@0i5Eh0GA=9068>>00B
4e/00b=g010RE000o`08ooooo`h00?l000@0d51h0:0Pl02P8?00^3RdAP2P8?000`00o`3ooooooooo
o`09ooooo`002_ooool0F000o`00N2P707T4002:0P<0U08209P10`2@0@@0Q@8508821@210PP0P@87
07`11P1k00H0N`8907X33@2S7BX0X`lK09`3402O0`l0XP8;0:d22`2^00T0[`490;<12`2l1`X0cQPD
0<TC5@2m2180_0PD0;T64@2f1100^PLB0;h74@372aH0a@XF0<@=6`2n2QT0bADQ0=`R;P3Y:SD0mCLn
0?Pn@P3h@4H0n3i90?Dg?P3j>S/0nSLd0?/];P3m;2/0nBPZ0>lP8`3Y7Ql0haXM0=dF7@3B41T0c`lH
0<L=5`2m2QL0_0PD0;X74`2d0a00/@8A0:d1302^0P`0/0@?0:P2302V0@`0Y`8;0:T33`2X0@`0YP4;
0:D12P2Q0PX0W`8909h12@2P0@d0XP4A0:434`2J0Q00S`0;08042P1U0P<0H`4307<210260P<0PP42
07P10@1_3P89ooooo`03003o003oP000oh0000`0oh0000<0X23`0=1@N03oP0004@3oP0000`2P8?00
oh000=1@N0080:0Pl2X0oh002?ooool>003o001;02SJ3@2>JdL0SgEY0:BIU02BU:40=D=b00/NK@04
7H0011Mi00h<G@0h2T<0D0L]03X8=`0I4FD02B>B00<VW`018Y/00B2I008SW`01:JL00SRi00A>eP05
G^T0167^00AVl`02J?L00V?c009Rl`02IOD00V;b005Ol001Gnh00V7]009SkP02Hnd016K[00ETi`09
H=d04V7C01eWc00^Kl<0?GFi04aj/@1HP:/0IHBW07:;Y01gSZ80NhfM082DWP23UZ40P9BL08JDV@28
UYd0Q9BK08JGW@22TiL0MhR=07N9S`1kRi40LH:706^2Q`1/Q8P0KH:;065gR01@Igl0@UUl02Y6N@0E
=7P02Rak00XZP`0>9h8012J400<[Q00J:5<00?l000Sooooo3P00o`00101@T7P0^3Rd0:0Pl02h>;A6
0:0Pl003003o0?oooooooooo00Wooooo000:ooooo`1H003o001j:P/0O`D109010P2G0P80W@@609T4
1`210P<0MP0307X2101m0@D0OP4708H22P2>10h0T0LB08d84P2@10h0T`4:09X12P2V0PX0/@<90;<4
2`2j2A40/@@=0:`42`2X10P0X`<909d12@2K0PX0VP4909`1302O0@h0Y04>0:/44@2a1aD0/`PF0;@8
5P2k3AT0bQDT0>0P;03d;cD0nd<n0?U8@@3hAT00n4Dm0?Q3>P3i?CD0nS8]0?/`;03f:RT0mRPY0>TM
803T6R40gaTS0=0B703:4A/0`PdG0;L84`2c1Q40[`D@0:T23@2W0Pd0X`4;0:@12`2Q0@d0V`4:09X0
2@2K0@T0W`8=0:<13P2Q0Ph0W08:08h11@2G0PP0WP4909l12P2O0@h0WP<@09L12`2B0@P0R`8807D2
0`1b0@<0M`4407d20`1l0@80MP8106lB0@Wooooo00<00?l00?n0003oP0007`3oP000103XJ3`0oh00
0?n0003oP0030:0Pl0060;Ph]03@D7P0^3Rd0=1@N03oP000j6Pl1P3oP0000`2h>;@0oh000?n0000P
0?n000Sooooo3`00o`00<02JQ4T0RVaJ092:T@0c>W@0BAUJ06TDD00W4VP0;@eK0548<@0l1S4040I5
00DGLP0299800RVR008ZYP02;Zl013Fg008g_P05@/L00T340092b@02B=<00TgH009EhP03E^H00UST
009Hh`02FN<00eSO00=FfP06F]/02ekC01UUb@0cMLD0CH6l06N>^@1lU[D0SJ2`09>R[@2GY:/0Wjj^
0:Ba/`2R[Zl0X:f[0:6ZZP2U[Jh0Zk>a0:jg]P80]Kfo01P0^Kjo0;Rl_P2j_Kl0]kZk0;Rl^@2g^K/0
/kNi0;6d]`2_/[D0ZJj`0:2XZ02OZJX0WZVY09NSX`2>Vi`0QiNH06j3R01NLgh0BVAm0214N`08<hT0
1Rj001M[<P00o`08ooooo`l00?l000<0^3Rd0:0Pl02P8?009@2P8?030=1@N080^3Rd2@3@D7P00`3o
P000j6Pl0>QX?0060=1@N0X0X23`00<00?l0ooooooooool02Oooool000[ooooo00X00?l008Hf5@25
1`80VP<409L41@2720P0RALI07L2101b0080N@440P1o0@L0C0220@H0R@4808X12P270@L0R0870941
1`2L0P/0Z08=0;053`2O0P`0UP4809412@2>0@T0S`0908`12@2:0@P0R`0808l12@2H0@T0Y@<=0:h4
402f21<0`0/F0=0F7`3M82H0j2/b0>P_>@3cA4L0nfiW0?bGR03i[jD0n[Zh0?Zg]@3jYIX0oXek0?iU
F@3oDT/0oTQ40?i2@@3m>S`0nc0e0?P[<03`9b`0iR0V0=lL8`3E51h0b0dH0;`8502g1A40]@D?0:d2
3@2X0@h0X@4=09d12@2K00P0V04709H12@2H0@/0V@4<09H12@2A0@P0U@4;09P12P2I0@X0U@4:09<1
2P2>0@@0R`4208`21@240@D0OP4507/1101e0@80L`8206h30@1^60<9ooooo`03003o003@D7P0oh00
00<0oh0000<0j6Pl0?n0003oP0006`3oP0000`3@D7P0^3Rd0:0Pl0030:0Pl0@0d51h1`2P8?000`2h
>;@0d51h0?n000020=1@N0030>QX?03oP000oh0001/0oh002?ooool?003o001:05?<902<KET0@cmS
06LJB`2S2b80[0LF08D7;01K2CD08`U300LBI`025WH00R6<004XW@03;jL00c>a008g^P01=[T00cVo
008k_`03>[/00SFe004j^`02A<L00e3E00=BeP06E=003EW7029T`@12MKX0EX2h06Z;]`26W;@0TZ:^
0:Nc]`2c_K`0_<?20;Rn`@39cl/0eMSH0=OKf`3JgMl0dM;G0<S9c`32_lL0^;6h0:jUZP2PV9/0UXf>
08^1Q@24NGl0P75e07eaK`1lK6/0OFeZ07IZI01gJVL0MVYU07A[I@1fKFP0MVeY07E_J@1jM6h0OgYg
08V5P@2DU900Si:@08N?RP21RhL0M8>0069eMP14GF/07cYE00n^4`00o`08ooooo`l00?l000@0T71h
0:0Pl02P8?00X23`0P3@D7PK0:0Pl0030=1@N03oP000oh0000H0oh001P3@D7P@0:0Pl0030;Ph]02P
8?00X23`00D0X23`00<0D91h003o0?ooool02_ooool000[ooooo05P00?l009A770222`40XPL808d3
0`2D8B<0S1/R07D2101j0@<0N00207h11@1i0080O@4408D120260@T0R0<9094>4`2F2a@0V08?0:03
4@2K0@h0SP4908T01P2<0PX0SP0709D01`2H00L0W0480:412P2T0PX0[P<<0<4:503<3aT0fATQ0>/U
;03`:Bl0mc8i0?Lf@P3f>DP0nDIA0?]QIP3jOGd0m8F?0?B4V03aMh/0l6Id0?AHFP3f@T40nCPh0?`i
>@3k=3H0nBdb0?/]<P3f9b`0lB<Z0>PM9`3T6bH0g1DQ0=HD803<3QX0b@`J0<H95P2o1a<0]P<@0;01
3P2Z0@`0Y@0909l01`2M0PP0W`8=09/1302G00L0U@4908`22`2C10l0W0<E09@1402@0@X0RP4408L0
0P2<0@@0S04508<1101m0@80NP430741001e30<0KQ/32Oooool00`00o`00oh000?n000030?n00003
0=1@N03oP000oh0001T0oh00602P8?000`3@D7P0oh000=1@N00>0?n000030=1@N03oP000oh0000X0
oh002?ooool?003o000g00gi1P1jKTl0CQi80:PA8P2b31<0/@TA09<67@0Q3d`00aM[008OO@017800
0RJE00</Y@02;:T00B^[008a/`02;kH00cJk008f^@03>[P00cZg00<o^@08AKP085Zf04Ul_@1dUk`0
W[320;>maP2i`L@0^;o10;_1a032alL0d=GD0>3Qi03MgN<0e=3I0<>lb@2c[;T0WiNU08J1S`1fM7d0
Kfmc06][K`1UIf/0JfaV07M`I`1gLF@0N79T07UaHP1iKf80N6iQ07]cHP1hL5h0Ng1P07M_G00207I^
F`0A07I_G01fKUh0LfiL06aZF@1]JUX0K6MH06QRE@1SFe40IEa>06IQE01ZIUP0K6]O06]_I01LIed0
AeY>01nQ6000o`002?ooool?003o000402S8?02h>;@0X23`0=1@N080oh0000<0d51h0:0Pl02P8?00
4@2P8?020=1@N0030>QX?03@D7P0d51h00<0oh0000@0j6Pl0=1@N03@D7P0^3Rd8P2P8?000`2XR3`0
0?l0ooooo`0:ooooo`002_ooool0F000o`00BJH608DU3@2G1PD0Q08207`31@2610P0N04308d31@25
0@<0QP8508`220260`L0O`4608H33@2H4Ah0Y24_09/F8`2D1Q@0TP4=09812P2B0PT0U04709d22P2Z
1@d0]@T?0;d@4P2h2Pl0/PH?0:l63P2/0`/0/PL@0;/9502k1a80`@TF0<@<5`3731P0cA0N0=0@7P3O
6bH0lBLa0?Hf?03i@TH0n45:0?Hi@P3h>3`0mc@b0?/b;03j:R<0nb/W0?TX9`3f8RD0mB0S0>dJ7@3V
5A/0gA8I0=<?603;31P0``PD0;l64`2l1140^P@?0;L23@2f0`h0]@8>0;82302^0`/0Z@490:L12@2V
0Pd0Y08=09l22`2H0@T0Q@8808T3402O1a/0W0HH09D23P2=0@L0Q`0508T21@2<0PD0QP4208420P1o
0P80M@@107PF2P1=E049ooooo`03003o002P8?00oh0000`0oh0000<0d51h0:0Pl02h>;@04P3oP000
103XJ3`0d51h0=1@N03@D7P50:0Pl0030=1@N03XJ3`0oh0001X0oh0000<0j6Pl0:0Pl02P8?002P3o
P0000`3@D7Soooooooooo`06oooooa000?l004T0PWU?07hI=02^6Qd0hHB70;M2C02X2Q/0DaMB00PT
Q`02:9800RZG008XVP029Z000RJQ008ZYP02;Jh00S2c004a/003=:h02CVW02UDY`1PPKH0VZg50<?<
d03?e=40eMOC0=cNg03Ph^80gMgQ0=;?f@36`lh0[J^d092>V@21OXP0PGn808B4R`2;Si<0Qhj@07f4
QP1TLG40H6m_05i_K`1MK6l0Gfa]05iXG`1UJEd0Lg=T07QbG`1gLEd0MVeM07I_FP1gL5/0NVmO07Q`
G`1fKe`0MFmL075[E@1cKUT0Mg5P07I_H01dKF00LFYK06iWEP1_JeT0JfIE06USCP1WIE<0EeY:04U=
@P17BT00FUi=05YOC`19F3L01O<200Sooooo4000o`001P2h>;@0X23`0?n0002P8?00^3Rd0=1@N0l0
X23`00<0^3Rd0>QX?03oP0000`3oP000103XJ3`0d51h0=1@N03@D7PT0:0Pl080d51h0P2P8?000`2h
>;@0:<Plooooo`0:ooooo`002_ooool0F000o`005nl607@/2P231P80NP4207@10P2410H0N@840:06
2P2Z1PX0X@<809/42@2:0PL0O`8708H33`2D21P0X1TV09XA7@2@0Ph0S`8:09X22`2N0PL0XP870:L3
2@2T0PX0XP<909X21P2A0@@0T00608h1102B0@D0W08:0:@1302_1100^`D?0<L:4P3B41L0hQ/P0>PQ
903d<c00ndM00?MGD03dIf00mWei0?J5P`3gOGT0nVeR0?aJC@3mD3l0oT]00?i6>`3m?S<0oSX`0?/b
:`3i9bH0mB8P0>XI6P3J41P0d0hI0<L:50342Q<0_0H?0;P33@2e0`d0/@4;0:`1202Z0@P0ZP4:0:P1
2`2X0@`0Z`8=0:P12`2R0@T0V`4909L2302M0a<0VP8B09P23`2?0@X0Q08706l10`1o0@D0QP4508P1
0P260P<0N@L306TB0P0^W@09ooooo`03003o001@T7P0oh0000`0oh0000<0d51h0;Ph]02h>;@05P3o
P0030=1@N0040;Ph]03@D7P0X23`0;Ph]0@0d51h603oP0000`3XJ3`0d51h0?n000090?n0000306RX
??oooooooooo00Kooooo4000o`00B@1_X2D0U1hJ0;UMG@3EYZl0chbI0:LA7P2K2RP0=aa_00@VU@02
9YT00RNK008VX002:J800RRN00@[X00:<9d0842I04iUV`27TZ/0ZJjf0<71a@3=b/`0d<oA0<[9c`2g
/[X0XIFO08IkQ01bK780JFM]06Q[K`1XL6l0LGYg06YcKP1ZKVP0JV]Q06UZG@1/JUh0L6aN06e/GP1Z
Ie/0FUeG04=?C014DE00D5eK05eXG@1/K600LfeN07=_G01gKel0MFiJ07E_F@1fKeX0MfmM07E^FP1d
KEL0MfeI07E]F`1dKUl0NWIW07I]H01`IeL0KVUH071YEP1]IeL0JVE@06QXF@1CE4h0<c/f02hk<@15
CSh0EUM505]J@`0Fd``02?ooool@003o0003091`N03XJ3`0^3Rd0080X23`00<0d51h0;Ph]02P8?00
302P8?030?n00080d51h00<0^3Rd0:0Pl02P8?009`2P8?020?n000040;Ph]02P8?00X23`052@N0_o
oooo000:ooooo`800?l005H0FfH707`90@200P80K`0007L41@1b0P80Y@P;0:h3202^1Pd0VP4708H1
1P1m0PP0QP@?094:5`2C3QP0S0<;08d12@2@0P/0U04709/01`2O00@0XP050:001@2I00@0U@4209T2
0`2M0PD0W0050:42202g1@`0a`/E0=@@603U6A`0kQhP0?PY:03n=cD0odQ30?mJD@3oNG40oinN0?o:
c`3ognX0omcY0?oDgP3oZ:H0ogM^0?iUF@3mEd/0oUE60?i=?P3n@cP0oST`0?d]:@3n:bH0nb@Q0>`K
7`3Q5R40e@lI0=<@6P3<31H0``HA0<08502h10h0/P890:d02`2]0@/0Z`4:0:X12@2]0@T0[0090:D0
1`2R00D0W`4809/12`2G0@X0T`4;08`21`260@L0L`8507`1102400@0R`4408`20`1m1`80KAD000oU
0@Wooooo0P00o`000`3@D7P0oh000?n0000Q0?n000@0X23`00D0oh000=1@N02P8?00oh000=1@N004
0:0Pl0030=1@N03oP000oh0000@0oh0000<0d51h0?n0003oP0006P3oP0000`1@T7Soooooooooo`06
oooooa400?l004P0NFdC0<J8R03R`l`0gkG30:/Z?02b1Q@0PA1001<MQ@029YT00RNL008UV@0499<0
6SB804M@Q@1]JHP0R7^=09>7S`2LU9L0XYnT0:BNXP2?R8X0NFmb06mSI01fJ600PWMZ07AbJ@1QJfP0
F6UY059QHP1NHUX0IVMJ07IdI`2?SGl0Zj^O0<K3``32_[l0/ZRT09f=Q@2FPW@0RWQY07ibH@1_J5P0
DeQ;04iJDP1UJ600MgI[07EbI01gKeh0M6eH079/E@1eJeL0MVUG07EZEP1eK5D0MF]H07M^FP1bJUL0
M6aM07Q]H01jKEh0MVmO079/G@1bJel0IfAE05MID012A3X0?dHj04AA@P1<F4l0H6MJ05UH@@0Ge@h8
oooooa400?l00P2h>;@0103@D7P0X23`0:0Pl03XJ3`=0:0Pl0030;Ph]02P8?00X23`00/0X23`00@0
^3Rd0=1@N02h>;@0^3Rd702P8?020?n000050;Ph]02P8?00X23`0:0Pl01@T7P02oooool000[ooooo
0P00o`00EP0h_PT0N@l108`5101g0`<0Ka8B07<61@2X30d0Y`860:P22@2S10`0P`8506D1101m0P/0
P`L?08@53@250@H0Q00508H11P2=0@H0Y`8;0;D43@2l1@`0aP/@0;X5302k2`d0`@h@0;d83@2l2140
_`lH0<T<4`3F4AP0gQ<I0>LJ7`3[7240n2LX0?db;`3o?SL0o4@o0?a;C`3iDUd0mEa[0?ITN03cFVd0
m5MV0?]IG@3kCT`0oTi:0?a6@P3nACh0o3/d0?hg<03m<B/0nR@R0?DO703a6QX0iADK0=H?6P3@3A/0
b@/H0;`:5P2f1a@0^`HC0;X54@2g0`d0]P8=0;T33P2m1A00_`D>0<D:4@2k1@h0ZP480:@11`2P0PH0
VP4609L01`2C0@H0S@4408X110220@D0P`4408@110270@@0RP<507l:101_6@000?l02Oooool2003o
000306RX?03oP000oh0001T0oh0000<0j6Pl0?n0003oP0001P3oP0000`3@D7P0X23`0:0Pl0080:0P
l0030=1@N03oP000oh0000H0oh0000<0d51h0?n0003oP0006@3oP0000`00o`3oooooooooo`06oooo
oa400?l004P05N/70<VBSP3L/l00`FMk0;D?7@2j2@l0W@hZ02<LN00299<012F>01H^O`16BWH0LFAd
07m^M@22LWD0R7Ml08IkOP1hLG40KF9M071RE01iKEL0OW1I081aF022LU/0LV]M05MMF@0kC4T0?e18
05eTF021OW40UI2509^GTP2DSh`0R8>308N1PP23P7d0OgYf075aJ01NG500GeM6079PA01kHdD0LVQA
04aDB@1;EU00HfQK07QhJ`21OF`0Mg9M07I]EP1hKEH0MF]F07AYE01eK5P0N71N07A]F@1fKU/0LfaI
07M/G@1iLF80Mg9R07EcI`1YJ5l0GUU?059?@P1EED@0Ee];05IPDP1FHEL0IFaT06=OB`0Ge0/8oooo
oa400?l000L0:<Pl0:0Pl02P8?00X23`0>QX?03oP000d51h01<0X23`00<0^3Rd0:0Pl02P8?008`2P
8?000`2h>;@0X23`0:0Pl0040:0Pl003052@N?oooooooooo00Wooooo000:ooooo`800?l005H03?L4
080P1@2G3@@0U0P:09Pl@0213@l0X@@70:D21`2W0PL0/@H=0:852P1m0PD0NP4507`10`220PH0Q`47
08X21`2;0@H0UP480:l43@2m1Ph0c0XB0</94P2i0`/0[P<:0:L22@2S00P0X08:09l32`2]1Q40]P<?
0;h7403;2Q@0bP@?0>`L7`3j9R@0nBPS0?/Y8`3i9b<0nRPX0?X[:@3l;R/0o2l[0?/^;03e9BP0mbh_
0?dg=03l<c00nc0`0?`_;@3h:BH0lR4Q0>lL7`3`7R00kAXM0>8D6@3821<0_@HD0:@4402`7bd0/2He
09h33P2/0Pd0[`8<0;P33P301Q00b@XB0=4>503C3Q80b0XB0;422`2V0PP0W@8509T1102G0@@0U@85
08l21@2C0PD0T04408/10P260@<0P@4408031@1l4@D0AW80003o00Wooooo0P00o`001@0Xb3`0oh00
0?n0003oP000j6Pl02@0oh0000P0j6Pl0?n0003oP000j6Pl0=1@N03XJ3`0oh000>QX?0X0oh0000<0
^3Rd0:0Pl03oP0005P3oP0000`2P8?000?l0ooooo`07oooooa800?l004L0^YEe0>2L[02e:SH0ba<C
0;4@7@1N75L03RF600lZO00e?VT0Fe=Q06aNHP1cIVD0MVeX071WG`1ZHEH0Kf9A07UZDP25M5P0RWQJ
08QeF@20LET0PG5E081aDP1cJE40DU93061SEP1`L680N7EW07QdJ01hNFd0Q8Mm07EmM`1YMFh0I71Y
061ZH@1VJEl0HVMJ061QE@1OG500NFeE085WA`1hGch0LFeH04M?B01:E4/0HfMG07EcI01oOF`0NW9M
07Q]F01eKET0N6aG07I/E01dKET0MFeF07Q^F@1gKU/0NW1P07QeIP1fM6T0KFeU05aME`1LF4`0JF9C
06UUE`1WJEh0G6EL05mWH01SIel0Iea201cF2@08oooooa800?l000D0^3Rd0:0Pl02h>;@0oh000>QX
?00C0:0Pl080^3Rd302P8?000`2h>;@0X23`0:0Pl0020:0Pl0030;Ph]02P8?00X23`01P0X23`00<0
D91hooooooooool02Oooool000[ooooo0`00o`00E@29>@h0VQL809@40`2A61D0T@T609T20P2P0@<0
Z`880;T62`2j1P/0]`P=0:<4202B0@D0U08809P12@2K0`/0UP8809T22@2T0`X0[@<:0<073`372Q40
`0T@0;072`2P0@L0U`0709<11`2A0@H0X`<90;L83@3A5QH0hQlJ0>HS7@3[:B80ib`V0>Hd:`3P=B/0
fS`a0=11=`3CB3h0d4]20=1?A@3<CDD0aTU10<1:?`37D4H0bDm60;i4?02j@3`0]S/f0;4b<02d<C00
/RTW0;LU902k8200]aPJ0;4C602B3a<0YS8j08`9502O2@l0/PP>0;`940312A40`@T?0<@7403?31D0
d@hC0<L;4P2_0``0X04909L11P2E0@L0U`4709D21`1n0@<0TP8909<11P2<0@80R@4108@10`1j10@0
MQX701c90000o`002Oooool3003o02D0oh0000<0j6Pl0=1@N03@D7P02`3@D7P00`3XJ3`0oh000?n0
00040?n000030;Ph]03oP000oh0001H0oh0000<0D91h003o0?ooool01ooooolB003o001706jO:`2f
GEd0^R//0<<J8@1Y:V<04b^002DfJ01>BeD0GEEC06=KEP1WGeP0JV5?06mQA@1gIDH0PFm>08McD`28
LU<0RGAE08MdDP27Le40PW=J07i`EP23M5L0NVY=07U[C`1kKUH0LVQB05UHC010DDd0BVAU055WK011
EUP0D5]C06EUEP1iN6D0TI5o09jLS@2BRH40OG5Q07m]E01oJT`0OfQ607MS@P1cL5h0DEQ?06i_H`1c
KUh0M6eH071YE@1cJUH0OG=P07U[EP1fI4T0LfUA07I/F01nLV@0O7AX07QdJ@1^KV@0Gf5J05]MF@1P
I5P0LFmR07MfJ@1aLVD0J6mT06M`J@1VKF<0If9B075W;@0:m`@02?oooolB003o0004091`N02P8?00
j6Pl0>QX?1L0X23`00<0^3Rd0:0Pl02P8?009`2P8?000`3@D7P0:<Plooooo`0:ooooo`002_ooool3
003o001C05eU0P2>5@@0R`8108H10@2D10<0V`420:D11@2a0`L0a0d?0<07303:3A00a`d>0:P1102N
0@L0UP0709<01`2A0@P0U@490:l7402h1a00`@/B0<<;4@2o1`d0`PdA0;`?4@2^3A40XPd?0:@G502g
:240_BlU0<<m<038Cd00aUa<0<IZFP34NFd0`hQk0<>@P`33X940_JFF0<:ZW@34[Z<0a[BX0<>cYP2n
[j40^:fP0:nVV`2`YIT0ZJ2D09nER`2KT8D0W8f509J4N`2IP7H0UgU_095/G`2DHU80TUI708A@A02H
MG40GbPT080S702G5a<0Z1DD0:d@402l4a@0aPlB0<h?5P3>3Q@0b0dD0;L73`2Q0@/0V04;09@12@2G
0@L0U@4608d11P2E0PT0T04608d10`290@80P`4107L60P1^7`D00P00o`09ooooo`<00?l000<0d51h
0?n0003oP000703oP0000`3@D7P0X23`0:0Pl00I0:0Pl1P0oh000P00o`08oooooa800?l003l02O@1
09=/;@2c>C@0T3=N02<fQ00m@EP0Ed]006=JB`1YH580KF9<075O@P1iHS`0PVY608Q_CP27LU@0QgMK
08EeEP29M5D0RWEF08MaD025Kdl0PW1@07m]C@21K4l0Pfa:07m^CP1_ITl0FUU805iUF01]NW40OhZ7
096GT@2PWiT0WYbH08n@S024R840S8V707]hL020MFD0QgMU0960J@2=Nf00NV8i07=Q>`1^JUL0Jf=C
07IXB`1eHd<0MF=:075SB`1hL5X0O7=P085aFP1jKUP0MVaI06eUDP1WHE<0F5eA05ENEP1LIUh0K7=V
07IkKP1lOW<00P1eMfd01P1bMV/0KG1V06mZFP1]JS@06^<8003o00Sooooo4P00o`000`0Xb3`0X23`
0>QX?0030:0Pl0030;Ph]02P8?00X23`0180X23`0`3@D7P01@3oP000d51h0;Ph]02P8?00^3Rd00L0
X23`0P2h>;@I0:0Pl00302S8?000o`3ooooo00[ooooo000:ooooo`<00?l005<0CIT807`J0`230P80
S`D309`60`2T0P80[0@60;8310394A40`0L:0<X=3P3>3Ph0a0X=0;<72P2N10/0V@TB09d;4P2T1a00
/0P@0;093`2/3@l0Z1@C0:0L6P2P:bD0Xd0d0:5<@P2OFD`0WfYM0:=fJP2RPGH0X8Yn0:6BQ`2PUhd0
XibD0:NSWP2/[:H0];Na0<76_P3=d<P0f=WB0=OGd03If]@0f=WB0=?EcP3<dLX0`/W30;W0^02e_KL0
YJj[09nZY`2HX9l0T9RE08bAS028SXP0Q8V307j0M`1mOG40NWe`07EiKP1hM6P0Og5R07mUE`23FTd0
PDXm08m2=`2M<BX0Y2<Q0:hK6`2f51H0[PX@0;<;5P2U1A80V04=09P12@2G0PP0U04709811@2A0@D0
TP<408`10P260P<0N@X404QT0@02003o00Wooooo0`00o`000`2XR3`0oh000?n0000E0?n000<0d51h
00<0^3Rd0:0Pl02P8?001@2P8?040=1@N0030?n0003XJ3`0j6Pl0080d51h0P3XJ3`40=1@N0`0X23`
0`3@D7P00`3XJ3`0oh000?n0000>0?n000030=1@N000o`000?l000Sooooo5000o`00@`1jFaH0G4Aj
03hlE@1VDSD0KUTk07=UB01aHdL0N6Q707e[BP23LE40QWAF08MfF@2;N5/0RgYK08QfF@26L540RW=@
08I]BP25KTD0Q6i407m[B021LE@0QW9?081ZAP1lJT`0NfU<085^E02BPGH0VXfA07adM`1gLVd0OgIW
07M`G`2IUHP0[:BL09B:O@22MF<0QgUV08QoKP2JU900RW]Y089/B@1`Gch0MVU>07]T?P1kHcd0LUm1
07IWC01mLV40OW9R07e]E`1aHdX0J5m6061PCP1JHeP0FVUS06AdK`1cOgP0NH1g07Z0N01jOWP0Mgad
07IhKP1aL6<0LVYG07Qa>`0Ki0T00P00o`08oooooa@00?l000@0j6Pl0:0Pl02h>;@0^3Rd7P2P8?00
0`2h>;@0X23`0:0Pl0020:0Pl0030;Ph]02P8?00X23`01L0X23`00@0^3Rd02S8?000o`000?l02ooo
ool000[ooooo0`00o`00D`0Ek@H0Mbh=08D<102K20@0Z0D30;481P2b1PD0_@X:0;d:302k1@T0b0`>
0<l@403@4180d18F0<0H6@2Z7b40Y2LX09PW9`2C>cH0TDe708eQE@2AMf/0TX5e0926NP2=RWh0Rh]n
08n>Q02>ShP0TiFB09JHV02JXJ00YZn/0;6k]`2laL@0cM?F0=WNh03TjN`0ko3c0?Ccn03fm?P0mO;f
0?C`mP3`k_<0kN[`0>[Wk03ThNH0h]gQ0>3Ig03Ccm00c/g<0<C6`@2o_k`0`;fi0;^g/`2b/Zh0Z:RU
09bNVP2HViD0T8n:08V:PP22QW`0OH9j07MnM@1gOW80NGa`07MeJ@1iL6P0OFYP081FC`1o@3/0UcHc
0:LP902Y3aL0YPP@09T21`2@0PH0R04308`10`2A0P<0S@4308L20P1l3`@05]H000800?l02Oooool3
003o000302S8?03oP000oh0000l0oh000`3@D7P:0:0Pl080d51h00<0j6Pl0?n0003oP0001`3oP000
0`3@D7P0oh000?n000060?n000@0d51h302P8?000`2h>;@0d51h0=1@N00;0?n00003052@N000o`00
0?l000Sooooo5000o`00@P0Xf@l0Fchd0657;@1lHSX0OVM306iRAP1aJDl0OFY9081[B022KU00Q7AK
089dFP29NEh0RgUL08IcE@28LDh0Q6a308I[AP25K4<0Q6Tn08AY?01iHcP0QG5?08idEP2:Kdh0QFU3
08E[@`22JT80O6U=04Q?A@1jQ880ViB808UiI@2=O6@0T81Z091oJ@2=OFP0R7]W08MmKP2:PGD0S7e]
07aXB@1kJ480NfY<081cF026N5l0OgEO085gHP1oN6H0P7MV07YcH@1bLV<0KGE[079lN01gPh40MX9o
07B3PP1jQhD0OXJ408:5P01mOgT0OG]a07]dI@1nJe80J8l]01C^1`<00?l02?oooolD003o0003052@
N02h>;@0^3Rd0100X23`0`3@D7P50:0Pl0030=1@N02P8?00d51h0280X23`00<0^3Rd02S8?000o`00
0P00o`0;ooooo`002_ooool4003o001A09176P2F7P/0Y`d40;@:1`2k2`X0_0`90;/91`2`0P<0^`D9
0<`>4@3=4180ba<D0<@I6`2/;2L0U4Do095SG@2AO7<0RXEi08^9P@27Rgl0Rhf308b<PP2?ShH0TYB>
09NKT`2JWYP0XjNR0;2f]@33b<X0`/W=0<G9c`30aLd0^[c40:ZY/@2PWJT0W9VW09RDW`2DRYP0UXRF
09V;V02ER9H0VhnK09B6S`2CQHX0T8:409F3PP2?O7/0Sgml0926P@2?R880ThR308j0N`2BPW`0TXIn
09b>QP2OTH`0[9fF0;:QV`2bXYT0Zj2E0:>OTP2IUHX0Ti2608V9OP21QW/0OXAn07IoN01dNG80MWE^
07I]I@1oEe<0R3@`094Q7P2J4a@0SPH908X110280@40R04208X10@240P40Na4200<00?l02Oooool4
003o00h0oh003@2P8?050?n002L0X23`2P3oP003003o00Sooooo5@00o`00?`1U@Q80NUhb07]U?@1I
CSH0Gem@06YZE@1eI4@0NV8m07iW@`1mK500PgEJ089eFP26MET0Q6e=07mZ@@22KD@0QFm;08E^AP26
KD00QF`m08IY>P1oI3X0P6]=08EaE02;ME<0PVLn07]P<01hI3`0NWUU0:ZZY@2DQh00Yheb0:^?K`2R
SG<0[IAk0922L@2;PgL0Q7mb07ifIP23M5d0R7QK08eoH@2;P6H0SHIe08Z4L`2;Q740Vi5o09bGR`2O
WYD0VibG09:FU`2?UiT0S9JG08jHVP2=U9D0QY:@086<R`20QX@0OGij07]gK@1nKe@0N7dh03O85@05
003o00Sooooo5@00o`00103oP000j6Pl0:0Pl02h>;@>0:0Pl0040>QX?03oP000oh000=1@N0<0X23`
00D0^3Rd0?n0002h>;@0X23`0;Ph]00N0:0Pl0030;Ph]02P8?00J:Pl00D00?l02oooool000[ooooo
1000o`00D@1KM`P0Ral40:`D1P3350/0bQTA0<HC3@303P`0`14A0<4=3@2n3a00/AlL0:He<02LDd/0
T7=[08Z2N@27R7l0QXYo08Z>Q@2<T8L0SY6809>DS@2DUXl0VY^G09ZLV@2FVYL0VIfK09fPV`2FUI40
THj;08n<R@2?RX@0TXf709F?Q`2CRh80ThR109B:P02BQWT0U8Ig09B5MP2DQWT0VHf109fAQ`2JS7d0
V8Yi09Z<NP2JRgL0VHag09Z=O02PUXH0XIV909Z>N`2EQ780S7]V08YjHP2:NF40SGYV08]hH`2=Mf80
S7AN08igH@2BOFT0VXEc09b8N@2KS7h0WI:809ZBS02CT8H0R8Un0864O01jOGX0M79_075WH01_FE00
Kcdg07LK6P2A4A<0T0H708810P240@40P0@106L`1003003o00Wooooo1000o`000`3@D7P0oh000?n0
00080?n00080d51h302P8?000`2h>;@0X23`0:0Pl00/0:0Pl080d51h1P3oP000103XJ3`00?l0003o
0000o`08oooooa@00?l003h04>X207MD8@27J3X0IE/j04I6>@11Bch0GVUL071_G`1fJe@0NViC07]_
EP1nL5T0PGAK08=_E021KDX0Q6i608E_C@25Le00R79>08M/@@26Jcd0Qf/m08EX>`1mIcl0Ofe8089b
D02>Me@0P6Dh07YR=@1dITP0P7]]0923K`38YXP0aJF;0;>MR02]Tgh0QWAT085dI01nLE/0QWUN08Il
H`27OFH0Ui1i092<N028PWH0YJBF0;jn/@2o^[40^[Nc0;Zj^02b];@0ZJf`0:BWZ`2PYZT0V::U09>L
W@25SXd0OXF507YnN@1lN6d0P6]704fj6`L00?l02?oooolD003o0006052@N03oP000oh000:0Pl03o
P000d51h3@2P8?00103@D7P0oh000?n0003oP0040:0Pl0030=1@N03oP000X23`0180X23`0`3oP009
0:0Pl0030=1@N02P8?000?l000H00?l02oooool000[ooooo1000o`007@16Y@P0NBP209lN2@3481D0
aAlF0<DF402h4@d0[B4M09hW7P2?C3l0QW1V08R1N@26R840Phf508ZDR`2=V8l0SI>;08Z=QP24QGX0
QHAl08R8O`29QWd0SHMm09>>O`2ETX@0VIF:09RER02IU8<0U8ej0080Vi>00380V91n09J@N`2LU880
ViF309nFQP2MU880VY5m09Z@N`2GSWP0WI9n09Z>O@2HRWL0WI9o09fEPP2NV8@0X9V60:6IR02SWHd0
WIF309F6K`2?O6@0SG]R08imH@2<Nel0RWYP08MhG`26Meh0Q7=I08AaF@27LET0SGQL09F0I`2MSGX0
UHQf0961K`2>OVX0T85]08f2L02>QgT0Qh=j07elM@1aLFd0J6YU069FC`1V?cH0M2<K08092@1m0P40
OPX304e=0`<00?l02Oooool4003o00030830003oP000oh0000H0oh0000<0d51h0:0Pl02P8?00?P2P
8?000`2h>;@0d51h0?n000030?n000040=1@N000o`000?l0003o00Sooooo5000o`00?@0PdP<0Qf4Z
07iW@01SI580DeaB04YEBP1:ET/0HVYS07j0M01iNFL0MW1O07QcGP1mLeh0OG1H07m_DP24L540RGEG
08UgF@26MEH0Qg=@08McC028M4d0R7A@08UfD`29N5T0QgMI08YjGP2BPV@0SWiK08=cCP20LUH0NfmE
09=oIP2FQ700THEb09nAO@2MTG`0Vi5m09J?N`2DSgh0X:2>0:j^W@2g^j`0`LNk0<S<b@37c<X0`lS6
0<G6aP34aLH0_L310;Rn_P2d_;`0[;:f0::X[02AV9`0QXb>07^0O@1iNW@0OVmI06RB=`0Vg@l02000
o`08oooooa@00?l000<0D91h0?n0002h>;@00P2P8?000`2h>;@0X23`0:0Pl00S0:0Pl0030;Ph]03X
J3`0oh0000H0oh0000<0d51h0:0Pl02P8?001@2P8?000`1@T7P00?l0003o0006003o00_ooooo000:
ooooo`@00?l005405N`4080k1`2D;aT0[R8N0>Q]K02c6Q@0VR4G09QKCP20IeL0LG=V07n2O026R880
RHf608fBR`2:ShL0PXMl07inL`27Q7L0S8Qd09:;N@2FSWl0V9:009J@OP2HTWh0TXei09B>OP2?RWX0
UY9o09VDP02LU880Vi>109N@O`2FT7/0WYF309fEP`2PVHP0WIB30::HQP2NUh@0Xif<0:BMS@2TWHX0
XYZ70:2IQP2MVHH0WiZ80:6JRP2NVXd0Wib>09fIR@2AQg@0RWaW08IjH`23OVH0Q89/08B0K`22PG40
QHIi08j>P02CTH<0TXil09RBO02FSWP0V8ej09R;M`2KSGP0V8]c09F6K02:NF40QWAN08QiIP2AR7P0
RhMi07UjL01VJ680GUeH05a;@01W81T0P@l:07hC200[Q@400`00o`09ooooo`@00?l000D0D91h0?n0
003oP000oh000:0Pl0020?n004D0X23`00D0d51h0?n0003oP000oh0008300003003o00Sooooo5000
o`004`0TeP@0SVT`07a`EP1/LfX0IgEY06EbJ01OK6<0GfYU061^J`1hQ800NX9j08>8O@25QWX0PhAd
08N4L`28Pfl0RhE`0929M@2@S7H00P2ET7P09P2?RW40ShU`09FAN02ITg`0V8ii09N=N02CRgD0Thec
09:>L`2GT7L0W9R20:FQS@2g]:<0aLFg0=ODcP3NfMD0h=kJ0>_[i`3fmo<0oOkk0?7clP3UjNX0g>7R
0=WKg`3Dfmd0dmWK0=7If`3>d]P0`/O<0;c4aP2[]KP0WZNZ09FJW027QXH0OGA^07]gC`1EXbX04nd8
2P00o`08oooooa@00?l000<0D91h0?n0002P8?00802P8?030=1@N0d0oh0000<0d51h0:0Pl02P8?00
0`2P8?000`1hF;@0:<Pl003o0009003o00_ooooo000:ooooo`D00?l00500QYX_0:=SCP2U<Bh0`dE4
09db9P24FDP0LfYM06mbI@1gOW00QhQn08N7O@22PGH0R89f08R2M02=RWH0UY5n09ZDP@2JU800VY=o
09ZCP02ITWh0Ui9m09ZDP@2HT7d0VY>109N@O@2KUX@0VY>009bDPP2MUh@0V9F109^HQ@2LV8D0VIF4
09^HQP2OVXT0XIZ;09jIRP2NW8d0WI^=09fLSP2OWXl0Z:BG0:FTUP2VY9P0YZFI0:BUW02PYIT0X:FK
09jRV02FW900V9nB09bVV@2LY9T0SYF=08B?R01iQH80NHF307f7Q020R880QhUm096<O02HSg`0Wi9l
0:2@N`2MTGT0WI5j09Z<M`2HRG40TX9[08n0J`2>PFh0QWe]07mlL01dLVT0H5iE05I0=@1O8A<0HaH7
01jT0@<00?l02Oooool5003o00060=1@N02P8?00j6Pl0=1@N03XJ3`0^3RdAP2P8?00103XJ3`0oh00
0?n0001XZ3`3003o00Sooooo5000o`008`0;mP80TFHZ07agH01dPGP0Kgeh07J1OP1kQ8@0Ohb<07n=
S@24T8l0Q96>08NET`2:UiL0WZVV0:Zc[@2i_[H0^l6g0;o2^@2j_k<0`/Rk0<36_031a[X0^l2c0<76
^`3:cl<0blo30<g?`P3Cel/0g>3C0>CUf@3/k>@0mOG_0?cln03nood0o_km0080o_kn01@0oooo0?kn
oP3nooh0o_ko0?gmo@3mo_h0o_kn0?gno@3bloH0i>O[0=KIgP35bm00^l340;6d^@2UZ:/0U9:>08Ig
I@1KVC<0><XH00_g10`00?l02?oooolD003o000302S8?03oP000X23`00X0X23`00<0^3Rd0=1@N03@
D7P00P3@D7P20:0Pl0070=1@N02h>;@0X23`0=1@N02P8?00d51h0:0Pl0020;Ph]0<0d51h00<0j6Pl
0?n0003oP0003`3oP0000`3@D7P0X23`0:0Pl0020:0Pl00306RX?00Xb3`00?l000/00?l02oooool0
00[ooooo1P00o`005P2KMdP0SS<U0917=P1hGTh0KFiO07AgIP1kOfd0Ogm^08IoK02;Pfh0UH]h09F9
M02ISW/0UHmi09B?N@2JTh40ViF409jGQP2PVXT0WiZ90:2KS02NVhd20:2MSP0X09jKSP2QWi@0Y:6G
0:VVV`2^ZIl0XZ6F09fOU02NWi<0VI^A09bOU`2KXIX0Xj^T0;:i/@2f_KD0/kZe0:jf/02/]J/0[[B_
0:fd[P2]]Jl0WjNS096HUP29TY40OHR406mmN01aOWH0P8Z009fPUP2][:00WYf?08b7N01jMF@0MFaN
06YSE`1GGE<0JW9[07n0M@2@QgL0WI9m0:6CO080WY5k00d0V8]d09V<M02OTG/0V8]e09F<N`1iM6D0
HV9C06YWE`1nMfD0JF1@05E5<`1@9A@04/<100<00?l02Oooool6003o00030>QX?03oP000d51h0240
X23`103@D7P00`2P8?00d51h0:0Pl0020=1@N1l0X23`0P3oP000101@T7P00?l0003o0000o`08oooo
oaD00?l00140C;@D07m/C01dOG80N8R0086?S02:UID0TYjO09>RXP2JZ:L0XZj]0:Jb]02JZ:/0ZkRi
0<3;b`3Bg=`0gnKU0>?[jP020>S_kP090>O^k@3Zlo40j?3_0>kcl`3cn?L0loKf0?Gin03io?`0o?gm
0080oOkn01L0oOgm0?clo03lo?d0o?cm0?_ko03hnOT0n_Wi0?SinP3inOT0o?ck0?knoP3moOd0n__k
0??dm@3[k^l0i>SZ0=[Jg030_l00[:BO0:6>O01QXSl0@/8P01K`2P0?003o00Sooooo5@00o`000`2@
L7P0^3Rd0:0Pl0050:0Pl0050;Ph]03@D7P0d51h0:0Pl03XJ3`08P3oP0001P3XJ3`0d51h0;Ph]02P
8?00D91h02S8?0l00?l02oooool000[ooooo1P00o`00@`1]`CH0M5Dj06aMB01fJeX0OWUV07]hI01_
K5/0QGm/09F:L`2HSGH0Uhei09^CP02GT7d0WIB209fHQP2KUXP0WYZ@09fIS`2QWI@0Y:2E0:NRU`2X
Y9L0Yj>F0:VVVP2ZYj00/ZfX0;Jb[`3=b<P0c/O<0;Je]P2MXZ80RI:F07n<S@1nS8l0NXZ;07Z<RP28
UI00V:6M0:>YY`2Y/:`0[K>^0;>g/`30aL40b<g90<K;b@39c/h0a<[80;Vl^`2_[j`0VifG0::QWP31
^l00`k_00;J[Y`2MSG`0VH1V09UiFP2AL4l0OfM806IKA`1UGd`0R7eX09jANP2OTWT0WY1i09b@N@2L
TG`00P2JSgT02@2ERgP0RhQm06AXHP0mBSl0@4Xl05ID@@20M5`0NFYC05a0:@04003o00Wooooo1P00
o`000`2XR3`0X23`0:0Pl00F0:0Pl080d51h00@0oh000>QX?03@D7P0^3Rd1`2P8?000`2h>;@0d51h
0=1@N0040=1@N080oh001`3@D7PB0:0Pl0030>QX?03oP000^3Rd0080X23`00<0^3Rd003o0000o`00
0P00o`08oooooaH00?l002D0FIlL07e_DP1mPgT0QY:=08^JV@2IYjL0Wjf^0:nk_@2jaLL0`lc>0<;;
c034cLh0bmGG0=OPh`3JhNH0f>;U0=WTj03KhnP0g>CX0=cVj03Li^X0g>KX0=SRi03Li>L0g^KX0>;U
j@3Qi^T0i>O/0=kTi`3Ri^X0i>OY0>S/k`3]l_<0l_Gf0?Ogn@3gmoP0mOGf0080m_Oh00X0m_Kg0?Sg
nP3fmOD0kNOY0=K:bP2o[:40SZMU05bf=@0[h1H03?P64P00o`08oooooaH00?l000<0T71h0;Ph]02P
8?000`2P8?000`2h>;@0oh000?n0000R0?n000060>QX?03@D7P0^3Rd07QH]01@T7P0:<Pl4P00o`0;
ooooo`002_ooool6003o001>03o>6P1]FSH0N6Y=089eG@1`Ie80JVAA06QVEP20OFd0TXQe09bDOP2@
RW@0UY1l09VEPP2DRg/0UXil09R=OP2LTH@0WYJ90:2MS`2MUHP0WYJ809fGQP2KUH@0VIB209ZBP@2J
T840V8j309R>Q@2>R8D0Ngj105iXKP1?GfH0B5UK04mNF`1`NG@0Vj>L0;g6_P3Fg=P0h^OW0>_]lP3X
j?00gM[R0<2k`P2[YJX0V9:G08=lO`1kKfd0OF]S085ZG024L5/0SG]T09N4L`2QSh00XHmi0:6?L@2M
R6H0UWiM08meD`2GMTh0Sg1:08M^B023KD/0Y9Em09jBN`2OTgl0VXij09nGPP2KSgX0V8aj09:>PP1Z
KF/0AU9>04EDAP1:EDD0D5A607EbF`24MEX0MUdn1000o`09ooooo`H00?l000<0D91h0:0Pl02P8?00
8P2P8?050?n002@0X23`1000o`08oooooaL00?l001@0;<h>07Em>P28PG00PHN0096KV02QZjX0Yk>e
0;6l`@2i`lH0_/O;0;c6bP31cLl0`loB0<G?d`38dM@0am7E0<OBd`34cm00b]OG0=3Jg080c]SJ01H0
e=_N0=WPh`3Kh><0f^3S0=gRi@3Ki>D0gnGU0>7Ui`3UjN/0jN_^0>c]l03_l?40l_;d0?Ccm@3bko00
i]kM0=[8``3</J<0Vjm]05S4>P16dbD03?P65P00o`08oooooaL00?l000<0J:Pl0;Ph]02P8?000`2P
8?000`3XJ3`0oh000?n0000M0?n00080d51h00@0^3Rd052@N01@T7P0:<Pl5P00o`0;ooooo`002_oo
ool6003o001>04jU501nId40QWQF06YQA@1=BcH0De=205iQE01nOW40ShMe09ZAO@2?RWD0Thik08Z2
K`2BQW80U8E_0921J@2DQ6h0UHYg09:=NP2FSGd0UHil09N>N`2HSgX0Uhmk09^AO@2KTh00W9>009J>
O01kOG80EeeJ045<B01;ETd0MWa`07mmL02GSh@0Y9fG0:bTY02YXJ@0Vi:C08j1P026MW<0RgM[095i
I@2FOVD0WXI_0:68K@2QQfD0W7eE09AgD02:N5d0TXI]09R;LP2RV8<0Yij:09^DPP2BSWh0Q8=e07Ic
H`2<LDd0X7U909ahA`2;K4D0XXmf09f<M@2KRG<0Th5Z08QgG@24M5T0OgEV06U_K01:EeH0BUM@04mL
C`1CGU00FfEF08>:N`29PV/0R6e;1000o`09ooooo`H00?l000<0Z8Pl0:0Pl02P8?00802P8?030=1@
N0T0X23`00<0d51h0;Ph]02P8?002@2P8?020?n000030;Ph]02P8?00X23`00h0X23`1000o`08oooo
oaT00?l002D0=lPD062O<@2>NUT0UX]j0:FQVP2^/jh0/KRe0;Jn_@2f`L40]l310;o7bP33bld0`l[<
0;k;c@30bl`0_lO:0;k8b@34c/h0alo@0<O?d@39d=40c]CF0=;Gf03FfM/0fmcK0=WLf@3LgMX0f]GF
0=C;bP3Fb/H0d/>j0<fdXP2_]H<0T[UY06O2@`1AcB`09>XB01/00?l02?oooolI003o000606RX?02P
8?00^3Rd0:0Pl02h>;@0d51h5`3oP0030=1@N0050?n0002P8?00N5Rd06RX?01@T7P06`00o`0;oooo
o`002_ooool6003o001>06Z=8P2<M540LFU=051?=`1<CcX0Ce0o04mA@`1UIU`0QX9e09>;NP2ITX00
V95n09jCOP2ERG80UhM^09V:L028MUd0UX=Y09f>L`2GRFl0UHM[09J4IP2HPfH0V8AV09V5JP2LSGL0
WXmj09b>NP22NfH0KFMB07E/E@1nLUH0TX1T09=mG@2LPF00Y8YZ09J2IP2EQg80]jZI0<2dY`2PU800
U8AW09V8I`2@RW00NGQZ08V3L@2APF<0XHAI09AjDP1OFdP0MGQ^08B2MP2LV8h0/J^Q09FAQP1mNFd0
KFiN071ZDP2HNdh0YWe80:9kA`2INe40TGaP08ehG02>Neh0SGmR08AjH`1kMfL0G6EM051OE@1AGU<0
FFAG05eVF`1QKF40KGQ]086:P@2_[Ih0S71<1000o`09ooooo`H00?l000<0d51h0:0Pl02P8?00;02P
8?000`3XJ3`0d51h0:0Pl0080:0Pl0040>QX?03oP000oh000=1@N0l0X23`00<0d51h003o0000o`00
0P00o`08oooooa`00?l001`07nD;03S96@17^R/0Lim607BRCP2AWFT0ZIF00:bKRP2bXYP0]ZRN0;BZ
W`2g[Z<0]ZfT0;V/XP2iZj40^ZbR0;j^X`2o[Il0^jZH0;nYU@2`ZH00R[QY07fhF01EacX0F<De053<
:@0`i1T09N/A8@00o`08oooooa`00?l000<0D91h06RX?01@T7P00`2P8?000`2h>;@0d51h0=1@N00;
0=1@N0030;Ph]02P8?00X23`0080D91h00<0J:Pl052@N01@T7P08@00o`0;ooooo`002_ooool6003o
001>09id=`2;MUH0O7]Y04mDA01?E4<0CeA505=FB01CEdX0HfEN07ioM02;RGX0UHik09fEP@2RUX@0
TXI^09Z<LP2LS780U89Y09nBM`2RUWd0VXec09Z>K`2LSG00WHa`09^9K02KRW80Vh]b09n@M`2APFD0
SWQE08]`A02YS600]YI^0;6DK@2]Sf/0[8m^0:ZBL`2RT7X0WY>309ZCPP2JTgl0Ui9k09:AO02UZ9P0
WZ>G08J1L`24L5@0[XmT09elCP1hJ4`0J69D081aG@2BQg40/Z^I09NCQ01mMfX0OW]X08YkG02LOTd0
W7];0:R>IP2[W7l0ZIf90:nVUP2XXi<0Rh]n06eaJ01NIV40GFUQ05m[F`1NJEX0HFiO06IbJ01ZMfd0
M7mf08B;Q@2JTh@0UgI91000o`09ooooo`H00?l000<0oh000:0Pl02P8?006`2P8?000`3@D7P0oh00
0:0Pl00>0:0Pl080d51h2@2P8?020?n00140X23`00<0d51h003o0000o`000P00o`3=ooooo`002_oo
ool6003o001>07JI;@2:NU`0Oh1d061VFP1EG4d0DEU905EMCP1FGDl0F5iC065WG`1lOWL0THn209RD
Q02PVX/0WiV709nFQ02TW8X0YIf:0:>LR@2XXI40Xi^:0:2JQ`2NV8D0X9J509jDO`2JTGh0VY9k09^C
O@2KSWH0VGmL0:>4EP2_UF/0Z8iX0;6@JP2YRVH0Vh=W0:25J@2AOV/0QhIl0:R[WP2/[J00_;ba0;2^
X`2AS7h0PGi/08QhG02PQEh0ZXUI0:AnB`2QQ5`0U81S0:J>LP2gYI<0f]7>0:JOVP1lKUh0PgAH09V4
HP2WTVd0/::70;6XU`2/Yi/0Xj6J08Z<Q`1mP7T0JW5V06I]I01XKVP0Ig5Y06]cJ@1/Mfd0IgE/06aj
M01`NgP0O8F008f;PP2<NF00MYXa1000o`09ooooo`H00?l000<0d51h0:0Pl02P8?006`2P8?000`3X
J3`0d51h0:0Pl00>0:0Pl080oh0000H0d51h0:0Pl02P8?00X23`0=1@N02h>;@30:0Pl0030=1@N02P
8?00X23`0100X23`00<0^3Rd003o0000o`000P00o`3=ooooo`002_ooool6003o001>06N/9P2FQVP0
O7i_06acJ01OIe`0Ff5H05IPE01JHUH0GFMI05mZF`1TIel0JVaV07QjL`2>SHH0WY^C09bJT02KVH`0
WIV;09nKS@2NVHX0Xif>0:>NS@2/YID0[ZFI0:bSU@2XXi<0[Z^K0:RRT`2YXI40WHih09=jF@2LQ5d0
WXQR0:n?K@2UR6/0SgaU09QmIP2QQg<0ZYnH0<O2`@2a[JT0YibH09N8N`2>OV<0TWaI09n3F02^U6`0
[9E_0:V?J02ZU6`0Z9E`0:JCM@2UUGd0Z9V60:RGO`2VUWh0]:JC0;N/W@2/Z9d0WIjH08f@R`25RH<0
MGYc07IjL`1eNg80O8Ai0867O`1nQWh0Lh1j071oN01bPGX0KH1j07V6PP22R8<0RXV008UgGP2<Rcl0
5^l81000o`09ooooo`H00?l000<0Z8Pl0:0Pl02P8?008`2P8?00102h>;@0oh000=1@N03@D7P30:0P
l0D0d51h00<0^3Rd0:0Pl02P8?005`2P8?000`3@D7P0:<Pl003o0003003o0<gooooo000:ooooo`H0
0?l004`0:Md=09n9I01lN6D0LGIX06QcJ01SKVD0GVYO05eWGP1TKV40J71T06YaI`1WK6<0J6mV06U/
I01/KVL0PH5k09RESP2OWI<0ZJFM0:BQU`2OWhh0ViV709VDQ02MUXT0VIB709:?P@2FT8<0VY6409ZA
P@2HT7P0V8a]09V8H@2HQEl0V8=Q09N5J027Med0TGaQ09J0I@2KRW@0WXmm0:FDO`2YUh00]9n30;RU
PP2o[Xd0_[2A0<>iWP2eZiH0]ZfI0;R`W@2e[i/0]ZjO0;2XU`2m[il0^Z^J0;N[X02/YYh0XYjI08n=
R@26RX@0P8Eo08:5P`22R800P8El08F;PP2=UHd0QH^807b7P`1fPWh0NXJ207f9PP1lRXD0QY2:08^=
Q@24NFH0R8Ln1P00o`09ooooo`H00?l000<0D91h0=1@N02P8?00B@2P8?06003o0<gooooo000:oooo
o`L00?l004/0P94h099oHP1jMfH0NWmf075jM01YM6d0Hg1X06McJ@1YMF/0KgQ_06meJ@1dNfh0LWU/
079eJ@1`M6`0LgM`07MhL021OgX0QhR208nBRP2LWI@0Y:BH0:VWWP2]ZZ00/JnS0;2^X@2a[9h0ZJ>B
0:n[UP2_ZiD0]:bJ0;J]U`2m]9h0`[^S0<BmY03;`jT0dlVb0=WA_03NeL80hMW60=_D`03@ak@0cLJd
0<g8^038a[D0a/Fe0<;1]031`;H0_;be0;Zj/@2h]Jh0^[2V0<2_Y02cXi/0XiZD09^FT@2KV9<0UiVD
09FIU02CUY<0TiJD08fDS@2;Th`0RY:;08NCS`22Shh0P8n<082?R026T8/0Ri:<08jDS`2AShL0SGiW
07Z??`0Rj0h01P00o`09ooooo`L00?l000<0d51h0:0Pl02P8?00;02P8?000`2h>;@0d51h0=1@N00G
0:0Pl0030;Ph]00Xb3`00?l000D00?l0cOooool000[ooooo1`00o`00400;m`@0IJ`V08n7E02ETX<0
QX^407n8PP1cOgP0L7]d071kM@1dPGT0M7mb07b2N01mPWP0PhMn08N<Q01fNg8207EkL`0g07AnM@1e
OWT0NGij07]oO01jP800P8N808^DU02FWj00WJJT0:J^Z02Y[jT0];Vc0;Rm]@36bkl0c=;70=GKcP3R
iMX0jngT0??bk03jnOD0o?ci0?glnP3inOD0mOG`0?7ckP3[k>T0hnOQ0=OOfP3?fMD0cMKE0<37b@33
alL0`lC20<S5_P33_[P0`;fg0;bm^02e][80/K>^0:N[Z@2QZJP0Vj:R09bRX@2DWY`0U9jM092KV@2=
VIH0Si^G092LV@2?VID0T9B?09NER`2DQG80LY/m047A7008003o00Wooooo1`00o`000`0Xb3`0d51h
0:0Pl00G0:0Pl0090=1@N02P8?00X23`0>QX?02h>;@0X23`0;Ph]02P8?00^3Rd0080d51h0`3oP000
1@3XJ3`0oh000?n0003oP000j6Pl00H0oh000`3@D7P00`3oP000d51h0=1@N0020;Ph]0d0X23`00<0
D91h003o0000o`001P00o`3=ooooo`002_ooool9003o000Q01C_201jY4<0WX]^09^EQ@2>U8T0Qi69
07R3OP1oSHL0PHb607n7Q020RHH0Qi:<08^DSP2;TX`0RXn:08VAR`25T8X0TijJ08jGU029TY00OHN7
08JBTP2?W9/0SY^K096NWP2LYjL0Z;6`0;Jo_`2oc<T0bmGC0=GNg@3TjnT0m_Wi0080o_kn00@0oOgn
0?knoP3no_d0oOkm0P3no_h0703loOd0lOCd0>K/k03Tk>`0hNSY0=GMgP3Ggml0e]cL0=GGe`3@d/l0
d=?A0<76a@2j`L40][fm0:^c/`2W/:l0YZn]0::/Z`2NZJT0WJRX09bVY02GWI`0U9JE08j>R02:P6d0
Oha=04Vj9`0[h1<:003o00Wooooo2@00o`000`0Xb3`0^3Rd0:0Pl00F0:0Pl0030;Ph]03@D7P0oh00
01/0oh000P3XJ3`00`3@D7P0^3Rd0;Ph]0060:0Pl0030;Ph]01@T7P0D91h00X00?l0cOooool000[o
oooo2`00o`008`0]hA<0RHU209f?M@2JVX`0Qh^008fES@2@VIH0SiZH08VDTP2<UY<0Si^I092KVP2@
VIP0VJ:O09ZSX`2OZJP0TYbK0:6[Y`25Thh0Tj:N0:F`[@2d_[d0]l:o0;g6a@2e_;`0b]3B0=KNh@3I
hN00h>GW0>S]kP3cm_L0ooon0?knoP3moOh0oOgm00<0oOgn01X0o_kn0?Kfm`3bm?D0j^o_0>W^kP3W
kNd0gN;T0>3Vj03MhN<0emcL0<cAd@3:cll0aLW:0<35a`2e^k`0^;fm0;:g]`2Z[k40Z[2a0:B][P2N
YZL0VI^L08j5O`2=NFT0U7ID05C09Pd00?l02Oooool;003o01@0X23`00<0d51h0?n0003oP000803o
P0000`2P8?00oh000=1@N0060:0Pl0d00?l0cOooool000[ooooo3@00o`00?@0lcQ`0H;0k0:68I`2L
SGP0WYV?09RITP2GViP0V9jL09ZTX`2;V9L0SING09fXY`2R[Jh0Xjf/07n;R@2R[Z/0YkB_0:Fb[`2h
`L80a<k@0<SAdP3Dg=h0dMSI0=_PhP3Ign40hNKX0>S]kP3]l?40n?Wj0?gmo@3oool0oOgm0?knoP3m
o_h0o_kn0?gmo@3oool0no_k0?Ggm`3_l_<0kO7c0>_`l@3QinP0hNKX0=_PhP3CfMT0dMWF0<cAd@36
bld0aL_:0;g2`P2i_L00];Vi0:n`/@2TXj<0V92:09R9N024T5X0Ek@a02KL4`0Gl@/03P00o`09oooo
o`d00?l000<0J:Pl07QH]03@D7P0202P8?00102h>;@0d51h0=1@N02P8?030=1@N2<0oh0000P0d51h
0:0Pl02P8?00X23`0;Ph]01hF;@0D91h02S8?0h00?l0cOooool000[ooooo4000o`00=P0]hA@0D;dY
07ZQA@2KT6@0Wh]e0:FGRP2[XIL0[JRQ0:j^Z`2_/[40/KFb0:ne[`2f_;T0]ko00;[1a02maLP0`<S;
0<S>d@3?f=X0dM[K0=SOh03PjNP0ing_0>cal@3fmoH0o_gm0?ooo`3no_h0o_gm0?gmo@3no_d0o_kn
0?kno@3no_h0o_ko0?_mo03hnOT0m?Gg0>_^l03UjN/0hnKY0=cOhP3Hg=d0d=CE0<[<b`2l_K/0[jbY
0:^SW02VUHH0QZ=Q07jXCP1M^CD0:n4G01[c3A800?l02Oooool@003o0004052@N01XZ3`0X23`0;Ph
]0@0X23`00@0d51h0?n0003oP000j6Pl8@3oP0001`3XJ3`0d51h0=1@N02P8?00^3Rd0:0Pl01hF;@0
0P1@T7PB003o0<gooooo000:oooooa@00?l001h06?4;05>n9P2YPE40XX1N0:V@NP2bWhh0^jVM0<Fg
[`3:_K`0a[no0;nl_P34`lD0aLK40<g?cP3AemH0f^7O0=gQhP3VkN`0jnk_0?GfmP3jno/0oOgm0?ko
o@3no_h0o_gm0?gmo@3no_h0o_on0?kno@3mo_h20?gmoP0=0?Kfn@3em_T0k>__0>SVj@3MfMd0c/S9
0;fbZ`2`XID0Z99o0:N8I022YDL0G<Lb03CX6P0G003o00Wooooo5000o`000`1@T7P0X23`0?n00004
0:0Pl0030=1@N03oP000oh0001`0oh0000L0d51h0:0Pl02P8?00X23`0?n0002P8?00D91h01L00?l0
cOooool000[ooooo6000o`009P0]hAD0GLH]04[89P21]4/0S[1J08Z`G`2>^6X0W;Yl0<F_V034/9l0
bKV]0<g1]`3@al80e/g90=K=b`3Sf]P0jn?P0>_ShP3[i>@0k>CS0>gThP3`i^@0k^CR0>WNg03ReM40
g<k70=c;`@3F`[H0d;VX0<^aV`2C`7<0SkUX08jeG`1o]Th0G<Pc02gS6@0cia`06o@=6P00o`09oooo
oaP00?l000<0D91h0830001@T7P0102P8?000`2h>;@0X23`0=1@N0050=1@N0030>QX?03oP000oh00
00H0oh001@3@D7P00`3XJ3`0^3Rd0:0Pl0020:0Pl00406RX?01@T7P0D91h02S8?1X00?l0cOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {177.5, 0}} -> {-0.107233, -0.0446483, \
0.0105626, 0.0105626}, {{10.125, 98.1875}, {173.25, 4.1875}} -> {-17.1322, \
-6.21784, 1.692, 1.692}, {{107, 195.062}, {173.25, 4.1875}} -> {-181.044, \
-6.21784, 1.692, 1.692}, {{203.875, 291.938}, {173.25, 4.1875}} -> {-393.575, \
-30.3891, 1.93047, 1.93047}, {{300.75, 388.812}, {173.25, 4.1875}} -> \
{-580.589, -30.3891, 1.93047, 1.93047}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Coke\>", "\<Coke Light\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.0074003 [
[.27273 -0.0125 -14 -12 ]
[.27273 -0.0125 14 0 ]
[.72727 -0.0125 -32 -12 ]
[.72727 -0.0125 32 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16272 -12 -4.5 ]
[-0.0125 .16272 0 4.5 ]
[-0.0125 .31073 -12 -4.5 ]
[-0.0125 .31073 0 4.5 ]
[-0.0125 .45873 -12 -4.5 ]
[-0.0125 .45873 0 4.5 ]
[-0.0125 .60674 -12 -4.5 ]
[-0.0125 .60674 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -14 0 ]
[.27273 .63053 14 12 ]
[.72727 .63053 -32 0 ]
[.72727 .63053 32 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -93 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16272 m
.00625 .16272 L
s
[(20)] -0.0125 .16272 1 0 Mshowa
0 .31073 m
.00625 .31073 L
s
[(40)] -0.0125 .31073 1 0 Mshowa
0 .45873 m
.00625 .45873 L
s
[(60)] -0.0125 .45873 1 0 Mshowa
0 .60674 m
.00625 .60674 L
s
[(80)] -0.0125 .60674 1 0 Mshowa
.125 Mabswid
0 .05172 m
.00375 .05172 L
s
0 .08872 m
.00375 .08872 L
s
0 .12572 m
.00375 .12572 L
s
0 .19972 m
.00375 .19972 L
s
0 .23672 m
.00375 .23672 L
s
0 .27373 m
.00375 .27373 L
s
0 .34773 m
.00375 .34773 L
s
0 .38473 m
.00375 .38473 L
s
0 .42173 m
.00375 .42173 L
s
0 .49573 m
.00375 .49573 L
s
0 .53274 m
.00375 .53274 L
s
0 .56974 m
.00375 .56974 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coke) show
93.000 13.000 moveto
(Light) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16272 m
1 .16272 L
s
.99375 .31073 m
1 .31073 L
s
.99375 .45873 m
1 .45873 L
s
.99375 .60674 m
1 .60674 L
s
.125 Mabswid
.99625 .05172 m
1 .05172 L
s
.99625 .08872 m
1 .08872 L
s
.99625 .12572 m
1 .12572 L
s
.99625 .19972 m
1 .19972 L
s
.99625 .23672 m
1 .23672 L
s
.99625 .27373 m
1 .27373 L
s
.99625 .34773 m
1 .34773 L
s
.99625 .38473 m
1 .38473 L
s
.99625 .42173 m
1 .42173 L
s
.99625 .49573 m
1 .49573 L
s
.99625 .53274 m
1 .53274 L
s
.99625 .56974 m
1 .56974 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .18449 L
.72727 .18449 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .18449 L
.72727 .18449 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .16614 L
.45455 .16614 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .16614 L
.45455 .16614 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .58497 L
.90909 .58497 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .58497 L
.90909 .58497 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3oool/0?ooo`?o0000HP3oool00?l0oooo;`3oool00ol00000oooo
0?ooo`1O0?ooo`00M`3oool2o`0000<0oooo0ol000020?ooo`;o000000<0ooooo`000?l000000P3o
ool3o`0007L0oooo0_l000030?ooo`?o00000P3oool2o`0000030?ooool0003o00000080oooo0ol0
00080?ooo`Go000000<0ooooo`000?l000000ol000020?ooo`Co000000<0ooooo`000?l000001?l0
00020?ooo`;o0000EP3oool007H0oooo00Ko00000?ooo`3ooooo00000?ooool000030?ooo`06o`00
003oool0ooooo`00003ooooo00000P3oool00ol00000oooo0?ooo`1g0?ooo`06o`00003oool0oooo
o`00003ooooo00000`3oool01_l00000oooo0?ooool00000ooooo`000080oooo00?o00000?ooo`3o
ool02P3oool01?l00000oooo0?ooool000030?ooo`05o`00003oool0oooo0?ooool000000`3oool0
1?l00000oooo0?ooool000020?ooo`04o`00003oool0ooooo`000080oooo00?o00000?ooo`3oool0
D`3oool007D0oooo00?o00000?ooo`3oool00`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo
0_l000030?ooo`Go0000M03oool00ol00000oooo0?ooo`030?ooo`05o`00003oool0oooo0?ooool0
00000P3oool2o`0000<0oooo1Ol000080?ooo`03o`00003oool0oooo00@0oooo00Go00000?ooo`3o
ool0ooooo`0000030?ooo`04o`00003oool0ooooo`000080oooo00Co00000?ooo`3ooooo0000F03o
ool007D0oooo00?o00000?ooo`3oool00`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00?o
00000?ooool000000P3oool01Ol00000oooo0?ooo`3ooooo000007@0oooo00?o00000?ooo`3oool0
0`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00?o00000?ooool000000P3oool01Ol00000
oooo0?ooo`3ooooo000000P0oooo00?o00000?ooo`3oool0103oool01Ol00000oooo0?ooo`3ooooo
000000<0oooo00Co00000?ooo`3ooooo00000P3oool01?l00000oooo0?ooool0001H0?ooo`00M@3o
ool00ol00000oooo0?ooo`040?ooo`?o00000`3oool01?l00000ooooo`000?l000020?ooo`?o0000
M@3oool00ol00000oooo0?ooo`040?ooo`?o00000`3oool01?l00000ooooo`000?l000020?ooo`?o
00002@3oool00ol00000oooo0?ooo`020?ooo`?o0000103oool5o`0000040?ooool0003o0000o`00
0080oooo1?l0001F0?ooo`00MP3oool01?l00000oooo0?ooool000080?ooo`03o`00003oool0oooo
07`0oooo00Co00000?ooo`3ooooo0000203oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`1F0?ooo`00M`3oool3o`00
00L0oooo0_l0001o0?ooo`?o00001`3oool2o`000100oooo0ol000050?ooo`03o`00003oool0oooo
00L0oooo0_l000050?ooo`03o`00003oool0oooo05H0oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo000R0?ooool00000
G000000C0?ooo`008P3oool00`000000oooo0?ooo`1L0?ooo`03o`00003oool0oooo09X0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`006P3oool2o`0000H0oooo00<00000
0?ooo`3oool0G03oool00ol00000oooo0?ooo`2J0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool04@3oool001T0oooo00Co00000?ooo`3ooooo00001@3oool00`000000oooo0?ooo`3o
0?oooeP0oooo00<000000?ooo`3oool04@3oool001T0oooo00Co00000?ooo`3ooooo00001@3oool0
0`000000oooo0?ooo`3o0?oooeP0oooo00<000000?ooo`3oool04@3oool001T0oooo00Co00000?oo
o`3ooooo00001@3ooooo000005`000004`3oool001T0oooo00Co00000?ooo`3ooooo00001@3oool0
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000I0?ooo`04o`00003oool0oooo
o`0000D0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`006P3oool2o`00
00H0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo
00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo
000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3o
ool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool30000
01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01`0oooo00?o00000000003oool04P3oool00280oooo00<000000?ooo`3oool07@3oool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003o
ogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl0
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?oo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
0?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00
003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00
003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003co
ogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003co
ogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`<000007@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool0703oool00ol0000000000?ooo`0B0?ooo`008P3oool00`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP
8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP
8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000
003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_o
X23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_o
X23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<0
0000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
0000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A
0?ooo`008P3oool3000001d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0P
l0030000003oool0oooo01`0oooo00?o00000000003oool04P3oool00280oooo00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3o
ool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0
oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0
oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0
oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0
oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00003oogl0
oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
0000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
0000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R
0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00k
oj0Pl0030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00k
oj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00180oooo1Ol000030?oo
o`;o00001P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0P
l?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000oj0P
l?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000C0?ooo`04
o`00003oool0ooooo`000080oooo00Co00000?ooo`3ooooo00001@3oool00`000000oooo0?ooo`0M
0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`0300000?ooO`3oogl003coogl000<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000D0?ooo`03o`00003oool0oooo0080oooo00Co00000?oo
o`3ooooo00001@3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000E0?oo
o`05o`00003oool0oooo0?ooool000000P3oool00ol00000oooo0?ooo`030?ooo`<000007@3oool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool0
0`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool06`3oool3
000001<0oooo000B0?ooo`05o`00003oool0oooo0?ooool000000P3oool01?l00000oooo0?ooool0
00050?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`0o000001l0oooo00<0
0000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00180oooo00Go00000?ooo`3oool0ooooo`0000020?ooo`04o`00003o
ool0ooooo`0000D0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo05/0oooo00<00000oomo0?ooO`00??ooO`000`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool001<0oooo0ol000040?ooo`;o00001P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3o
ool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3oool00`00
003oogl0oomo000loomo000300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003co
ogl000<000000?ooo`3oool0F`3oool00`00003oogl0oomo000loomo000300000?nP8?3oX23`03_o
X23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0F`3ooom0000003goX23`
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?oo
o`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3o
ool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`<000007@3oool00`00003oogl0oomo000loomo00030000003o
ool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0L0?ooo`03o`000000
0000oooo0180oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`00
0`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl0
03coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003o
ogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?oo
o`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3o
ool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo0`00000M0?ooo`0300000?ooO`3oogl0
03coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo
01`0oooo00?o00000000003oool04P3oool00280oooo00<000000?ooo`3oool07@3oool00`00003o
ogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?oo
o`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?oo
o`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3o
ool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00
003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0
oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_o
X23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`
oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo0`00
000M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0P
l00koj0Pl0030000003oool0oooo01`0oooo00?o00000000003oool04P3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000
oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?oo
o`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?oo
o`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3o
ool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??oo
O`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3o
ogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00
003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0
oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_o
X23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`
oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool001@0oooo0ol0
00030?ooo`;o00001P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool001D0oooo00Go00000?ooo`3oool0ooooo`0000020?ooo`03o`00003o
ool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003o
ool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0140oooo000B0?ooo`Go00000P3oool01?l00000oooo0?ooool000050?ooo`030000003o
ool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP
8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool0
1?l00000oooo0?ooool000030?ooo`04o`00003oool0ooooo`0000D0oooo0`00000M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01/0oooo0`00000C0?ooo`004`3oool00ol00000ooooo`0000030?ooo`04o`00003o
ool0ooooo`0000D0oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo000D0?ooo`;o00000`3oool01?l00000oooo0?ooool000050?ooo`030000
003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`030000
0?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`005@3o
ool00ol00000oooo0?ooo`020?ooo`;o00001P3oool00`000000oooo0?ooo`0M0?ooo`0300000?oo
O`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003o
ool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool0
0`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo0`00000M0?ooo`0300000?oo
O`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003o
ool0oooo01`0oooo00?o00000000003oool04P3oool00280oooo00<000000?ooo`3oool07@3oool0
0`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?00
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo
01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`
03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000
oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo0`00000M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003o
X23`oj0Pl00koj0Pl0030000003oool0oooo01`0oooo00?o00000000003oool04P3oool00280oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool3000001d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool0703oool00ol0000000000?oo
o`0B0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool001<0oooo0ol000040?ooo`;o00001P3oool00`000000oooo0?ooo`0M
0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00k
oj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00180oooo00Go00000?oo
o`3oool0ooooo`0000020?ooo`04o`00003oool0ooooo`0000D0oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000B0?ooo`05o`00003oool0
oooo0?ooool000000P3oool01?l00000oooo0?ooool000050?ooo`<000007@3oool00`00003oogl0
oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo
0?ooo`0K0?ooo`<000004`3oool00180oooo1?l000030?ooo`04o`00003oool0ooooo`0000D0oooo
00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
000B0?ooo`03o`00003oool0oooo00@0oooo00Co00000?ooo`3ooooo00001@3oool00`000000oooo
0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`
oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool001<0oooo00?o
00000?ooo`3oool00`3oool01?l00000oooo0?ooool000050?ooo`030000003oool0oooo01d0oooo
00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`00503oool2o`0000@0oooo0_l0
00060?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`<000007@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo
00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0L0?ooo`03o`0000000000oooo0180oooo
000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?oo
o`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<00000
0?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`<000007@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0L0?oo
o`03o`0000000000oooo0180oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?oo
O`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000l
oomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo
0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`03
00000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl003
0000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280oooo0`00000M0?ooo`030000
0?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00003oX23`oj0Pl00koj0Pl0030000
003oool0oooo01`0oooo00?o00000000003oool04P3oool00280oooo00<000000?ooo`3oool07@3o
ool00`00003oogl0oomo000loomo00030000003oool0oooo09X0oooo00<00000oj0Pl?nP8?00>onP
8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0
oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo0?ooo`2J0?ooo`0300000?nP8?3o
X23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0VP3oool00`00
003oX23`oj0Pl00koj0Pl0030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00280
oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo09X0
oooo00<00000oj0Pl?nP8?00>onP8?000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo01d0oooo00<00000oomo0?ooO`00??ooO`000`000000oooo
0?ooo`2J0?ooo`0300000?nP8?3oX23`03_oX23`00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<0
00000?ooo`3oool0VP3ooolo000001l0oooo00<000000?ooo`3oool04@3oool00280oooo00<00000
0?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo0?P0oooo00<00000
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo
00030000003oool0oooo0?P0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3o
ool07@3oool00`00003oogl0oomo000loomo00030000003oool0oooo0?P0oooo00<000000?ooo`3o
ool04@3oool00280oooo00<000000?ooo`3oool07@3oool00`00003oogl0oomo000loomo00030000
003oool0oooo0?P0oooo00<000000?ooo`3oool04@3oool001<0oooo0ol000040?ooo`;o00001P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?ooO`3oogl003coogl000<000000?ooo`3oool0n03o
ool00`000000oooo0?ooo`0A0?ooo`004P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co
00000?ooo`3ooooo00001@3oool00`000000oooo0?ooo`0M0?oood000000nP3oool00`000000oooo
0?ooo`0A0?ooo`004P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo
00001@3oool300000?l0ooooEP3oool3000001<0oooo000C0?ooo`?o00000`3oool01?l00000oooo
0?ooool000050?ooo`030000003oool0oooo0?l0ooooF03oool00`000000oooo0?ooo`0A0?ooo`00
4P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo00001@3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0A0?ooo`004P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co00000?oo
o`3ooooo00001@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool3o`0000@0oooo0_l000060?oo
ool00000G000000C0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3oool/0?ooo`?o0000HP3oool00?l0oooo;`3oool00ol00000oooo
0?ooo`1O0?ooo`00M`3oool2o`0000<0oooo0ol000020?ooo`;o000000<0ooooo`000?l000000P3o
ool3o`0007L0oooo0_l000030?ooo`?o00000P3oool2o`0000030?ooool0003o00000080oooo0ol0
00080?ooo`Go000000<0ooooo`000?l000000ol000020?ooo`Co000000<0ooooo`000?l000001?l0
00020?ooo`;o0000EP3oool007H0oooo00Ko00000?ooo`3ooooo00000?ooool000030?ooo`06o`00
003oool0ooooo`00003ooooo00000P3oool00ol00000oooo0?ooo`1g0?ooo`06o`00003oool0oooo
o`00003ooooo00000`3oool01_l00000oooo0?ooool00000ooooo`000080oooo00?o00000?ooo`3o
ool02P3oool01?l00000oooo0?ooool000030?ooo`05o`00003oool0oooo0?ooool000000`3oool0
1?l00000oooo0?ooool000020?ooo`04o`00003oool0ooooo`000080oooo00?o00000?ooo`3oool0
D`3oool007D0oooo00?o00000?ooo`3oool00`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo
0_l000030?ooo`Go0000M03oool00ol00000oooo0?ooo`030?ooo`05o`00003oool0oooo0?ooool0
00000P3oool2o`0000<0oooo1Ol000080?ooo`03o`00003oool0oooo00@0oooo00Go00000?ooo`3o
ool0ooooo`0000030?ooo`04o`00003oool0ooooo`000080oooo00Co00000?ooo`3ooooo0000F03o
ool007D0oooo00?o00000?ooo`3oool00`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00?o
00000?ooool000000P3oool01Ol00000oooo0?ooo`3ooooo000007@0oooo00?o00000?ooo`3oool0
0`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00?o00000?ooool000000P3oool01Ol00000
oooo0?ooo`3ooooo000000P0oooo00?o00000?ooo`3oool0103oool01Ol00000oooo0?ooo`3ooooo
000000<0oooo00Co00000?ooo`3ooooo00000P3oool01?l00000oooo0?ooool0001H0?ooo`00M@3o
ool00ol00000oooo0?ooo`040?ooo`?o00000`3oool01?l00000ooooo`000?l000020?ooo`?o0000
M@3oool00ol00000oooo0?ooo`040?ooo`?o00000`3oool01?l00000ooooo`000?l000020?ooo`?o
00002@3oool00ol00000oooo0?ooo`020?ooo`?o0000103oool5o`0000040?ooool0003o0000o`00
0080oooo1?l0001F0?ooo`00MP3oool01?l00000oooo0?ooool000080?ooo`03o`00003oool0oooo
07`0oooo00Co00000?ooo`3ooooo0000203oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`1F0?ooo`00M`3oool3o`00
00L0oooo0_l0001o0?ooo`?o00001`3oool2o`000100oooo0ol000050?ooo`03o`00003oool0oooo
00L0oooo0_l000050?ooo`03o`00003oool0oooo05H0oooo003o0?oooi40oooo003o0?oooi40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -8.37097, \
0.00636706, 0.391081}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{754, 725},
WindowMargins->{{1, Automatic}, {Automatic, 1}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 54, 0, 62, "Title"],
Cell[1811, 53, 204, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[2040, 62, 35, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2100, 66, 38, 0, 49, "Subsection"],
Cell[2141, 68, 161, 4, 63, "Input"],
Cell[2305, 74, 362, 7, 95, "Input"],
Cell[2670, 83, 55, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2762, 89, 39, 0, 49, "Subsection"],
Cell[2804, 91, 68, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2909, 97, 38, 0, 49, "Subsection"],
Cell[2950, 99, 180, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[3155, 106, 53, 0, 43, "Subsubsection"],
Cell[3211, 108, 202, 3, 79, "Input"],
Cell[3416, 113, 63, 1, 47, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3540, 121, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3601, 125, 42, 0, 49, "Subsection"],
Cell[3646, 127, 492, 9, 143, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4175, 141, 40, 0, 49, "Subsection"],
Cell[4218, 143, 391, 6, 127, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4646, 154, 60, 0, 49, "Subsection"],
Cell[4709, 156, 312, 7, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5058, 168, 55, 0, 49, "Subsection"],
Cell[5116, 170, 271, 5, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5424, 180, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5493, 184, 123, 3, 43, "Subsubsection"],
Cell[5619, 189, 752, 12, 159, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6408, 206, 96, 3, 43, "Subsubsection"],
Cell[6507, 211, 470, 8, 127, "Input"],
Cell[6980, 221, 164, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7181, 228, 64, 0, 43, "Subsubsection"],
Cell[7248, 230, 777, 12, 159, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8074, 248, 41, 0, 49, "Subsection"],
Cell[8118, 250, 1274, 20, 255, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9429, 275, 41, 0, 49, "Subsection"],
Cell[9473, 277, 965, 14, 239, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10475, 296, 55, 0, 49, "Subsection"],
Cell[10533, 298, 969, 17, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11539, 320, 68, 0, 49, "Subsection"],
Cell[11610, 322, 1333, 23, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12980, 350, 94, 3, 49, "Subsection"],
Cell[13077, 355, 958, 16, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14072, 376, 68, 0, 33, "Subsection"],
Cell[14143, 378, 1191, 21, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15371, 404, 94, 3, 49, "Subsection"],
Cell[15468, 409, 812, 14, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16317, 428, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[16393, 432, 60, 0, 43, "Subsubsection"],
Cell[16456, 434, 765, 14, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17258, 453, 58, 0, 43, "Subsubsection"],
Cell[17319, 455, 437, 7, 127, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17817, 469, 42, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[17884, 473, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[17952, 477, 427, 8, 111, "Input"],
Cell[18382, 487, 1431598, 19907, 190, 1150913, 16438, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1450029, 20400, 38, 0, 49, "Subsection"],
Cell[1450070, 20402, 127, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1450234, 20409, 40, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1450299, 20413, 52, 0, 43, "Subsubsection"],
Cell[1450354, 20415, 301, 6, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1450692, 20426, 33, 0, 43, "Subsubsection"],
Cell[1450728, 20428, 452, 10, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1451217, 20443, 33, 0, 35, "Subsubsection"],
Cell[1451253, 20445, 452, 10, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1451742, 20460, 33, 0, 35, "Subsubsection"],
Cell[1451778, 20462, 452, 10, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1452267, 20477, 33, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[1452325, 20481, 114, 2, 47, "Input"],
Cell[1452442, 20485, 507702, 19975, 70, 317673, 17626, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1960217, 40468, 56, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1960298, 40472, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1960368, 40476, 708, 15, 143, "Input"],
Cell[1961079, 40493, 140952, 4873, 199, 74687, 4052, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2102080, 45372, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2102142, 45376, 40, 0, 43, "Subsubsection"],
Cell[2102185, 45378, 243, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2102465, 45387, 37, 0, 43, "Subsubsection"],
Cell[2102505, 45389, 145, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2102687, 45396, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2102751, 45400, 91, 1, 47, "Input"],
Cell[2102845, 45403, 484214, 12180, 333, 294215, 9831, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2587108, 57589, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2587178, 57593, 198, 3, 63, "Input"],
Cell[2587379, 57598, 324160, 16819, 296, 251274, 15914, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2911600, 74424, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2911667, 74428, 317, 6, 79, "Input"],
Cell[2911987, 74436, 1384339, 19196, 190, 1189508, 16787, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4296363, 93637, 343, 8, 79, "Input"],
Cell[4296709, 93647, 1286477, 18243, 187, 1112318, 16089, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5583235, 111896, 32, 0, 49, "Subsection"],
Cell[5583270, 111898, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[5583426, 111904, 375, 7, 79, "Input"],
Cell[5583804, 111913, 50537, 985, 256, 8644, 464, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5634402, 112905, 56, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[5634483, 112909, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5634553, 112913, 708, 15, 143, "Input"],
Cell[5635264, 112930, 146619, 4941, 199, 74882, 4052, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5781932, 117877, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5781994, 117881, 40, 0, 43, "Subsubsection"],
Cell[5782037, 117883, 243, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5782317, 117892, 37, 0, 43, "Subsubsection"],
Cell[5782357, 117894, 145, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5782539, 117901, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[5782603, 117905, 91, 1, 47, "Input"],
Cell[5782697, 117908, 483978, 12158, 333, 293700, 9806, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6266724, 130072, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6266794, 130076, 198, 3, 63, "Input"],
Cell[6266995, 130081, 329870, 16913, 296, 251784, 15944, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6596926, 147001, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6596993, 147005, 315, 6, 79, "Input"],
Cell[6597311, 147013, 1388895, 19252, 190, 1189508, 16787, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7986243, 166270, 319, 6, 79, "Input"],
Cell[7986565, 166278, 1294030, 18336, 187, 1112318, 16089, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9280644, 184620, 32, 0, 49, "Subsection"],
Cell[9280679, 184622, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[9280835, 184628, 375, 7, 79, "Input"],
Cell[9281213, 184637, 50461, 978, 256, 8581, 458, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9331735, 185622, 56, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[9331816, 185626, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[9331886, 185630, 708, 15, 143, "Input"],
Cell[9332597, 185647, 129960, 4738, 199, 74694, 4052, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9462606, 190391, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[9462668, 190395, 40, 0, 43, "Subsubsection"],
Cell[9462711, 190397, 243, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9462991, 190406, 37, 0, 43, "Subsubsection"],
Cell[9463031, 190408, 145, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9463213, 190415, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[9463277, 190419, 91, 1, 47, "Input"],
Cell[9463371, 190422, 444936, 11463, 333, 290269, 9550, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9908356, 201891, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[9908426, 201895, 198, 3, 63, "Input"],
Cell[9908627, 201900, 270871, 13896, 296, 210212, 13142, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10179559, 215803, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[10179626, 215807, 341, 8, 79, "Input"],
Cell[10179970, 215817, 1393787, 19312, 190, 1189508, 16787, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11573794, 235134, 345, 8, 79, "Input"],
Cell[11574142, 235144, 1308922, 18520, 187, 1112318, 16089, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12883113, 253670, 32, 0, 49, "Subsection"],
Cell[12883148, 253672, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[12883304, 253678, 375, 7, 79, "Input"],
Cell[12883682, 253687, 49076, 967, 256, 8641, 464, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12932819, 254661, 68, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[12932912, 254665, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[12932982, 254669, 708, 15, 143, "Input"],
Cell[12933693, 254686, 129960, 4738, 199, 74694, 4052, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13063702, 259430, 59, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[13063786, 259434, 40, 0, 43, "Subsubsection"],
Cell[13063829, 259436, 132, 2, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13063998, 259443, 68, 0, 43, "Subsubsection"],
Cell[13064069, 259445, 43, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13064149, 259451, 66, 0, 43, "Subsubsection"],
Cell[13064218, 259453, 186, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13064441, 259461, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[13064511, 259465, 80, 1, 47, "Input"],
Cell[13064594, 259468, 69, 1, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13064712, 259475, 38, 0, 43, "Subsubsection"],
Cell[13064753, 259477, 359, 7, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13065149, 259489, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[13065210, 259493, 59, 1, 47, "Input"],
Cell[13065272, 259496, 329347, 8570, 408, 237837, 7437, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13394680, 268073, 65, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[13394770, 268077, 40, 0, 43, "Subsubsection"],
Cell[13394813, 268079, 132, 2, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13394982, 268086, 68, 0, 35, "Subsubsection"],
Cell[13395053, 268088, 43, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13395133, 268094, 66, 0, 43, "Subsubsection"],
Cell[13395202, 268096, 186, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13395425, 268104, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[13395495, 268108, 80, 1, 47, "Input"],
Cell[13395578, 268111, 68, 1, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13395695, 268118, 38, 0, 43, "Subsubsection"],
Cell[13395736, 268120, 359, 7, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13396132, 268132, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[13396193, 268136, 59, 1, 47, "Input"],
Cell[13396255, 268139, 412700, 11672, 408, 279127, 10020, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13809016, 279818, 58, 0, 49, "Subsection"],
Cell[13809077, 279820, 491, 11, 127, "Input"],

Cell[CellGroupData[{
Cell[13809593, 279835, 614, 12, 159, "Input"],
Cell[13810210, 279849, 439767, 9161, 408, 353764, 8096, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14250026, 289016, 42, 0, 49, "Subsection"],
Cell[14250071, 289018, 180, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[14250276, 289025, 355, 8, 79, "Input"],
Cell[14250634, 289035, 1400522, 19395, 190, 1189508, 16787, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15651193, 308435, 359, 8, 79, "Input"],
Cell[15651555, 308445, 1305418, 18476, 187, 1112318, 16089, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16957022, 326927, 32, 0, 49, "Subsection"],
Cell[16957057, 326929, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[16957213, 326935, 375, 7, 79, "Input"],
Cell[16957591, 326944, 52618, 1000, 256, 8538, 452, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

